(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   9894629,     199726]*)
(*NotebookOutlinePosition[   9927858,     200537]*)
(*  CellTagsIndexPosition[   9922547,     200416]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5.5 Similarity Reduction of Partial Differential Equations", "Section",
  CounterAssignments->{{"Title", 5}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 23}, {"NumberedFigure", 0}, {"NumberedTable", 0}},
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral},
  CellTags->"Reduction of partial differential equations"],

Cell[TextData[{
  "A similarity reduction of a differential equation is closely connected \
with the invariance of the equation. In C",
  ButtonBox["hapter 3,",
    ButtonData:>{"symmet1.nb", 
      "Symmetries of Ordinary Differential Equations"},
    ButtonStyle->"Hyperlink"],
  " we discussed the group invariance of ordinary differential equations. The \
invariance condition in connection with ordinary differential equations was \
beneficial for the reduction of the order or the integration of ODEs by \
quadratures. In this section, we will discuss the invariance condition of a \
partial differential equation to reduce the equation to an ODE or to a PDE in \
less independent coordinates. The first case occurs for an equation with two \
independent variables, whereas a general reduction to another PDE follows in \
cases with more than two independent variables. The reduction procedure \
generates a similarity representation of the original equation. Since we \
reduce the number of independent variables, a similarity reduction results \
into a representation which has some advantages compared with the original \
equation."
}], "Text",
  CellTags->{
  "reduction of differential equations", "group invariance", 
    "invariance condition", "reduction of order", 
    "integration of ODEs by quadrature", 
    "invariance condition of partial differential equations", 
    "similarity representation", "reduce of independent variables"}],

Cell["\<\
This procedure works independent of the nature of the PDE, linear \
or nonlinear. It is also independent of the order of the PDE and it does not \
need information on boundary conditions. The benefit of the reduction is a \
simpler equation allowing an analytic or numeric solution. Examples of \
similarity solutions are widely encountered in mechanics, hydrodynamics, in \
the general theory of relativity, etc. However, the solutions derived in \
these fields are mainly guesswork and lack an algorithmic procedure. We are \
going to show here that a similarity reduction is an algorithmic procedure \
delivering a large number of ans\[ADoubleDot]tze discussed in the literature.\
\
\>", "Text",
  CellTags->{
  "boundary condition", "similarity solution", "mechanics", "hydrodynamics", 
    "theory of relativity", "algorithmic procedure of similarity reduction"}],

Cell["\<\
The main idea behind a similarity reduction is the term invariance. \
The discussion of invariance is the first step in this section. To simplify \
the theoretical representation, we restrict the examination to cases with two \
independent variables. A generalization to more independent variables is \
straightforward.\
\>", "Text",
  CellTags->"invariance"],

Cell["\<\
Let us consider the general PDE in two independent variables and \
one dependent variable in the form\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[CapitalDelta](x, t, u, u\_x, u\_t, u\_\(x, x\), \[Ellipsis])\  = \ 
      0, \)\)], "NumberedEquation",
  CellTags->"eq-1"],

Cell["\<\
which is invariant under the one-parameter Lie group of \
transformations\
\>", "Text",
  Evaluatable->False,
  CellTags->{"one-parameter Lie group", "transformation"}],

Cell[BoxData[
    \(TraditionalForm\`\(\(x\^*\)\  = \ X(x, t, u; \[Epsilon]), \)\)], 
  "NumberedEquation"],

Cell[BoxData[
    \(TraditionalForm\`\(\(t\^*\) = \ T(x, t, u; \[Epsilon]), \)\)], 
  "NumberedEquation"],

Cell[BoxData[
    \(TraditionalForm\`\(u\^*\)\  = \ \ \(U(x, t, u; \[Epsilon]) . \)\)], 
  "NumberedEquation"],

Cell[TextData[{
  "Let us further assume that ",
  Cell[BoxData[
      \(TraditionalForm\`u = \[CapitalTheta](x, t)\)]],
  " is a solution of equation ",
  ButtonBox["(5.24)",
    ButtonData:>"eq-1",
    ButtonStyle->"Hyperlink"],
  ". Inserting this solution into the transformations (5.25)\[Dash](5.27), we \
can write"
}], "Text",
  Evaluatable->False,
  CellTags->"transformation"],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(x\^*\)\  = \ \ X(x, t, \[Theta](x, t); \[Epsilon]), \)\)], 
  "NumberedEquation"],

Cell[BoxData[
    \(TraditionalForm\`\(\(t\^*\)\  = \ T(x, t, \[Theta](x, t); \[Epsilon]), 
    \)\)], "NumberedEquation"],

Cell[BoxData[
    \(TraditionalForm\`\(\(u\^*\)\  = \ U(x, t, \[Theta](x, t); \[Epsilon]), 
    \)\)], "NumberedEquation"],

Cell[TextData[{
  "stating that ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\^*\)\)]],
  " is also a solution of the transformed PDE. The use of these facts allows \
us to define the invariance in the following way."
}], "Text",
  Evaluatable->False,
  CellTags->{"transformed PDE", "invariance"}],

Cell["Definition: Invariance", "Definition",
  CellTags->"Definition: Invariance"],

Cell[TextData[{
  "A PDE is invariant under a one-parameter Lie group transformation if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(u\^*\),
            "TraditionalForm"], "="}], TraditionalForm]], "InlineFormula"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ U(x, t, \[CapitalTheta](x, t); \[Epsilon])\)\)], 
    "InlineFormula"],
  " also satisfies the transformed PDE whenever ",
  Cell[BoxData[
      \(TraditionalForm\`u = \[CapitalTheta](x, t)\)]],
  " is a solution of the original PDE.\[ThickSpace]\[EmptyCircle]"
}], "Text",
  Evaluatable->False,
  Background->None,
  CellTags->"invariant under a one-parameter Lie group"],

Cell["\<\
If we additionally require that we can solve this problem uniquely, \
we end up with the functional equation\
\>", "Text",
  Evaluatable->False,
  CellTags->"functional equation"],

Cell[BoxData[
    \(TraditionalForm
    \`\[CapitalTheta](X(x, t, \[CapitalTheta](x, t); \[Epsilon]), 
        T(x, t, \[Theta](x, t); \[Epsilon]))\  = \ 
      \(U(x, t, \[CapitalTheta](x, t); \[Epsilon]) . \)\)], "NumberedEquation",\

  CellTags->"eq-8"],

Cell[TextData[
"The solution of this functional equation can be found by introducing the \
infinitesimal representation of the transformations (5.28)\[Dash](5.30). We \
will carry out the calculation by replacing the transformations \
(5.28)\[Dash](5.30) by their infinitesimal representations"], "Text",
  Evaluatable->False,
  CellTags->{
  "infinitesimal representation of a transformation", 
    "infinitesimal representation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[T, X, U]; \n
    itrafo = {
        X \[Rule] 
          Function[{x, t, u, \[Epsilon]}, 
            x + \[Epsilon]\ \(xi[1]\)[x, t, u]], \n\t\t
        T \[Rule] 
          Function[{x, t, u, \[Epsilon]}, 
            t + \[Epsilon]\ \(xi[2]\)[x, t, u]], \n\t\t
        U \[Rule] 
          Function[{x, t, u, \[Epsilon]}, 
            u + \[Epsilon]\ \(phi[1]\)[x, t, u]]}\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({X \[Rule] 
        Function[{x, t, u, \[Epsilon]}, x + \[Epsilon]\ \(xi[1]\)[x, t, u]], 
      T \[Rule] 
        Function[{x, t, u, \[Epsilon]}, t + \[Epsilon]\ \(xi[2]\)[x, t, u]], 
      U \[Rule] 
        Function[{x, t, u, \[Epsilon]}, u + \[Epsilon]\ \(phi[1]\)[x, t, u]]}
      \)], "Output"]
}, Open  ]],

Cell["\<\
Inserting the infinitesimal representation of the transformations \
into the functional equation (5.31), we get the simplification\
\>", "Text",
  Evaluatable->False,
  CellTags->"simplification"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fun = 
      \[CapitalTheta][X[x, t, \[CapitalTheta], \[Epsilon]], 
            T[x, t, \[CapitalTheta], \[Epsilon]]] == 
          U[x, t, \[CapitalTheta], \[Epsilon]] /. itrafo\)], "Input"],

Cell[BoxData[
    \(\[CapitalTheta][x + \[Epsilon]\ \(xi[1]\)[x, t, \[CapitalTheta]], 
        t + \[Epsilon]\ \(xi[2]\)[x, t, \[CapitalTheta]]] == 
      \[CapitalTheta] + \[Epsilon]\ \(phi[1]\)[x, t, \[CapitalTheta]]\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "The parameter \[Epsilon] is the group parameter of the transformation. On \
the left-hand side this expression contains the solution \[Theta] for which \
we are looking. Actually, the above expressions contain \[Theta] in a \
functional form, too. However, this representation depends on the \
infinitesimals parameter \[Epsilon] allowing us a Taylor expansion around the \
identity \[Epsilon]",
  Cell[BoxData[
      \(TraditionalForm\`\( = 0\)\)]],
  ". If we additionally subtract the right-hand side from the left-hand side \
and extract the terms of lowest order in \[Epsilon], we get the result "
}], "Text",
  Evaluatable->False,
  CellTags->{
  "group parameter", "infinitesimals parameter", "Taylor expansion"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Coefficient[
          \((Series[
                  fun\[LeftDoubleBracket]1\[RightDoubleBracket], {\[Epsilon], 
                    0, 1}] /. \[CapitalTheta][x, t] \[Rule] \[CapitalTheta])
              \) - fun\[LeftDoubleBracket]2\[RightDoubleBracket], 
          \[Epsilon]] == 0 // LieTraditionalForm\)], "Input"],

Cell[BoxData[
    \(\[CapitalTheta]\_x\ \[Xi]\_1 + \[CapitalTheta]\_t\ \[Xi]\_2 - 
        \[Phi]\_1 == 0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This first-order PDE is called the invariant surface condition. The \
problem we face is the solution of this first-order partial differential \
equation. Actually, this is not a problem if we use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " offers a package integrated in the function ",
  StyleBox["DSolve[]", "MmaText"],
  " allowing the integration of first-order PDEs. This package uses the fact \
that a first-order PDE is closely related to a set of ordinary differential \
equations. The connection between the first-order PDE and the system of ODEs \
can be demonstrated by the following reasoning."
}], "Text",
  Evaluatable->False,
  CellTags->{
  "invariant surface condition", "first-order partial differential equation", 
    "DSolve[]", "first-order PDEs"}],

Cell[TextData[{
  "Let us assume that an arbitrary surface in the space with coordinates ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["u ",
    FontSlant->"Italic"],
  "is given by"
}], "Text",
  Evaluatable->False,
  CellTags->"surface"],

Cell[BoxData[
    \(TraditionalForm\`u\  = \ \(\[CapitalTheta](x, t) . \)\)], 
  "NumberedEquation",
  Evaluatable->False],

Cell[TextData[{
  "Later, we will identify this surface as the solution surface of the \
first-order PDE. A curve embedded in this surface can be described by a set \
of parametric coordinates. Let ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " be the parameter along the curve; then the curve itself is given by the \
triple"
}], "Text",
  Evaluatable->False,
  CellTags->"first-order PDE"],

Cell[BoxData[
    \(TraditionalForm\`\(\((x = x(s), t = t(s), u = u(s))\) . \)\)], 
  "NumberedEquation",
  Evaluatable->False],

Cell["The tangent vector to this curve is", "Text",
  Evaluatable->False,
  CellTags->"tangent vector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(v\&\[RightVector]\), " ", "=", " ", 
          RowBox[{
            RowBox[{\(e\&\[RightVector]\_x\), " ", 
              FractionBox[
                StyleBox["dx",
                  FontSlant->"Italic"], 
                StyleBox["ds",
                  FontSlant->"Italic"]]}], " ", "+", " ", 
            RowBox[{\(e\&\[RightVector]\_t\), " ", 
              FractionBox[
                StyleBox["dt",
                  FontSlant->"Italic"], 
                StyleBox["ds",
                  FontSlant->"Italic"]]}], " ", "+", " ", 
            RowBox[{\(e\&\[RightVector]\_u\), " ", 
              FractionBox[
                StyleBox["du",
                  FontSlant->"Italic"], 
                StyleBox["ds",
                  FontSlant->"Italic"]]}]}]}], ","}], TraditionalForm]], 
  "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ e\&\[RightVector]\_x\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ e\&\[RightVector]\_t\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ e\&\[RightVector]\_u\)\)]],
  " are the unit vectors in the directions of the coordinate axes. The normal \
direction on the surface ",
  Cell[BoxData[
      \(TraditionalForm
      \`H = \(u - \[CapitalTheta](x, t) = \(const . \)\)\)]],
  " is determined by the gradient divided by the magnitude of the gradient"
}], "Text",
  Evaluatable->False,
  CellTags->{"normal direction", "unit vector", "gradient"}],

Cell[BoxData[
    \(TraditionalForm
    \`n\&\[RightVector]\  = \ 
      \(\[Del]H\/\(\[VerticalSeparator]\(\[Del]H \[VerticalSeparator] 
            \)\)\  = \ 
        \(1\/\(\[VerticalSeparator]\(\[Del]H \[VerticalSeparator] \)\)\) 
          \(\((\(-e\&\[RightVector]\_x\) \[CapitalTheta]\_x\  - \ 
                e\&\[RightVector]\_t\ \[CapitalTheta]\_t\  + \ 
                e\&\[RightVector]\_u)\) . \)\)\)], "NumberedEquation"],

Cell[TextData[{
  "The condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\&\[RightVector]\) v\&\[RightVector]\  = \ 0\)]],
  " assures that the curve ",
  Cell[BoxData[
      \(TraditionalForm\`\((x(s), t(s), u(s))\)\)]],
  " is part of the surface ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  ". This condition, however, is nothing more than"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(\[CapitalTheta]\_x\), " ", 
            FractionBox[
              StyleBox["dx",
                FontSlant->"Italic"], 
              StyleBox["ds",
                FontSlant->"Italic"]]}], " ", "+", " ", 
          RowBox[{\(\[CapitalTheta]\_t\), " ", 
            FractionBox[
              StyleBox["dt",
                FontSlant->"Italic"], 
              StyleBox["ds",
                FontSlant->"Italic"]]}]}], "  ", "=", "  ", 
        RowBox[{
          FractionBox[
            StyleBox["du",
              FontSlant->"Italic"], 
            StyleBox["ds",
              FontSlant->"Italic"]], "."}]}], TraditionalForm]], 
  "NumberedEquation"],

Cell["If we define a family of curves by", "Text",
  Evaluatable->False,
  CellTags->"family of curves"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox["dx",
              FontSlant->"Italic"], 
            StyleBox["ds",
              FontSlant->"Italic"]], " ", "=", " ", 
          \(\(\[Xi]\_1\)(x, t, u)\)}], ","}], TraditionalForm]], 
  "NumberedEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox["dt",
              FontSlant->"Italic"], 
            StyleBox["ds",
              FontSlant->"Italic"]], " ", "=", " ", 
          \(\(\[Xi]\_2\)(x, t, u)\)}], ","}], TraditionalForm]], 
  "NumberedEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox["du",
              FontSlant->"Italic"], 
            StyleBox["ds",
              FontSlant->"Italic"]], " ", "=", " ", 
          \(\(\[Phi]\_1\)(x, t, u)\)}], ","}], TraditionalForm]], 
  "NumberedEquation"],

Cell[TextData[{
  "called the characteristic differential equations, we can rewrite the \
surface condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\&\[RightVector]\) v\&\[RightVector]\  = \ 0\)]],
  " in a partial differential equation of first order:"
}], "Text",
  Evaluatable->False,
  CellTags->{"characteristic differential equations", "surface condition"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Xi]\_1\ \[CapitalTheta]\_x\  + \ \[Xi]\_2\ \[CapitalTheta]\_t\  = \ 
      \[Phi]\_1, \)\)], "NumberedEquation"],

Cell[TextData[{
  "which is equivalent with the equation derived from the functional relation \
",
  ButtonBox["(5.31) ",
    ButtonData:>"eq-8",
    ButtonStyle->"Hyperlink"],
  "for \[CapitalTheta]. Consequently, each one-parameter family of \
characteristic curves generates a surface which defines an integral surface ",
  
  Cell[BoxData[
      \(TraditionalForm\`u - \[CapitalTheta](x, t) = \(const . \)\)]],
  " and each such integral surface is generated by a one-parameter family of \
characteristic curves."
}], "Text",
  Evaluatable->False,
  CellTags->{
  "family of characteristic curves", "integral surface", 
    "characteristic curves"}],

Cell["Example 1", "Example"],

Cell["\<\
Let us consider the first-order partial differential equation\
\>", 
  "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(pde1 = 
      x\ \[PartialD]\_x \[CapitalTheta][x, t] + 
          t\ \[PartialD]\_t \[CapitalTheta][x, t] == \[CapitalTheta][x, t]; 
    pde1 // LieTraditionalForm\)], "Input"],

Cell[BoxData[
    \(t\ \[CapitalTheta]\_t + x\ \[CapitalTheta]\_x == \[CapitalTheta]\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "corresponding to a scaling symmetry with infinitesimals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_1 = x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_2 = t\)]],
  ". The first-order PDE is solved by"
}], "Text",
  Evaluatable->False,
  CellTags->{"scaling symmetry", "first-order PDE"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[pde1, \[CapitalTheta][x, t], {x, t}]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({{\[CapitalTheta][x, t] \[Rule] x\ \(C[1]\)[t\/x]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  StyleBox["C[1][t/x]", "MmaText",
    FontSlant->"Italic"],
  " is an arbitrary function. A graphical representation of this solution \
with ",
  StyleBox["C[1]", "MmaText",
    FontSlant->"Italic"],
  " replaced by ",
  StyleBox["Sin[]", "MmaText"],
  " is given by"
}], "Text",
  Evaluatable->False,
  CellTags->"Sin[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[
      \((\[CapitalTheta][x, t] /. \((sol /. C[1] \[Rule] Sin)\))
          \)\[LeftDoubleBracket]1\[RightDoubleBracket], \n
      \t{x, 0.1, 2}, {t, \(-2\)\ \[Pi], 2\ \[Pi]}, \n\t
      AxesLabel \[Rule] {"\<x\>", "\<t\>", "\<\[CapitalTheta]\>"}, \n\t
      PlotPoints \[Rule] 40, Mesh \[Rule] False]\)], "Input",
  PageWidth->Infinity],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.15237 .19707 -17.8465 -9 ]
[.15237 .19707 .15354 0 ]
[.31741 .13214 -5.61962 -9 ]
[.31741 .13214 .38038 0 ]
[.49342 .06293 -15.8713 -9 ]
[.49342 .06293 2.12873 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.73568 .04839 0 -6.20944 ]
[.73568 .04839 12 2.79056 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95831 .38931 0 -5.88673 ]
[.95831 .38931 6 3.11327 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02413 .26502 -12 -2.74225 ]
[.02413 .26502 0 6.25775 ]
[.01569 .31791 -12 -2.78696 ]
[.01569 .31791 0 6.21304 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00209 .42932 -6 -2.88165 ]
[-0.00209 .42932 0 6.11835 ]
[-0.01146 .48805 -6 -2.93184 ]
[-0.01146 .48805 0 6.06816 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(0.5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(1)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(1.5)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.03716 .25514 m
.04004 .25782 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72342 .05305 m
.71728 .05538 L
s
[(-5)] .73568 .04839 -1 .37988 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94577 .39318 m
.9395 .39511 L
s
[(5)] .95831 .38931 -1 .30816 Mshowa
.125 Mabswid
.74932 .09266 m
.74563 .09403 L
s
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.92673 .36405 m
.92298 .36523 L
s
.69654 .01193 m
.69287 .01336 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03635 .26025 m
.04246 .25786 L
s
[(-2)] .02413 .26502 1 -0.39061 Mshowa
.02795 .31324 m
.03408 .3109 L
s
[(-1)] .01569 .31791 1 -0.38068 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01026 .42488 m
.01644 .42265 L
s
[(1)] -0.00209 .42932 1 -0.35963 Mshowa
.00094 .48373 m
.00713 .48157 L
s
[(2)] -0.01146 .48805 1 -0.34848 Mshowa
.125 Mabswid
.03469 .2707 m
.03836 .26928 L
s
.03303 .28123 m
.0367 .27981 L
s
.03135 .29183 m
.03502 .29041 L
s
.02966 .3025 m
.03333 .30109 L
s
.02624 .32406 m
.02992 .32266 L
s
.02451 .33495 m
.0282 .33356 L
s
.02277 .34591 m
.02646 .34453 L
s
.02102 .35696 m
.02471 .35558 L
s
.01749 .37928 m
.02118 .37792 L
s
.0157 .39056 m
.0194 .3892 L
s
.0139 .40192 m
.0176 .40057 L
s
.01209 .41335 m
.01579 .41202 L
s
.00842 .43648 m
.01213 .43515 L
s
.00657 .44816 m
.01028 .44685 L
s
.00471 .45993 m
.00842 .45862 L
s
.00283 .47179 m
.00654 .47048 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.435 .687 .97 r
.3936 .69521 .40169 .70185 .41543 .69063 .407 .69616 Mtetra
.881 .991 .747 r
.407 .69616 .41543 .69063 .42867 .69819 .42107 .67769 Mtetra
.641 .557 .744 r
.42107 .67769 .42867 .69819 .44231 .69515 .43473 .67331 Mtetra
0 .129 .652 r
.43473 .67331 .44231 .69515 .45595 .69598 .44792 .69408 Mtetra
.937 .802 .686 r
.44792 .69408 .45595 .69598 .47007 .67331 .46238 .65799 Mtetra
0 0 .446 r
.46238 .65799 .47007 .67331 .48385 .67266 .47583 .68131 Mtetra
.585 .157 .194 r
.47583 .68131 .48385 .67266 .49753 .69729 .48975 .68593 Mtetra
.867 .715 .692 r
.48975 .68593 .49753 .69729 .51168 .67736 .50404 .65388 Mtetra
.76 .607 .689 r
.50404 .65388 .51168 .67736 .52576 .64546 .51815 .63216 Mtetra
.47 .545 .851 r
.51815 .63216 .52576 .64546 .53979 .63433 .53224 .63553 Mtetra
.796 .338 .154 r
.53224 .63553 .53979 .63433 .554 .64456 .54656 .65308 Mtetra
.757 .365 .311 r
.54656 .65308 .554 .64456 .56852 .66347 .56113 .67071 Mtetra
.668 .232 .204 r
.56113 .67071 .56852 .66347 .58325 .67956 .57583 .68007 Mtetra
.06 .625 .712 r
.57583 .68007 .58325 .67956 .59804 .68684 .59053 .67894 Mtetra
.772 .772 .853 r
.59053 .67894 .59804 .68684 .61276 .6842 .60512 .66881 Mtetra
.774 .666 .744 r
.60512 .66881 .61276 .6842 .62732 .67335 .61957 .65264 Mtetra
.763 .625 .707 r
.61957 .65264 .62732 .67335 .64173 .65698 .6339 .63338 Mtetra
.753 .606 .695 r
.6339 .63338 .64173 .65698 .65599 .63774 .64816 .61337 Mtetra
.745 .598 .694 r
.64816 .61337 .65599 .63774 .67017 .61775 .66239 .59423 Mtetra
.738 .598 .701 r
.66239 .59423 .67017 .61775 .68433 .59849 .67665 .57692 Mtetra
.732 .604 .715 r
.67665 .57692 .68433 .59849 .69852 .58089 .69099 .56193 Mtetra
.726 .617 .736 r
.69099 .56193 .69852 .58089 .71279 .56544 .70544 .54944 Mtetra
.718 .638 .767 r
.70544 .54944 .71279 .56544 .72718 .55232 .72005 .53939 Mtetra
.708 .669 .81 r
.72005 .53939 .72718 .55232 .74172 .54155 .73482 .53162 Mtetra
.687 .713 .868 r
.73482 .53162 .74172 .54155 .75643 .533 .74979 .5259 Mtetra
.642 .768 .94 r
.74979 .5259 .75643 .533 .77134 .52647 .76495 .52198 Mtetra
.533 .812 .997 r
.76495 .52198 .77134 .52647 .78645 .52176 .78032 .51961 Mtetra
.305 .768 .945 r
.78032 .51961 .78645 .52176 .80177 .51862 .79589 .51855 Mtetra
.004 .581 .714 r
.79589 .51855 .80177 .51862 .81731 .51684 .81168 .51859 Mtetra
.225 0 0 r
.81168 .51859 .81731 .51684 .83306 .51622 .82768 .51952 Mtetra
.357 0 0 r
.82768 .51952 .83306 .51622 .84903 .51657 .84388 .52118 Mtetra
.429 0 0 r
.84388 .52118 .84903 .51657 .86521 .51771 .86029 .52341 Mtetra
.47 0 0 r
.86029 .52341 .86521 .51771 .8816 .5195 .8769 .52608 Mtetra
.495 .002 .015 r
.8769 .52608 .8816 .5195 .8982 .5218 .8937 .52909 Mtetra
.51 .029 .05 r
.8937 .52909 .8982 .5218 .915 .52451 .9107 .53233 Mtetra
.518 .046 .072 r
.9107 .53233 .915 .52451 .932 .52753 .92789 .53572 Mtetra
.523 .056 .086 r
.92789 .53572 .932 .52753 .9492 .53077 .94526 .53921 Mtetra
.525 .06 .093 r
.94526 .53921 .9492 .53077 .96659 .53416 .96281 .54273 Mtetra
.524 .06 .095 r
.96281 .54273 .96659 .53416 .98416 .53763 .98055 .54623 Mtetra
.582 .697 .921 r
.3855 .68688 .3936 .69521 .407 .69616 .399 .68544 Mtetra
.73 .695 .817 r
.399 .68544 .407 .69616 .42107 .67769 .41282 .67708 Mtetra
.821 .946 .904 r
.41282 .67708 .42107 .67769 .43473 .67331 .42674 .66606 Mtetra
0 .182 .665 r
.42674 .66606 .43473 .67331 .44792 .69408 .44017 .67612 Mtetra
.774 .64 .713 r
.44017 .67612 .44792 .69408 .46238 .65799 .45437 .65676 Mtetra
.872 .462 .244 r
.45437 .65676 .46238 .65799 .47583 .68131 .46776 .68376 Mtetra
.915 .966 .794 r
.46776 .68376 .47583 .68131 .48975 .68593 .48204 .66504 Mtetra
.808 .642 .677 r
.48204 .66504 .48975 .68593 .50404 .65388 .49637 .63437 Mtetra
.662 .577 .749 r
.49637 .63437 .50404 .65388 .51815 .63216 .51045 .62822 Mtetra
.705 .17 0 r
.51045 .62822 .51815 .63216 .53224 .63553 .52459 .64263 Mtetra
.774 .375 .298 r
.52459 .64263 .53224 .63553 .54656 .65308 .53897 .66134 Mtetra
.697 .281 .254 r
.53897 .66134 .54656 .65308 .56113 .67071 .55356 .67292 Mtetra
.245 0 0 r
.55356 .67292 .56113 .67071 .57583 .68007 .56821 .6735 Mtetra
.768 .803 .881 r
.56821 .6735 .57583 .68007 .59053 .67894 .58282 .66423 Mtetra
.777 .673 .749 r
.58282 .66423 .59053 .67894 .60512 .66881 .59733 .64829 Mtetra
.764 .626 .708 r
.59733 .64829 .60512 .66881 .61957 .65264 .61173 .62901 Mtetra
.753 .606 .695 r
.61173 .62901 .61957 .65264 .6339 .63338 .62606 .60898 Mtetra
.744 .598 .695 r
.62606 .60898 .6339 .63338 .64816 .61337 .64036 .58998 Mtetra
.736 .598 .703 r
.64036 .58998 .64816 .61337 .66239 .59423 .65469 .57302 Mtetra
.73 .606 .719 r
.65469 .57302 .66239 .59423 .67665 .57692 .66909 .55857 Mtetra
.723 .621 .743 r
.66909 .55857 .67665 .57692 .69099 .56193 .68361 .54677 Mtetra
.714 .645 .779 r
.68361 .54677 .69099 .56193 .70544 .54944 .69828 .53751 Mtetra
.7 .682 .829 r
.69828 .53751 .70544 .54944 .72005 .53939 .71311 .53058 Mtetra
.671 .733 .896 r
.71311 .53058 .72005 .53939 .73482 .53162 .72812 .52571 Mtetra
.6 .791 .972 r
.72812 .52571 .73482 .53162 .74979 .5259 .74333 .52262 Mtetra
.427 .804 .992 r
.74333 .52262 .74979 .5259 .76495 .52198 .75873 .52104 Mtetra
.126 .67 .828 r
.75873 .52104 .76495 .52198 .78032 .51961 .77434 .5207 Mtetra
.157 0 0 r
.77434 .5207 .78032 .51961 .79589 .51855 .79016 .52138 Mtetra
.326 0 0 r
.79016 .52138 .79589 .51855 .81168 .51859 .80617 .52288 Mtetra
.415 0 0 r
.80617 .52288 .81168 .51859 .82768 .51952 .82239 .52502 Mtetra
.464 0 0 r
.82239 .52502 .82768 .51952 .84388 .52118 .83881 .52765 Mtetra
.492 0 .008 r
.83881 .52765 .84388 .52118 .86029 .52341 .85542 .53064 Mtetra
.509 .027 .047 r
.85542 .53064 .86029 .52341 .8769 .52608 .87222 .53388 Mtetra
.518 .045 .072 r
.87222 .53388 .8769 .52608 .8937 .52909 .8892 .53729 Mtetra
.523 .056 .086 r
.8892 .53729 .8937 .52909 .9107 .53233 .90637 .54079 Mtetra
.525 .06 .093 r
.90637 .54079 .9107 .53233 .92789 .53572 .92372 .54431 Mtetra
.524 .06 .094 r
.92372 .54431 .92789 .53572 .94526 .53921 .94124 .5478 Mtetra
.521 .056 .091 r
.94124 .5478 .94526 .53921 .96281 .54273 .95893 .55123 Mtetra
.516 .048 .082 r
.95893 .55123 .96281 .54273 .98055 .54623 .97679 .55455 Mtetra
.818 .814 .846 r
.37719 .68173 .3855 .68688 .399 .68544 .39115 .66957 Mtetra
.073 .268 .757 r
.39115 .66957 .399 .68544 .41282 .67708 .40425 .68252 Mtetra
.391 .805 .603 r
.40425 .68252 .41282 .67708 .42674 .66606 .41822 .67353 Mtetra
.841 .977 .676 r
.41822 .67353 .42674 .66606 .44017 .67612 .43251 .65373 Mtetra
.345 .369 .742 r
.43251 .65373 .44017 .67612 .45437 .65676 .44604 .66483 Mtetra
.663 .242 .236 r
.44604 .66483 .45437 .65676 .46776 .68376 .45981 .67359 Mtetra
.874 .726 .695 r
.45981 .67359 .46776 .68376 .48204 .66504 .47435 .64161 Mtetra
.74 .598 .698 r
.47435 .64161 .48204 .66504 .49637 .63437 .48859 .62381 Mtetra
.101 .392 .849 r
.48859 .62381 .49637 .63437 .51045 .62822 .50261 .63252 Mtetra
.792 .373 .253 r
.50261 .63252 .51045 .62822 .52459 .64263 .51679 .65144 Mtetra
.721 .319 .286 r
.51679 .65144 .52459 .64263 .53897 .66134 .53123 .6653 Mtetra
.446 0 0 r
.53123 .6653 .53897 .66134 .55356 .67292 .54583 .66784 Mtetra
.756 .844 .918 r
.54583 .66784 .55356 .67292 .56821 .6735 .56045 .65958 Mtetra
.78 .682 .756 r
.56045 .65958 .56821 .6735 .58282 .66423 .575 .64392 Mtetra
.765 .628 .709 r
.575 .64392 .58282 .66423 .59733 .64829 .58947 .62461 Mtetra
.753 .606 .695 r
.58947 .62461 .59733 .64829 .61173 .62901 .60387 .60458 Mtetra
.743 .597 .695 r
.60387 .60458 .61173 .62901 .62606 .60898 .61824 .58576 Mtetra
.735 .598 .705 r
.61824 .58576 .62606 .60898 .64036 .58998 .63264 .5692 Mtetra
.727 .607 .723 r
.63264 .5692 .64036 .58998 .65469 .57302 .64711 .55537 Mtetra
.719 .625 .751 r
.64711 .55537 .65469 .57302 .66909 .55857 .66168 .54434 Mtetra
.709 .654 .793 r
.66168 .54434 .66909 .55857 .68361 .54677 .6764 .53594 Mtetra
.69 .698 .852 r
.6764 .53594 .68361 .54677 .69828 .53751 .69127 .52992 Mtetra
.645 .756 .93 r
.69127 .52992 .69828 .53751 .71311 .53058 .70633 .52595 Mtetra
.528 .807 .997 r
.70633 .52595 .71311 .53058 .72812 .52571 .72157 .52372 Mtetra
.267 .749 .928 r
.72157 .52372 .72812 .52571 .74333 .52262 .73701 .52293 Mtetra
.063 0 0 r
.73701 .52293 .74333 .52262 .75873 .52104 .75265 .52331 Mtetra
.283 0 0 r
.75265 .52331 .75873 .52104 .77434 .5207 .76848 .52462 Mtetra
.397 0 0 r
.76848 .52462 .77434 .5207 .79016 .52138 .78451 .52665 Mtetra
.457 0 0 r
.78451 .52665 .79016 .52138 .80617 .52288 .80073 .52922 Mtetra
.49 0 0 r
.80073 .52922 .80617 .52288 .82239 .52502 .81715 .5322 Mtetra
.508 .025 .044 r
.81715 .5322 .82239 .52502 .83881 .52765 .83375 .53544 Mtetra
.518 .045 .071 r
.83375 .53544 .83881 .52765 .85542 .53064 .85053 .53886 Mtetra
.523 .056 .086 r
.85053 .53886 .85542 .53064 .87222 .53388 .8675 .54236 Mtetra
.525 .06 .093 r
.8675 .54236 .87222 .53388 .8892 .53729 .88464 .54588 Mtetra
.523 .059 .094 r
.88464 .54588 .8892 .53729 .90637 .54079 .90195 .54937 Mtetra
.519 .054 .089 r
.90195 .54937 .90637 .54079 .92372 .54431 .91943 .55276 Mtetra
.514 .045 .079 r
.91943 .55276 .92372 .54431 .94124 .5478 .93707 .55604 Mtetra
.506 .033 .066 r
.93707 .55604 .94124 .5478 .95893 .55123 .95488 .55917 Mtetra
.497 .018 .047 r
.95488 .55917 .95893 .55123 .97679 .55455 .97284 .56214 Mtetra
.356 .557 .91 r
.36901 .67165 .37719 .68173 .39115 .66957 .38236 .67562 Mtetra
0 0 0 r
.38236 .67562 .39115 .66957 .40425 .68252 .39631 .66698 Mtetra
.358 .452 .821 r
.39631 .66698 .40425 .68252 .41822 .67353 .40978 .6739 Mtetra
.947 .847 .712 r
.40978 .6739 .41822 .67353 .43251 .65373 .4245 .64312 Mtetra
.831 .395 0 r
.4245 .64312 .43251 .65373 .44604 .66483 .43764 .66965 Mtetra
.852 .996 .762 r
.43764 .66965 .44604 .66483 .45981 .67359 .45202 .65254 Mtetra
.801 .638 .681 r
.45202 .65254 .45981 .67359 .47435 .64161 .46656 .62377 Mtetra
.578 .548 .785 r
.46656 .62377 .47435 .64161 .48859 .62381 .48061 .62349 Mtetra
.8 .33 .112 r
.48061 .62349 .48859 .62381 .50261 .63252 .4946 .64109 Mtetra
.743 .346 .3 r
.4946 .64109 .50261 .63252 .51679 .65144 .50886 .65714 Mtetra
.56 .074 .059 r
.50886 .65714 .51679 .65144 .53123 .6653 .52337 .66192 Mtetra
.719 .891 .959 r
.52337 .66192 .53123 .6653 .54583 .66784 .53798 .65485 Mtetra
.785 .694 .764 r
.53798 .65485 .54583 .66784 .56045 .65958 .55258 .63953 Mtetra
.767 .631 .71 r
.55258 .63953 .56045 .65958 .575 .64392 .56712 .6202 Mtetra
.752 .606 .695 r
.56712 .6202 .575 .64392 .58947 .62461 .58159 .60017 Mtetra
.742 .597 .696 r
.58159 .60017 .58947 .62461 .60387 .60458 .59603 .58157 Mtetra
.733 .598 .707 r
.59603 .58157 .60387 .60458 .61824 .58576 .61049 .5655 Mtetra
.724 .609 .728 r
.61049 .5655 .61824 .58576 .63264 .5692 .62502 .55237 Mtetra
.715 .63 .761 r
.62502 .55237 .63264 .5692 .64711 .55537 .63965 .5422 Mtetra
.702 .665 .811 r
.63965 .5422 .64711 .55537 .66168 .54434 .65441 .53475 Mtetra
.674 .717 .882 r
.65441 .53475 .66168 .54434 .6764 .53594 .66932 .52969 Mtetra
.601 .782 .967 r
.66932 .52969 .6764 .53594 .69127 .52992 .68441 .52667 Mtetra
.407 .796 .989 r
.68441 .52667 .69127 .52992 .70633 .52595 .69968 .52532 Mtetra
.063 .625 .779 r
.69968 .52532 .70633 .52595 .72157 .52372 .71514 .52532 Mtetra
.224 0 0 r
.71514 .52532 .72157 .52372 .73701 .52293 .73079 .5264 Mtetra
.374 0 0 r
.73079 .5264 .73701 .52293 .75265 .52331 .74664 .52829 Mtetra
.448 0 0 r
.74664 .52829 .75265 .52331 .76848 .52462 .76267 .5308 Mtetra
.486 0 0 r
.76267 .5308 .76848 .52462 .78451 .52665 .77889 .53375 Mtetra
.507 .023 .04 r
.77889 .53375 .78451 .52665 .80073 .52922 .79529 .537 Mtetra
.518 .044 .07 r
.79529 .537 .80073 .52922 .81715 .5322 .81187 .54043 Mtetra
.523 .056 .086 r
.81187 .54043 .81715 .5322 .83375 .53544 .82863 .54394 Mtetra
.524 .06 .093 r
.82863 .54394 .83375 .53544 .85053 .53886 .84557 .54746 Mtetra
.522 .058 .093 r
.84557 .54746 .85053 .53886 .8675 .54236 .86267 .55092 Mtetra
.518 .052 .087 r
.86267 .55092 .8675 .54236 .88464 .54588 .87994 .55429 Mtetra
.512 .042 .076 r
.87994 .55429 .88464 .54588 .90195 .54937 .89737 .55751 Mtetra
.503 .028 .06 r
.89737 .55751 .90195 .54937 .91943 .55276 .91495 .56057 Mtetra
.492 .01 .039 r
.91495 .56057 .91943 .55276 .93707 .55604 .93269 .56343 Mtetra
.479 0 .013 r
.93269 .56343 .93707 .55604 .95488 .55917 .95059 .56609 Mtetra
.464 0 0 r
.95059 .56609 .95488 .55917 .97284 .56214 .96863 .56853 Mtetra
.703 .864 .959 r
.36046 .66796 .36901 .67165 .38236 .67562 .37428 .66196 Mtetra
.767 .672 .758 r
.37428 .66196 .38236 .67562 .39631 .66698 .38847 .6479 Mtetra
.388 .427 .78 r
.38847 .6479 .39631 .66698 .40978 .6739 .40188 .65557 Mtetra
.684 .598 .754 r
.40188 .65557 .40978 .6739 .4245 .64312 .41595 .6478 Mtetra
.737 .301 .215 r
.41595 .6478 .4245 .64312 .43764 .66965 .42947 .66105 Mtetra
.884 .742 .7 r
.42947 .66105 .43764 .66965 .45202 .65254 .44426 .62936 Mtetra
.708 .582 .712 r
.44426 .62936 .45202 .65254 .46656 .62377 .45854 .61672 Mtetra
.561 .04 0 r
.45854 .61672 .46656 .62377 .48061 .62349 .47241 .63052 Mtetra
.767 .365 .292 r
.47241 .63052 .48061 .62349 .4946 .64109 .48646 .64837 Mtetra
.629 .182 .17 r
.48646 .64837 .4946 .64109 .50886 .65714 .50084 .65568 Mtetra
.614 .921 .975 r
.50084 .65568 .50886 .65714 .52337 .66192 .51543 .65004 Mtetra
.79 .709 .775 r
.51543 .65004 .52337 .66192 .53798 .65485 .53007 .63512 Mtetra
.768 .634 .712 r
.53007 .63512 .53798 .65485 .55258 .63953 .54467 .61577 Mtetra
.752 .606 .695 r
.54467 .61577 .55258 .63953 .56712 .6202 .55922 .59576 Mtetra
.74 .596 .697 r
.55922 .59576 .56712 .6202 .58159 .60017 .57373 .57744 Mtetra
.73 .599 .71 r
.57373 .57744 .58159 .60017 .59603 .58157 .58825 .56193 Mtetra
.721 .612 .735 r
.58825 .56193 .59603 .58157 .61049 .5655 .60283 .54962 Mtetra
.71 .637 .774 r
.60283 .54962 .61049 .5655 .62502 .55237 .6175 .5404 Mtetra
.691 .68 .834 r
.6175 .5404 .62502 .55237 .63965 .5422 .6323 .53398 Mtetra
.648 .742 .918 r
.6323 .53398 .63965 .5422 .65441 .53475 .64724 .52996 Mtetra
.522 .8 .996 r
.64724 .52996 .65441 .53475 .66932 .52969 .66236 .52791 Mtetra
.218 .722 .903 r
.66236 .52791 .66932 .52969 .68441 .52667 .67765 .52744 Mtetra
.138 0 0 r
.67765 .52744 .68441 .52667 .69968 .52532 .69312 .52823 Mtetra
.341 0 0 r
.69312 .52823 .69968 .52532 .71514 .52532 .70877 .52996 Mtetra
.435 0 0 r
.70877 .52996 .71514 .52532 .73079 .5264 .72462 .53239 Mtetra
.482 0 0 r
.72462 .53239 .73079 .5264 .74664 .52829 .74064 .53531 Mtetra
.506 .02 .036 r
.74064 .53531 .74664 .52829 .76267 .5308 .75685 .53856 Mtetra
.518 .044 .069 r
.75685 .53856 .76267 .5308 .77889 .53375 .77323 .54199 Mtetra
.523 .056 .086 r
.77323 .54199 .77889 .53375 .79529 .537 .78979 .54551 Mtetra
.524 .06 .093 r
.78979 .54551 .79529 .537 .81187 .54043 .80651 .54903 Mtetra
.522 .057 .092 r
.80651 .54903 .81187 .54043 .82863 .54394 .8234 .55247 Mtetra
.516 .05 .085 r
.8234 .55247 .82863 .54394 .84557 .54746 .84046 .55579 Mtetra
.509 .037 .071 r
.84046 .55579 .84557 .54746 .86267 .55092 .85767 .55895 Mtetra
.499 .021 .052 r
.85767 .55895 .86267 .55092 .87994 .55429 .87504 .56191 Mtetra
.486 .001 .028 r
.87504 .56191 .87994 .55429 .89737 .55751 .89256 .56466 Mtetra
.471 0 0 r
.89256 .56466 .89737 .55751 .91495 .56057 .91023 .56718 Mtetra
.453 0 0 r
.91023 .56718 .91495 .56057 .93269 .56343 .92805 .56946 Mtetra
.431 0 0 r
.92805 .56946 .93269 .56343 .95059 .56609 .94601 .57149 Mtetra
.405 0 0 r
.94601 .57149 .95059 .56609 .96863 .56853 .96411 .57328 Mtetra
.718 .68 .813 r
.35221 .65618 .36046 .66796 .37428 .66196 .36615 .64822 Mtetra
.507 .563 .847 r
.36615 .64822 .37428 .66196 .38847 .6479 .37972 .65007 Mtetra
.876 .979 .839 r
.37972 .65007 .38847 .6479 .40188 .65557 .39406 .63473 Mtetra
0 .101 .642 r
.39406 .63473 .40188 .65557 .41595 .6478 .40718 .6548 Mtetra
.672 .935 .652 r
.40718 .6548 .41595 .6478 .42947 .66105 .4216 .63987 Mtetra
.79 .633 .688 r
.4216 .63987 .42947 .66105 .44426 .62936 .4363 .61397 Mtetra
.379 .47 .827 r
.4363 .61397 .44426 .62936 .45854 .61672 .4502 .62024 Mtetra
.794 .369 .238 r
.4502 .62024 .45854 .61672 .47241 .63052 .46404 .63892 Mtetra
.675 .254 .238 r
.46404 .63892 .47241 .63052 .48646 .64837 .47825 .64904 Mtetra
.337 .819 .845 r
.47825 .64904 .48646 .64837 .50084 .65568 .4928 .64511 Mtetra
.796 .728 .789 r
.4928 .64511 .50084 .65568 .51543 .65004 .50747 .63069 Mtetra
.771 .637 .714 r
.50747 .63069 .51543 .65004 .53007 .63512 .52214 .61132 Mtetra
.752 .606 .695 r
.52214 .61132 .53007 .63512 .54467 .61577 .53676 .59136 Mtetra
.738 .596 .698 r
.53676 .59136 .54467 .61577 .55922 .59576 .55134 .57338 Mtetra
.727 .599 .713 r
.55134 .57338 .55922 .59576 .57373 .57744 .56591 .55855 Mtetra
.716 .615 .743 r
.56591 .55855 .57373 .57744 .58825 .56193 .58053 .54716 Mtetra
.703 .647 .791 r
.58053 .54716 .58825 .56193 .60283 .54962 .59524 .53902 Mtetra
.676 .699 .864 r
.59524 .53902 .60283 .54962 .6175 .5404 .61006 .53371 Mtetra
.602 .77 .96 r
.61006 .53371 .6175 .5404 .6323 .53398 .62503 .53076 Mtetra
.38 .783 .984 r
.62503 .53076 .6323 .53398 .64724 .52996 .64015 .52971 Mtetra
0 .566 .713 r
.64015 .52971 .64724 .52996 .66236 .52791 .65545 .53012 Mtetra
.293 0 0 r
.65545 .53012 .66236 .52791 .67765 .52744 .67093 .53165 Mtetra
.419 0 0 r
.67093 .53165 .67765 .52744 .69312 .52823 .68658 .53398 Mtetra
.476 0 0 r
.68658 .53398 .69312 .52823 .70877 .52996 .70241 .53687 Mtetra
.504 .016 .03 r
.70241 .53687 .70877 .52996 .72462 .53239 .71842 .54011 Mtetra
.518 .043 .067 r
.71842 .54011 .72462 .53239 .74064 .53531 .7346 .54356 Mtetra
.523 .056 .086 r
.7346 .54356 .74064 .53531 .75685 .53856 .75095 .54709 Mtetra
.524 .059 .093 r
.75095 .54709 .75685 .53856 .77323 .54199 .76747 .55059 Mtetra
.52 .056 .091 r
.76747 .55059 .77323 .54199 .78979 .54551 .78415 .554 Mtetra
.514 .046 .081 r
.78415 .554 .78979 .54551 .80651 .54903 .80099 .55727 Mtetra
.505 .032 .065 r
.80099 .55727 .80651 .54903 .8234 .55247 .81799 .56034 Mtetra
.493 .013 .043 r
.81799 .56034 .8234 .55247 .84046 .55579 .83514 .5632 Mtetra
.479 0 .014 r
.83514 .5632 .84046 .55579 .85767 .55895 .85244 .56581 Mtetra
.461 0 0 r
.85244 .56581 .85767 .55895 .87504 .56191 .86989 .56817 Mtetra
.439 0 0 r
.86989 .56817 .87504 .56191 .89256 .56466 .88748 .57026 Mtetra
.413 0 0 r
.88748 .57026 .89256 .56466 .91023 .56718 .90521 .57209 Mtetra
.381 0 0 r
.90521 .57209 .91023 .56718 .92805 .56946 .92308 .57365 Mtetra
.343 0 0 r
.92308 .57365 .92805 .56946 .94601 .57149 .94109 .57495 Mtetra
.298 0 0 r
.94109 .57495 .94601 .57149 .96411 .57328 .95923 .57598 Mtetra
.192 .694 .91 r
.34341 .65386 .35221 .65618 .36615 .64822 .35702 .65418 Mtetra
.314 0 0 r
.35702 .65418 .36615 .64822 .37972 .65007 .3708 .65317 Mtetra
.937 .941 .769 r
.3708 .65317 .37972 .65007 .39406 .63473 .38552 .63112 Mtetra
.798 .306 .006 r
.38552 .63112 .39406 .63473 .40718 .6548 .39874 .64831 Mtetra
.897 .765 .708 r
.39874 .64831 .40718 .6548 .4216 .63987 .41376 .6173 Mtetra
.651 .555 .733 r
.41376 .6173 .4216 .63987 .4363 .61397 .42794 .61126 Mtetra
.799 .309 .028 r
.42794 .61126 .4363 .61397 .4502 .62024 .44161 .6288 Mtetra
.713 .305 .273 r
.44161 .6288 .4502 .62024 .46404 .63892 .45561 .64189 Mtetra
.082 0 0 r
.45561 .64189 .46404 .63892 .47825 .64904 .47008 .64004 Mtetra
.803 .754 .808 r
.47008 .64004 .47825 .64904 .4928 .64511 .48478 .62623 Mtetra
.773 .641 .716 r
.48478 .62623 .4928 .64511 .50747 .63069 .49952 .60685 Mtetra
.751 .605 .696 r
.49952 .60685 .50747 .63069 .52214 .61132 .51421 .58696 Mtetra
.736 .595 .699 r
.51421 .58696 .52214 .61132 .53676 .59136 .52885 .56941 Mtetra
.723 .6 .718 r
.52885 .56941 .53676 .59136 .55134 .57338 .54347 .55539 Mtetra
.711 .62 .754 r
.54347 .55539 .55134 .57338 .56591 .55855 .55812 .54506 Mtetra
.693 .659 .812 r
.55812 .54506 .56591 .55855 .58053 .54716 .57285 .53811 Mtetra
.65 .724 .903 r
.57285 .53811 .58053 .54716 .59524 .53902 .58769 .534 Mtetra
.515 .791 .995 r
.58769 .534 .59524 .53902 .61006 .53371 .60266 .53217 Mtetra
.154 .683 .865 r
.60266 .53217 .61006 .53371 .62503 .53076 .61779 .53212 Mtetra
.22 0 0 r
.61779 .53212 .62503 .53076 .64015 .52971 .63309 .53338 Mtetra
.395 0 0 r
.63309 .53338 .64015 .52971 .65545 .53012 .64855 .53558 Mtetra
.469 0 0 r
.64855 .53558 .65545 .53012 .67093 .53165 .66419 .53842 Mtetra
.502 .012 .024 r
.66419 .53842 .67093 .53165 .68658 .53398 .68 .54167 Mtetra
.517 .042 .065 r
.68 .54167 .68658 .53398 .70241 .53687 .69598 .54513 Mtetra
.523 .056 .086 r
.69598 .54513 .70241 .53687 .71842 .54011 .71213 .54866 Mtetra
.523 .059 .093 r
.71213 .54866 .71842 .54011 .7346 .54356 .72844 .55215 Mtetra
.519 .054 .089 r
.72844 .55215 .7346 .54356 .75095 .54709 .74491 .55552 Mtetra
.511 .042 .077 r
.74491 .55552 .75095 .54709 .76747 .55059 .76155 .55872 Mtetra
.501 .025 .058 r
.76155 .55872 .76747 .55059 .78415 .554 .77833 .56169 Mtetra
.487 .003 .031 r
.77833 .56169 .78415 .554 .80099 .55727 .79526 .56441 Mtetra
.469 0 0 r
.79526 .56441 .80099 .55727 .81799 .56034 .81234 .56686 Mtetra
.448 0 0 r
.81234 .56686 .81799 .56034 .83514 .5632 .82956 .56902 Mtetra
.421 0 0 r
.82956 .56902 .83514 .5632 .85244 .56581 .84693 .5709 Mtetra
.389 0 0 r
.84693 .5709 .85244 .56581 .86989 .56817 .86443 .57249 Mtetra
.349 0 0 r
.86443 .57249 .86989 .56817 .88748 .57026 .88207 .5738 Mtetra
.302 0 0 r
.88207 .5738 .88748 .57026 .90521 .57209 .89984 .57482 Mtetra
.246 0 0 r
.89984 .57482 .90521 .57209 .92308 .57365 .91775 .57557 Mtetra
.179 0 0 r
.91775 .57557 .92308 .57365 .94109 .57495 .93579 .57605 Mtetra
.105 0 0 r
.93579 .57605 .94109 .57495 .95923 .57598 .95395 .57627 Mtetra
.621 .624 .833 r
.3351 .64049 .34341 .65386 .35702 .65418 .34887 .63783 Mtetra
.629 .592 .793 r
.34887 .63783 .35702 .65418 .3708 .65317 .36275 .63451 Mtetra
.466 .482 .79 r
.36275 .63451 .3708 .65317 .38552 .63112 .37638 .63898 Mtetra
0 0 0 r
.37638 .63898 .38552 .63112 .39874 .64831 .39079 .62702 Mtetra
.77 .625 .699 r
.39079 .62702 .39874 .64831 .41376 .6173 .40554 .60546 Mtetra
0 .188 .719 r
.40554 .60546 .41376 .6173 .42794 .61126 .41917 .61819 Mtetra
.75 .34 .274 r
.41917 .61819 .42794 .61126 .44161 .6288 .43294 .6341 Mtetra
.382 0 0 r
.43294 .6341 .44161 .6288 .45561 .64189 .44728 .63479 Mtetra
.812 .792 .834 r
.44728 .63479 .45561 .64189 .47008 .64004 .462 .62175 Mtetra
.777 .647 .719 r
.462 .62175 .47008 .64004 .48478 .62623 .47681 .60236 Mtetra
.751 .605 .696 r
.47681 .60236 .48478 .62623 .49952 .60685 .49157 .58258 Mtetra
.733 .594 .701 r
.49157 .58258 .49952 .60685 .51421 .58696 .50626 .56558 Mtetra
.719 .601 .724 r
.50626 .56558 .51421 .58696 .52885 .56941 .52092 .55252 Mtetra
.703 .626 .768 r
.52092 .55252 .52885 .56941 .54347 .55539 .53559 .54341 Mtetra
.678 .676 .842 r
.53559 .54341 .54347 .55539 .55812 .54506 .55033 .53776 Mtetra
.603 .754 .95 r
.55033 .53776 .55812 .54506 .57285 .53811 .56517 .53492 Mtetra
.344 .766 .976 r
.56517 .53492 .57285 .53811 .58769 .534 .58014 .53424 Mtetra
.106 0 0 r
.58014 .53424 .58769 .534 .60266 .53217 .59526 .53516 Mtetra
.361 0 0 r
.59526 .53516 .60266 .53217 .61779 .53212 .61054 .5372 Mtetra
.459 0 0 r
.61054 .5372 .61779 .53212 .63309 .53338 .62598 .53998 Mtetra
.5 .006 .015 r
.62598 .53998 .63309 .53338 .64855 .53558 .64159 .54322 Mtetra
.517 .041 .063 r
.64159 .54322 .64855 .53558 .66419 .53842 .65737 .54669 Mtetra
.523 .055 .086 r
.65737 .54669 .66419 .53842 .68 .54167 .67332 .55023 Mtetra
.522 .058 .092 r
.67332 .55023 .68 .54167 .69598 .54513 .68943 .5537 Mtetra
.517 .051 .087 r
.68943 .5537 .69598 .54513 .71213 .54866 .70569 .55701 Mtetra
.508 .037 .072 r
.70569 .55701 .71213 .54866 .72844 .55215 .72211 .56012 Mtetra
.495 .016 .048 r
.72211 .56012 .72844 .55215 .74491 .55552 .73868 .56296 Mtetra
.478 0 .016 r
.73868 .56296 .74491 .55552 .76155 .55872 .7554 .56552 Mtetra
.457 0 0 r
.7554 .56552 .76155 .55872 .77833 .56169 .77226 .56778 Mtetra
.43 0 0 r
.77226 .56778 .77833 .56169 .79526 .56441 .78926 .56972 Mtetra
.397 0 0 r
.78926 .56972 .79526 .56441 .81234 .56686 .8064 .57135 Mtetra
.357 0 0 r
.8064 .57135 .81234 .56686 .82956 .56902 .82367 .57266 Mtetra
.307 0 0 r
.82367 .57266 .82956 .56902 .84693 .5709 .84108 .57367 Mtetra
.246 0 0 r
.84108 .57367 .84693 .5709 .86443 .57249 .85862 .57439 Mtetra
.175 0 0 r
.85862 .57439 .86443 .57249 .88207 .5738 .87629 .57481 Mtetra
.093 0 0 r
.87629 .57481 .88207 .5738 .89984 .57482 .89409 .57496 Mtetra
.004 0 0 r
.89409 .57496 .89984 .57482 .91775 .57557 .91202 .57484 Mtetra
.089 .645 .791 r
.91202 .57484 .91775 .57557 .93579 .57605 .93007 .57446 Mtetra
.178 .702 .869 r
.93007 .57446 .93579 .57605 .95395 .57627 .94825 .57384 Mtetra
.848 .922 .88 r
.32602 .63942 .3351 .64049 .34887 .63783 .3404 .62655 Mtetra
.734 .697 .816 r
.3404 .62655 .34887 .63783 .36275 .63451 .35459 .61756 Mtetra
0 .066 .63 r
.35459 .61756 .36275 .63451 .37638 .63898 .3676 .63533 Mtetra
.915 .802 .721 r
.3676 .63533 .37638 .63898 .39079 .62702 .38282 .6057 Mtetra
.533 .498 .762 r
.38282 .6057 .39079 .62702 .40554 .60546 .39673 .60771 Mtetra
.793 .354 .204 r
.39673 .60771 .40554 .60546 .41917 .61819 .41024 .62552 Mtetra
.539 .07 .091 r
.41024 .62552 .41917 .61819 .43294 .6341 .42441 .6293 Mtetra
.818 .846 .87 r
.42441 .6293 .43294 .6341 .44728 .63479 .43912 .61724 Mtetra
.781 .654 .722 r
.43912 .61724 .44728 .63479 .462 .62175 .454 .59786 Mtetra
.75 .605 .697 r
.454 .59786 .462 .62175 .47681 .60236 .46883 .57823 Mtetra
.729 .593 .703 r
.46883 .57823 .47681 .60236 .49157 .58258 .48357 .56193 Mtetra
.713 .602 .732 r
.48357 .56193 .49157 .58258 .50626 .56558 .49825 .55002 Mtetra
.693 .635 .787 r
.49825 .55002 .50626 .56558 .52092 .55252 .51292 .5423 Mtetra
.652 .701 .882 r
.51292 .5423 .52092 .55252 .53559 .54341 .52766 .53808 Mtetra
.505 .778 .994 r
.52766 .53808 .53559 .54341 .55033 .53776 .54248 .53656 Mtetra
.069 .626 .808 r
.54248 .53656 .55033 .53776 .56517 .53492 .55743 .53701 Mtetra
.305 0 0 r
.55743 .53701 .56517 .53492 .58014 .53424 .57253 .53883 Mtetra
.445 0 0 r
.57253 .53883 .58014 .53424 .59526 .53516 .58779 .54155 Mtetra
.496 0 .004 r
.58779 .54155 .59526 .53516 .61054 .5372 .6032 .54478 Mtetra
.517 .039 .061 r
.6032 .54478 .61054 .5372 .62598 .53998 .61878 .54826 Mtetra
.523 .055 .086 r
.61878 .54826 .62598 .53998 .64159 .54322 .63452 .55179 Mtetra
.521 .057 .091 r
.63452 .55179 .64159 .54322 .65737 .54669 .65042 .55523 Mtetra
.514 .048 .084 r
.65042 .55523 .65737 .54669 .67332 .55023 .66648 .55848 Mtetra
.503 .03 .065 r
.66648 .55848 .67332 .55023 .68943 .5537 .68269 .56147 Mtetra
.487 .005 .036 r
.68269 .56147 .68943 .5537 .70569 .55701 .69905 .56415 Mtetra
.467 0 0 r
.69905 .56415 .70569 .55701 .72211 .56012 .71555 .56651 Mtetra
.44 0 0 r
.71555 .56651 .72211 .56012 .73868 .56296 .7322 .56853 Mtetra
.407 0 0 r
.7322 .56853 .73868 .56296 .7554 .56552 .74898 .57021 Mtetra
.365 0 0 r
.74898 .57021 .7554 .56552 .77226 .56778 .7659 .57154 Mtetra
.312 0 0 r
.7659 .57154 .77226 .56778 .78926 .56972 .78295 .57254 Mtetra
.248 0 0 r
.78295 .57254 .78926 .56972 .8064 .57135 .80013 .57321 Mtetra
.169 0 0 r
.80013 .57321 .8064 .57135 .82367 .57266 .81744 .57357 Mtetra
.079 0 0 r
.81744 .57357 .82367 .57266 .84108 .57367 .83487 .57363 Mtetra
.019 .593 .719 r
.83487 .57363 .84108 .57367 .85862 .57439 .85244 .57341 Mtetra
.119 .666 .817 r
.85244 .57341 .85862 .57439 .87629 .57481 .87012 .57291 Mtetra
.214 .723 .895 r
.87012 .57291 .87629 .57481 .89409 .57496 .88793 .57216 Mtetra
.298 .76 .948 r
.88793 .57216 .89409 .57496 .91202 .57484 .90587 .57116 Mtetra
.367 .78 .98 r
.90587 .57116 .91202 .57484 .93007 .57446 .92392 .56992 Mtetra
.423 .788 .995 r
.92392 .56992 .93007 .57446 .94825 .57384 .9421 .56847 Mtetra
.294 .436 .834 r
.31765 .62457 .32602 .63942 .3404 .62655 .33094 .63176 Mtetra
.508 .887 .698 r
.33094 .63176 .3404 .62655 .35459 .61756 .34528 .62199 Mtetra
.417 .844 .694 r
.34528 .62199 .35459 .61756 .3676 .63533 .35956 .61401 Mtetra
.733 .607 .717 r
.35956 .61401 .3676 .63533 .38282 .6057 .3742 .59891 Mtetra
.741 .233 0 r
.3742 .59891 .38282 .6057 .39673 .60771 .38754 .61602 Mtetra
.629 .193 .194 r
.38754 .61602 .39673 .60771 .41024 .62552 .40147 .62346 Mtetra
.806 .922 .914 r
.40147 .62346 .41024 .62552 .42441 .6293 .41616 .6127 Mtetra
.787 .663 .727 r
.41616 .6127 .42441 .6293 .43912 .61724 .4311 .59333 Mtetra
.748 .604 .697 r
.4311 .59333 .43912 .61724 .454 .59786 .446 .57395 Mtetra
.724 .591 .707 r
.446 .57395 .454 .59786 .46883 .57823 .46077 .55854 Mtetra
.705 .605 .743 r
.46077 .55854 .46883 .57823 .48357 .56193 .47545 .548 Mtetra
.678 .649 .814 r
.47545 .548 .48357 .56193 .49825 .55002 .49011 .54185 Mtetra
.603 .733 .936 r
.49011 .54185 .49825 .55002 .51292 .5423 .50482 .53916 Mtetra
.294 .741 .961 r
.50482 .53916 .51292 .5423 .52766 .53808 .51962 .53897 Mtetra
.211 0 0 r
.51962 .53897 .52766 .53808 .54248 .53656 .53454 .5405 Mtetra
.423 0 0 r
.53454 .5405 .54248 .53656 .55743 .53701 .5496 .54311 Mtetra
.492 0 0 r
.5496 .54311 .55743 .53701 .57253 .53883 .56482 .54633 Mtetra
.516 .037 .057 r
.56482 .54633 .57253 .53883 .58779 .54155 .5802 .54982 Mtetra
.522 .055 .085 r
.5802 .54982 .58779 .54155 .6032 .54478 .59574 .55335 Mtetra
.52 .055 .09 r
.59574 .55335 .6032 .54478 .61878 .54826 .61144 .55674 Mtetra
.511 .043 .079 r
.61144 .55674 .61878 .54826 .63452 .55179 .62729 .55989 Mtetra
.497 .021 .055 r
.62729 .55989 .63452 .55179 .65042 .55523 .64329 .56273 Mtetra
.477 0 .019 r
.64329 .56273 .65042 .55523 .66648 .55848 .65944 .56522 Mtetra
.451 0 0 r
.65944 .56522 .66648 .55848 .68269 .56147 .67573 .56734 Mtetra
.418 0 0 r
.67573 .56734 .68269 .56147 .69905 .56415 .69216 .56907 Mtetra
.374 0 0 r
.69216 .56907 .69905 .56415 .71555 .56651 .70872 .57043 Mtetra
.319 0 0 r
.70872 .57043 .71555 .56651 .7322 .56853 .72542 .57141 Mtetra
.249 0 0 r
.72542 .57141 .7322 .56853 .74898 .57021 .74225 .57204 Mtetra
.163 0 0 r
.74225 .57204 .74898 .57021 .7659 .57154 .75921 .57233 Mtetra
.063 0 0 r
.75921 .57233 .7659 .57154 .78295 .57254 .77629 .57229 Mtetra
.047 .614 .745 r
.77629 .57229 .78295 .57254 .80013 .57321 .7935 .57195 Mtetra
.156 .69 .847 r
.7935 .57195 .80013 .57321 .81744 .57357 .81083 .57131 Mtetra
.255 .743 .921 r
.81083 .57131 .81744 .57357 .83487 .57363 .82828 .5704 Mtetra
.34 .774 .968 r
.82828 .5704 .83487 .57363 .85244 .57341 .84585 .56923 Mtetra
.407 .788 .992 r
.84585 .56923 .85244 .57341 .87012 .57291 .86354 .56782 Mtetra
.459 .789 .999 r
.86354 .56782 .87012 .57291 .88793 .57216 .88135 .56618 Mtetra
.498 .782 .996 r
.88135 .56618 .88793 .57216 .90587 .57116 .89928 .56432 Mtetra
.527 .771 .987 r
.89928 .56432 .90587 .57116 .92392 .56992 .91733 .56226 Mtetra
.549 .759 .975 r
.91733 .56226 .92392 .56992 .9421 .56847 .9355 .56 Mtetra
.819 .958 .904 r
.3083 .62459 .31765 .62457 .33094 .63176 .32273 .61308 Mtetra
.303 .388 .784 r
.32273 .61308 .33094 .63176 .34528 .62199 .33606 .62205 Mtetra
.936 .862 .742 r
.33606 .62205 .34528 .62199 .35956 .61401 .35139 .59511 Mtetra
.251 .353 .774 r
.35139 .59511 .35956 .61401 .3742 .59891 .36486 .60561 Mtetra
.7 .267 .218 r
.36486 .60561 .3742 .59891 .38754 .61602 .37848 .61715 Mtetra
.694 .976 .91 r
.37848 .61715 .38754 .61602 .40147 .62346 .3931 .60812 Mtetra
.794 .675 .733 r
.3931 .60812 .40147 .62346 .41616 .6127 .40811 .58879 Mtetra
.746 .603 .699 r
.40811 .58879 .41616 .6127 .4311 .59333 .42307 .56976 Mtetra
.718 .59 .711 r
.42307 .56976 .4311 .59333 .446 .57395 .43785 .55549 Mtetra
.694 .61 .758 r
.43785 .55549 .446 .57395 .46077 .55854 .45251 .54659 Mtetra
.653 .67 .854 r
.45251 .54659 .46077 .55854 .47545 .548 .46714 .5422 Mtetra
.492 .76 .99 r
.46714 .5422 .47545 .548 .49011 .54185 .4818 .5411 Mtetra
0 .541 .718 r
.4818 .5411 .49011 .54185 .50482 .53916 .49656 .54221 Mtetra
.388 0 0 r
.49656 .54221 .50482 .53916 .51962 .53897 .51144 .54468 Mtetra
.485 0 0 r
.51144 .54468 .51962 .53897 .53454 .5405 .52646 .54788 Mtetra
.515 .034 .052 r
.52646 .54788 .53454 .5405 .5496 .54311 .54164 .55139 Mtetra
.522 .054 .084 r
.54164 .55139 .5496 .54311 .56482 .54633 .55697 .5549 Mtetra
.517 .052 .088 r
.55697 .5549 .56482 .54633 .5802 .54982 .57246 .55822 Mtetra
.506 .036 .072 r
.57246 .55822 .5802 .54982 .59574 .55335 .58811 .56125 Mtetra
.488 .008 .041 r
.58811 .56125 .59574 .55335 .61144 .55674 .60391 .56389 Mtetra
.463 0 0 r
.60391 .56389 .61144 .55674 .62729 .55989 .61985 .56613 Mtetra
.43 0 0 r
.61985 .56613 .62729 .55989 .64329 .56273 .63593 .56794 Mtetra
.385 0 0 r
.63593 .56794 .64329 .56273 .65944 .56522 .65215 .56932 Mtetra
.326 0 0 r
.65215 .56932 .65944 .56522 .67573 .56734 .6685 .5703 Mtetra
.25 0 0 r
.6685 .5703 .67573 .56734 .69216 .56907 .68499 .57088 Mtetra
.155 0 0 r
.68499 .57088 .69216 .56907 .70872 .57043 .7016 .57108 Mtetra
.042 0 0 r
.7016 .57108 .70872 .57043 .72542 .57141 .71834 .57092 Mtetra
.08 .64 .776 r
.71834 .57092 .72542 .57141 .74225 .57204 .73519 .57044 Mtetra
.198 .715 .879 r
.73519 .57044 .74225 .57204 .75921 .57233 .75218 .56964 Mtetra
.302 .763 .948 r
.75218 .56964 .75921 .57233 .77629 .57229 .76928 .56854 Mtetra
.385 .786 .985 r
.76928 .56854 .77629 .57229 .7935 .57195 .7865 .56718 Mtetra
.447 .791 .998 r
.7865 .56718 .7935 .57195 .81083 .57131 .80383 .56556 Mtetra
.493 .785 .997 r
.80383 .56556 .81083 .57131 .82828 .5704 .82129 .56371 Mtetra
.527 .774 .988 r
.82129 .56371 .82828 .5704 .84585 .56923 .83886 .56163 Mtetra
.551 .759 .974 r
.83886 .56163 .84585 .56923 .86354 .56782 .85655 .55935 Mtetra
.569 .745 .959 r
.85655 .55935 .86354 .56782 .88135 .56618 .87435 .55687 Mtetra
.582 .73 .945 r
.87435 .55687 .88135 .56618 .89928 .56432 .89227 .55422 Mtetra
.592 .717 .93 r
.89227 .55422 .89928 .56432 .91733 .56226 .91031 .55139 Mtetra
.6 .704 .917 r
.91031 .55139 .91733 .56226 .9355 .56 .92846 .5484 Mtetra
.638 .602 .798 r
.29987 .60845 .3083 .62459 .32273 .61308 .31387 .60447 Mtetra
.637 .728 .914 r
.31387 .60447 .32273 .61308 .33606 .62205 .32792 .60087 Mtetra
.651 .567 .747 r
.32792 .60087 .33606 .62205 .35139 .59511 .34218 .59493 Mtetra
.773 .293 .093 r
.34218 .59493 .35139 .59511 .36486 .60561 .35545 .61015 Mtetra
0 0 0 r
.35545 .61015 .36486 .60561 .37848 .61715 .36995 .6035 Mtetra
.805 .694 .742 r
.36995 .6035 .37848 .61715 .3931 .60812 .38503 .58424 Mtetra
.744 .602 .7 r
.38503 .58424 .3931 .60812 .40811 .58879 .40003 .56573 Mtetra
.709 .588 .718 r
.40003 .56573 .40811 .58879 .42307 .56976 .4148 .55292 Mtetra
.677 .617 .781 r
.4148 .55292 .42307 .56976 .43785 .55549 .42942 .54598 Mtetra
.602 .701 .913 r
.42942 .54598 .43785 .55549 .45251 .54659 .44398 .5435 Mtetra
.222 .7 .936 r
.44398 .5435 .45251 .54659 .46714 .5422 .45858 .544 Mtetra
.322 0 0 r
.45858 .544 .46714 .5422 .4818 .5411 .47328 .54626 Mtetra
.475 0 0 r
.47328 .54626 .4818 .5411 .49656 .54221 .48811 .54944 Mtetra
.514 .03 .046 r
.48811 .54944 .49656 .54221 .51144 .54468 .50308 .55295 Mtetra
.521 .052 .083 r
.50308 .55295 .51144 .54468 .52646 .54788 .51822 .55644 Mtetra
.514 .048 .084 r
.51822 .55644 .52646 .54788 .54164 .55139 .53351 .55966 Mtetra
.499 .026 .063 r
.53351 .55966 .54164 .55139 .55697 .5549 .54895 .5625 Mtetra
.476 0 .022 r
.54895 .5625 .55697 .5549 .57246 .55822 .56454 .56489 Mtetra
.443 0 0 r
.56454 .56489 .57246 .55822 .58811 .56125 .58028 .5668 Mtetra
.397 0 0 r
.58028 .5668 .58811 .56125 .60391 .56389 .59616 .56823 Mtetra
.335 0 0 r
.59616 .56823 .60391 .56389 .61985 .56613 .61218 .56919 Mtetra
.252 0 0 r
.61218 .56919 .61985 .56613 .63593 .56794 .62832 .56971 Mtetra
.145 0 0 r
.62832 .56971 .63593 .56794 .65215 .56932 .6446 .56981 Mtetra
.016 0 0 r
.6446 .56981 .65215 .56932 .6685 .5703 .661 .56951 Mtetra
.121 .669 .811 r
.661 .56951 .6685 .5703 .68499 .57088 .67752 .56885 Mtetra
.249 .742 .913 r
.67752 .56885 .68499 .57088 .7016 .57108 .69416 .56786 Mtetra
.353 .781 .972 r
.69416 .56786 .7016 .57108 .71834 .57092 .71092 .56655 Mtetra
.432 .793 .996 r
.71092 .56655 .71834 .57092 .73519 .57044 .7278 .56496 Mtetra
.488 .789 .998 r
.7278 .56496 .73519 .57044 .75218 .56964 .74479 .56311 Mtetra
.527 .776 .989 r
.74479 .56311 .75218 .56964 .76928 .56854 .7619 .56101 Mtetra
.554 .76 .974 r
.7619 .56101 .76928 .56854 .7865 .56718 .77912 .55869 Mtetra
.573 .743 .957 r
.77912 .55869 .7865 .56718 .80383 .56556 .79646 .55615 Mtetra
.587 .727 .94 r
.79646 .55615 .80383 .56556 .82129 .56371 .81391 .55343 Mtetra
.597 .712 .925 r
.81391 .55343 .82129 .56371 .83886 .56163 .83147 .55052 Mtetra
.604 .699 .91 r
.83147 .55052 .83886 .56163 .85655 .55935 .84915 .54745 Mtetra
.61 .686 .897 r
.84915 .54745 .85655 .55935 .87435 .55687 .86694 .54423 Mtetra
.614 .675 .885 r
.86694 .54423 .87435 .55687 .89227 .55422 .88485 .54085 Mtetra
.617 .665 .874 r
.88485 .54085 .89227 .55422 .91031 .55139 .90287 .53734 Mtetra
.619 .656 .864 r
.90287 .53734 .91031 .55139 .92846 .5484 .921 .5337 Mtetra
0 0 0 r
.29022 .60937 .29987 .60845 .31387 .60447 .30411 .60831 Mtetra
.931 .954 .775 r
.30411 .60831 .31387 .60447 .32792 .60087 .31934 .58663 Mtetra
0 .069 .629 r
.31934 .58663 .32792 .60087 .34218 .59493 .33242 .60211 Mtetra
.191 0 0 r
.33242 .60211 .34218 .59493 .35545 .61015 .34671 .59881 Mtetra
.821 .721 .755 r
.34671 .59881 .35545 .61015 .36995 .6035 .36185 .57967 Mtetra
.739 .601 .702 r
.36185 .57967 .36995 .6035 .38503 .58424 .37688 .56194 Mtetra
.697 .586 .727 r
.37688 .56194 .38503 .58424 .40003 .56573 .3916 .55105 Mtetra
.651 .63 .817 r
.3916 .55105 .40003 .56573 .4148 .55292 .40613 .54637 Mtetra
.473 .732 .983 r
.40613 .54637 .4148 .55292 .42942 .54598 .42061 .5459 Mtetra
.183 0 0 r
.42061 .5459 .42942 .54598 .44398 .5435 .43513 .54785 Mtetra
.458 0 0 r
.43513 .54785 .44398 .5435 .45858 .544 .44977 .55099 Mtetra
.511 .024 .036 r
.44977 .55099 .45858 .544 .47328 .54626 .46454 .55451 Mtetra
.519 .05 .08 r
.46454 .55451 .47328 .54626 .48811 .54944 .47948 .55795 Mtetra
.509 .041 .079 r
.47948 .55795 .48811 .54944 .50308 .55295 .49457 .56103 Mtetra
.488 .011 .048 r
.49457 .56103 .50308 .55295 .51822 .55644 .50981 .56362 Mtetra
.457 0 0 r
.50981 .56362 .51822 .55644 .53351 .55966 .52521 .56566 Mtetra
.411 0 0 r
.52521 .56566 .53351 .55966 .54895 .5625 .54075 .56715 Mtetra
.346 0 0 r
.54075 .56715 .54895 .5625 .56454 .56489 .55643 .5681 Mtetra
.254 0 0 r
.55643 .5681 .56454 .56489 .58028 .5668 .57225 .56854 Mtetra
.131 0 0 r
.57225 .56854 .58028 .5668 .59616 .56823 .5882 .5685 Mtetra
0 0 0 r
.5882 .5685 .59616 .56823 .61218 .56919 .60427 .56803 Mtetra
.173 .702 .852 r
.60427 .56803 .61218 .56919 .62832 .56971 .62047 .56716 Mtetra
.308 .769 .947 r
.62047 .56716 .62832 .56971 .6446 .56981 .63678 .56593 Mtetra
.41 .794 .99 r
.63678 .56593 .6446 .56981 .661 .56951 .65321 .56437 Mtetra
.48 .793 .999 r
.65321 .56437 .661 .56951 .67752 .56885 .66976 .56251 Mtetra
.527 .78 .99 r
.66976 .56251 .67752 .56885 .69416 .56786 .68642 .56038 Mtetra
.558 .761 .973 r
.68642 .56038 .69416 .56786 .71092 .56655 .70319 .558 Mtetra
.578 .742 .954 r
.70319 .558 .71092 .56655 .7278 .56496 .72008 .5554 Mtetra
.592 .723 .935 r
.72008 .5554 .7278 .56496 .74479 .56311 .73707 .55258 Mtetra
.602 .707 .917 r
.73707 .55258 .74479 .56311 .7619 .56101 .75418 .54958 Mtetra
.609 .692 .902 r
.75418 .54958 .7619 .56101 .77912 .55869 .7714 .5464 Mtetra
.614 .678 .887 r
.7714 .5464 .77912 .55869 .79646 .55615 .78873 .54307 Mtetra
.618 .667 .875 r
.78873 .54307 .79646 .55615 .81391 .55343 .80617 .53958 Mtetra
.62 .656 .864 r
.80617 .53958 .81391 .55343 .83147 .55052 .82372 .53595 Mtetra
.622 .647 .854 r
.82372 .53595 .83147 .55052 .84915 .54745 .84138 .5322 Mtetra
.624 .639 .845 r
.84138 .5322 .84915 .54745 .86694 .54423 .85915 .52832 Mtetra
.625 .631 .837 r
.85915 .52832 .86694 .54423 .88485 .54085 .87704 .52434 Mtetra
.626 .625 .83 r
.87704 .52434 .88485 .54085 .90287 .53734 .89504 .52024 Mtetra
.626 .619 .823 r
.89504 .52024 .90287 .53734 .921 .5337 .91315 .51605 Mtetra
.639 .594 .787 r
.28173 .59213 .29022 .60937 .30411 .60831 .29583 .58778 Mtetra
.451 .461 .778 r
.29583 .58778 .30411 .60831 .31934 .58663 .30943 .59263 Mtetra
.421 0 0 r
.30943 .59263 .31934 .58663 .33242 .60211 .32338 .59403 Mtetra
.845 .767 .776 r
.32338 .59403 .33242 .60211 .34671 .59881 .33857 .57511 Mtetra
.733 .598 .706 r
.33857 .57511 .34671 .59881 .36185 .57967 .3536 .55856 Mtetra
.678 .584 .743 r
.3536 .55856 .36185 .57967 .37688 .56194 .36823 .55015 Mtetra
.597 .654 .877 r
.36823 .55015 .37688 .56194 .3916 .55105 .38263 .54802 Mtetra
.112 .631 .886 r
.38263 .54802 .3916 .55105 .40613 .54637 .397 .54947 Mtetra
.423 0 0 r
.397 .54947 .40613 .54637 .42061 .5459 .41144 .55254 Mtetra
.508 .015 .021 r
.41144 .55254 .42061 .5459 .43513 .54785 .42602 .55607 Mtetra
.516 .045 .076 r
.42602 .55607 .43513 .54785 .44977 .55099 .44075 .55942 Mtetra
.501 .031 .07 r
.44075 .55942 .44977 .55099 .46454 .55451 .45565 .56227 Mtetra
.472 0 .024 r
.45565 .56227 .46454 .55451 .47948 .55795 .4707 .5645 Mtetra
.427 0 0 r
.4707 .5645 .47948 .55795 .49457 .56103 .48591 .56608 Mtetra
.358 0 0 r
.48591 .56608 .49457 .56103 .50981 .56362 .50127 .56701 Mtetra
.256 0 0 r
.50127 .56701 .50981 .56362 .52521 .56566 .51676 .56735 Mtetra
.113 0 0 r
.51676 .56735 .52521 .56566 .54075 .56715 .53239 .56714 Mtetra
.063 .627 .744 r
.53239 .56714 .54075 .56715 .55643 .5681 .54815 .56645 Mtetra
.237 .74 .898 r
.54815 .56645 .55643 .5681 .57225 .56854 .56403 .56532 Mtetra
.376 .792 .978 r
.56403 .56532 .57225 .56854 .5882 .5685 .58003 .5638 Mtetra
.469 .799 .999 r
.58003 .5638 .5882 .5685 .60427 .56803 .59614 .56192 Mtetra
.527 .784 .991 r
.59614 .56192 .60427 .56803 .62047 .56716 .61237 .55974 Mtetra
.562 .762 .972 r
.61237 .55974 .62047 .56716 .63678 .56593 .62871 .55729 Mtetra
.585 .739 .95 r
.62871 .55729 .63678 .56593 .65321 .56437 .64516 .55458 Mtetra
.599 .718 .928 r
.64516 .55458 .65321 .56437 .66976 .56251 .66172 .55165 Mtetra
.608 .7 .909 r
.66172 .55165 .66976 .56251 .68642 .56038 .67839 .54853 Mtetra
.615 .683 .891 r
.67839 .54853 .68642 .56038 .70319 .558 .69517 .54521 Mtetra
.619 .669 .876 r
.69517 .54521 .70319 .558 .72008 .5554 .71205 .54174 Mtetra
.622 .657 .863 r
.71205 .54174 .72008 .5554 .73707 .55258 .72904 .53811 Mtetra
.624 .646 .852 r
.72904 .53811 .73707 .55258 .75418 .54958 .74614 .53434 Mtetra
.625 .636 .842 r
.74614 .53434 .75418 .54958 .7714 .5464 .76335 .53045 Mtetra
.626 .628 .833 r
.76335 .53045 .7714 .5464 .78873 .54307 .78067 .52644 Mtetra
.627 .621 .825 r
.78067 .52644 .78873 .54307 .80617 .53958 .79809 .52232 Mtetra
.627 .614 .818 r
.79809 .52232 .80617 .53958 .82372 .53595 .81562 .5181 Mtetra
.628 .608 .812 r
.81562 .5181 .82372 .53595 .84138 .5322 .83327 .51378 Mtetra
.628 .603 .806 r
.83327 .51378 .84138 .5322 .85915 .52832 .85102 .50937 Mtetra
.628 .599 .801 r
.85102 .50937 .85915 .52832 .87704 .52434 .86888 .50488 Mtetra
.628 .594 .797 r
.86888 .50488 .87704 .52434 .89504 .52024 .88686 .50031 Mtetra
.628 .59 .793 r
.88686 .50031 .89504 .52024 .91315 .51605 .90495 .49566 Mtetra
.801 .985 .892 r
.27179 .59372 .28173 .59213 .29583 .58778 .2865 .5819 Mtetra
0 .281 .694 r
.2865 .5819 .29583 .58778 .30943 .59263 .29997 .58908 Mtetra
.88 .845 .806 r
.29997 .58908 .30943 .59263 .32338 .59403 .3152 .57057 Mtetra
.722 .593 .712 r
.3152 .57057 .32338 .59403 .33857 .57511 .33017 .55587 Mtetra
.646 .582 .769 r
.33017 .55587 .33857 .57511 .3536 .55856 .34463 .55062 Mtetra
.449 .684 .966 r
.34463 .55062 .3536 .55856 .36823 .55015 .35887 .55113 Mtetra
.336 0 0 r
.35887 .55113 .36823 .55015 .38263 .54802 .37313 .55409 Mtetra
.501 0 0 r
.37313 .55409 .38263 .54802 .397 .54947 .38751 .55762 Mtetra
.51 .038 .069 r
.38751 .55762 .397 .54947 .41144 .55254 .40204 .56081 Mtetra
.488 .013 .054 r
.40204 .56081 .41144 .55254 .42602 .55607 .41676 .56331 Mtetra
.444 0 0 r
.41676 .56331 .42602 .55607 .44075 .55942 .43163 .56501 Mtetra
.373 0 0 r
.43163 .56501 .44075 .55942 .45565 .56227 .44667 .56593 Mtetra
.259 0 0 r
.44667 .56593 .45565 .56227 .4707 .5645 .46185 .56613 Mtetra
.088 0 0 r
.46185 .56613 .4707 .5645 .48591 .56608 .47717 .56569 Mtetra
.125 .673 .797 r
.47717 .56569 .48591 .56608 .50127 .56701 .49263 .5647 Mtetra
.319 .778 .946 r
.49263 .5647 .50127 .56701 .51676 .56735 .5082 .56323 Mtetra
.45 .805 .997 r
.5082 .56323 .51676 .56735 .53239 .56714 .5239 .56134 Mtetra
.526 .791 .993 r
.5239 .56134 .53239 .56714 .54815 .56645 .53971 .55908 Mtetra
.568 .764 .97 r
.53971 .55908 .54815 .56645 .56403 .56532 .55564 .55651 Mtetra
.592 .736 .944 r
.55564 .55651 .56403 .56532 .58003 .5638 .57167 .55367 Mtetra
.606 .711 .919 r
.57167 .55367 .58003 .5638 .59614 .56192 .58781 .55059 Mtetra
.615 .69 .897 r
.58781 .55059 .59614 .56192 .61237 .55974 .60406 .54729 Mtetra
.62 .672 .878 r
.60406 .54729 .61237 .55974 .62871 .55729 .62042 .54381 Mtetra
.623 .657 .862 r
.62042 .54381 .62871 .55729 .64516 .55458 .63688 .54016 Mtetra
.626 .644 .849 r
.63688 .54016 .64516 .55458 .66172 .55165 .65344 .53636 Mtetra
.627 .634 .837 r
.65344 .53636 .66172 .55165 .67839 .54853 .67011 .53243 Mtetra
.628 .624 .828 r
.67011 .53243 .67839 .54853 .69517 .54521 .68688 .52837 Mtetra
.628 .616 .819 r
.68688 .52837 .69517 .54521 .71205 .54174 .70376 .5242 Mtetra
.628 .609 .812 r
.70376 .5242 .71205 .54174 .72904 .53811 .72074 .51993 Mtetra
.628 .603 .805 r
.72074 .51993 .72904 .53811 .74614 .53434 .73782 .51556 Mtetra
.628 .597 .799 r
.73782 .51556 .74614 .53434 .76335 .53045 .75502 .5111 Mtetra
.628 .592 .794 r
.75502 .5111 .76335 .53045 .78067 .52644 .77232 .50656 Mtetra
.628 .588 .789 r
.77232 .50656 .78067 .52644 .79809 .52232 .78972 .50195 Mtetra
.628 .584 .785 r
.78972 .50195 .79809 .52232 .81562 .5181 .80723 .49726 Mtetra
.628 .58 .782 r
.80723 .49726 .81562 .5181 .83327 .51378 .82486 .4925 Mtetra
.628 .577 .778 r
.82486 .4925 .83327 .51378 .85102 .50937 .84259 .48768 Mtetra
.627 .574 .775 r
.84259 .48768 .85102 .50937 .86888 .50488 .86043 .48279 Mtetra
.627 .572 .773 r
.86043 .48279 .86888 .50488 .88686 .50031 .87838 .47784 Mtetra
.627 .569 .77 r
.87838 .47784 .88686 .50031 .90495 .49566 .89644 .47284 Mtetra
.292 .396 .797 r
.26322 .5756 .27179 .59372 .2865 .5819 .27649 .58379 Mtetra
.899 .955 .827 r
.27649 .58379 .2865 .5819 .29997 .58908 .29172 .56612 Mtetra
.701 .585 .723 r
.29172 .56612 .29997 .58908 .3152 .57057 .30654 .55439 Mtetra
.584 .584 .818 r
.30654 .55439 .3152 .57057 .33017 .55587 .32075 .55291 Mtetra
0 .52 .796 r
.32075 .55291 .33017 .55587 .34463 .55062 .33483 .55564 Mtetra
.486 0 0 r
.33483 .55564 .34463 .55062 .35887 .55113 .34901 .55914 Mtetra
.499 .023 .056 r
.34901 .55914 .35887 .55113 .37313 .55409 .36336 .56204 Mtetra
.462 0 .023 r
.36336 .56204 .37313 .55409 .38751 .55762 .37791 .56394 Mtetra
.39 0 0 r
.37791 .56394 .38751 .55762 .40204 .56081 .39263 .56484 Mtetra
.262 0 0 r
.39263 .56484 .40204 .56081 .41676 .56331 .40751 .56484 Mtetra
.049 0 0 r
.40751 .56484 .41676 .56331 .43163 .56501 .42254 .56408 Mtetra
.214 .732 .865 r
.42254 .56408 .43163 .56501 .44667 .56593 .43771 .56267 Mtetra
.416 .809 .986 r
.43771 .56267 .44667 .56593 .46185 .56613 .453 .56074 Mtetra
.525 .8 .996 r
.453 .56074 .46185 .56613 .47717 .56569 .46842 .55837 Mtetra
.577 .766 .968 r
.46842 .55837 .47717 .56569 .49263 .5647 .48394 .55563 Mtetra
.602 .731 .935 r
.48394 .55563 .49263 .5647 .5082 .56323 .49958 .5526 Mtetra
.615 .701 .906 r
.49958 .5526 .5082 .56323 .5239 .56134 .51532 .5493 Mtetra
.622 .677 .881 r
.51532 .5493 .5239 .56134 .53971 .55908 .53117 .54578 Mtetra
.626 .658 .862 r
.53117 .54578 .53971 .55908 .55564 .55651 .54712 .54208 Mtetra
.628 .642 .845 r
.54712 .54208 .55564 .55651 .57167 .55367 .56318 .53821 Mtetra
.629 .629 .832 r
.56318 .53821 .57167 .55367 .58781 .55059 .57933 .5342 Mtetra
.629 .618 .821 r
.57933 .5342 .58781 .55059 .60406 .54729 .59559 .53006 Mtetra
.63 .609 .811 r
.59559 .53006 .60406 .54729 .62042 .54381 .61194 .52581 Mtetra
.629 .602 .803 r
.61194 .52581 .62042 .54381 .63688 .54016 .6284 .52146 Mtetra
.629 .595 .796 r
.6284 .52146 .63688 .54016 .65344 .53636 .64496 .51702 Mtetra
.629 .589 .79 r
.64496 .51702 .65344 .53636 .67011 .53243 .66162 .51249 Mtetra
.629 .584 .785 r
.66162 .51249 .67011 .53243 .68688 .52837 .67838 .50788 Mtetra
.628 .58 .781 r
.67838 .50788 .68688 .52837 .70376 .5242 .69524 .5032 Mtetra
.628 .576 .777 r
.69524 .5032 .70376 .5242 .72074 .51993 .71221 .49846 Mtetra
.628 .573 .773 r
.71221 .49846 .72074 .51993 .73782 .51556 .72927 .49365 Mtetra
.627 .569 .77 r
.72927 .49365 .73782 .51556 .75502 .5111 .74645 .48878 Mtetra
.627 .567 .767 r
.74645 .48878 .75502 .5111 .77232 .50656 .76373 .48386 Mtetra
.627 .564 .765 r
.76373 .48386 .77232 .50656 .78972 .50195 .78111 .47888 Mtetra
.626 .562 .762 r
.78111 .47888 .78972 .50195 .80723 .49726 .7986 .47385 Mtetra
.626 .56 .76 r
.7986 .47385 .80723 .49726 .82486 .4925 .8162 .46876 Mtetra
.626 .558 .758 r
.8162 .46876 .82486 .4925 .84259 .48768 .83391 .46363 Mtetra
.626 .556 .757 r
.83391 .46363 .84259 .48768 .86043 .48279 .85172 .45845 Mtetra
.625 .555 .755 r
.85172 .45845 .86043 .48279 .87838 .47784 .86965 .45323 Mtetra
.625 .553 .754 r
.86965 .45323 .87838 .47784 .89644 .47284 .88769 .44796 Mtetra
.874 .971 .849 r
.25299 .57762 .26322 .5756 .27649 .58379 .26812 .56196 Mtetra
.659 .57 .744 r
.26812 .56196 .27649 .58379 .29172 .56612 .28261 .55502 Mtetra
.424 .596 .916 r
.28261 .55502 .29172 .56612 .30654 .55439 .29654 .5572 Mtetra
.435 0 0 r
.29654 .5572 .30654 .55439 .32075 .55291 .31053 .56059 Mtetra
.473 0 .024 r
.31053 .56059 .32075 .55291 .33483 .55564 .32473 .56287 Mtetra
.408 0 0 r
.32473 .56287 .33483 .55564 .34901 .55914 .33914 .56375 Mtetra
.262 0 0 r
.33914 .56375 .34901 .55914 .36336 .56204 .35374 .56341 Mtetra
0 0 0 r
.35374 .56341 .36336 .56204 .37791 .56394 .3685 .56212 Mtetra
.342 .799 .943 r
.3685 .56212 .37791 .56394 .39263 .56484 .38341 .56011 Mtetra
.521 .815 .999 r
.38341 .56011 .39263 .56484 .40751 .56484 .39845 .55754 Mtetra
.59 .768 .964 r
.39845 .55754 .40751 .56484 .42254 .56408 .4136 .55455 Mtetra
.615 .722 .922 r
.4136 .55455 .42254 .56408 .43771 .56267 .42886 .55121 Mtetra
.626 .686 .887 r
.42886 .55121 .43771 .56267 .453 .56074 .44423 .54761 Mtetra
.63 .659 .86 r
.44423 .54761 .453 .56074 .46842 .55837 .4597 .5438 Mtetra
.631 .639 .839 r
.4597 .5438 .46842 .55837 .48394 .55563 .47527 .53981 Mtetra
.632 .623 .823 r
.47527 .53981 .48394 .55563 .49958 .5526 .49094 .53567 Mtetra
.631 .61 .811 r
.49094 .53567 .49958 .5526 .51532 .5493 .5067 .5314 Mtetra
.631 .6 .8 r
.5067 .5314 .51532 .5493 .53117 .54578 .52257 .52703 Mtetra
.63 .592 .792 r
.52257 .52703 .53117 .54578 .54712 .54208 .53852 .52256 Mtetra
.63 .585 .785 r
.53852 .52256 .54712 .54208 .56318 .53821 .55458 .51801 Mtetra
.629 .579 .779 r
.55458 .51801 .56318 .53821 .57933 .5342 .57073 .51339 Mtetra
.629 .574 .774 r
.57073 .51339 .57933 .5342 .59559 .53006 .58698 .50869 Mtetra
.628 .57 .77 r
.58698 .50869 .59559 .53006 .61194 .52581 .60333 .50394 Mtetra
.627 .566 .766 r
.60333 .50394 .61194 .52581 .6284 .52146 .61978 .49912 Mtetra
.627 .563 .763 r
.61978 .49912 .6284 .52146 .64496 .51702 .63632 .49425 Mtetra
.627 .56 .76 r
.63632 .49425 .64496 .51702 .66162 .51249 .65296 .48933 Mtetra
.626 .558 .758 r
.65296 .48933 .66162 .51249 .67838 .50788 .66971 .48437 Mtetra
.626 .556 .756 r
.66971 .48437 .67838 .50788 .69524 .5032 .68655 .47935 Mtetra
.625 .554 .754 r
.68655 .47935 .69524 .5032 .71221 .49846 .7035 .47429 Mtetra
.625 .552 .752 r
.7035 .47429 .71221 .49846 .72927 .49365 .72055 .46919 Mtetra
.625 .55 .75 r
.72055 .46919 .72927 .49365 .74645 .48878 .7377 .46404 Mtetra
.625 .549 .749 r
.7377 .46404 .74645 .48878 .76373 .48386 .75496 .45885 Mtetra
.624 .548 .748 r
.75496 .45885 .76373 .48386 .78111 .47888 .77232 .45363 Mtetra
.624 .546 .747 r
.77232 .45363 .78111 .47888 .7986 .47385 .78978 .44836 Mtetra
.624 .545 .745 r
.78978 .44836 .7986 .47385 .8162 .46876 .80736 .44305 Mtetra
.624 .544 .745 r
.80736 .44305 .8162 .46876 .83391 .46363 .82504 .4377 Mtetra
.623 .543 .744 r
.82504 .4377 .83391 .46363 .85172 .45845 .84283 .43232 Mtetra
.623 .543 .743 r
.84283 .43232 .85172 .45845 .86965 .45323 .86073 .42689 Mtetra
.623 .542 .742 r
.86073 .42689 .86965 .45323 .88769 .44796 .87874 .42143 Mtetra
.555 .542 .795 r
.24433 .55888 .25299 .57762 .26812 .56196 .25827 .55875 Mtetra
0 .499 .784 r
.25827 .55875 .26812 .56196 .28261 .55502 .27209 .56176 Mtetra
.395 0 0 r
.27209 .56176 .28261 .55502 .29654 .5572 .2862 .56259 Mtetra
.246 0 0 r
.2862 .56259 .29654 .5572 .31053 .56059 .30055 .56159 Mtetra
.149 .692 .75 r
.30055 .56159 .31053 .56059 .32473 .56287 .3151 .55939 Mtetra
.509 .841 .998 r
.3151 .55939 .32473 .56287 .33914 .56375 .32978 .55643 Mtetra
.61 .771 .957 r
.32978 .55643 .33914 .56375 .35374 .56341 .34459 .55297 Mtetra
.632 .705 .899 r
.34459 .55297 .35374 .56341 .3685 .56212 .35951 .54918 Mtetra
.636 .662 .858 r
.35951 .54918 .3685 .56212 .38341 .56011 .37453 .54514 Mtetra
.636 .632 .83 r
.37453 .54514 .38341 .56011 .39845 .55754 .38965 .54093 Mtetra
.635 .612 .81 r
.38965 .54093 .39845 .55754 .4136 .55455 .40486 .53658 Mtetra
.633 .597 .796 r
.40486 .53658 .4136 .55455 .42886 .55121 .42017 .53213 Mtetra
.632 .586 .785 r
.42017 .53213 .42886 .55121 .44423 .54761 .43557 .52758 Mtetra
.63 .578 .777 r
.43557 .52758 .44423 .54761 .4597 .5438 .45105 .52297 Mtetra
.629 .571 .77 r
.45105 .52297 .4597 .5438 .47527 .53981 .46664 .51828 Mtetra
.628 .565 .765 r
.46664 .51828 .47527 .53981 .49094 .53567 .48231 .51355 Mtetra
.627 .561 .76 r
.48231 .51355 .49094 .53567 .5067 .5314 .49807 .50875 Mtetra
.627 .557 .757 r
.49807 .50875 .5067 .5314 .52257 .52703 .51393 .50392 Mtetra
.626 .554 .754 r
.51393 .50392 .52257 .52703 .53852 .52256 .52988 .49904 Mtetra
.625 .552 .751 r
.52988 .49904 .53852 .52256 .55458 .51801 .54593 .49411 Mtetra
.625 .549 .749 r
.54593 .49411 .55458 .51801 .57073 .51339 .56207 .48915 Mtetra
.625 .547 .747 r
.56207 .48915 .57073 .51339 .58698 .50869 .5783 .48415 Mtetra
.624 .546 .746 r
.5783 .48415 .58698 .50869 .60333 .50394 .59463 .47911 Mtetra
.624 .544 .744 r
.59463 .47911 .60333 .50394 .61978 .49912 .61106 .47403 Mtetra
.624 .543 .743 r
.61106 .47403 .61978 .49912 .63632 .49425 .62758 .46892 Mtetra
.623 .542 .742 r
.62758 .46892 .63632 .49425 .65296 .48933 .64421 .46378 Mtetra
.623 .541 .741 r
.64421 .46378 .65296 .48933 .66971 .48437 .66093 .45859 Mtetra
.623 .54 .74 r
.66093 .45859 .66971 .48437 .68655 .47935 .67775 .45338 Mtetra
.623 .539 .739 r
.67775 .45338 .68655 .47935 .7035 .47429 .69467 .44813 Mtetra
.622 .538 .738 r
.69467 .44813 .7035 .47429 .72055 .46919 .7117 .44284 Mtetra
.7117 .44284 .72055 .46919 .7377 .46404 .72883 .43752 Mtetra
.622 .537 .737 r
.72883 .43752 .7377 .46404 .75496 .45885 .74606 .43217 Mtetra
.622 .536 .737 r
.74606 .43217 .75496 .45885 .77232 .45363 .76339 .42678 Mtetra
.622 .536 .736 r
.76339 .42678 .77232 .45363 .78978 .44836 .78083 .42136 Mtetra
.622 .535 .736 r
.78083 .42136 .78978 .44836 .80736 .44305 .79838 .4159 Mtetra
.622 .535 .735 r
.79838 .4159 .80736 .44305 .82504 .4377 .81604 .41041 Mtetra
.81604 .41041 .82504 .4377 .84283 .43232 .8338 .40488 Mtetra
.621 .534 .735 r
.8338 .40488 .84283 .43232 .86073 .42689 .85167 .39931 Mtetra
.621 .534 .734 r
.85167 .39931 .86073 .42689 .87874 .42143 .86965 .39372 Mtetra
0 0 0 r
.23383 .56106 .24433 .55888 .25827 .55875 .24806 .55816 Mtetra
.448 .869 .941 r
.24806 .55816 .25827 .55875 .27209 .56176 .26247 .55423 Mtetra
.643 .772 .942 r
.26247 .55423 .27209 .56176 .2862 .56259 .27699 .54994 Mtetra
.647 .667 .855 r
.27699 .54994 .2862 .56259 .30055 .56159 .29161 .54547 Mtetra
.64 .617 .811 r
.29161 .54547 .30055 .56159 .3151 .55939 .30631 .54091 Mtetra
.635 .59 .786 r
.30631 .54091 .3151 .55939 .32978 .55643 .3211 .53629 Mtetra
.632 .574 .771 r
.3211 .53629 .32978 .55643 .34459 .55297 .33597 .53162 Mtetra
.629 .563 .762 r
.33597 .53162 .34459 .55297 .35951 .54918 .35093 .5269 Mtetra
.627 .556 .755 r
.35093 .5269 .35951 .54918 .37453 .54514 .36597 .52215 Mtetra
.626 .551 .75 r
.36597 .52215 .37453 .54514 .38965 .54093 .3811 .51737 Mtetra
.625 .547 .746 r
.3811 .51737 .38965 .54093 .40486 .53658 .39631 .51256 Mtetra
.624 .544 .744 r
.39631 .51256 .40486 .53658 .42017 .53213 .41162 .50771 Mtetra
.624 .542 .741 r
.41162 .50771 .42017 .53213 .43557 .52758 .42701 .50284 Mtetra
.623 .54 .74 r
.42701 .50284 .43557 .52758 .45105 .52297 .44248 .49793 Mtetra
.623 .538 .738 r
.44248 .49793 .45105 .52297 .46664 .51828 .45805 .493 Mtetra
.622 .537 .737 r
.45805 .493 .46664 .51828 .48231 .51355 .47371 .48803 Mtetra
.622 .536 .736 r
.47371 .48803 .48231 .51355 .49807 .50875 .48945 .48304 Mtetra
.622 .535 .735 r
.48945 .48304 .49807 .50875 .51393 .50392 .50529 .47801 Mtetra
.622 .534 .735 r
.50529 .47801 .51393 .50392 .52988 .49904 .52122 .47296 Mtetra
.621 .534 .734 r
.52122 .47296 .52988 .49904 .54593 .49411 .53725 .46788 Mtetra
.621 .533 .734 r
.53725 .46788 .54593 .49411 .56207 .48915 .55336 .46276 Mtetra
.621 .533 .733 r
.55336 .46276 .56207 .48915 .5783 .48415 .56958 .45762 Mtetra
.621 .532 .733 r
.56958 .45762 .5783 .48415 .59463 .47911 .58588 .45244 Mtetra
.621 .532 .732 r
.58588 .45244 .59463 .47911 .61106 .47403 .60229 .44724 Mtetra
.60229 .44724 .61106 .47403 .62758 .46892 .61879 .442 Mtetra
.621 .531 .732 r
.61879 .442 .62758 .46892 .64421 .46378 .63539 .43673 Mtetra
.63539 .43673 .64421 .46378 .66093 .45859 .65208 .43144 Mtetra
.621 .531 .731 r
.65208 .43144 .66093 .45859 .67775 .45338 .66888 .4261 Mtetra
.66888 .4261 .67775 .45338 .69467 .44813 .68578 .42074 Mtetra
.62 .53 .731 r
.68578 .42074 .69467 .44813 .7117 .44284 .70278 .41535 Mtetra
.70278 .41535 .7117 .44284 .72883 .43752 .71988 .40992 Mtetra
.71988 .40992 .72883 .43752 .74606 .43217 .73708 .40446 Mtetra
.62 .53 .73 r
.73708 .40446 .74606 .43217 .76339 .42678 .75439 .39896 Mtetra
.75439 .39896 .76339 .42678 .78083 .42136 .77181 .39344 Mtetra
.77181 .39344 .78083 .42136 .79838 .4159 .78933 .38788 Mtetra
.78933 .38788 .79838 .4159 .81604 .41041 .80696 .38228 Mtetra
.62 .529 .73 r
.80696 .38228 .81604 .41041 .8338 .40488 .82469 .37665 Mtetra
.82469 .37665 .8338 .40488 .85167 .39931 .84254 .37099 Mtetra
.84254 .37099 .85167 .39931 .86965 .39372 .86049 .36529 Mtetra
.658 .593 .771 r
.22505 .54196 .23383 .56106 .24806 .55816 .23957 .53565 Mtetra
.635 .556 .748 r
.23957 .53565 .24806 .55816 .26247 .55423 .25407 .53033 Mtetra
.628 .543 .739 r
.25407 .53033 .26247 .55423 .27699 .54994 .26863 .52532 Mtetra
.624 .537 .736 r
.26863 .52532 .27699 .54994 .29161 .54547 .28325 .52043 Mtetra
.623 .534 .733 r
.28325 .52043 .29161 .54547 .30631 .54091 .29794 .51558 Mtetra
.622 .532 .732 r
.29794 .51558 .30631 .54091 .3211 .53629 .31272 .51074 Mtetra
.621 .531 .731 r
.31272 .51074 .3211 .53629 .33597 .53162 .32758 .50589 Mtetra
.621 .53 .731 r
.32758 .50589 .33597 .53162 .35093 .5269 .34252 .50103 Mtetra
.621 .53 .73 r
.34252 .50103 .35093 .5269 .36597 .52215 .35754 .49616 Mtetra
.62 .529 .73 r
.35754 .49616 .36597 .52215 .3811 .51737 .37265 .49126 Mtetra
.37265 .49126 .3811 .51737 .39631 .51256 .38784 .48634 Mtetra
.62 .529 .729 r
.38784 .48634 .39631 .51256 .41162 .50771 .40312 .48139 Mtetra
.40312 .48139 .41162 .50771 .42701 .50284 .41849 .47642 Mtetra
.41849 .47642 .42701 .50284 .44248 .49793 .43394 .47142 Mtetra
.62 .528 .729 r
.43394 .47142 .44248 .49793 .45805 .493 .44949 .4664 Mtetra
.44949 .4664 .45805 .493 .47371 .48803 .46512 .46135 Mtetra
.46512 .46135 .47371 .48803 .48945 .48304 .48084 .45626 Mtetra
.48084 .45626 .48945 .48304 .50529 .47801 .49666 .45115 Mtetra
.49666 .45115 .50529 .47801 .52122 .47296 .51256 .44601 Mtetra
.51256 .44601 .52122 .47296 .53725 .46788 .52856 .44085 Mtetra
.52856 .44085 .53725 .46788 .55336 .46276 .54465 .43565 Mtetra
.54465 .43565 .55336 .46276 .56958 .45762 .56084 .43042 Mtetra
.56084 .43042 .56958 .45762 .58588 .45244 .57712 .42516 Mtetra
.57712 .42516 .58588 .45244 .60229 .44724 .5935 .41987 Mtetra
.5935 .41987 .60229 .44724 .61879 .442 .60998 .41455 Mtetra
.60998 .41455 .61879 .442 .63539 .43673 .62655 .4092 Mtetra
.62655 .4092 .63539 .43673 .65208 .43144 .64322 .40381 Mtetra
.64322 .40381 .65208 .43144 .66888 .4261 .65999 .3984 Mtetra
.65999 .3984 .66888 .4261 .68578 .42074 .67686 .39295 Mtetra
.67686 .39295 .68578 .42074 .70278 .41535 .69383 .38747 Mtetra
.69383 .38747 .70278 .41535 .71988 .40992 .71091 .38195 Mtetra
.71091 .38195 .71988 .40992 .73708 .40446 .72809 .37641 Mtetra
.62 .528 .728 r
.72809 .37641 .73708 .40446 .75439 .39896 .74537 .37083 Mtetra
.74537 .37083 .75439 .39896 .77181 .39344 .76276 .36521 Mtetra
.76276 .36521 .77181 .39344 .78933 .38788 .78025 .35956 Mtetra
.78025 .35956 .78933 .38788 .80696 .38228 .79785 .35388 Mtetra
.79785 .35388 .80696 .38228 .82469 .37665 .81556 .34816 Mtetra
.81556 .34816 .82469 .37665 .84254 .37099 .83337 .34241 Mtetra
.83337 .34241 .84254 .37099 .86049 .36529 .8513 .33662 Mtetra
.671 .973 .898 r
.21427 .54401 .22505 .54196 .23957 .53565 .22914 .53489 Mtetra
.826 .943 .901 r
.22914 .53489 .23957 .53565 .25407 .53033 .2443 .52259 Mtetra
.769 .788 .869 r
.2443 .52259 .25407 .53033 .26863 .52532 .25931 .51247 Mtetra
.713 .688 .825 r
.25931 .51247 .26863 .52532 .28325 .52043 .27422 .50414 Mtetra
.68 .634 .796 r
.27422 .50414 .28325 .52043 .29794 .51558 .2891 .49696 Mtetra
.661 .602 .778 r
.2891 .49696 .29794 .51558 .31272 .51074 .30399 .49048 Mtetra
.649 .583 .767 r
.30399 .49048 .31272 .51074 .32758 .50589 .31892 .48443 Mtetra
.642 .57 .759 r
.31892 .48443 .32758 .50589 .34252 .50103 .3339 .47867 Mtetra
.637 .561 .753 r
.3339 .47867 .34252 .50103 .35754 .49616 .34895 .47309 Mtetra
.633 .555 .748 r
.34895 .47309 .35754 .49616 .37265 .49126 .36407 .46764 Mtetra
.63 .55 .745 r
.36407 .46764 .37265 .49126 .38784 .48634 .37927 .46226 Mtetra
.629 .546 .743 r
.37927 .46226 .38784 .48634 .40312 .48139 .39455 .45693 Mtetra
.627 .544 .741 r
.39455 .45693 .40312 .48139 .41849 .47642 .40991 .45163 Mtetra
.626 .541 .739 r
.40991 .45163 .41849 .47642 .43394 .47142 .42536 .44635 Mtetra
.625 .54 .738 r
.42536 .44635 .43394 .47142 .44949 .4664 .44089 .44107 Mtetra
.624 .538 .737 r
.44089 .44107 .44949 .4664 .46512 .46135 .45651 .4358 Mtetra
.624 .537 .736 r
.45651 .4358 .46512 .46135 .48084 .45626 .47221 .43052 Mtetra
.623 .536 .735 r
.47221 .43052 .48084 .45626 .49666 .45115 .48801 .42522 Mtetra
.623 .535 .734 r
.48801 .42522 .49666 .45115 .51256 .44601 .5039 .41991 Mtetra
.622 .534 .734 r
.5039 .41991 .51256 .44601 .52856 .44085 .51987 .41459 Mtetra
.622 .534 .733 r
.51987 .41459 .52856 .44085 .54465 .43565 .53595 .40924 Mtetra
.622 .533 .733 r
.53595 .40924 .54465 .43565 .56084 .43042 .55211 .40387 Mtetra
.55211 .40387 .56084 .43042 .57712 .42516 .56837 .39848 Mtetra
.622 .532 .732 r
.56837 .39848 .57712 .42516 .5935 .41987 .58472 .39306 Mtetra
.621 .532 .732 r
.58472 .39306 .5935 .41987 .60998 .41455 .60118 .38761 Mtetra
.60118 .38761 .60998 .41455 .62655 .4092 .61772 .38214 Mtetra
.621 .531 .731 r
.61772 .38214 .62655 .4092 .64322 .40381 .63437 .37664 Mtetra
.63437 .37664 .64322 .40381 .65999 .3984 .65112 .37111 Mtetra
.65112 .37111 .65999 .3984 .67686 .39295 .66796 .36555 Mtetra
.66796 .36555 .67686 .39295 .69383 .38747 .68491 .35996 Mtetra
.621 .53 .731 r
.68491 .35996 .69383 .38747 .71091 .38195 .70196 .35434 Mtetra
.70196 .35434 .71091 .38195 .72809 .37641 .71911 .34869 Mtetra
.621 .53 .73 r
.71911 .34869 .72809 .37641 .74537 .37083 .73637 .343 Mtetra
.73637 .343 .74537 .37083 .76276 .36521 .75373 .33728 Mtetra
.62 .53 .73 r
.75373 .33728 .76276 .36521 .78025 .35956 .77119 .33153 Mtetra
.77119 .33153 .78025 .35956 .79785 .35388 .78877 .32575 Mtetra
.78877 .32575 .79785 .35388 .81556 .34816 .80645 .31993 Mtetra
.62 .529 .73 r
.80645 .31993 .81556 .34816 .83337 .34241 .82424 .31407 Mtetra
.82424 .31407 .83337 .34241 .8513 .33662 .84214 .30818 Mtetra
.343 .423 .8 r
.20535 .52483 .21427 .54401 .22914 .53489 .21879 .53142 Mtetra
.456 .821 .994 r
.21879 .53142 .22914 .53489 .2443 .52259 .23318 .52915 Mtetra
.565 .912 .702 r
.23318 .52915 .2443 .52259 .25931 .51247 .24844 .51754 Mtetra
.708 .981 .795 r
.24844 .51754 .25931 .51247 .27422 .50414 .26381 .5047 Mtetra
.796 .976 .907 r
.26381 .5047 .27422 .50414 .2891 .49696 .27912 .49299 Mtetra
.787 .884 .916 r
.27912 .49299 .2891 .49696 .30399 .49048 .29435 .48268 Mtetra
.752 .794 .887 r
.29435 .48268 .30399 .49048 .31892 .48443 .30954 .47355 Mtetra
.721 .728 .856 r
.30954 .47355 .31892 .48443 .3339 .47867 .32472 .46532 Mtetra
.698 .682 .831 r
.32472 .46532 .3339 .47867 .34895 .47309 .33991 .45775 Mtetra
.681 .65 .813 r
.33991 .45775 .34895 .47309 .36407 .46764 .35514 .45069 Mtetra
.668 .627 .798 r
.35514 .45069 .36407 .46764 .37927 .46226 .37042 .44399 Mtetra
.659 .609 .787 r
.37042 .44399 .37927 .46226 .39455 .45693 .38575 .43757 Mtetra
.652 .596 .779 r
.38575 .43757 .39455 .45693 .40991 .45163 .40116 .43135 Mtetra
.647 .586 .772 r
.40116 .43135 .40991 .45163 .42536 .44635 .41663 .42529 Mtetra
.643 .578 .766 r
.41663 .42529 .42536 .44635 .44089 .44107 .43218 .41935 Mtetra
.64 .571 .762 r
.43218 .41935 .44089 .44107 .45651 .4358 .44781 .41349 Mtetra
.637 .566 .758 r
.44781 .41349 .45651 .4358 .47221 .43052 .46352 .4077 Mtetra
.635 .562 .755 r
.46352 .4077 .47221 .43052 .48801 .42522 .47932 .40195 Mtetra
.633 .558 .752 r
.47932 .40195 .48801 .42522 .5039 .41991 .4952 .39624 Mtetra
.632 .555 .75 r
.4952 .39624 .5039 .41991 .51987 .41459 .51117 .39055 Mtetra
.63 .552 .748 r
.51117 .39055 .51987 .41459 .53595 .40924 .52723 .38488 Mtetra
.629 .55 .746 r
.52723 .38488 .53595 .40924 .55211 .40387 .54339 .37921 Mtetra
.628 .548 .745 r
.54339 .37921 .55211 .40387 .56837 .39848 .55963 .37354 Mtetra
.627 .546 .743 r
.55963 .37354 .56837 .39848 .58472 .39306 .57597 .36787 Mtetra
.627 .545 .742 r
.57597 .36787 .58472 .39306 .60118 .38761 .5924 .36218 Mtetra
.626 .543 .741 r
.5924 .36218 .60118 .38761 .61772 .38214 .60893 .35649 Mtetra
.626 .542 .74 r
.60893 .35649 .61772 .38214 .63437 .37664 .62556 .35078 Mtetra
.625 .541 .74 r
.62556 .35078 .63437 .37664 .65112 .37111 .64229 .34506 Mtetra
.625 .54 .739 r
.64229 .34506 .65112 .37111 .66796 .36555 .65911 .33931 Mtetra
.624 .539 .738 r
.65911 .33931 .66796 .36555 .68491 .35996 .67604 .33354 Mtetra
.624 .539 .737 r
.67604 .33354 .68491 .35996 .70196 .35434 .69306 .32775 Mtetra
.624 .538 .737 r
.69306 .32775 .70196 .35434 .71911 .34869 .71019 .32193 Mtetra
.623 .537 .736 r
.71019 .32193 .71911 .34869 .73637 .343 .72742 .31609 Mtetra
.72742 .31609 .73637 .343 .75373 .33728 .74476 .31022 Mtetra
.623 .536 .736 r
.74476 .31022 .75373 .33728 .77119 .33153 .7622 .30432 Mtetra
.623 .536 .735 r
.7622 .30432 .77119 .33153 .78877 .32575 .77975 .29839 Mtetra
.623 .535 .735 r
.77975 .29839 .78877 .32575 .80645 .31993 .7974 .29243 Mtetra
.622 .535 .734 r
.7974 .29243 .80645 .31993 .82424 .31407 .81516 .28644 Mtetra
.622 .534 .734 r
.81516 .28644 .82424 .31407 .84214 .30818 .83304 .28042 Mtetra
.893 .951 .836 r
.19433 .52648 .20535 .52483 .21879 .53142 .21011 .50887 Mtetra
.314 .369 .76 r
.21011 .50887 .21879 .53142 .23318 .52915 .22349 .5175 Mtetra
.385 .58 .918 r
.22349 .5175 .23318 .52915 .24844 .51754 .23758 .52012 Mtetra
.556 .934 .856 r
.23758 .52012 .24844 .51754 .26381 .5047 .25268 .51214 Mtetra
.541 .89 .656 r
.25268 .51214 .26381 .5047 .27912 .49299 .26817 .4998 Mtetra
.617 .933 .703 r
.26817 .4998 .27912 .49299 .29435 .48268 .28374 .4867 Mtetra
.719 .987 .824 r
.28374 .4867 .29435 .48268 .30954 .47355 .29927 .47422 Mtetra
.778 .981 .907 r
.29927 .47422 .30954 .47355 .32472 .46532 .31476 .46274 Mtetra
.786 .925 .928 r
.31476 .46274 .32472 .46532 .33991 .45775 .33021 .45226 Mtetra
.768 .856 .916 r
.33021 .45226 .33991 .45775 .35514 .45069 .34566 .44264 Mtetra
.745 .795 .893 r
.34566 .44264 .35514 .45069 .37042 .44399 .36111 .43375 Mtetra
.724 .747 .87 r
.36111 .43375 .37042 .44399 .38575 .43757 .37658 .42543 Mtetra
.707 .71 .85 r
.37658 .42543 .38575 .43757 .40116 .43135 .39209 .41759 Mtetra
.692 .68 .834 r
.39209 .41759 .40116 .43135 .41663 .42529 .40766 .41013 Mtetra
.681 .658 .82 r
.40766 .41013 .41663 .42529 .43218 .41935 .42328 .40296 Mtetra
.672 .639 .809 r
.42328 .40296 .43218 .41935 .44781 .41349 .43896 .39604 Mtetra
.665 .625 .799 r
.43896 .39604 .44781 .41349 .46352 .4077 .45471 .38931 Mtetra
.659 .613 .791 r
.45471 .38931 .46352 .4077 .47932 .40195 .47054 .38274 Mtetra
.654 .603 .785 r
.47054 .38274 .47932 .40195 .4952 .39624 .48644 .3763 Mtetra
.65 .595 .779 r
.48644 .3763 .4952 .39624 .51117 .39055 .50243 .36996 Mtetra
.647 .588 .774 r
.50243 .36996 .51117 .39055 .52723 .38488 .5185 .36369 Mtetra
.644 .582 .77 r
.5185 .36369 .52723 .38488 .54339 .37921 .53466 .35749 Mtetra
.641 .577 .767 r
.53466 .35749 .54339 .37921 .55963 .37354 .5509 .35133 Mtetra
.639 .572 .763 r
.5509 .35133 .55963 .37354 .57597 .36787 .56724 .34522 Mtetra
.637 .568 .761 r
.56724 .34522 .57597 .36787 .5924 .36218 .58367 .33913 Mtetra
.636 .565 .758 r
.58367 .33913 .5924 .36218 .60893 .35649 .60019 .33306 Mtetra
.634 .562 .756 r
.60019 .33306 .60893 .35649 .62556 .35078 .6168 .32701 Mtetra
.633 .56 .754 r
.6168 .32701 .62556 .35078 .64229 .34506 .63352 .32096 Mtetra
.632 .557 .752 r
.63352 .32096 .64229 .34506 .65911 .33931 .65032 .31491 Mtetra
.631 .555 .751 r
.65032 .31491 .65911 .33931 .67604 .33354 .66723 .30885 Mtetra
.63 .553 .749 r
.66723 .30885 .67604 .33354 .69306 .32775 .68424 .3028 Mtetra
.63 .552 .748 r
.68424 .3028 .69306 .32775 .71019 .32193 .70135 .29673 Mtetra
.629 .55 .747 r
.70135 .29673 .71019 .32193 .72742 .31609 .71856 .29064 Mtetra
.628 .549 .746 r
.71856 .29064 .72742 .31609 .74476 .31022 .73588 .28455 Mtetra
.628 .547 .745 r
.73588 .28455 .74476 .31022 .7622 .30432 .75329 .27843 Mtetra
.627 .546 .744 r
.75329 .27843 .7622 .30432 .77975 .29839 .77082 .27229 Mtetra
.627 .545 .743 r
.77082 .27229 .77975 .29839 .7974 .29243 .78845 .26613 Mtetra
.626 .544 .742 r
.78845 .26613 .7974 .29243 .81516 .28644 .80619 .25995 Mtetra
.626 .543 .742 r
.80619 .25995 .81516 .28644 .83304 .28042 .82404 .25374 Mtetra
.466 .499 .809 r
.18524 .50747 .19433 .52648 .21011 .50887 .19906 .51023 Mtetra
.882 .956 .848 r
.19906 .51023 .21011 .50887 .22349 .5175 .21485 .49356 Mtetra
.3 .349 .746 r
.21485 .49356 .22349 .5175 .23758 .52012 .22828 .50304 Mtetra
.34 .456 .833 r
.22828 .50304 .23758 .52012 .25268 .51214 .24225 .50872 Mtetra
.562 .867 .996 r
.24225 .50872 .25268 .51214 .26817 .4998 .25717 .50458 Mtetra
.561 .926 .767 r
.25717 .50458 .26817 .4998 .28374 .4867 .27265 .49438 Mtetra
.535 .882 .64 r
.27265 .49438 .28374 .4867 .29927 .47422 .28835 .48165 Mtetra
.576 .905 .661 r
.28835 .48165 .29927 .47422 .31476 .46274 .30411 .46836 Mtetra
.651 .956 .749 r
.30411 .46836 .31476 .46274 .33021 .45226 .31985 .45543 Mtetra
.724 .989 .844 r
.31985 .45543 .33021 .45226 .34566 .44264 .33556 .44321 Mtetra
.768 .983 .907 r
.33556 .44321 .34566 .44264 .36111 .43375 .35126 .43179 Mtetra
.78 .944 .931 r
.35126 .43179 .36111 .43375 .37658 .42543 .36694 .42113 Mtetra
.773 .893 .929 r
.36694 .42113 .37658 .42543 .39209 .41759 .38263 .41116 Mtetra
.758 .841 .915 r
.38263 .41116 .39209 .41759 .40766 .41013 .39835 .40178 Mtetra
.741 .796 .896 r
.39835 .40178 .40766 .41013 .42328 .40296 .41409 .3929 Mtetra
.726 .758 .879 r
.41409 .3929 .42328 .40296 .43896 .39604 .42988 .38445 Mtetra
.712 .727 .862 r
.42988 .38445 .43896 .39604 .45471 .38931 .44572 .37636 Mtetra
.7 .701 .848 r
.44572 .37636 .45471 .38931 .47054 .38274 .46161 .36857 Mtetra
.69 .68 .835 r
.46161 .36857 .47054 .38274 .48644 .3763 .47758 .36103 Mtetra
.682 .662 .824 r
.47758 .36103 .48644 .3763 .50243 .36996 .49361 .3537 Mtetra
.674 .647 .815 r
.49361 .3537 .50243 .36996 .5185 .36369 .50972 .34655 Mtetra
.668 .635 .807 r
.50972 .34655 .5185 .36369 .53466 .35749 .5259 .33954 Mtetra
.663 .624 .8 r
.5259 .33954 .53466 .35749 .5509 .35133 .54217 .33265 Mtetra
.659 .615 .794 r
.54217 .33265 .5509 .35133 .56724 .34522 .55852 .32587 Mtetra
.655 .607 .788 r
.55852 .32587 .56724 .34522 .58367 .33913 .57495 .31917 Mtetra
.652 .6 .784 r
.57495 .31917 .58367 .33913 .60019 .33306 .59148 .31254 Mtetra
.649 .594 .779 r
.59148 .31254 .60019 .33306 .6168 .32701 .6081 .30596 Mtetra
.646 .589 .776 r
.6081 .30596 .6168 .32701 .63352 .32096 .62481 .29943 Mtetra
.644 .584 .772 r
.62481 .29943 .63352 .32096 .65032 .31491 .64161 .29293 Mtetra
.642 .58 .769 r
.64161 .29293 .65032 .31491 .66723 .30885 .65851 .28646 Mtetra
.64 .576 .767 r
.65851 .28646 .66723 .30885 .68424 .3028 .67551 .28001 Mtetra
.639 .573 .764 r
.67551 .28001 .68424 .3028 .70135 .29673 .69261 .27358 Mtetra
.638 .57 .762 r
.69261 .27358 .70135 .29673 .71856 .29064 .7098 .26715 Mtetra
.636 .567 .76 r
.7098 .26715 .71856 .29064 .73588 .28455 .7271 .26073 Mtetra
.635 .565 .758 r
.7271 .26073 .73588 .28455 .75329 .27843 .74451 .2543 Mtetra
.634 .563 .756 r
.74451 .2543 .75329 .27843 .77082 .27229 .76201 .24787 Mtetra
.633 .56 .755 r
.76201 .24787 .77082 .27229 .78845 .26613 .77962 .24143 Mtetra
.632 .559 .754 r
.77962 .24143 .78845 .26613 .80619 .25995 .79734 .23499 Mtetra
.632 .557 .752 r
.79734 .23499 .80619 .25995 .82404 .25374 .81517 .22852 Mtetra
.426 .869 .885 r
.17399 .50845 .18524 .50747 .19906 .51023 .18865 .50356 Mtetra
.824 .811 .838 r
.18865 .50356 .19906 .51023 .21485 .49356 .2043 .48917 Mtetra
.794 .871 .904 r
.2043 .48917 .21485 .49356 .22828 .50304 .21963 .47833 Mtetra
.293 .339 .739 r
.21963 .47833 .22828 .50304 .24225 .50872 .23317 .48823 Mtetra
.314 .398 .789 r
.23317 .48823 .24225 .50872 .25717 .50458 .2471 .49584 Mtetra
.499 .71 .965 r
.2471 .49584 .25717 .50458 .27265 .49438 .26191 .49497 Mtetra
.607 .947 .927 r
.26191 .49497 .27265 .49438 .28835 .48165 .27734 .48743 Mtetra
.558 .915 .723 r
.27734 .48743 .28835 .48165 .30411 .46836 .2931 .4761 Mtetra
.533 .879 .633 r
.2931 .4761 .30411 .46836 .31985 .45543 .309 .46309 Mtetra
.555 .89 .64 r
.309 .46309 .31985 .45543 .33556 .44321 .32494 .44962 Mtetra
.609 .929 .701 r
.32494 .44962 .33556 .44321 .35126 .43179 .34088 .43637 Mtetra
.672 .969 .782 r
.34088 .43637 .35126 .43179 .36694 .42113 .35681 .42363 Mtetra
.727 .99 .857 r
.35681 .42363 .36694 .42113 .38263 .41116 .37273 .41153 Mtetra
.761 .984 .907 r
.37273 .41153 .38263 .41116 .39835 .40178 .38864 .40008 Mtetra
.775 .955 .93 r
.38864 .40008 .39835 .40178 .41409 .3929 .40456 .38925 Mtetra
.774 .915 .934 r
.40456 .38925 .41409 .3929 .42988 .38445 .42051 .37898 Mtetra
.765 .873 .926 r
.42051 .37898 .42988 .38445 .44572 .37636 .43648 .36921 Mtetra
.752 .832 .913 r
.43648 .36921 .44572 .37636 .46161 .36857 .45249 .35989 Mtetra
.739 .797 .898 r
.45249 .35989 .46161 .36857 .47758 .36103 .46855 .35094 Mtetra
.726 .765 .884 r
.46855 .35094 .47758 .36103 .49361 .3537 .48466 .34233 Mtetra
.715 .739 .87 r
.48466 .34233 .49361 .3537 .50972 .34655 .50084 .334 Mtetra
.705 .716 .857 r
.50084 .334 .50972 .34655 .5259 .33954 .51708 .32592 Mtetra
.696 .696 .846 r
.51708 .32592 .5259 .33954 .54217 .33265 .53339 .31805 Mtetra
.688 .679 .836 r
.53339 .31805 .54217 .33265 .55852 .32587 .54978 .31036 Mtetra
.682 .665 .827 r
.54978 .31036 .55852 .32587 .57495 .31917 .56625 .30283 Mtetra
.676 .652 .819 r
.56625 .30283 .57495 .31917 .59148 .31254 .5828 .29543 Mtetra
.671 .641 .812 r
.5828 .29543 .59148 .31254 .6081 .30596 .59943 .28815 Mtetra
.666 .632 .806 r
.59943 .28815 .6081 .30596 .62481 .29943 .61616 .28096 Mtetra
.662 .623 .8 r
.61616 .28096 .62481 .29943 .64161 .29293 .63297 .27385 Mtetra
.659 .616 .795 r
.63297 .27385 .64161 .29293 .65851 .28646 .64987 .26682 Mtetra
.656 .61 .791 r
.64987 .26682 .65851 .28646 .67551 .28001 .66687 .25984 Mtetra
.653 .604 .787 r
.66687 .25984 .67551 .28001 .69261 .27358 .68397 .25291 Mtetra
.65 .598 .783 r
.68397 .25291 .69261 .27358 .7098 .26715 .70116 .24601 Mtetra
.648 .594 .78 r
.70116 .24601 .7098 .26715 .7271 .26073 .71845 .23915 Mtetra
.646 .589 .777 r
.71845 .23915 .7271 .26073 .74451 .2543 .73584 .23231 Mtetra
.644 .586 .774 r
.73584 .23231 .74451 .2543 .76201 .24787 .75334 .22549 Mtetra
.643 .582 .771 r
.75334 .22549 .76201 .24787 .77962 .24143 .77094 .21869 Mtetra
.641 .579 .769 r
.77094 .21869 .77962 .24143 .79734 .23499 .78864 .21189 Mtetra
.64 .576 .767 r
.78864 .21189 .79734 .23499 .81517 .22852 .80645 .20509 Mtetra
.683 .617 .775 r
.16468 .48988 .17399 .50845 .18865 .50356 .17969 .48161 Mtetra
.088 .235 .721 r
.17969 .48161 .18865 .50356 .2043 .48917 .19263 .49461 Mtetra
.941 .951 .754 r
.19263 .49461 .2043 .48917 .21963 .47833 .20949 .46913 Mtetra
.684 .757 .907 r
.20949 .46913 .21963 .47833 .23317 .48823 .22448 .46302 Mtetra
.289 .334 .736 r
.22448 .46302 .23317 .48823 .2471 .49584 .23813 .47314 Mtetra
.298 .365 .764 r
.23813 .47314 .2471 .49584 .26191 .49497 .25211 .482 Mtetra
.44 .59 .905 r
.25211 .482 .26191 .49497 .27734 .48743 .26686 .48371 Mtetra
.597 .876 .993 r
.26686 .48371 .27734 .48743 .2931 .4761 .28224 .4788 Mtetra
.607 .954 .855 r
.28224 .4788 .2931 .4761 .309 .46309 .29802 .46937 Mtetra
.555 .907 .699 r
.29802 .46937 .309 .46309 .32494 .44962 .31402 .45734 Mtetra
.532 .878 .63 r
.31402 .45734 .32494 .44962 .34088 .43637 .33012 .44409 Mtetra
.545 .883 .629 r
.33012 .44409 .34088 .43637 .35681 .42363 .34626 .43046 Mtetra
.582 .91 .672 r
.34626 .43046 .35681 .42363 .37273 .41153 .3624 .41695 Mtetra
.633 .947 .736 r
.3624 .41695 .37273 .41153 .38864 .40008 .37853 .40382 Mtetra
.685 .976 .806 r
.37853 .40382 .38864 .40008 .40456 .38925 .39467 .3912 Mtetra
.728 .99 .865 r
.39467 .3912 .40456 .38925 .42051 .37898 .4108 .37913 Mtetra
.757 .984 .907 r
.4108 .37913 .42051 .37898 .43648 .36921 .42695 .3676 Mtetra
.77 .962 .929 r
.42695 .3676 .43648 .36921 .45249 .35989 .44312 .35659 Mtetra
.773 .93 .936 r
.44312 .35659 .45249 .35989 .46855 .35094 .45931 .34606 Mtetra
.768 .895 .933 r
.45931 .34606 .46855 .35094 .48466 .34233 .47554 .33596 Mtetra
.759 .86 .924 r
.47554 .33596 .48466 .34233 .50084 .334 .49182 .32624 Mtetra
.748 .827 .912 r
.49182 .32624 .50084 .334 .51708 .32592 .50815 .31687 Mtetra
.737 .797 .9 r
.50815 .31687 .51708 .32592 .53339 .31805 .52454 .3078 Mtetra
.727 .77 .887 r
.52454 .3078 .53339 .31805 .54978 .31036 .541 .29901 Mtetra
.717 .747 .875 r
.541 .29901 .54978 .31036 .56625 .30283 .55752 .29044 Mtetra
.709 .726 .864 r
.55752 .29044 .56625 .30283 .5828 .29543 .57412 .28209 Mtetra
.701 .709 .854 r
.57412 .28209 .5828 .29543 .59943 .28815 .59079 .27392 Mtetra
.694 .693 .845 r
.59079 .27392 .59943 .28815 .61616 .28096 .60755 .2659 Mtetra
.687 .679 .836 r
.60755 .2659 .61616 .28096 .63297 .27385 .62439 .25802 Mtetra
.682 .667 .829 r
.62439 .25802 .63297 .27385 .64987 .26682 .64131 .25026 Mtetra
.677 .656 .822 r
.64131 .25026 .64987 .26682 .66687 .25984 .65832 .24261 Mtetra
.672 .646 .816 r
.65832 .24261 .66687 .25984 .68397 .25291 .67543 .23504 Mtetra
.668 .638 .81 r
.67543 .23504 .68397 .25291 .70116 .24601 .69263 .22756 Mtetra
.665 .63 .805 r
.69263 .22756 .70116 .24601 .71845 .23915 .70992 .22014 Mtetra
.662 .623 .8 r
.70992 .22014 .71845 .23915 .73584 .23231 .72732 .21277 Mtetra
.659 .617 .796 r
.72732 .21277 .73584 .23231 .75334 .22549 .74481 .20546 Mtetra
.656 .611 .792 r
.74481 .20546 .75334 .22549 .77094 .21869 .7624 .19818 Mtetra
.654 .606 .789 r
.7624 .19818 .77094 .21869 .78864 .21189 .7801 .19093 Mtetra
.652 .602 .785 r
.7801 .19093 .78864 .21189 .80645 .20509 .7979 .18371 Mtetra
.509 .902 .937 r
.15323 .48991 .16468 .48988 .17969 .48161 .16801 .48463 Mtetra
.36 .829 .779 r
.16801 .48463 .17969 .48161 .19263 .49461 .18292 .4789 Mtetra
.609 .62 .837 r
.18292 .4789 .19263 .49461 .20949 .46913 .19767 .47556 Mtetra
.936 .964 .747 r
.19767 .47556 .20949 .46913 .22448 .46302 .2146 .4503 Mtetra
.594 .662 .885 r
.2146 .4503 .22448 .46302 .23813 .47314 .22939 .44754 Mtetra
.286 .331 .734 r
.22939 .44754 .23813 .47314 .25211 .482 .24318 .45779 Mtetra
.288 .346 .749 r
.24318 .45779 .25211 .482 .26686 .48371 .25724 .46746 Mtetra
.397 .511 .857 r
.25724 .46746 .26686 .48371 .28224 .4788 .27197 .4712 Mtetra
.549 .766 .978 r
.27197 .4712 .28224 .4788 .29802 .46937 .28733 .46866 Mtetra
.63 .943 .954 r
.28733 .46866 .29802 .46937 .31402 .45734 .30314 .46126 Mtetra
.599 .947 .804 r
.30314 .46126 .31402 .45734 .33012 .44409 .31921 .45064 Mtetra
.552 .902 .683 r
.31921 .45064 .33012 .44409 .34626 .43046 .33544 .43812 Mtetra
.532 .877 .628 r
.33544 .43812 .34626 .43046 .3624 .41695 .35174 .42465 Mtetra
.539 .878 .623 r
.35174 .42465 .3624 .41695 .37853 .40382 .36807 .41086 Mtetra
.566 .898 .653 r
.36807 .41086 .37853 .40382 .39467 .3912 .38442 .39712 Mtetra
.606 .928 .703 r
.38442 .39712 .39467 .3912 .4108 .37913 .40076 .38367 Mtetra
.651 .959 .763 r
.40076 .38367 .4108 .37913 .42695 .3676 .41711 .37063 Mtetra
.694 .981 .822 r
.41711 .37063 .42695 .3676 .44312 .35659 .43346 .35805 Mtetra
.729 .99 .871 r
.43346 .35805 .44312 .35659 .45931 .34606 .44983 .34594 Mtetra
.754 .984 .907 r
.44983 .34594 .45931 .34606 .47554 .33596 .46621 .33431 Mtetra
.767 .966 .928 r
.46621 .33431 .47554 .33596 .49182 .32624 .48263 .32312 Mtetra
.771 .94 .936 r
.48263 .32312 .49182 .32624 .50815 .31687 .49909 .31234 Mtetra
.769 .911 .936 r
.49909 .31234 .50815 .31687 .52454 .3078 .51558 .30193 Mtetra
.763 .88 .931 r
.51558 .30193 .52454 .3078 .541 .29901 .53213 .29188 Mtetra
.754 .85 .922 r
.53213 .29188 .541 .29901 .55752 .29044 .54874 .28213 Mtetra
.745 .822 .912 r
.54874 .28213 .55752 .29044 .57412 .28209 .56541 .27266 Mtetra
.736 .797 .901 r
.56541 .27266 .57412 .28209 .59079 .27392 .58215 .26344 Mtetra
.727 .774 .89 r
.58215 .26344 .59079 .27392 .60755 .2659 .59896 .25444 Mtetra
.719 .753 .879 r
.59896 .25444 .60755 .2659 .62439 .25802 .61584 .24564 Mtetra
.711 .735 .869 r
.61584 .24564 .62439 .25802 .64131 .25026 .6328 .23702 Mtetra
.704 .718 .86 r
.6328 .23702 .64131 .25026 .65832 .24261 .64985 .22855 Mtetra
.698 .704 .852 r
.64985 .22855 .65832 .24261 .67543 .23504 .66698 .22023 Mtetra
.692 .691 .844 r
.66698 .22023 .67543 .23504 .69263 .22756 .6842 .21202 Mtetra
.687 .679 .837 r
.6842 .21202 .69263 .22756 .70992 .22014 .70151 .20392 Mtetra
.682 .668 .83 r
.70151 .20392 .70992 .22014 .72732 .21277 .71892 .19591 Mtetra
.678 .659 .824 r
.71892 .19591 .72732 .21277 .74481 .20546 .73642 .18799 Mtetra
.674 .65 .819 r
.73642 .18799 .74481 .20546 .7624 .19818 .75401 .18014 Mtetra
.67 .642 .814 r
.75401 .18014 .7624 .19818 .7801 .19093 .77171 .17235 Mtetra
.667 .635 .809 r
.77171 .17235 .7801 .19093 .7979 .18371 .78951 .16461 Mtetra
.449 .512 .831 r
.14367 .47203 .15323 .48991 .16801 .48463 .15758 .4746 Mtetra
.831 .755 .779 r
.15758 .4746 .16801 .48463 .18292 .4789 .17393 .4558 Mtetra
0 .037 .601 r
.17393 .4558 .18292 .4789 .19767 .47556 .1864 .47442 Mtetra
.904 .894 .809 r
.1864 .47442 .19767 .47556 .2146 .4503 .20303 .45375 Mtetra
.918 .96 .795 r
.20303 .45375 .2146 .4503 .22939 .44754 .21968 .43224 Mtetra
.529 .593 .862 r
.21968 .43224 .22939 .44754 .24318 .45779 .23438 .43187 Mtetra
.284 .329 .732 r
.23438 .43187 .24318 .45779 .25724 .46746 .24831 .44218 Mtetra
.281 .334 .739 r
.24831 .44218 .25724 .46746 .27197 .4712 .26247 .4524 Mtetra
.366 .459 .823 r
.26247 .4524 .27197 .4712 .28733 .46866 .27724 .4577 Mtetra
.499 .668 .939 r
.27724 .4577 .28733 .46866 .30314 .46126 .29261 .45722 Mtetra
.613 .879 .99 r
.29261 .45722 .30314 .46126 .31921 .45064 .30844 .45181 Mtetra
.633 .961 .903 r
.30844 .45181 .31921 .45064 .33544 .43812 .32458 .44278 Mtetra
.59 .938 .768 r
.32458 .44278 .33544 .43812 .35174 .42465 .34092 .43133 Mtetra
.55 .898 .673 r
.34092 .43133 .35174 .42465 .36807 .41086 .35737 .41843 Mtetra
.532 .877 .627 r
.35737 .41843 .36807 .41086 .38442 .39712 .37387 .40475 Mtetra
.535 .876 .62 r
.37387 .40475 .38442 .39712 .40076 .38367 .39041 .39079 Mtetra
.555 .89 .641 r
.39041 .39079 .40076 .38367 .41711 .37063 .40696 .37685 Mtetra
.586 .915 .68 r
.40696 .37685 .41711 .37063 .43346 .35805 .42351 .36312 Mtetra
.624 .942 .73 r
.42351 .36312 .43346 .35805 .44983 .34594 .44007 .34972 Mtetra
.664 .967 .784 r
.44007 .34972 .44983 .34594 .46621 .33431 .45664 .33671 Mtetra
.701 .983 .834 r
.45664 .33671 .46621 .33431 .48263 .32312 .47322 .32412 Mtetra
.73 .989 .876 r
.47322 .32412 .48263 .32312 .49909 .31234 .48983 .31194 Mtetra
.751 .984 .907 r
.48983 .31194 .49909 .31234 .51558 .30193 .50647 .30018 Mtetra
.764 .969 .926 r
.50647 .30018 .51558 .30193 .53213 .29188 .52315 .2888 Mtetra
.769 .948 .936 r
.52315 .2888 .53213 .29188 .54874 .28213 .53987 .27778 Mtetra
.769 .923 .938 r
.53987 .27778 .54874 .28213 .56541 .27266 .55664 .2671 Mtetra
.765 .896 .935 r
.55664 .2671 .56541 .27266 .58215 .26344 .57346 .25672 Mtetra
.758 .869 .929 r
.57346 .25672 .58215 .26344 .59896 .25444 .59035 .24663 Mtetra
.751 .843 .921 r
.59035 .24663 .59896 .25444 .61584 .24564 .6073 .23679 Mtetra
.743 .819 .911 r
.6073 .23679 .61584 .24564 .6328 .23702 .62433 .22718 Mtetra
.735 .797 .901 r
.62433 .22718 .6328 .23702 .64985 .22855 .64143 .21779 Mtetra
.728 .777 .892 r
.64143 .21779 .64985 .22855 .66698 .22023 .6586 .20858 Mtetra
.72 .758 .883 r
.6586 .20858 .66698 .22023 .6842 .21202 .67586 .19954 Mtetra
.713 .742 .874 r
.67586 .19954 .6842 .21202 .70151 .20392 .6932 .19065 Mtetra
.707 .726 .865 r
.6932 .19065 .70151 .20392 .71892 .19591 .71064 .18189 Mtetra
.701 .713 .857 r
.71064 .18189 .71892 .19591 .73642 .18799 .72816 .17326 Mtetra
.696 .7 .85 r
.72816 .17326 .73642 .18799 .75401 .18014 .74577 .16474 Mtetra
.691 .689 .843 r
.74577 .16474 .75401 .18014 .77171 .17235 .76348 .15631 Mtetra
.686 .679 .837 r
.76348 .15631 .77171 .17235 .78951 .16461 .78129 .14796 Mtetra
.877 .908 .847 r
.13205 .47086 .14367 .47203 .15758 .4746 .14826 .45386 Mtetra
.515 .516 .795 r
.14826 .45386 .15758 .4746 .17393 .4558 .1625 .45455 Mtetra
.208 .726 .871 r
.1625 .45455 .17393 .4558 .1864 .47442 .17707 .45335 Mtetra
.346 .416 .791 r
.17707 .45335 .1864 .47442 .20303 .45375 .191 .45966 Mtetra
.949 .946 .739 r
.191 .45966 .20303 .45375 .21968 .43224 .20843 .43195 Mtetra
.883 .935 .847 r
.20843 .43195 .21968 .43224 .23438 .43187 .22477 .41461 Mtetra
.483 .543 .842 r
.22477 .41461 .23438 .43187 .24831 .44218 .23945 .41597 Mtetra
.283 .327 .732 r
.23945 .41597 .24831 .44218 .26247 .4524 .25352 .42631 Mtetra
.276 .325 .733 r
.25352 .42631 .26247 .4524 .27724 .4577 .26781 .4369 Mtetra
.345 .423 .799 r
.26781 .4369 .27724 .4577 .29261 .45722 .28264 .44341 Mtetra
.456 .593 .9 r
.28264 .44341 .29261 .45722 .30844 .45181 .29804 .44469 Mtetra
.576 .795 .982 r
.29804 .44469 .30844 .45181 .32458 .44278 .31391 .44113 Mtetra
.64 .936 .966 r
.31391 .44113 .32458 .44278 .34092 .43133 .33012 .43373 Mtetra
.626 .961 .858 r
.33012 .43373 .34092 .43133 .35737 .41843 .34656 .42355 Mtetra
.583 .93 .743 r
.34656 .42355 .35737 .41843 .37387 .40475 .36315 .41148 Mtetra
.549 .896 .665 r
.36315 .41148 .37387 .40475 .39041 .39079 .37982 .39825 Mtetra
.532 .877 .626 r
.37982 .39825 .39041 .39079 .40696 .37685 .39654 .38437 Mtetra
.533 .874 .618 r
.39654 .38437 .40696 .37685 .42351 .36312 .41328 .37024 Mtetra
.547 .885 .633 r
.41328 .37024 .42351 .36312 .44007 .34972 .43004 .3561 Mtetra
.572 .904 .664 r
.43004 .3561 .44007 .34972 .45664 .33671 .4468 .34211 Mtetra
.604 .928 .705 r
.4468 .34211 .45664 .33671 .47322 .32412 .46358 .3284 Mtetra
.639 .952 .753 r
.46358 .3284 .47322 .32412 .48983 .31194 .48037 .31502 Mtetra
.674 .972 .8 r
.48037 .31502 .48983 .31194 .50647 .30018 .49717 .302 Mtetra
.705 .985 .844 r
.49717 .302 .50647 .30018 .52315 .2888 .514 .28936 Mtetra
.731 .989 .879 r
.514 .28936 .52315 .2888 .53987 .27778 .53086 .27709 Mtetra
.749 .984 .907 r
.53086 .27709 .53987 .27778 .55664 .2671 .54776 .26517 Mtetra
.761 .971 .925 r
.54776 .26517 .55664 .2671 .57346 .25672 .5647 .2536 Mtetra
.767 .953 .935 r
.5647 .2536 .57346 .25672 .59035 .24663 .5817 .24235 Mtetra
.768 .932 .939 r
.5817 .24235 .59035 .24663 .6073 .23679 .59874 .2314 Mtetra
.766 .908 .938 r
.59874 .2314 .6073 .23679 .62433 .22718 .61585 .22073 Mtetra
.761 .884 .933 r
.61585 .22073 .62433 .22718 .64143 .21779 .63302 .21031 Mtetra
.755 .861 .927 r
.63302 .21031 .64143 .21779 .6586 .20858 .65027 .20013 Mtetra
.749 .838 .919 r
.65027 .20013 .6586 .20858 .67586 .19954 .66758 .19016 Mtetra
.742 .817 .911 r
.66758 .19016 .67586 .19954 .6932 .19065 .68498 .18039 Mtetra
.735 .797 .902 r
.68498 .18039 .6932 .19065 .71064 .18189 .70245 .17079 Mtetra
.728 .779 .893 r
.70245 .17079 .71064 .18189 .72816 .17326 .72001 .16136 Mtetra
.721 .762 .885 r
.72001 .16136 .72816 .17326 .74577 .16474 .73766 .15207 Mtetra
.715 .747 .877 r
.73766 .15207 .74577 .16474 .76348 .15631 .7554 .14291 Mtetra
.709 .733 .869 r
.7554 .14291 .76348 .15631 .78129 .14796 .77323 .13387 Mtetra
.371 .487 .847 r
.12218 .4539 .13205 .47086 .14826 .45386 .13595 .45798 Mtetra
.215 0 0 r
.13595 .45798 .14826 .45386 .1625 .45455 .15035 .45795 Mtetra
.947 .909 .748 r
.15035 .45795 .1625 .45455 .17707 .45335 .16799 .4296 Mtetra
0 0 .517 r
.16799 .4296 .17707 .45335 .191 .45966 .18025 .45122 Mtetra
.785 .795 .86 r
.18025 .45122 .191 .45966 .20843 .43195 .19622 .43928 Mtetra
.947 .956 .723 r
.19622 .43928 .20843 .43195 .22477 .41461 .2138 .41081 Mtetra
.832 .89 .883 r
.2138 .41081 .22477 .41461 .23945 .41597 .2299 .39719 Mtetra
.449 .506 .826 r
.2299 .39719 .23945 .41597 .25352 .42631 .2446 .39983 Mtetra
.282 .326 .731 r
.2446 .39983 .25352 .42631 .26781 .4369 .25882 .41018 Mtetra
.272 .32 .729 r
.25882 .41018 .26781 .4369 .28264 .44341 .27325 .42102 Mtetra
.328 .398 .782 r
.27325 .42102 .28264 .44341 .29804 .44469 .28817 .42848 Mtetra
.422 .536 .867 r
.28817 .42848 .29804 .44469 .31391 .44113 .30363 .43123 Mtetra
.535 .716 .956 r
.30363 .43123 .31391 .44113 .33012 .43373 .31955 .42936 Mtetra
.623 .88 .989 r
.31955 .42936 .33012 .43373 .34656 .42355 .33584 .42356 Mtetra
.646 .959 .929 r
.33584 .42356 .34656 .42355 .36315 .41148 .35238 .41472 Mtetra
.618 .956 .822 r
.35238 .41472 .36315 .41148 .37982 .39825 .3691 .40366 Mtetra
.578 .923 .725 r
.3691 .40366 .37982 .39825 .39654 .38437 .38593 .3911 Mtetra
.548 .893 .66 r
.38593 .3911 .39654 .38437 .41328 .37024 .40282 .37757 Mtetra
.533 .877 .626 r
.40282 .37757 .41328 .37024 .43004 .3561 .41976 .3635 Mtetra
.532 .873 .617 r
.41976 .3635 .43004 .3561 .4468 .34211 .43671 .34919 Mtetra
.542 .881 .627 r
.43671 .34919 .4468 .34211 .46358 .3284 .45368 .33485 Mtetra
.562 .897 .652 r
.45368 .33485 .46358 .3284 .48037 .31502 .47066 .32063 Mtetra
.589 .917 .686 r
.47066 .32063 .48037 .31502 .49717 .302 .48766 .30664 Mtetra
.619 .94 .727 r
.48766 .30664 .49717 .302 .514 .28936 .50466 .29292 Mtetra
.651 .96 .771 r
.50466 .29292 .514 .28936 .53086 .27709 .52169 .27953 Mtetra
.682 .976 .813 r
.52169 .27953 .53086 .27709 .54776 .26517 .53875 .26646 Mtetra
.709 .986 .851 r
.53875 .26646 .54776 .26517 .5647 .2536 .55583 .25373 Mtetra
.731 .988 .882 r
.55583 .25373 .5647 .2536 .5817 .24235 .57296 .24134 Mtetra
.748 .984 .907 r
.57296 .24134 .5817 .24235 .59874 .2314 .59012 .22926 Mtetra
.759 .973 .923 r
.59012 .22926 .59874 .2314 .61585 .22073 .60734 .21749 Mtetra
.765 .957 .934 r
.60734 .21749 .61585 .22073 .63302 .21031 .62461 .20601 Mtetra
.767 .939 .939 r
.62461 .20601 .63302 .21031 .65027 .20013 .64194 .1948 Mtetra
.766 .918 .939 r
.64194 .1948 .65027 .20013 .66758 .19016 .65934 .18384 Mtetra
.763 .896 .936 r
.65934 .18384 .66758 .19016 .68498 .18039 .67681 .17311 Mtetra
.758 .875 .932 r
.67681 .17311 .68498 .18039 .70245 .17079 .69435 .1626 Mtetra
.753 .854 .925 r
.69435 .1626 .70245 .17079 .72001 .16136 .71196 .15229 Mtetra
.747 .834 .918 r
.71196 .15229 .72001 .16136 .73766 .15207 .72966 .14216 Mtetra
.74 .815 .91 r
.72966 .14216 .73766 .15207 .7554 .14291 .74744 .1322 Mtetra
.734 .797 .902 r
.74744 .1322 .7554 .14291 .77323 .13387 .76531 .12239 Mtetra
.666 .912 .977 r
.11043 .4513 .12218 .4539 .13595 .45798 .12556 .44457 Mtetra
.668 .683 .856 r
.12556 .44457 .13595 .45798 .15035 .45795 .14068 .43848 Mtetra
.74 .641 .75 r
.14068 .43848 .15035 .45795 .16799 .4296 .15681 .42413 Mtetra
.054 .558 .883 r
.15681 .42413 .16799 .4296 .18025 .45122 .17107 .42705 Mtetra
.101 .229 .711 r
.17107 .42705 .18025 .45122 .19622 .43928 .18441 .44035 Mtetra
.926 .919 .789 r
.18441 .44035 .19622 .43928 .2138 .41081 .20168 .41683 Mtetra
.94 .959 .744 r
.20168 .41683 .2138 .41081 .2299 .39719 .21916 .39034 Mtetra
.773 .834 .899 r
.21916 .39034 .2299 .39719 .2446 .39983 .23508 .37983 Mtetra
.423 .479 .813 r
.23508 .37983 .2446 .39983 .25882 .41018 .24983 .38344 Mtetra
.281 .325 .73 r
.24983 .38344 .25882 .41018 .27325 .42102 .26421 .39378 Mtetra
.27 .315 .726 r
.26421 .39378 .27325 .42102 .28817 .42848 .27879 .40478 Mtetra
.316 .379 .769 r
.27879 .40478 .28817 .42848 .30363 .43123 .29382 .41299 Mtetra
.396 .494 .841 r
.29382 .41299 .30363 .43123 .31955 .42936 .30935 .41699 Mtetra
.496 .649 .926 r
.30935 .41699 .31955 .42936 .33584 .42356 .32535 .41661 Mtetra
.592 .813 .984 r
.32535 .41661 .33584 .42356 .35238 .41472 .34173 .41232 Mtetra
.645 .929 .972 r
.34173 .41232 .35238 .41472 .3691 .40366 .35838 .40484 Mtetra
.643 .966 .892 r
.35838 .40484 .3691 .40366 .38593 .3911 .37522 .3949 Mtetra
.609 .949 .793 r
.37522 .3949 .38593 .3911 .40282 .37757 .3922 .38316 Mtetra
.573 .918 .711 r
.3922 .38316 .40282 .37757 .41976 .3635 .40927 .37018 Mtetra
.547 .892 .656 r
.40927 .37018 .41976 .3635 .43671 .34919 .42639 .35638 Mtetra
.533 .877 .626 r
.42639 .35638 .43671 .34919 .45368 .33485 .44355 .34211 Mtetra
.531 .873 .616 r
.44355 .34211 .45368 .33485 .47066 .32063 .46072 .32762 Mtetra
.539 .878 .623 r
.46072 .32762 .47066 .32063 .48766 .30664 .47791 .31308 Mtetra
.555 .891 .643 r
.47791 .31308 .48766 .30664 .50466 .29292 .49511 .29864 Mtetra
.577 .908 .672 r
.49511 .29864 .50466 .29292 .52169 .27953 .51232 .28438 Mtetra
.603 .928 .707 r
.51232 .28438 .52169 .27953 .53875 .26646 .52956 .27036 Mtetra
.632 .948 .746 r
.52956 .27036 .53875 .26646 .55583 .25373 .54681 .25662 Mtetra
.661 .966 .786 r
.54681 .25662 .55583 .25373 .57296 .24134 .56409 .24317 Mtetra
.688 .979 .823 r
.56409 .24317 .57296 .24134 .59012 .22926 .5814 .23003 Mtetra
.712 .987 .857 r
.5814 .23003 .59012 .22926 .60734 .21749 .59876 .21719 Mtetra
.731 .988 .885 r
.59876 .21719 .60734 .21749 .62461 .20601 .61615 .20465 Mtetra
.746 .984 .907 r
.61615 .20465 .62461 .20601 .64194 .1948 .6336 .1924 Mtetra
.757 .974 .922 r
.6336 .1924 .64194 .1948 .65934 .18384 .6511 .18043 Mtetra
.763 .961 .933 r
.6511 .18043 .65934 .18384 .67681 .17311 .66866 .16871 Mtetra
.766 .944 .938 r
.66866 .16871 .67681 .17311 .69435 .1626 .68628 .15725 Mtetra
.766 .926 .94 r
.68628 .15725 .69435 .1626 .71196 .15229 .70398 .14601 Mtetra
.764 .906 .938 r
.70398 .14601 .71196 .15229 .72966 .14216 .72174 .13498 Mtetra
.76 .887 .935 r
.72174 .13498 .72966 .14216 .74744 .1322 .73959 .12416 Mtetra
.756 .867 .93 r
.73959 .12416 .74744 .1322 .76531 .12239 .75751 .11351 Mtetra
.715 .666 .801 r
.10021 .43547 .11043 .4513 .12556 .44457 .11576 .42558 Mtetra
.682 .621 .781 r
.11576 .42558 .12556 .44457 .14068 .43848 .13118 .41705 Mtetra
0 .172 .696 r
.13118 .41705 .14068 .43848 .15681 .42413 .14405 .43083 Mtetra
.947 .95 .738 r
.14405 .43083 .15681 .42413 .17107 .42705 .16188 .40284 Mtetra
0 0 .469 r
.16188 .40284 .17107 .42705 .18441 .44035 .17406 .42608 Mtetra
.602 .652 .872 r
.17406 .42608 .18441 .44035 .20168 .41683 .18934 .42269 Mtetra
.951 .945 .734 r
.18934 .42269 .20168 .41683 .21916 .39034 .20723 .39397 Mtetra
.928 .957 .779 r
.20723 .39397 .21916 .39034 .23508 .37983 .22451 .3704 Mtetra
.715 .777 .901 r
.22451 .3704 .23508 .37983 .24983 .38344 .24032 .36242 Mtetra
.404 .458 .803 r
.24032 .36242 .24983 .38344 .26421 .39378 .25515 .36678 Mtetra
.281 .325 .73 r
.25515 .36678 .26421 .39378 .27879 .40478 .26969 .3771 Mtetra
.268 .313 .724 r
.26969 .3771 .27879 .40478 .29382 .41299 .28442 .38822 Mtetra
.306 .364 .759 r
.28442 .38822 .29382 .41299 .30935 .41699 .29958 .39701 Mtetra
.375 .461 .821 r
.29958 .39701 .30935 .41699 .32535 .41661 .31521 .40205 Mtetra
.464 .594 .897 r
.31521 .40205 .32535 .41661 .34173 .41232 .33131 .40299 Mtetra
.558 .747 .965 r
.33131 .40299 .34173 .41232 .35838 .40484 .34777 .40011 Mtetra
.629 .881 .988 r
.34777 .40011 .35838 .40484 .37522 .3949 .36454 .39396 Mtetra
.653 .954 .945 r
.36454 .39396 .37522 .3949 .3922 .38316 .38152 .38518 Mtetra
.636 .965 .86 r
.38152 .38518 .3922 .38316 .40927 .37018 .39865 .37437 Mtetra
.602 .943 .771 r
.39865 .37437 .40927 .37018 .42639 .35638 .41589 .36207 Mtetra
.57 .914 .7 r
.41589 .36207 .42639 .35638 .44355 .34211 .4332 .34871 Mtetra
.546 .89 .653 r
.4332 .34871 .44355 .34211 .46072 .32762 .45055 .33466 Mtetra
.533 .877 .626 r
.45055 .33466 .46072 .32762 .47791 .31308 .46793 .32019 Mtetra
.53 .872 .616 r
.46793 .32019 .47791 .31308 .49511 .29864 .48533 .30551 Mtetra
.536 .876 .62 r
.48533 .30551 .49511 .29864 .51232 .28438 .50274 .29078 Mtetra
.549 .886 .636 r
.50274 .29078 .51232 .28438 .52956 .27036 .52016 .27612 Mtetra
.568 .901 .66 r
.52016 .27612 .52956 .27036 .54681 .25662 .53761 .26161 Mtetra
.59 .919 .691 r
.53761 .26161 .54681 .25662 .56409 .24317 .55507 .2473 Mtetra
.616 .938 .725 r
.55507 .2473 .56409 .24317 .5814 .23003 .57255 .23323 Mtetra
.642 .955 .762 r
.57255 .23323 .5814 .23003 .59876 .21719 .59006 .21943 Mtetra
.668 .97 .798 r
.59006 .21943 .59876 .21719 .61615 .20465 .60761 .20591 Mtetra
.693 .981 .831 r
.60761 .20591 .61615 .20465 .6336 .1924 .62519 .19266 Mtetra
.714 .987 .861 r
.62519 .19266 .6336 .1924 .6511 .18043 .64282 .1797 Mtetra
.732 .988 .887 r
.64282 .1797 .6511 .18043 .66866 .16871 .6605 .167 Mtetra
.745 .984 .907 r
.6605 .167 .66866 .16871 .68628 .15725 .67823 .15456 Mtetra
.755 .975 .921 r
.67823 .15456 .68628 .15725 .70398 .14601 .69603 .14238 Mtetra
.761 .963 .932 r
.69603 .14238 .70398 .14601 .72174 .13498 .71388 .13043 Mtetra
.765 .949 .937 r
.71388 .13043 .72174 .13498 .73959 .12416 .73181 .1187 Mtetra
.765 .932 .94 r
.73181 .1187 .73959 .12416 .75751 .11351 .74981 .10719 Mtetra
.352 .767 .979 r
.08836 .43124 .10021 .43547 .11576 .42558 .10284 .43017 Mtetra
.686 .98 .838 r
.10284 .43017 .11576 .42558 .13118 .41705 .11878 .41848 Mtetra
.536 0 0 r
.11878 .41848 .13118 .41705 .14405 .43083 .13251 .42527 Mtetra
.908 .798 .728 r
.13251 .42527 .14405 .43083 .16188 .40284 .15087 .394 Mtetra
0 .41 .838 r
.15087 .394 .16188 .40284 .17406 .42608 .16491 .40005 Mtetra
0 .085 .627 r
.16491 .40005 .17406 .42608 .18934 .42269 .17786 .41816 Mtetra
.859 .868 .845 r
.17786 .41816 .18934 .42269 .20723 .39397 .19469 .40128 Mtetra
.951 .952 .717 r
.19469 .40128 .20723 .39397 .22451 .3704 .21279 .37132 Mtetra
.908 .945 .817 r
.21279 .37132 .22451 .3704 .24032 .36242 .22988 .3508 Mtetra
.663 .724 .895 r
.22988 .3508 .24032 .36242 .25515 .36678 .24562 .3449 Mtetra
.389 .442 .795 r
.24562 .3449 .25515 .36678 .26969 .3771 .26055 .34986 Mtetra
.28 .324 .73 r
.26055 .34986 .26969 .3771 .28442 .38822 .27526 .36015 Mtetra
.266 .31 .722 r
.27526 .36015 .28442 .38822 .29958 .39701 .29016 .37133 Mtetra
.298 .353 .751 r
.29016 .37133 .29958 .39701 .31521 .40205 .30545 .38058 Mtetra
.358 .435 .804 r
.30545 .38058 .31521 .40205 .33131 .40299 .3212 .38649 Mtetra
.437 .55 .873 r
.3212 .38649 .33131 .40299 .34777 .40011 .3374 .38859 Mtetra
.525 .688 .942 r
.3374 .38859 .34777 .40011 .36454 .39396 .35398 .387 Mtetra
.603 .825 .985 r
.35398 .387 .36454 .39396 .38152 .38518 .37086 .38214 Mtetra
.649 .924 .975 r
.37086 .38214 .38152 .38518 .39865 .37437 .38798 .37452 Mtetra
.652 .965 .915 r
.38798 .37452 .39865 .37437 .41589 .36207 .40527 .36469 Mtetra
.628 .961 .832 r
.40527 .36469 .41589 .36207 .4332 .34871 .42268 .35317 Mtetra
.596 .937 .753 r
.42268 .35317 .4332 .34871 .45055 .33466 .44018 .34038 Mtetra
.567 .91 .692 r
.44018 .34038 .45055 .33466 .46793 .32019 .45773 .32669 Mtetra
.546 .889 .65 r
.45773 .32669 .46793 .32019 .48533 .30551 .47531 .31239 Mtetra
.534 .877 .625 r
.47531 .31239 .48533 .30551 .50274 .29078 .49292 .29771 Mtetra
.53 .872 .616 r
.49292 .29771 .50274 .29078 .52016 .27612 .51055 .28284 Mtetra
.534 .875 .618 r
.51055 .28284 .52016 .27612 .53761 .26161 .5282 .26791 Mtetra
.545 .883 .631 r
.5282 .26791 .53761 .26161 .55507 .2473 .54585 .25304 Mtetra
.56 .896 .651 r
.54585 .25304 .55507 .2473 .57255 .23323 .56353 .23828 Mtetra
.58 .911 .678 r
.56353 .23828 .57255 .23323 .59006 .21943 .58122 .2237 Mtetra
.603 .929 .708 r
.58122 .2237 .59006 .21943 .60761 .20591 .59894 .20933 Mtetra
.627 .946 .741 r
.59894 .20933 .60761 .20591 .62519 .19266 .61669 .1952 Mtetra
.651 .961 .775 r
.61669 .1952 .62519 .19266 .64282 .1797 .63447 .18132 Mtetra
.675 .974 .808 r
.63447 .18132 .64282 .1797 .6605 .167 .65229 .16769 Mtetra
.697 .983 .838 r
.65229 .16769 .6605 .167 .67823 .15456 .67016 .15432 Mtetra
.716 .987 .865 r
.67016 .15432 .67823 .15456 .69603 .14238 .68807 .14121 Mtetra
.732 .988 .888 r
.68807 .14121 .69603 .14238 .71388 .13043 .70604 .12834 Mtetra
.744 .984 .907 r
.70604 .12834 .71388 .13043 .73181 .1187 .72407 .1157 Mtetra
.754 .976 .921 r
.72407 .1157 .73181 .1187 .74981 .10719 .74217 .1033 Mtetra
.596 .645 .869 r
.07774 .4167 .08836 .43124 .10284 .43017 .09252 .41349 Mtetra
.273 .446 .851 r
.09252 .41349 .10284 .43017 .11878 .41848 .10627 .41899 Mtetra
.886 .939 .844 r
.10627 .41899 .11878 .41848 .13251 .42527 .12315 .40089 Mtetra
.552 .512 .765 r
.12315 .40089 .13251 .42527 .15087 .394 .13801 .39943 Mtetra
.925 .966 .772 r
.13801 .39943 .15087 .394 .16491 .40005 .15559 .37543 Mtetra
0 0 .442 r
.15559 .37543 .16491 .40005 .17786 .41816 .16776 .39955 Mtetra
.387 .485 .838 r
.16776 .39955 .17786 .41816 .19469 .40128 .18245 .40336 Mtetra
.934 .929 .776 r
.18245 .40336 .19469 .40128 .21279 .37132 .20027 .37815 Mtetra
.948 .955 .724 r
.20027 .37815 .21279 .37132 .22988 .3508 .21837 .34908 Mtetra
.88 .923 .849 r
.21837 .34908 .22988 .3508 .24562 .3449 .23528 .33143 Mtetra
.617 .678 .885 r
.23528 .33143 .24562 .3449 .26055 .34986 .25101 .32722 Mtetra
.377 .429 .788 r
.25101 .32722 .26055 .34986 .27526 .36015 .26605 .33265 Mtetra
.28 .324 .73 r
.26605 .33265 .27526 .36015 .29016 .37133 .28092 .34291 Mtetra
.265 .309 .721 r
.28092 .34291 .29016 .37133 .30545 .38058 .29599 .35411 Mtetra
.292 .344 .745 r
.29599 .35411 .30545 .38058 .3212 .38649 .31143 .36373 Mtetra
.344 .415 .791 r
.31143 .36373 .3212 .38649 .3374 .38859 .32732 .37037 Mtetra
.414 .515 .852 r
.32732 .37037 .3374 .38859 .35398 .387 .34364 .37349 Mtetra
.495 .638 .918 r
.34364 .37349 .35398 .387 .37086 .38214 .36034 .37308 Mtetra
.574 .769 .971 r
.36034 .37308 .37086 .38214 .38798 .37452 .37736 .36941 Mtetra
.633 .881 .987 r
.37736 .36941 .38798 .37452 .40527 .36469 .39462 .36294 Mtetra
.657 .949 .954 r
.39462 .36294 .40527 .36469 .42268 .35317 .41207 .35412 Mtetra
.648 .968 .887 r
.41207 .35412 .42268 .35317 .44018 .34038 .42966 .34344 Mtetra
.621 .956 .809 r
.42966 .34344 .44018 .34038 .45773 .32669 .44734 .33131 Mtetra
.59 .931 .739 r
.44734 .33131 .45773 .32669 .47531 .31239 .46509 .31809 Mtetra
.564 .907 .685 r
.46509 .31809 .47531 .31239 .49292 .29771 .48289 .30409 Mtetra
.545 .889 .648 r
.48289 .30409 .49292 .29771 .51055 .28284 .50071 .28954 Mtetra
.534 .877 .625 r
.50071 .28954 .51055 .28284 .5282 .26791 .51856 .27466 Mtetra
.53 .872 .616 r
.51856 .27466 .5282 .26791 .54585 .25304 .53643 .25959 Mtetra
.533 .874 .617 r
.53643 .25959 .54585 .25304 .56353 .23828 .55431 .24447 Mtetra
.541 .88 .627 r
.55431 .24447 .56353 .23828 .58122 .2237 .5722 .22937 Mtetra
.555 .891 .644 r
.5722 .22937 .58122 .2237 .59894 .20933 .59011 .21437 Mtetra
.572 .905 .667 r
.59011 .21437 .59894 .20933 .61669 .1952 .60804 .19953 Mtetra
.592 .921 .694 r
.60804 .19953 .61669 .1952 .63447 .18132 .626 .18487 Mtetra
.613 .937 .724 r
.626 .18487 .63447 .18132 .65229 .16769 .64399 .17042 Mtetra
.636 .952 .755 r
.64399 .17042 .65229 .16769 .67016 .15432 .66201 .1562 Mtetra
.659 .965 .787 r
.66201 .1562 .67016 .15432 .68807 .14121 .68008 .14221 Mtetra
.68 .976 .816 r
.68008 .14221 .68807 .14121 .70604 .12834 .69819 .12847 Mtetra
.7 .984 .844 r
.69819 .12847 .70604 .12834 .72407 .1157 .71634 .11495 Mtetra
.717 .987 .869 r
.71634 .11495 .72407 .1157 .74217 .1033 .73456 .10167 Mtetra
.822 .838 .861 r
.06582 .41068 .07774 .4167 .09252 .41349 .08212 .39671 Mtetra
.518 .578 .855 r
.08212 .39671 .09252 .41349 .10627 .41899 .09663 .39627 Mtetra
.746 .625 .726 r
.09663 .39627 .10627 .41899 .12315 .40089 .11343 .37907 Mtetra
0 0 .369 r
.11343 .37907 .12315 .40089 .13801 .39943 .12517 .40254 Mtetra
.96 .864 .699 r
.12517 .40254 .13801 .39943 .15559 .37543 .14468 .36395 Mtetra
0 .307 .789 r
.14468 .36395 .15559 .37543 .16776 .39955 .15858 .37231 Mtetra
0 0 .557 r
.15858 .37231 .16776 .39955 .18245 .40336 .17127 .3937 Mtetra
.746 .785 .885 r
.17127 .3937 .18245 .40336 .20027 .37815 .1876 .38381 Mtetra
.951 .945 .733 r
.1876 .38381 .20027 .37815 .21837 .34908 .20595 .35442 Mtetra
.941 .957 .745 r
.20595 .35442 .21837 .34908 .23528 .33143 .22394 .32724 Mtetra
.845 .893 .873 r
.22394 .32724 .23528 .33143 .25101 .32722 .24073 .31215 Mtetra
.578 .638 .874 r
.24073 .31215 .25101 .32722 .26605 .33265 .25647 .30935 Mtetra
.367 .418 .782 r
.25647 .30935 .26605 .33265 .28092 .34291 .27164 .31516 Mtetra
.28 .324 .73 r
.27164 .31516 .28092 .34291 .29599 .35411 .28669 .32537 Mtetra
.265 .308 .72 r
.28669 .32537 .29599 .35411 .31143 .36373 .30193 .33658 Mtetra
.287 .337 .74 r
.30193 .33658 .31143 .36373 .32732 .37037 .31753 .34648 Mtetra
.333 .398 .78 r
.31753 .34648 .32732 .37037 .34364 .37349 .33356 .35374 Mtetra
.395 .486 .834 r
.33356 .35374 .34364 .37349 .36034 .37308 .35002 .35775 Mtetra
.468 .595 .896 r
.35002 .35775 .36034 .37308 .37736 .36941 .36685 .35839 Mtetra
.545 .717 .952 r
.36685 .35839 .37736 .36941 .39462 .36294 .38401 .35585 Mtetra
.611 .833 .985 r
.38401 .35585 .39462 .36294 .41207 .35412 .40142 .35047 Mtetra
.651 .919 .977 r
.40142 .35047 .41207 .35412 .42966 .34344 .41904 .34268 Mtetra
.658 .962 .93 r
.41904 .34268 .42966 .34344 .44734 .33131 .43681 .33288 Mtetra
.642 .967 .861 r
.43681 .33288 .44734 .33131 .46509 .31809 .45468 .32147 Mtetra
.614 .95 .789 r
.45468 .32147 .46509 .31809 .48289 .30409 .47264 .30881 Mtetra
.586 .927 .727 r
.47264 .30881 .48289 .30409 .50071 .28954 .49065 .2952 Mtetra
.562 .905 .679 r
.49065 .2952 .50071 .28954 .51856 .27466 .5087 .28089 Mtetra
.545 .888 .646 r
.5087 .28089 .51856 .27466 .53643 .25959 .52677 .26611 Mtetra
.534 .877 .625 r
.52677 .26611 .53643 .25959 .55431 .24447 .54486 .25101 Mtetra
.53 .872 .616 r
.54486 .25101 .55431 .24447 .5722 .22937 .56297 .23574 Mtetra
.532 .873 .616 r
.56297 .23574 .5722 .22937 .59011 .21437 .58109 .22041 Mtetra
.539 .878 .624 r
.58109 .22041 .59011 .21437 .60804 .19953 .59923 .20509 Mtetra
.55 .888 .639 r
.59923 .20509 .60804 .19953 .626 .18487 .61739 .18986 Mtetra
.565 .9 .658 r
.61739 .18986 .626 .18487 .64399 .17042 .63556 .17475 Mtetra
.583 .914 .682 r
.63556 .17475 .64399 .17042 .66201 .1562 .65377 .15982 Mtetra
.602 .929 .709 r
.65377 .15982 .66201 .1562 .68008 .14221 .672 .14506 Mtetra
.623 .943 .738 r
.672 .14506 .68008 .14221 .69819 .12847 .69027 .13052 Mtetra
.644 .957 .767 r
.69027 .13052 .69819 .12847 .71634 .11495 .70858 .11619 Mtetra
.665 .969 .796 r
.70858 .11619 .71634 .11495 .73456 .10167 .72694 .10208 Mtetra
.289 .53 .91 r
.05475 .39756 .06582 .41068 .08212 .39671 .06864 .40108 Mtetra
.927 .949 .786 r
.06864 .40108 .08212 .39671 .09663 .39627 .08645 .37722 Mtetra
.512 .547 .828 r
.08645 .37722 .09663 .39627 .11343 .37907 .10104 .3771 Mtetra
.667 .12 0 r
.10104 .3771 .11343 .37907 .12517 .40254 .11425 .38879 Mtetra
.828 .726 .752 r
.11425 .38879 .12517 .40254 .14468 .36395 .13188 .36668 Mtetra
.892 .97 .827 r
.13188 .36668 .14468 .36395 .15858 .37231 .14913 .34731 Mtetra
0 0 .429 r
.14913 .34731 .15858 .37231 .17127 .3937 .16133 .37189 Mtetra
.183 .323 .772 r
.16133 .37189 .17127 .3937 .1876 .38381 .17555 .38143 Mtetra
.892 .901 .827 r
.17555 .38143 .1876 .38381 .20595 .35442 .1931 .36144 Mtetra
.953 .95 .716 r
.1931 .36144 .20595 .35442 .22394 .32724 .21168 .33061 Mtetra
.932 .954 .772 r
.21168 .33061 .22394 .32724 .24073 .31215 .22954 .30573 Mtetra
.806 .858 .888 r
.22954 .30573 .24073 .31215 .25647 .30935 .24624 .29289 Mtetra
.546 .605 .863 r
.24624 .29289 .25647 .30935 .27164 .31516 .26202 .29126 Mtetra
.358 .409 .778 r
.26202 .29126 .27164 .31516 .28669 .32537 .27732 .29737 Mtetra
.28 .324 .729 r
.27732 .29737 .28669 .32537 .30193 .33658 .29255 .30753 Mtetra
.264 .307 .72 r
.29255 .30753 .30193 .33658 .31753 .34648 .30797 .31872 Mtetra
.283 .331 .736 r
.30797 .31872 .31753 .34648 .33356 .35374 .32375 .32885 Mtetra
.323 .385 .771 r
.32375 .32885 .33356 .35374 .35002 .35775 .33993 .33662 Mtetra
.379 .462 .82 r
.33993 .33662 .35002 .35775 .36685 .35839 .35654 .34141 Mtetra
.446 .559 .876 r
.35654 .34141 .36685 .35839 .38401 .35585 .37352 .343 Mtetra
.518 .671 .933 r
.37352 .343 .38401 .35585 .40142 .35047 .39082 .3415 Mtetra
.586 .785 .974 r
.39082 .3415 .40142 .35047 .41904 .34268 .4084 .33717 Mtetra
.636 .881 .986 r
.4084 .33717 .41904 .34268 .43681 .33288 .42619 .33037 Mtetra
.659 .944 .961 r
.42619 .33037 .43681 .33288 .45468 .32147 .44414 .32146 Mtetra
.656 .968 .906 r
.44414 .32146 .45468 .32147 .47264 .30881 .46222 .31082 Mtetra
.635 .964 .839 r
.46222 .31082 .47264 .30881 .49065 .2952 .48038 .29878 Mtetra
.608 .945 .773 r
.48038 .29878 .49065 .2952 .5087 .28089 .49861 .28564 Mtetra
.582 .923 .718 r
.49861 .28564 .5087 .28089 .52677 .26611 .51688 .27167 Mtetra
.56 .903 .675 r
.51688 .27167 .52677 .26611 .54486 .25101 .53519 .25708 Mtetra
.544 .887 .644 r
.53519 .25708 .54486 .25101 .56297 .23574 .55351 .24205 Mtetra
.534 .877 .625 r
.55351 .24205 .56297 .23574 .58109 .22041 .57185 .22674 Mtetra
.53 .872 .616 r
.57185 .22674 .58109 .22041 .59923 .20509 .59021 .21127 Mtetra
.531 .872 .615 r
.59021 .21127 .59923 .20509 .61739 .18986 .60858 .19572 Mtetra
.537 .877 .622 r
.60858 .19572 .61739 .18986 .63556 .17475 .62697 .18018 Mtetra
.546 .885 .634 r
.62697 .18018 .63556 .17475 .65377 .15982 .64538 .16471 Mtetra
.559 .895 .651 r
.64538 .16471 .65377 .15982 .672 .14506 .6638 .14935 Mtetra
.575 .908 .673 r
.6638 .14935 .672 .14506 .69027 .13052 .68226 .13414 Mtetra
.593 .922 .697 r
.68226 .13414 .69027 .13052 .70858 .11619 .70075 .11909 Mtetra
.612 .936 .723 r
.70075 .11909 .70858 .11619 .72694 .10208 .71927 .10423 Mtetra
.724 .809 .918 r
.04279 .38962 .05475 .39756 .06864 .40108 .0584 .38141 Mtetra
.527 .548 .821 r
.0584 .38141 .06864 .40108 .08645 .37722 .07302 .3807 Mtetra
.323 0 0 r
.07302 .3807 .08645 .37722 .10104 .3771 .08737 .38291 Mtetra
.893 .986 .795 r
.08737 .38291 .10104 .3771 .11425 .38879 .10495 .3619 Mtetra
.188 .269 .716 r
.10495 .3619 .11425 .38879 .13188 .36668 .11837 .37312 Mtetra
.971 .892 .69 r
.11837 .37312 .13188 .36668 .14913 .34731 .13825 .33373 Mtetra
0 .238 .749 r
.13825 .33373 .14913 .34731 .16133 .37189 .15207 .34381 Mtetra
0 0 .505 r
.15207 .34381 .16133 .37189 .17555 .38143 .16461 .36744 Mtetra
.591 .669 .893 r
.16461 .36744 .17555 .38143 .1931 .36144 .18046 .36398 Mtetra
.938 .935 .769 r
.18046 .36398 .1931 .36144 .21168 .33061 .19879 .33757 Mtetra
.951 .953 .716 r
.19879 .33757 .21168 .33061 .22954 .30573 .21743 .30697 Mtetra
.918 .947 .801 r
.21743 .30697 .22954 .30573 .24624 .29289 .23517 .28445 Mtetra
.767 .821 .895 r
.23517 .28445 .24624 .29289 .26202 .29126 .25181 .27357 Mtetra
.518 .576 .853 r
.25181 .27357 .26202 .29126 .27732 .29737 .26766 .27291 Mtetra
.351 .401 .774 r
.26766 .27291 .27732 .29737 .29255 .30753 .28311 .27928 Mtetra
.28 .324 .729 r
.28311 .27928 .29255 .30753 .30797 .31872 .29851 .28938 Mtetra
.264 .307 .719 r
.29851 .28938 .30797 .31872 .32375 .32885 .31412 .30054 Mtetra
.279 .327 .733 r
.31412 .30054 .32375 .32885 .33993 .33662 .33007 .31084 Mtetra
.315 .374 .764 r
.33007 .31084 .33993 .33662 .35654 .34141 .34643 .31905 Mtetra
.365 .442 .807 r
.34643 .31905 .35654 .34141 .37352 .343 .36319 .3245 Mtetra
.426 .529 .859 r
.36319 .3245 .37352 .343 .39082 .3415 .38033 .32695 Mtetra
.493 .631 .913 r
.38033 .32695 .39082 .3415 .4084 .33717 .3978 .3264 Mtetra
.56 .739 .96 r
.3978 .3264 .4084 .33717 .42619 .33037 .41554 .32307 Mtetra
.617 .839 .985 r
.41554 .32307 .42619 .33037 .44414 .32146 .43351 .31723 Mtetra
.652 .916 .979 r
.43351 .31723 .44414 .32146 .46222 .31082 .45166 .30921 Mtetra
.662 .958 .941 r
.45166 .30921 .46222 .31082 .48038 .29878 .46994 .29936 Mtetra
.651 .969 .883 r
.46994 .29936 .48038 .29878 .49861 .28564 .48832 .28799 Mtetra
.629 .96 .819 r
.48832 .28799 .49861 .28564 .51688 .27167 .50677 .27539 Mtetra
.603 .941 .759 r
.50677 .27539 .51688 .27167 .53519 .25708 .52527 .26182 Mtetra
.578 .92 .709 r
.52527 .26182 .53519 .25708 .55351 .24205 .54381 .2475 Mtetra
.558 .901 .671 r
.54381 .2475 .55351 .24205 .57185 .22674 .56238 .23263 Mtetra
.544 .887 .643 r
.56238 .23263 .57185 .22674 .59021 .21127 .58096 .21736 Mtetra
.534 .877 .625 r
.58096 .21736 .59021 .21127 .60858 .19572 .59956 .20183 Mtetra
.53 .872 .616 r
.59956 .20183 .60858 .19572 .62697 .18018 .61818 .18614 Mtetra
.531 .872 .615 r
.61818 .18614 .62697 .18018 .64538 .16471 .6368 .17038 Mtetra
.535 .875 .62 r
.6368 .17038 .64538 .16471 .6638 .14935 .65545 .15461 Mtetra
.543 .882 .63 r
.65545 .15461 .6638 .14935 .68226 .13414 .67411 .1389 Mtetra
.555 .892 .645 r
.67411 .1389 .68226 .13414 .70075 .11909 .6928 .12329 Mtetra
.569 .903 .664 r
.6928 .12329 .70075 .11909 .71927 .10423 .71151 .1078 Mtetra
.75 .745 .847 r
.03123 .37802 .04279 .38962 .0584 .38141 .04728 .36716 Mtetra
0 .192 .715 r
.04728 .36716 .0584 .38141 .07302 .3807 .06028 .37761 Mtetra
.572 .887 .99 r
.06028 .37761 .07302 .3807 .08737 .38291 .07571 .37248 Mtetra
.884 .754 .714 r
.07571 .37248 .08737 .38291 .10495 .3619 .09499 .33974 Mtetra
.759 .392 0 r
.09499 .33974 .10495 .3619 .11837 .37312 .10592 .36939 Mtetra
.928 .815 .713 r
.10592 .36939 .11837 .37312 .13825 .33373 .12556 .33351 Mtetra
.844 .958 .884 r
.12556 .33351 .13825 .33373 .15207 .34381 .14248 .31844 Mtetra
0 0 .423 r
.14248 .31844 .15207 .34381 .16461 .36744 .15474 .34323 Mtetra
.016 .188 .699 r
.15474 .34323 .16461 .36744 .18046 .36398 .1686 .35724 Mtetra
.82 .851 .872 r
.1686 .35724 .18046 .36398 .19879 .33757 .18579 .34294 Mtetra
.951 .945 .733 r
.18579 .34294 .19879 .33757 .21743 .30697 .2046 .31299 Mtetra
.947 .955 .728 r
.2046 .31299 .21743 .30697 .23517 .28445 .22321 .28356 Mtetra
.9 .934 .827 r
.22321 .28356 .23517 .28445 .25181 .27357 .24084 .26332 Mtetra
.728 .784 .897 r
.24084 .26332 .25181 .27357 .26766 .27291 .25746 .25414 Mtetra
.495 .552 .844 r
.25746 .25414 .26766 .27291 .28311 .27928 .27339 .2543 Mtetra
.345 .395 .77 r
.27339 .2543 .28311 .27928 .29851 .28938 .28899 .26087 Mtetra
.28 .323 .729 r
.28899 .26087 .29851 .28938 .31412 .30054 .30458 .27091 Mtetra
.264 .306 .719 r
.30458 .27091 .31412 .30054 .33007 .31084 .32038 .28203 Mtetra
.277 .323 .73 r
.32038 .28203 .33007 .31084 .34643 .31905 .33652 .29245 Mtetra
.308 .364 .757 r
.33652 .29245 .34643 .31905 .36319 .3245 .35305 .30102 Mtetra
.353 .425 .796 r
.35305 .30102 .36319 .3245 .38033 .32695 .36998 .30706 Mtetra
.409 .503 .844 r
.36998 .30706 .38033 .32695 .3978 .3264 .38729 .31027 Mtetra
.471 .596 .895 r
.38729 .31027 .3978 .3264 .41554 .32307 .40493 .3106 Mtetra
.536 .697 .943 r
.40493 .3106 .41554 .32307 .43351 .31723 .42285 .3082 Mtetra
.595 .797 .977 r
.42285 .3082 .43351 .31723 .45166 .30921 .44101 .30328 Mtetra
.639 .882 .986 r
.44101 .30328 .45166 .30921 .46994 .29936 .45936 .29615 Mtetra
.661 .939 .965 r
.45936 .29615 .46994 .29936 .48832 .28799 .47785 .28709 Mtetra
.661 .966 .92 r
.47785 .28709 .48832 .28799 .50677 .27539 .49645 .27641 Mtetra
.646 .968 .862 r
.49645 .27641 .50677 .27539 .52527 .26182 .51513 .26439 Mtetra
.623 .955 .802 r
.51513 .26439 .52527 .26182 .54381 .2475 .53387 .25128 Mtetra
.598 .936 .748 r
.53387 .25128 .54381 .2475 .56238 .23263 .55266 .23731 Mtetra
.575 .917 .702 r
.55266 .23731 .56238 .23263 .58096 .21736 .57147 .22266 Mtetra
.557 .899 .667 r
.57147 .22266 .58096 .21736 .59956 .20183 .5903 .20752 Mtetra
.543 .886 .642 r
.5903 .20752 .59956 .20183 .61818 .18614 .60915 .192 Mtetra
.535 .877 .625 r
.60915 .192 .61818 .18614 .6368 .17038 .62802 .17624 Mtetra
.53 .872 .616 r
.62802 .17624 .6368 .17038 .65545 .15461 .6469 .16033 Mtetra
.53 .872 .614 r
.6469 .16033 .65545 .15461 .67411 .1389 .66579 .14435 Mtetra
.534 .874 .618 r
.66579 .14435 .67411 .1389 .6928 .12329 .6847 .12836 Mtetra
.541 .88 .627 r
.6847 .12836 .6928 .12329 .71151 .1078 .70362 .1124 Mtetra
.242 .587 .947 r
.01926 .36808 .03123 .37802 .04728 .36716 .03332 .37063 Mtetra
.877 .977 .839 r
.03332 .37063 .04728 .36716 .06028 .37761 .05065 .35232 Mtetra
.628 .553 .751 r
.05065 .35232 .06028 .37761 .07571 .37248 .06627 .34569 Mtetra
.674 .569 .729 r
.06627 .34569 .07571 .37248 .09499 .33974 .08257 .33477 Mtetra
.724 .192 0 r
.08257 .33477 .09499 .33974 .10592 .36939 .09541 .34969 Mtetra
.687 .632 .788 r
.09541 .34969 .10592 .36939 .12556 .33351 .11174 .34021 Mtetra
.969 .908 .7 r
.11174 .34021 .12556 .33351 .14248 .31844 .13159 .30313 Mtetra
0 .189 .718 r
.13159 .30313 .14248 .31844 .15474 .34323 .14538 .31453 Mtetra
0 0 .467 r
.14538 .31453 .15474 .34323 .1686 .35724 .15783 .33967 Mtetra
.417 .532 .867 r
.15783 .33967 .1686 .35724 .18579 .34294 .17324 .3418 Mtetra
.909 .917 .812 r
.17324 .3418 .18579 .34294 .2046 .31299 .19142 .31962 Mtetra
.954 .949 .716 r
.19142 .31962 .2046 .31299 .22321 .28356 .21047 .28816 Mtetra
.942 .955 .746 r
.21047 .28816 .22321 .28356 .24084 .26332 .22902 .26038 Mtetra
.877 .917 .85 r
.22902 .26038 .24084 .26332 .25746 .25414 .24656 .24226 Mtetra
.691 .748 .895 r
.24656 .24226 .25746 .25414 .27339 .2543 .26319 .23456 Mtetra
.475 .532 .835 r
.26319 .23456 .27339 .2543 .28899 .26087 .27921 .23541 Mtetra
.34 .39 .767 r
.27921 .23541 .28899 .26087 .30458 .27091 .29498 .24214 Mtetra
.279 .323 .729 r
.29498 .24214 .30458 .27091 .32038 .28203 .31076 .25211 Mtetra
.263 .306 .719 r
.31076 .25211 .32038 .28203 .33652 .29245 .32676 .26317 Mtetra
.274 .32 .728 r
.32676 .26317 .33652 .29245 .35305 .30102 .34309 .27369 Mtetra
.303 .356 .752 r
.34309 .27369 .35305 .30102 .36998 .30706 .3598 .28256 Mtetra
.343 .411 .787 r
.3598 .28256 .36998 .30706 .38729 .31027 .37691 .28911 Mtetra
.394 .481 .831 r
.37691 .28911 .38729 .31027 .40493 .3106 .3944 .29299 Mtetra
.452 .565 .879 r
.3944 .29299 .40493 .3106 .42285 .3082 .41222 .29413 Mtetra
.513 .659 .926 r
.41222 .29413 .42285 .3082 .44101 .30328 .43034 .29259 Mtetra
.572 .756 .965 r
.43034 .29259 .44101 .30328 .45936 .29615 .44869 .28856 Mtetra
.621 .844 .985 r
.44869 .28856 .45936 .29615 .47785 .28709 .46724 .28228 Mtetra
.653 .913 .979 r
.46724 .28228 .47785 .28709 .49645 .27641 .48595 .27402 Mtetra
.664 .954 .949 r
.48595 .27402 .49645 .27641 .51513 .26439 .50478 .26405 Mtetra
.658 .969 .9 r
.50478 .26405 .51513 .26439 .53387 .25128 .5237 .25264 Mtetra
.64 .966 .843 r
.5237 .25264 .53387 .25128 .55266 .23731 .54269 .24003 Mtetra
.617 .951 .787 r
.54269 .24003 .55266 .23731 .57147 .22266 .56172 .22646 Mtetra
.594 .932 .738 r
.56172 .22646 .57147 .22266 .5903 .20752 .58079 .2121 Mtetra
.573 .914 .696 r
.58079 .2121 .5903 .20752 .60915 .192 .59988 .19714 Mtetra
.556 .898 .664 r
.59988 .19714 .60915 .192 .62802 .17624 .61899 .18171 Mtetra
.543 .886 .641 r
.61899 .18171 .62802 .17624 .6469 .16033 .63812 .16595 Mtetra
.535 .877 .625 r
.63812 .16595 .6469 .16033 .66579 .14435 .65725 .14996 Mtetra
.531 .873 .617 r
.65725 .14996 .66579 .14435 .6847 .12836 .6764 .13382 Mtetra
.53 .872 .614 r
.6764 .13382 .6847 .12836 .70362 .1124 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(0.5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(1)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(1.5)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.03716 .25514 m
.04004 .25782 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{Inherited, Inherited}, {Inherited, 8}},
  ImageSize->{260.5, 185.625},
  ImageMargins->{{Inherited, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000550000j1000`40O003h00OogooAWoo003JOol5
001VOol00=Yoo`05001oogooOol0001VOol00=]oo`03001oogoo06Moo`00g7oo00<007ooOol0IWoo
003MOol00`00Oomoo`1UOol00=ioo`03001oogoo06Aoo`00fWoo00D007ooOomoo`0006Ioo`00fgoo
0`00Igoo003oOom6Ool00?moodIoo`00ogooAWoo003oOom6Ool00?moodIoo`00ogooAWoo003QOol2
001ROol00=moo`800003Ool00000065oo`00g7oo0`000goo0P00HGoo003JOol20006Ool3001POol0
0=Moo`<000Qoo`04001oogoo001OOol00=Aoo`<00003Ool007oo00Qoo`04001oogoo001OOol009Yo
o`D000Aoo`8000Eoo`@002Aoo`8000ioo`05001oogooOol0001NOol009aoo`03001oogoo00Aoo`80
00Aoo`03001oogoo009oo`03001oogoo01ioo`<0011oo`03001oogoo009oo`03001oogoo00ioo`@0
04Uoo`00L7oo0P000Woo0P009Woo00<007ooOol03goo00<007ooOol077oo0P004goo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol0AWoo001aOol01000Oomoo`009goo00<0
07ooOol03goo00<007ooOol06Goo0`0000=oo`00Ool04goo00<007ooOol00Woo00<007ooOol04Goo
00<007ooOol0AWoo001bOol2000XOol00`00Oomoo`0;Ool4000JOol2000IOol00`00Oomoo`03Ool0
0`00Oomoo`03Ool60007Ool00`00Oomoo`16Ool0079oo`8002Qoo`03001oogoo00]oo`03001oogoo
01Qoo`<001]oo`03001oogoo00=oo`03001oogoo00aoo`@004Uoo`00LGoo00@007ooOol002Eoo`<0
00eoo`03001oogoo01Ioo`8001ioo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo04Yoo`00
L7oo0P000Woo0P009Woo00<007ooOol02goo1@004Goo0`0087oo00<007ooOol01Goo00<007ooOol0
2Woo00<007ooOol0BWoo002mOol3000SOol00`00Oomoo`03Ool3000<Ool50018Ool00;Uoo`04001o
o`00000VOol00`00Oomoo`06Ool00`00Oomoo`1FOol00;Qoo`<002Qoo`03001oogoo00Moo`03001o
ogoo05Eoo`00]Woo0P00:goo00<007ooOol01goo00<007ooOol0EGoo002cOol3000]Ool00`00Oomo
o`08Ool00`00Oomoo`1DOol00;1oo`<0031oo`03001oogoo00Uoo`03001oogoo05=oo`00[Woo1000
<Goo00<007ooOol02Goo00<007ooOol0Dgoo002[Ool30003Ool00`00Oomoo`0_Ool00`00Oomoo`0:
Ool00`00Oomoo`1BOol00:Uoo`8003Qoo`03001oogoo00Yoo`03001oogoo059oo`00YWoo0`00>Woo
00<007ooOol02goo00<007ooOol0DGoo001iOol5000VOol200000goo001oo`0jOol00`00Oomoo`0<
Ool00`00Oomoo`1@Ool007]oo`03001oogoo02=oo`<0041oo`03001oogoo00Yoo`80059oo`00Ngoo
00<007ooOol08Goo0P00@goo00<007ooOol037oo00<007ooOol0Cgoo001kOol00`00Oomoo`0NOol3
0015Ool00`00Oomoo`0=Ool00`00Oomoo`1>Ool007]oo`03001oogoo01aoo`800003Ool007oo04Eo
o`03001oogoo00=oo`08CkICf5OIFmYKneoLHoeOg09oo`03001oogoo04ioo`00Ngoo00<007ooOol0
6Goo0`00BWoo00<007ooOol00TND00Q?]U?HFo]Kfe_kGmaOgEoL0Unm0Woo00<007ooOol0CGoo001i
Ool3000GOol4001=Ool04000Oom;UDNDEmUGfU_kFmYOgEoLHoeOWF>mGieS_EnM0Woo00<007ooOol0
C7oo001kOol00`00Oomoo`0DOol3001?Ool01`00AiA;]U?HEmYKnUOJ009Og006HkeO_EnmGkeS_Enm
0Umm00=oo`00Ool0CGoo002?Ool3001AOol05CmB001;UE?HEmYKnUOJGoaKg6?MGkeS_EnMHkeOG5mm
GeaSOEmLOol0001=Ool008eoo`8005=oo`03@g=7U000009GfP05FoYOg5oLGmaS_@03Gkd00emmGeeO
O@02Ggd01EmMFcaK77oo0000C7oo002:Ool3001COol03d=c@e97U4ng001GfUolFmaOo5_LHmeO_F?M
GkaSW@02Ggd025mLHgeK6ellFa]O?7oo001<Ool008Qoo`800003Ool007oo059oo`93L`09BkE?]UOI
001Oo5_KFo]Kff>m009O_@03GgeOWEmm009OO@07GcaK75/lFaaO?5/LFc`00P00Bgoo0025Ool3001F
Ool2@g<06d^ECkIGfE_K001KfeolFm]SgEnlHmeOO6>MGgeSWEmlGcaK?5llFa]O?5/KGcaFfU[kOol0
001:Ool008=oo`8005Qoo`93L`07CkMGfEOIFm]Oo000Fo/015oM00AOWF>MGgeOO@9O?005FcaO?5ll
GcaK7002F]/015[kE]]Jf`00BWoo0020Ool3001HOol014=b@g=3LdoG0U?H01]GfU_kFmX005nlHmeO
_6>MGgeSWEnMHieK?5llFcaO?5/lGcaK?5[kE]YJneKJF_]FfWoo0000BGoo001mOol30002Ool00`00
Oomoo`1EOol014=b@g=;]T^f0U?H00IKfe_kFmYOg000Gmd3Gid01V>MGieOG5mLGeeK?0=O?0AJn`07
E]]Jfe[KF_]Ffgoo0000B7oo001kOol2001LOol05d=cAg=;UE?IDmQKneOJFo]Og5oMGm`005nMHkeO
WEmMGcaOGE/lGeeO?5mME]/00e[k00YFfe[kE]YJneKJF_]FVEJjOol004Qoo`00?Goo10001Goo0P00
1Goo10009goo0`00GGoo0T=c00I;]U?HDmQKne_KGmd3Gm`01F>mGid005nmGed00emL00EOGEllGeaJ
ne/K00IJn`9F^P06EYYF^UJjE[Yoo`00Agoo000lOol00`00Oomoo`02Ool00`00Oomoo`02Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`0ROol200000goo001oo`1LOol2@g<05TNDDmQ?]e_jEmUOo5_L
GoaOWF>mGieS_@00GgeOG5mmFcaOGEllFaaJne/L0U[k00]Ffe[kF_]JneJiE[YFVEJjDYUF^UJI009o
o`03001oogoo04Aoo`00?7oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol07goo0`00Ggoo
0T=c0T^E00E?edngEmYOg5ol009Og00:GkeS_EnmGeeOG000GeaOGEmLGed3F_/00e/KF_]Jn`03F_/7
E[X01EJJE[YF^Woo0000AWoo000lOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0MOol2
001QOol07DND@g=;UDngDmQGfEolFmaOo5_LHkeO_F?MGkeSOEmLGgd005mmGeaO75/KGaaJne/LF_]K
75[kFa`00UJj00YF^EJjE[YF^U:IE[YFVEJjDYUF^P9oo`03001oogoo04=oo`00?7oo00<007ooOol0
0Woo00<007ooOol02Goo10007Goo0`00HWoo00e7M4=cBiE?]doGDmUKne_KGoaO_F>mGkeS_@05Ggd0
1@00Fa]K75/KFa`00U/K0e[k00=FfUJjE[X01UJj00=FVUJjE[X00U9i00Aoo`00000004Aoo`00?7oo
00<007ooOol00Woo00<007ooOol02Goo00<007ooOol077oo0P00I7oo01m7U4=bAiA;UTngDmQOo5_K
GoaO_6?MGkaSgEmlHgeOG6=mGgaO?000GaaK6elLF_]O75/KF]YF^U[KE[YJfP04E[X02EJiE[YF^UJI
DWQFVE9iEYUBN002Ool00`00Oomoo`12Ool003aoo`03001oogoo009oo`03001oogoo00Uoo`03001o
ogoo01Uoo`<006Aoo`0:@g=7M4=cAiA;]UOIDmUKne_KHmd3Gmd00f?MGgeOW@02Ggd015/LGcaK7000
0U/L00=K6e/LE]X00eKJ0eJj00=FfUJjE[X00UJj00=BNE:IDWT01E9i0goo00<007ooOol0@Goo000m
Ool4000<Ool5000DOol3001VOol0<4=dAiE3LdnfDmQGnE?HGoaKff?MGkaSgEnlHieOOF>MGgaSWE/K
GcaK6ell001O?5/KF]]F^U[KE[YJfeJjF]YF^U[KE[YJfU9iEYUBNEJIDWUFVE9iEYUBN5JIDWUFV@=o
o`03001oogoo041oo`00I7oo0P0000=oo`00Ool0IGoo0dND00a;UE?HDmQCf5_kFmYOgEoLGmeOWF>M
Ggd2Gid02F>MFcaO?5/LGcaK7000FaaJf`03E]X03E[KE]YFfUJjE]YF^UJIDYUFVE9iDYUBNEJI00MB
N@=oo`03001oogoo041oo`00HGoo0`00JGoo0393M4=c@g=;]DngDmQGfU_kGmaSoEoLGmeOWF>mGgeS
WEmlGeeK?5llFcaO?5/KGc`005[kE]YJfeJjF]]F^U[KE[YJfe9iEYUBNEJJDWUFVE9iEYUBNEJIDWUF
VE9iEYU>F59h17oo00<007ooOol0?goo001OOol2001ZOol2Ai@2@g<03D^EDmQKne_JGmeOg5oMGmaS
WEnMHkeOWF>M009O?00<FcaO?5llGcaK?5[KE]/005KJF]]Ffe[K0eKJ00eFVE:IEYUBVEJIDYUFVE9i
EYUBNE:IDWUFV@06DUP4Ool00`00Oomoo`0NOol3000MOol005aoo`<006]oo`0]BiI7UD=cBiE;]Dnf
FoYGfEolFmaOo5nMHkeOWF>mGieOGE/lGeeK?5llFcaOGEKKF_]FfU[k001JfeKJF_]FfUJJDYUFVU:I
EYYBVEJJDWUFVE9iEYYBNEJI009BN@07DUQBN4iHDWQ>F59hCUP017oo00<007ooOol07Goo00D007oo
Oomoo`0001aoo`00FWoo0P00KGoo00=7UD=c@g<00TND00=?]eOjGm`00UoL00EOo5nmHkeO_F>m00=O
G003GeeOG5mL009Jn`0:F]]Jne[kF_]FfP00E]]JfeJIEYX2EYT02E:IEYUFVEJIDYUFVE:IEYUBV@02
DUP00e9hDUQBF006DUP5Ool00`00Oomoo`0LOol00`00Oomoo`0NOol005Moo`<006ioo`0iBiI3Ld=c
AiA;UEOIGoaKg5olFmaS_EnmHkeO_F>mGeaOOE/lGeeO?5/LF_]K75KKF_]FfU[kE]]Jn`00E[YBVEJj
DYUF^U:IEYYBVEJJDYUFVU9iEYYBF59iCUQBNE9HDWQ>F59iDUQBN4iHDWQ>F59h00=oo`<001eoo`03
001oogoo01ioo`00E7oo0`00Kgoo01A7UDNDAiA3LdNDCkMCf5okFm]Kne_KHkeO_F>mGkeOOEmLGgeO
GEmm25[k00QJfeJjE[X005JIEYYFVEJj15JI00QBVEJIEYUBN59HDWQBF59h0e9H00=BN59HDUP01E9H
1Goo00<007ooOol06goo00<007ooOol07Woo001BOol20002Ool00`00Oomoo`1/Ool0?D^FAiE3M4=c
AiA?]U?HGoaKfeolFm]SgEnmHmeOG6=mGeaOOEmLHgeJnelLF_]K75[kFaaJne/LEYUF^U:IE[X005Jj
DYUF^U:IE[YBVEJJDYUFVU9HDWUBF59iCUQBNE9HDWU>F59iDUQBN4iHDWU>=e9HCSMBF4hg00Eoo`03
001oogoo00Moo`@000ioo`D001eoo`00Cgoo0`00LWoo00i;]TND@g=3LdMcDmUCf5okFm]KnenmHmeO
_EoM0Umm00MOG5mmGeeK75/KFaaK6`05F_/4E[X02EJJE[X005JjEYUFVUJIE[YBF002DWP02E9iDUQB
N59HDWQBF59hDUQBN004DUP01ThgCSQ>=e9HCSM>>0Ioo`03001oogoo00Eoo`03001oogoo009oo`03
001oogoo00aoo`03001oogoo01ioo`00C7oo0`00M7oo01a3M4NE?e97U5?HEmUCf5olFm]SgEnlHmeO
_F>MGgaSWEmlHieJnelLF_]O75[kGaaJne/LF_]J^PAF^P0DEYUF^U:I001BVEJjDYUFNE9hDWUBF59i
DUQBNE9HDWUBF59iCUQBN@9BF00:CSMBF4hgDUQ>=e9HCSMBF4hgDUP5Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Oomoo`0]Ool004Yoo`@007=oo`0=BkM7UDNE@g=;UDngDmM?]e_kFmYOgEoLGmd0
1Emm00UO?5/LGcaK6e/LFa]K75/KFa`01UJj00eFVUJjE[YF^P00DWUBN59iDWQBNE9hDWUBF002DWP0
4U9iDUQBN59HDWQ>=e9HCSMBF4hgDUQ>=e9HCSM>>4hgDUQ>=`Ioo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo02eoo`00B7oo0P00MWoo01e?fDNEBkI3LT^eCkMCf5OJFo]Og6?MGmaSoEnMHieO
WF>MFa]O?5/KGcaK6elLF_]O75[kF]]F^U[K00=F^P0TF[YF^UJjDYUF^U9h001BN5IiDWQBNE9HEWUB
F59iDUQBNE9HDWU>=e9HCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9HCSMBF4hg1Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol0;Goo0014Ool4001gOol04DoHAiE3M4=cBiE?]e_jFmYOgEoLGmeO
g6>MGieSWEnMHid00Ull00YK75llFaaO?5/LE]YF^UKJE[YFfPMF^P=BN@0:001BNE9hDWUBN59iDWQB
NE9hDWT2DUP04TiHDUQ>=e9HCSQBF4hgDUQ>=e9HCSMBF4hgDUQ>=dhhCSMBF0Ioo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo02eoo`00@goo0`00N7oo025;]TNEAiE3DT^eBkIGnUOIGoaOg5ol
FmaSWEnMHieOWEmMFcaO?5/lGcaK6ellE[YJfeKJF]]F^U[KE[YJfeJjF[X00UJj00aBN5JIDWUFNE9h
001BN5IiDUQFNE9hDWT2DUP05DhgDUQ>=e9HCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9HCQM>=dhGDSM>
5`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool0041oo`<002]oo`06E_]Fo5Kl
>QXj6CXJB7oo00=?^4^gBkL00T=c00E7U4^fEmUOg5ol009Og004GkeS_EnmHkd7Gc`01E[KE]YJfeKJ
F]/00UKJ00AF^UKJE[YFfP=BN@03EYUBNE9i009BN@06001BNE9iDWUBN59i0U9H00i>F59HCUQBF4iH
DUQ>>59HCSMBF4hhDUQ>=e9H2Dhg1Woo00<007ooOol00goo1000<7oo000mOol3000/Ool03EKlE_]F
o5KKE_`j6CXJ>QTn6RUg:IPUMbVH049oo`0nCkU?]d^gAiA3LdNDEmUGnU_LGoaOWF>mGieS_EnMHkeO
?5mMFcaO?5/lGeeFfU[kE]YJfeKJF]]F^U[KE[YJfeJjEYUBNEJIDWQFVE9iEYUBN5JIDWP0059hEYUB
N59HCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9HCSMBF09>=`0:CQMB>4hgCSM>5e8gCQM>=dhGDSL5Ool0
0`00Ool0000hOol003]oo`<002eoo`9_VP=Fo00:E_]Fo3XJ>QXj6BUh:GLYV2Ug8CI0Ool01ToJBkM7
U4=dAiA?]P9Cf007Fm]OnenmHkeO_F>mGkd00UmL01EOGEmLGeaJfe[kF]]Jne[KF_]FfU[KE]YJfeKJ
F]]BVEJIDWUFVE:IEYT00e9i00IFVE9i0000059HCUP3DUP034iHDUQBF59HCUQBF4iHDUQ>F59HCSQB
F0e>=`Qoo`03001oogoo03Eoo`00>7oo0`00;goo019_^fnJKkY_VUKlE_]Fo5KK?QXj6CXJ>QTYV2Ug
:IPUMb5G8CHlOol015?JBiI?]dNE0T=c02A;]E?HDmQKff?MGkeSgEnlHmeO_EmMGcaOGEmLGeeJne[l
E]YJneKJF_]FfU[kE[YJfeKJEYYBNEJJDWUFVE9iEYUBNEJIDWP300005TiGDUP0059HCUMBF4hgDUQ>
=e9HCSMBF4hgDUQ>=e9HCQMB>4hgDSM>5e8h0Thg00Q>5e8hCSM>=dhGDSM>5dhg27oo00<007ooOol0
=Goo000fOol2000aOol5KiX01EKkE_aFo5KlE_/00cXJ00@YMbUh:GLYV0<Q=SUoo`9?fP03CkU?fD=c
0093L`9Cf008Fo]Kff?MGkeS_EnmHmeOO09OO@03GeeOG5[k00AJn`07F]]Jne[KF_]JfeJIDYT00eJI
00EBVEJIDYUFVE9i00<000ABF005CUP0059HDUQ>F003DUP01DiHDUQBF59HCUP04dhg27oo00<007oo
Ool0=7oo000dOol2000bOol05VnkKiY_^VnJKk]_VVnjE]]Fo5KkE_`j6ChJ>QTj6REg:IPYMb5G7CHQ
EadF=goo00ECfe?LBkQ?fDND0093L`0>EmUCf5_jEmYSgEoLHmeOG6=mGeaSOEmLHgeOG09Jn`03F_aJ
ne[k009Jn`0<E]YJne:IE[YBVEJJDWUFVU:IEYYBNEJI0P0001i>F59iCUQBF4iHDWQ>F59HCUL004iH
DUQ>Ee9HCSMBF4hgDUQ>=e8gCSMB>4hgDSM>5e8hCSMB=dhGDSP2CSL01dhGDSQ>5dhgCQMB=dhG00Uo
o`03001oogoo03=oo`00<goo0`00<Goo1VnJ0U/L00Hn>ShJ?SXn>RVH:GL3:IP00bUg:GPQ=P038CH0
0adf8CIoo`0bOol2Dm`01ToICkU;]TND@g=;U@9?]`08FoYKfUoMGmaOgEnMHieOO0=OO@=K6`IJn`05
EYYFVEJJEYUFVP02EYT00e:IEYT00002000;DUP014iH001BF59H5Dhg0ThG00=>=dhFCQL02Goo00<0
07ooOol0<goo000dOol00`00Ool0000_Ool06g_GMkIgegNfGaaK6elLFa]O75/K?SXj6Shj>QXYV2Ug
:IPQ=RVH9GLYV24f8ELM=R4f7AHQ=P0`Ool06U?KDma?^4oIBkQ?^4NDAi=7M5?GEmYKnUoLHmeOg6>M
GgaSWEmmHieJnelLF_]O75[kGa`3F_/02E[lEYUF^U:IE[YBVEJjDYUF^P0300008E9iDUQBN4iHDWUB
F59hCUQBN4iHDUQ>F59hCUQBF4iG001>=e8hCSMB>4hgDSQ>=e8hCSMB=dhgDSQ>=e8gCQMB>002CSL0
2ThGDSQ>5ThgCQI>=dhFCSM>5Thg2Goo00<007ooOol0<Woo000YOol50006Ool01000Oomoo`00;Woo
00Eg]gOGMkMc^W>i00=K7006Fa]K73hj?SXn6Shj0RVH00DYMbVH8CHQ=RUg00<Q=P<M=P038CIoogoo
02aoo`08DkeCgDoJDm]CfTNEAiA3L`9?]`05EmYKnUoLGmeOO@02Gid01F>MGgeOWE/LGc`00e/K00=K
75/KFa/00UJj00IFVUJjE[YF^UJIEYX300001E9hDUQBN59HDWP02e9H0dhg00<004hgCSL03dhg00=>
5dhgCQH00ThG00I>=dhFCQM>5dhgCQH:Ool00`00Oomoo`0aOol002Uoo`05001oogooOol00005Ool2
0003Ool00`00Oomoo`0ZOol067NfMmMg]W>jKkUc^VnIGaaK6elLFa]O73XJ?SXj6RVH:GLYV2Ug8ELQ
=R5G7CHQE`8Q=P057AHQ=QdF8CLM=P0ZOol075?NDkeGgToJDm];]d^fAiI7U4^ECkICfEOIFmaOo5nM
HkeOO6>MGgeO?5/KGcaK6ellF_]O75[k0UJj00EJfUJIE[YBVEJj00<0000SE[YBF59iDUQBNE9HDWU>
F59iDUQBN4iHDWUBF59hCUQBN4hgDSQ>=e9HCSMB>000DUQ>=e8hCSMB>4hgDSM>=e8hCSMB=`02CSL0
3ThFCSM>5ThgCQI>=dhFCSM>5ThgCQI>=dhFCSL9Ool2000cOol002Yoo`03001oogoo00Ioo`03001o
ogoo00=oo`03001oogoo02Uoo`03MmMg]g>j00=c^@03LkYc^E/L009K7005Fa/n>Shj?SXn6P03:IP0
0bUg8CHQ=P058CH27CH38CHWOol01E>mDmeC_E?KCmX00ToI00A;]TNFAg=;]@9Gf@9Og00=HkeOWF>m
GieS_EnMGcaK75llFaaO?5/LGc`01UJj0`000UJj00UBNE9HDWQBN59iDUQBN59HDWP01e9H00EB>4hg
CSM>=e8h00A>=`03001>=dhg00M>=`03CQM>=dhG009>5`06CSM>5dhGCQM>=dhF0ThG00A>=dhFCQM>
5`]oo`03001oogoo031oo`008Goo1P0017oo00<007ooOol01Goo0P001Goo00<007ooOol09goo01Mg
egNfLkY_^G>jKiUc^VniHeaO>d9K?SY2Fchj;IPYMbVH:GLYV2Ug:IPM=R5G008Q=P0:7AHQEadF8CHM
5R4f7CHQ=b5G9GLSOol08E>oDiiCWdnNEmeCg4oICkU;]T=bAiACfEOiDmUOo5_LHkeOWF>mGieS_E/l
GeaK?5llFa]O?5/KF]]F^U[KE[YJfP030000>UJjEYUF^U9HEWUBF59iDUQBNE9HDWU>F59iDUQBNDiH
DWUBF59hCSMBF4hgDSQ>=e9HCSMB>4hgDUQ>=e8h001B>4hgDSQ>=e8hCQI>=dhFCSM>5ThgCQI>=dhF
CSM>5ThgCQI>=dhFCSM>5ThgCQI>=dhF2goo00<007ooOol0;goo000/Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`0UOol00gOGMkMc^P03LkT02G>jGc]S?5llHc`n>T8j?SY2FP03:IP0124f
:GLYV2VH0b4f00<M=R4f7CH00Qdf00<Q=Qdf8CH00R4f00@QEbEG9ELUMaeoo`ECWP08DmaCgE?LCmU7
UT^f@g97L`9Cf006DkMKne_kHkeO_F>m1ell0UKJ00AJfUJjE]YFfP8000=F^P09DWQBNE9hDWUBN59i
DWQBNE9H00=BN004DUQBN59HDWP3CSL01E8hCSM>=dhgDSP01dhg00<004hgCSL00Thg0dhG00E>=dhG
CQM>5dhg00=>5`06CSM>5ThGCQM>=dhF0ThG00=>=dhFCQL02goo00<007ooOol0;goo000]Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool2000UOol0:GNfNmMg]W_GMkIkeelkHeaO>f=LGc]SG3hj@U/n>T9K
:GL]V2Ug8ELM=RVH:GLQEadf8ELM5R4f7CHQ=QdF8CHM=R5G7CHUMb5G9GLQEbVH9IP06Goo025;GTmO
Bei?Ge?LDmeC_5OMCkU?fD^gCmQ3LdNDCkMCf5_KGo]O_6?MGkeSgEmLHgeK?5mLFcaOGEKJF]]FfU[K
E[X00`000eJj00eFVE9hEWUBF5IiDWQBNE9HDWUBF59iDUQBN@02DUP0;DhgDUQ>=e9HCSMBF4hgDUQ>
=e9HCSMB>4hgDUQ>=e8hCSMBF4hg001>5ThgCQI>=dhFCSM>5ThgCQI>=dhFCSM>5ThgCQI>=dhFCSM>
5ThgCQI>5dhFCQM:5P0<Ool00`00Oomoo`0^Ool002Uoo`05001oogooOol00005Ool00`00Oomoo`08
Ool00`00Oomoo`0QOol04GNfNkIg]WOFMkIgeW>hLkUO?6<lGc]S?5ll@UXn>T8j?SX00bVH1b4f0Qdf
0b4f00<M=R4f8CH00R4f00@UMb5G9ELUE`<YV1Aoo`06Cei?GdmNCem?GTmO15>n0U?K01=;^4nh@g=3
Le?HGo]Kfe_kGkeS_EnmGeeOG5mMGeaOGEmLF]]FfP02F]/3000015KJF]YF^UKJ1U9i00ABN59iDWQB
N@=BN009DWU>=e9HCSMBF4hgCSQ>=e8h00=>=`05DSQ>=dhgCSMB>002CSL02ThGCSM>5dhgCQL004hG
CSM>5dhg0dhG00E>=dhGCQM>5dhg00=>5`05CSM>5ThGCQI>5`03CQH00dhGCQIoo`0;Ool00`00Oomo
o`0]Ool002Yoo`<000Eoo`03001oogoo00Yoo`03001oogoo01moo`0IMkEkeWNfNmMg]W_GLkQgfG>h
MmUc^6=LGc]SG5lk@U/n>T9K?SXYV2Ug;IPQ=R5G7CH00R4f00XQEadF8CHM5R5G7CHQEadf8CLM=P8Q
E`039GLQEbEg008YV0069IPY^BgI<OX]fC7j2Woo00Y6oD/NA_i:oTKmBai;GTmOBeiG_P9C_P0EDkeG
_ToKDma;]dNE@g93Ld^fFoYGfU_jGmaSgEoLGeeOG6=mGeaOGEmL009Jn`<0000TE]YJfeJjF]]F^UJI
DWQFVE9hEWUBN5JIDWQBNE9HEWUBN59iCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9H
0Thg021>5ThgCQI>=dhFCSL004hgCQI>=dhFCSM>5ThgCQI>=dhFCSM>5ThgCQI>=dhFCQM:5ThGCQI>
5dXFCQM>5ThG37oo00<007ooOol0;Goo000bOol00`00Oomoo`0;Ool00`00Oomoo`0NOol01W^fMkIg
eWNfMmIg]P9c^@09MkUc^6MKIe]6Fd9J@U/YV2fH00DYV0@Q=P8M=P048CHM=Qdf7CH38CH29GL28CH0
12EG9GLQEbEG0bVH00LafRgI<OX]fC7J=S/j>`03=S/01D:M?Y`nWCjM@Yd01TKn1E>n0U?K0T^h00I;
]T=cAiEGfU_jEmX2Gmd026?MGgeOOEmmGeeOG5mMF_/30002F]/025KJF]]JfeJIDWUBVE9iEYT6DWT0
4U9hDWUBN59HCUQBF4hgDUQ>=e9HCSM>>4hgDUQ>=dhhCSMB>0A>=`0@CQM>=dhGCSM>5dhgCQM>=dhG
CSL004hgCQM>=dhGCSL3CQL01DhgCQI>5dhFCQL00dhF00E>5dhFCQI>5ThG00=>5P03CQMoogoo00Yo
o`03001oogoo02aoo`00<Woo0P003Goo00<007ooOol077oo02AkeWNfNmMg]W_GMkIgfG>hMmUSFfMl
He]WO49JAW]2FTIk:IP]V2VG8ELYMbVH7CHQEb4f8ELM5R4f7AHQ=QdF8CHM=R5G7CH28EL01bEg8ELU
Mb5G9GLQEbVi008YV00[9IPanRgI<OX]fCXl=S/j>cHk>S`f>d:M?Ya2WCjL@Ye6oD/NA_iCOdmnDim?
OU=oCm]Cg4oKDmY?^DMc@g97U5OJFoYOg6?MGmaSWEmlHgeOO6>MGg`00`000U[k04]FfU[kE]YJfe9i
EYYBNEJIDWQFVE9iEYUBN5JIDWQFNE9hEYU>=e9HCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9HCSMBF4hg
DUQ>5U8gCQM>=dhFDSM>5dhgCQI>=dhFCSM>5Thg001>=dhFCSM>5ThgCQI>=dhFCQM:5ThGCQI>5dXF
CQM>5ThGBQI>5dhFCQM:5ThGCQH03Goo00<007ooOol0:goo000bOol00`00Oomoo`0=Ool00`00Oomo
o`0KOol01GNfMmIg]WOFMkH00W>i00EWO6MKIe]WFfMl009WF`03@UY6Fd9J008YV005;IPYV24f8CHY
V0048CH27CH28CH00adf8CHQ=P028CH39GL01BEG:KPUEbEg8EL00bVH00D]fC7J;MTanRgI008f>`06
>S/f>cHk?Ye2WCjL0SjM00I2WDmnCgm?OU=oCgh3Dmd025>mCmY;]T=c@g9?]U?HEmT3Gm`01F>MGieO
OEmmHgd00P0000=K6e[kF_/015[k0eJI00UBVEJIEYUFVE9iDYUBNEJICUP00e9H011>F59HCUQBF4hg
DUQ>F59HCSMBF4hgDUQ>=dhhCSMBF0A>=`0@CQM>=dhGCSM>5dhgCQM>=dhGCSM>5dhgCQM>=`00CSL2
CQL02ThFCQM>5ThGCQI>5dhFCQM>5ThG0dhF00E>5dhFCQI>5ThG00=>5P]oo`8002eoo`00<Woo00<0
07ooOol03Woo00<007ooOol01goo00=kUGooOol03goo01mg]W_FMkIkegNfNmIg]GOHLkMWO6=KIgaS
FfMlHe]6Nd9JAW/YUbfH:IP]V1df8ELQ=R5G7CHQEadF8CHM5P028CH0125G7AHQEadf0R5G00TUN25G
9GLYV2fi:IP]^BFH:KT00RVH01T]fC7j;MTanSHk>S`f>cXk=S/j?4/NBcm;7T/oBai;?d/NEmeC_E?M
DkeGgDniCmQ;^002@g<02D^eDmQOo5oLGoaOW6>mGieSW@0300000elLF_]O7002F_/07UKJF_]BVEJj
DYUFVU9iEYUBNEJJDWUFVE9hDUQ>F59HCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9HCSMBF09>=`0^CQIB
=dhGCSM>5U8gCQM>=dhFDSM>5dhgCQIB=dhFCSM>5ThgCQI>=dhF001>5ThGBQI>=dhFCQM:5ThgCQI>
5dXFCQM>5ThGBQI>5dhFCQM:5ThGCQI>5dXFCQL=Ool00`00Oomoo`0ZOol0035oo`<0011oo`03001o
ogoo00Eoo`04NiEkUW^E0;H>Ool017NfNkIg]W^g0gNf00EkeWNgMmQg^7OH00=6N`05BY/YV2fH@UY6
F`03:IP38CH01adf8CHQ=R4f7CHQ=Qdf008Q=P068ELQ=R4f8CHUMbEG0bEg00<YV2Vh:IP01C7j00@]
fC7J;MTanPI2_@04Bai;?T/NBch5Dih2Dm`2CkP2@g<01eOIDmQOo5oLHieOWF>M00<00006GcaK75/K
Fa]K75[k0U/K00IFVUJIEYUFVEJJDYT3EYT00e:IEYUBF005DUP034iHDUQBF59HCSMBF4iHDUQ>=e9H
CSMBF0A>=`05CQM>=dhgCSM>5`03CSL02ThGCSM>5dhgCQM>=dhGCSM>5dhg0ThG011>5P00CQI>5dhF
CQM>5ThGCQI>5dhFCQM>5ThGCQI>5`=>5P03CQM>5ThF00=>5Pioo`03001oogoo02Uoo`00<Goo00<0
07ooOol04Goo00<007ooOol017oo00EkUW^ENiH0]@2f00eoo`0`NmIg]W_GMkIk]gNeNmIc]gOHLkMg
f6]kJi]6NTZKAW]:VbVH;KPYV2fH:IL]V24f8ELM=R5G7AHQ=Qdf8CHM5R4f7CHQEb4f9GPUEb5G7CHU
Mb5G9GPQEbfi:IP]^BVH137j018jG3YK>U`jFcYL@[e6gT:m@]e2_DKN@[eC_dnNDkm?WU>oCih2Dm`0
2DoHAiA7LdNEDmM?]eokFm]S_@030000FUllFa]O?5/KGcaJnelLF_]O75JIE[YFVEJjDYUF^U:IE[YB
NEJJDWUBF4iHDUQ>F59HCUMBF4iHDUQ>=e9HCSMBF4hgDUQ>=e9HCSMB=dhGCSM>5e8gCQM>=dhFDSM>
5dhgCQIB=dhGCSM>5U8gCQM>=dhFCSM>5ThGBQI>=dhFCQM:5P00CQI>5dXFCSM>5ThGBQI>5dhFCQM:
5ThGCQI>5dXFCQM>5ThGBOI>5dXFCQM9mPeoo`03001oogoo02Uoo`00:7oo1@0017oo00<007ooOol0
4Woo00<007ooOol00Woo00MkUW^ENiEkUG^F0;H03P0;Ool2LiT03G^gMkIg]WNfNmIg]gOHMkQgf6]k
Ji][Nf^K00=6N`05;KPYV2fH8CH]V002:IP38CH27CH01B4f7CHM=Qdf8EL00b4f00<UN2Eg9GL00REg
00HUEbEg9GLY^BVH:KP5<OX00cYL>U/jG002>U`4@[d00d]NCem?GP03Dih2Dm`01T^hCkQ;]d=cAgA?
]`9Kn`<00003HkeO_Ell009O?005FaaO?5/LGcaFVP03E[X015JJE[YFVEJJ0eJI3E9H00=>F59HDUP0
3Dhg00E>5dhgCSM>=dhG00=>=`0HCQM>=dhFCQM>5ThGCQI>5dhFCQM>5ThG001>5dhFCQM>5ThGCQI>
5dhFCQM>5ThG34hF3Woo00<007ooOol0:7oo000ZOol00`00Oomoo`04Ool2000DOol02`00Oomoogoo
NiEkUW^ENiI[^`0=0;D02Woo03=c^G>HNmMg]W^gMkIkeW>gMmQc]gOHJg][Vf]jJi][NdZKAWY:VdIk
;KPYV2fh8CHQEbVG8ELQ=R5G7AHQ=QdF8ELM5R4f7AHQEadf8ELUMbEh9ELUN2Vh;KTY^2gI:IP]^BVH
;KT0137j01HjFcYL>U/jG3YK>Ua;?TmOBci?Gd/nCem;?U?LCk]Cg4oJDm]3LdMcCkMOn`<0000GHkeO
_6>mGcaOG5/lGeeK6ellFa]JfUJjF]YFVEJjEYUF^UJIE[YBVEJjCUQBN@02DUP08TiHDWQ>F59HCUMB
F4iHDUQ>Ee9HCSMBF4hGDSQ>5dhgCQMB=dhGCSM>5e8gCQM>=dhFDSM>5dhgCQIB=dhGCSM>5U8g0ThG
02=:5ThgCQI>5dXFCSM>5ThGBQI>=dhFCQL004hgCQI>5dXFCSM>5ThGBQI>5dXFCQM9mThGBQI>5dWf
CQM:5ThGBOI>5dXF00moo`03001oogoo02Moo`00:Woo00<007ooOol017oo00<007ooOol057oo00<0
07ooNiD00W^E00IkUV^kJm][f`2f00h8Ool3LiT3MkH03G_FMkIgf7NhMmQ[Nf^KJg][Vf]kJi][NdZK
0096N`03;IP]^2VH00LQ=P<M=P058ELQ=Qdf8CHQE`028CH00bEg9GPUM`03;KT01BVi;KTf6SHK<QX0
1C7j0TKn00Q6gDKnA_i6oT]NCem?GTmO15>n00A?fT^gAiE3L`<00005FoYOg6?MGmeOG003Gc`00emL
GcaO?006E[X01EJJE[YF^UJjEYX00U9H00=BN59HDUP02e9H3dhg00A>5dhgCSM>=`9>5`0HCQI>5dhF
CQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThG001>5dhFCQM>5ThG44hF3goo00<007ooOol09goo
000OOol60005Ool00`00Oomoo`04Ool00`00Oomoo`0EOol02P00NiIkUF_LJk][g6^kJm`0300>27oo
01YcV7>iMkIk]gNfNmIg]W_FMkEkeWNfMmMg]WOGBY]>_4ZKC[`]V2fhAWY:VbVH;KPYV25G0R4f00DM
=R5G8CHQ=QdF008Q=P0V8ELQ=R5G8CHQEadf9GPUMbEh9EL]fBVh;KTY^3HK<QXf6c7j?YdjO3il>W`n
WDKMA_i2gDKnA]e6oT;MDmiC_E>nDkeCfd^iCmU3L`800007FoYGfF?MGmaSgEmLHgd00UmL00YK?5mM
GcaJfeJjF]]F^U[JE[YJfP9F^P1BEYUF^U9HDWU>F59iDUQBN4iHDWU>F59HCUQBN4iHDUQ>Ee9HCSMB
=dhGDSQ>=e8gCQMB=dhGCSM>5e8gCQM>=dhGDSM>5dhgCQIB=dhFCQM:5ThgCQI>5dXFCSM>5ThGBQI>
=dhFCQM:5ThgCQI>5dXFCSM>5ThG001>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>
5dWfCQL?Ool00`00Oomoo`0VOol002Yoo`03001oogoo00=oo`8001Moo`9kU@03Jm][^f_K009[f`04
Jk/03@0>00h6Ool2LiT3MkH02g^gMkIg]WNfNmIg]WOGMkMgefnJKkX00Tjk00A:Vdjk;KP]^0<]V003
;KPQ=R4f008Q=P047CHQ=Qdf8CH27CH01b4f8ELQ=REh8CHQEb4f008UM`039GPY^Bfi008]^@05:KTf
6SHJ=Q/b6P05?W`2A_h01TKMA_i?OTmoCgi?O`9Cg@0ECkT00000001;UEOJGmeSgEoLGgeOG5mmGeaO
OEmLGgeFfU[JE]YJfeKJ00IF^P05DWUBF59hDWQBN@03DUP00e9hDUQBF004DUPDCSL06ThFCQM>5ThG
CQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhF000ECQH>Ool3000WOol002Yo
o`03001oogoo00Aoo`03001oogoo00]oo`04DSIF=eRPG<06Ool02g^EMcIc=GLfLcEkUG]eJm`0300=
00h01Goo04EcV7>iLiUk]gNfNmMg]gNhMkEkeWNfMmMg]WOGKiY_^VnJC[a:VdjlBY/]^BfH;KPM=R5G
:IP]^1df8ELM5R4f7AHQ=QdF8CHM5R5G8CHQEbEg:IPUMbVH9ELUN2Eg9GPY^2gI:KP]^C7j=Q/b6SHK
>W`nWCYl?W`jO3jMCgiCOdmnDim?OU?MDk`00`00038oDTnfBiECf5oLHoaOg6>MGgaSOEmLHgeOG5[k
F]YJneJjF]]FfU[KE[YFNE9hDWUBF5IiDUQBNE9HDWUBF59hCUQBNE9HDWQ>F58hCSMB>4hgDSQ>=e8g
CQMB>4hgDSM>5e8h0Thg03Q>5e8gCQM>=dhGCSM>5ThGBQI>=dhFCQM:5ThgCQI>5dXFCSM>5ThGBQI>
=dhFCQM:5ThgCQI>5dXFCSM:5ThGBOI>5dXF0019mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>
5dWfCQM:5ThG47oo00<007ooOol09Goo000XOol30005Ool00`00Oomoo`0:Ool01eHfDSIF=U8fESIH
X5f000Aoo`9FN009LcIg=WLfMcIkMG^ENgE[f`0<00803P03<Q/b6S8K00=cV@=WF`0=MkMg^7NfNmIg
]WOGMkMgefnJKkY_VVnjKiX00djk00@]V2fh;KP]^0HQ=P0;7CHQ=R5F8ELM=R4f7CHQEb4f8ELUM`02
9GP4;MT00bfi:KT]^@02;KT0138J=QXf6SHK24/N00MCg@00000004niBkM3L`02Ai@2Gm`01UolGgeS
WEnMHieOO@=Jn`08F]]Jne[kF]]FfU[JDWUFN@9BN@07DWQBNE9hDWUBN59iDUP00e9h0U9H00=>=e8g
CSL04Dhg0ThG01A>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThG2dhF00<004hF
CQH04DhF4Goo00<007ooOol097oo000ZOol00`00Oomoo`03Ool20009Ool01e8fEUMB=UHgDSIFEe8f
009HX09oo`0dEWQBN5JILcEg=W<eMcIkMG^ENgEkU@3G00d0]@0><QXf6c8J=Q/b6VMKIeY[NfMKMkQg
Ug_FMkIgegNfMmM_VVnjKiYc^fnJKkY:VdjlBY]>_2fH;KT]V25G7CHQEadf8ELM=R4f7AH28CH072EG
8CHQEb4f8ELQ=RVH9GLYV2Eg;MT]^C7J;KTj>cHK>S/f>cXk?Ya2_CjL@[e77T/OAai;7TLN0`00011?
WU?LCm];]d=cBiECf5olGmaSWEmlHieOO6>MF_]K709Jn`1QF]YJneKJF_]JfUJIDWQFVE9hEYUBF5Ii
DWQBNE9HDWUBF59iDUQBNDhgDSQ>=e9HCSMB>4hgDSQ>=e8hCQMB>4hgDSM>5e8hCSMB=dhGDSQ>5Thg
BQI>=dhFCSM:5ThgCQI>5dXFCSM>5ThGBQI>=dhFCQM:5ThgCQI>5dXFCSM:5ThGBOI>5dXFCQM9mThG
BQI>5dWfCQM:5P00BOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQH04Goo00<007oo
Ool08goo000`Ool00`00Oomoo`06Ool2CSL01UHfDSIF=U8fESIB=P9^mPIFN0=g=P0:LcIkUG]eNiEk
MG^E00l03@2e00h2<Q/00c8JIe]WF`02Ie/00gNhMkMkeP02MkH01gNgMmM_VVnjKiYBg5;K00=Bg0@]
^003;IP]^24f00<Q=P037CHQ=R4f008M=P0;8ELQER5G8ELYV2Eh8ELQ=REh9GLUN005;MT4=S/01T:m
?Ye2WCjM@[dnW@<0009CWP05Dm]Cg4^gBkM3L`02CkH2Fo/01F>mGkeS_F>mFa/00e[k00=K6e[kF_/0
0U[k00ABNEJIDWUFN@=BN@05EWUBN59iDWQBN@03DWP01E8hCSM>=dhgDSL03Dhg0dhG00E>5ThGCQM>
5dhF00=>5`0>CQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5a1>5P03001>5ThF015>5Q5oo`03001o
ogoo02=oo`00<7oo00<007ooOol017oo05]>5dhgCQM>=dhGESMB=UIGDSIF=fkeLaI^mEIhDWQFVEIh
McIc=GLfLcEkUG]eNiEkMG^EKmT03@0<1;H0]CHK<QYWFfMJJg]WFgNhMiMkeWNfNmIg]W_GMkIkeWNf
LmYc^E;LD]]Fo5;K<KT]^37I8CH]^2fH8ELQ=R5G7CHQ=Qdf8CHM5R4f7AHQEb4f9ELQ=RVH9GLYV2Eg
:IPUMbVH;KT]fBfi<MXf>cXk=Q/j>cHk@[dnW0030000NT/nCem;?U?LCk]Cg4niCmY3DToGFmYOnenL
HkeOWF>mGiaO?5/KFaaJnelLF_]K75[kEYUBNEJIDWUFVE9hEYUBN5JIDWQBNE9HEWUBN59iCSMBF4hg
DUQ>=e9HCSMB>4hgDUQ>=e8hCSMB>4hgDSM>5e8hCQI>=dXFCSM>5ThgBQI>=dhFCSM:5ThgCQI>5dXF
CSM>5ThGBQI>=dhFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5`00
CQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQLAOol00`00Oomoo`0ROol002moo`80
00Eoo`0:KmY>=dhgCSM>5dhgDSIF=U8fESH4K_H4EWP2McH03G<fNiEkMG^ENgEkUFoILmY_f@0?00`4
]@2e00AWF`0;MkQg]gNhMkIcVGNfNkMg]WOFMkIgeP03LkT01E;LD]]Bg5;L<KT00Rfh0R4f00@]V24f
8CHQ=P<M=P038ELM=Qdf008QE`088EHQEbVH:IPUN2VH<MXanPH]f@@f>`80000>Bci?Gd]NCem;?U>n
DkeC_ToIAiE3LdnfFm]Kn`9S_@08GkeS_ElLGcaK6ellF_]K6`9Jn`9FV@04DWUFVE:IEYT3DWT02EIi
DWUBNE9iDUQ>=e8hCSMB>003CSL01E8hCSM>=dhgDSL01Thg0ThG00E>5ThGCQM>5dhF00=>5`0<CQI>
5dhGCQM>5ThGCQI>5dhFCQM>5ThG0dhF00E>5dhFCQI>5ThG019>5P03001>5ThF011>5Q9oo`03001o
ogoo025oo`00<7oo00<007ooOol00Woo011_fFojKmU>=dhGCSM>5dhgDSIF=e8fLaI^mG;fK_Ec5P9F
N00BLcEg=W<eMcIkMG^ENgEkUFoILmY_fG?J00`0402e1;H0]F]k0VMK00YgUgNhKgUcVVmiNmMg]W_F
MkIke`=c^@0=LmYBfe;LD]]Fo2fh<KT]^25G8CHQEadf8EL00R4f00DM5R4f7CHUEb5F008Q=P0?8ELQ
=RVH9GPYV2Eg<OX]fC7j;MTjG3YK>U`fFcYL00<0000gA]i;?TmOBci?Ge>mDmiC_DoJBkM?^4=BCmMG
fEOjGkaSgEnlHmeK6ellFa]O?5/KGcaBVEJJDYUF^U:IEYYBNEJIDWUFVE9iEYUBN5JICSMBF4hgDUQ>
=e9HCSMBF4hgDUQ>=e9HCSMBF4hgDSP00Thg04M>5ThgCQI>=dhFCSM>5ThgCQI>=dXFCSM>5ThgBQI>
=dhFCSM:5ThgCQI>5dXFCSM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>
5dWfCQM:5ThGBOH004XFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWf015oo`03001o
ogoo025oo`00;goo00<007oo00000goo0foJ00M>5dhgCSM>=dhGESIB=P06K_H2EWP06GLfLcIg=W]e
NiEkMG^EKmUcfVoILmU_f@0=00l03@2e1;D0]@BeBY]:_6nILiU_VG^g00=g]P03MmIc^G>i00Ac^@9B
g005D]]Bg2fh<KT]^0078CH27CH68EL02REh:IPYV2VH9GPanS7J<OX]fCYL0`0000<jG4;MA]h00d;M
00=C_U>mDkh00U?L00E;]d^h@g=;UEOI00=Sg@0:GmaOG5llGeaK6ellGaaF^UJiE[X6EYT0459iEYUB
VEJICSMBF4hhDUQ>=e9HCSMBF4hgDSQ>=e8h0dhg00IB>4hgCSM>5dhgCQH2CQL00dhgCQI>5`02CQL0
1DhFCQM>5dhGCQH00dhG00A>5ThGCQM>5`=>5P05CQM>5ThFCQI>5`03CQH00dhGCQI>5P0CCQH00`00
CQI>5P0@CQH@Ool3000ROol002moo`8000=oo`0`KoY_fFojKmU_nThGCSM>5dhgCQMFEfkeL_I^mG<F
K_EcnFoHMcIc=GLfLcEkUG]eNiEVef[gI]MkMP4HLmY_f@0=00m:_4ZKB[a6VdZlBY]cVVmiLiYg]W^g
MkIkegNf0W>i00ecfW>iFaaFnc7I<KPafBfh<MT]^36i7CHQE`028CH04QdF8ELM=R4f7AHUEb5F9ELQ
ERVi8CHQEbEg:IPUN2VH;MTanP<0000i>U`jFcYL=U/jG4mnDgm?OU>OCgiCOdnlDme;]dND@g=KnUOI
HmeO_5mMGcaOG5llGeeO?5mLEYUF^UJIE[YFVEJjDYUFVU:IE[YBVEJIDWUBF4hgDUQ>=e9HCSMBF4hg
DUQ>=e9HCSMBF4hgDUQ>=e9H009>=`1;CQI>=dhFCSM>5ThgCQI>=dhFCSM>5ThgCQI>=dhFCSM:5Thg
CQI>=dXFCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThG
BOI>5dXFCQM9mThGBQI>5dWf001:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXF019oo`03
001oogoo00Moo`@001Eoo`009Woo10001Goo00@001iM7UdJG@8NG@9NnP9_fP03CSM>5dhg009>=`I^
mP0;KmQcnFoH5AHDmQDF5?HE5VKGJ]MVe`03NgD20CP02P0=00l03dZLBY]:_4ZKLiU_VG>J0gNf00=g
eWNfLkT00W>i1E/L0c7I0R4f00H]^36i8CHQ=Qdf8CH37CH00b4f8ELQE`028EL4:IP00bEh:IP00002
0000337j<MXanTKnAai6oTLNA_i77TmnCgm?OP9Cg006BkQ;]dNFBiECf5>g0UoL00ISOEmlGeaO?5mL
Gc`2E[X00e[JE[UF^P02E[X00eJiEYUFV@03EYT2DUP034iHDUQBF59HCSMBF4hhDUQ>=e8hCSMBF0=>
=`06DSQ>5dhGCQM>=dhF0ThG00I>=dhFCQM>5dhgCQH3CQL024hFCQM>5dhGCQI>5dhFCQL3CQH01DhG
CQI>5ThFCQL00dhF00E>5dhFCQI>5ThG01E>5P03001>5ThF00m>5Q9oo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo019oo`009Goo00<007ooOol00Woo00<007ooOol00Woo02L007oo6SdNGU[J
G_YNfUkjF]X0eVoICSM>5d^OAgi;WfkeLaI^mG;fKmQcnFoHLoTDmADF5?HE5VKGJ_MVef[GMeEkMWME
NgH1600A4CL00P0?02U:_4ZKLiY_NG>JMkIk]gNfNmMgUg_FMkEkeW>hMmQFne/LF_]K72fh<MTa^37I
7CHQEb4f8ELM=R5G7CHQ=R5G9GLM=R4f8EHUEb5F9ELYV2Vi00<0000B=Q/anSjM>W`nWCYl?Ye6oT/N
A_i;7TKnBai?g5?MCkaCfdoJ0T=c00eCf5oLGoaOG6=mGgaSOEmLHgeF^U[JE[YJf`02E[X0JUJIE[YF
VEJjEYUBF4iHDUQ>Ee9HCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9HCSMBF4hFCSM>5ThgCQI>=dhFCSM>
5ThgCQI>=dhFCSM>5ThgCQI>=dhFCSM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:
5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThG001>5dXFCQM9
mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThG4goo00<007ooOol02Goo00<007ooOol04Woo000UOol0
0`00Oomoo`02Ool01000Oomoogoo0P000Woo1Ukj0P2f00=7OdNOAgh00TMo00e7WfkfK_I_f48j?QTn
>FoH5AHDmQDF5?IZe`02I]L2NgD01WMENgEcf00=0CP03@8E>005BY]:W6nILiY_V@02MkH02WNhMiQg
^7NfNmIc^7OHMkQgf7>h0e/L00@a^37I<MTQEP8Q=P087CHQ=R4f8CHM=R4f8ELUE`DQE`800003:IPa
nS8J00<anP0A?YdnO3il?W`nWDKnAai6oU>nDiiC_U>NCm]7UTMdDmMCf002Gm`00emmHgeOO002Ggd0
1E[KF]YJfeJjF]X015Jj00=F^EJjDUP02E9H00a>F59HCSQBF4hgDUQ>>4hgCQM>=dhGCSL3CQL01Thg
CQM>5dhGCSM>5P9>5`03CSM>5ThG009>5`=>5P05CQM>5ThFCQI>5`03CQH01DhGCQI>5ThFCQL00dhF
00E>5dhFCQI>5ThG01Q>5P03001>5ThF00i>5Q=oo`03001oogoo00Uoo`03001oogoo019oo`009Goo
00<007ooOol00Woo00<007ooOol00Woo03`007ooOomooekJG_YJfUkjG]YNnShI@SXn6D8j?QU2>ShI
MmQc^48j?QU2>ShI@SY_f1DF5?EZmfKGJ]MVeg]fMeEkMWMEMmQce`4h010EF14g5EQ_NG>JKgUO75/K
MkQgUgNhMkEkeWNfMmQc]gOHLkQSG37I=OT2<MT03bfh<MTQ=R5G7CHQEadf8CHM=R4f7CHUMb5G9GLQ
E`030000TR5F:KTYV2Vi<OXb6c7j=Q/jO3jM>W`nWCYl?Ye?WU>oCiiC_TnjDm];^4NDBiE?]U_JGo]O
W6>mGieS_EKJF_]FfU[kE]YJfeJjF]YF^U[KDUQBN4iHDWQBF59hCUMBF4iHDUQ>=e9HCSMBF4hgDUQ>
=e9HCQIB=dhFCSM>5ThgCQI>=dhFCSM>5ThgCQI>=dhFCSM>5ThgCQI>=dhFCSM:5ThGBOI>5dXFCQM9
mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:
5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThG001>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQLD
Ool00`00Oomoo`04Ool4000EOol002Eoo`03001oogoo009oo`05001oogooOol00005Ool3G_X2Fc`0
1U/m@QU2>D8I@SU26@=g^008?QTn>ChI@SYNMW?h5?IZe`=Ve`0:NgEgEG]eNgEgf7?GMmP03@4h5CL3
5CP01ADgGa]O6gNhMiP00WNh00IkeWNfMmQg^7OHGc`3He`01C7I=MTQ=S7I<KP00R4f00PQER4f8CHM
=R4f7CHQ=Qdf0`0000@Y^Bfi:KPY^@<YV08anP0B<QXanS7jBci;Gd/nBcm;?T]OBci;?e>mDme3M4Md
BkEKne_J1F>M0U[k00EJfU[KF]YJfe[J009F^P03DWQBF59h00YBF00@CUQBF59HDUQ>F4hgCQM>=dhG
CSM>5dhgCQM>=dhGCSL3CQL01DhgCQI>5dhGCSL00dhF00E>5dhFCQI>5ThG00=>5P05CQM>5ThFCQI>
5`03CQH01DhGCQI>5ThFCQL084hF00<004hFCQH03DhF57oo00<007ooOol00goo00<007ooOol05Woo
000UOol00`00Oomoo`02Ool01000Oomoogoo0P001Goo045K?5/mFaaO?E/l@SXn6D8j?QU2>W>hMmUc
^7OH?QU2>ShIGWIJEV[gI]MZefKGJ_MgEG]fMeEgf7?GMmQc]gOH00d04A4g5EQK6elLFa]O77NGMkQc
Ug_FMkIgf7>gHeaO>f=LGc]SG5lk=OTafCGi8CHQEbfh8ELQ=R5G7CHQ=adf00<0000T8ELUMb5G9GLY
^2fi:IP]^CHK=S/b6T:n?[e2_Cjm@[i;?TmOBci?Gd/nDme?_DoIAiI3Le_JGo]KfV>mGiaS_EnMFa]J
nelL0U[k07=FfU[kE]YJne9HDWUBF59iDUQBN59HDWQ>F59hCUQBF4iGDUQ>F4hgCQIB=dhGCSM>5U8g
CQI>=dhFCSM>5ThgCQI>=dhFCSM>5ThgCQI>=dhFCQM:5ThGBQI>5dXFCQM:5ThGBQI>5dWfCQM:5ThG
BOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThG
BQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQH004WfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5P0D
Ool00`00Oomoo`03Ool00`00Oomoo`0FOol002Eoo`03001oogoo009oo`05001oogooOol00007Ool0
0e/lFceK?002Fc`00d8i@QU2>@02MkP01G>hMkQg^48j?QT015if0VKG00=ZegMENgD00W]e00McegOH
LmQgf7?G00d1>005Ga/017NHMkQg^7_F0gNf00=gegNgHe`00V=L00EO?6=L<MTefC7I008Q=P048EHQ
=R4f8CH300001adf9GLUEb4f8ELUEb5G008Y^@06;KTY^3Hk=Q/f>cHK1T:m00MCgE>mDme?fe?L@g=;
]@03EmT00f?MHkeSg@07F_/02E[KF]YBNE9hDWUBF59hDUQBN008DUP4CSL044hGCSM>=dhgCQM>=dhG
CSM>5dhgCQM>=dhGCSM>5dhg0ThG00=>5ThGCQH00ThF00E>5dhFCQI>5ThG00=>5P05CQM>5ThFCQI>
5`03CQH00dhGCQI>5P0UCQH00`00CQI>5P0<CQHCOol30004Ool5000DOol001Aoo`80011oo`@000Ao
o`03001oogoo00Moo`0hFceK75lm?QU2>W>hMmUc^7OHLkQgfG>hGWIJEUigFWINMUYFJ_MVeg]fMeEk
MT7gAQQc5W<g0IUgf7>g00h045lLFa]O77NGMkQcUgNhMkIk]gNfNmMg]WOGMkIgeelkHeaO>f=L<MTe
nC7I8ELQ=P<0008Q=P2M7CHQ=b5G9GPQEbEg8ELUMb5G;KTY^2fi:IPf>cHK=S/b6T:n?[e2_DmnDim?
OTmoCk]Cg4=dAiACf5OiGkaSgEnlGcaK6ellF_]O75[kFa]JnelLDWQFNE9HEWUBN59iDUQBNE9HDWU>
F59hDUQBN4iHDSM>5dhgCQIB=dhGCSM>5U8gCQM>=dhFDSM>5ThgCQI>=dhFCSM>5ThGCQI>5dXFCQM:
5ThGBQI>5dXFCQM:5ThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9
mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:
5P00BOI>5dXFCQM9mThGBQI>5dXFCQM:5ThGBQH05Woo00<007ooOol06Woo000COol01000Oomoo`00
5Woo0P002Woo1R8L00EWFfMJ@UXn>T8j00MNMP95m`0>AQQ1mdGgAOMc=W<FLcIc5P6J00d]nRgJ<OYg
V0=g^09[NP03MkIk]gNg00=ge`07Ig][NcGi=OXenCGI<MT00`000R4f00DM=R4f7CHQ=Qdf00<UM`@]
f@0B:KPY^BVi;KTf6cHk=Q/f>cHKCgm?OTmoCgiCg4oKBkI3M4ND0UOI00ES_F?MGaaO?5/K009O700;
GcaK6eIiDWUFVE9iEWUBN59iDWQBN@02DWP0159HDWQBF59h34hg00a>5dhgCQM>=dhGCSM>5dhgCQM>
=dhFCQL3CQH01DhGCQI>5ThFCQL00dhF00E>5dhFCQI>5ThG00=>5P03CQM>5ThF02a>5P03001>5ThF
00A>5P03CQM>5ThG00=>5P03CQM>5Woo01Aoo`03001oogoo01Yoo`004Woo00<007ooOol00Woo00<0
07ooOol057oo00<007ooOol02Goo034R727l9QaW>V]KIcY[Fchj@U/n>T9KFWINMUYFGWMJMW>j@OM6
647gAQQ1mg<gLaIc=g<FNmL1V@1C00danRgI<OX]fC7jJeY_NWNfNmMg]WOGMkI[W6MkJiaWNcXJ=OTi
nP020000YS7I=OTM=R5G7CHQ=Qdf8CLM=R4f8ELUN25G9GPY^BgJ;KT]fSIK>U`fFcYL@]e6oT;nA_i2
gDKn@_iCg4nkCmY3M4NDCkICeeoLHoaO?6=MFa]O?5/KGcaBVEJIDWQFVE9iEYUBN5IiDWQFNE9HEWUB
F59iDUQB>4hgDSM>5e8gCQMB=dhFDSM>5dhgCQIB=dhGCSM>5U8gCQI>=dhFDSM>5ThGBQI>5dhFCQM:
5ThGCQI>5dXFCQM:5ThGBQI>5dXFCQM:5ThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:
5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9
mThGBQI>5dWfCQL004hGBOI>5dXFCQM:5ThGBQI>5dXFCQM:5ThG5Woo00<007ooOol06Goo000BOol0
1P00Ool00000Ool001Eoo`03001oogoo00]oo`0:Ie]WFVMKIeYWFfMJIe/n>T9J?SX4GWH3KkX0447g
AOM5mdHHLaIc=W<FLcIg]WNg0IX0DbgJ;OX]fS7j0f]j00Uk]gNfMmMgef^KIg][NfMkJi/00`0000De
nR4f8CHQ=R5F00@Q=P057CHUN1df8CHUE`029GL5;MT013YK>U`jG3YL14Kn00U?WU>nDki?fD=dAiA?
]UolGm`01UmL1EJI00ABNEIiDWUFV@9BN@04DWQBNE9hDWT>CSL01DhGCSM>=dhgCQL00ThF00E>5dhF
CQI>5ThG00=>5P05CQM>5ThFCQI>5`03CQH01DhGCQI>5ThFCQL06dhF00=>5dhFCQH05dhF00]>5`00
CQM>5ThGCQI>5dhFCQM>5ThG00=>5P03CQMoogoo01Aoo`03001oogoo01Qoo`004Woo00H007oo0000
07oo000EOol2000=Ool0:F]KIcY[FfLjJe]W>T9K?SY2FeYFGWMJMW>jKkYc^VnjAQQ1mdHHLaIc=g<F
LcMg]W_GMkH1VP0c00d]fFmjJeY_NV]JNmMg]W^gMkIkegNfJi`00`0002m[W3Gi>QXenB5G8CHQEadf
8ELM=R4g7CHQ=REg9IPUMbEh8ELUN25G;MXY^BgJ;KTjG3IK>U`fFcYLCiiC_TnNDki;^DoJAiICeeoL
HoaOg6=MGcaSGEmLHeeFVEZj009FV@1kDYUFVU:IEYUBN5JIDWUFVDhgDSQ>=e8hCSMB>4hgDSM>5e8h
CQMB=dhGDSM>5dhgCQIB=dhGCSM>5U8gCQI>5dXFCQM>5ThGBQI>5dhFCQM:5ThGCQI>5dXFCQM:5ThG
BQI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThG
BQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM>5ThG
BQI>5`00CQM:5ThGBQI>5dXFCQM:5ThGBQI>5dXF01Ioo`03001oogoo01Qoo`004Woo00<007ooOol0
0Woo00<007ooOol04goo00<007ooOol03Woo00U:NdZKBY]:VdYk8KXn>T9JGWH01Fnj00]5mdHHLaIc
=W<FLcIc5WNgMkIge`0>0080D`05KgY[NV]jJgYk]`02MkH00gNHMkP0000200001GOFIg][NfMkJi/0
0SGi00<Q=R5G8CH01b4f00HUMbEh9GLanRgj<OX5;MT01D/oBci;?T/nBcl00T/n0U?M00U3Ld^EFoYK
nemlHieSOF>MGg`00eJj00=F^EJjEYT01EJI00ABNDhgCSMB>0=>=`03DSM>=dhg00e>=`05CQM>5ThF
CQI>5`03CQH01DhGCQI>5ThFCQL00dhF00E>5dhFCQI>5ThG01m>5P05CQM>5ThFCQI>5`0ACQH03dhG
CQI>5dhFCQM>5ThGCQH004hFCQM>5ThGCQI>5`03CQH014hGCQI>5ThF5Woo00<007ooOol05goo000C
Ool01000Oomoo`005Woo00<007ooOol03goo021:NTZKBWY:Vafj8M/M^W>jKkYc^VnjLkY_^W>j@OMc
=g<FLcMc5W_GMkIkegNf00h0<`1C03=_NV]JKgYg]TjK0`0004ekeWNfNmM_^W>j>QTn>SXJ8ELenB5G
8CHQEb4f8ELM=R4g7CHQ=adf9GPUMbFH;MXanRgI<OXjO3jM>W`nWCYlBcm7?T/oBciCgDnlBkM3Leok
FmYSWEmlHieOO6>ME[YJfUJjF[YFVEJjEYUJ^U:IEYUBVEJJCSMBF4hgDUQ>=e8hCSMB>4hgDSQ>5e8h
CSMB=dhGDSM>5e8g009>5`1TCQI>5dXFCQM>5ThGBQI>5dhFCQM:5ThGCQI>5dXFCQM>5ThGBQI>5dhF
CQM:5ThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWf
CQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dXFCQM>5ThGBQI>5dhF
CQM:5ThGCQI>5dXF001>5ThGBQI>5dXFCQM:5ThGBQI>5dXFCQLFOol2000HOol001Aoo`8001Ioo`<0
015oo`05BW]:VdZKBY/M^P038KX00eOJEWQFN002EWP037<fLaIc=W<FMkMg]WOGMkIg]gNf00h0<`<0
D`<00005MkQcV7OFMkIgeP03KkX01Shj>QXj6SXJ8ELen@8Q=P068ELM=R4f8CHYV2Eh0R4f00<UN2Eg
9GP00S7j00D]nS7j?YdnWCjL008nW@08Dme?_5?MCmY?fd=cEmQCf0=S_@07E]YJfUJjF]YFfU[JE[T0
0eJj00QF^E8hCSMBF4hgDSQ>=e8h0dhg00=B=dhgCSL01Thg0dhF00E>5dhFCQI>5ThG00=>5P05CQM>
5ThFCQI>5`03CQH01DhGCQI>5ThFCQL06dhF00E>5dhFCQI>5ThG00=>5P05CQM>5ThFCQI>5`03CQH0
0dhGCQI>5P07CQH05dhGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhF001>5ThGCQI>5dhFCQL0
0dhF00=>5dhFOol057oo00<007oo000067oo000SOol50005Ool00`00Oomoo`0@Ool06TZKBWY:VdYj
8MXM^UOj:_iJ^E9GEWQBF5IhDUMc=g<FLcMg]P2fFWMNU`HK1S`03TjKBWX20000^TjKBWYg^G>HNmIg
]W>jKkYc^VnJLkY_^Shj>QTn>R4f8ELQ=R5G8CHQ=adf8ELM=RVH9GPYV2Eg9GPUMc7j;MXanRgI<OY?
OTmoBgi?WdmnCgm?^TNEAiAGf5nlHmeS_6>mF]YNneJjF]YF^U[KE[YJfUJIF[Y>=e9HCSMBF4hgDUQ>
=e9HCSMBF4hgDUQ>=e8hCSMB>4hgDSM>5dhgCQI>5dXFCQM>5ThGBQI>5dhFCQM:5ThGCQI>5dXFCQM>
5ThGBQI>5dhFCQM:5ThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9
mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCSM>
5ThGBQI>=dhFCQM:5ThGCQI>5dXFCQM>5ThGBQI>5dhFCQM:5P00BQI>5dXFCQM:5ThgBQI>=dhFCSM:
5QIoo`8001Moo`009Goo00<007ooOol01Goo00<007ooOol04Goo00I:VdYkBY]:Vb/NFYP3FYT4EWP0
2@2E0;D0U@2eFWMNUeigGYMJM`030003BY/017NhLiQgeWNf1fnj00<j6Shj>QX00R4f00<QEb4f8CH0
0R4f00hM=R4f9IPYV2Eh=Q/b6cHK<QY2gT;M@]i2gD;N0Tmo00I?OToJCmY;^5?HEmP3Hkd5F_/01eKJ
F]YF^U[JE]YBF4iG00=BF004CSMB>4hgDUP3CSL01E8hCSM>=dhgDSL00Thg00I>5ThGCQI>5dhFCQL3
CQH01DhGCQI>5ThFCQL00dhF00E>5dhFCQI>5ThG01]>5P05CQM>5ThFCQI>5`03CQH01DhGCQI>5ThF
CQL00dhF00E>5dhFCQI>5ThG00=>5P0JCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhF
CQM>5ThGCQI>5dhFCQL0009>5`03CSM>5dhG009>5`04CQI>5dhGCQLCOol300000goo001oo`0FOol0
02Eoo`03001oogoo00Aoo`8001Ioo`0@F[UJV5ZiEYQJ^EZHEWQBEeIhDUQFN02EGYMJMejGFWH30000
C00?3?H8eDjKBWYg^G>HMkQg]V<kMkIkeg>hMmU2FT9K?SXQEcXJ?SXQ=R5G8CHQEadf8ELM=R4g7CHY
V2Eh:IPUN3Hk<QXf6c8J@]i2gD;N@[e2gT;MDki?WD=cBiE?]UoLHoaOg5[kF]YNne[jF_]JfU[KE[YJ
fTiGDUQ>=e9HCSMBF4hgDUQ>=e9HCSMBF4hgDUQ>=e9H0Thg075>5ThGBQI>=dhFCQM:5ThgCQI>5dXF
CQM>5ThGBQI>5dhFCQM:5ThGCQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXF
CQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWf
CQM:5ThGBQI>=dhFCQM:5ThgCQI>5dXFCSM>5ThGBQI>5dhFCQM:5ThGCQI>5dXFCQM>5ThGBQI>5dhF
CSL004hgCQI>=dXFCSM>5ThgBQI>=dhF00moo`@000Aoo`03001oogoo01Eoo`009Goo00<007ooOol0
17oo00<007ooOol05Woo0eZI00=JV5ZIEWP015Ih00=NUeYg00000P0000EJMejGMiMgU`Hk0088eP06
MkQcV7NHHaYS>gNf0WNg00UgfG>hLmQ2FT9K@UXQER4f?SX00b4f00HQEb4f8CHYV24f7CH29IP02BVH
<QXf6c8K=Q/b6T;N@]e2gP02Ckh02D^gAg=;UF?LGmaSo5lKGaaO6`06F_/7DUP024iGDUQ>=e9HCSMB
>4hgDUP2CSL02ThFCQM>5ThGCQI>5dhFCQM>5ThG0dhF00E>5dhFCQI>5ThG00=>5P03CQM>5ThF01U>
5P05CQM>5ThFCQI>5`03CQH01DhGCQI>5ThFCQL00dhF00E>5dhFCQI>5ThG00=>5P0JCQM>5ThGCQI>
5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5P9>5`06CSM>5dhGCQM>=`00
0ThG00=>=dhGCQL00ThG00=>5ThGOol02goo0`0027oo00<007ooOol05Goo000UOol00`00Oomoo`04
Ool00`00Oomoo`0GOol025ZiFYQJ^EJHF[UBF5IhDYX30000aUYfGYMJMejGMiIkUgNG0108e@cf2=D8
mV<JHc]S6W_GMkIgfG>hMmUc^49K@UY2Fb4f8ELQ=R5G8CHQEadf8ELM=RVi:IPY^BEh:IPUN2VH<QXf
>c8J=Q/b6U>nCkiCg4nk@gAOg6?lGmaO?5/KGcaK6ellFa]O?59HDWUBF59hCUMBF4iHDUQ>Ee9HCSMB
F4hgDUQ>=e9HCSMBF4hgCQM:5ThgCQI>5dXFCSM>5ThGBQI>=dhFCQM:5ThGCQI>5dXFCQM>5ThGBQI>
5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>
5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM:5ThgCQI>5dXFCSM>5ThGBQI>
=dhFCQM:5ThgCQI>5dXFCSM>5ThGBQI>5dhFCQM:5ThgCQI>=dXFCSM>5ThgBQI>=dhF001:5ThgCQI>
=dXFCSM>5ThgBQI>=`Qoo`<000aoo`03001oogoo01Aoo`009Goo00<007ooOol00goo0P006Goo00EJ
V5ZIFYUJVEZH00<0009B^P04GWMNUeYgGYL4MiL01`0?1S/8eV<KHaYS>f<J009g]`0;MmUc^7?HLmQg
fG>h@U]2FT9K8CHQEP028EL38CH02B5G8CHY^BVH:KTfG3YL=Ua;?`03Aah01T/oCma?g4NE@g=KfP9K
nP07HgaOG5lLGa]O?5lKDWT00U9h0e9H00=BN59HDUP01U9H01A>EdhGCQI>5dhFCQM>5ThGCQI>5dhF
CQM>5ThGCQI>5dhFCQM>5ThG0dhF00=>5dhFCQH06DhF00E>5dhFCQI>5ThG00=>5P05CQM>5ThFCQI>
5`03CQH08ThGCQI>5ThFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>
5dhFCQM>5ThGCQI>5dhF0ThG00E>=dhGCQM>5dhg00=>5`05CSM>5dhGCQL00004CQL01DhFCQM>5dhG
CQH017oo10003goo00<007ooOol057oo000SOol30006Ool00`00Oomoo`0HOol0AU>N00000000DiiF
^e:JE[]BVUJkFWMNUgNFNiMgUg^GMiIkU`0?Hc]S6V<kHaYS>gNfNmMc^7OIBY]:_4ZKBY`Q=T9K@UXQ
Eb4f8ELQ=R5G8CHQEadf8ELYV2Vi:IPY^CHk>U`fFcYL=S]Cg4nlDma;^4=dFmYKnUmLHgeOG6=mGeaS
OE9hEWUBN5Ii0U9h08UBF59iDUQBF4iGDUQ>F59HCQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThGBQI>=dhF
CQM:5ThgCQI>5dXFCSM>5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWf
CQM:5ThGBOI>5dXFCQM:5ThGBQI>5dXFCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dhF
CQM:5ThgCQI>5dXFCSM>5ThGBQI>=dhFCQM:5ThgCQI>5dXFCSM>5ThGBQI>=dhFCQM:5ThgCQI>=dXF
CSM>5ThgBQI>=dhFCSM:5ThgCQI>=dXFCSM>5P00BQI>=dhFCSM:5ThgCQM>=goo00<001=oo`03001o
ogoo01Aoo`009Goo00<007ooOol017oo00<007ooOol05goo0P000Woo0e>N0U:j00AF^e:jGYMNM`Ig
U`0501003f<kHaYS6`02MkL017=iLiUgegOG14ZK00DQ=R5F@UXQEb4f00<QE`<Q=P0D8ELYV2Vi:IPj
G3IL>Ua;OdmoBgi?Od^i@g=KfU_jGeaSO5mLHeaOG09FV@07DWUBN5IiDWQBNE9HDWP01E9H0dhG01A>
5ThGCQM>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThG6dhF00E>5dhFCQI>5ThG00=>5P05
CQM>5ThFCQI>5`03CQH01DhGCQI>5ThFCQL00dhF00=>5dhFCQL00ThG01=>5ThGCQI>5dhFCQM>5ThG
CQI>5dhFCQM>5ThGCQI>5dhFCQM>5P04CQL01DhgCQM>5dhGCSL00dhG00E>=dhGCQM>5dhg00=>5`05
CSM>5dhGCQL00002CQL2CSL014hGCSM>=dhg5Woo00<007ooOol057oo000[Ool2000FOol30005Ool0
:2WJ;OXYfUJkDYYF^e:J@QTmn48I?OQ26Cgh6]/FfRVi00mS>f<JNmMcNG>IKgQgegNgMmM:VdZlBY/Q
Eb4f9ELQ=R5G7CHQEb4f;MXY^BgJ0RVi0:<YV2Vi:IQ?Od]nCim;OT_IBkQCedngHkeSW6NmHiaS_E9i
EYUBNEJIDWUFNE9hEWUBN5IiDUQBN59HDWU>5ThgCQI>=dhFCSM>5ThgCQI>=dXFCSM>5ThgBQI>=dhF
CQM:5ThgCQI>5dXFCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWf
CQM:5ThGBQI>5dXFCQM:5ThGBQI>5dXFCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCSM>5ThgBQI>=dhF
CQM:5ThgCQI>5dXFCSM>5ThGBQI>=dhFCQM:5ThgCQI>5dXFCSM>5ThgBQI>=dhGCSM:5ThgCQM>=dXF
CSM>5ThgBQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThgBQM>>000CSM:5dhhCQM>=dXGCSQ>5`0FOol00`00
Oomoo`0DOol002]oo`03001oogoo019oo`<000Qoo`04;OX]fRgj;MX3KiX023gh?QPmn48I?OQZn6Kh
6]/4:IP00g=iLiUcN@05MmL2BY/01b4f8ELQ=R5G8CHQEb4f008QE`05;MTY^BgI;MTn_@03?Yd03Cjm
?Ye?_TnmDmMSW6>mHieS_F>LE[YF^EJj00AFV@05DWQBNE9hEWUBN002CQL01ThgCQM>5dhGCSM>5P=>
5`0<CQI>5dhGCQM>5ThGCQI>5dhFCQM>5ThG6dhF00E>5dhFCQI>5ThG00=>5P05CQM>5ThFCQI>5`03
CQH01DhGCQI>5ThFCQL00ThF0ThG00E>5ThGCQM>5dhF00=>5`0?CQI>5dhGCQM>5ThGCQI>5dhFCQM>
5ThGCQI>5dhF009>5`07CSM>5dhgCQM>=dhGCSL00dhG00E>=dhGCQM>5dhg00=>5`06CSM>5dhGCQM>
=dhG1Dhg00<004hgCSL00dhg00=>5dhgOol05Goo00<007ooOol057oo000[Ool00`00Oomoo`0?Ool3
000<Ool00bgj:MX]nP04KiX0<Sgh@QTmn6[hI_M[600b6]/YV2Vi:IQcVFmhLiUg]gOGLkIG75Kl8EM:
VbEG8CHQEb4f9ELQ=R5G7CHQEbVi;MXY^BgJ:KTn_CZM?[e?_Dnn@g=Cef?LHoaOg6?lEYUJ^UJIF[X2
EYT0TE9iEYUBNEJIDWQFNDhFCSM>5U8gCQI>=dhFCSM>5ThgCQI>=dhFCSM>5ThgCQI>=dXFCSM>5ThG
BOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM:5ThG
BQI>5dXFCQM:5ThGBQI>5dXFCQM:5ThGBQI>5dXFCQM:5ThGBOI>5dXFCSM:5ThgCQI>=dXFCSM>5Thg
BQI>=dhFCQM:5ThgCQI>5dXFCSM>5ThGBQI>=dhFCQM:5ThgCQM>=dXFCSM>5dhgBQI>=dhGCSM:5Thg
CQM>=dXFCSM>5ThgBQI>=dhFCSM:5ThgCQM>=dhGCSQ>5dhgBQM>>000CSM:5dhhCQM>=dXG01Ioo`03
001oogoo01Aoo`00:goo00<007ooOol037oo0`003goo00<]fRgjKiX016nJ00Q26Cgh?QQVn6[hI_QZ
n00b0RVH00=cVG=iLiT00WOG1EKl00@QEdZK8EHQ=PDQE`058CHQEbgI;MTY^@02;MT01DnnCke;fT=c
Ho`00f?L00QJfe[JF]YF^EJjE[UF^UJi15JI00E>=dhGCSM>5dhg00=>5`06CSM>5ThGCQM>=dhF0dhG
00A>5ThGCQI>5a]>5P05CQM>5ThFCQI>5`03CQH01DhGCQI>5ThFCQL00dhF00I>5dhFCQI>5ThGCQH3
CQL01DhFCQM>5dhGCQH00dhG00E>5ThGCQM>5dhF00=>5`05CQI>5dhFCQM>5P02CQL03DhgCQM>=dhG
CSM>5dhgCQM>=dhGCSM>5dhg00=>5`05CSM>5dhGCQM>=`03CQL>CSL01000CSM>=dhG0dhg00=>5goo
Ool04goo00<007ooOol057oo000ZOol2000;Ool3000COol7KiX03d8II_M[66KhJ_QVm`0c039cVFmh
LiUcNGOGMkMgf002E_`0VE;lEa`Q=R5G8CHUEb4f8ELQEREG;OXb6bgjAam2oTLO@_i77d;nCm]3Lf?l
HmaJne[JF_]JfU[kF]YJ^UJIF[YFVEZjCQMB=dhFDSM>5ThgCQIB=dhFCSM>5U8gCQI>=dhFCSM>5Thg
CQI>=dhFCSM>5ThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM:5ThG
BQI>5dXFCQM:5ThGBQI>5dXFCQM:5ThGBQI>5dXFCQM:5ThGBQI>5dXFCQM:5ThgCQI>=dXFCSM>5Thg
BQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThGBQI>=dhFCQM:5ThgCQM>=dXGCSM>5dhgBQI>=dhGCSM:5Thg
CQM>=dXFCSM>5dhgBQI>=dhGCSM:5P02CSL06DhhCQM>>4hgCSQ>5dhhCQM>>4hGCSQ>5dhgCQM>>4hG
CSM:5`00CQM>=dXGCSQ>5dhg01Ioo`03001oogoo01=oo`00:goo00<007ooOol01Woo0`006Woo00Xf
6SGi=OYVn6[hI_QZn6KhJ_QVn0@0<P9:NP03MmMg]eKl00=Fo0058ELQER5G8CHQEP048EL02c7j<O/]
nTLN@_i77T^jBmY7U5_iFmT00UlK00UJfe[JF]YJfU[KF]YF^UJiDSL01Thg00I>5dhgCQM>=dhGCSL3
CQL01DhgCQI>5dhGCSL05dhF00E>5dhFCQM>5ThG00=>5P05CQM>5ThFCQI>5`03CQH01DhGCQI>5ThF
CQL00dhF00E>5dhFCQM>5dhg00=>5`03CSM>5ThG009>5`05CQI>5dhGCQM>5P03CQL01ThFCQM>5dhG
CQI>5`9>=`0DCQM>=dhgCSM>5dhgCQM>=dhGCSM>5dhgCQM>=dhGCSM>5dhgCQM>=`=>5`03CSQ>=dhg
01=>=`04001>>4hhCSL3CSPEOol00`00Oomoo`0COol002Yoo`03001oo`0000Eoo`8001eoo`0D=OTj
6SGi>QYVn6[hI_M[66KhJ_Q:FDijBUU>NTYIMmQg]gOGMkMG709Fo0068CHUEb4f9GPQEbEG0R5G0:/Q
ES8K;OXb6bgj<Q];OT]o@g=KnUlKGcaO6ellGa]Jne[JF_]JfU[kCQMB=dhgDSM>5e8gCQMB=dhFDSM>
5ThgCQIB=dhFCSM>5U8gBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9
mThGBQI>5dXFCQM>5ThGBQI>5dhFCQM:5ThGBQI>5dXFCQM:5ThGBQI>5dXFCQM:5ThGBQI>5dXFCQM>
5ThgBQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThgBQI>=dhFCSM:5ThgCQI>=dXFCSM>5dhgBQM>>4hGCSM:
5dhgCQM>=dXFCSM>5dhgBQI>=dhGCSM:5ThgCQM>=dXFCSM>5dhhCQM>>4hgCSQ>5dhhCSM>>4hGCSQ>
5dhhCQM>>4hGCSM>5dhhCQM>=dhGCSQ>5diHCSL004hgCSQ>=diHCSL05Goo00<007ooOol04goo000Z
Ool20003Ool3000POol01CGi=QXenCGj=OT00SnM00=FN0SF;eP00dYj00MgegNgMkMSO6MlHg`QE`02
E_`0124f8ELQEREh1B5G14]o00=7UT=cFoT00elK00UO?5lKGa]O6e8gCSMB=dhgDSL00dhg00=B=dhg
CSL00Thg00A>5dhgCQM>=`=>5aY>5P0;CQM>5ThGCQI>5dhFCQM>5ThGCQI>5`03CQH01DhGCQI>5ThF
CQL00dhF14hG00E>=dhGCQM>5dhg00=>5`03CSM>5dhG009>5`05CQI>5dhGCQM>5P03CQL00dhFCSM>
=`05CSL01DhGCSM>=dhgCQL00dhg00U>5dhgCQM>=dhGCSM>5dhgCQL00Thg00E>>4hgCSM>=dhh00=>
=`03CSQ>=dhg00m>=`=>>005001>>4hhCSQ>=`02CSPDOol00`00Oomoo`0COol0021oo`D000Eoo`03
001oo`00008002=oo`0L>QXenCXJ?ga3WE9GEWQBEeIh1=I>NTYIMmQg]fMlHe]WO6=LIg`Q=REG8CHQ
Eb4f9ELQEbEh8EL3=U`0OcHk=U`fG4oM@g=WWF=lHieO6ellGa]O?4hgDUQ>=e8hCSMBF4hgDSM>5e8g
CSMB=dhFDSM>5e8gCQIB=dhFCSM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThG
BOI>5dXFCQM:5ThgCQI>5dXFCQM>5ThGBQI>5dhFCQM:5ThGBQI>5dXFCQM:5ThGBQI>5dXFCSM:5Thg
CQM>=dXFCSM>5ThgBQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThgBQI>=dhFCSQ>5dhhCQM>>4hGCSQ>5dhg
CQM>>4hGCSM:5dhhCQM>=dXGCSM>5dhgBQI>=dhG009>=`0YCUQ>=dhhCSM>>4hgCSQ>=dhhCSM>>4hG
CSQ>=dhhCQM>>4hgCSQ>5dhhCQM>>4hGCSQ>=diHCSM>F4hgCUQ>=diHCSM>F000CUQ>=dhhCSM>F00D
Ool00`00Oomoo`0COol0021oo`05001oogooOol00005Ool2000WOol3?id02EIHEWQFN5IhEUP8mR/h
CWYg]`02IcX01fMlHgaSO6=lIg`QER5G008UV0058CHQEb5g9GPQE`03=U`00d^lBke3L`06Hg`02e9H
DUMBF58gDUQ>=e8gCSMB=dhgDSL01dhg64hF015>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>
5ThG00=>5P04CQM>5ThFCQH2CQL01dhgCQM>=dhGCSM>5dhg00=>5`05CSM>5dhGCQM>=`03CQL00dhg
CQM>5`02CQL@CSL01DhGCSM>=dhgCQL00dhg00Q>5dhhCSQ>>4hgCSQ>=dhh0dhg00E>>4hgCSM>=dhh
00Q>=`=>>003CUQ>>4hh00I>>005CSM>>4hhCSP00003CSP00dhgCSQoo`0BOol00`00Oomoo`0COol0
025oo`03001oogoo00Moo`03001oogoo02Qoo`0EEWQBEeIhDUMFN0CF2?H4eV/jIaU[>VLiJcYSFfMl
He`UEb4f9ELUN2FH008UN01o8ELUN25GCme;_4oMHmaWo6=lHieSO6NMDUQBN4hgDUQ>=e9HCSMBF4hg
DSQ>=e8gCSMB=dhGDSM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWf
CQM:5ThGBQI>=dhFCQM:5ThgCQI>5dXFCSM>5ThGBQI>5dhFCQM:5ThGCQI>5dXFCQM:5ThGBQI>=dhG
CSM:5ThgCQM>=dXFCSM>5ThgBQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThgBQI>>4hgCSQ>5dhhCQM>>4hG
CSQ>5dhgCQM>>4hGCSM:5dhhCQM>=dXGCSM>5dhgBQL00Thg02i>>4hgCUQ>=dhhCSM>F4hgCSQ>=dhh
CSM>>4hgCSQ>=dhhCQM>>4hgCSQ>5diHCSQ>F4hgCUQ>>4iHCSM>F4hgCUQ>=diHCSM>F4hgCUQ>=diH
001>F4hgCSQ>=a=oo`03001oogoo01=oo`008Woo00<007ooOol01goo0P00:Goo00=FN5IHEWP00UIh
00<8eVLjIcX00fLj00=_^REG8EL00V=l00<UEb5F9IP00RFH00PUN3kN?]hngSjn?]iSg6OL0f?L1E9H
00QB=e9HDUMBF4hgDSM>=e8g0dhg6ThF01Q>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThG
CQI>5dhFCQM>5ThgCQL3CSL034hGCSM>5dhgCQM>=dhGCSM>5dhgCQM>=`=>5`05CSM>5dhGCQM>>003
CSL00dhhCSM>=`0>CSL00dhGCSM>=`02CSL3CSP01DhgCSQ>>4hhCSL00dhh00A>=dhhCSM>>0=>=`0=
CSQ>=dhgCSM>>4hgCUQ>>4iHCSQ>F4hhCUP00dhh00=>F4hhCSP01Thh00A>=dhhCSP000=>F003CUUo
ogoo019oo`03001oogoo019oo`008goo00<007ooOol027oo00<007ooOol09Woo021BEeIhDUMFN59G
JcYW6F/jIcU[>VnjLm]_^REG8EHUMb4f9ELUN2FI9GPUV3Zm?]hn_TNDHmaWo59hEYUBN5JI0U9h03UB
EeIhDUQBF4hgDUQ>=e9HCSMBF4hgDSQ9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:
5ThGBOI>5dXFCSM:5ThgCQI>5dXFCSM>5ThGBQI>=dhFCQM:5ThgCQI>5dXFCQM>5ThGBQH00ThG01I>
=dhGCSQ>5dhgBQM>=dhGCSM:5ThgCQM>=dXFCSM>5dhgBQI>=dhFCSM:5P9>=`0`CSQ>=dhhCSM>>4hg
CSQ>=dhhCQM>>4hgCSQ>5dhhCQM>>4hGCSQ>5dhgCQM>>4hGCUQ>=diHCSM>F4hgCUQ>=diHCSM>F4hg
CSQ>=diHCSM>>4hgCUQ>=dhhCSM>>4hg0Thh01I>F4hhCUQ>>4iHCSQ>F4hhCUQ>>4iHCSM>F4hhCUQ>
=diHCSM>F4hgCUQ>=`9>F007CUU>F000CSQ>FDiHCUT04goo00<007ooOol04Woo000TOol00`00Oomo
o`08Ool00`00Oomoo`0VOol2EWP00c=k=g/gN`03IcX02fnjKmY_^VoJ8ELUEb5G:MXQEbEG9GP00bFH
00E7Gd=dFmQKnEZi009FN003EWUFN5Ih00IBF004DSMBF59GCQLFCQH2CQL01DhFCQM>5dhGCQH00dhG
00m>5ThGCQI>5dhFCQM>5ThGCQI>5dhFCQM>5ThGCQH01Dhg00E>5dhgCSM>=dhG00=>=`08CQM>=dhG
CSM>5dhgCQM>=`=>5`09CSQ>=dhhCSM>>4hgCSQ>=dhh00e>=`07CUQ>>4iHCSQ>F4hhCUP014hh00E>
=dhhCSQ>>4hg00=>>006CSM>>4hgCSQ>=dhh1TiH00Q>>4iHCUQ>F4hhCUQ>>4iH0dhh00=>F4hhCSP0
1Thh00Q>F4iICUQ>FDiHCUU>F0000diH4goo00<007ooOol04Woo000POol01@00Oomoogoo00002goo
00<007ooOol0:Goo0cWi04m_^W?KKkY_fVnj9GLQEREG8EHYfRViAgm3GTMoAei7U5OHF[YF^EZjE[UF
VE9hEYUBN5JIDUQBN59GEWQ:5ThGBOI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>
5dWfCQM:5ThgBQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThGBQI>=dhFCQM:5ThgCQI>5dXFCSM>5P02CQL0
5ThhCQM>=dhGCSQ>5dhgCQM>>4hGCSM:5dhgCQM>=dXFCSM>5dhgBQI>=dhG0Thg01A>F4hgCSQ>=dhh
CSM>>4hgCSQ>=dhhCSM>>4hgCSQ>5dhhCSM>>4hG0Thh02i>F4hgCUQ>>4iHCSM>F4hgCUQ>=diHCSM>
F4hgCUQ>=diHCSM>F4hgCSQ>=diICUQ>FDhhCUU>>4iHCSQ>FDhhCUQ>>4iHCSQ>F4hhCUQ>>4iHCSQ>
F4hhCUQ>=`9>F00?CUU>F4iiCUQ>FDiHCUU>F4iICUQ>F@00CUU>>4iI01=oo`03001oogoo019oo`00
8Goo0`003Goo0P00:Goo1CWi00ac^REgKmY_^REG8ELUEbVi:MXY^RWJ:KT2FmP01EZjF[UJ^EZiF[X0
0eIh00EFNEIhCQI>5ThG00=>5P05CQM>5ThFCQI>5`0@CQH3CQL00dhgCQM>5`02CQL03dhFCQM>5dhG
CQI>5dhFCQM>5ThGCQI>5dhFCQM>5P09CSL01DhGCSM>=dhgCQL00dhg00I>5dhgCQM>=dhGCSL6CSP0
24hgCSQ>>4hhCSM>>4hgCSP3CSL00dhhCSM>=`05CSL00diHCSQ>F002CUP014hhCUQ>>4iH0dhh00=>
F4hhCSP00Thh00Q>=dhhCSQ>FDiHCUU>F4iI0diH00=>FDiHCUP01TiH00Q>>4iHCUQ>F4hhCUQ>>4iH
24iI00Q>F4iICUU>FDiHCUU>F4iI0TiH00@004iICUQ>F19oo`03001oogoo019oo`00<goo00<007oo
Ool09goo058ef3Wi>OUcfVniLmXUEbEh8EHUMb5F9ELU^BWJ@kY7UUlJHc]O6UZjE[UJ^UJiF[YBN5JI
CQI>5dXFCQM>5ThGBQI>5dXFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCQM9mThGBQI>=dXFCSM>5Thg
BQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThgBQI>=dhFCQM:5ThhCSM>>4hgCSQ>=dhhCQM>>09>=`0kCQM>
>4hGCSM>5dhhCQM>=dhGCSM>5dhgBQMBF4hhCUQ>=e9HCSM>F4hgDUQ>=dhhCSM>F4hgCSQ>=dhhCSM>
>4hgCSQ>=dhhCSMBFDhhCUU>>59ICSQ>F4hhDUQ>>4iHCSM>F4hhCUQ>=diHCSM>F4hgCUQ>=`02CUP0
<4iiCUQ>FDiHCUU>F4iICSQ>FDiHCUU>>4iICSQ>F4hhCUU>>4iHCSQ>F4hhCWU>F4iiCUU>NDiHCWU>
F4iiCUQ>NDiHCUU>F4iiCUQ>FDiHCUU>F4iICSQ>F@00CUU>>19oo`03001oogoo019oo`00=7oo00<0
07ooOol09Woo0SWi00Ac^VnjLmY_^P<UM`0<;S`^G2hl;Ud^?6<KGa]S6elKHa]O6eZj0eZi00E>5dhF
CQI>5ThG00=>5P05CQM>5ThFCQI>5`03CQH00dhGCQI>5P04CQH2CSL024hGCSM>5dhgCQM>=dhGCSL4
CQL01DhFCQM>5dhGCQH00dhG00A>=dhhCSQ>>0=>=`03CSQ>=dhg00Y>=`05CQM>=dhgCSM>>003CUP0
14hhCUQ>>4iH24hh00Q>=dhhCSQ>>4hgCSQ>=dhh0diH00=>FDiHCUP01TiH00Q>>4iHCSQ>F4hhCUQ>
>4iH0dhh00=>F4iICUT014iI00I>F4iICUQ>FDiHCUT3CUP00diICUQ>F003CUP3CWT014iICWU>FDii
24iI00]>F4iICUU>FDiHCUU>F4iICUQ>FDiH00=>N@03001>NDii015oo`03001oogoo019oo`00=Goo
00<007ooOol09Woo05]cfVniLmY_^G?J9ELUN2EG9GP^?39MAiE[_6NkHc]O6V<KGaYS>elJCQM:5Thg
CQI>5dXFCQM>5ThGBQI>5dhFCQM9mThGBQI>5dWfCQM:5ThGBOI>5dXFCSM>5dhgCQM>=dhFCSM>5Thg
BQI>=dhFCSM:5ThgCQI>=dXFCSM>5ThgBQIBF4hgCUQ>=e9HCSM>F4hgCSQ>=dhhCSM>>4hgCSQ>5dhh
CQM>=dhGCSQ>5dhgCQMBF@02CUP04DhhDUQ>>4iHCSMBF4hhCUQ>=e9HCSM>F4hgDUQ>=dhhCSL00TiH
055>NDiHDWU>F4iICUQBFDiHCUU>>59ICSQ>FDhhDUQ>>4iHCSQBF4hhCUQ>=diHCSQ>NDiHCWU>FDii
CUQ>NDiHCWU>F4iICUQ>FDiHCUU>F4iICSQ>FDiHCWY>FDijCUU>NTiICWY>FDiiCUU>NTiICWU>F4ii
CUU>NDiHCWU>F4iiCUQ>NDiHCUU>F4ijCWU>NTiICWY>NDijCUT004iICWX04Goo00<007ooOol04Woo
000fOol2000YOol00bViKkYcfP049GL013LoIkaW_6^l0VNl00Y>5dhgCQI>5dhFCQM>5ThGCQI>5`=>
5P05CQM>5ThFCQI>5`03CQH01DhGCQI>5ThFCQL024hg00A>5dhgCQM>=`=>5`03CSM>5dhG009>5`04
CQI>5dhhCUP4CSP014hgCSQ>>4hh0dhg00=>>4hgCSL01dhg1diH00Q>>4iHCUQ>F4hhCUQ>>4iH1Dhh
0TiI00=>NDiICUT00TiI00A>F4iICUU>F@a>F005CSQ>NDiiCWU>F@03CWT8CUT01TiHCUU>F4iICUQ>
F@9>NP04CWU>NTijCWX3CWT00dijCUU>N@02CWT3CUT00diiCUU>F@05CUT7CWX014iiCWY>NDij0dii
00H004iiCWTl8D0Q?24>Ool00`00Oomoo`0AOol003Qoo`03001oogoo02Moo`0U:KTYV3]O=chkGcLn
JkaW^f_LIk]B=dhFCSM>5ThgCQI>=dhFCQM:5ThgCQI>5dXFCQM>5ThGBQI>5dhFCQM9mThGBQI>>4hg
DSP00Thg05=>5dhhCQM>=dhFCSM>5dhgBQI>=dhFCSM:5ThgCQI>=dXFDUQ>>4iHCSQBF4hgCUQ>=e9H
CSM>F4hgDUQ>=dhhCSM>>4hgCSQ>5dhhCSM>>4iHDWU>F4iICUQBFDiHCUU>>59ICSQ>F4hhDUQ>>4iH
CSMBF4hhCUQ>FE9jCUU>NTiHDWU>FDiiCUQBNDiHCWU>F59iCUQ>FDiHDUU>F4iICSQBFDhh009>F@0a
CWY>NDijCUU>NTiICWU>FDijCUU>NDiHCWU>FDiiCUQ>NDiHCWU>F4iICUQ>VTYiCWY>NDijCWU>NTiI
CWY>FDijCUU>NDiICWY>FDiiCUU>NDiICWU>F4iiCWY>VTYjCYX00Tij01I:NDjJCWU>NTiICWY>NDij
CUU>NTiICWY>F@00CUU08S`Q@28l8D0R?2508PYoo`03001oogoo015oo`00>Goo00<007ooOol09Woo
00DYV2Vi:IPY^BVH009W_003Jka>=dhg00=>=`9>5`05CSM>5ThGCQI>5`03CQH01DhGCQI>5ThFCQL0
0ThF0Thh00A>=dhhCSM>>0Q>=`08CQM>=dhgCSM>5dhgCQM>=`=>F003CUU>F4iH00=>F09>>003CUQ>
>4hh009>>004CSM>>4hhCSP3CSL00diiCUU>N@02CUT014iHCUU>F4iI24iH00I>>4iHCSQ>F4hhCWX6
CWT3CUT00diiCUU>F@02CUT014iHCUU>F4iI0TiH1Tij0dii00=>NTiiCWT00Tii00A>FDiiCUU>N@M>
F@U>NP04CWU>NTiiCWX4CWT01DiICWU>NDiiCWX00djJ00A>NTjJCWY>VPQ>NP05CWU>NTiiCWY>N@03
CY/01DjJ001>Vd0R?2800d0R00<l8T0R@280240R00<007ooOol04Goo000jOol00`00Oomoo`0VOol0
BRFH:KUCfeOLDm]BF59GDSM>5U8gCQMB=dhFCSM>5ThgBQI>=dhFCQM:5ThGCQI>5dXFDUU>F59HCSQB
F4hgCUQ>=e9HCSM>>4hgDSQ>5dhgCQM>>4hGCSM>5ThgCQMBNDiHDWU>FE9ICUQBFDiHDUU>>59HCSQ>
F4hgDUQ>=diHCSMBF4hgCUQ>=e9HCWU>NTiIDWX2CWT0PdiHDWU>FDiICUQBNDiHCUU>>59ICUQ>FDhh
DUQ>>4iHCSQBVTiiCWY>NE:JCWU>NTiIDWY>FDiiCUQBNDiICWU>F59iCUQ>NDiHCY]>NTjJCWY>Vdii
CYY>NDjJCWU>NTiICWY>NDijCUU>NTiICWU>FDiiCUU>NDiHCWU>NTjKBWY>VdijCYY:NDjJCWY>VTii
CWY>NDijCWU>NTiICWY>FDijBYY>VdYjCY]:VTjKBWY>VdijCY]:NTjJCWY>VTYjCYY>NDijBWU>VTii
C[]:VTjkBY]>^dZJCY]:VTjK001>Vc`R@28l8T0R?2908S`Q@28l8T0R?2908S`R@28l8T0R00004goo
000kOol2000VOol00eOLDm]Cg002DUP00e9GDUQBF005CSL02DhFCQM>5dhGCQI>5dhFCQM>F@02CWT0
0e9iCUQ>F003CUP3CSP3CSL00dhhCSM>=`04CSL024iiCWY>NDijCUU>NDiICWT2CUT8CUP3CSP01DiH
CSQ>NTijCYX00Tij14ii00Q>FDiiCUU>NDiHCUU>F4iI1TiH00A>NTjJCWY>VP9>NP04CWU>NTiiCWX6
CWT3CUT01DiiCYY>VdjJCY/00TjJ00A>NTjJCWY>VPI>NP=>N@05CWY>VdjKCY]>^`02CY/014jJCY]>
VTjK0TjJ00=>NTjJCWX01Dij00E>NDijCWY>NTii00M>V`05CYY>VdjKCYY>NP03CYX3CWX01djJCWY>
^djKC[]:Vdjk009>V`05BY]>VdjKCY]>VP03CY/00`00CY]08P05@2800c`R@2908P05@2800goo001o
o`0BOol003eoo`03001oogoo02Ioo`0eDUQBEe9HDSMBF4hGDSM>5U8gCQI>=dhFCSM>5ThGBQIB^djJ
DWU>F59iCUUBNDhhDUU>F59HCSMBF4hgCUQ>=e8hCSM>>4hgD[]>VU:KCYYB^diiDWY>NE:JCUUBNDiH
DWU>F59ICUQBF@02CUP0UDhhDUQ>>4jKCYYBVdjJCY]>VU:JCWU>VTiiDWY>NDijCUUBNTiICWU>F59i
CUQ>FDiHDWU>F4jKCYY>VdjJCY]>NTjJCWY>VTijDYY>NDijCWUBVTiICWY>FE9jBY]>^dZKC[]:Vdjk
BYY>VdjJCY]>NTjKCWY>VTijCYY>NDjJCWU>VTZKC[a:VdjlBY]>_4ZKC[]:VdjkBYY>VdjJCY]:VTjK
CWY>VdYjCY]>NTjJBWU>VTijC[a:VdjlBY]>_4ZKC[]:VdjkBYY>VdZJCY]:NTjKBYY>VdYjCY]>NTjK
BY]>_4ZkC[a:VdjlBY]>_4ZKC[a:VdjkBYY>^dZKC[]:NTjKBYY>V`00@28l8D0R?2508S`R@28l8D0R
?2508S`Q@28l8Goo00004goo000nOol00`00Oomoo`0VOol3DUP00e9GCSM>=`03CSL014hGCSM>5ThG
0U:J00E>VU:JDYYBNDiI009>N@E>F009CSM>>4hhCSQ>_4kLC[a>g4jl009>VP05CY]>VTijCWU>NP02
CWT01TiICWU>FDiiCUQ>F@9>F003C[]>_4jk009>^`05CY]>VTjKCYY>V`03CWX00djJCWY>N@04CWT0
0diICWU>F@03C[/01TjKC[]>^djKCYY>V`9>VP09CWY>VTijCYY>NDijCWU>NTii00=>_006B[]>_4jK
C[]>Vdjk0TjK00U>VTjKCYY>VdijCYY>NTjJCWX00TZl00M>g4ZlB[a>^djlB[]>_002C[/3CY/01Djk
CYY>VdjJCY/014jJ00A>NTZlB[a>_0=:_005C[a:VdjkC[]>_008CY/00djJCY]:_005B[`02TZkC[a:
_4jlBY]>^djKC[]:Vdjk0TjK00Y:VdjKCY]:g4ZlB]a:_000B[`l8PLl8@07@28l8D0R?2508Woo0000
4goo000oOol00`00Oomoo`0UOol0158gDUQBEe9H0U8g051>5e8gCQIC7TkmDae>oE<NCYYB^djJD[]>
FE9iCUQBNDiIDUQ>>59ICUQ?7T[mCai:oDlNC[]Bg4jkC]a>VU:kCYYBVdjJDYY>NE9jCWUBNDiIDWU>
F4kMB]a>gD[LC]e>^djlCY]>_4jkCY]>VU:KCYY>VdiiDYY>NDjJB]a>oD[MC_e:g4kLB[a>g4ZkC[a>
VdjkBY]>_4jJCY]>VTjK0TjJ02i>NTjJCWY>VTZlC]e:_4kMB[a>_4ZkC[a:^djkBY]>^dZKC[]:VdjK
BYY>VdjJB]e:_4kMB]a:gDZlC]a:_4kLB[a>_4ZKC[a:VdjlBY]>^dZKC[]:Vd[MA]a:o@9:g@0fA]a>
gDZlC]e:_4kLB[]>_4ZkC]a:VdjlBY]>_4ZKC[a:VTjkBY]>^dZlB]e:_4[MB[a:gDZlC]a:_4kLB[a>
_4ZKC[a:^djlBY]>_4ZKC[a:Vd[MB]a:gDJlB]e:g4[MB[a>gDZl000h0D0Q0c`Q00M08C`Q?24h0C`Q
?04l8@03Ool00`00Oomoo`0@Ool0041oo`8002Ioo`04DUMBF59HDUP5=gd015<MCaeC7Dkm0e:J00I>
VU:JCWUBNDiICWT5?el02DlNB_e?7T/MC]a>_4kLC[a>g003CYX04DjKCWU>NTiiCWY:oT/NB_i;7T[n
C]e>g4kMB]a>gDjkC[`00Tjk00Y>VTjKCYY>VdjJBai6oTLNA_i;7P=:g@06B_e:gDjlC[a>g4Zl0djk
00A>VdjkA_i77P=6oP05B_e:gD[mB]e:o@03B]`00dkMB[]>_002C[`02DZkC[]>VdjkCY]>^d[mB_i6
g@02B_d00d[MB]a:g@02B]d3B[`034kLB[a>_4jkC[a:^djlA_e:oTKMA_i6o@E:g@04B[a:g4ZlB]`3
B[`02DjlB[a:_4KmA_i6oDKnA_e6oP04B]d01D[LB]e:g4[MB]`01TZl00Y>_4ZkC[a:_4[MA]e:gDKM
B]e6g@E:g@06B[a:g4ZlB]a:_0000cP000Ph0CP0?24l0C`Q?04l8C`10goo00<007ooOol047oo0012
Ool00`00Oomoo`0VOol0P48HASU264Hi@QQ6>E8fDai>oE<MC_eB^djJD[]>VQ;G3[LB]`jf4]L>]a:g
?cm3GcmOCai:oDlNB_e>g4jkD]a>^b/m9ad[?R/M:cdo?d<o?cm3?dKmBai:oD/NA_e;7T[LC]e:g4kM
C[]>_4jKC[`o7T<o?ai3?clNBai6oD/NA_i>oD[LC_e:gDkmB]a>g4ZlC]a:^d<o?ai3?clN@cm6oTLN
A_i;7T[MB_e6gD[nB]e:oDZlC]e:_4kM?ai37clN@alo7TLNA_i77T;nAai6gD[nA]e:oT[LB]e:_4kM
B]a:gCkn@alo7T<O?_i77d;nAai2oTLOA]e:oTKMB_h2B]d0@DKLB_e:gD[MB[a>gDZlC]e2oTLO@_i7
7T;nAam6gD[nA]e:oTKMB_e6gD[mA]e:oDZlB]e:_4[MB[a77d;nAai2oTLO@_i6oTKMB_i6gD[mA]e:
oTKMB_e6_4[MB]a:gDJlB]e2oTLN@_i77d;n000h03`1>00l0C@0>00d03P0=00017oo00<007ooOol0
47oo0013Ool00`00Oomoo`0VOol014HHAQU664HH0VoJ1U8g00=FEUYFESH00UIF00=JETHiFUH00eYF
00QBF58gDUQJEEYFFUEFEe8g0UIG00=NEUYEEUH00eIF0d<o00To?eYFFUIJEUIFEWQJEQ[k6]X00Q[K
00`c?c<n<clc?T<o@am3?d<OBai6oTLNA_h79ad013Lo>clg?cLo14<O00A6oTLNA_i6oPH_7P05>alk
?c/O>cm37P03@al014<N@am6oTLN0TKn00I:oD[nA]e:oC/O>cl3>al00c/o@ai37`02@al00d<NA_i6
oP03A_h02dKmB_i6gDKn>alo7c/O?alk7clO@ah00d<O00]2oTKnA_i6oT;nA_i6oDKnA_e6oTKm00Do
7`05@ai37d<N@am37P03A_h01D;nA_i6oTKnA_d00TKn011:gDKMB]e6gD[M@_i37d<N@am2oT<O@_i6
oT;nA_h000<d00Hh00Aoo`03001oogoo011oo`00A7oo00<007ooOol09Goo04E6>D8HASU[fVoKKmYB
=e8fDUMB=U8gKkUJEeHfFUIF=UYGESIJEUXeFUIJEEYFFSEBF5YEGUIJEEifDSIFEe8fGWIJEEiFESIJ
EeHfFUMF=UifESIJEUHeFUIF=UYFESEJEUYEFUIF=EYFEUMJEUXeGUIJEEYgEUIJMeYEGUIJ=EYgEUIJ
MeIFGUH00eYF00EJMeYFFUIJEEif009JEP1]FUENMUIG7_`Jfakl6]/No2lN;cl_7Rlo>alk?c/O>clB
^QKK4[XFfa:j5]/B^RLN8_dW7R;m<clc7S<o<aho?c/O?clk7clo6]`NoAkL7_`Jg1km:ah_7R[n;ah[
7SLo<ahg?c<N?alk7clo>alo7ckn@alnoT<O;ahc?blN<al_7S<o=alk?cLO>clg7clO>alo7c/O?aln
oT<O?_i37ckn<clc7S<O<ahc?c<N>alg7c/o=alo7c/N?alo7SlO>ai37ckn@alnoT<O@_i77T;nAal0
03@0;0000c0000</0300Ool017oo00<007ooOol047oo0015Ool2000VOol00dHHKmY_fP03KmX3DSL0
0g>iLmYc^@02EUH00eYFESI_F@06FUH01EYEFUIJEEiFFUD00eIG00AJEEiEGUENEP=FEP03GUINEEiE
009JEP03EUIJEUiE00MJEP06FUEJEUYEFUIJEEYG0eYE15YF00=NEUYEFUD015YF00=JEEYFFUH02UYF
00=JMeYEFUH00eYF00AJMeYFGUIJE@9JEP05FWIJEUYFFUEJMP03FUH01EYfFUIJEUYFFWH00eYF00MJ
MeYFFUIJEUYgFUIJM`0:Ool55]/29_d01bLM8_d_7blN;al_7RlO00HB^P<No0037_dNo2/N00@[7P8c
7`05<ahc7c/O>alg7`02>al01RKm8_dVoB;m9_dRo@<_7P0;:ah_7S<O=alc7cLO000T0200900P0007
Ool00`00Oomoo`0@Ool004Moo`03001oogoo02=oo`16JmY_ffoJKmY[fVoKDSIB=e8fLmY_^G?JESIJ
EeHfKeU_F7=IFUEJEUXeFUIZmeiFFUENMUYEGUIJEEIGFUENEUYEGWIJEEYGESIJEeYEGWIJEEYFESIJ
EUYEGWIJEEYFESEJEUYEGWIJ=EiFFUEJEUXeGUIJEEiFFSENEUYEGUIFEUiFFUENEUYEFWL2FUH0<5YE
GUIJEEYFFUENMUYFGUIJEEifFUENEUYEGWIJEEiFFUENMUYEGUIJEUifFUENEUYEGWMJEUYgFUENMUYE
GWIJEUigFUINEUYFGWIJEUifFUINMUYFGWIJEEifFUIJMcYoo`0;1WP:V@Ih2YT6N1KK4[XFf`005]/8
0008Ool00`00Oomoo`0@Ool004Qoo`03001oogoo02Ioo`0;8IU_fVoJDSMcfW>iLmUc^EYFESIFEP03
KeT3FUH02F[hJaQZn5iFFUEJEUYEGUIJE@02GUD01EiFFUENEEiEEUH00eiE00ANEUIFFUIJEP=NE@=J
EP=NE@05FUEJEUYEFUINE@02FUD01EYFFUEJEEYEGUH00eYE00MNEUYFFUIJEUiEFUENE@03FUH00eiE
FUENE@04FUH01EYEFUIJEUYFFUD00UYF015NEUYEFUIJEEiFFUEJEUYEGUIJEEiFFUIJMUYFGUEJEEiF
00=JEP05FWIJEEYFFUINEP02FUI3Ool00`00Oomoo`08Ool00`00Oomoo`0@Ool004Uoo`03001oogoo
02Eoo`188GPUVB5h9IUSffOl0?EcfVniFUI_F7=IKeQ_FEXeFUIJEF/HJ_M[65YEGUIJEEifI]MZeeYE
GWIJEEiFFUENMUYEGWIJEEifFUENMUHeGWIJEEifFUEJEUYEFUIJEEifGUEJEUXeGUINEEifFUENEUYE
GUIJ=EifFUENEUYEGUIJEEiFFUINEUYEGUIJEEif0UYF02QJEEiFFUENEUYEGWIJEEiFFUENMUYEGUIJ
EEiFFUENEUYEGWIJEEiFFUENMUYEGUIJEEifFUINEUYEGWIJEEifFUINMUYEGUIJEEifFUINMTEoo`03
001oogoo00Qoo`03001oogoo00moo`00BWoo0P009Woo00PQV6OlHm]Wo6OKIoaSf`4E1VmI00QJEV/H
J_Q[66[hFUIJEEiF0fKG00INEUYEGUENEEiFI[H2GUD00eiFGUENE@07GUD00eYFGUENE@02GUD00eYE
FUIJE@03GUD3FUD01EYFGUENEEYEGUH00eYE00]NEEYEGUEJEEiEFUEJEUYEGUEJEEiE00=JEP=NE@0L
FUEJEUYFGUEJEEiEFUENEUYEFUINEEiFFUENEUYEGUIJEEiEFUENEUYEGUEJEUYfFUINEEYEGUH3FUI6
Ool00`00Oomoo`07Ool00`00Oomoo`0?Ool004aoo`03001oogoo02=oo`1`IoaSffOlCUQBFDiHDUPe
]cWH=KQ_FFmHLeU_F6/HJ_M[66[gJaQJEEifFUEZefKGJ]QVeeiFFUENMV:fI[MR]UifFUENMUYEI[MJ
EEifFUENMUYEGWIJEEifGUENMUYEGWIJEEifFUENMUiEGUIJ=EiFGUENMUiEGUIJEEiFFUENMUYEGUIJ
EEiFFUENEUYEGUIJEEiFFUENEUYEGUIJEEiFFUENEUYEGWIJEEiFFUENMUYEGUIJEEiFFUENEUYEGWIJ
EEiEFUENMUYEGUIJEEifFUINEUYEGWIJEEifFUE7Ool00`00Oomoo`07Ool00`00Oomoo`0?Ool004eo
o`03001oogoo02Eoo`05DUQ>F4iHCUQBF003=MP02WOHMkQgf7NhJaQZn6/HJ_Q[65YE1FKG00=NEEiF
FUD00fJg0eiE00=V]f:FH[H015iE00=RUUiEGUD02EiE00=JEEYFGUD00eiE0eYE0eiE00=JEEiEFUD0
0eiE00EJEEiEFUENEEYE00=NE@05FUENEEiEFUIJE@03GUD00eYEFUIJE@03GUD00eYEGUIJE@03GUD0
35YEGUEJEEiFFUENEEYEGUIJEEiEFUENETQoo`03001oogoo00Ioo`03001oogoo00moo`00CWoo00<0
07ooOol09Goo06]BF4iHDUU>F3WH=KMgf7>gMmQc]gOHCSM[66[gJaQZmf[GI]MZf6KGJ]MVef[HFUEV
]f:fI]MR]UifFUENMV:FI[MRUUifFUENMV:FI[MRUUifFUENMUiEHYIJEEifGUENMUYEGWIJEEifGUEN
MUiEGUIJEEiFGUENMUiEGUIJEEiFGUENMUiEGUIJEEiFFUENMEYEGUIJEEiFFUENEUYEGUIJEEiFFUEN
EUYEGUIJEEiEFUENMUYEGUIJEEifFUENEUYEGWIJEEiEFUENMUYEGUIJEEif04Yoo`03001oogoo00Eo
o`03001oogoo00moo`00Cgoo0P009Goo00=>F59HCUP00TiH00Dif7NhMmQ>g5;L009>g0EB=`IVe`=V
]`08I[IV]fJgGUIRUV:fHYIV]`=NE@=RUPANE@9RUP]NE@03GUINEEiE009NE@04FUENEEYEGWD2GUD0
0eYEGUEJE@02GUD00eieFUENE@06GUD00eYEGUENE@06GUD00eiFGUENE@02GUD00eYEGUIJE@03GUD0
15YEGUEJEEiFC7oo00<007ooOol017oo00<007ooOol03goo001AOol00`00Oomoo`0SOol054iHDUQ>
F59ICUQBNDiHDWU>g5;lC]aBEdhgDSM>=WMgMeIZefKGJ]P300004VKGH[IV]f:fI]MRUVJgHYIV]f:F
I[MJEFJgHYIRUf:FGWINE@9NMP9RUP0kGWIJEEifGUERUUiEGWINEEifGUENMUiEGWINEEifGUENMUYE
GWINEEieGUENEUYEGUINEEifGUENEUYEGUINEEieGUENEUYEGUIJEEifFUENEEYEGUIJEEiEFUENMUYE
GUEJEEifFUENEUYEGWIJEEiFFUENMP1=Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool0059oo`03001o
ogoo02Eoo`05CUQ>FDiHDUU>F002C]`00e;LC]aB=`02DSL01WMFMgMgEgMg7EQJEP800004I[IV]fJg
I[L2Em`016:FI[MRUV:f1V:F0UiE16:F0eiE0f:F15iE00=NMUiEGUD015iE00ENMEiEGUENEEie00=N
E@03GWENEEiE009NE@05FUENEEiEGWEJE@0EGUD00eYEGUIJE@1>Ool00`00Oomoo`04Ool00`00Oomo
o`0>Ool005=oo`03001oogoo02Eoo`0FCUQBNDiHDWU>F5;mC]aBo4hfDUMgEWMgLeIgMgMFGWIJEEif
FUH006:fFo`3Em`036JgHYIV]f:FIkeRUV:GHYIV]f:FHYMJE@=RUP9NMP04GUENMUifHYH2GWH09UiE
GWINMV:FGWENMUiEGWINEF:FGUENMEiEGWINEEieGUENMUiEGWENEEifFUENMEiEGWINEEiFFUENEUiE
GWENEEiFFUENEEYEGWH2GUD02eYEGWIJEEiEFUENMUYEGUEJEEifFUD0D7oo00<007ooOol00goo00<0
07ooOol03Woo001DOol2000UOol03E9ICUQ>FDiHIm`QN2EhC]aBg58gMgMgEgMg008cE@03FUINMUYF
009JEP04LcIc5T7g@OL2Em`01F:fIiaW_6NLIk`02f:F00ENEF:FHYIRMV:F00=NE@03HYIRMV:F00=N
E@05HYINMV9fGUENM@02GUD00eifGWENE@02GUD01EieGUENEEiEGWD01eiE00ENMEiEGUENEEie00eN
EE5oo`03001oogoo00=oo`03001oogoo00ioo`00EWoo00<007ooOol08goo02IBNFNkJmaW_6OL8GPU
V25hMgMcET>FF[UNfC=E=eIJEUifFUEg=W<FMcIc5T7hGWERMV>LIkeSW6NlHiaV]f:FHYMRUV]KIeYR
UUif0f:F00YNMV:FGWIRUUifHYINEF:FGWERUP9NMP07GUENMUieHYINMEifGUD00Uie015RUUieGWEN
EEifGUERMUiEGWINEEieGUENMUYEGWENEEif009NE@07FUENMUiEGWENEEifFUD00UiE00INMUiEGUEJ
EEifFUECOol00`00Oomoo`02Ool00`00Oomoo`0>Ool005Moo`03001oogoo029oo`9Wg005IkaWg6OL
9IPQN0029GP01UjiF[UJ^EZiG[TcE@9JEP03GWIc5W<f009c=P0:GWERMF9eHWENMFNlIiaW_6NLHYH4
Ie/4HYH00fLJHYIRMP03HYH02F9fHYIRMV:FGWIRUV9fGUENMP02HWH02F:FGUENEEiEHWINMV9fGUEN
M@02GUD00eifHWINE@02GUD01EieGUENEEiEGWD01eiE00ENMEiEGUENEEie00ENEEEoo`05001oogoo
Ool0000@Ool005Qoo`03001oogoo02Eoo`0nJmaW_2FH?gE__6^KG]UJ^EkIF[TgEEYEGWIc5WLfLaIg
=P00HWINEF9fGWERMVkeLaI>5U8gIeY[FfMJIe]WFV]KHYIW>V<IIcYW6F:FGWIRUUifI_UNMF:FGWIR
UUieHYINMF:FGWERUUieHYINEF:FGWERUUieGWINE@9NM@0KHYINMEieGUENMUiEHWINEEifGUENMEiE
GWINEEieGUENMUiEGWEJEEifGUENMEiEGWIJEEiE05Ioo`04001oogoo000@Ool005Uoo`8002Eoo`08
8KTQ^R6jJk][Vf^kF[UN^@=J^@0><eEJEW<fLcH007NgMkP0069eGWERMG;fLaI^m@9B=P9RM@AWF`=W
6P05IaUW6V:FHYIRMP03I_T01EifHYIRMV:FH]P00V9f00=RUUifHWH00V9f00ANMV9fGWIRMP9NE@07
GWIRMUieHWINEEieGUD00Uif00ARMUiEGUENE@9NM@9NE@05GWENEEiEGUENM@03GUD00eieGUENE@1G
Ool01000Oomoo`0047oo001KOol00`00Oomoo`0SOol0@b6IKka[Vf^kJi]__4iHCUU>>59I>MQg=W<F
>OTif7NhLkL005ieHWINEG<FK_Ec5VkeDSMRMFJEHWEVUFkEL_IF=FLjIaUW>V<IIcYNMVKiH_QW6F;h
HYINMF:FH]QVn6;HHYINMF:FGWEVf6:gHYINMF:FGWERUUiEHYINMF9fGWENMUiE009NM@0CHWINMEie
GUENMUieHWINMEifGUENMEiEHWINEEieGUENMUiEGWD0FGoo00<007oo000047oo001LOol00`00Oomo
o`0ROol00f^kJi]>NP02CWX014iiCUQ>F4iI0TiH00Dif3Wh>MQg^7Ng009_fP9RM@05LaI^mG;fL_Ic
5P05HWD2K_D00fkfESIW6P02IaX01FLII_UVnFKiH_T00VKi00IRUV;HH]QRf6KHGWH2HWH05V;HH[QR
f5ifHWINMV9fGWIRMUieHWINMV9fGWENEEifHWINMEifGUENMEiE0Uif00URMUiEGUENEF9fGWENMUiE
GWD00UiEFgoo00<007oo00003goo001MOol00`00Oomoo`0TOol0BDijBWU>NTYIDUU>F4iICSPinCWH
MkQc]fojKmU_nP00HWI^mG<FK_Ec5U>cEkARMFJEHWEVUFkEL_I^eEYFESEVUF9dIYERM6LIH_QVnF;h
IaURf6KhH]QVnF;HI_QNMFKHH[MVf6:gI]QNMF:FGWERf6:gHWINMF:FGWERMUieHWINMF9fGWERMUiE
HWINMF9f009NM@08GUENMUieHWINEEifGUENMEeoo`8000moo`00GWoo00<007ooOol097oo0dij0diH
00A>FDiH>MQg]`E_fP07K_EbmW;fLaI^mENdDk@00f9e00=^mFkfK]D00Vke00EVUF9eIWEVMFJE009^
e@@[>P03H]QVf6;H00=Rf008H[QRf6;HH]QR^69fGWIRMP9R]`07GWIRMUieHWIR]f9fGWD00Uif00IR
MUieGWINMV9fGWD2GWH2GWD00eifGWERMP03GUEMOol2000?Ool005moo`8002Eoo`09CWY:NDijCSQB
FDiHCUTn>T8j008n>P15GYLa^6oIKoY^mG<FK_EFEe9GEkAC/fJEHWEbmVkEL_I^eG;fHWAVUF9dIYER
M6kEJ]ENMUYEIYERM2]JH]QVn6;HCkm;WVKHH[MVf6:gI]QR]f:FH[MR^6:gH]QNMF9fGWER^6:GHWIN
MF9fGWER]eieHWINMF9fGWERMUieHWINEF9fGWERMUiE05ioo`8000moo`00HGoo00<007ooOol097oo
1EZi0chj00=NUf:gGYL00Rfh1EIG0WMF00=RMFkfK]D00Vke00I^mV_gIWEVMFJEHWD3K]D02EYEGUEV
MFJEIWAVUDnNCki;WP02Cih00f;HH[QRf002H]P3H[L016:hH[MRMUif0f:g00MNMV9fGWER]f:GH[MN
M@02GWH0269fHYMNMUieHWINMEifGWEKOol4000AOol0069oo`03001oogoo02Aoo`0<FYUJ^EJIF[UJ
VChjGYMR^5jGH[P]Uc6h0UIG019BEeIhMeEkEWMEJoE^eG;fK]EbmV_GKoQ[efJEHWAVUF[EK_H2K]D0
:F9dIYERM6JEJ[E^eUiEHWENEDnoH[MVf6:gFiiKOE^NH[MRf6:gH[QR]f:hHYMR]ejGH[QNMF:gGYIR
]ejGHWINMF9fGYIR]ejFHWINMF9fGUD0F7oo10005Goo001SOol00`00Oomoo`0SOol5F[T025jGH[MN
Uf:gGYMR]bfH;KP3EUL2MeH01V_EJmA[eFkeK_I^e@9[m`03JoQRMFIe00E^e@06IYEVM6JEIWE^eF[E
0UiE00UNMGooOomKOU^NFgeKWU]nH[P00V:g00=OG5mMGe`01F:g00IRUf:gHYMR]f:GHWH4HYL00eie
GWINM@1EOol4000IOol006Aoo`8002Aoo`0MFgiGGE]nEeeKOUjGH[QNUf:hGYLa^2fGEWQFEg]FMeE[
mF_DJoEWe7;fK]DYMeieKoQ[efJEHWA^mP02K]D02V[EMmURM6JEHWAVUF[EK]ENEF9e1Goo01]KWU]m
FiiKOEmMGeaSGEmLGeeNUf:hHYMS>elKH[MNUf:gGYIR]ejFH[MNUV:gGYIRMUiEHWH0DGoo10007Goo
001VOol00`00Oomoo`0SOol01UMnFgiGGF:gGYMR]`<00003<KP]V5IG009gEP08JmAW_6NlJmE[e2Ug
HWIRUP9RMP03JoM^eFkE009^e@06LmUcf7?HIWEVUF[E0VkE00=NMEiEOol02Goo00iOGEmLGeaOG5mM
H[MS>elkHc]O6f:gHYMR]ekj1V:G00=RMWooOol0C7oo10008Goo001WOol00`00Oomoo`0SOol012XL
;S`Z72hl0VLj0P00010Y^BgJMeEkEVNlJmaW^f_LIk`0]EieHYINMF:FLaAg=@9^e@0;J]E^mW?HMmUc
^6JEHWA^eFZeK]IZe@0<Ool04emMGeaSGEmLHc]O6f<lGa]S>ejFH[MNnV<KG_YR]ejFH[MNUV:g04ao
o`<002Eoo`00J7oo00<007ooOol08goo00<Z?2hlIcX00VLj00D55`Cg000Y^BgI009W_006CSMB=dhg
DSL0M6:F0f9f00=g=GLEMcD00VkE0g?H00=cfFIdIYD00VkE00=ZeFkEOol04Goo00EO6f<kGc]S>ekj
00=S6PARUdUoo`@002Qoo`00JGoo0P0097oo0fLj01m[>VLj2AL4mekJF[UN^FoFDSM>5U8gCQIB=`2D
HYINMGLeMaEg=G<DOomcf7OILkQgfG?HMmUZ]FkFJ]E^e@0GOol01PIfG_YS6ekjHa]NUTMoo`@002ao
o`00Jgoo00<007ooOol08goo0fLj15Zi0Vog00U_ee8gCSMB=dhg07ARMV:FMaD00gLe1goo00A^eF[E
K]E^eAUoo`03G_YS6V<J04Aoo`@0031oo`00K7oo00<007ooOol08goo01=:gDJlB]eJ^EjiF[UcmfoG
KoM>5U8gCQIB=dhF0;Eg5GLeLaAg=@09Ool00fkEJ[Eoo`1LOol4000dOol006eoo`03001oogoo029o
o`03A[a:_DJl009J^@03KoMoogoo009_m`05CSMB=dhgDSL0M003McD00gLEOomoo`07Ool2K]EIOol4
000hOol006ioo`8002=oo`03A[a:gDJl071oo`<003aoo`00L7oo00<007ooOol08Woo00<007ooOol0
JWoo1000?goo001aOol00`00Oomoo`0QOol00`00Oomoo`1VOol40013Ool0079oo`03001oogoo021o
o`03001oogoo069oo`@004Moo`00Lgoo0P0087oo00<007ooOol0GWoo1000Bgoo001eOol00`00Oomo
o`0MOol00`00Oomoo`1JOol4001?Ool007Ioo`03001oogoo01aoo`03001oogoo05Moo`<005=oo`00
Mgoo00<007ooOol06goo00<007ooOol0Dgoo1000EWoo001hOol2000KOol00`00Oomoo`1?Ool4001J
Ool007Yoo`03001oogoo01Qoo`03001oogoo04]oo`@005ioo`00Ngoo00<007ooOol05goo00<007oo
Ool0Agoo1000HWoo001lOol00`00Oomoo`0FOol00`00Oomoo`13Ool4001VOol007eoo`8001Ioo`03
001oogoo041oo`<006Yoo`00Ogoo00<007ooOol04goo00<007ooOol0?7oo1000KGoo0020Ool00`00
Oomoo`0BOol00`00Oomoo`0hOol4001aOol0085oo`03001oogoo015oo`03001oogoo03Aoo`@007Eo
o`00PWoo0P0047oo00<007ooOol0<Goo1000NGoo0024Ool00`00Oomoo`0=Ool00`00Oomoo`0]Ool4
001mOol008Eoo`03001oogoo00aoo`03001oogoo02Yoo`<0085oo`00QWoo00<007ooOol02goo00<0
07ooOol09Woo1000Q7oo0027Ool2000;Ool00`00Oomoo`0ROol40028Ool008Uoo`03001oogoo00Qo
o`03001oogoo01ioo`@008aoo`00RWoo00<007ooOol01goo00<007ooOol06Woo1000T7oo002;Ool0
0`00Oomoo`06Ool00`00Oomoo`0FOol4002DOol008aoo`8000Ioo`03001oogoo01=oo`<009Qoo`00
SWoo00<007ooOol00goo00<007ooOol03goo1000Vgoo002?Ool00`00Oomoo`02Ool00`00Oomoo`0;
Ool4002OOol0091oo`05001oogooOol00009Ool4002SOol0095oo`800003Ool007oo00Aoo`@00:Mo
o`00Tgoo0P0000=oo`0000000P00Zgoo002DOol2002_Ool00001\
\>"],
  ImageRangeCache->{{{0, 324.625}, {231, 0}} -> {-0.150424, 0.0141804, \
0.00445478, 0.00445478}}]
}, Open  ]],

Cell[TextData["\[EmptySquare]"], "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell["\<\
Actually, the family of solutions of the characteristic \
differential equations can be represented in a parametric form by\
\>", "Text",\

  Evaluatable->False,
  CellTags->"characteristic differential equations"],

Cell[BoxData[
    \(TraditionalForm\`x\  = \ x(s, r), \ \ \ t = \ t(s, r), \ \ \ 
    u\  = \ u(s, r), \)], "NumberedEquation",
  Evaluatable->False],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " is the parameter along a characteristic curve and ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is the parameter identifying a characteristic curve equal to a certain \
constant on a characteristic. The essential point of these considerations is \
that the solution of a first-order partial differential equation is \
represented by a family of surfaces ",
  Cell[BoxData[
      \(TraditionalForm\`u - \[CapitalTheta](x, t) = \(const . \)\)]]
}], "Text",
  Evaluatable->False,
  CellTags->{"characteristic curve", "family of surfaces"}],

Cell[TextData[{
  "Now, if ",
  Cell[BoxData[
      \(TraditionalForm\`F(x, t, \[CapitalTheta]) = 0\)]],
  " defines a surface satisfying the first-order partial differential \
equation, then this surface is an invariant of the one-parameter Lie group \
transformation. This is obvious from the condition"
}], "Text",
  Evaluatable->False,
  CellTags->"one-parameter Lie group transformation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            FormBox[\(v\&\[RightVector]\),
              "TraditionalForm"], \(F(x, t, \[CapitalTheta])\)}], " ", "=", 
          " ", "0"}], ","}], TraditionalForm]], "NumberedEquation",
  Evaluatable->False],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\)]],
  " is the vector field of the transformation given by "
}], "Text",
  Evaluatable->False,
  CellTags->"vector field"],

Cell[BoxData[
    \(TraditionalForm
    \`v\&\[RightVector]\  = \ 
      \[Xi]\_1\ \[PartialD]\_x\ \(+\ \[Xi]\_2\)\ 
        \[PartialD]\_t\ \(+\ \[Phi]\_1\)\ \[PartialD]\_\[CapitalTheta] . \)], 
  "NumberedEquation"],

Cell[TextData[{
  "The result is that the vector field ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\&\[RightVector]\ \)\)]],
  " applied on the surface ",
  Cell[BoxData[
      \(TraditionalForm\`F(x, t, \[CapitalTheta])\)]],
  " delivers  the determining equation for the surface. These facts are \
summarized in the following theorem."
}], "Text",
  Evaluatable->False,
  CellTags->"determining equation of a surface"],

Cell["Theorem: Invariance condition", "Theorem",
  CellTags->"Theorem: Invariance condition"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`F(x, t, \[CapitalTheta])\)]],
  " is an invariant of a one-parameter Lie group transformation if the \
condition"
}], "Text",
  Evaluatable->False,
  CellTags->{"one-parameter Lie group transformation", "invariant"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[\(v\&\[RightVector]\),
            "TraditionalForm"], "F"}], " ", "=", " ", "0"}], 
      TraditionalForm]], "NumberedEquation",
  Evaluatable->False],

Cell[TextData["is satisfied.\[ThickSpace]\[EmptyCircle]"], "Text"],

Cell["\<\
This condition always results into a first-order partial \
differential equation independent of the number of dependent and independent \
variables. The equation is solvable by applying the method of \
characteristics. We demonstrate the application of the theorem by an example.\
\
\>", "Text",
  Evaluatable->False,
  CellTags->"method of characteristics"],

Cell["Example 2", "Example"],

Cell["\<\
Let us apply the theorem for a subgroup of the heat equation. The \
symmetry we will examine is connected with the scaling symmetry\
\>", "Text",
  Evaluatable->False,
  CellTags->{"heat equation", "scaling symmetry"}],

Cell[BoxData[
    \(\(xi[1]\)[x, t, u] = x; \n\(xi[2]\)[x, t, u] = 2\ t; \n
    \(phi[1]\)[x, t, u] = c\ u; \)], "Input",
  PageWidth->Infinity],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is an arbitrary parameter. The invariance condition (5.44) now reads"
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(invar = 
      \(xi[1]\)[x, t, u]\ \[PartialD]\_x F[x, t, u] + \n\t\t
          \(xi[2]\)[x, t, u]\ \[PartialD]\_t F[x, t, u] + \n\t\t
          \(phi[1]\)[x, t, u]\ \[PartialD]\_u F[x, t, u] == 0; 
    invar // \ LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(2\ t\ F\_t + c\ u\ F\_u + x\ F\_x == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["The solution of this PDE follows by", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(solh = DSolve[invar, F[x, t, u], {x, t, u}]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({{F[x, t, u] \[Rule] \(C[1]\)[t\/x\^2, u\ x\^\(-c\)]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "representing the general solution of the first-order partial differential \
equation. The arbitrary function ",
  StyleBox["C[1]", "MmaText",
    FontSlant->"Italic"],
  " depends on two invariants given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(I\_1\),
            "TraditionalForm"], "=", " ", 
          FormBox[\(t/x\^2\),
            "TraditionalForm"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(I\_2\),
            "TraditionalForm"], "=", \(u/x\^c\)}], TraditionalForm]]],
  ". These two invariants allow the reduction of the heat equation to an \
ordinary differential equation. The reduction procedure itself is based on \
the following theorem."
}], "Text",
  Evaluatable->False,
  CellTags->{"invariants", "reduction procedure"}],

Cell["Theorem: Invariant representation", "Theorem",
  CellTags->"Theorem: Invariant Representation"],

Cell[TextData[{
  "Let the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta] = 0\)]],
  " be invariant under a one-parameter group \[GothicCapitalG] and let the \
infinitesimals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\[Alpha]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, \[Ellipsis], p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1, 2, \[Ellipsis], q\)]],
  ", be non-vanishing functions on the solution surface ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " of the equation. Then, the surface ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " can be represented by equations of the form"
}], "Text",
  Evaluatable->False,
  CellTags->{"invariant", "infinitesimals"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[CapitalPhi]\_k\)(\(I\_1\)(x, u), \[Ellipsis], \ I\_\(p - 1\))\ \  = 
      \ 0\ , \ \ \ \ \ \ \ \ \ k\  = 1, 2, \[Ellipsis], q, \)], 
  "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`I\_1\)]],
  ", \[Ellipsis], ",
  Cell[BoxData[
      \(TraditionalForm\`I\_\(p - 1\)\)]],
  " define a basis of invariants of the group \[GothicCapitalG].\[ThickSpace]\
\[EmptyCircle]"
}], "Text",
  Evaluatable->False,
  CellTags->"invariants of a group"],

Cell["\<\
The use of the invariants allows us to reduce the original \
equation. Let us demonstrate the reduction process by the example of the heat \
equation. The left-hand side of the equation of motion reads\
\>", "Text",
  Evaluatable->False,
  CellTags->{"reduction process", "heat equation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(heat = {\[PartialD]\_t u[x, t] - \[PartialD]\_{x, 2}u[x, t]}; 
    heat // LTF\ \)\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(u\_t - u\_\(x, x\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The two integrals obtained by integrating the characteristic equation are \
",
  Cell[BoxData[
      \(TraditionalForm\`I\_1\)]],
  " = ",
  StyleBox["t",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(/ x\)\^2\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(I\_2\),
            "TraditionalForm"], "=", \(u/x\^c\)}], TraditionalForm]]],
  ". The first integral combines the independent variables in a unique \
variable called the similarity variable ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta] = t/x\^2\)]],
  ". The second invariant, ",
  Cell[BoxData[
      \(TraditionalForm\`I\_2\)]],
  ", combines the dependent variable and one independent variable to the \
similarity representation of the solution ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(u(x, t) = x\^c\),
            "TraditionalForm"], " ", \(F(\[Zeta])\)}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`F(\[Zeta]) = I\_2\)]],
  ". These two relations allow us to define the following rules:"
}], "Text",
  Evaluatable->False,
  CellTags->{
  "characteristic equation", "similarity variable", 
    "similarity representation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = {t \[Rule] \[Zeta]\ x\^2, 
        u \[Rule] Function[{x, t}, x\^c\ F[t\/x\^2]]}\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({t \[Rule] x\^2\ \[Zeta], u \[Rule] Function[{x, t}, x\^c\ F[t\/x\^2]]}
      \)], "Output"]
}, Open  ]],

Cell["Applying these two rules to the heat equation, we get", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(rheat = heat /. rules; rheat // LTF\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{
              \(\(-\((\(-1\) + c)\)\)\ c\ F\ x\^\(\(-2\) + c\)\), "+", 
                \(x\^\(\(-2\) + c\)\ F\_\[Zeta]\), "+", 
                \(4\ c\ x\^\(\(-2\) + c\)\ \[Zeta]\ F\_\[Zeta]\), "-", 
                RowBox[{\(x\^c\), " ", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(\(6\ \[Zeta]\ F\_\[Zeta]\)\/x\^2\),
                        ScriptLevel->0], "+", 
                      
                      StyleBox[
                        \(\(4\ \[Zeta]\^2\ F\_\(\[Zeta], \[Zeta]\)\)\/x\^2\),
                        ScriptLevel->0]}], ")"}]}]}], "\n", "\t", "==", 
              "0"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "representing an ordinary differential equation for ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " depending only on \[Zeta]. The common factor ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(c - 2\)\)]],
  " can be eliminated by division:"
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(rheat = Expand[rheat\/x\^\(c - 2\)]; rheat // LTF\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    TagBox[GridBox[{
          {
            \(c\ F - c\^2\ F + F\_\[Zeta] - 6\ \[Zeta]\ F\_\[Zeta] + 
                4\ c\ \[Zeta]\ F\_\[Zeta] - 
                4\ \[Zeta]\^2\ F\_\(\[Zeta], \[Zeta]\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, we reduced the original PDE to an ODE by utilizing the invariants of \
the group. The merit of this reduction is that the derived ODE is easier to \
solve than the original PDE. Another advantage is that we can use the \
solution procedures discussed in S",
  ButtonBox["ection 4.4,",
    ButtonData:>{"symmet2.nb", 
      "Analysis of Ordinary Differential Equations"},
    ButtonStyle->"Hyperlink"],
  " allowing us to solve the reduced equation. However, in the present case, \
we utilize the capabilities of ",
  StyleBox["DSolve[]", "MmaText"],
  ". The solution of the ODE follows by"
}], "Text",
  Evaluatable->False,
  CellTags->{"reduced a PDE to an ODE", "invariants of a group", "DSolve[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(sheat = 
      DSolve[rheat\[LeftDoubleBracket]1\[RightDoubleBracket] == 0, F, \[Zeta]]
        \)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({{F \[Rule] 
          \((C[1]\ Hypergeometric1F1[1\/2 - c\/2, 3\/2, \(-\(1\/\(4\ #1\)\)\)]
                    \ \((1\/#1)\)\^\(1\/2 - c\/2\) + 
                C[2]\ Hypergeometric1F1[\(-\(c\/2\)\), 1\/2, 
                    \(-\(1\/\(4\ #1\)\)\)]\ \((1\/#1)\)\^\(\(-c\)/2\)&)\)}}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The resulting solution is a combination of special functions containing \
the group parameter ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". Since we started from a second-order ordinary differential equation, we \
end up with a solution containing two constants of integration ",
  StyleBox["C[1]", "MmaText",
    FontSlant->"Italic"],
  " and ",
  StyleBox["C[2]", "MmaText",
    FontSlant->"Italic"],
  ". The two solutions are graphically shown in the following figure. The \
different curves represent different values of the group parameter ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "."
}], "Text",
  Evaluatable->False,
  CellTags->{"special functions", "group parameter"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[Table[
            F[\[Zeta]] /. sheat\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
            \n\t\t\t{c, \(-2.1\), 2.1,  .5}] /. {C[1] \[Rule] 1, 
            C[2] \[Rule] 0}], \n\t{\[Zeta], 0.01, 2}, \t
      AxesLabel \[Rule] {"\<\[Zeta]\>", "\<F\>"}, \n\t
      PlotStyle \[Rule] Table[Hue[i\/10], {i, 1, 8}]]\)], "Input",
  PageWidth->Infinity],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0832909 0.155681 [
[.2619 .07079 -9 -9 ]
[.2619 .07079 9 0 ]
[.5 .07079 -3 -9 ]
[.5 .07079 3 0 ]
[.7381 .07079 -9 -9 ]
[.7381 .07079 9 0 ]
[.97619 .07079 -3 -9 ]
[.97619 .07079 3 0 ]
[1.025 .08329 0 -7.5 ]
[1.025 .08329 10 7.5 ]
[.01131 .00545 -24 -4.5 ]
[.01131 .00545 0 4.5 ]
[.01131 .16113 -18 -4.5 ]
[.01131 .16113 0 4.5 ]
[.01131 .23897 -6 -4.5 ]
[.01131 .23897 0 4.5 ]
[.01131 .31681 -18 -4.5 ]
[.01131 .31681 0 4.5 ]
[.01131 .39465 -6 -4.5 ]
[.01131 .39465 0 4.5 ]
[.01131 .47249 -18 -4.5 ]
[.01131 .47249 0 4.5 ]
[.01131 .55033 -6 -4.5 ]
[.01131 .55033 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .08329 m
.2619 .08954 L
s
[(0.5)] .2619 .07079 0 1 Mshowa
.5 .08329 m
.5 .08954 L
s
[(1)] .5 .07079 0 1 Mshowa
.7381 .08329 m
.7381 .08954 L
s
[(1.5)] .7381 .07079 0 1 Mshowa
.97619 .08329 m
.97619 .08954 L
s
[(2)] .97619 .07079 0 1 Mshowa
.125 Mabswid
.07143 .08329 m
.07143 .08704 L
s
.11905 .08329 m
.11905 .08704 L
s
.16667 .08329 m
.16667 .08704 L
s
.21429 .08329 m
.21429 .08704 L
s
.30952 .08329 m
.30952 .08704 L
s
.35714 .08329 m
.35714 .08704 L
s
.40476 .08329 m
.40476 .08704 L
s
.45238 .08329 m
.45238 .08704 L
s
.54762 .08329 m
.54762 .08704 L
s
.59524 .08329 m
.59524 .08704 L
s
.64286 .08329 m
.64286 .08704 L
s
.69048 .08329 m
.69048 .08704 L
s
.78571 .08329 m
.78571 .08704 L
s
.83333 .08329 m
.83333 .08704 L
s
.88095 .08329 m
.88095 .08704 L
s
.92857 .08329 m
.92857 .08704 L
s
.25 Mabswid
0 .08329 m
1 .08329 L
s
gsave
1.025 .08329 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.02381 .00545 m
.03006 .00545 L
s
[(-0.5)] .01131 .00545 1 0 Mshowa
.02381 .16113 m
.03006 .16113 L
s
[(0.5)] .01131 .16113 1 0 Mshowa
.02381 .23897 m
.03006 .23897 L
s
[(1)] .01131 .23897 1 0 Mshowa
.02381 .31681 m
.03006 .31681 L
s
[(1.5)] .01131 .31681 1 0 Mshowa
.02381 .39465 m
.03006 .39465 L
s
[(2)] .01131 .39465 1 0 Mshowa
.02381 .47249 m
.03006 .47249 L
s
[(2.5)] .01131 .47249 1 0 Mshowa
.02381 .55033 m
.03006 .55033 L
s
[(3)] .01131 .55033 1 0 Mshowa
.125 Mabswid
.02381 .02102 m
.02756 .02102 L
s
.02381 .03659 m
.02756 .03659 L
s
.02381 .05215 m
.02756 .05215 L
s
.02381 .06772 m
.02756 .06772 L
s
.02381 .09886 m
.02756 .09886 L
s
.02381 .11443 m
.02756 .11443 L
s
.02381 .13 m
.02756 .13 L
s
.02381 .14556 m
.02756 .14556 L
s
.02381 .1767 m
.02756 .1767 L
s
.02381 .19227 m
.02756 .19227 L
s
.02381 .20784 m
.02756 .20784 L
s
.02381 .2234 m
.02756 .2234 L
s
.02381 .25454 m
.02756 .25454 L
s
.02381 .27011 m
.02756 .27011 L
s
.02381 .28568 m
.02756 .28568 L
s
.02381 .30124 m
.02756 .30124 L
s
.02381 .33238 m
.02756 .33238 L
s
.02381 .34795 m
.02756 .34795 L
s
.02381 .36352 m
.02756 .36352 L
s
.02381 .37908 m
.02756 .37908 L
s
.02381 .41022 m
.02756 .41022 L
s
.02381 .42579 m
.02756 .42579 L
s
.02381 .44136 m
.02756 .44136 L
s
.02381 .45692 m
.02756 .45692 L
s
.02381 .48806 m
.02756 .48806 L
s
.02381 .50363 m
.02756 .50363 L
s
.02381 .5192 m
.02756 .5192 L
s
.02381 .53476 m
.02756 .53476 L
s
.02381 .5659 m
.02756 .5659 L
s
.02381 .58147 m
.02756 .58147 L
s
.02381 .59704 m
.02756 .59704 L
s
.02381 .6126 m
.02756 .6126 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(F) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .6 0 r
.5 Mabswid
.02857 .02175 m
.03081 .01937 L
.03203 .01792 L
.0332 .01655 L
.03428 .01544 L
.03545 .01472 L
.03652 .01483 L
.0375 .01589 L
.03867 .01864 L
.03976 .02294 L
.04096 .02976 L
.04225 .03964 L
.04488 .06754 L
.04729 .10074 L
.05752 .27519 L
.06701 .41723 L
.07199 .4731 L
.07729 .51898 L
.08032 .53953 L
.08317 .55556 L
.08577 .56761 L
.08851 .57801 L
.09094 .58546 L
.09362 .59189 L
.09605 .59632 L
.09832 .59938 L
.0997 .60077 L
.101 .60178 L
.10217 .60247 L
.10345 .60297 L
.1041 .60315 L
.10483 .60327 L
.10559 .60332 L
.1063 .6033 L
.10757 .60312 L
.10828 .60293 L
.10894 .60271 L
.11021 .60215 L
.11141 .60148 L
.11365 .59986 L
.11869 .59477 L
.12777 .58181 L
.14836 .54321 L
.18664 .46756 L
.22735 .40006 L
.26656 .34931 L
.30426 .31108 L
.34439 .27894 L
.38302 .25426 L
.42409 .23304 L
Mistroke
.46366 .21633 L
.50171 .20292 L
.5422 .1909 L
.58119 .18107 L
.62262 .17214 L
.66253 .16473 L
.70094 .1585 L
.74179 .15268 L
.78114 .14775 L
.81897 .14352 L
.85924 .1395 L
.89801 .13603 L
.93922 .13271 L
.97619 .13001 L
Mfstroke
.8 1 0 r
.02857 .2738 m
.03081 .27832 L
.0332 .28387 L
.03526 .28969 L
.0375 .29778 L
.04014 .31043 L
.04262 .32568 L
.04729 .3608 L
.05667 .43706 L
.06165 .47146 L
.06701 .50098 L
.06987 .51351 L
.07248 .52315 L
.07759 .53745 L
.08034 .5429 L
.0818 .54522 L
.08335 .54731 L
.08483 .54895 L
.08618 .55015 L
.08754 .5511 L
.08881 .55178 L
.08998 .55222 L
.09126 .55252 L
.09191 .5526 L
.0926 .55264 L
.09385 .55258 L
.09509 .55237 L
.09627 .55205 L
.09733 .55165 L
.09848 .55112 L
.10111 .54952 L
.10391 .54731 L
.10894 .54226 L
.12831 .51481 L
.1465 .48463 L
.18499 .42363 L
.22593 .37047 L
.26535 .33021 L
.30327 .29943 L
.34363 .27311 L
.38248 .25252 L
.42377 .23452 L
.46355 .22008 L
.50183 .20831 L
.54254 .1976 L
.58175 .18872 L
.61944 .18125 L
.65958 .17427 L
.69821 .16833 L
.73928 .16273 L
Mistroke
.77884 .15792 L
.8169 .15375 L
.85739 .14975 L
.89638 .14626 L
.9378 .14289 L
.97619 .14005 L
Mfstroke
.2 1 0 r
.02857 .39126 m
.04729 .44021 L
.05682 .4692 L
.05956 .4757 L
.06216 .48093 L
.06451 .48491 L
.06701 .48835 L
.0696 .49112 L
.07198 .49301 L
.07331 .49381 L
.07455 .49439 L
.07591 .49487 L
.07667 .49506 L
.07737 .49519 L
.0786 .49533 L
.07974 .49534 L
.08099 .49525 L
.08169 .49515 L
.08232 .49502 L
.08348 .49473 L
.08474 .49432 L
.08702 .49332 L
.08967 .49183 L
.09257 .48981 L
.09844 .48475 L
.10894 .47341 L
.14916 .42191 L
.18787 .37682 L
.22903 .33804 L
.26867 .3083 L
.30681 .28511 L
.34739 .26489 L
.38646 .24874 L
.42402 .2356 L
.46402 .22364 L
.50252 .21372 L
.54345 .20456 L
.58288 .19684 L
.6208 .19026 L
.66115 .18402 L
.7 .17865 L
.74129 .17352 L
.78108 .16907 L
.81935 .16516 L
.86007 .16137 L
.89927 .15803 L
.93697 .15507 L
.97619 .15223 L
s
0 1 .4 r
.02857 .40875 m
.0375 .41607 L
.04729 .42562 L
.05222 .42962 L
.05498 .43133 L
.0575 .43252 L
.05864 .43294 L
.05984 .4333 L
.06047 .43346 L
.06117 .43361 L
.06239 .43381 L
.06354 .43392 L
.06478 .43397 L
.06594 .43394 L
.06701 .43386 L
.06771 .43378 L
.06837 .43368 L
.06959 .43345 L
.07091 .43313 L
.07234 .4327 L
.07729 .43065 L
.08313 .42729 L
.08851 .42351 L
.10894 .40585 L
.14823 .36955 L
.18601 .33921 L
.22623 .31277 L
.26495 .29202 L
.3061 .27387 L
.34575 .25931 L
.38388 .2474 L
.42446 .23652 L
.46353 .22743 L
.50109 .21975 L
.5411 .21251 L
.57959 .20629 L
.62052 .20037 L
.65995 .19524 L
.69787 .19076 L
.73823 .1864 L
.77708 .18256 L
.81837 .17882 L
.85815 .1755 L
.89642 .17254 L
.93714 .16962 L
.97619 .167 L
s
0 1 1 r
.02857 .37034 m
.0332 .37068 L
.0375 .37102 L
.03993 .3712 L
.04223 .37134 L
.0435 .3714 L
.04422 .37142 L
.04488 .37143 L
.04605 .37145 L
.04729 .37143 L
.0485 .3714 L
.04962 .37134 L
.05091 .37124 L
.05213 .37112 L
.0543 .37082 L
.05667 .37039 L
.06204 .36902 L
.06701 .36729 L
.08731 .35728 L
.10894 .34448 L
.15031 .32092 L
.19018 .30176 L
.22854 .28647 L
.26933 .2729 L
.30862 .26189 L
.34641 .25279 L
.38663 .24438 L
.42534 .23728 L
.4665 .23062 L
.50614 .2249 L
.54428 .21994 L
.58486 .21517 L
.62393 .21099 L
.66149 .2073 L
.70149 .20368 L
.73999 .20047 L
.78092 .1973 L
.82035 .19446 L
.85827 .19192 L
.89862 .18938 L
.93747 .18708 L
.97619 .18493 L
s
0 .4 1 r
.02857 .31049 m
.0375 .30936 L
.04729 .30787 L
.0575 .30581 L
.06701 .30347 L
.10894 .29136 L
.14774 .28083 L
.18897 .27132 L
.2287 .26361 L
.26693 .25725 L
.30759 .25139 L
.34674 .24646 L
.38439 .24224 L
.42447 .23821 L
.46305 .23472 L
.50407 .23135 L
.54358 .22838 L
.58158 .22576 L
.62203 .22317 L
.66096 .22087 L
.70233 .21858 L
.7422 .21653 L
.78056 .21468 L
.82136 .21282 L
.86065 .21114 L
.89843 .20961 L
.93865 .20806 L
.97619 .20668 L
s
.2 0 1 r
.02857 .2501 m
.06701 .24866 L
.10894 .24687 L
.14831 .24536 L
.18618 .2441 L
.22648 .24294 L
.26528 .24195 L
.30652 .24102 L
.34625 .24022 L
.38447 .23953 L
.42513 .23885 L
.46429 .23825 L
.50193 .23771 L
.54202 .23718 L
.5806 .23671 L
.62162 .23623 L
.66113 .2358 L
.69913 .23541 L
.73957 .23501 L
.77851 .23465 L
.81988 .23429 L
.85975 .23395 L
.8981 .23365 L
.9389 .23333 L
.97619 .23306 L
s
.8 0 1 r
.02857 .19901 m
.06701 .20452 L
.10894 .21049 L
.14831 .21552 L
.18618 .21982 L
.22648 .22392 L
.26528 .22749 L
.30652 .23094 L
.34625 .23399 L
.38447 .23671 L
.42513 .23942 L
.46429 .24186 L
.50193 .24407 L
.54202 .24631 L
.5806 .24835 L
.62162 .25041 L
.66113 .25231 L
.69913 .25406 L
.73957 .25584 L
.77851 .25749 L
.81988 .25918 L
.85975 .26075 L
.8981 .26221 L
.9389 .26371 L
.97619 .26504 L
s
1 .6 0 r
.02857 .16004 m
.06701 .17047 L
.10894 .1813 L
.14831 .19059 L
.18618 .19879 L
.22648 .20686 L
.26528 .21409 L
.30652 .22129 L
.34625 .22783 L
.38447 .23381 L
.42513 .23986 L
.46429 .24544 L
.50193 .2506 L
.54202 .25588 L
.5806 .26079 L
.62162 .26583 L
.66113 .27054 L
.69913 .27493 L
.73957 .27947 L
.77851 .28373 L
.81988 .28813 L
.85975 .29227 L
.8981 .29616 L
.9389 .30021 L
.97619 .30382 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{Inherited, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`002Goo10001Goo0P001Goo1000ogooC7oo0008Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3oOom3Ool000Qoo`03001o
ogoo009oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo0?mood=oo`001P000Woo00<007oo
Ool00Woo00<007ooOol03Goo00<007ooOol00goo0`00ogoo@goo0008Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool40006Ool00`00Oomoo`3oOom3Ool000Qoo`03001oogoo009oo`03001oogoo00Uoo`03
001oogoo00Moo`03001oogoo0?mood=oo`0027oo00<007ooOol00Woo00<007ooOol02Goo00<007oo
Ool01goo00<007ooOol00Wi0ogoo@Goo0009Ool4000<Ool50005Ool01P00Oomn@7i0Oomn@?mood1o
o`008goo00<007i0Ool00Woo00=n@7ooOol0ogoo?Woo000SOol00`00Oomoo`02Ool00gi0Oomoo`3o
OolnOol002=oo`03001oogoo009oo`03OT1oogoo0?moocioo`008goo00<007ooOol00Woo00=n@7oo
Ool0ogoo?Woo000SOol20004Ool00gi0Oomoo`0gOol40005Ool20005Ool4000mOol5000mOol50004
Ool20005Ool4000lOol5000MOol002=oo`03001oogoo00=oo`03OT1oogoo03Ioo`03001oogoo009o
o`03001oogoo009oo`8000Aoo`03001oogoo009oo`03001oogoo03aoo`03001oogoo03moo`03001o
ogoo00Aoo`8000Aoo`03001oogoo009oo`03001oogoo03Uoo`05001oogooOol0000MOol002=oo`03
001oogoo00=oo`03OT1oogoo03Ioo`03001oogoo009oo`03001oogoo00eoo`03001oogoo03aoo`03
001oogoo03moo`03001oogoo00moo`03001oogoo03Yoo`03001oogoo01ioo`008goo00<007ooOol0
0goo00=n@7ooOol0=Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0?7oo00<007ooOol0
?goo00<007ooOol03goo00<007ooOol0>goo00<007ooOol07Goo000SOol00`00Oomoo`03Ool00gi0
Oomoo`0fOol00`00Oomoo`02Ool00`00Oomoo`09Ool4000oOol00`00Oomoo`0oOol00`00Oomoo`0;
Ool4000oOol00`00Oomoo`0LOol002=oo`8000Aoo`03OT1oogoo03Ioo`03001oogoo009oo`03001o
ogoo00Uoo`03001oogoo041oo`03001oogoo03moo`03001oogoo00]oo`03001oogoo045oo`03001o
ogoo01]oo`008goo00<007ooOol017oo00=n@7ooOol0=Goo00<007ooOol00Woo00<007ooOol02Goo
00<007ooOol0?Woo0`00?goo0`003Goo00<007ooOol0?Goo00D007ooOomoo`0001eoo`008goo00<0
07ooOol017oo00=n@7ooOol0=Woo100037oo1@00?Woo00<007ooOol0?goo00<007ooOol02goo1@00
?7oo0`007Woo000SOol00`00Oomoo`04Ool00gi0Oomoo`3oOollOol002=oo`03001oogoo00Aoo`03
OT1oogoo0?moocaoo`008goo0P001Goo00=n@7ooOol0ogoo<7oo100027oo000SOol00`00Oomoo`04
Ool00gi0Oomoo`3oOol_Ool00`00Oomoo`02Ool00`00Oomoo`05Ool002=oo`03001oogoo00Aoo`03
OT1oogoo0?mooc5oo`<000Qoo`008goo00<007ooOol017oo00=n@7ooOol0ogoo<7oo00<007ooOol0
2Goo000SOol00`00Oomoo`04Ool00gi0Oomoo`3oOol`Ool00`00Oomoo`09Ool001aoo`h00003OT00
00000?l002H000Yoo`03001oogoo00Uoo`008goo00<007ooOol017oo00=n@7ooOol01Goo00<007oo
Ool02goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo00<007oo
Ool037oo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol037oo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo00<007oo
Ool037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo00<007ooOol04Goo00<007oo
Ool027oo000SOol00`00Oomoo`04Ool00gi0Oomoo`10Ool00`00Oomoo`16Ool00`00Oomoo`17Ool0
0`00Oomoo`16Ool00`00Oomoo`0BOol30007Ool002=oo`03001oogoo00Aoo`03OT1oogoo0?mooc5o
o`80009oo`03001oogoo00Aoo`008goo00<007ooOol017oo00=n@7ooOol0ogoo<goo0`001Woo000S
Ool20005Ool00gi0Oomoo`3oOollOol002=oo`03001oogoo00Aoo`03OT1oogoo0?moocaoo`008goo
00<007ooOol017oo00=n@7ooOol0ogoo?7oo000SOol00`00Oomoo`04Ool00gi0Oomoo`3oOollOol0
02=oo`8000Eoo`03OT1oogoo0?moocaoo`008goo00<007ooOol017oo00=n@7ooOol0ogoo?7oo000S
Ool00`00Oomoo`04Ool00gi0Oomoo`3oOollOol002=oo`03001oogoo00Aoo`03OT1oogoo0?moocao
o`008goo00<007ooOol017oo00=n@7ooOol0ogoo?7oo000SOol20006Ool00gi0Oomoo`3oOolGOol6
OT0NOol002=oo`03001oogoo00Eoo`03OT1oogoo0?moo`]oo`an@2Aoo`008goo00<007ooOol01Goo
00=n@7ooOol0oWoo37i0<7oo000SOol00`00Oomoo`05Ool00gi0Oomoo`3bOol<OT0HOol6In0NOol0
02=oo`03001oogoo00Eoo`03OT1oogoo0>Uoo`Un@1Qoo`aWh2Aoo`008goo0P001Woo00=n@7ooOol0
hgoo1Wi05Goo36OP<7oo000SOol00`00Oomoo`05Ool00gi0Oomoo`3JOol9OT0AOol:In0lOol000Uo
o`@000Eoo`8000Eoo`@000Ioo`03001oogoo00Eoo`03OT1oogoo0=1oo`Yn@1Aoo`IWh29oo`HGh1io
o`0027oo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol01Goo00=n@7ooOol0bWoo1Wi05Goo2FOP77oo31OP97oo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00gi0Oomoo`34Ool6OT0?Ool<In0IOol<
5n0`Ool000Qoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00=oo`03001n@7i000Eoo`03
OT1oogoo0;ioo`In@0]oo`YWh1Uoo``Gh3aoo`0027oo00<007ooOol00Woo00<007ooOol02Goo1000
1Woo00<007ooOol017i000=oogi0Ool0^Goo1Wi02goo1VOP5goo31OPB7oo0008Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool4OT2bOol6OT0;Ool6In0DOol95n0T
OolB0n`NOol000Qoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Eo
o`03OT1oogoo00En@:Moo`In@0]oo`IWh1Aoo`HGh25oo``3k31oo`002Goo100037oo1@001Goo00<0
07ooOol01Goo00=n@7ooOol01Goo17i0Wgoo17i02goo1VOP47oo2QOP6goo30?/?7oo000SOol20006
Ool00gi0Oomoo`09Ool4OT2GOol4OT09Ool6In0=Ool95n0HOol=0na8Ool002=oo`03001oogoo00Eo
o`03OT1oogoo00eoo`An@8moo`An@0Moo`IWh0eoo`HGh1Qoo`T3k5Eoo`008goo00<007ooOol01Goo
00=n@7ooOol04Goo17i0Qgoo17i01Goo1VOP37oo1aOP67oo1P?/>Woo1P?o7Woo000SOol00`00Oomo
o`06Ool00gi0Oomoo`0DOol4OT1oOol4OT04Ool5In0<Ool65n0EOol:0n`dOol<0olTOol002=oo`80
00Moo`03OT1oogoo01Qoo`En@7Ioo`An@0Aoo`AWh0]oo`HGh0moo``3k2IooaP3oc1oo`008goo00<0
07ooOol01Woo00=n@7ooOol07Goo1Wi0KGoo0gi017oo16OP2Goo1QOP37oo2@?/9Woo30?oB7oo000S
Ool00`00Oomoo`06Ool00gi0Oomoo`0SOol6OT1TOol3OT03Ool4In08Ool55n0<Ool60n`ROol=0omD
Ool002=oo`03001T7f@O00AT7`9oo`03OT1oogoo02Uoo`An@5eoo`=n@09oo`AWh0Ioo`HGh0]oo`H3
k1aoo``3of5oo`008goo00<007ooOol017oo2V@O:7oo17i0EWoo0gi000=oofOPIn000VOP17oo1QOP
2goo1P?/5Woo30?oKGoo000SOol20007Ool00gi0Oomoo`05Ool6I1lVOol5OT1>Ool3OT04In04Ool4
5n0;Ool60n`@Ool<0om9OolB0IlNOol002=oo`03001oogoo00Ioo`03OT1oogoo00]oo`IT7bEoo`In
@4Eoo`=n@0=Wh0Aoo`@Gh0Uoo`H3k0eoo`T3oceooaP1Wc1oo`008goo00<007ooOol01Woo00=n@7oo
Ool04Goo1V@O9Goo1Wi0?7oo0gi00fOP0goo11OP1Woo1`?/3Goo1P?o;Woo606OB7oo000SOol00`00
Oomoo`06Ool00gi0Oomoo`0GOol9I1lROol6OT0cOol3OT03In02Ool45n04Ool60n`;Ool90olXOol<
0ImPOol002=oo`03001oogoo00Ioo`03OT1oogoo021oo`eT7a]oo`Mn@2Yoo`9n@0=Wh003OolGh1OP
008Gh09oo`H3k0Qoo`T3oaQooaT1Wfaoo`008goo0P001goo00=n@7ooOol0;Goo36@O5Woo1Wi08Woo
0Wi00VOP11OP1P?/27oo1P?o57oo3@6OQGoo000SOol00`00Oomoo`06Ool00gi0Oomoo`0iOol<I1l@
Ool6OT0IOol3OT0016OP5n0Gh1OP10?/1Goo2@?o3Woo306OTWoo000IOol50005Ool00`00Oomoo`06
Ool00gi0Oomoo`15Ool=I1l9Ool6OT0AOol2OT000fOP5n0Gh0030n`:0ol;Ool<0InNOol001]oo`03
001oogoo00Eoo`03001oogoo00Ioo`03OT1oogoo059oo`aT7`=oo`In@0Uoo`9n@0035n03k0?o00D3
o`Uoo``1WeEoocLD7aioo`006goo00<007ooOol01Goo00<007ooOol01Woo00=n@7ooOol0GWoo2F@O
1Wi000=oogi00ol010?o0goo306O37ooEA@OEGoo000KOol00`00Oomoo`05Ool30006Ool00gi0Oomo
o`1BOolH51l3I1l6OT03I1lI51nZOol001]oo`03001oogoo00Eoo`03001oogoo00Ioo`03OT1oogoo
025ooc4D7`aoo``1W`030ol3k6OP00Ioo`In@1ET7j]oo`006goo00<007ooOol01Goo00<007ooOol0
1goo00=n@7ooOol01goo6A@O=Goo206O17oo1@?o00<3k1OPIn003goo2Gi037oo36@OWgoo000IOol3
0007Ool00`0051lD7`0A51m8Ool60Il6Ool60ol30n`00aOPIn1n@00JOol9OT0?OolII1n6Ool001]o
o`03001oogoo00Eoo`03001oogoo00Moo`03OT1oogoo04Qoo`L1W`Moo`D3o`9oo`@3k0045n1Wh6OP
OT0UOol6OT0ROol<I1mjOol002=oo`8000Qoo`03OT1oogoo049oo`H1W`Yoo`@3o`=oo`@3k003OolG
h1OP009Wh003OT1oogoo02]oo`In@2QooaQT7f9oo`008goo00<007ooOol01goo00=n@7ooOol0?7oo
1P6O37oo10?o0goo10?/0Woo0aOP0VOP0Wi0=7oo1Wi0>Woo6F@OBGoo000SOol00`00Oomoo`07Ool0
0gi0Oomoo`0fOol60Il>Ool40ol5Ool20n`4Ool25n000gooIn1Wh002OT0lOol:OT19OolII1l`Ool0
02=oo`03001oogoo00Moo`03OT1oogoo031oo`H1Wa1oo`@3o`Moo`83k0=oo`<Gh005OomWh6OPOomn
@018Ool9OT1IOolBI1lNOol002=oo`03001oogoo00Moo`03OT1oogoo02Yoo`H1Wa9oo`@3o`Qoo`<3
k0=oo`8Gh09oo`9Wh003Oomn@7i0059oo`In@8=oo`008goo0P0027oo00=n@7ooOol097oo1P6O57oo
10?o2Woo0P?/17oo0QOP0Woo0VOP00=oogi0OT00FWoo2Gi0NWoo000SOol00`00In1oo`07Ool00gi0
Oomoo`0POol40IlHOol20ol;Ool30n`4Ool25n02Ool2In000gooOT1n@01UOol<OT1^Ool002=oo`03
001oofOP00Moo`03OT1oogoo01aoo`@1WaUoo`<3o`]oo`83k0Eoo`8Gh0=oo`04In1oogooOT1cOol9
OT1UOol002=oo`04001oogooIn06Ool00gi0Oomoo`0HOol40IlJOol30ol<Ool20n`5Ool25n03Ool2
In02Ool00gi0Oomoo`1kOol6OT1OOol002=oo`800003OomWh7oo00Eoo`03OT1oogoo01Aoo`@1Waao
o`83o`aoo`<3k0Eoo`8Gh0Aoo`05In1oogooOomn@024Ool:OT1EOol002=oo`05001oogooOomWh005
Ool00gi0Oomoo`0@Ool40IlMOol30ol<Ool20n`6Ool25n05Ool00fOPOomoo`02OT2?Ool<OT19Ool0
02=oo`05001oogooOomWh005Ool00gi0Oomoo`0<Ool40IlNOol30ol=Ool20n`7Ool00aOPOomoo`03
Ool2In02Ool00gi0Oomoo`2KOol9OT10Ool002=oo`05001oogooOomWh005Ool00gi0Oomoo`09Ool3
0IlOOol30ol>Ool20n`7Ool25n05Ool01FOPOomoogooOT00Ygoo1Wi0>Woo000SOol01@00Oomoogoo
In001Goo00=n@7ooOol01Goo106O7goo0`?o3goo0P?/1goo0QOP1Goo0VOP0goo00=n@7ooOol0[7oo
2Wi0<7oo000SOol20002Ool00fOPOomoo`04Ool017i0Oomoogoo0`6O8Goo0P?o4Goo00<3k7ooOol0
1Woo00<Gh7ooOol017oo00=Wh7ooOol00Woo00=n@7ooOol0]goo37i097oo000SOol00`00Oomoo`02
Ool00fOPOomoo`03Ool017i00Il1W`6O8Woo0P?o4Goo0P?/1goo0QOP1Woo00AWh7ooOomoo`9n@<Io
o`In@1ioo`002Goo1@0017oo0P001Goo10001Woo00<007ooOol00Woo00=Wh06O0Il0106O8goo0P?o
4Goo0P?/27oo00<Gh7ooOol017oo0VOP0goo00=n@7ooOol0jWoo000;Ool00`00Oomoo`04Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`000Il1W`030Il5Ool00gi0Oomoo`0OOol20olAOol2
0n`9Ool00aOPOomoo`04Ool00fOPOomoo`02Ool00gi0Oomoo`3[Ool000]oo`03001oogoo00moo`03
001oogoo00=oo`03001oogoo009oo`03In1oogoo00=oo`03OT1oogoo01eoo`83oa9oo`030naoogoo
00Moo`8Gh0Ioo`03In1oogoo009oo`03OT1oogoo0>aoo`002goo00<007ooOol03goo00<007ooOol0
0goo0`000Woo00=Wh7ooOol00goo00=n@7ooOol06goo0P?o4Woo0P?/2Goo00<Gh7ooOol01Goo00=W
h7ooOol00Woo00=n@7ooOol0kGoo000;Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`03Ool00fOP
Oomoo`02Ool00gi0Oomoo`0IOol20olBOol20n`:Ool00aOPOomoo`05Ool00fOPOomoo`02Ool00gi0
Oomoo`3^Ool000]oo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00=oo`03In1oogoo009o
o`03OT1oogoo01Moo`83oa=oo`030naoogoo00Qoo`8Gh0Ioo`9Wh0Aoo`03OT1oogoo0>moo`002Goo
0`003Goo00<007ooOol01goo00<007ooOol00goo00=Wh7ooOol00Woo00=n@7ooOol05Goo0P?o4goo
0P?/2Woo00<Gh7ooOol01Goo00=Wh7ooOol00goo00=n@7ooOol0l7oo000;Ool00`00Oomoo`0;Ool5
0005Ool00`00Oomoo`03Ool00fOPOomoo`02Ool00gi0Oomoo`0DOol00`?oOomoo`0BOol00`?/Oomo
o`09Ool00aOPOomoo`05Ool00fOPOomoo`03Ool00gi0Oomoo`3aOol002=oo`8000Aoo`03In1oogoo
009oo`03OT1oogoo019oo`83oa=oo`83k0Yoo`8Gh0Moo`03In1oogoo00=oo`03OT1oogoo0?9oo`00
8goo00<007ooOol00goo00=Wh7ooOol00Woo00=n@7ooOol04Goo00<3ogooOol04Goo0P?/2goo00<G
h7ooOol01Woo00=Wh7ooOol00goo00=n@7ooOol0lgoo000SOol00`00Oomoo`03Ool00fOPOomoo`02
Ool00gi0Oomoo`0?Ool20olCOol00`?/Oomoo`0:Ool00aOPOomoo`06Ool00fOPOomoo`03Ool00gi0
Oomoo`3dOol002=oo`03001oogoo00=oo`03In1oogoo009oo`03OT1oogoo00eoo`83oaAoo`030nao
ogoo00Yoo`035n1oogoo00Ioo`03In1oogoo00=oo`03OT1oogoo0?Eoo`008goo00<007ooOol017oo
00=Wh7ooOol00Woo00=n@7ooOol02goo00<3ogooOol04Woo0P?/37oo00<Gh7ooOol01Woo00=Wh7oo
Ool00goo00=n@7ooOol0mWoo000SOol20005Ool00fOPOomoo`02Ool00gi0Oomoo`09Ool20olDOol0
0`?/Oomoo`0;Ool00aOPOomoo`06Ool00fOPOomoo`03Ool00gi0Oomoo`3gOol002=oo`03001oogoo
00Aoo`03In1oogoo009oo`03OT1oogoo00Moo`83oaEoo`030naoogoo00]oo`035n1oogoo00Ioo`03
In1oogoo00=oo`03OT1oogoo0?Qoo`008goo00<007ooOol017oo00=Wh7ooOol00Woo00=n@7ooOol0
1Goo0P?o5Goo0P?/3Goo00<Gh7ooOol01Woo00=Wh7ooOol00goo00=n@7ooOol0nGoo000SOol00`00
Oomoo`04Ool00fOPOomoo`02Ool00gi0Oomoo`03Ool20olFOol00`?/Oomoo`0;Ool25n08Ool00fOP
Oomoo`04Ool00gi0Oomoo`3iOol002=oo`8000Eoo`03In1oogoo009oo`04OT1oogooOol20olGOol0
0`?/Oomoo`0;Ool00aOPOomoo`07Ool00fOPOomoo`04Ool00gi0Oomoo`3jOol002=oo`03001oogoo
00Aoo`03In1oogoo009oo`04OT1oo`?o0olGOol20n`=Ool00aOPOomoo`07Ool00fOPOomoo`04Ool0
0gi0Oomoo`3kOol002=oo`030003ogoo00Aoo`03In1oogoo009oo`83oaQoo`030naoogoo00aoo`03
5n1oogoo00Moo`03In1oogoo00Aoo`03OT1oogoo0?aoo`008goo00<007oo0ol02@?o00=n@7ooOol0
5Woo00<3k7ooOol037oo00<Gh7ooOol01goo00=Wh7ooOol01Goo00=n@7ooOol0o7oo000SOol00`00
Oomoo`05Ool01FOPOomoogooOT005goo00<3k7ooOol037oo00<Gh7ooOol01goo00=Wh7ooOol01Goo
00=n@7ooOol0oGoo000SOol20006Ool01FOPOomoogooOT005Woo00<3k7ooOol037oo00<Gh7ooOol0
1goo00=Wh7ooOol01Goo00=n@7ooOol0oWoo000SOol00`00Oomoo`05Ool01FOPOomoogooOT005Goo
00<3k7ooOol037oo00<Gh7ooOol027oo00=Wh7ooOol017oo00=n@7ooOol0ogoo000HOol50006Ool0
0`00Oomoo`05Ool01FOPOomoogooOT0057oo00<3k7ooOol037oo00<Gh7ooOol027oo00=Wh7ooOol0
1Goo00=n@7ooOol0ogoo000HOol01@00Oomoogoo00001Woo00<007ooOol01Goo00EWh7ooOomoogi0
019oo`83k0moo`035n1oogoo00Moo`03In1oogoo00Eoo`03OT1oogoo0?moo`5oo`006Goo00<007oo
Ool01goo00<001OPOol01Goo00EWh7ooOomoogi0015oo`030naoogoo00ioo`035n1oogoo00Moo`03
In1oogoo00Eoo`03OT1oogoo0?moo`9oo`006Woo00<007ooOol01Woo00<001OP00001Goo00=Wh7oo
Ool00Woo00=n@7ooOol03Goo00<3k7ooOol03Woo00<Gh7ooOol027oo00=Wh7ooOol017oo00=n@7oo
Ool0ogoo0goo000KOol00`00Oomoo`05Ool00`00OolGh005Ool00fOPOomoo`02Ool00gi0Oomoo`0<
Ool00`?/Oomoo`0>Ool00aOPOomoo`08Ool00fOPOomoo`05Ool00gi0Oomoo`3oOol3Ool001aoo`03
001oogoo00Aoo`03001ooaOP00Ioo`05In1oogooOomn@00=Ool00`?/Oomoo`0>Ool00aOPOomoo`08
Ool00fOPOomoo`05Ool00gi0Oomoo`3oOol4Ool001Qoo`05001oogooOol00006Ool01000OomooaOP
1Goo00EWh7ooOomoogi000aoo`030naoogoo00ioo`035n1oogoo00Qoo`03In1oogoo00Eoo`03OT1o
ogoo0?moo`Eoo`006Goo0`001goo00@000?/OolGh0Eoo`05In1oogooOomn@00;Ool00`?/Oomoo`0>
Ool00aOPOomoo`09Ool00fOPOomoo`05Ool00gi0Oomoo`3oOol5Ool002=oo`8000030n`Gh7oo00Ao
o`05In1oogooOomn@00:Ool00`?/Oomoo`0?Ool00aOPOomoo`08Ool00fOPOomoo`05Ool00gi0Oomo
o`3oOol6Ool002=oo`05001oogoo0n`Gh004Ool01FOPOomoogooOT002Goo00<3k7ooOol03goo00<G
h7ooOol027oo00=Wh7ooOol01Woo00=n@7ooOol0ogoo1Woo000SOol01@00Oomoogoo0n`017oo00EW
h7ooOomoogi000Qoo`030naoogoo00moo`035n1oogoo00Qoo`03In1oogoo00Ioo`03OT1oogoo0?mo
o`Moo`008goo00<007ooOol00Woo00D3k7ooOomoofOP00=oo`03OT1oogoo00Eoo`030naoogoo00mo
o`035n1oogoo00Uoo`03In1oogoo00Eoo`03OT1oogoo0?moo`Qoo`008goo00<007ooOol00Woo00DG
h0?/OomoofOP00=oo`03OT1oogoo00Aoo`030naoogoo00moo`035n1oogoo00Uoo`03In1oogoo00Io
o`03OT1oogoo0?moo`Qoo`008goo0P000goo00<Gh7oo0n`00Woo00AWh7ooOomn@0Aoo`83k15oo`03
5n1oogoo00Uoo`03In1oogoo00Ioo`03OT1oogoo0?moo`Uoo`008goo00<007ooOol00goo00<Gh7oo
0n`00P?/0Woo00En@7ooOomoo`?/01=oo`035n1oogoo00Uoo`03In1oogoo00Eoo`03OT1oogoo0?mo
o`Yoo`008goo00<007ooOol00goo00@Gh7ooOomoo`L3k1=oo`035n1oogoo00Uoo`03In1oogoo00Io
o`03OT1oogoo0?moo`Yoo`008goo00<007ooOol017oo00@Gh7ooOomWh0=oo`03OT1oogoo019oo`03
5n1oogoo00Uoo`03In1oogoo00Ioo`03OT1oogoo0?moo`]oo`008goo0P001Goo00@Gh7ooOomWh0=o
o`03OT1oogoo015oo`035n1oogoo00Yoo`03In1oogoo00Ioo`03OT1oogoo0?moo`]oo`008goo00<0
07ooOol017oo00@Gh7ooOomWh0=oo`03OT1oogoo011oo`035n1oogoo00Yoo`03In1oogoo00Ioo`03
OT1oogoo0?moo`aoo`008goo00<007ooOol01Goo00@Gh7ooOomWh09oo`03OT1oogoo00moo`035n1o
ogoo00]oo`03In1oogoo00Eoo`03OT1oogoo0?moo`eoo`008goo00<007ooOol01Goo00@Gh7ooOomW
h09oo`03OT1oogoo00moo`035n1oogoo00Yoo`03In1oogoo00Ioo`03OT1oogoo0?moo`eoo`008goo
00<007ooOol01Goo00@Gh7ooOomWh09oo`03OT1oogoo00ioo`035n1oogoo00Yoo`03In1oogoo00Io
o`03OT1oogoo0?moo`ioo`008goo0P001goo00<Gh7ooIn000Woo00=n@7ooOol03Goo00<Gh7ooOol0
2goo00=Wh7ooOol01Goo00=n@7ooOol0ogoo3goo000SOol00`00Oomoo`06Ool00aOPOomWh003Ool0
0gi0Oomoo`0;Ool00aOPOomoo`0;Ool00fOPOomoo`06Ool00gi0Oomoo`3oOol?Ool000Qoo`D000Eo
o`8000Eoo`@000Ioo`03001oogoo00Ioo`035n1oofOP00=oo`03OT1oogoo00Yoo`035n1oogoo00]o
o`03In1oogoo00Ioo`03OT1oogoo0?mooa1oo`0027oo00D007ooOomoo`0000Eoo`8000Aoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Moo`035n1oofOP009oo`03OT1oogoo00Yoo`035n1o
ogoo00]oo`03In1oogoo00Ioo`03OT1oogoo0?mooa1oo`002Goo00<007ooOol04Goo00<007ooOol0
0goo00<007ooOol01goo00<Gh7ooIn000Woo00=n@7ooOol02Goo00<Gh7ooOol02goo00=Wh7ooOol0
1Woo00=n@7ooOol0ogoo4Goo000:Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool30008Ool01AOPIn1o
ogooOT002Woo00<Gh7ooOol037oo00=Wh7ooOol01Goo00=n@7ooOol0ogoo4Woo000;Ool00`00Oomo
o`0;Ool40006Ool00`00Oomoo`08Ool01AOPIn1oogooOT002Goo00<Gh7ooOol037oo00=Wh7ooOol0
1Woo00=n@7ooOol0ogoo4Woo000<Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`09Ool0
11OPOomoogi027oo00<Gh7ooOol037oo00=Wh7ooOol01Woo00=n@7ooOol0ogoo4goo0008Ool01@00
Oomoogoo000037oo00<007ooOol01goo00<007ooOol02Goo00@Gh7ooOomn@0Qoo`035n1oogoo00ao
o`03In1oogoo00Ioo`03OT1oogoo0?mooa=oo`002Goo0`003Goo1@001Goo00<007ooOol02Goo00EW
h1OPOomoogi000Ioo`035n1oogoo00aoo`03In1oogoo00Ioo`03OT1oogoo0?mooaAoo`008goo0P00
2goo00@Gh7ooOomn@0Aoo`8Gh0ioo`03In1oogoo00Moo`03OT1oogoo0?mooaAoo`008goo00<007oo
Ool02Woo00AWh1OP5n1n@0=oo`035n1oogoo00ioo`03In1oogoo00Ioo`03OT1oogoo0?mooaEoo`00
8goo00<007ooOol02Woo00=Wh7oo5n0011OP47oo00=Wh7ooOol01goo00=n@7ooOol0ogoo5Goo000S
Ool00`00Oomoo`0:Ool016OPOomoogi04Woo00=Wh7ooOol01goo00=n@7ooOol0ogoo5Woo000SOol0
0`00Oomoo`0:Ool016OPOomoogi04Woo00=Wh7ooOol01goo00=n@7ooOol0ogoo5Woo000SOol2000;
Ool016OPOomoogi04Goo00=Wh7ooOol01goo00=n@7ooOol0ogoo5goo000SOol00`00Oomoo`0;Ool0
16OPOomoogi03goo00=Wh7ooOol027oo00=n@7ooOol0ogoo5goo000SOol00`00Oomoo`0;Ool016OP
Oomoogi03goo00=Wh7ooOol01goo00=n@7ooOol0ogoo67oo000SOol00`00Oomoo`0;Ool016OPOomo
ogi03Woo00=Wh7ooOol027oo00=n@7ooOol0ogoo67oo000SOol2000<Ool016OPOomoogi03Goo00=W
h7ooOol027oo00=n@7ooOol0ogoo6Goo000SOol00`00Oomoo`0<Ool00fOPOomn@00=Ool00fOPOomo
o`08Ool00gi0Oomoo`3oOolIOol002=oo`03001oogoo00aoo`03In1oogi000aoo`03In1oogoo00Qo
o`03OT1oogoo0?mooaYoo`008goo00<007ooOol03Goo00=Wh7i0Ool02Woo00=Wh7ooOol02Goo00=n
@7ooOol0ogoo6Woo000SOol00`00Oomoo`0=Ool00fOPOT1oo`0:Ool00fOPOomoo`08Ool00gi0Oomo
o`3oOolKOol002=oo`8000moo`03In1oogoo00Qoo`03In1oogoo00Uoo`03OT1oogoo0?mooa]oo`00
8goo00<007ooOol03Woo00=Wh7ooOol01goo00=Wh7ooOol02Goo00=n@7ooOol0ogoo77oo000IOol3
0007Ool00`00Oomoo`0>Ool00fOPOomoo`07Ool00fOPOomoo`09Ool00gi0Oomoo`3oOolLOol001Qo
o`05001oogooOol00006Ool00`00Oomoo`0>Ool00fOPOomoo`06Ool00fOPOomoo`09Ool00gi0Oomo
o`3oOolMOol001aoo`03001oogoo00Aoo`03001oogoo00ioo`03OT1Wh7oo00Eoo`03In1oogoo00Uo
o`03OT1oogoo0?mooaioo`0077oo00<007ooOol017oo0`003goo00=n@6OPIn000Woo0VOP37oo00=n
@7ooOol0ogoo7Woo000JOol20007Ool00`00Oomoo`0?Ool00gi0OomWh003In0<Ool00gi0Oomoo`3o
OolOOol001aoo`03001oogoo00Aoo`03001oogoo00moo`03OT1oogoo00moo`03OT1oogoo0?mooamo
o`0067oo00D007ooOomoo`0000Ioo`03001oogoo00moo`03OT1oogoo00ioo`03OT1oogoo0?moob1o
o`006Goo0`001goo00<007ooOol047oo00=n@7ooOol03Goo00=n@7ooOol0ogoo87oo000SOol2000A
Ool00gi0Oomoo`0<Ool00gi0Oomoo`3oOolQOol002=oo`03001oogoo011oo`03OT1oogoo00aoo`03
OT1oogoo0?moob5oo`008goo00<007ooOol04Goo00=n@7ooOol02Woo00=n@7ooOol0ogoo8Woo000S
Ool00`00Oomoo`0AOol00gi0Oomoo`0:Ool00gi0Oomoo`3oOolROol002=oo`03001oogoo015oo`03
OT1oogoo00Uoo`03OT1oogoo0?moob=oo`008goo0P004goo00=n@7ooOol027oo00=n@7ooOol0ogoo
8goo000SOol00`00Oomoo`0BOol00gi0Oomoo`07Ool00gi0Oomoo`3oOolTOol002=oo`03001oogoo
01=oo`03OT1oogoo00Eoo`03OT1oogoo0?moobEoo`008goo00<007ooOol04goo00=n@7ooOol01Goo
00=n@7ooOol0ogoo9Goo000SOol00`00Oomoo`0COol00gi0Oomoo`04Ool00gi0Oomoo`3oOolVOol0
02=oo`8001Eoo`03OT1oogoo009oo`03OT1oogoo0?moobMoo`008goo00<007ooOol057oo1Gi0ogoo
:Woo000SOol00`00Oomoo`3oOom3Ool002=oo`03001oogoo0?mood=oo`008goo0P00ogooA7oo000S
Ool00`00Oomoo`3oOom3Ool002=oo`03001oogoo0?mood=oo`00ogooJGoo003oOomYOol00?moofUo
o`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003o
OomYOol00?moofUoo`00ogooJGoo000POol3003oOom6Ool0025oo`03001oogoo0?moodEoo`008Goo
00<007ooOol0ogooAGoo000QOol00`00Ool0003oOom5Ool0025oo`<00?moodEoo`008Goo00<007oo
0000ogooAGoo000QOol01@00Oomoogoo0000ogoo@goo000POol6003oOom3Ool00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.241336, -0.616962, \
0.00849577, 0.0259865}}]
}, Open  ]],

Cell[TextData[{
  "The second solution with ",
  Cell[BoxData[
      \(TraditionalForm\`C[1] = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C[2] = 1\)]],
  " has the graph "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[Table[
            F[\[Zeta]] /. 
              sheat\[LeftDoubleBracket]1, 1\[RightDoubleBracket], {c, 
              \(-2.1\), 2.1,  .5}] /. {C[1] \[Rule] 0, C[2] \[Rule] 1}], \n
      \t{\[Zeta], 0.01, 2}, AxesLabel \[Rule] {"\<\[Zeta]\>", "\<F\>"}, 
      PlotStyle \[Rule] Table[Hue[i\/10], {i, 1, 8}]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0995965 0.283835 [
[.2619 .0871 -9 -9 ]
[.2619 .0871 9 0 ]
[.5 .0871 -3 -9 ]
[.5 .0871 3 0 ]
[.7381 .0871 -9 -9 ]
[.7381 .0871 9 0 ]
[.97619 .0871 -3 -9 ]
[.97619 .0871 3 0 ]
[1.025 .0996 0 -7.5 ]
[1.025 .0996 10 7.5 ]
[.01131 .24151 -18 -4.5 ]
[.01131 .24151 0 4.5 ]
[.01131 .38343 -6 -4.5 ]
[.01131 .38343 0 4.5 ]
[.01131 .52535 -18 -4.5 ]
[.01131 .52535 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .0996 m
.2619 .10585 L
s
[(0.5)] .2619 .0871 0 1 Mshowa
.5 .0996 m
.5 .10585 L
s
[(1)] .5 .0871 0 1 Mshowa
.7381 .0996 m
.7381 .10585 L
s
[(1.5)] .7381 .0871 0 1 Mshowa
.97619 .0996 m
.97619 .10585 L
s
[(2)] .97619 .0871 0 1 Mshowa
.125 Mabswid
.07143 .0996 m
.07143 .10335 L
s
.11905 .0996 m
.11905 .10335 L
s
.16667 .0996 m
.16667 .10335 L
s
.21429 .0996 m
.21429 .10335 L
s
.30952 .0996 m
.30952 .10335 L
s
.35714 .0996 m
.35714 .10335 L
s
.40476 .0996 m
.40476 .10335 L
s
.45238 .0996 m
.45238 .10335 L
s
.54762 .0996 m
.54762 .10335 L
s
.59524 .0996 m
.59524 .10335 L
s
.64286 .0996 m
.64286 .10335 L
s
.69048 .0996 m
.69048 .10335 L
s
.78571 .0996 m
.78571 .10335 L
s
.83333 .0996 m
.83333 .10335 L
s
.88095 .0996 m
.88095 .10335 L
s
.92857 .0996 m
.92857 .10335 L
s
.25 Mabswid
0 .0996 m
1 .0996 L
s
gsave
1.025 .0996 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.02381 .24151 m
.03006 .24151 L
s
[(0.5)] .01131 .24151 1 0 Mshowa
.02381 .38343 m
.03006 .38343 L
s
[(1)] .01131 .38343 1 0 Mshowa
.02381 .52535 m
.03006 .52535 L
s
[(1.5)] .01131 .52535 1 0 Mshowa
.125 Mabswid
.02381 .12798 m
.02756 .12798 L
s
.02381 .15636 m
.02756 .15636 L
s
.02381 .18475 m
.02756 .18475 L
s
.02381 .21313 m
.02756 .21313 L
s
.02381 .2699 m
.02756 .2699 L
s
.02381 .29828 m
.02756 .29828 L
s
.02381 .32666 m
.02756 .32666 L
s
.02381 .35505 m
.02756 .35505 L
s
.02381 .41182 m
.02756 .41182 L
s
.02381 .4402 m
.02756 .4402 L
s
.02381 .46858 m
.02756 .46858 L
s
.02381 .49697 m
.02756 .49697 L
s
.02381 .07121 m
.02756 .07121 L
s
.02381 .04283 m
.02756 .04283 L
s
.02381 .01445 m
.02756 .01445 L
s
.02381 .55373 m
.02756 .55373 L
s
.02381 .58212 m
.02756 .58212 L
s
.02381 .6105 m
.02756 .6105 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(F) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .6 0 r
.5 Mabswid
.14976 0 m
.16671 .0767 L
.17759 .11354 L
.18752 .14118 L
.20651 .1818 L
.21724 .1992 L
.22716 .21251 L
.24574 .23171 L
.25631 .23999 L
.26623 .24637 L
.27602 .25155 L
.28632 .25598 L
.30473 .26179 L
.31423 .26392 L
.32437 .26567 L
.33395 .26688 L
.34265 .26767 L
.34747 .26799 L
.35258 .26825 L
.35694 .26841 L
.35942 .26848 L
.36173 .26853 L
.36301 .26855 L
.36441 .26857 L
.36505 .26857 L
.36573 .26858 L
.36695 .26859 L
.36824 .26859 L
.36945 .26859 L
.37054 .26859 L
.37171 .26858 L
.37301 .26857 L
.37443 .26856 L
.37591 .26854 L
.3773 .26852 L
.38243 .2684 L
.38743 .26823 L
.39285 .26801 L
.40272 .26748 L
.42119 .26614 L
.46182 .26209 L
.50095 .25734 L
.53856 .25243 L
.57861 .24708 L
.61716 .24198 L
.65815 .2367 L
.69762 .23182 L
.73559 .22733 L
.776 .22278 L
.81491 .21862 L
Mistroke
.85625 .21445 L
.89608 .21065 L
.93441 .20718 L
.97517 .2037 L
.97619 .20362 L
Mfstroke
.8 1 0 r
.10286 0 m
.10894 .03575 L
.11913 .08539 L
.13015 .12929 L
.14938 .18664 L
.15884 .20788 L
.16922 .22711 L
.18018 .24361 L
.19018 .25587 L
.20959 .27378 L
.22028 .28103 L
.2304 .28657 L
.24001 .29082 L
.25021 .29443 L
.25977 .2971 L
.26854 .29903 L
.27786 .30061 L
.28266 .30126 L
.28791 .30186 L
.29677 .30261 L
.3016 .30291 L
.3061 .30311 L
.30871 .30321 L
.31112 .30327 L
.31377 .30333 L
.3151 .30335 L
.31586 .30336 L
.31657 .30336 L
.31786 .30337 L
.31903 .30338 L
.3203 .30338 L
.32101 .30338 L
.32168 .30338 L
.32289 .30337 L
.32399 .30337 L
.32526 .30335 L
.32646 .30334 L
.32871 .3033 L
.33109 .30325 L
.33535 .30313 L
.33993 .30297 L
.34495 .30274 L
.3644 .30151 L
.38522 .29969 L
.42643 .29511 L
.46613 .29001 L
.50432 .28485 L
.54495 .27932 L
.58407 .27408 L
.62168 .26918 L
Mistroke
.66174 .26417 L
.70028 .25955 L
.74127 .25487 L
.78075 .25059 L
.81872 .24668 L
.85913 .24271 L
.89803 .23909 L
.93937 .23544 L
.97619 .23235 L
Mfstroke
.2 1 0 r
.02857 .04603 m
.0332 .04456 L
.03541 .04382 L
.0365 .04349 L
.0375 .04325 L
.03869 .04307 L
.03998 .04307 L
.04107 .04325 L
.04223 .04368 L
.04347 .04443 L
.04464 .04542 L
.04591 .04685 L
.04729 .04879 L
.04981 .05341 L
.05257 .05989 L
.05759 .07476 L
.06701 .10858 L
.08731 .1808 L
.09844 .21309 L
.10894 .2382 L
.11913 .2582 L
.13015 .27573 L
.14938 .29833 L
.15884 .30655 L
.16922 .31387 L
.18018 .32002 L
.19018 .32445 L
.19948 .32775 L
.20959 .33058 L
.22028 .33286 L
.2304 .33445 L
.23975 .3355 L
.24508 .33595 L
.25008 .33628 L
.25263 .33642 L
.25532 .33654 L
.26013 .33671 L
.26282 .33678 L
.26531 .33682 L
.26675 .33684 L
.26805 .33686 L
.26877 .33686 L
.26956 .33687 L
.2703 .33687 L
.27098 .33687 L
.27223 .33687 L
.27341 .33687 L
.27447 .33686 L
.27563 .33685 L
.27688 .33684 L
Mistroke
.27822 .33683 L
.28062 .33679 L
.28536 .33668 L
.28965 .33654 L
.30023 .33609 L
.31018 .33552 L
.3302 .33404 L
.34859 .33237 L
.38794 .32819 L
.42577 .32374 L
.46604 .31881 L
.50481 .31407 L
.54602 .30912 L
.58571 .3045 L
.6239 .30022 L
.66453 .29586 L
.70366 .29184 L
.74127 .28815 L
.78132 .28439 L
.81987 .28094 L
.86086 .27745 L
.90033 .27423 L
.9383 .27128 L
.97619 .26846 L
Mfstroke
0 1 .4 r
.02857 .26737 m
.06701 .30162 L
.08702 .32392 L
.09837 .33373 L
.10894 .34109 L
.12796 .35082 L
.13862 .3547 L
.14831 .35747 L
.15822 .35969 L
.16736 .36128 L
.1774 .36261 L
.18296 .36318 L
.18804 .36361 L
.19741 .36421 L
.20257 .36444 L
.20495 .36453 L
.20748 .3646 L
.20985 .36466 L
.21199 .36471 L
.21418 .36475 L
.21619 .36477 L
.21733 .36478 L
.21854 .36479 L
.21975 .3648 L
.22044 .3648 L
.22108 .36481 L
.22224 .36481 L
.2233 .36481 L
.22453 .36481 L
.22569 .3648 L
.22682 .36479 L
.22804 .36479 L
.23025 .36476 L
.23288 .36473 L
.23529 .36469 L
.24026 .36458 L
.2455 .36444 L
.25425 .36414 L
.26383 .36372 L
.30418 .36131 L
.34303 .35836 L
.38432 .35494 L
.42411 .35154 L
.46238 .34828 L
.50309 .34488 L
.5423 .3417 L
.58 .33875 L
.62014 .33572 L
.65877 .33292 L
.69984 .33006 L
Mistroke
.7394 .32743 L
.77745 .325 L
.81795 .32252 L
.85693 .32023 L
.89836 .31789 L
.93828 .31573 L
.97619 .31375 L
Mfstroke
0 1 1 r
.02857 .37387 m
.06701 .37764 L
.08702 .37945 L
.09837 .38019 L
.10894 .38072 L
.1189 .38111 L
.12796 .38137 L
.13298 .38148 L
.13842 .38159 L
.14353 .38166 L
.14831 .38172 L
.15284 .38177 L
.1577 .3818 L
.16047 .38182 L
.16311 .38183 L
.16547 .38184 L
.16671 .38184 L
.16805 .38185 L
.16879 .38185 L
.16947 .38185 L
.17011 .38185 L
.1708 .38185 L
.17202 .38185 L
.1733 .38185 L
.17403 .38185 L
.1747 .38185 L
.17547 .38185 L
.1762 .38185 L
.17749 .38185 L
.1789 .38185 L
.18144 .38184 L
.18413 .38183 L
.18897 .38181 L
.19384 .38179 L
.1983 .38176 L
.20835 .38168 L
.22654 .38149 L
.26596 .38094 L
.30388 .38032 L
.34424 .37962 L
.38309 .37893 L
.42438 .37821 L
.46416 .37752 L
.50243 .37688 L
.54315 .37621 L
.58235 .3756 L
.62005 .37503 L
.66019 .37444 L
.69882 .37389 L
.73989 .37333 L
Mistroke
.77945 .37282 L
.81751 .37233 L
.858 .37184 L
.89699 .37137 L
.93841 .3709 L
.97619 .37048 L
Mfstroke
0 .4 1 r
.02857 .3926 m
.04729 .38935 L
.06701 .38583 L
.07737 .38441 L
.08702 .38343 L
.09257 .38299 L
.09761 .38268 L
.1004 .38254 L
.10343 .38241 L
.10609 .38231 L
.10894 .38222 L
.11147 .38216 L
.11379 .38212 L
.1149 .3821 L
.11612 .38209 L
.11726 .38207 L
.11833 .38206 L
.11898 .38206 L
.11969 .38206 L
.12093 .38205 L
.12163 .38205 L
.12237 .38205 L
.123 .38205 L
.1237 .38205 L
.12494 .38205 L
.12564 .38206 L
.12627 .38206 L
.12868 .38208 L
.12997 .3821 L
.13135 .38211 L
.13382 .38215 L
.13942 .38227 L
.14426 .38241 L
.1496 .38259 L
.16885 .38347 L
.1896 .38471 L
.23054 .38769 L
.26996 .39091 L
.30788 .39413 L
.34824 .39758 L
.38709 .40087 L
.42838 .4043 L
.46816 .40752 L
.50643 .41053 L
.54715 .41365 L
.58635 .41656 L
.62405 .41928 L
.66419 .42209 L
.70282 .42472 L
.74389 .42743 L
Mistroke
.78345 .42997 L
.82151 .43235 L
.862 .43481 L
.90099 .43712 L
.94241 .43951 L
.97619 .44141 L
Mfstroke
.2 0 1 r
.02857 .36073 m
.0375 .36027 L
.04729 .35976 L
.05222 .35955 L
.05493 .35945 L
.0575 .35938 L
.05866 .35935 L
.05989 .35933 L
.06053 .35932 L
.06124 .35931 L
.06248 .3593 L
.06361 .3593 L
.06482 .35929 L
.06597 .3593 L
.06701 .3593 L
.06771 .35931 L
.06837 .35932 L
.06959 .35934 L
.07091 .35936 L
.07234 .3594 L
.07492 .35948 L
.07729 .35958 L
.08274 .35987 L
.08851 .36028 L
.09825 .3612 L
.10894 .36247 L
.14916 .36903 L
.18787 .37682 L
.22903 .38578 L
.26867 .39463 L
.30681 .40317 L
.34739 .41217 L
.38646 .42069 L
.42402 .42874 L
.46402 .43713 L
.50252 .44502 L
.54345 .45324 L
.58288 .46097 L
.6208 .46824 L
.66115 .47582 L
.7 .48297 L
.74129 .4904 L
.78108 .49742 L
.81935 .50404 L
.86007 .51096 L
.89927 .51749 L
.93697 .52366 L
.97619 .52997 L
s
.8 0 1 r
.02857 .30839 m
.06701 .31864 L
.10894 .33244 L
.14831 .34697 L
.18618 .36152 L
.22648 .37721 L
.26528 .39231 L
.30652 .40824 L
.34625 .42343 L
.38447 .43787 L
.42513 .45303 L
.46429 .46743 L
.50193 .48109 L
.54202 .49545 L
.5806 .5091 L
.62162 .52342 L
.66113 .53705 L
.69913 .55 L
.73957 .56362 L
.77851 .57659 L
.81988 .59022 L
.85975 .6032 L
.8981 .61557 L
s
.8981 .61557 m
.90581 .61803 L
s
1 .6 0 r
.02857 .2544 m
.06701 .27557 L
.10894 .29897 L
.14831 .3211 L
.18618 .34242 L
.22648 .3651 L
.26528 .3869 L
.30652 .41002 L
.34625 .43224 L
.38447 .45357 L
.42513 .4762 L
.46429 .49793 L
.50193 .51878 L
.54202 .54093 L
.5806 .5622 L
.62162 .58476 L
.66113 .60644 L
s
.66113 .60644 m
.68229 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{Inherited, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005e0000ia000`40O003h00O77oo00<007ooOol0
5goo00=Wh7ooOol03Goo00=n@7ooOol0ogoo;Goo000LOol00`00Oomoo`0GOol00fOPOomoo`0=Ool0
0gi0Oomoo`3oOol]Ool001aoo`03001oogoo01Moo`03In1oogoo00eoo`03OT1oogoo0?moobeoo`00
77oo00<007ooOol067oo00=Wh7ooOol03Goo00=n@7ooOol0ogoo;7oo000LOol00`00Oomoo`0HOol0
0fOPOomoo`0=Ool00gi0Oomoo`3oOol/Ool001aoo`<001Qoo`03In1oogoo00eoo`03OT1oogoo0?mo
obaoo`0077oo00<007ooOol067oo00=Wh7ooOol03Goo00=n@7ooOol0ogoo;7oo000LOol00`00Oomo
o`0HOol00fOPOomoo`0=Ool00gi0Oomoo`3oOol/Ool001aoo`03001oogoo01Qoo`03In1oogoo00io
o`03OT1oogoo0?moob]oo`0077oo00<007ooOol06Goo00=Wh7ooOol03Goo00=n@7ooOol0ogoo:goo
000LOol00`00Oomoo`0IOol00fOPOomoo`0=Ool00gi0Oomoo`3oOol[Ool001aoo`03001oogoo01Uo
o`03In1oogoo00eoo`03OT1oogoo0?moob]oo`0077oo00<007ooOol06Goo00=Wh7ooOol03Goo00=n
@7ooOol0ogoo:goo000LOol00`00Oomoo`0IOol00fOPOomoo`0>Ool00gi0Oomoo`3oOolZOol001ao
o`<0009oo`8Gh1Ioo`03In1oogoo00eoo`03OT1oogoo0?moobYoo`0077oo00<007oo5n000QOP00=o
oaOP5n005Goo00=Wh7ooOol03Goo00=n@7ooOol0ogoo:Woo000LOol00`00Oomoo`05Ool00aOPOomo
o`0BOol00fOPOomoo`0=Ool00gi0Oomoo`3oOolZOol001aoo`03001oogoo00Ioo`035n1oogoo015o
o`03In1oogoo00eoo`03OT1oogoo0?moobYoo`0077oo00<007ooOol01Woo00<Gh7ooOol04Woo00=W
h7ooOol03Goo00=n@7ooOol057oo10001Goo0P001Goo1000@Woo1@00@Goo1@0017oo0P001Goo1000
@Woo1@007Goo000LOol00`00Oomoo`07Ool00aOPOomoo`0AOol00fOPOomoo`0=Ool00gi0Oomoo`0C
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`11Ool00`00
Oomoo`13Ool00`00Oomoo`04Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0oOol01@00Oomoogoo
00007Goo000LOol00`00Oomoo`07Ool00aOPOomoo`0AOol00fOPOomoo`0=Ool00gi0Oomoo`0COol0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`11Ool00`00Oomoo`13Ool00`00Oomoo`0?Ool0
0`00Oomoo`10Ool00`00Oomoo`0NOol001aoo`03001oogoo00Moo`035n1oogoo015oo`03In1oogoo
00eoo`03OT1oogoo01=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo045oo`03001oogoo
04=oo`03001oogoo00moo`03001oogoo045oo`03001oogoo01eoo`0077oo00<007ooOol01goo00<G
h7ooOol04Woo00=Wh7ooOol037oo00=n@7ooOol04goo00<007ooOol00Woo00<007ooOol02Goo1000
A7oo00<007ooOol0@goo00<007ooOol02goo1000AGoo00<007ooOol077oo000LOol00`00Oomoo`08
Ool00aOPOomoo`0AOol00fOPOomoo`0=Ool00gi0Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`09
Ool00`00Oomoo`15Ool00`00Oomoo`13Ool00`00Oomoo`0;Ool00`00Oomoo`17Ool00`00Oomoo`0K
Ool001aoo`<000Qoo`035n1oogoo015oo`03In1oogoo00eoo`03OT1oogoo019oo`03001oogoo009o
o`03001oogoo00Uoo`03001oogoo04=oo`<004=oo`<000eoo`03001oogoo04=oo`05001oogooOol0
000MOol001aoo`03001oogoo00Qoo`035n1oogoo015oo`03In1oogoo00eoo`03OT1oogoo01=oo`@0
00aoo`D004=oo`03001oogoo04=oo`03001oogoo00]oo`D0049oo`<001ioo`0077oo00<007ooOol0
27oo00<Gh7ooOol04Woo00=Wh7ooOol037oo00=n@7ooOol0ogoo:7oo000LOol00`00Oomoo`09Ool0
0aOPOomoo`0AOol00fOPOomoo`0=Ool00gi0Oomoo`3oOolWOol001aoo`03001oogoo00Uoo`035n1o
ogoo015oo`03In1oogoo00eoo`03OT1oogoo0?mooa]oo`@000Qoo`0077oo00<007ooOol02Goo00<G
h7ooOol04Goo00=Wh7ooOol03Goo00=n@7ooOol0ogoo6Woo00<007ooOol00Woo00<007ooOol01Goo
000LOol00`00Oomoo`09Ool00aOPOomoo`0AOol00fOPOomoo`0>Ool00gi0Oomoo`3oOolKOol30008
Ool001aoo`03001oogoo00Yoo`035n1oogoo015oo`03In1oogoo00eoo`03OT1oogoo0?mooaYoo`03
001oogoo00Uoo`0077oo00<007ooOol02Woo00<Gh7ooOol04Goo00=Wh7ooOol03Goo00=n@7ooOol0
ogoo6Woo00<007ooOol02Goo000DOolE00000aOP0000000A00000fOP0000000=00000gi00000003o
000?000;Ool00`00Oomoo`09Ool001aoo`03001oogoo00Yoo`045n1oogoo000?Ool00`00In1oo`0<
Ool01000Oomoogi037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol0
3Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol0
3Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol0
37oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol027oo000LOol00`00
Oomoo`0;Ool00aOPOomoo`0@Ool00fOPOomoo`0>Ool00gi0Oomoo`0JOol00`00Oomoo`1;Ool00`00
Oomoo`1;Ool00`00Oomoo`1<Ool00`00Oomoo`0BOol30007Ool001aoo`03001oogoo00]oo`035n1o
ogoo015oo`03In1oogoo00eoo`03OT1oogoo0?mooaYoo`80009oo`03001oogoo00Aoo`0077oo00<0
07ooOol02goo00<Gh7ooOol04Goo00=Wh7ooOol03Woo00=n@7ooOol0ogoo6goo0`001Woo000LOol0
0`00Oomoo`0<Ool00aOPOomoo`0@Ool00fOPOomoo`0>Ool00gi0Oomoo`3oOolTOol001aoo`03001o
ogoo00aoo`035n1oogoo011oo`03In1oogoo00ioo`03OT1oogoo0?moobAoo`0077oo00<007ooOol0
37oo00<Gh7ooOol047oo00=Wh7ooOol03goo00=n@7ooOol0ogoo8goo000LOol00`00Oomoo`0<Ool0
0aOPOomoo`0AOol00fOPOomoo`0>Ool00gi0Oomoo`3oOolSOol001aoo`<000eoo`035n1oogoo011o
o`03In1oogoo00ioo`03OT1oogoo0?moob=oo`0077oo00<007ooOol03Goo00<Gh7ooOol047oo00=W
h7ooOol03goo00=n@7ooOol0ogoo8Woo000LOol00`00Oomoo`0=Ool00aOPOomoo`0@Ool00fOPOomo
o`0?Ool00gi0Oomoo`3oOolROol001aoo`03001oogoo00ioo`035n1oogoo011oo`03In1oogoo00io
o`03OT1oogoo0?moob9oo`0077oo00<007ooOol03Woo00<Gh7ooOol047oo00=Wh7ooOol03goo00=n
@7ooOol0ogoo8Goo000LOol00`00Oomoo`0>Ool00aOPOomoo`0@Ool00fOPOomoo`0?Ool00gi0Oomo
o`3oOolQOol001aoo`03001oogoo00moo`035n1oogoo011oo`03In1oogoo00ioo`03OT1oogoo0?mo
ob5oo`0077oo00<007ooOol03goo00<Gh7ooOol047oo00=Wh7ooOol03goo00=n@7ooOol0ogoo87oo
000LOol00`00Oomoo`0?Ool00aOPOomoo`0AOol00fOPOomoo`0>Ool00gi0Oomoo`3oOolPOol001ao
o`03001oogoo00moo`035n1oogoo015oo`03In1oogoo00moo`03OT1oogoo0?mooamoo`0077oo0`00
47oo00<Gh7ooOol047oo00=Wh7ooOol03goo00=n@7ooOol0ogoo7goo000LOol00`00Oomoo`0@Ool0
0aOPOomoo`0AOol00fOPOomoo`0?Ool00gi0Oomoo`3oOolNOol001aoo`03001oogoo011oo`035n1o
ogoo015oo`03In1oogoo00moo`03OT1oogoo0?mooaioo`0077oo00<007ooOol04Goo00<Gh7ooOol0
47oo00=Wh7ooOol047oo00=n@7ooOol0ogoo7Goo000LOol00`00Oomoo`0AOol00aOPOomoo`0AOol0
0fOPOomoo`0?Ool00gi0Oomoo`3oOolMOol001aoo`03001oogoo015oo`035n1oogoo015oo`03In1o
ogoo011oo`03OT1oogoo0?mooaaoo`0077oo00<007ooOol04Goo00<Gh7ooOol04Woo00=Wh7ooOol0
3goo00=n@7ooOol0ogoo77oo000LOol00`00Oomoo`0BOol00aOPOomoo`0AOol00fOPOomoo`0@Ool0
0gi0Oomoo`3oOolKOol001aoo`03001oogoo019oo`035n1oogoo015oo`03In1oogoo011oo`03OT1o
ogoo0?mooa]oo`0077oo0`004Woo00<Gh7ooOol04Woo00=Wh7ooOol047oo00=n@7ooOol0ogoo6Woo
000LOol00`00Oomoo`0COol00aOPOomoo`0AOol00fOPOomoo`0@Ool00gi0Oomoo`3oOolJOol001ao
o`03001oogoo01=oo`035n1oogoo015oo`03In1oogoo015oo`03OT1oogoo0?mooaUoo`0077oo00<0
07ooOol057oo00<Gh7ooOol04Goo00=Wh7ooOol04Goo00=n@7ooOol0ogoo67oo000LOol00`00Oomo
o`0DOol00aOPOomoo`0AOol00fOPOomoo`0AOol00gi0Oomoo`3oOolHOol001aoo`03001oogoo01Ao
o`035n1oogoo019oo`03In1oogoo015oo`03OT1oogoo0?mooaMoo`0077oo00<007ooOol05Goo00<G
h7ooOol04Goo00=Wh7ooOol04Woo00=n@7ooOol0kgoo27i07Woo000LOol00`00Oomoo`0EOol00aOP
Oomoo`0BOol00fOPOomoo`0BOol00gi0Oomoo`3TOol:OT0VOol001aoo`03001oogoo01Ioo`035n1o
ogoo015oo`03In1oogoo019oo`03OT1oogoo0=ioo`In@31oo`0077oo0`005Woo00<Gh7ooOol04Woo
00=Wh7ooOol04Woo00=n@7ooOol0dgoo2Wi0=Woo000LOol00`00Oomoo`0FOol00aOPOomoo`0BOol0
0fOPOomoo`0COol00gi0Oomoo`35Ool=OT10Ool001aoo`03001oogoo01Moo`035n1oogoo019oo`03
In1oogoo01=oo`03OT1oogoo0;Yoo`Yn@4eoo`0077oo00<007ooOol05goo00<Gh7ooOol04Woo00=W
h7ooOol057oo00=n@7ooOol0/goo1Wi0Egoo000LOol00`00Oomoo`0GOol00aOPOomoo`0COol00fOP
Oomoo`0DOol00gi0Oomoo`2XOol:OT1MOol001aoo`03001oogoo01Qoo`035n1oogoo019oo`03In1o
ogoo01Eoo`03OT1oogoo09Yoo`en@6Moo`0077oo00<007ooOol067oo00<Gh7ooOol04goo00=Wh7oo
Ool05Goo00=n@7ooOol0Sgoo2Wi0M7oo0002Ool40005Ool20005Ool40006Ool00`00Oomoo`0HOol0
0aOPOomoo`0DOol00fOPOomoo`0EOol00gi0Oomoo`28Ool6OT1IOol7In0NOol00003Ool007oo00=o
o`03001oogoo009oo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01Uoo`035n1o
ogoo01=oo`03In1oogoo01Ioo`9n@85oo`Mn@59oo`eWh2Eoo`0000=oo`00Ool00goo00<007ooOol0
3Goo00<007ooOol00goo00<007ooOol06Goo00<Gh7ooOol057oo00=Wh7ooOol05goo00=n@7ooOol0
Mgoo1gi0C7oo3FOP<Woo00000goo001oo`03Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool3000JOol0
0aOPOomoo`0DOol00fOPOomoo`0GOol2OT1aOol6OT16Ool=In0oOol00003Ool007oo00=oo`03001o
ogoo00Uoo`@000Ioo`03001oogoo01Yoo`035n1oogoo01Eoo`03In1oogoo01Qoo`03OT1oogoo06Qo
o`In@49oo`YWh4aoo`0000=oo`00Ool00goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
6goo00<Gh7ooOol05Goo00=Wh7ooOol067oo0Wi0GWoo2Wi0@Woo1VOPEWoo00000goo001oo`03Ool0
0`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`0LOol00aOPOomoo`0DOol00fOPOomoo`0JOol2
OT1BOol:OT12Ool:In1LOol0009oo`@000aoo`D000Eoo`03001oogi001aoo`035n1oogoo01Eoo`03
In1oogoo01]oo`An@4Qoo`In@49oo`YWh6Ioo`0077oo00<007ooOol00Wi06goo00<Gh7ooOol05Goo
00=Wh7ooOol07Woo0gi0>goo2Wi0@Woo1VOPL7oo000LOol00`00Oomoo`02Ool2OT0JOol00aOPOomo
o`0EOol00fOPOomoo`0POol3OT0^Ool:OT12Ool:In1fOol001aoo`03001oogoo00Aoo`03OT1oogoo
01Moo`035n1oogoo01Ioo`03In1oogoo029oo`=n@2Eoo`In@49oo`YWh81oo`0077oo00<007oo0n`0
1Goo0Wi067oo00<Gh7ooOol05Woo00=Wh7ooOol097oo2gi02goo3gi0@Woo1VOPRWoo000LOol30000
0`?/Oomoo`04Ool2OT0FOol00aOPOomoo`0GOol00fOPOomoo`0^Ool;OT18Ool9In1OOolC5n0NOol0
01aoo`05001oogooOol3k007Ool2OT0EOol00aOPOomoo`0GOol00fOPOomoo`1fOol:In1NOol:5n0a
Ool001aoo`03001oogoo009oo`030naoogoo00Ioo`03OT1oogoo019oo`035n1oogoo01Qoo`03In1o
ogoo06moo`IWh69oo`HGh3]oo`0077oo00<007ooOol00goo00<3k7ooOol01Woo0Wi04goo00<Gh7oo
Ool067oo0VOPJ7oo1fOPGWoo2QOP@Goo000LOol00`00Oomoo`04Ool00`?/Oomoo`07Ool2OT0BOol0
0aOPOomoo`0IOol00fOPOomoo`1NOol7In1GOol>5n1;Ool001aoo`03001oogoo00Eoo`83k0Uoo`9n
@15oo`035n1oogoo01Uoo`9Wh5Qoo`IWh55oo`dGh5Uoo`0077oo00<007ooOol01goo00<3k7ooOol0
27oo00=n@7ooOol03goo00<Gh7ooOol06Woo0VOPD7oo1VOPBgoo31OPIWoo000LOol00`00Oomoo`08
Ool00`?/Oomoo`08Ool2OT0@Ool00aOPOomoo`0KOol3In13Ool:In17Ool:5n1bOol001aoo`03001o
ogoo00Uoo`030naoogoo00Uoo`9n@0moo`035n1oogoo01eoo`AWh3Eoo`YWh4]oo`HGh7aoo`0077oo
0`002Woo00<3k7ooOol02Woo0Wi03Woo00<Gh7ooOol087oo0fOP:goo1fOPBgoo2QOPPWoo000LOol0
0`00Oomoo`0;Ool00`?/Oomoo`0;Ool00gi0Oomoo`0<Ool00aOPOomoo`0ROol6In0HOol=In15Ool=
5n2<Ool001aoo`03001oogoo00aoo`030naoogoo00]oo`9n@0eoo`035n1oogoo02MooaQWh4Qoo`XG
h9Uoo`0077oo00<007ooOol03Goo00<3k7ooOol037oo0Wi037oo00<Gh7ooOol0P7oo1QOPXgoo000L
Ool01000OomT7f@O3Goo00<3k7ooOol03Goo0Wi02goo0QOPNGoo1aOPZGoo000LOol01000Oomoogoo
16@O2Woo00<3k7ooOol03Woo0Wi02goo00<Gh7ooOol0Kgoo1aOPRgoo1`?/7Woo000LOol00`00Oomo
o`05Ool4I1l6Ool00`?/Oomoo`0@Ool2OT0:Ool00aOPOomoo`1UOol95n25Ool=0n`UOol001aoo`03
001oogoo00Uoo`AT7`=oo`030naoogoo015oo`9n@0Uoo`8Gh5]oo`XGh85oo`d3k39oo`0077oo00<0
07ooOol03Goo0f@O00=oo`?/Ool04goo00=n@7ooOol027oo0QOPDWoo1aOPL7oo6`?/?goo000LOol0
0`00Oomoo`0@Ool2I1l00`?/Oomoo`0BOol2OT0:Ool35n16Ool95n1[Ool<0naJOol001aoo`<0019o
o`=T7aAoo`9n@0]oo`<Gh3Uoo`XGh6Moo`d3k6Ioo`0077oo00<007ooOol057oo00@3k6@OI1mT7a=o
o`9n@0aoo`<Gh31oo`HGh6Aoo`d3k7=oo`0077oo00<007ooOol05Woo00<3k7ooI1l00V@O4Woo0Wi0
3Goo1aOP77oo3AOPG7oo3P?/P7oo000LOol00`00Oomoo`0GOol20n`2Ool3I1lAOol2OT0BOolL5n1L
Ool=0nb>Ool001aoo`03001oogoo01Uoo`030naoogoo009oo`AT7`moo`9n@7aoo``3k9]oo`0077oo
00<007ooOol06Woo0P?/1Woo0f@O3Woo00=n@7ooOol0K7oo3@?/Ygoo000LOol00`00Oomoo`0LOol2
0n`7Ool3I1l<Ool2OT1OOol=0nbdOol001aoo`03001oogoo01ioo`83k0Qoo`9T7`aoo`9n@51oo`d3
k<5oo`0077oo00<007ooOol087oo0P?/27oo0f@O2goo0Wi0@Goo3@?/cWoo000LOol3000ROol30n`8
Ool3I1l:Ool2OT0bOol=0ncKOol001aoo`03001oogoo00Qoo`LD7aIoo`<3k0Qoo`9T7`Yoo`9n@29o
o`h3k>Qoo`0077oo00<007oo51l021@O1goo3A@O37oo1P?/17oo0f@O2Goo0Wi04goo3@?/mWoo000L
Ool00`00Oomoo`0LOol451l>Ool70n`2I1l90n`00gi00n`3k00@0ncoOol4Ool001aoo`03001oogoo
021oo`DD7a9oo`=T7`Moo`9n@?mooaAoo`0077oo00<007ooOol09Goo1A@O47oo0f@O1Woo0Wi0dWoo
8@?o7Woo000BOol50005Ool00`00Ool3o`050olUOol651l=Ool2I1l6Ool00gi0Oomoo`21Oom>0olo
Ool001Aoo`03001oogoo00Eoo`03001oogoo00Eoo`X3ob5oo`HD7`Uoo`=T7`Aoo`9n@41ood43oheo
o`0057oo00<007ooOol01Goo00<007ooOol03goo30?o6goo11@O27oo0V@O17oo00=n@7ooOol02Goo
=0?ocWoo000DOol00`00Oomoo`05Ool3000AOolP0Il90ol551l50ol3I1l20ol2OT090oooOol3Ool0
01Aoo`03001oogoo00Eoo`03001oogoo00Uoo`P1Wb1oo`X1W`Aoo`DD7`=oo`=T7`03Oomn@7i00?mo
o`Yoo`0057oo00<007ooOol01Goo00<007ooOol00goo1P6O<Woo2@6O11@O0Woo0V@O00=oogi0Ool0
ogoo27oo000BOol30007Ool00`00Ool1W`030Im5Ool451l2I1l2OT050IooOol2Ool001Aoo`03001o
ogoo00Eoo`03001oogoo04aoo`<D7`03I1mn@7i000=oo`d1WoAoo`0077oo00<007ooOol0D7oo00@D
7f@OOT1n@0ioo`d1WnMoo`0077oo00<007ooOol0Dgoo00=T7gi0OT000Q@O5goo3@6OfWoo000LOol0
0`00Oomoo`1EOol00f@OOT1n@00551lOOol=0Io=Ool001aoo`03001oogoo05Moo`03I1mn@7i000=o
o`@D7bQoo`d1Wl1oo`0077oo00<007ooOol0FGoo00=T7gi0I1l01Goo1A@O<7oo3@6O/goo000LOol3
001KOol2OT000f@OOomoo`06Ool551lhOol=0InVOol001aoo`03001oogoo05eoo`9n@09T7`Yoo`@D
7d5oo`d1WiUoo`0077oo00<007ooOol0Ggoo0Wi00f@O2goo11@OBWoo3@6OS7oo000LOol00`00Oomo
o`1QOol2OT000gooI1mT7`0=Ool551mBOol=0ImoOol001aoo`03001oogoo06=oo`9n@004OomT7f@O
I1l?Ool651mIOol=0ImbOol001aoo`03001oogoo06Eoo`9n@09oo`=T7a9oo`HD7f1oo`d1WfEoo`00
77oo00<007ooOol0Igoo00=n@7ooOol00Woo16@O57oo11@OJGoo6P6OBgoo000LOol00`00Oomoo`1X
Ool2OT06Ool3I1lEOol451moOol=0IlnOol001aoo`03001oogoo06Yoo`9n@0Moo`=T7aIoo`DD7hMo
o`d1Wc5oo`0077oo0`00K7oo0Wi027oo0V@O6Goo11@OT7oo4`6O7Woo000LOol00`00Oomoo`1^Ool2
OT08Ool3I1lJOol451nmOol001aoo`03001oogoo071oo`9n@0Uoo`=T7a]oo`HD7kMoo`0077oo00<0
07ooOol0LWoo0Wi02Woo0V@O7goo1Q@O/Goo000LOol00`00Oomoo`1dOol00gi0Oomoo`09Ool3I1lR
Ool651n[Ool001aoo`03001oogoo07Eoo`9n@0aoo`9T7bIoo`@D7jMoo`0077oo00<007ooOol0Mgoo
0Wi037oo0f@O9goo11@OXgoo000LOol00`00Oomoo`1iOol00gi0Oomoo`0<Ool3I1lXOol651nMOol0
01aoo`03001oogoo07Yoo`9n@0moo`9T7baoo`HD7iMoo`0077oo0`00O7oo00=n@7ooOol03Woo0f@O
;goo1Q@OTGoo000LOol00`00Oomoo`1mOol2OT0AOol3I1lbOol451n=Ool001aoo`03001oogoo07mo
o`9n@19oo`AT7c9oo`@D7hUoo`0077oo00<007ooOol0PGoo00=n@7ooOol04goo0f@O<goo1Q@OPgoo
000LOol00`00Oomoo`22Ool2OT0FOol3I1lfOol651mmOol001aoo`03001oogoo08Aoo`9n@1Moo`9T
7cYoo`HD7gMoo`0077oo00<007ooOol0QWoo0Wi05goo0f@O?Goo11@OLgoo000LOol00`00Oomoo`28
Ool2OT0HOol3I1lnOol451m_Ool001aoo`03001oogoo08Yoo`9n@1Uoo`9T7d1oo`HD7fUoo`0077oo
00<007ooOol0S7oo0Wi06Goo0f@O@goo1Q@OHgoo000LOol3002>Ool00gi0Oomoo`0IOol2I1m7Ool7
51mLOol001aoo`03001oogoo08moo`9n@1]oo`9T7daoo`HD7eIoo`0077oo00<007ooOol0TGoo0Wi0
6goo0f@OCgoo1a@OCgoo000LOol00`00Oomoo`2COol2OT0LOol2I1mDOol651m9Ool001aoo`03001o
ogoo09Eoo`9n@1aoo`=T7eMoo`LD7d9oo`0077oo00<007ooOol0Ugoo0Wi07Goo16@OFWoo1Q@O?7oo
0002Ool50004Ool20005Ool40006Ool00`00Oomoo`2IOol2OT0OOol3I1mMOol751leOol000Aoo`03
001oogoo00Aoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo09]oo`03OT1oogoo
01moo`AT7f1oo`HD7bmoo`0017oo00<007ooOol03goo00<007ooOol00goo00<007ooOol0W7oo0Wi0
8goo0f@OHgoo1Q@O:Goo0004Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3002NOol2OT0TOol2I1mW
Ool451lUOol000Aoo`03001oogoo00]oo`@000Ioo`03001oogoo0:1oo`9n@2Aoo`=T7fQoo`@D7b5o
o`0017oo00<007ooOol02goo00<007ooOol01goo00<007ooOol0XWoo0Wi09Goo0f@OJGoo0a@O7Woo
0002Ool3000=Ool00`00Oomoo`07Ool00`00Oomoo`2TOol2OT0VOol2I1n8Ool000Aoo`03001oogoo
00]oo`D000Eoo`03001oogoo0:Ioo`9n@2Ioo`=T7hEoo`0077oo00<007ooOol0Z7oo00=n@7ooOol0
9Woo0f@OPWoo000LOol00`00Oomoo`2YOol2OT0YOol3I1moOol001aoo`03001oogoo0:]oo`9n@2Yo
o`=T7gaoo`0077oo00<007ooOol0[Goo00=n@7ooOol0:Woo0f@ONGoo000LOol3002^Ool2OT0]Ool3
I1mfOol001aoo`03001oogoo0;1oo`9n@2ioo`9T7gAoo`0077oo00<007ooOol0/Woo0Wi0;Woo0f@O
LGoo000LOol00`00Oomoo`2dOol00gi0Oomoo`0^Ool3I1m^Ool001aoo`03001oogoo0;Eoo`9n@35o
o`=T7f]oo`0077oo00<007ooOol0]goo0Wi0<Woo0f@OJ7oo000LOol00`00Oomoo`2iOol2OT0cOol4
I1mTOol001aoo`03001oogoo0;]oo`03OT1oogoo03Aoo`=T7f5oo`0077oo00<007ooOol0_7oo0Wi0
=goo0f@OGWoo000LOol00`00Oomoo`2nOol2OT0hOol3I1mKOol001aoo`<00<1oo`9n@3Uoo`AT7eMo
o`0077oo00<007ooOol0`Woo00=n@7ooOol0>Woo0f@OE7oo000LOol00`00Oomoo`33Ool2OT0mOol3
I1mAOol001aoo`03001oogoo0<Eoo`9n@3ioo`9T7dmoo`0077oo00<007ooOol0agoo0Wi0?Woo0f@O
C7oo000LOol00`00Oomoo`39Ool2OT0oOol3I1m9Ool001aoo`03001oogoo0<]oo`9n@41oo`9T7dMo
o`0077oo00<007ooOol0cGoo0Wi0@7oo0f@OA7oo000LOol00`00Oomoo`3?Ool00gi0Oomoo`10Ool3
I1m1Ool001aoo`<00=1oo`9n@4=oo`AT7ceoo`0077oo00<007ooOol0dWoo0Wi0AGoo0f@O>Woo000L
Ool00`00Oomoo`3DOol2OT16Ool2I1lhOol001aoo`03001oogoo0=Ioo`03OT1oogoo04Eoo`9T7cIo
o`00ogooMWoo003oOomfOol00?moogIoo`00ogooMWoo003oOomfOol00?moogIoo`00ogooMWoo003o
OomfOol00?moogIoo`00ogooMWoo003oOomfOol00?moogIoo`00ogooMWoo000JOol3003oOomIOol0
01]oo`03001oogoo0?mooeQoo`006goo00<007ooOol0ogooF7oo000KOol00`00Ool0003oOomHOol0
01]oo`<00?mooeQoo`006goo00<007oo0000ogooF7oo000KOol01@00Oomoogoo0000ogooEWoo000J
Ool6003oOomFOol00?moogIoo`00ogooMWoo003oOomfOol00?moogIoo`00ogooMWoo0000\
\>"],
  ImageRangeCache->{{{0, 372.75}, {230.25, 0}} -> {-0.183758, -0.350907, \
0.00798096, 0.0133897}}]
}, Open  ]],

Cell[TextData[{
  "The symbolic solution for the heat equation in the original coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " is derived from the similarity solution by inverting the \
transformations:"
}], "Text",
  Evaluatable->False,
  CellTags->"heat equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(backrules = {\[Zeta] \[Rule] t\/x\^2, 
        F \[Rule] Function[\[Zeta], F[\[Zeta]]\ x\^c]}\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({\[Zeta] \[Rule] t\/x\^2, F \[Rule] Function[\[Zeta], F[\[Zeta]]\ x\^c]}
      \)], "Output"]
}, Open  ]],

Cell["\<\
The actual solution follows then by the resubstitution of the \
similarity representation:\
\>", "Text",
  Evaluatable->False,
  CellTags->"similarity representation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution = \(F[\[Zeta]] /. sheat\) /. backrules\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({\((x\^2\/t)\)\^\(1\/2 - c\/2\)\ C[1]\ 
          Hypergeometric1F1[1\/2 - c\/2, 3\/2, \(-\(x\^2\/\(4\ t\)\)\)] + 
        \((x\^2\/t)\)\^\(\(-c\)/2\)\ C[2]\ 
          Hypergeometric1F1[\(-\(c\/2\)\), 1\/2, \(-\(x\^2\/\(4\ t\)\)\)]}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In conclusion, we can say that a solution of a partial differential \
equation in two independent variables can be constructed by two invariants of \
the group. One of these two invariants becomes the new independent variable ",
  
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta] = \[Zeta](x, t)\)]],
  ", the so-called similarity variable, and the other invariant plays the \
role of a dependent variable ",
  Cell[BoxData[
      \(TraditionalForm\`F(\[Zeta])\)]],
  ". The similarity representation of the solution is given by the relation"
}], "Text",
  Evaluatable->False,
  CellTags->{"similarity variable", "similarity representation"}],

Cell[BoxData[
    \(TraditionalForm\`\[CapitalTheta]\  = \ H(x, t, F(\[Zeta]))\)], 
  "NumberedEquation"],

Cell[TextData[{
  "with the dependence of ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " on ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and the arbitrary function ",
  Cell[BoxData[
      \(TraditionalForm\`F(\[Zeta])\)]],
  " known explicitly. The substitution of this similarity representation into \
the original equation results in an ordinary differential equation for ",
  Cell[BoxData[
      \(TraditionalForm\`F(\[Zeta])\)]],
  ".\[ThickSpace]\[EmptySquare]"
}], "Text",
  Evaluatable->False],

Cell[TextData[{
  "Now we know the fundamental steps to reduce a PDE to an ODE if the \
symmetries of the PDE are given. The package ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  " offers a function called ",
  StyleBox["LieReduction[], ", "MmaText"],
  "which allows us to reduce the number of independent variables by applying \
the above considerations. The function ",
  StyleBox["LieReduction[]", "MmaText"],
  " can be used to automatically derive the similarity representation of the \
heat equation and others. The information we need to set up the calculation \
are the equation, the dependent and independent variables, and two lists for \
the infinitesimals. The first list of the infinitesimals carries the \
information on the independent variables and the second carries the group \
structure of the dependent variables. The following example shows how the \
reduction for the scaling symmetry is derived for the heat equation:"
}], "Text",
  Evaluatable->False,
  CellTags->{"LieReduction[]", "similarity representation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(red1 = 
      LieReduction[{\[PartialD]\_t u[x, t] - \[PartialD]\_{x, 2}u[x, t]}, {
          u}, \n\t\t{x, t}, {x, 2\ t}, {c\ u}]; 
    LTF[Flatten[red1]] /. zeta1 \[Rule] \[Zeta]\_1\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                StyleBox[\(t\/x\^2\),
                  ScriptLevel->0], "-", \(\[Zeta]\_1\)}], "==", "0"}]},
          {\(u\ x\^\(-c\) - F\_1 == 0\)},
          {
            \(\(-x\^c\)\ 
                \((\(-c\)\ F\_1 + c\^2\ F\_1 - \((F\_1)\)\_\(\[Zeta]\_1\) + 
                    6\ \[Zeta]\_1\ \((F\_1)\)\_\(\[Zeta]\_1\) - 
                    4\ c\ \[Zeta]\_1\ \((F\_1)\)\_\(\[Zeta]\_1\) + 
                    4\ \[Zeta]\_1\%2\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\))
                  \)\n\t == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The output of the function is a list containing the similarity variables \
as equations at the first position. The second part of the list contains the \
similarity representation of the solution. The third and last part of the \
resulting list contains the reduction of the original equation. Another \
example for the application of this function is given by the potential \
Burgers equation. We already determined the symmetries of the potential \
Burgers equation in S",
  ButtonBox["ection 5.4.4",
    ButtonData:>{"symmet5.nb", "potential Burgers equation"},
    ButtonStyle->"Hyperlink"],
  ". Using the results from there for the special group with ",
  StyleBox["k6=1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["ki=0",
    FontSlant->"Italic"],
  " for ",
  StyleBox["i",
    FontSlant->"Italic"],
  "\[NotEqual]6, we find"
}], "Text",
  Evaluatable->False,
  CellTags->{
  "similarity variables", "similarity representation of the solution", 
    "reduction", "potential Burgers equation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(red1 = 
      LieReduction[{
          \[PartialD]\_t u[x, t] + \((\[PartialD]\_x u[x, t])\)\^2 - 
            \[PartialD]\_{x, 2}u[x, t]}, \n
        \t\t{u}, {x, t}, {4\ t\ x, 4\ t\^2}, {2\ t + x\^2}]; 
    LTF[Flatten[red1]] /. zeta1 \[Rule] \[Zeta]\_1\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                StyleBox[\(t\/x\),
                  ScriptLevel->0], "-", \(\[Zeta]\_1\)}], "==", "0"}]},
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(1\/4\),
                    ScriptLevel->0], " ", 
                  RowBox[{"(", 
                    RowBox[{\(4\ u\), "-", 
                      StyleBox[\(x\^2\/t\),
                        ScriptLevel->0], "-", \(2\ Log[x]\)}], ")"}]}], "-", 
                \(F\_1\)}], "==", "0"}]},
          {
            \(\[Zeta]\_1\%2\ 
                \((3 - 12\ F1\_\(\[Zeta]\_1\)\ \[Zeta]\_1 + 
                    4\ F1\_\[Zeta]\_1\%2\ \[Zeta]\_1\%2 - 
                    4\ \[Zeta]\_1\%2\ F1\_\(\[Zeta]\_1, \[Zeta]\_1\))\) == 0
              \)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of the reduction is a non-linear second-order ordinary \
differential equation which we can solve by using the function ",
  StyleBox["DSolve[]:", "MmaText"]
}], "Text",
  Evaluatable->False,
  CellTags->"DSolve[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solburgersp = 
      DSolve[red1\[LeftDoubleBracket]3, 1\[RightDoubleBracket] == 0, F1, 
        zeta1]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({{F1 \[Rule] \((C[2] + \(3\ Log[#1]\)\/2 - Log[\(-1\) + #1\ C[1]]&)\)}}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The final solution of the potential Burgers equation follows by using the \
second part of the similarity reduction. Inserting the solution for ",
  Cell[BoxData[
      FormBox[
        StyleBox["F1",
          "InlineFormula",
          FontSlant->"Italic"], TraditionalForm]]],
  " into the similarity representation, we get a representation of the \
solution in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " coordinates,"
}], "Text",
  Evaluatable->False,
  CellTags->"similarity representation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution = 
      Flatten[red1\[LeftDoubleBracket]2\[RightDoubleBracket] /. solburgersp]
        \)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({1\/4\ \((4\ u - x\^2\/t - 2\ Log[x])\) == 
        C[2] + 3\/2\ Log[t\/x] - Log[\(-1\) + \(t\ C[1]\)\/x]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Solving this relation with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", we end up with the explicit solution of the potential Burgers equation \
in the form"
}], "Text",
  Evaluatable->False,
  CellTags->"solution of the potential Burgers equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solf = 
      Simplify[Solve[solution\[LeftDoubleBracket]1\[RightDoubleBracket], u]]
        \)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({{u \[Rule] 
          1\/4\ \((
              x\^2\/t + 4\ C[2] + 6\ Log[t\/x] + 2\ Log[x] - 
                4\ Log[\(-1\) + \(t\ C[1]\)\/x])\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
The solution of the chosen subgroup contains two constants of \
integration which have to be chosen in such a way that the initial and \
boundary conditions are satisfied.\
\>", "Text",
  Evaluatable->False],

Cell["Example 3", "Example"],

Cell[TextData[{
  "Another example of two coupled diffusion equations demonstrates the \
application of the function ",
  StyleBox["LieReduction[]", "MmaText"],
  " on a system of equations. The (1+1)-dimensional version of the equations \
of motion for the density ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " and the density ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " are given by"
}], "Text",
  Evaluatable->False,
  CellTags->{"two coupled diffusion equations", "LieReduction[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(cdiffu = {\[PartialD]\_t u[x, t] - \[PartialD]\_\(x, x\)v[x, t], \n\t\t
        \[PartialD]\_t v[x, t]\  - \[PartialD]\_\(x, x\)u[x, t]}; 
    cdiffu // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(u\_t - v\_\(x, x\) == 0\)},
          {\(v\_t - u\_\(x, x\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The two equations allow a large symmetry group. The infinitesimals of this \
group follow by applying the function ",
  StyleBox["Infinitesimals[]", "MmaText"],
  ". The result reads"
}], "Text",
  Evaluatable->False,
  CellTags->{"infinitesimals", "Infinitesimals[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(icdiffu = 
      Infinitesimals[cdiffu, {u, v}, \n\t\t{x, t}, {}, 
        SubstitutionRules 
          \[Rule] {\[PartialD]\_t u[x, t], \[PartialD]\_t v[x, t]}]; 
    icdiffu // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            \(\(-\((\[ScriptCapitalF]\_2)\)\_t\) + 
                \((\[ScriptCapitalF]\_1)\)\_\(x, x\) == 0\)},
          {
            \(\(-\((\[ScriptCapitalF]\_1)\)\_t\) + 
                \((\[ScriptCapitalF]\_2)\)\_\(x, x\) == 0\)},
          {\(\[Xi]\_1 == k6 + k7\ x - 2\ t\ \((k3 + k5\ x)\)\)},
          {\(\[Xi]\_2 == k1 + 2\ t\ \((k7 - k5\ t)\)\)},
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              RowBox[{\(\((k4 + k5\ t)\)\ u\), "+", 
                RowBox[{"v", " ", 
                  RowBox[{"(", 
                    RowBox[{"k2", "+", \(k3\ x\), "+", 
                      StyleBox[\(\(k5\ x\^2\)\/2\),
                        ScriptLevel->0]}], ")"}]}], "+", 
                \(\[ScriptCapitalF]\_1\)}]}]},
          {
            RowBox[{\(\[Phi]\_2\), "==", 
              RowBox[{\(\((k4 + k5\ t)\)\ v\), "+", 
                RowBox[{"u", " ", 
                  RowBox[{"(", 
                    RowBox[{"k2", "+", \(k3\ x\), "+", 
                      StyleBox[\(\(k5\ x\^2\)\/2\),
                        ScriptLevel->0]}], ")"}]}], "+", 
                \(\[ScriptCapitalF]\_2\)}]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Plus[ 
            Times[ -1, 
              Subscript[ 
                Subscript[ \[ScriptCapitalF], 2], t]], 
            Subscript[ 
              Subscript[ \[ScriptCapitalF], 1], x, x]], 0], 
        Equal[ 
          Plus[ 
            Times[ -1, 
              Subscript[ 
                Subscript[ \[ScriptCapitalF], 1], t]], 
            Subscript[ 
              Subscript[ \[ScriptCapitalF], 2], x, x]], 0], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Plus[ k6, 
            Times[ k7, x], 
            Times[ -2, t, 
              Plus[ k3, 
                Times[ k5, x]]]]], 
        Equal[ 
          Subscript[ \[Xi], 2], 
          Plus[ k1, 
            Times[ 2, t, 
              Plus[ k7, 
                Times[ -1, k5, t]]]]], 
        Equal[ 
          Subscript[ \[Phi], 1], 
          Plus[ 
            Times[ 
              Plus[ k4, 
                Times[ k5, t]], u], 
            Times[ v, 
              Plus[ k2, 
                Times[ k3, x], 
                Times[ 
                  Rational[ 1, 2], k5, 
                  Power[ x, 2]]]], 
            Subscript[ \[ScriptCapitalF], 1]]], 
        Equal[ 
          Subscript[ \[Phi], 2], 
          Plus[ 
            Times[ 
              Plus[ k4, 
                Times[ k5, t]], v], 
            Times[ u, 
              Plus[ k2, 
                Times[ k3, x], 
                Times[ 
                  Rational[ 1, 2], k5, 
                  Power[ x, 2]]]], 
            Subscript[ \[ScriptCapitalF], 2]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The two functions ",
  StyleBox["free[1]", "MmaText",
    FontSlant->"Italic"],
  " and ",
  StyleBox["free[2]", "MmaText",
    FontSlant->"Italic"],
  StyleBox[" ", "MmaText"],
  "satisfy the original equations and generate the infinite dimensional part \
of the group. The finite part of the group is represented by a \
seven-dimensional symmetry group. From this group, we select the subgroup \
with ",
  StyleBox["k4 = k7 = 1", "MmaText",
    FontSlant->"Italic"],
  " representing a scaling symmetry of the coupled equations:"
}], "Text",
  Evaluatable->False,
  CellTags->"symmetry group"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xinfi = 
      \({\(xi[1]\)[x, t, u, v], \(xi[2]\)[x, t, u, v]} /. \n\t\t
          icdiffu\[LeftDoubleBracket]1\[RightDoubleBracket]\) /. \n
        \t\t{k1 \[Rule] 0, k2 \[Rule] 0, k3 \[Rule] 0, k4 \[Rule] 1, 
          k5 \[Rule] 0, k6 \[Rule] 0, k7 \[Rule] 1}\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({x, 2\ t}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(uinfi = 
      \({\(phi[1]\)[x, t, u, v], \(phi[2]\)[x, t, u, v]} /. 
          icdiffu\[LeftDoubleBracket]1\[RightDoubleBracket]\) /. \n
        \t\t{k1 \[Rule] 0, k2 \[Rule] 0, k3 \[Rule] 0, k4 \[Rule] 1, 
          k5 \[Rule] 0, k6 \[Rule] 0, k7 \[Rule] 1, \n\t\t\t
          \(free[1]\)[x, t] \[Rule] 0, \(free[2]\)[x, t] \[Rule] 0}\)], 
  "Input"],

Cell[BoxData[
    \({u, v}\)], "Output"]
}, Open  ]],

Cell["\<\
The reduction of the coupled diffusion equations for the scaling \
group follows then by\
\>", "Text",
  Evaluatable->False,
  CellTags->"reduction of the coupled diffusion equations"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rcdiffu = LieReduction[cdiffu, {u, v}, {x, t}, {x, 2\ t}, {u, v}]; 
    LieTraditionalForm[rcdiffu] /. zeta1 \[Rule] \[Zeta]\_1 // TableForm\)], 
  "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              StyleBox[\(t\/x\^2\),
                ScriptLevel->0], "==", \(\[Zeta]\_1\)}], "\<\"\"\>"},
          {
            RowBox[{
              StyleBox[\(u\/x\),
                ScriptLevel->0], "==", \(F\_1\)}], 
            RowBox[{
              StyleBox[\(v\/x\),
                ScriptLevel->0], "==", \(F\_2\)}]},
          {
            \(\((F\_1)\)\_\(\[Zeta]\_1\) - 
                2\ \[Zeta]\_1\ \((F\_2)\)\_\(\[Zeta]\_1\) - 
                4\ \[Zeta]\_1\%2\ \((F\_2)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) == 0
              \), \(\(-2\)\ \[Zeta]\_1\ \((F\_1)\)\_\(\[Zeta]\_1\) + 
                \((F\_2)\)\_\(\[Zeta]\_1\) - 
                4\ \[Zeta]\_1\%2\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) == 0
              \)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{
        Equal[ 
          Times[ t, 
            Power[ x, -2]], 
          Subscript[ \[Zeta], 1]]}, {
        Equal[ 
          Times[ u, 
            Power[ x, -1]], 
          Subscript[ F, 1]], 
        Equal[ 
          Times[ v, 
            Power[ x, -1]], 
          Subscript[ F, 2]]}, {
        Equal[ 
          Plus[ 
            Subscript[ 
              Subscript[ F, 1], 
              Subscript[ \[Zeta], 1]], 
            Times[ -2, 
              Subscript[ \[Zeta], 1], 
              Subscript[ 
                Subscript[ F, 2], 
                Subscript[ \[Zeta], 1]]], 
            Times[ -4, 
              Power[ 
                Subscript[ \[Zeta], 1], 2], 
              Subscript[ 
                Subscript[ F, 2], 
                Subscript[ \[Zeta], 1], 
                Subscript[ \[Zeta], 1]]]], 0], 
        Equal[ 
          Plus[ 
            Times[ -2, 
              Subscript[ \[Zeta], 1], 
              Subscript[ 
                Subscript[ F, 1], 
                Subscript[ \[Zeta], 1]]], 
            Subscript[ 
              Subscript[ F, 2], 
              Subscript[ \[Zeta], 1]], 
            Times[ -4, 
              Power[ 
                Subscript[ \[Zeta], 1], 2], 
              Subscript[ 
                Subscript[ F, 1], 
                Subscript[ \[Zeta], 1], 
                Subscript[ \[Zeta], 1]]]], 0]}}]]], "Output",
  FontSize->8]
}, Open  ]],

Cell[TextData[{
  "The derived coupled set of ordinary differential equations in ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(F\_1\), "=", 
          StyleBox[
            RowBox[{
              StyleBox["F",
                FontSlant->"Italic"], "1"}]]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(F\_2\), "=", 
          StyleBox[
            RowBox[{
              StyleBox["F",
                FontSlant->"Italic"], "1"}]]}], TraditionalForm]]],
  " is not solved by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". This is obvious from"
}], "Text",
  ShowCellBracket->True,
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[rcdiffu\[LeftDoubleBracket]3\[RightDoubleBracket], {F1, F2}, 
      zeta1]\)], "Input"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["F1", "\[Prime]",
                    MultilineFunction->None], "[", "zeta1", "]"}], "-", 
                RowBox[{"2", " ", "zeta1", " ", 
                  RowBox[{
                    SuperscriptBox["F2", "\[Prime]",
                      MultilineFunction->None], "[", "zeta1", "]"}]}], "-", 
                RowBox[{"4", " ", \(zeta1\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["F2", "\[DoublePrime]",
                      MultilineFunction->None], "[", "zeta1", "]"}]}]}], 
              "==", "0"}], ",", 
            RowBox[{
              RowBox[{
                RowBox[{\(-2\), " ", "zeta1", " ", 
                  RowBox[{
                    SuperscriptBox["F1", "\[Prime]",
                      MultilineFunction->None], "[", "zeta1", "]"}]}], "+", 
                RowBox[{
                  SuperscriptBox["F2", "\[Prime]",
                    MultilineFunction->None], "[", "zeta1", "]"}], "-", 
                RowBox[{"4", " ", \(zeta1\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["F1", "\[DoublePrime]",
                      MultilineFunction->None], "[", "zeta1", "]"}]}]}], 
              "==", "0"}]}], "}"}], ",", \({F1, F2}\), ",", "zeta1"}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, this is not the end of the story. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " offers an alternate way: the numerical solution of the equation. The \
function ",
  StyleBox["NDSolve[]", "MmaText"],
  " is capable of handling this task. This function is beneficial in solving \
the reduced system of equations. In determining a numerical solution, it is \
mandatory that the equations be free of any parameters and that the initial \
conditions be added to the equations:"
}], "Text",
  Evaluatable->False,
  CellTags->{"NDSolve[]", "numerical solution", "initial conditions"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqat\  = \ rcdiffu\[LeftDoubleBracket]3\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["F1", "\[Prime]",
                MultilineFunction->None], "[", "zeta1", "]"}], "-", 
            RowBox[{"2", " ", "zeta1", " ", 
              RowBox[{
                SuperscriptBox["F2", "\[Prime]",
                  MultilineFunction->None], "[", "zeta1", "]"}]}], "-", 
            RowBox[{"4", " ", \(zeta1\^2\), " ", 
              RowBox[{
                SuperscriptBox["F2", "\[DoublePrime]",
                  MultilineFunction->None], "[", "zeta1", "]"}]}]}], "==", 
          "0"}], ",", 
        RowBox[{
          RowBox[{
            RowBox[{\(-2\), " ", "zeta1", " ", 
              RowBox[{
                SuperscriptBox["F1", "\[Prime]",
                  MultilineFunction->None], "[", "zeta1", "]"}]}], "+", 
            RowBox[{
              SuperscriptBox["F2", "\[Prime]",
                MultilineFunction->None], "[", "zeta1", "]"}], "-", 
            RowBox[{"4", " ", \(zeta1\^2\), " ", 
              RowBox[{
                SuperscriptBox["F1", "\[DoublePrime]",
                  MultilineFunction->None], "[", "zeta1", "]"}]}]}], "==", 
          "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
 For the initial conditions, we choose the following \
relations:\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"initials", "=", 
        RowBox[{"{", 
          RowBox[{\(F1[1] ==  .1\), ",", \(F2[1] ==  .2\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["F1", "\[Prime]",
                  MultilineFunction->None], "[", "1", "]"}], "==", 
              \(- .1\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["F2", "\[Prime]",
                  MultilineFunction->None], "[", "1", "]"}], "==", 
              \(-0.5\)}]}], "}"}]}], ";"}]], "Input"],

Cell[TextData[{
  "setting the function values at ",
  StyleBox["zeta1=1",
    FontSlant->"Italic"],
  " and the derivatives to certain constants. These four equations are joined \
with the list of equations ",
  StyleBox["eqat",
    FontSlant->"Italic"],
  ":"
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqat = Join[eqat, initials]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["F1", "\[Prime]",
                MultilineFunction->None], "[", "zeta1", "]"}], "-", 
            RowBox[{"2", " ", "zeta1", " ", 
              RowBox[{
                SuperscriptBox["F2", "\[Prime]",
                  MultilineFunction->None], "[", "zeta1", "]"}]}], "-", 
            RowBox[{"4", " ", \(zeta1\^2\), " ", 
              RowBox[{
                SuperscriptBox["F2", "\[DoublePrime]",
                  MultilineFunction->None], "[", "zeta1", "]"}]}]}], "==", 
          "0"}], ",", 
        RowBox[{
          RowBox[{
            RowBox[{\(-2\), " ", "zeta1", " ", 
              RowBox[{
                SuperscriptBox["F1", "\[Prime]",
                  MultilineFunction->None], "[", "zeta1", "]"}]}], "+", 
            RowBox[{
              SuperscriptBox["F2", "\[Prime]",
                MultilineFunction->None], "[", "zeta1", "]"}], "-", 
            RowBox[{"4", " ", \(zeta1\^2\), " ", 
              RowBox[{
                SuperscriptBox["F1", "\[DoublePrime]",
                  MultilineFunction->None], "[", "zeta1", "]"}]}]}], "==", 
          "0"}], ",", 
        RowBox[{\(F1[1]\), "==", 
          StyleBox["0.1`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", 
        RowBox[{\(F2[1]\), "==", 
          StyleBox["0.2`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["F1", "\[Prime]",
              MultilineFunction->None], "[", "1", "]"}], "==", 
          RowBox[{"-", 
            StyleBox["0.1`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}]}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["F2", "\[Prime]",
              MultilineFunction->None], "[", "1", "]"}], "==", 
          RowBox[{"-", 
            StyleBox["0.5`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The complete list of equations and initial conditions is now used in the \
numerical integration for ",
  StyleBox["zeta1",
    FontSlant->"Italic"],
  " in the range ",
  StyleBox["1\[LessEqual] zeta1\[LessEqual]50",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  CellTags->"numerical integration"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nsolve = NDSolve[eqat, {F1, F2}, {zeta1, 1, 50}]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"F1", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{1.`, 50.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"F2", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{1.`, 50.`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The numerical solution is represented by an interpolating function. \
We can use the representations to plot the solution:\
\>", "Text",
  Evaluatable->False,
  CellTags->"interpolating function"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[{F1[x], F2[x]} /. nsolve], {x, 1, 50}, \n\t
      PlotStyle 
        \[Rule] {RGBColor[1.000, 0.000, 0.000], \n\t\t\t
          RGBColor[0.000, 0.000, 1.000]}, \n\t
      AxesLabel 
        \[Rule] {\*"\"\<\!\(\[Zeta]\_1\)\>\"", 
          \*"\"\<\!\(F\_1\),\!\(F\_2\)\>\""}]\)], "Input",
  PageWidth->Infinity],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.585155 0.0908215 [
[.21429 .57265 -6 -9 ]
[.21429 .57265 6 0 ]
[.40476 .57265 -6 -9 ]
[.40476 .57265 6 0 ]
[.59524 .57265 -6 -9 ]
[.59524 .57265 6 0 ]
[.78571 .57265 -6 -9 ]
[.78571 .57265 6 0 ]
[.97619 .57265 -6 -9 ]
[.97619 .57265 6 0 ]
[1.025 .58515 0 -7.5 ]
[1.025 .58515 15 7.5 ]
[.01131 .04023 -12 -4.5 ]
[.01131 .04023 0 4.5 ]
[.01131 .13105 -12 -4.5 ]
[.01131 .13105 0 4.5 ]
[.01131 .22187 -12 -4.5 ]
[.01131 .22187 0 4.5 ]
[.01131 .31269 -12 -4.5 ]
[.01131 .31269 0 4.5 ]
[.01131 .40351 -12 -4.5 ]
[.01131 .40351 0 4.5 ]
[.01131 .49433 -12 -4.5 ]
[.01131 .49433 0 4.5 ]
[.02381 .64303 -16 0 ]
[.02381 .64303 16 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .58515 m
.21429 .5914 L
s
[(10)] .21429 .57265 0 1 Mshowa
.40476 .58515 m
.40476 .5914 L
s
[(20)] .40476 .57265 0 1 Mshowa
.59524 .58515 m
.59524 .5914 L
s
[(30)] .59524 .57265 0 1 Mshowa
.78571 .58515 m
.78571 .5914 L
s
[(40)] .78571 .57265 0 1 Mshowa
.97619 .58515 m
.97619 .5914 L
s
[(50)] .97619 .57265 0 1 Mshowa
.125 Mabswid
.0619 .58515 m
.0619 .5889 L
s
.1 .58515 m
.1 .5889 L
s
.1381 .58515 m
.1381 .5889 L
s
.17619 .58515 m
.17619 .5889 L
s
.25238 .58515 m
.25238 .5889 L
s
.29048 .58515 m
.29048 .5889 L
s
.32857 .58515 m
.32857 .5889 L
s
.36667 .58515 m
.36667 .5889 L
s
.44286 .58515 m
.44286 .5889 L
s
.48095 .58515 m
.48095 .5889 L
s
.51905 .58515 m
.51905 .5889 L
s
.55714 .58515 m
.55714 .5889 L
s
.63333 .58515 m
.63333 .5889 L
s
.67143 .58515 m
.67143 .5889 L
s
.70952 .58515 m
.70952 .5889 L
s
.74762 .58515 m
.74762 .5889 L
s
.82381 .58515 m
.82381 .5889 L
s
.8619 .58515 m
.8619 .5889 L
s
.9 .58515 m
.9 .5889 L
s
.9381 .58515 m
.9381 .5889 L
s
.25 Mabswid
0 .58515 m
1 .58515 L
s
gsave
1.025 .58515 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 16.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
73.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.02381 .04023 m
.03006 .04023 L
s
[(-6)] .01131 .04023 1 0 Mshowa
.02381 .13105 m
.03006 .13105 L
s
[(-5)] .01131 .13105 1 0 Mshowa
.02381 .22187 m
.03006 .22187 L
s
[(-4)] .01131 .22187 1 0 Mshowa
.02381 .31269 m
.03006 .31269 L
s
[(-3)] .01131 .31269 1 0 Mshowa
.02381 .40351 m
.03006 .40351 L
s
[(-2)] .01131 .40351 1 0 Mshowa
.02381 .49433 m
.03006 .49433 L
s
[(-1)] .01131 .49433 1 0 Mshowa
.125 Mabswid
.02381 .05839 m
.02756 .05839 L
s
.02381 .07655 m
.02756 .07655 L
s
.02381 .09472 m
.02756 .09472 L
s
.02381 .11288 m
.02756 .11288 L
s
.02381 .14921 m
.02756 .14921 L
s
.02381 .16738 m
.02756 .16738 L
s
.02381 .18554 m
.02756 .18554 L
s
.02381 .2037 m
.02756 .2037 L
s
.02381 .24003 m
.02756 .24003 L
s
.02381 .2582 m
.02756 .2582 L
s
.02381 .27636 m
.02756 .27636 L
s
.02381 .29453 m
.02756 .29453 L
s
.02381 .33085 m
.02756 .33085 L
s
.02381 .34902 m
.02756 .34902 L
s
.02381 .36718 m
.02756 .36718 L
s
.02381 .38535 m
.02756 .38535 L
s
.02381 .42168 m
.02756 .42168 L
s
.02381 .43984 m
.02756 .43984 L
s
.02381 .458 m
.02756 .458 L
s
.02381 .47617 m
.02756 .47617 L
s
.02381 .5125 m
.02756 .5125 L
s
.02381 .53066 m
.02756 .53066 L
s
.02381 .54883 m
.02756 .54883 L
s
.02381 .56699 m
.02756 .56699 L
s
.02381 .02206 m
.02756 .02206 L
s
.02381 .0039 m
.02756 .0039 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -77 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(F) show
69.000000 16.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
73.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
79.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(F) show
85.562500 16.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
90.125000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.04286 .59424 m
.08072 .57392 L
.12201 .55468 L
.16079 .53919 L
.19809 .52592 L
.23779 .51309 L
.276 .5017 L
.31662 .49043 L
.35575 .48023 L
.39339 .47094 L
.43344 .46153 L
.47201 .45286 L
.50908 .44487 L
.54857 .43666 L
.58656 .42904 L
.62696 .4212 L
.66588 .41389 L
.70331 .40706 L
.74314 .39998 L
.78149 .39334 L
.82224 .38647 L
.8615 .38 L
.89928 .37392 L
.93946 .36759 L
.97619 .36192 L
s
0 0 1 r
.04286 .60332 m
.06129 .5661 L
.08072 .53532 L
.12201 .48338 L
.15931 .44506 L
.19901 .40959 L
.23722 .379 L
.27784 .34932 L
.31697 .32286 L
.35461 .29901 L
.39466 .27507 L
.43323 .2532 L
.4703 .23311 L
.50979 .21261 L
.54778 .19365 L
.58818 .17422 L
.6271 .15615 L
.66453 .13931 L
.70436 .12191 L
.74271 .10564 L
.78346 .08881 L
.82272 .07302 L
.8605 .05818 L
.90068 .04276 L
.93938 .02824 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  TextAlignment->Center,
  ImageSize->{250.75, 154.875},
  ImageMargins->{{Inherited, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004i0000`A000`40O003h00O5Goo00<007ooOol0
ogoo8Woo000EOol2003oOolSOol001Eoo`03001oogoo0?moob9oo`005Goo00<007ooOol0ogoo8Woo
000EOol00`00Oomoo`3mOol201lROol001Eoo`03001oogoo0?]oo`807bAoo`005Goo0P00nWoo0P0O
9Woo000EOol00`00Oomoo`3gOol201lXOol000eoo`<000Eoo`03001oogoo0?Aoo`<07bYoo`0037oo
00D007ooOomoo`0000Aoo`03001oogoo0?1oo`@07beoo`0037oo00D007ooOomoo`0000Aoo`03001o
ogoo0>aoo`@07c5oo`000goo1P000goo00D007ooOomoo`0000Aoo`<00>Uoo`<07cEoo`0037oo1000
1Goo00<007ooOol0igoo0P0O>7oo000<Ool00`00Oomoo`06Ool00`00Oomoo`3UOol201ljOol000eo
o`03001oogoo00Eoo`03001oogoo0>=oo`807caoo`003Woo0`0017oo00<007ooOol0hGoo0P0O?Woo
000EOol2003OOol301m0Ool001Eoo`03001oogoo0=aoo`807d=oo`005Goo00<007ooOol0fGoo0`0O
AGoo000EOol00`00Oomoo`3GOol201m8Ool001Eoo`03001oogoo0=Aoo`<07dYoo`005Goo0P00dWoo
0`0OCGoo000EOol00`00Oomoo`3?Ool201m@Ool001Eoo`03001oogoo0<aoo`<07e9oo`005Goo00<0
07ooOol0bGoo0`0OEGoo000EOol00`00Oomoo`36Ool301mHOol001Eoo`800<Eoo`807e]oo`005Goo
00<007ooOol0`Goo0`0OGGoo000EOol00`00Oomoo`2oOol201mPOol001Eoo`03001oogoo0;eoo`80
7f9oo`005Goo0P00_7oo0P0OI7oo000EOol00`00Oomoo`2iOol201mVOol000aoo`@000Eoo`03001o
ogoo0;Moo`807fQoo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0]7oo0`0OJWoo
000@Ool00`00Oomoo`02Ool00`00Oomoo`2bOol201m]Ool000=oo`H000Moo`03001oogoo009oo`<0
0;1oo`807fmoo`0037oo10001Goo00<007ooOol0[Woo0P0OLGoo000<Ool00`00Oomoo`06Ool00`00
Oomoo`2/Ool201mcOol000aoo`03001oogoo00Ioo`03001oogoo0:Uoo`<07gEoo`0037oo1@0017oo
00<007ooOol0Ygoo0P0ON7oo000EOol2002UOol301mjOol001Eoo`03001oogoo0:9oo`807geoo`00
5Goo00<007ooOol0X7oo0P0OOgoo000EOol00`00Oomoo`2NOol201n1Ool001Eoo`03001oogoo09ao
o`807h=oo`005Goo0P00Vgoo0P0OQGoo000EOol00`00Oomoo`2HOol201n7Ool001Eoo`03001oogoo
09Eoo`<07hUoo`005Goo00<007ooOol0Tgoo0P0OS7oo000EOol00`00Oomoo`2AOol201n>Ool001Eo
o`80091oo`807i1oo`005Goo00<007ooOol0SGoo0P0OTWoo000EOol00`00Oomoo`2:Ool301nDOol0
01Eoo`03001oogoo08Qoo`807iMoo`005Goo00<007ooOol0QWoo0P0OVGoo000EOol20025Ool201nK
Ool001Eoo`03001oogoo089oo`807ieoo`003Woo0`0017oo00<007ooOol0P7oo0P0OWgoo000?Ool0
0`00Oomoo`03Ool00`00Oomoo`1nOol201nQOol000moo`03001oogoo00=oo`03001oogoo07aoo`80
7j=oo`000goo1P000Woo1P0017oo0`00Ngoo00<07gooOol0Xgoo000<Ool01000Oomoo`001Goo00<0
07ooOol0NGoo0P0OYWoo000<Ool01000Oomoo`001Goo00<007ooOol0Mgoo0P0OZ7oo000=Ool00`00
Ool00005Ool00`00Oomoo`1fOol00`0OOomoo`2XOol000ioo`8000Eoo`03001oogoo07Aoo`807j]o
o`005Goo0P00Lgoo0P0O[Goo000EOol00`00Oomoo`1`Ool201n_Ool001Eoo`03001oogoo06ioo`80
7k5oo`005Goo00<007ooOol0K7oo0P0O/goo000EOol00`00Oomoo`1ZOol201neOol001Eoo`8006Uo
o`807kMoo`005Goo00<007ooOol0IWoo0P0O^Goo000EOol00`00Oomoo`1TOol201nkOol001Eoo`03
001oogoo069oo`807keoo`005Goo00<007ooOol0HGoo00<07gooOol0_Goo000EOol2001POol201o0
Ool001Eoo`03001oogoo05ioo`0301moogoo0<1oo`005Goo00<007ooOol0G7oo0P0O`goo000EOol0
0`00Oomoo`1JOol201o5Ool001Eoo`03001oogoo05Uoo`0301moogoo0<Eoo`005Goo0P00F7oo0P0O
b7oo000<Ool30006Ool00`00Oomoo`1FOol00`0OOomoo`38Ool000]oo`05001oogooOol00005Ool0
0`00Oomoo`1DOol201o;Ool000moo`03001oogoo00=oo`03001oogoo059oo`807leoo`000goo1P00
1Woo00<007ooOol00goo0`00DGoo00<07gooOol0cGoo000=Ool20006Ool00`00Oomoo`1?Ool201o@
Ool000moo`03001oogoo00=oo`03001oogoo04eoo`807m9oo`002goo00D007ooOomoo`0000Eoo`03
001oogoo04aoo`0301moogoo0=9oo`0037oo0`001Woo00<007ooOol0BWoo0P0OeGoo000EOol2001:
Ool00`0OOomoo`3EOol001Eoo`03001oogoo04Qoo`0301moogoo0=Ioo`005Goo00<007ooOol0AWoo
0P0OfGoo000EOol00`00Oomoo`15Ool00`0OOomoo`3IOol001Eoo`03001oogoo04=oo`807maoo`00
5Goo0P00@goo00<07gooOol0g7oo000EOol00`00Oomoo`10Ool201oOOol001Eoo`03001oogoo03mo
o`0301moogoo0=moo`005Goo00<007ooOol0?Woo00<07gooOol0h7oo000EOol00`00Oomoo`0lOol2
01nlOol5O00ROol001Eoo`8003aoo`0301moogoo0;Eoo`Ml02Moo`005Goo00<007ooOol0>Woo00<0
7gooOol0/7oo1W`0;Woo000EOol00`00Oomoo`0hOol201n^Ool5O00dOol001Eoo`03001oogoo03Mo
o`0301moogoo0:Qoo`Il03Uoo`005Goo00<007ooOol0=Woo00<07gooOol0XWoo1g`0?goo000EOol2
000eOol201nMOol8O016Ool001Eoo`03001oogoo03=oo`0301moogoo09Moo`Il04ioo`002goo1@00
1Goo00<007ooOol0<Woo00<07gooOol0Tgoo1G`0E7oo000;Ool01@00Oomoogoo00001Goo00<007oo
Ool0<Goo00<07gooOol0SWoo1W`0FGoo000<Ool00`00Oomoo`06Ool00`00Oomoo`0`Ool00`0OOomo
o`2:Ool5O01OOol000=oo`H000Aoo`03001oogoo00Eoo`<002ioo`807hQoo`El06Aoo`003Woo00<0
07ooOol017oo00<007ooOol0;Goo00<07gooOol0Pgoo1G`0JGoo000?Ool00`00Oomoo`03Ool00`00
Oomoo`0/Ool00`0OOomoo`1oOol5O01^Ool000]oo`05001oogooOol00005Ool00`00Oomoo`0[Ool0
0`0OOomoo`1kOol5O01cOol000aoo`<000Ioo`03001oogoo02Yoo`0301moogoo07Ioo`Il07Qoo`00
5Goo0P00:Woo00<07gooOol0LWoo1G`0OWoo000EOol00`00Oomoo`0XOol00`0OOomoo`1]Ool6O023
Ool001Eoo`03001oogoo02Ioo`807f]oo`El08Uoo`005Goo00<007ooOol09Goo00<07gooOol0IWoo
1G`0SWoo000EOol00`00Oomoo`0TOol00`0OOomoo`1ROol5O02COol001Eoo`8002Aoo`0301moogoo
05eoo`Il09Qoo`005Goo00<007ooOol08Woo00<07gooOol0FGoo1G`0WWoo000EOol00`00Oomoo`0Q
Ool00`0OOomoo`1EOol5O02SOol001Eoo`03001oogoo021oo`0301moogoo059oo`Al0:Qoo`005Goo
00<007ooOol07goo00<07gooOol0D7oo0g`0[7oo000EOol2000OOol00`0OOomoo`1=Ool4O02_Ool0
01Eoo`03001oogoo01eoo`0301moogoo04Yoo`Al0;=oo`005Goo00<007ooOol07Goo00<07gooOol0
A7oo1W`0]goo000EOol00`00Oomoo`0LOol00`0OOomoo`11Ool4O02mOol001Eoo`03001oogoo01]o
o`0301moogoo03moo`=l0<5oo`005Goo0P006goo00<07gooOol0?7oo17`0a7oo000EOol00`00Oomo
o`0IOol00`0OOomoo`0iOol4O038Ool000aoo`D000Aoo`03001oogoo01Qoo`0301moogoo03Aoo`Il
0<aoo`003Woo00<007ooOol017oo00<007ooOol05goo00<07gooOol0<Goo17`0dWoo000>Ool00`00
Oomoo`04Ool00`00Oomoo`0FOol00`0OOomoo`0_Ool3O03FOol000=oo`H000Eoo`03001oogoo00Ao
o`<001Eoo`0301moogoo02ioo`9l0=Uoo`003Woo00<007ooOol017oo00<007ooOol05Goo00<07goo
Ool0:goo0g`0fgoo000>Ool00`00Oomoo`04Ool00`00Oomoo`0DOol00`0OOomoo`0YOol3O03NOol0
00aoo`<000Ioo`03001oogoo01=oo`0301moogoo02Moo`=l0>5oo`003Woo00<007ooOol017oo0P00
4goo00<07gooOol097oo17`0i7oo000EOol00`00Oomoo`0AOol00`0OOomoo`0ROol3O03XOol001Eo
o`03001oogoo011oo`0301moogoo01moo`Al0>]oo`005Goo00<007ooOol03goo00<07gooOol077oo
17`0kgoo000EOol00`00Oomoo`0?Ool00`0OOomoo`0IOol3O03cOol001Eoo`8000moo`0301moogoo
01Qoo`9l0?Ioo`005Goo00<007ooOol03Goo00<07gooOol05Woo0g`00Woo1@000goo10009Woo1@00
17oo10009goo0`001Goo1000:Woo0`000goo10009goo100017oo10007Goo000EOol00`00Oomoo`0<
Ool00`0OOomoo`0EOol2O007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0SOol01@00
Oomoogoo00000goo00<007ooOol00Woo00<007ooOol08goo00D007ooOomoo`0000=oo`03001oogoo
009oo`03001oogoo02Qoo`05001oogooOol00004Ool00`00Oomoo`0SOol00`00Oomoo`02Ool01000
Oomoo`0017oo00<007ooOol06Woo000EOol00`00Oomoo`0;Ool00`0OOomoo`0COol3O009Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`0WOol01@00Oomoogoo000017oo00<007ooOol0:7oo00D007ooOomoo`0000Aoo`03001oogoo
02Qoo`04001oogoo0004Ool00`00Oomoo`0JOol001Eoo`03001oogoo00]oo`0301moogoo015oo`9l
00aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Eoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo02Moo`05001oogooOol00004Ool00`00Oomoo`0TOol60002Ool00`00Oomoo`02
Ool00`00Oomoo`0XOol01000Oomoo`0017oo00<007ooOol06Woo000EOol2000;Ool00`0OOomoo`0?
Ool3O00>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0UOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0UOol01000Oomoo`00
0goo00<007ooOol00Woo00<007ooOol097oo10000goo00<007ooOol00Woo00<007ooOol06Woo000E
Ool00`00Oomoo`09Ool00`0OOomoo`0>Ool2O00AOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0WOol01@00Oomoogoo000017oo00<007ooOol09goo00D007ooOomoo`0000Aoo`03001oogoo
02Eoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`0JOol001Eoo`03001oogoo00Uoo`0301moogoo00]oo`=l015oo`<000Aoo`03
001oogoo009oo`03001oogoo02=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0S
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol09Woo00<007oo00000goo00<007oo
Ool00Woo00<007ooOol097oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol06Woo000EOol0
0`00Oomoo`08Ool00`0OOomoo`0:Ool2O00FOol00`00Oomoo`03Ool4000WOol30005Ool4000WOol3
0005Ool4000ZOol20004Ool4000WOol50003Ool4000MOol001Eoo`03001oogoo00Qoo`0301moogoo
00Qoo`9l0?moo`eoo`005Goo0P0027oo00<07gooOol01Woo0g`0o7oo10000goo1@001Woo000EOol0
0`00Oomoo`06Ool00`0OOomoo`05Ool2O03nOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool001Eoo`03001oogoo00Ioo`0301moogoo00=oo`9l0?moo`=oo`<000Eoo`03001oogoo00Io
o`005Goo00<007ooOol01Goo00<07gooOol00Woo0W`0ogoo17oo00<007ooOol01Woo00<007ooOol0
1Woo000EOol00`00Oomoo`05Ool00`0OOomoo`02O03oOol6Ool00`00Oomoo`06Ool00`00Oomoo`06
Ool000moo`d0000401l00000O03n0009Ool00`00Oomoo`05Ool20008Ool001Eoo`03001oogoo00Ao
o`0401ml07`0000:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0?
Ool00`00Oomoo`0>Ool001Eoo`03001oogoo00=oo`0301ml07oo02]oo`03001oogoo031oo`03001o
ogoo031oo`03001oogoo035oo`03001oogoo031oo`03001oogoo011oo`<000eoo`005Goo00<007oo
Ool00Woo00=l000OOol0ogoo37oo0P000Woo00<007ooOol02Woo000EOol00`00Oomoo`02Ool00`0O
Oomoo`3oOol>Ool3000<Ool001Eoo`8000=oo`0301moogoo0?mooaeoo`005Goo00<007ooOol0ogoo
8Woo000EOol00`00Oomoo`3oOolROol001Eoo`03001oogoo0?moob9oo`005Goo00<007ooOol0ogoo
8Woo003oOoljOol00?moocYoo`00ogoo>Woo003oOoljOol00?moocYoo`00ogoo>Woo003oOoljOol0
0?moocYoo`00ogoo>Woo003oOoljOol000]oo`D000=oo`03001oogoo00]oo`<00?mooaIoo`003Goo
00<007ooOol00goo0P0037oo00<007ooOol0ogoo5Woo0005Ool30005Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool30006Ool00`00Oomoo`3oOolEOol000Ioo`03001oogoo00Aoo`03001oogoo00Aoo`80
00Aoo`03001oogoo00Eoo`03001oogoo0?mooaEoo`001Woo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol017oo00<007oo0000ogoo5Woo0006Ool00`00Ool00003Ool2000<Ool00`00Ool00005
Ool00`00Oomoo`3oOolEOol000Ioo`<0015oo`<00?mooaeoo`001Woo00<007oo00004Goo00<007oo
0000ogoo7Goo0006Ool01@00Oomoogoo00003goo00D007ooOomoo`000?mooa]oo`001Goo1P003Woo
1P00ogoo6goo003oOoljOol00?moocYoo`00ogoo>Woo003oOoljOol00?moocYoo`00\
\>"],
  ImageRangeCache->{{{0, 312.438}, {192.563, 0}} -> {-4.18233, -6.44295, \
0.242786, 0.0509185}}]
}, Open  ]],

Cell[TextData[{
  "The utilization of the numerical capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allows us to examine the solution of the reduced equations for a limited \
range in ",
  StyleBox["zeta1",
    FontSlant->"Italic"],
  " and for a special choice of initial values. This numerical representation \
of the solution compared with an analytic solution is far from being \
complete. An analytic solution, if we found one, is valid for all initial \
conditions and unlimited in the range of the independent variable. So \
numerical solution can only show us the behavior for a specific case of \
initial conditions.\[ThickSpace]\[EmptySquare]"
}], "Text",
  CellTags->"analytic solution"],

Cell["Example 4", "Example"],

Cell[TextData[{
  "Another problem also handled by the function ",
  StyleBox["LieReduction[]", "MmaText"],
  " is the reduction of partial differential equations in more than two \
independent variables. Such a case is given by the ",
  ButtonBox["Karpman-Belashov",
    ButtonData:>{"Literat.nb", "Karp-91"},
    ButtonStyle->"Hyperlink"],
  " equation (KB) (",
  ButtonBox["Karpman and Belashov [1991]",
    ButtonData:>{"Literat.nb", "Karp-91"},
    ButtonStyle->"Hyperlink"],
  ")"
}], "Text",
  Evaluatable->False,
  CellTags->{"LieReduction[]", "Karpman-Belashov equation"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"6", " ", 
            FormBox[\(u\_x\%2\),
              "TraditionalForm"]}], " ", "+", " ", \(u\_\(x, t\)\), " ", "+", 
          " ", \(6\ u\ u\_\(x, x\)\), "-", \(u\_\(y, y\)\), "-", 
          \(\[Mu]\ u\_\(x, x, x\)\), "-", \(\[Epsilon]\ u\_\(x, x, x, x\)\), 
          "-", \(\[Lambda]\ u\_\(x, x, x, x, x, x\)\)}], "=", "0."}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[
"The KB equation contains the Zabolotskaya-Khoklov equation (ZK) with \
\[Epsilon] = 0 and \[Lambda] = 0, and the Kadomtsev-Petviashvili equation \
(KP) with \[Mu] = 0 and \[Lambda] = 0. The KB-equation is used to model \
two-dimensional solitons and wave packages in weakly dispersive and \
dissipative media. Karpman and Belashov studied this type of equation \
numerically. We will examine here the algebraic properties of the equation. \
Especially, we will examine the ZK equation and the corresponding analytical \
solutions. First, let us determine the symmetries of the  KB equation"], 
  "Text",
  Evaluatable->False,
  CellTags->{
  "Zabolotskaya-Khoklov equation", "KB-equation", 
    "Kadomtsev-Petviashvili equation", 
    "wave in weakly dispersive and dissipative media", "ZK-equation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(karp = {
        \[PartialD]\_x\((
              \[PartialD]\_t u[x, y, t] + 
                6\ u[x, y, t]\ \[PartialD]\_x u[x, y, t] - \ \n\t\t\t\t
                \[Mu]\ \[PartialD]\_{x, 2}u[x, y, t] - 
                \[Epsilon]\ \[PartialD]\_{x, 3}u[x, y, t] - \n\t\t\t\t\t
                \[Lambda]\ \[PartialD]\_{x, 5}u[x, y, t])\) - 
          \[PartialD]\_{y, 2}u[x, y, t]}; karp // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            \(6\ u\_x\%2 + u\_\(x, t\) + 6\ u\ u\_\(x, x\) - u\_\(y, y\) - 
                \[Mu]\ u\_\(x, x, x\) - \[Epsilon]\ u\_\(x, x, x, x\) - 
                \[Lambda]\ u\_\(x, x, x, x, x, x\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[
"The three parameters \[Lambda], \[Mu], and \[Epsilon] are real constants. \
The infinitesimals of the KB equation follow by"], "Text",
  Evaluatable->False,
  CellTags->{"KB-equation", "infinitesimals of the KB-equation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ikarp = 
      Infinitesimals[karp, {u}, {x, y, t}, {\[Mu], \[Epsilon], \[Lambda]}]; 
    ikarp // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              RowBox[{
                StyleBox[\(1\/12\),
                  ScriptLevel->0], " ", 
                \((2\ \((\[ScriptCapitalF]\_2)\)\_t + 
                    y\ \((\[ScriptCapitalF]\_1)\)\_\(t, t\))\)}]}]},
          {
            RowBox[{\(\[Xi]\_1\), "==", 
              RowBox[{\(\[ScriptCapitalF]\_2\), "+", 
                RowBox[{
                  StyleBox[\(1\/2\),
                    ScriptLevel->0], " ", "y", " ", 
                  \(\((\[ScriptCapitalF]\_1)\)\_t\)}]}]}]},
          {\(\[Xi]\_2 == \[ScriptCapitalF]\_1\)},
          {\(\[Xi]\_3 == k1\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Rational[ 1, 12], 
            Plus[ 
              Times[ 2, 
                Subscript[ 
                  Subscript[ \[ScriptCapitalF], 2], t]], 
              Times[ y, 
                Subscript[ 
                  Subscript[ \[ScriptCapitalF], 1], t, t]]]]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Plus[ 
            Subscript[ \[ScriptCapitalF], 2], 
            Times[ 
              Rational[ 1, 2], y, 
              Subscript[ 
                Subscript[ \[ScriptCapitalF], 1], t]]]], 
        Equal[ 
          Subscript[ \[Xi], 2], 
          Subscript[ \[ScriptCapitalF], 1]], 
        Equal[ 
          Subscript[ \[Xi], 3], k1]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of the calculation is an infinite dimensional symmetry group \
determined by two arbitrary functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[ScriptCapitalF]\_1\),
            FontFamily->"Times",
            FontSize->10,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            PrivateFontOptions->{"FontPostScriptName"->Automatic}], "="}], 
        " "}]]],
  StyleBox["free", "MmaText",
    FontSlant->"Italic"],
  StyleBox["[", "MmaText"],
  StyleBox["1", "MmaText",
    FontSlant->"Italic"],
  StyleBox["]", "MmaText"],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[ScriptCapitalF]\_2\),
            FontFamily->"Times",
            FontSize->10,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            PrivateFontOptions->{"FontPostScriptName"->Automatic}], "="}], 
        " "}]]],
  StyleBox["free", "MmaText",
    FontSlant->"Italic"],
  StyleBox["[", "MmaText"],
  StyleBox["2", "MmaText",
    FontSlant->"Italic"],
  StyleBox["]", "MmaText"],
  StyleBox[".",
    FontSlant->"Italic"],
  " These two functions determine the transformation of the ",
  Cell[BoxData[
      \(TraditionalForm\`y, x\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " coordinates. We also observe that the group is free of any system \
parameter \[Lambda], \[Epsilon], and \[Mu]. The two arbitrary functions ",
  StyleBox["free", "MmaText",
    FontSlant->"Italic"],
  StyleBox["[", "MmaText"],
  StyleBox["1", "MmaText",
    FontSlant->"Italic"],
  StyleBox["]", "MmaText"],
  " and",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["free", "MmaText",
    FontSlant->"Italic"],
  StyleBox["[", "MmaText"],
  StyleBox["2", "MmaText",
    FontSlant->"Italic"],
  StyleBox["]", "MmaText"],
  " do not have to satisfy any other equations. Thus, we can choose them \
individually. If we assume, for example, that these functions are given by \
two constants ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["free",
                FontSlant->"Italic"], 
              StyleBox["[",
                "MmaText"], 
              StyleBox["1",
                "MmaText"], 
              StyleBox["]",
                "MmaText"]}], 
            StyleBox["[",
              "MmaText"], 
            StyleBox["t",
              "MmaText"], 
            StyleBox["]",
              "MmaText"]}], 
          StyleBox[" ",
            "MmaText"], 
          StyleBox["=",
            "MmaText"], 
          StyleBox[" ",
            "MmaText"], 
          StyleBox["k2",
            "MmaText",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["free",
                FontSlant->"Italic"], 
              StyleBox["[",
                "MmaText"], 
              StyleBox["2",
                "MmaText"], 
              StyleBox["]",
                "MmaText"]}], 
            StyleBox["[",
              "MmaText"], 
            StyleBox["t",
              "MmaText"], 
            StyleBox["]",
              "MmaText"]}], 
          StyleBox[" ",
            "MmaText"], 
          StyleBox["=",
            "MmaText"], 
          StyleBox[" ",
            "MmaText",
            FontSlant->"Italic"], 
          StyleBox["k3",
            "MmaText",
            FontSlant->"Italic"]}], TraditionalForm]]],
  ", we immanently select from the infinite dimensional group those subgroups \
which describe the invariance of the equation with respect to translations in \
the independent variables. At the other hand, this special subgroup creates \
the following reduction:"
}], "Text",
  Evaluatable->False,
  CellTags->{"infinite-dimensional symmetry group", "subgroup"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(rkarp = LieReduction[karp, {u}, {x, y, t}, {k1, k2, k3}, \n\t\t{0}]; 
    LTF[Flatten[rkarp]] /. {zeta1 \[Rule] \[Zeta]\_1, 
        zeta2 \[Rule] \[Zeta]\_2}\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[\(\(\(-k1\)\ t + k3\ x\)\/k1\),
                    ScriptLevel->0]}], "-", \(\[Zeta]\_1\)}], "==", "0"}]},
          {
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[\(\(k2\ x - k1\ y\)\/k1\),
                    ScriptLevel->0]}], "-", \(\[Zeta]\_2\)}], "==", "0"}]},
          {\(u - F\_1 == 0\)},
          {
            \(6\ k1\^4\ k3\^2\ \((F\_1)\)\_\[Zeta]\_1\%2 + 
                12\ k1\^4\ k2\ k3\ \((F\_1)\)\_\(\[Zeta]\_1\)\ 
                  \((F\_1)\)\_\(\[Zeta]\_2\) + 
                6\ k1\^4\ k2\^2\ \((F\_1)\)\_\[Zeta]\_2\%2 - 
                k1\^5\ k3\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) + 
                6\ k1\^4\ k3\^2\ F\_1\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) - 
                k1\^5\ k2\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) + 
                12\ k1\^4\ k2\ k3\ F\_1\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) - 
                k1\^6\ \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                6\ k1\^4\ k2\^2\ F\_1\ 
                  \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                k1\^3\ k3\^3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1\) + 
                3\ k1\^3\ k2\ k3\^2\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2\) + 
                3\ k1\^3\ k2\^2\ k3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2\) + 
                k1\^3\ k2\^3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                k1\^2\ k3\^4\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1\) - 
                4\ k1\^2\ k2\ k3\^3\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_2\) - 
                6\ k1\^2\ k2\^2\ k3\^2\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2, 
                    \[Zeta]\_2\) - 
                4\ k1\^2\ k2\^3\ k3\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2\) - 
                k1\^2\ k2\^4\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2\) - 
                k3\^6\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1\) - 
                6\ k2\ k3\^5\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2\) - 
                15\ k2\^2\ k3\^4\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2\) - 
                20\ k2\^3\ k3\^3\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                15\ k2\^4\ k3\^2\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2, 
                    \[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                6\ k2\^5\ k3\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                k2\^6\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a non-linear partial differential equation of sixth order \
for the similarity function ",
  Cell[BoxData[
      \(TraditionalForm\`F1\)],
    FontSlant->"Italic"],
  ". The similarity function depends on the two similarity variables ",
  StyleBox["zeta1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["zeta2",
    FontSlant->"Italic"],
  ". Thus, we reduced a (2+1)-dimensional PDE to a (1+1)-dimensional PDE. \
Both similarity variables ",
  StyleBox["zeta1 ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["zeta2",
    FontSlant->"Italic"],
  " are invariants of the KP equation. The reduced equation is again a \
candidate for Lie's method. For the sake of simplicity, we choose the group \
constants ",
  StyleBox["k1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["k2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["k3",
    FontSlant->"Italic"],
  " in a suited way by  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k1",
            FontSlant->"Italic"], "=", 
          RowBox[{
            StyleBox["k2",
              FontSlant->"Italic"], "=", "1"}]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k3",
            FontSlant->"Italic"], "=", "v"}], TraditionalForm]]],
  ". The corresponding reduction thus simplifies to"
}], "Text",
  Evaluatable->False,
  CellTags->{
  "nonlinear partial differential equation of sixth order", "reduction"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(rkarp1 = LieReduction[karp, {u}, {x, y, t}, {1, 1, v}, \n\t\t{0}]; 
    LTF[Flatten[rkarp1]] /. {zeta1 \[Rule] \[Zeta]\_1, 
        zeta2 \[Rule] \[Zeta]\_2}\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(t - v\ x - \[Zeta]\_1 == 0\)},
          {\(\(-x\) + y - \[Zeta]\_2 == 0\)},
          {\(u - F\_1 == 0\)},
          {
            \(6\ v\^2\ \((F\_1)\)\_\[Zeta]\_1\%2 + 
                12\ v\ \((F\_1)\)\_\(\[Zeta]\_1\)\ 
                  \((F\_1)\)\_\(\[Zeta]\_2\) + 6\ \((F\_1)\)\_\[Zeta]\_2\%2 - 
                v\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) + 
                6\ v\^2\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) - 
                \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) + 
                12\ v\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) - 
                \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                6\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                v\^3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1\) + 
                3\ v\^2\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2\) + 
                3\ v\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2\) + 
                \[Mu]\ \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                v\^4\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1\) - 
                4\ v\^3\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_2\) - 
                6\ v\^2\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2, 
                    \[Zeta]\_2\) - 
                4\ v\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2\) - 
                \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2\) - 
                v\^6\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1\) - 
                6\ v\^5\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2\) - 
                15\ v\^4\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2\) - 
                20\ v\^3\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                15\ v\^2\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2, 
                    \[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                6\ v\ \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                \[Lambda]\ 
                  \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
It is obvious that the reduction of the KB equation is a \
sixth-order non-linear PDE in 1+1 variables. Thus, the resulting equation is \
nearly as complicated as the original equation. To simplify things, let us \
examine models which follow from the KB equation. If we change the parameters \
in the KB equation in an appropriate way, we get a simplified equation. One \
example is the reduction of the KB equation by\
\>", "Text",
  CellTags->{"KB-equation", "sixth-order nonlinear PDE"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(karps1\  = \ karp\  /. \ \[Lambda] \[Rule] 0; karps1 // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            \(6\ u\_x\%2 + u\_\(x, t\) + 6\ u\ u\_\(x, x\) - u\_\(y, y\) - 
                \[Mu]\ u\_\(x, x, x\) - \[Epsilon]\ u\_\(x, x, x, x\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
This kind of equation is called a reduced KB equation (rKB) in the \
following. The infinitesimals of this equation are calculated by\
\>", "Text",\

  CellTags->"reduced KB-equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(infkarps1\  = \ 
      Infinitesimals[karps1, u, {x, y, t}, {\[Mu], \[Epsilon]}]; 
    infkarps1\  // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              RowBox[{
                StyleBox[\(1\/12\),
                  ScriptLevel->0], " ", 
                \((2\ \((\[ScriptCapitalF]\_2)\)\_t + 
                    y\ \((\[ScriptCapitalF]\_1)\)\_\(t, t\))\)}]}]},
          {
            RowBox[{\(\[Xi]\_1\), "==", 
              RowBox[{\(\[ScriptCapitalF]\_2\), "+", 
                RowBox[{
                  StyleBox[\(1\/2\),
                    ScriptLevel->0], " ", "y", " ", 
                  \(\((\[ScriptCapitalF]\_1)\)\_t\)}]}]}]},
          {\(\[Xi]\_2 == \[ScriptCapitalF]\_1\)},
          {\(\[Xi]\_3 == k1\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Rational[ 1, 12], 
            Plus[ 
              Times[ 2, 
                Subscript[ 
                  Subscript[ \[ScriptCapitalF], 2], t]], 
              Times[ y, 
                Subscript[ 
                  Subscript[ \[ScriptCapitalF], 1], t, t]]]]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Plus[ 
            Subscript[ \[ScriptCapitalF], 2], 
            Times[ 
              Rational[ 1, 2], y, 
              Subscript[ 
                Subscript[ \[ScriptCapitalF], 1], t]]]], 
        Equal[ 
          Subscript[ \[Xi], 2], 
          Subscript[ \[ScriptCapitalF], 1]], 
        Equal[ 
          Subscript[ \[Xi], 3], k1]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Again, we find a group which is determined by two arbitrary functions ",
  Cell[BoxData[
      \(\[ScriptCapitalF]\_1\)], "MmaText"],
  " ",
  StyleBox["= ", "MmaText"],
  StyleBox["free", "MmaText",
    FontSlant->"Italic"],
  StyleBox["[", "MmaText"],
  StyleBox["1", "MmaText",
    FontSlant->"Italic"],
  StyleBox["] ", "MmaText"],
  "and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[ScriptCapitalF]\_2\),
            FontFamily->"Times",
            FontSize->10,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            PrivateFontOptions->{"FontPostScriptName"->Automatic}], "="}], 
        "  "}]]],
  StyleBox["f",
    FontSlant->"Italic"],
  StyleBox["ree", "MmaText",
    FontSlant->"Italic"],
  StyleBox["[", "MmaText"],
  StyleBox["2", "MmaText",
    FontSlant->"Italic"],
  StyleBox["]", "MmaText"],
  ". Both functions depend only on ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " and are not restricted by any side conditions. It is obvious that the \
symmetries of the model with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 0\)]],
  " allow the same transformations as the complete model."
}], "Text"],

Cell[TextData[{
  "The following reduction of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 0\)]],
  " model assumes that ",
  StyleBox["free", "MmaText",
    FontSlant->"Italic"],
  StyleBox["[2] = 1 = ", "MmaText"],
  StyleBox["free", "MmaText",
    FontSlant->"Italic"],
  StyleBox["[1]", "MmaText"],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k1",
            FontSlant->"Italic"], "=", "c"}], TraditionalForm]], "MmaText"],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " a real constant:"
}], "Text",
  CellTags->"reduction"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rkarps1 = LieReduction[karps1, {u}, {x, y, t}, {1, 1, c}, \n\t\t{0}]; 
    LTF[Flatten[rkarps1]] /. {zeta1 \[Rule] \[Zeta]\_1, 
        zeta2 \[Rule] \[Zeta]\_2}\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(t - c\ x - \[Zeta]\_1 == 0\)},
          {\(\(-x\) + y - \[Zeta]\_2 == 0\)},
          {\(u - F\_1 == 0\)},
          {
            \(6\ c\^2\ \((F\_1)\)\_\[Zeta]\_1\%2 + 
                12\ c\ \((F\_1)\)\_\(\[Zeta]\_1\)\ 
                  \((F\_1)\)\_\(\[Zeta]\_2\) + 6\ \((F\_1)\)\_\[Zeta]\_2\%2 - 
                c\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) + 
                6\ c\^2\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) - 
                \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) + 
                12\ c\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) - 
                \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                6\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                c\^3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1\) + 
                3\ c\^2\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2\) + 
                3\ c\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2\) + 
                \[Mu]\ \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) - 
                c\^4\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_1\) - 
                4\ c\^3\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1, 
                    \[Zeta]\_2\) - 
                6\ c\^2\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2, 
                    \[Zeta]\_2\) - 
                4\ c\ \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2\) - 
                \[Epsilon]\ 
                  \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2, 
                    \[Zeta]\_2\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a fourth-order non-linear PDE in the similarity variables ",
  StyleBox["zeta1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["zeta2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["F1",
    FontSlant->"Italic"],
  ". The reduction is as complicated as the reduction of the full KB \
equation."
}], "Text",
  CellTags->"fourth-order nonlinear PDE"],

Cell[TextData[
"Another simplification of the original KB equation follows if we set \
\[Epsilon] and \[Lambda] equal to zero:"], "Text",
  CellTags->"KB-equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(karps2\  = \ karp\  /. \ {\[Lambda] \[Rule] 0, \[Epsilon] \[Rule] 0}; 
    karps2 // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            \(6\ u\_x\%2 + u\_\(x, t\) + 6\ u\ u\_\(x, x\) - u\_\(y, y\) - 
                \[Mu]\ u\_\(x, x, x\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
The resulting equation is known as the ZK equation. The symmetries \
of the ZK equation are determined by\
\>", "Text",
  CellTags->"ZK-equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(infkarps2\  = \ Infinitesimals[karps2, u, {x, y, t}, {\[Mu]}]; 
    infkarps2\  // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              RowBox[{
                StyleBox[\(1\/12\),
                  ScriptLevel->0], " ", 
                \((\(-6\)\ k2\ u + 2\ \((\[ScriptCapitalF]\_2)\)\_t + 
                    y\ \((\[ScriptCapitalF]\_1)\)\_\(t, t\))\)}]}]},
          {
            RowBox[{\(\[Xi]\_1\), "==", 
              RowBox[{
                StyleBox[\(1\/2\),
                  ScriptLevel->0], " ", 
                \((k2\ x + 2\ \[ScriptCapitalF]\_2 + 
                    y\ \((\[ScriptCapitalF]\_1)\)\_t)\)}]}]},
          {
            RowBox[{\(\[Xi]\_2\), "==", 
              RowBox[{
                StyleBox[\(\(3\ k2\ y\)\/4\),
                  ScriptLevel->0], "+", \(\[ScriptCapitalF]\_1\)}]}]},
          {\(\[Xi]\_3 == k1 + k2\ t\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Rational[ 1, 12], 
            Plus[ 
              Times[ -6, k2, u], 
              Times[ 2, 
                Subscript[ 
                  Subscript[ \[ScriptCapitalF], 2], t]], 
              Times[ y, 
                Subscript[ 
                  Subscript[ \[ScriptCapitalF], 1], t, t]]]]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Times[ k2, x], 
              Times[ 2, 
                Subscript[ \[ScriptCapitalF], 2]], 
              Times[ y, 
                Subscript[ 
                  Subscript[ \[ScriptCapitalF], 1], t]]]]], 
        Equal[ 
          Subscript[ \[Xi], 2], 
          Plus[ 
            Times[ 
              Rational[ 3, 4], k2, y], 
            Subscript[ \[ScriptCapitalF], 1]]], 
        Equal[ 
          Subscript[ \[Xi], 3], 
          Plus[ k1, 
            Times[ k2, t]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "For this model, we again find an infinite symmetry group depending on two \
arbitrary functions. Contrary to the models examined above, the discrete part \
of the symmetry group increases by one group parameter. The reduction of this \
model for a scaling group with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["k2",
              FontSlant->"Italic"], "=", "1"}], ",", " ", 
          RowBox[{
            StyleBox["k1",
              FontSlant->"Italic"], "=", "0"}]}], TraditionalForm]]],
  ", and the arbitrary functions set equal to zero follows by"
}], "Text",
  CellTags->{"infinite symmetry group", "scaling group"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(rkarps21 = 
      LieReduction[karps2, {u}, {x, y, t}, {x\/2, \(3  y\)\/4, t}, \n
          \t\t{\(-\(u\/2\)\)}] // PowerExpand; 
    LTF[Flatten[rkarps21]] /. {zeta1 \[Rule] \[Zeta]\_1, 
        zeta2 \[Rule] \[Zeta]\_2}\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                StyleBox[\(t\/x\^2\),
                  ScriptLevel->0], "-", \(\[Zeta]\_1\)}], "==", "0"}]},
          {
            RowBox[{
              RowBox[{
                StyleBox[\(y\/x\^\(3/2\)\),
                  ScriptLevel->0], "-", \(\[Zeta]\_2\)}], "==", "0"}]},
          {\(u\ x - F\_1 == 0\)},
          {
            \(\[Zeta]\_1\%\(7/4\)\ 
                \((48\ I\ t\^\(1/4\)\ \[Mu]\ F\_1 + 
                    144\ I\ t\^\(1/4\)\ F\_1\%2 - 
                    24\ I\ t\^\(1/4\)\ \((F\_1)\)\_\(\[Zeta]\_1\) + 
                    432\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_1\ 
                      \((F\_1)\)\_\(\[Zeta]\_1\) + 
                    672\ I\ t\^\(1/4\)\ F\_1\ \[Zeta]\_1\ 
                      \((F\_1)\)\_\(\[Zeta]\_1\) + 
                    192\ I\ t\^\(1/4\)\ \[Zeta]\_1\%2\ 
                      \((F\_1)\)\_\[Zeta]\_1\%2 + 
                    267\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_2\ 
                      \((F\_1)\)\_\(\[Zeta]\_2\) + 
                    468\ I\ t\^\(1/4\)\ F\_1\ \[Zeta]\_2\ 
                      \((F\_1)\)\_\(\[Zeta]\_2\) + 
                    288\ I\ t\^\(1/4\)\ \[Zeta]\_1\ \[Zeta]\_2\ 
                      \((F\_1)\)\_\(\[Zeta]\_1\)\ 
                      \((F\_1)\)\_\(\[Zeta]\_2\) + 
                    108\ I\ t\^\(1/4\)\ \[Zeta]\_2\%2\ 
                      \((F\_1)\)\_\[Zeta]\_2\%2 - 
                    16\ I\ t\^\(1/4\)\ \[Zeta]\_1\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) + 
                    384\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_1\%2\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) + 
                    192\ I\ t\^\(1/4\)\ F\_1\ \[Zeta]\_1\%2\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) - 
                    12\ I\ t\^\(1/4\)\ \[Zeta]\_2\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) + 
                    540\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_1\ \[Zeta]\_2\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) + 
                    288\ I\ t\^\(1/4\)\ F\_1\ \[Zeta]\_1\ \[Zeta]\_2\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) - 
                    8\ I\ t\^\(1/4\)\ 
                      \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                    189\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_2\%2\ 
                      \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                    108\ I\ t\^\(1/4\)\ F\_1\ \[Zeta]\_2\%2\ 
                      \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                    64\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_1\%3\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1\) + 
                    144\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_1\%2\ \[Zeta]\_2\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2\) + 
                    108\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_1\ \[Zeta]\_2\%2\ 
                      \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2\) + 
                    27\ I\ t\^\(1/4\)\ \[Mu]\ \[Zeta]\_2\%3\ 
                      \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\))
                  \) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
representing a third-order non-linear PDE. Another reduction \
follows for translations as symmetry transformations:\
\>", "Text",
  CellTags->{"third-order nonlinear PDE", "translation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(rkarps22 = LieReduction[karps2, {u}, {x, y, t}, {1, 1, c}, \n\t\t{0}]; 
    LTF[Flatten[rkarps22]] /. {zeta1 \[Rule] \[Zeta]\_1, 
        zeta2 \[Rule] \[Zeta]\_2}\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(t - c\ x - \[Zeta]\_1 == 0\)},
          {\(\(-x\) + y - \[Zeta]\_2 == 0\)},
          {\(u - F\_1 == 0\)},
          {
            \(6\ c\^2\ \((F\_1)\)\_\[Zeta]\_1\%2 + 
                12\ c\ \((F\_1)\)\_\(\[Zeta]\_1\)\ 
                  \((F\_1)\)\_\(\[Zeta]\_2\) + 6\ \((F\_1)\)\_\[Zeta]\_2\%2 - 
                c\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) + 
                6\ c\^2\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) - 
                \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) + 
                12\ c\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2\) - 
                \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                6\ F\_1\ \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2\) + 
                c\^3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_1\) + 
                3\ c\^2\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1, \[Zeta]\_2\) + 
                3\ c\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_2, \[Zeta]\_2\) + 
                \[Mu]\ \((F\_1)\)\_\(\[Zeta]\_2, \[Zeta]\_2, \[Zeta]\_2\) == 0
              \)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
We use this similarity representation to apply Lie's procedure \
again. The symmetries of the reduction follow by\
\>", "Text",
  CellTags->{"similarity representation", "Lie's procedure"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(irkarps22 = 
      Infinitesimals[rkarps22\[LeftDoubleBracket]3, 1\[RightDoubleBracket], 
        F1, {zeta1, zeta2}, {c, \[Mu]}, 
        SubstitutionRules \[Rule] {\[PartialD]\_{zeta1, 3}F1[zeta1, zeta2]}]; 
    irkarps22 // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              
              StyleBox[
                \(\(\((1 - 4\ c + 24\ c\^2\ F1)\)\ k3\)\/\(\(-6\) + 
                      12\ c\)\),
                ScriptLevel->0]}]},
          {
            RowBox[{\(\[Xi]\_1\), "==", 
              
              StyleBox[
                \(\(\((\(-1\) + 2\ c)\)\ k1 - 
                      c\ k3\ \((zeta1 + 4\ c\ zeta1 - c\ zeta2)\)\)\/\(\(-1
                        \) + 2\ c\)\),
                ScriptLevel->0]}]},
          {
            RowBox[{\(\[Xi]\_2\), "==", 
              
              StyleBox[
                \(\(\((\(-1\) + 2\ c)\)\ k2 + 
                      k3\ \((\((\(-1\) + 2\ c)\)\ zeta1 + 
                            \((1 - 6\ c)\)\ c\ zeta2)\)\)\/\(\(-1\) + 
                      2\ c\)\),
                ScriptLevel->0]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Power[ 
              Plus[ -6, 
                Times[ 12, c]], -1], 
            Plus[ 1, 
              Times[ -4, c], 
              Times[ 24, 
                Power[ c, 2], F1]], k3]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Times[ 
            Power[ 
              Plus[ -1, 
                Times[ 2, c]], -1], 
            Plus[ 
              Times[ 
                Plus[ -1, 
                  Times[ 2, c]], k1], 
              Times[ -1, c, k3, 
                Plus[ zeta1, 
                  Times[ 4, c, zeta1], 
                  Times[ -1, c, zeta2]]]]]], 
        Equal[ 
          Subscript[ \[Xi], 2], 
          Times[ 
            Power[ 
              Plus[ -1, 
                Times[ 2, c]], -1], 
            Plus[ 
              Times[ 
                Plus[ -1, 
                  Times[ 2, c]], k2], 
              Times[ k3, 
                Plus[ 
                  Times[ 
                    Plus[ -1, 
                      Times[ 2, c]], zeta1], 
                  Times[ 
                    Plus[ 1, 
                      Times[ -6, c]], c, zeta2]]]]]]}]]], "Output"]
}, Open  ]],

Cell["\<\
The result is a finite symmetry group of order three, allowing us a \
further reduction. Before we execute this step, we rename the variables to \
simplify the equations:\
\>", "Text",
  CellTags->"finite symmetry group"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqv\  = 
      \ {rkarps22\[LeftDoubleBracket]3, 1, 1\[RightDoubleBracket]} /. 
        \ {F1 \[Rule] H, zeta1 \[Rule] \[Zeta]1, zeta2 \[Rule] \[Zeta]2}; 
    eqv // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            \(6\ c\^2\ H\_\[Zeta]1\%2 + 12\ c\ H\_\[Zeta]1\ H\_\[Zeta]2 + 
                6\ H\_\[Zeta]2\%2 - c\ H\_\(\[Zeta]1, \[Zeta]1\) + 
                6\ c\^2\ H\ H\_\(\[Zeta]1, \[Zeta]1\) - 
                H\_\(\[Zeta]1, \[Zeta]2\) + 
                12\ c\ H\ H\_\(\[Zeta]1, \[Zeta]2\) - 
                H\_\(\[Zeta]2, \[Zeta]2\) + 6\ H\ H\_\(\[Zeta]2, \[Zeta]2\) + 
                c\^3\ \[Mu]\ H\_\(\[Zeta]1, \[Zeta]1, \[Zeta]1\) + 
                3\ c\^2\ \[Mu]\ H\_\(\[Zeta]1, \[Zeta]1, \[Zeta]2\) + 
                3\ c\ \[Mu]\ H\_\(\[Zeta]1, \[Zeta]2, \[Zeta]2\) + 
                \[Mu]\ H\_\(\[Zeta]2, \[Zeta]2, \[Zeta]2\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
For the non-linear third-order PDE in the second similarity \
representation, we select the subgroup of translations to carry out another \
reduction. The infinitesimals for this case are given by\
\>", "Text",
  CellTags->{
  "nonlinear third-order PDE", "second similarity representation", 
    "infinitesimals"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(inf1\  = \ 
      \(\({\(xi[1]\)[zeta1, zeta2, F1], \(xi[2]\)[zeta1, zeta2, F1]}\  /. \ 
            irkarps22\)\  /. 
          \ {k1 \[Rule] 1, k2 \[Rule] v, k3 \[Rule] 0}\)\  /. {F1 \[Rule] H, 
          zeta1 \[Rule] \[Zeta]1, zeta2 \[Rule] \[Zeta]2}\ \)\)], "Input"],

Cell[BoxData[
    \({1, v}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(inf2\  = \ 
      \(\({\(phi[1]\)[zeta1, zeta2, F1]}\  /. \ irkarps22\)\  /. 
          \ {k1 \[Rule] 1, k2 \[Rule] v, k3 \[Rule] 0}\)\  /. {F1 \[Rule] H, 
          zeta1 \[Rule] \[Zeta]1, zeta2 \[Rule] \[Zeta]2}\ \)\)], "Input"],

Cell[BoxData[
    \({0}\)], "Output"]
}, Open  ]],

Cell["The corresponding reduction follows from", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rkarps221 = LieReduction[eqv, {H}, {\[Zeta]1, \[Zeta]2}, inf1, inf2]; 
    LTF[Flatten[rkarps221]] /. {zeta1 \[Rule] \[Zeta]}\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(\(-\[Zeta]\) - v\ \[Zeta]1 + \[Zeta]2 == 0\)},
          {\(H - F\_1 == 0\)},
          {
            \(6\ \((F\_1)\)\_\[Zeta]\%2 - 12\ c\ v\ \((F\_1)\)\_\[Zeta]\%2 + 
                6\ c\^2\ v\^2\ \((F\_1)\)\_\[Zeta]\%2 - 
                \((F\_1)\)\_\(\[Zeta], \[Zeta]\) + 
                v\ \((F\_1)\)\_\(\[Zeta], \[Zeta]\) - 
                c\ v\^2\ \((F\_1)\)\_\(\[Zeta], \[Zeta]\) + 
                6\ F\_1\ \((F\_1)\)\_\(\[Zeta], \[Zeta]\) - 
                12\ c\ v\ F\_1\ \((F\_1)\)\_\(\[Zeta], \[Zeta]\) + 
                6\ c\^2\ v\^2\ F\_1\ \((F\_1)\)\_\(\[Zeta], \[Zeta]\) + 
                \[Mu]\ \((F\_1)\)\_\(\[Zeta], \[Zeta], \[Zeta]\) - 
                3\ c\ v\ \[Mu]\ \((F\_1)\)\_\(\[Zeta], \[Zeta], \[Zeta]\) + 
                3\ c\^2\ v\^2\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta], \[Zeta], \[Zeta]\) - 
                c\^3\ v\^3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta], \[Zeta], \[Zeta]\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        ColumnWidths->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a third-order non-linear ODE which allows a two-dimensional \
discrete symmetry group depending on group parameters ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " of the preceding reductions:"
}], "Text",
  CellTags->"third-order nonlinear ODE"],

Cell[CellGroupData[{

Cell[BoxData[
    \(irkarps221 = 
      Infinitesimals[rkarps221\[LeftDoubleBracket]3, 1\[RightDoubleBracket], 
        F1, {zeta1}, {c, \[Mu], v}, 
        SubstitutionRules \[Rule] {\[PartialD]\_{zeta1, 3}F1[zeta1]}]; 
    irkarps221 // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              
              StyleBox[
                \(\(k2\ \((
                        \(-1\) + v - c\ v\^2 + 6\ F1\ \((\(-1\) + c\ v)\)\^2)
                        \)\)\/\(6\ \((\(-1\) + c\ v)\)\^2\)\),
                ScriptLevel->0]}]},
          {\(\[Xi]\_1 == k1 - k2\ zeta1\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Rational[ 1, 6], k2, 
            Power[ 
              Plus[ -1, 
                Times[ c, v]], -2], 
            Plus[ -1, v, 
              Times[ -1, c, 
                Power[ v, 2]], 
              Times[ 6, F1, 
                Power[ 
                  Plus[ -1, 
                    Times[ c, v]], 2]]]]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Plus[ k1, 
            Times[ -1, k2, zeta1]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result indicates that the third-order ODE is at least reducible to a \
second-order ODE which, in fact, is possible by an integration with respect \
to ",
  StyleBox["zeta1",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(firstIntegral\  = \ 
      \[Integral]rkarps221\[LeftDoubleBracket]3, 1, 1\[RightDoubleBracket] 
            \[DifferentialD]zeta1\  == \ c1; 
    LTF[firstIntegral] /. zeta1 \[Rule] \[Zeta]\_1\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            \(\(-c1\) + 
                \((\(-1\) + v - c\ v\^2 + 6\ F\_1 - 12\ c\ v\ F\_1 + 
                      6\ c\^2\ v\^2\ F\_1)\)\ \((F\_1)\)\_\(\[Zeta]\_1\)\n
                \t - \((\(-1\) + c\ v)\)\^3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->0.95,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["The resulting second-order ODE is solved by", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1\  = \ DSolve[firstIntegral, F1, zeta1]\)], "Input"],

Cell[BoxData[
    \({{F1 \[Rule] 
          \((\((\((1 - v + c\ v\^2)\)\ 
                      AiryBi[\((
                            13 - 2\ c\ v\^3 + c\^2\ v\^4 + 12\ c1\ #1 - 
                              2\ v\ \((1 + 12\ c\ \((1 + c1\ #1)\))\) + 
                              v\^2\ \((1 + 2\ c + 12\ c\^2\ \((1 + c1\ #1)\))
                                  \))\)/
                          \((4\ 3\^\(2/3\)\ 
                              \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)] - 
                    2\ 3\^\(1/3\)\ \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(1/3\)\ 
                      AiryBiPrime[
                        \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 12\ c1\ #1 - 
                              2\ v\ \((1 + 12\ c\ \((1 + c1\ #1)\))\) + 
                              v\^2\ \((1 + 2\ c + 12\ c\^2\ \((1 + c1\ #1)\))
                                  \))\)/
                          \((4\ 3\^\(2/3\)\ 
                              \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)] + 
                    \((AiryAi[
                            \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 12\ c1\ #1 - 
                                  2\ v\ \((1 + 12\ c\ \((1 + c1\ #1)\))\) + 
                                  v\^2\ \((
                                      1 + 2\ c + 12\ c\^2\ \((1 + c1\ #1)\))
                                      \))\)/
                              \((4\ 3\^\(2/3\)\ 
                                  \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))
                                \)] - 
                          v\ AiryAi[
                              \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 12\ c1\ #1 - 
                                    2\ v\ \((1 + 12\ c\ \((1 + c1\ #1)\))\) + 
                                    v\^2\ \((
                                        1 + 2\ c + 12\ c\^2\ \((1 + c1\ #1)\))
                                        \))\)/
                                \((4\ 3\^\(2/3\)\ 
                                    \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))
                                  \)] + 
                          c\ v\^2\ 
                            AiryAi[
                              \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 12\ c1\ #1 - 
                                    2\ v\ \((1 + 12\ c\ \((1 + c1\ #1)\))\) + 
                                    v\^2\ \((
                                        1 + 2\ c + 12\ c\^2\ \((1 + c1\ #1)\))
                                        \))\)/
                                \((4\ 3\^\(2/3\)\ 
                                    \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))
                                  \)] - 
                          2\ 3\^\(1/3\)\ 
                            \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(1/3\)\ 
                            AiryAiPrime[
                              \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 12\ c1\ #1 - 
                                    2\ v\ \((1 + 12\ c\ \((1 + c1\ #1)\))\) + 
                                    v\^2\ \((
                                        1 + 2\ c + 12\ c\^2\ \((1 + c1\ #1)\))
                                        \))\)/
                                \((4\ 3\^\(2/3\)\ 
                                    \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))
                                  \)])\)\ C[1])\)/
                \((6\ \((\(-1\) + c\ v)\)\^2\ 
                    \((AiryBi[
                          \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 12\ c1\ #1 - 
                                2\ v\ \((1 + 12\ c\ \((1 + c1\ #1)\))\) + 
                                v\^2\ \((
                                    1 + 2\ c + 12\ c\^2\ \((1 + c1\ #1)\))\))
                              \)/\((4\ 3\^\(2/3\)\ 
                                \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))
                              \)] + AiryAi[
                            \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 12\ c1\ #1 - 
                                  2\ v\ \((1 + 12\ c\ \((1 + c1\ #1)\))\) + 
                                  v\^2\ \((
                                      1 + 2\ c + 12\ c\^2\ \((1 + c1\ #1)\))
                                      \))\)/
                              \((4\ 3\^\(2/3\)\ 
                                  \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))
                                \)]\ C[1])\))\)&)\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a complicated expression containing special functions of the \
Airy type. However, the solution simplifies if we set the integration \
constant ",
  StyleBox["c1",
    FontSlant->"Italic"],
  " equal to zero."
}], "Text",
  CellTags->"Airy"],

Cell[CellGroupData[{

Cell[BoxData[
    \(firstIntegral\  = firstIntegral\  /. c1 \[Rule] 0; 
    LTF[firstIntegral] /. zeta1 \[Rule] \[Zeta]\_1\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            \(\((\(-1\) + v - c\ v\^2 + 6\ F\_1 - 12\ c\ v\ F\_1 + 
                      6\ c\^2\ v\^2\ F\_1)\)\ \((F\_1)\)\_\(\[Zeta]\_1\) - 
                \((\(-1\) + c\ v)\)\^3\ \[Mu]\ 
                  \((F\_1)\)\_\(\[Zeta]\_1, \[Zeta]\_1\)\n\t == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["The solution now reads", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol2\  = \ DSolve[firstIntegral, F1, zeta1]\)], "Input"],

Cell[BoxData[
    \({{F1 \[Rule] 
          \((1\/6\ \((
                  1\/\((1 - c\ v)\)\^2 - v\/\(1 - c\ v\) + 
                    \(1\/\((1 - c\ v)\)\^2\) 
                      \((\[Sqrt]\((
                              \(-1\) + 2\ v - v\^2 - 2\ c\ v\^2 + 
                                2\ c\ v\^3 - c\^2\ v\^4 - 12\ C[2] + 
                                24\ c\ v\ C[2] - 12\ c\^2\ v\^2\ C[2])\)\ 
                          Tan[1\/6\ 
                              \((\(-\(\((
                                        3\ #1\ 
                                        \[Sqrt]\((
                                        \(-1\) + 2\ v - v\^2 - 2\ c\ v\^2 + 
                                        2\ c\ v\^3 - c\^2\ v\^4 - 12\ C[2] + 
                                        24\ c\ v\ C[2] - 12\ c\^2\ v\^2\ C[2])
                                        \))\)/
                                      \((\((1 - c\ v)\)\^3\ \[Mu])\)\)\) + 
                                  \(1\/\((1 - c\ v)\)\^2\) 
                                    \((C[1]\ 
                                        \[Sqrt]\((
                                        \(-1\) + 2\ v - v\^2 - 2\ c\ v\^2 + 
                                        2\ c\ v\^3 - c\^2\ v\^4 - 12\ C[2] + 
                                        24\ c\ v\ C[2] - 12\ c\^2\ v\^2\ C[2])
                                        \))\))\)])\))\)&)\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "containing only the ",
  StyleBox["Tan[]", "MmaText"],
  " function. At this stage of the calculation, we derived a solution for a \
special subgroup of all the possible symmetries of the original equation. \
This special function will help us to represent the solution in the original \
variables. To get the representation of the solution in ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, t, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", we have to invert all the similarity transformations carried out above:"
}], "Text",
  CellTags->{"Tan[]", "special function"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol\  = \ 
      u \[Rule] Function[{x, y, t}, $r] /. $r \[Rule] 
          \((F1[t - c\ x, \(-x\) + y] /. 
              \((F1 \[Rule] Function[{zeta1, zeta2}, $w]\  /. 
                  \ $w \[Rule] 
                    \((\((\((H == F1[\(-v\)\ \[Zeta]1 + \[Zeta]2] /. \ sol1)
                              \)\  /. {H \[Rule] F1, \[Zeta]1 \[Rule] zeta1, 
                              \[Zeta]2 \[Rule] zeta2})\)\  /. 
                        \ {Equal[a_, b_]} -> b)\))\))\)\)], "Input",
  CellTags->{"AiryBi[]", "AiryBiPrime[]", "AiryAi[]", "AiryAiPrime[]"}],

Cell[BoxData[
    \(u \[Rule] 
      Function[{x, y, t}, 
        \((\((1 - v + c\ v\^2)\)\ 
                AiryBi[\((
                      13 - 2\ c\ v\^3 + c\^2\ v\^4 + 
                        12\ c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\) - 
                        2\ v\ \((
                            1 + 12\ c\ 
                                \((1 + 
                                    c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\))
                                  \))\) + 
                        v\^2\ \((
                            1 + 2\ c + 
                              12\ c\^2\ 
                                \((1 + 
                                    c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\))
                                  \))\))\)/
                    \((4\ 3\^\(2/3\)\ 
                        \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)] - 
              2\ 3\^\(1/3\)\ \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(1/3\)\ 
                AiryBiPrime[
                  \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 
                        12\ c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\) - 
                        2\ v\ \((
                            1 + 12\ c\ 
                                \((1 + 
                                    c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\))
                                  \))\) + 
                        v\^2\ \((
                            1 + 2\ c + 
                              12\ c\^2\ 
                                \((1 + 
                                    c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\))
                                  \))\))\)/
                    \((4\ 3\^\(2/3\)\ 
                        \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)] + 
              \((AiryAi[
                      \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 
                            12\ c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\) - 
                            2\ v\ \((
                                1 + 12\ c\ 
                                    \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\) + 
                            v\^2\ \((
                                1 + 2\ c + 
                                  12\ c\^2\ 
                                    \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\))\)/
                        \((4\ 3\^\(2/3\)\ 
                            \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)] - 
                    v\ AiryAi[
                        \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 
                              12\ c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\) - 
                              2\ v\ \((
                                  1 + 12\ c\ 
                                      \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\) + 
                              v\^2\ \((
                                  1 + 2\ c + 
                                    12\ c\^2\ 
                                      \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\))\)/
                          \((4\ 3\^\(2/3\)\ 
                              \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)] + 
                    c\ v\^2\ 
                      AiryAi[\((
                            13 - 2\ c\ v\^3 + c\^2\ v\^4 + 
                              12\ c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\) - 
                              2\ v\ \((
                                  1 + 12\ c\ 
                                      \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\) + 
                              v\^2\ \((
                                  1 + 2\ c + 
                                    12\ c\^2\ 
                                      \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\))\)/
                          \((4\ 3\^\(2/3\)\ 
                              \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)] - 
                    2\ 3\^\(1/3\)\ \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(1/3\)\ 
                      AiryAiPrime[
                        \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 
                              12\ c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\) - 
                              2\ v\ 
                                \((1 + 
                                    12\ c\ 
                                      \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\) + 
                              v\^2\ \((
                                  1 + 2\ c + 
                                    12\ c\^2\ 
                                      \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\))\)/
                          \((4\ 3\^\(2/3\)\ 
                              \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)])
                  \)\ C[1])\)/
          \((6\ \((\(-1\) + c\ v)\)\^2\ 
              \((AiryBi[
                    \((13 - 2\ c\ v\^3 + c\^2\ v\^4 + 
                          12\ c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\) - 
                          2\ v\ \((
                              1 + 12\ c\ 
                                  \((1 + 
                                      c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\) + 
                          v\^2\ \((
                              1 + 2\ c + 
                                12\ c\^2\ 
                                  \((1 + 
                                      c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\))\)/
                      \((4\ 3\^\(2/3\)\ 
                          \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)] + 
                  AiryAi[\((
                          13 - 2\ c\ v\^3 + c\^2\ v\^4 + 
                            12\ c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)\) - 
                            2\ v\ \((
                                1 + 12\ c\ 
                                    \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\) + 
                            v\^2\ \((
                                1 + 2\ c + 
                                  12\ c\^2\ 
                                    \((1 + 
                                        c1\ \((\(-x\) - v\ \((t - c\ x)\) + y)
                                        \))\))\))\)/
                        \((4\ 3\^\(2/3\)\ 
                            \((c1\ \((\(-1\) + c\ v)\)\^2)\)\^\(2/3\))\)]\ 
                    C[1])\))\)]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The second type of solution allowed by the reduced KB equation was derived \
for ",
  Cell[BoxData[
      \(TraditionalForm\`c1 = 0\)]],
  ". In original variables, this solution reads "
}], "Text",
  CellTags->"KB-equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sols\  = \ 
      u \[Rule] Function[{x, y, t}, $r] /. $r \[Rule] 
          \((F1[t - c\ x, \(-x\) + y] /. 
              \((F1 \[Rule] Function[{zeta1, zeta2}, $w]\  /. 
                  \ $w \[Rule] 
                    \((\((\((H == F1[\(-v\)\ \[Zeta]1 + \[Zeta]2] /. \ sol2)
                              \)\  /. {H \[Rule] F1, \[Zeta]1 \[Rule] zeta1, 
                              \[Zeta]2 \[Rule] zeta2})\)\  /. 
                        \ {Equal[a_, b_]} -> b)\))\))\)\)], "Input"],

Cell[BoxData[
    \(u \[Rule] 
      Function[{x, y, t}, 
        1\/6\ \((
            1\/\((1 - c\ v)\)\^2 - v\/\(1 - c\ v\) + 
              \(1\/\((1 - c\ v)\)\^2\) 
                \((\[Sqrt]\((
                        \(-1\) + 2\ v - v\^2 - 2\ c\ v\^2 + 2\ c\ v\^3 - 
                          c\^2\ v\^4 - 12\ C[2] + 24\ c\ v\ C[2] - 
                          12\ c\^2\ v\^2\ C[2])\)\ 
                    Tan[1\/6\ 
                        \((\(-\(\(1\/\(\((1 - c\ v)\)\^3\ \[Mu]\)\) 
                                \((3\ \((\(-x\) - v\ \((t - c\ x)\) + y)\)\ 
                                    \[Sqrt]\((
                                        \(-1\) + 2\ v - v\^2 - 2\ c\ v\^2 + 
                                        2\ c\ v\^3 - c\^2\ v\^4 - 12\ C[2] + 
                                        24\ c\ v\ C[2] - 12\ c\^2\ v\^2\ C[2])
                                        \))\)\)\) + 
                            \(1\/\((1 - c\ v)\)\^2\) 
                              \((C[1]\ 
                                  \[Sqrt]\((
                                      \(-1\) + 2\ v - v\^2 - 2\ c\ v\^2 + 
                                        2\ c\ v\^3 - c\^2\ v\^4 - 12\ C[2] + 
                                        24\ c\ v\ C[2] - 12\ c\^2\ v\^2\ C[2])
                                      \))\))\)])\))\)]\)], "Output"]
}, Open  ]],

Cell["We can inspect the ZK equation by this solution:", "Text",
  CellTags->"ZK-equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(karp\  /. \ {\[Lambda] \[Rule] 0, \[Epsilon] \[Rule] 0}\)\  /. sols
        \  // Simplify\)], "Input"],

Cell[BoxData[
    \({0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is that the given solution satisfies the ZK equation. To get an \
impression on how the complicated symbolic solutions behave in the ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, t\)]],
  " space, let us plot the solutions for different times over the (",
  Cell[BoxData[
      \(TraditionalForm\`x, y\)]],
  ")-plane. We choose the parameters for both plots as"
}], "Text",
  CellTags->{"ZK-equation", "symbolic solution"}],

Cell[BoxData[
    \(\(parameters\  = 
      \ {c \[Rule] 2, v \[Rule] 1, C[1] \[Rule] 0, C[2] \[Rule] 1, 
        \[Mu] \[Rule] 2, c1 \[Rule] 1}; \)\)], "Input"],

Cell["The two functions are created by", "Text"],

Cell[BoxData[
    \(\(pl\  = \ \(u[x, y, t]\  /. \ sol\)\  /. parameters; \)\)], "Input"],

Cell[TextData[{
  "for the general case with ",
  Cell[BoxData[
      \(TraditionalForm\`c1 = 1\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pls\  = \ \(u[x, y, t]\  /. \ sols\)\  /. parameters\)], "Input"],

Cell[BoxData[
    \(1\/6\ \((2 + 4\ Tanh[t - x - y])\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The two special solutions serve to create an animation for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) \[LessEqual] t \[LessEqual] \ 2\)]],
  " in steps of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]t = 1/4\)]],
  ". The general solution looks like a bunch of crests moving from the left \
to the right:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Plot3D[
        Evaluate[pl /. t \[Rule] \[Tau]], {x, \(-2\) \[Pi], 2  \[Pi]}, {y, 
          \(-\[Pi]\), \[Pi]}, AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<u\>"}, 
        PlotRange 
          \[Rule] {{\(-2\) \[Pi], 2  \[Pi]}, {\(-\[Pi]\), \[Pi]}, {\(-100\), 
              100}}, PlotPoints \[Rule] 60, Mesh \[Rule] False], {\[Tau], 
        \(-2\), 2,  .25}]\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .75 .92 r
.39636 .69721 .40169 .70188 .41061 .69936 .4053 .6947 Mtetra
.657 .752 .92 r
.4053 .6947 .41061 .69936 .41957 .69679 .41427 .69214 Mtetra
.658 .753 .92 r
.41427 .69214 .41957 .69679 .42855 .6942 .42328 .68953 Mtetra
.659 .754 .92 r
.42328 .68953 .42855 .6942 .43756 .69158 .43231 .6869 Mtetra
.43231 .6869 .43756 .69158 .44661 .68895 .44137 .68426 Mtetra
.44137 .68426 .44661 .68895 .45568 .68632 .45046 .68161 Mtetra
.45046 .68161 .45568 .68632 .46478 .68369 .45959 .67896 Mtetra
.658 .753 .92 r
.45959 .67896 .46478 .68369 .47391 .68106 .46874 .67631 Mtetra
.46874 .67631 .47391 .68106 .48308 .67842 .47792 .67365 Mtetra
.47792 .67365 .48308 .67842 .49227 .67577 .48714 .67099 Mtetra
.48714 .67099 .49227 .67577 .5015 .67313 .49638 .66832 Mtetra
.49638 .66832 .5015 .67313 .51075 .67047 .50566 .66565 Mtetra
.50566 .66565 .51075 .67047 .52004 .66781 .51496 .66297 Mtetra
.51496 .66297 .52004 .66781 .52936 .66514 .5243 .66029 Mtetra
.657 .753 .92 r
.5243 .66029 .52936 .66514 .5387 .66247 .53367 .65759 Mtetra
.53367 .65759 .5387 .66247 .54809 .65978 .54307 .65489 Mtetra
.657 .752 .92 r
.54307 .65489 .54809 .65978 .5575 .65709 .55251 .65218 Mtetra
.55251 .65218 .5575 .65709 .56694 .65439 .56197 .64947 Mtetra
.56197 .64947 .56694 .65439 .57642 .65169 .57147 .64674 Mtetra
.57147 .64674 .57642 .65169 .58593 .64897 .581 .64401 Mtetra
.581 .64401 .58593 .64897 .59547 .64625 .59057 .64127 Mtetra
.59057 .64127 .59547 .64625 .60504 .64351 .60016 .63852 Mtetra
.60016 .63852 .60504 .64351 .61465 .64077 .60979 .63576 Mtetra
.60979 .63576 .61465 .64077 .62429 .63802 .61945 .63299 Mtetra
.61945 .63299 .62429 .63802 .63396 .63526 .62915 .63021 Mtetra
.62915 .63021 .63396 .63526 .64367 .6325 .63888 .62743 Mtetra
.63888 .62743 .64367 .6325 .65341 .62972 .64864 .62463 Mtetra
.64864 .62463 .65341 .62972 .66318 .62693 .65844 .62183 Mtetra
.65844 .62183 .66318 .62693 .67299 .62414 .66827 .61902 Mtetra
.66827 .61902 .67299 .62414 .68283 .62133 .67814 .6162 Mtetra
.67814 .6162 .68283 .62133 .69271 .61852 .68803 .61336 Mtetra
.68803 .61336 .69271 .61852 .70262 .6157 .69797 .61052 Mtetra
.69797 .61052 .70262 .6157 .71256 .61287 .70794 .60767 Mtetra
.70794 .60767 .71256 .61287 .72254 .61002 .71794 .60481 Mtetra
.71794 .60481 .72254 .61002 .73256 .60717 .72798 .60194 Mtetra
.72798 .60194 .73256 .60717 .74261 .60431 .73806 .59906 Mtetra
.73806 .59906 .74261 .60431 .75269 .60144 .74817 .59617 Mtetra
.74817 .59617 .75269 .60144 .76281 .59856 .75831 .59327 Mtetra
.75831 .59327 .76281 .59856 .77297 .59567 .76849 .59037 Mtetra
.76849 .59037 .77297 .59567 .78316 .59277 .77871 .58745 Mtetra
.77871 .58745 .78316 .59277 .79339 .58986 .78896 .58452 Mtetra
.78896 .58452 .79339 .58986 .80365 .58694 .79925 .58158 Mtetra
.79925 .58158 .80365 .58694 .81396 .58401 .80958 .57863 Mtetra
.80958 .57863 .81396 .58401 .82429 .58107 .81995 .57567 Mtetra
.81995 .57567 .82429 .58107 .83467 .57812 .83035 .5727 Mtetra
.83035 .5727 .83467 .57812 .84508 .57516 .84079 .56972 Mtetra
.84079 .56972 .84508 .57516 .85553 .57219 .85126 .56673 Mtetra
.85126 .56673 .85553 .57219 .86602 .56921 .86178 .56373 Mtetra
.86178 .56373 .86602 .56921 .87654 .56622 .87233 .56071 Mtetra
.87233 .56071 .87654 .56622 .8871 .56321 .88292 .55769 Mtetra
.88292 .55769 .8871 .56321 .8977 .5602 .89355 .55466 Mtetra
.89355 .55466 .8977 .5602 .90834 .55718 .90421 .55161 Mtetra
.90421 .55161 .90834 .55718 .91902 .55414 .91492 .54856 Mtetra
.91492 .54856 .91902 .55414 .92973 .5511 .92566 .54549 Mtetra
.92566 .54549 .92973 .5511 .94049 .54804 .93645 .54241 Mtetra
.93645 .54241 .94049 .54804 .95128 .54497 .94727 .53933 Mtetra
.94727 .53933 .95128 .54497 .96211 .54189 .95813 .53623 Mtetra
.95813 .53623 .96211 .54189 .97299 .5388 .96903 .53312 Mtetra
.96903 .53312 .97299 .5388 .9839 .5357 .97998 .53 Mtetra
.654 .749 .92 r
.391 .6925 .39636 .69721 .4053 .6947 .39996 .69 Mtetra
.656 .751 .92 r
.39996 .69 .4053 .6947 .41427 .69214 .40895 .68744 Mtetra
.658 .753 .92 r
.40895 .68744 .41427 .69214 .42328 .68953 .41797 .68484 Mtetra
.659 .753 .92 r
.41797 .68484 .42328 .68953 .43231 .6869 .42702 .6822 Mtetra
.659 .754 .92 r
.42702 .6822 .43231 .6869 .44137 .68426 .4361 .67954 Mtetra
.4361 .67954 .44137 .68426 .45046 .68161 .44522 .67688 Mtetra
.44522 .67688 .45046 .68161 .45959 .67896 .45436 .67421 Mtetra
.659 .753 .92 r
.45436 .67421 .45959 .67896 .46874 .67631 .46353 .67153 Mtetra
.658 .753 .92 r
.46353 .67153 .46874 .67631 .47792 .67365 .47273 .66886 Mtetra
.47273 .66886 .47792 .67365 .48714 .67099 .48197 .66618 Mtetra
.48197 .66618 .48714 .67099 .49638 .66832 .49123 .66349 Mtetra
.49123 .66349 .49638 .66832 .50566 .66565 .50053 .6608 Mtetra
.50053 .6608 .50566 .66565 .51496 .66297 .50986 .6581 Mtetra
.50986 .6581 .51496 .66297 .5243 .66029 .51922 .6554 Mtetra
.657 .753 .92 r
.51922 .6554 .5243 .66029 .53367 .65759 .52861 .65269 Mtetra
.52861 .65269 .53367 .65759 .54307 .65489 .53803 .64997 Mtetra
.53803 .64997 .54307 .65489 .55251 .65218 .54749 .64724 Mtetra
.657 .752 .92 r
.54749 .64724 .55251 .65218 .56197 .64947 .55697 .64451 Mtetra
.55697 .64451 .56197 .64947 .57147 .64674 .56649 .64177 Mtetra
.56649 .64177 .57147 .64674 .581 .64401 .57605 .63902 Mtetra
.57605 .63902 .581 .64401 .59057 .64127 .58563 .63626 Mtetra
.58563 .63626 .59057 .64127 .60016 .63852 .59525 .63349 Mtetra
.59525 .63349 .60016 .63852 .60979 .63576 .6049 .63071 Mtetra
.6049 .63071 .60979 .63576 .61945 .63299 .61459 .62793 Mtetra
.61459 .62793 .61945 .63299 .62915 .63021 .62431 .62513 Mtetra
.62431 .62513 .62915 .63021 .63888 .62743 .63406 .62233 Mtetra
.63406 .62233 .63888 .62743 .64864 .62463 .64384 .61952 Mtetra
.64384 .61952 .64864 .62463 .65844 .62183 .65366 .61669 Mtetra
.65366 .61669 .65844 .62183 .66827 .61902 .66352 .61386 Mtetra
.66352 .61386 .66827 .61902 .67814 .6162 .67341 .61102 Mtetra
.67341 .61102 .67814 .6162 .68803 .61336 .68333 .60817 Mtetra
.68333 .60817 .68803 .61336 .69797 .61052 .69329 .60531 Mtetra
.69329 .60531 .69797 .61052 .70794 .60767 .70328 .60244 Mtetra
.70328 .60244 .70794 .60767 .71794 .60481 .71331 .59957 Mtetra
.71331 .59957 .71794 .60481 .72798 .60194 .72337 .59668 Mtetra
.72337 .59668 .72798 .60194 .73806 .59906 .73347 .59378 Mtetra
.73347 .59378 .73806 .59906 .74817 .59617 .74361 .59087 Mtetra
.74361 .59087 .74817 .59617 .75831 .59327 .75378 .58795 Mtetra
.75378 .58795 .75831 .59327 .76849 .59037 .76399 .58502 Mtetra
.76399 .58502 .76849 .59037 .77871 .58745 .77423 .58208 Mtetra
.77423 .58208 .77871 .58745 .78896 .58452 .78451 .57914 Mtetra
.78451 .57914 .78896 .58452 .79925 .58158 .79483 .57618 Mtetra
.79483 .57618 .79925 .58158 .80958 .57863 .80518 .57321 Mtetra
.80518 .57321 .80958 .57863 .81995 .57567 .81557 .57023 Mtetra
.81557 .57023 .81995 .57567 .83035 .5727 .826 .56724 Mtetra
.826 .56724 .83035 .5727 .84079 .56972 .83646 .56424 Mtetra
.83646 .56424 .84079 .56972 .85126 .56673 .84697 .56123 Mtetra
.84697 .56123 .85126 .56673 .86178 .56373 .85751 .55821 Mtetra
.85751 .55821 .86178 .56373 .87233 .56071 .86809 .55517 Mtetra
.86809 .55517 .87233 .56071 .88292 .55769 .87871 .55213 Mtetra
.87871 .55213 .88292 .55769 .89355 .55466 .88936 .54908 Mtetra
.88936 .54908 .89355 .55466 .90421 .55161 .90006 .54601 Mtetra
.90006 .54601 .90421 .55161 .91492 .54856 .91079 .54294 Mtetra
.91079 .54294 .91492 .54856 .92566 .54549 .92156 .53985 Mtetra
.92156 .53985 .92566 .54549 .93645 .54241 .93238 .53675 Mtetra
.93238 .53675 .93645 .54241 .94727 .53933 .94323 .53364 Mtetra
.94323 .53364 .94727 .53933 .95813 .53623 .95412 .53052 Mtetra
.95412 .53052 .95813 .53623 .96903 .53312 .96505 .52739 Mtetra
.96505 .52739 .96903 .53312 .97998 .53 .97602 .52425 Mtetra
.652 .748 .92 r
.38561 .68773 .391 .6925 .39996 .69 .39459 .68526 Mtetra
.655 .75 .92 r
.39459 .68526 .39996 .69 .40895 .68744 .40359 .68271 Mtetra
.657 .752 .92 r
.40359 .68271 .40895 .68744 .41797 .68484 .41263 .68011 Mtetra
.658 .753 .92 r
.41263 .68011 .41797 .68484 .42702 .6822 .4217 .67746 Mtetra
.659 .754 .92 r
.4217 .67746 .42702 .6822 .4361 .67954 .4308 .67479 Mtetra
.4308 .67479 .4361 .67954 .44522 .67688 .43994 .67211 Mtetra
.43994 .67211 .44522 .67688 .45436 .67421 .4491 .66942 Mtetra
.4491 .66942 .45436 .67421 .46353 .67153 .45829 .66673 Mtetra
.658 .753 .92 r
.45829 .66673 .46353 .67153 .47273 .66886 .46751 .66403 Mtetra
.46751 .66403 .47273 .66886 .48197 .66618 .47677 .66133 Mtetra
.47677 .66133 .48197 .66618 .49123 .66349 .48605 .65863 Mtetra
.48605 .65863 .49123 .66349 .50053 .6608 .49537 .65592 Mtetra
.49537 .65592 .50053 .6608 .50986 .6581 .50472 .65321 Mtetra
.50472 .65321 .50986 .6581 .51922 .6554 .5141 .65048 Mtetra
.5141 .65048 .51922 .6554 .52861 .65269 .52351 .64776 Mtetra
.657 .753 .92 r
.52351 .64776 .52861 .65269 .53803 .64997 .53296 .64502 Mtetra
.53296 .64502 .53803 .64997 .54749 .64724 .54243 .64228 Mtetra
.657 .752 .92 r
.54243 .64228 .54749 .64724 .55697 .64451 .55194 .63952 Mtetra
.55194 .63952 .55697 .64451 .56649 .64177 .56148 .63676 Mtetra
.56148 .63676 .56649 .64177 .57605 .63902 .57106 .63399 Mtetra
.57106 .63399 .57605 .63902 .58563 .63626 .58067 .63122 Mtetra
.58067 .63122 .58563 .63626 .59525 .63349 .59031 .62843 Mtetra
.59031 .62843 .59525 .63349 .6049 .63071 .59998 .62564 Mtetra
.59998 .62564 .6049 .63071 .61459 .62793 .60969 .62283 Mtetra
.60969 .62283 .61459 .62793 .62431 .62513 .61943 .62002 Mtetra
.61943 .62002 .62431 .62513 .63406 .62233 .6292 .6172 Mtetra
.6292 .6172 .63406 .62233 .64384 .61952 .63901 .61437 Mtetra
.63901 .61437 .64384 .61952 .65366 .61669 .64886 .61153 Mtetra
.64886 .61153 .65366 .61669 .66352 .61386 .65873 .60868 Mtetra
.65873 .60868 .66352 .61386 .67341 .61102 .66865 .60582 Mtetra
.66865 .60582 .67341 .61102 .68333 .60817 .67859 .60295 Mtetra
.67859 .60295 .68333 .60817 .69329 .60531 .68858 .60007 Mtetra
.68858 .60007 .69329 .60531 .70328 .60244 .69859 .59718 Mtetra
.69859 .59718 .70328 .60244 .71331 .59957 .70865 .59428 Mtetra
.70865 .59428 .71331 .59957 .72337 .59668 .71874 .59138 Mtetra
.71874 .59138 .72337 .59668 .73347 .59378 .72886 .58846 Mtetra
.72886 .58846 .73347 .59378 .74361 .59087 .73902 .58553 Mtetra
.73902 .58553 .74361 .59087 .75378 .58795 .74922 .58259 Mtetra
.74922 .58259 .75378 .58795 .76399 .58502 .75945 .57965 Mtetra
.75945 .57965 .76399 .58502 .77423 .58208 .76972 .57669 Mtetra
.76972 .57669 .77423 .58208 .78451 .57914 .78003 .57372 Mtetra
.78003 .57372 .78451 .57914 .79483 .57618 .79037 .57074 Mtetra
.79037 .57074 .79483 .57618 .80518 .57321 .80075 .56775 Mtetra
.80075 .56775 .80518 .57321 .81557 .57023 .81117 .56475 Mtetra
.81117 .56475 .81557 .57023 .826 .56724 .82162 .56174 Mtetra
.82162 .56174 .826 .56724 .83646 .56424 .83211 .55872 Mtetra
.83211 .55872 .83646 .56424 .84697 .56123 .84264 .55569 Mtetra
.84264 .55569 .84697 .56123 .85751 .55821 .85321 .55265 Mtetra
.85321 .55265 .85751 .55821 .86809 .55517 .86382 .5496 Mtetra
.86382 .5496 .86809 .55517 .87871 .55213 .87446 .54653 Mtetra
.87446 .54653 .87871 .55213 .88936 .54908 .88515 .54346 Mtetra
.88515 .54346 .88936 .54908 .90006 .54601 .89587 .54037 Mtetra
.89587 .54037 .90006 .54601 .91079 .54294 .90664 .53728 Mtetra
.90664 .53728 .91079 .54294 .92156 .53985 .91744 .53417 Mtetra
.91744 .53417 .92156 .53985 .93238 .53675 .92828 .53105 Mtetra
.92828 .53105 .93238 .53675 .94323 .53364 .93916 .52792 Mtetra
.93916 .52792 .94323 .53364 .95412 .53052 .95008 .52478 Mtetra
.95008 .52478 .95412 .53052 .96505 .52739 .96104 .52163 Mtetra
.96104 .52163 .96505 .52739 .97602 .52425 .97205 .51846 Mtetra
.649 .746 .92 r
.38019 .6829 .38561 .68773 .39459 .68526 .38918 .68047 Mtetra
.654 .749 .92 r
.38918 .68047 .39459 .68526 .40359 .68271 .3982 .67794 Mtetra
.656 .751 .92 r
.3982 .67794 .40359 .68271 .41263 .68011 .40726 .67534 Mtetra
.658 .753 .92 r
.40726 .67534 .41263 .68011 .4217 .67746 .41635 .67269 Mtetra
.659 .753 .92 r
.41635 .67269 .4217 .67746 .4308 .67479 .42547 .67001 Mtetra
.659 .754 .92 r
.42547 .67001 .4308 .67479 .43994 .67211 .43462 .66731 Mtetra
.43462 .66731 .43994 .67211 .4491 .66942 .4438 .66461 Mtetra
.4438 .66461 .4491 .66942 .45829 .66673 .45302 .66189 Mtetra
.659 .753 .92 r
.45302 .66189 .45829 .66673 .46751 .66403 .46226 .65918 Mtetra
.658 .753 .92 r
.46226 .65918 .46751 .66403 .47677 .66133 .47154 .65646 Mtetra
.47154 .65646 .47677 .66133 .48605 .65863 .48084 .65374 Mtetra
.48084 .65374 .48605 .65863 .49537 .65592 .49018 .65101 Mtetra
.49018 .65101 .49537 .65592 .50472 .65321 .49955 .64828 Mtetra
.49955 .64828 .50472 .65321 .5141 .65048 .50895 .64554 Mtetra
.50895 .64554 .5141 .65048 .52351 .64776 .51838 .64279 Mtetra
.657 .753 .92 r
.51838 .64279 .52351 .64776 .53296 .64502 .52785 .64004 Mtetra
.52785 .64004 .53296 .64502 .54243 .64228 .53735 .63727 Mtetra
.53735 .63727 .54243 .64228 .55194 .63952 .54688 .6345 Mtetra
.657 .752 .92 r
.54688 .6345 .55194 .63952 .56148 .63676 .55644 .63173 Mtetra
.55644 .63173 .56148 .63676 .57106 .63399 .56604 .62894 Mtetra
.56604 .62894 .57106 .63399 .58067 .63122 .57567 .62614 Mtetra
.57567 .62614 .58067 .63122 .59031 .62843 .58533 .62334 Mtetra
.58533 .62334 .59031 .62843 .59998 .62564 .59503 .62053 Mtetra
.59503 .62053 .59998 .62564 .60969 .62283 .60476 .6177 Mtetra
.60476 .6177 .60969 .62283 .61943 .62002 .61452 .61487 Mtetra
.61452 .61487 .61943 .62002 .6292 .6172 .62432 .61203 Mtetra
.62432 .61203 .6292 .6172 .63901 .61437 .63415 .60918 Mtetra
.63415 .60918 .63901 .61437 .64886 .61153 .64402 .60632 Mtetra
.64402 .60632 .64886 .61153 .65873 .60868 .65392 .60345 Mtetra
.65392 .60345 .65873 .60868 .66865 .60582 .66386 .60058 Mtetra
.66386 .60058 .66865 .60582 .67859 .60295 .67383 .59769 Mtetra
.67383 .59769 .67859 .60295 .68858 .60007 .68384 .59479 Mtetra
.68384 .59479 .68858 .60007 .69859 .59718 .69388 .59189 Mtetra
.69388 .59189 .69859 .59718 .70865 .59428 .70396 .58897 Mtetra
.70396 .58897 .70865 .59428 .71874 .59138 .71407 .58604 Mtetra
.71407 .58604 .71874 .59138 .72886 .58846 .72422 .5831 Mtetra
.72422 .5831 .72886 .58846 .73902 .58553 .7344 .58016 Mtetra
.7344 .58016 .73902 .58553 .74922 .58259 .74463 .5772 Mtetra
.74463 .5772 .74922 .58259 .75945 .57965 .75488 .57423 Mtetra
.75488 .57423 .75945 .57965 .76972 .57669 .76518 .57126 Mtetra
.76518 .57126 .76972 .57669 .78003 .57372 .77551 .56827 Mtetra
.77551 .56827 .78003 .57372 .79037 .57074 .78588 .56527 Mtetra
.78588 .56527 .79037 .57074 .80075 .56775 .79629 .56226 Mtetra
.79629 .56226 .80075 .56775 .81117 .56475 .80673 .55924 Mtetra
.80673 .55924 .81117 .56475 .82162 .56174 .81721 .55621 Mtetra
.81721 .55621 .82162 .56174 .83211 .55872 .82773 .55317 Mtetra
.82773 .55317 .83211 .55872 .84264 .55569 .83829 .55012 Mtetra
.83829 .55012 .84264 .55569 .85321 .55265 .84889 .54706 Mtetra
.84889 .54706 .85321 .55265 .86382 .5496 .85952 .54398 Mtetra
.85952 .54398 .86382 .5496 .87446 .54653 .8702 .5409 Mtetra
.8702 .5409 .87446 .54653 .88515 .54346 .88091 .5378 Mtetra
.88091 .5378 .88515 .54346 .89587 .54037 .89166 .5347 Mtetra
.89166 .5347 .89587 .54037 .90664 .53728 .90245 .53158 Mtetra
.90245 .53158 .90664 .53728 .91744 .53417 .91328 .52845 Mtetra
.91328 .52845 .91744 .53417 .92828 .53105 .92415 .52531 Mtetra
.92415 .52531 .92828 .53105 .93916 .52792 .93507 .52216 Mtetra
.93507 .52216 .93916 .52792 .95008 .52478 .94602 .519 Mtetra
.94602 .519 .95008 .52478 .96104 .52163 .95701 .51582 Mtetra
.95701 .51582 .96104 .52163 .97205 .51846 .96804 .51264 Mtetra
.646 .743 .92 r
.37473 .67799 .38019 .6829 .38918 .68047 .38374 .67563 Mtetra
.652 .748 .92 r
.38374 .67563 .38918 .68047 .3982 .67794 .39278 .67312 Mtetra
.655 .75 .92 r
.39278 .67312 .3982 .67794 .40726 .67534 .40186 .67053 Mtetra
.657 .752 .92 r
.40186 .67053 .40726 .67534 .41635 .67269 .41096 .66789 Mtetra
.658 .753 .92 r
.41096 .66789 .41635 .67269 .42547 .67001 .4201 .6652 Mtetra
.659 .754 .92 r
.4201 .6652 .42547 .67001 .43462 .66731 .42927 .66249 Mtetra
.42927 .66249 .43462 .66731 .4438 .66461 .43848 .65976 Mtetra
.43848 .65976 .4438 .66461 .45302 .66189 .44771 .65703 Mtetra
.44771 .65703 .45302 .66189 .46226 .65918 .45697 .6543 Mtetra
.658 .753 .92 r
.45697 .6543 .46226 .65918 .47154 .65646 .46627 .65156 Mtetra
.46627 .65156 .47154 .65646 .48084 .65374 .4756 .64882 Mtetra
.4756 .64882 .48084 .65374 .49018 .65101 .48495 .64607 Mtetra
.48495 .64607 .49018 .65101 .49955 .64828 .49434 .64332 Mtetra
.49434 .64332 .49955 .64828 .50895 .64554 .50377 .64056 Mtetra
.50377 .64056 .50895 .64554 .51838 .64279 .51322 .63779 Mtetra
.51322 .63779 .51838 .64279 .52785 .64004 .52271 .63502 Mtetra
.657 .753 .92 r
.52271 .63502 .52785 .64004 .53735 .63727 .53223 .63224 Mtetra
.53223 .63224 .53735 .63727 .54688 .6345 .54178 .62945 Mtetra
.657 .752 .92 r
.54178 .62945 .54688 .6345 .55644 .63173 .55137 .62666 Mtetra
.55137 .62666 .55644 .63173 .56604 .62894 .56098 .62385 Mtetra
.56098 .62385 .56604 .62894 .57567 .62614 .57064 .62104 Mtetra
.57064 .62104 .57567 .62614 .58533 .62334 .58032 .61821 Mtetra
.58032 .61821 .58533 .62334 .59503 .62053 .59004 .61538 Mtetra
.59004 .61538 .59503 .62053 .60476 .6177 .59979 .61254 Mtetra
.59979 .61254 .60476 .6177 .61452 .61487 .60958 .60969 Mtetra
.60958 .60969 .61452 .61487 .62432 .61203 .6194 .60683 Mtetra
.6194 .60683 .62432 .61203 .63415 .60918 .62926 .60396 Mtetra
.62926 .60396 .63415 .60918 .64402 .60632 .63915 .60109 Mtetra
.63915 .60109 .64402 .60632 .65392 .60345 .64908 .5982 Mtetra
.64908 .5982 .65392 .60345 .66386 .60058 .65904 .5953 Mtetra
.65904 .5953 .66386 .60058 .67383 .59769 .66903 .5924 Mtetra
.66903 .5924 .67383 .59769 .68384 .59479 .67906 .58948 Mtetra
.67906 .58948 .68384 .59479 .69388 .59189 .68913 .58655 Mtetra
.68913 .58655 .69388 .59189 .70396 .58897 .69923 .58362 Mtetra
.69923 .58362 .70396 .58897 .71407 .58604 .70937 .58067 Mtetra
.70937 .58067 .71407 .58604 .72422 .5831 .71954 .57771 Mtetra
.71954 .57771 .72422 .5831 .7344 .58016 .72976 .57475 Mtetra
.72976 .57475 .7344 .58016 .74463 .5772 .74 .57177 Mtetra
.74 .57177 .74463 .5772 .75488 .57423 .75029 .56878 Mtetra
.75029 .56878 .75488 .57423 .76518 .57126 .76061 .56579 Mtetra
.76061 .56579 .76518 .57126 .77551 .56827 .77097 .56278 Mtetra
.77097 .56278 .77551 .56827 .78588 .56527 .78136 .55976 Mtetra
.78136 .55976 .78588 .56527 .79629 .56226 .7918 .55673 Mtetra
.7918 .55673 .79629 .56226 .80673 .55924 .80227 .55369 Mtetra
.80227 .55369 .80673 .55924 .81721 .55621 .81278 .55064 Mtetra
.81278 .55064 .81721 .55621 .82773 .55317 .82332 .54758 Mtetra
.82332 .54758 .82773 .55317 .83829 .55012 .83391 .54451 Mtetra
.83391 .54451 .83829 .55012 .84889 .54706 .84453 .54143 Mtetra
.84453 .54143 .84889 .54706 .85952 .54398 .8552 .53833 Mtetra
.8552 .53833 .85952 .54398 .8702 .5409 .8659 .53523 Mtetra
.8659 .53523 .8702 .5409 .88091 .5378 .87664 .53211 Mtetra
.87664 .53211 .88091 .5378 .89166 .5347 .88742 .52898 Mtetra
.88742 .52898 .89166 .5347 .90245 .53158 .89824 .52584 Mtetra
.89824 .52584 .90245 .53158 .91328 .52845 .9091 .52269 Mtetra
.9091 .52269 .91328 .52845 .92415 .52531 .92 .51953 Mtetra
.92 .51953 .92415 .52531 .93507 .52216 .93094 .51636 Mtetra
.93094 .51636 .93507 .52216 .94602 .519 .94192 .51317 Mtetra
.94192 .51317 .94602 .519 .95701 .51582 .95295 .50998 Mtetra
.95295 .50998 .95701 .51582 .96804 .51264 .96401 .50677 Mtetra
.64 .738 .92 r
.36925 .67297 .37473 .67799 .38374 .67563 .37826 .67073 Mtetra
.649 .746 .92 r
.37826 .67073 .38374 .67563 .39278 .67312 .38732 .66826 Mtetra
.654 .749 .92 r
.38732 .66826 .39278 .67312 .40186 .67053 .39642 .66568 Mtetra
.656 .751 .92 r
.39642 .66568 .40186 .67053 .41096 .66789 .40554 .66304 Mtetra
.658 .753 .92 r
.40554 .66304 .41096 .66789 .4201 .6652 .4147 .66035 Mtetra
.659 .753 .92 r
.4147 .66035 .4201 .6652 .42927 .66249 .42389 .65763 Mtetra
.659 .754 .92 r
.42389 .65763 .42927 .66249 .43848 .65976 .43312 .65489 Mtetra
.43312 .65489 .43848 .65976 .44771 .65703 .44237 .65214 Mtetra
.44237 .65214 .44771 .65703 .45697 .6543 .45165 .64938 Mtetra
.659 .753 .92 r
.45165 .64938 .45697 .6543 .46627 .65156 .46097 .64663 Mtetra
.658 .753 .92 r
.46097 .64663 .46627 .65156 .4756 .64882 .47032 .64386 Mtetra
.47032 .64386 .4756 .64882 .48495 .64607 .4797 .6411 Mtetra
.4797 .6411 .48495 .64607 .49434 .64332 .48911 .63833 Mtetra
.48911 .63833 .49434 .64332 .50377 .64056 .49855 .63555 Mtetra
.49855 .63555 .50377 .64056 .51322 .63779 .50803 .63277 Mtetra
.50803 .63277 .51322 .63779 .52271 .63502 .51754 .62997 Mtetra
.657 .753 .92 r
.51754 .62997 .52271 .63502 .53223 .63224 .52708 .62718 Mtetra
.52708 .62718 .53223 .63224 .54178 .62945 .53665 .62437 Mtetra
.53665 .62437 .54178 .62945 .55137 .62666 .54626 .62155 Mtetra
.657 .752 .92 r
.54626 .62155 .55137 .62666 .56098 .62385 .5559 .61873 Mtetra
.5559 .61873 .56098 .62385 .57064 .62104 .56557 .6159 Mtetra
.56557 .6159 .57064 .62104 .58032 .61821 .57528 .61306 Mtetra
.57528 .61306 .58032 .61821 .59004 .61538 .58502 .61021 Mtetra
.58502 .61021 .59004 .61538 .59979 .61254 .5948 .60735 Mtetra
.5948 .60735 .59979 .61254 .60958 .60969 .60461 .60448 Mtetra
.60461 .60448 .60958 .60969 .6194 .60683 .61445 .6016 Mtetra
.61445 .6016 .6194 .60683 .62926 .60396 .62433 .59871 Mtetra
.62433 .59871 .62926 .60396 .63915 .60109 .63425 .59582 Mtetra
.63425 .59582 .63915 .60109 .64908 .5982 .6442 .59291 Mtetra
.6442 .59291 .64908 .5982 .65904 .5953 .65418 .58999 Mtetra
.65418 .58999 .65904 .5953 .66903 .5924 .6642 .58707 Mtetra
.6642 .58707 .66903 .5924 .67906 .58948 .67426 .58413 Mtetra
.67426 .58413 .67906 .58948 .68913 .58655 .68435 .58119 Mtetra
.68435 .58119 .68913 .58655 .69923 .58362 .69448 .57823 Mtetra
.69448 .57823 .69923 .58362 .70937 .58067 .70464 .57527 Mtetra
.70464 .57527 .70937 .58067 .71954 .57771 .71484 .57229 Mtetra
.71484 .57229 .71954 .57771 .72976 .57475 .72508 .5693 Mtetra
.72508 .5693 .72976 .57475 .74 .57177 .73535 .56631 Mtetra
.73535 .56631 .74 .57177 .75029 .56878 .74566 .5633 Mtetra
.74566 .5633 .75029 .56878 .76061 .56579 .75601 .56028 Mtetra
.75601 .56028 .76061 .56579 .77097 .56278 .76639 .55725 Mtetra
.76639 .55725 .77097 .56278 .78136 .55976 .77681 .55422 Mtetra
.77681 .55422 .78136 .55976 .7918 .55673 .78727 .55117 Mtetra
.78727 .55117 .7918 .55673 .80227 .55369 .79777 .54811 Mtetra
.79777 .54811 .80227 .55369 .81278 .55064 .80831 .54503 Mtetra
.80831 .54503 .81278 .55064 .82332 .54758 .81888 .54195 Mtetra
.81888 .54195 .82332 .54758 .83391 .54451 .8295 .53886 Mtetra
.8295 .53886 .83391 .54451 .84453 .54143 .84015 .53576 Mtetra
.84015 .53576 .84453 .54143 .8552 .53833 .85084 .53264 Mtetra
.85084 .53264 .8552 .53833 .8659 .53523 .86157 .52951 Mtetra
.86157 .52951 .8659 .53523 .87664 .53211 .87234 .52638 Mtetra
.87234 .52638 .87664 .53211 .88742 .52898 .88315 .52323 Mtetra
.88315 .52323 .88742 .52898 .89824 .52584 .894 .52007 Mtetra
.894 .52007 .89824 .52584 .9091 .52269 .90489 .5169 Mtetra
.90489 .5169 .9091 .52269 .92 .51953 .91582 .51371 Mtetra
.91582 .51371 .92 .51953 .93094 .51636 .92679 .51052 Mtetra
.92679 .51052 .93094 .51636 .94192 .51317 .9378 .50731 Mtetra
.9378 .50731 .94192 .51317 .95295 .50998 .94886 .50409 Mtetra
.94886 .50409 .95295 .50998 .96401 .50677 .95995 .50086 Mtetra
.628 .728 .919 r
.36374 .66773 .36925 .67297 .37826 .67073 .37276 .66574 Mtetra
.646 .743 .92 r
.37276 .66574 .37826 .67073 .38732 .66826 .38183 .66334 Mtetra
.652 .748 .92 r
.38183 .66334 .38732 .66826 .39642 .66568 .39094 .66079 Mtetra
.655 .75 .92 r
.39094 .66079 .39642 .66568 .40554 .66304 .40009 .65816 Mtetra
.657 .752 .92 r
.40009 .65816 .40554 .66304 .4147 .66035 .40927 .65547 Mtetra
.658 .753 .92 r
.40927 .65547 .4147 .66035 .42389 .65763 .41848 .65274 Mtetra
.659 .754 .92 r
.41848 .65274 .42389 .65763 .43312 .65489 .42772 .64999 Mtetra
.42772 .64999 .43312 .65489 .44237 .65214 .43699 .64722 Mtetra
.43699 .64722 .44237 .65214 .45165 .64938 .4463 .64444 Mtetra
.4463 .64444 .45165 .64938 .46097 .64663 .45564 .64166 Mtetra
.658 .753 .92 r
.45564 .64166 .46097 .64663 .47032 .64386 .465 .63888 Mtetra
.465 .63888 .47032 .64386 .4797 .6411 .4744 .6361 Mtetra
.4744 .6361 .4797 .6411 .48911 .63833 .48384 .63331 Mtetra
.48384 .63331 .48911 .63833 .49855 .63555 .4933 .63051 Mtetra
.4933 .63051 .49855 .63555 .50803 .63277 .5028 .62771 Mtetra
.5028 .62771 .50803 .63277 .51754 .62997 .51233 .6249 Mtetra
.51233 .6249 .51754 .62997 .52708 .62718 .52189 .62208 Mtetra
.657 .753 .92 r
.52189 .62208 .52708 .62718 .53665 .62437 .53149 .61925 Mtetra
.53149 .61925 .53665 .62437 .54626 .62155 .54112 .61642 Mtetra
.657 .752 .92 r
.54112 .61642 .54626 .62155 .5559 .61873 .55078 .61358 Mtetra
.55078 .61358 .5559 .61873 .56557 .6159 .56048 .61073 Mtetra
.56048 .61073 .56557 .6159 .57528 .61306 .57021 .60787 Mtetra
.57021 .60787 .57528 .61306 .58502 .61021 .57997 .605 Mtetra
.57997 .605 .58502 .61021 .5948 .60735 .58977 .60212 Mtetra
.58977 .60212 .5948 .60735 .60461 .60448 .59961 .59923 Mtetra
.59961 .59923 .60461 .60448 .61445 .6016 .60947 .59633 Mtetra
.60947 .59633 .61445 .6016 .62433 .59871 .61938 .59343 Mtetra
.61938 .59343 .62433 .59871 .63425 .59582 .62931 .59051 Mtetra
.62931 .59051 .63425 .59582 .6442 .59291 .63929 .58759 Mtetra
.63929 .58759 .6442 .59291 .65418 .58999 .6493 .58465 Mtetra
.6493 .58465 .65418 .58999 .6642 .58707 .65934 .58171 Mtetra
.65934 .58171 .6642 .58707 .67426 .58413 .66942 .57875 Mtetra
.66942 .57875 .67426 .58413 .68435 .58119 .67954 .57579 Mtetra
.67954 .57579 .68435 .58119 .69448 .57823 .68969 .57281 Mtetra
.68969 .57281 .69448 .57823 .70464 .57527 .69988 .56982 Mtetra
.69988 .56982 .70464 .57527 .71484 .57229 .7101 .56683 Mtetra
.7101 .56683 .71484 .57229 .72508 .5693 .72037 .56382 Mtetra
.72037 .56382 .72508 .5693 .73535 .56631 .73066 .56081 Mtetra
.73066 .56081 .73535 .56631 .74566 .5633 .741 .55778 Mtetra
.741 .55778 .74566 .5633 .75601 .56028 .75137 .55474 Mtetra
.75137 .55474 .75601 .56028 .76639 .55725 .76179 .55169 Mtetra
.76179 .55169 .76639 .55725 .77681 .55422 .77223 .54863 Mtetra
.77223 .54863 .77681 .55422 .78727 .55117 .78272 .54556 Mtetra
.78272 .54556 .78727 .55117 .79777 .54811 .79325 .54248 Mtetra
.79325 .54248 .79777 .54811 .80831 .54503 .80381 .53939 Mtetra
.80381 .53939 .80831 .54503 .81888 .54195 .81441 .53629 Mtetra
.81441 .53629 .81888 .54195 .8295 .53886 .82505 .53317 Mtetra
.82505 .53317 .8295 .53886 .84015 .53576 .83573 .53005 Mtetra
.83573 .53005 .84015 .53576 .85084 .53264 .84645 .52691 Mtetra
.84645 .52691 .85084 .53264 .86157 .52951 .85721 .52376 Mtetra
.85721 .52376 .86157 .52951 .87234 .52638 .86801 .52061 Mtetra
.86801 .52061 .87234 .52638 .88315 .52323 .87885 .51743 Mtetra
.87885 .51743 .88315 .52323 .894 .52007 .88973 .51425 Mtetra
.88973 .51425 .894 .52007 .90489 .5169 .90065 .51106 Mtetra
.90065 .51106 .90489 .5169 .91582 .51371 .91161 .50785 Mtetra
.91161 .50785 .91582 .51371 .92679 .51052 .92261 .50464 Mtetra
.92261 .50464 .92679 .51052 .9378 .50731 .93365 .50141 Mtetra
.93365 .50141 .9378 .50731 .94886 .50409 .94474 .49817 Mtetra
.94474 .49817 .94886 .50409 .95995 .50086 .95586 .49491 Mtetra
.596 .697 .913 r
.35822 .6619 .36374 .66773 .37276 .66574 .36723 .66064 Mtetra
.64 .738 .92 r
.36723 .66064 .37276 .66574 .38183 .66334 .37631 .65836 Mtetra
.649 .746 .92 r
.37631 .65836 .38183 .66334 .39094 .66079 .38544 .65585 Mtetra
.654 .749 .92 r
.38544 .65585 .39094 .66079 .40009 .65816 .3946 .65323 Mtetra
.656 .751 .92 r
.3946 .65323 .40009 .65816 .40927 .65547 .4038 .65055 Mtetra
.658 .753 .92 r
.4038 .65055 .40927 .65547 .41848 .65274 .41303 .64782 Mtetra
.659 .753 .92 r
.41303 .64782 .41848 .65274 .42772 .64999 .42229 .64505 Mtetra
.659 .754 .92 r
.42229 .64505 .42772 .64999 .43699 .64722 .43159 .64227 Mtetra
.43159 .64227 .43699 .64722 .4463 .64444 .44091 .63947 Mtetra
.44091 .63947 .4463 .64444 .45564 .64166 .45027 .63667 Mtetra
.659 .753 .92 r
.45027 .63667 .45564 .64166 .465 .63888 .45966 .63387 Mtetra
.658 .753 .92 r
.45966 .63387 .465 .63888 .4744 .6361 .46908 .63106 Mtetra
.46908 .63106 .4744 .6361 .48384 .63331 .47853 .62825 Mtetra
.47853 .62825 .48384 .63331 .4933 .63051 .48802 .62544 Mtetra
.48802 .62544 .4933 .63051 .5028 .62771 .49754 .62261 Mtetra
.49754 .62261 .5028 .62771 .51233 .6249 .50709 .61979 Mtetra
.50709 .61979 .51233 .6249 .52189 .62208 .51667 .61695 Mtetra
.657 .753 .92 r
.51667 .61695 .52189 .62208 .53149 .61925 .52629 .6141 Mtetra
.52629 .6141 .53149 .61925 .54112 .61642 .53594 .61125 Mtetra
.53594 .61125 .54112 .61642 .55078 .61358 .54563 .60839 Mtetra
.657 .752 .92 r
.54563 .60839 .55078 .61358 .56048 .61073 .55535 .60552 Mtetra
.55535 .60552 .56048 .61073 .57021 .60787 .5651 .60264 Mtetra
.5651 .60264 .57021 .60787 .57997 .605 .57489 .59975 Mtetra
.57489 .59975 .57997 .605 .58977 .60212 .58471 .59686 Mtetra
.58471 .59686 .58977 .60212 .59961 .59923 .59457 .59395 Mtetra
.59457 .59395 .59961 .59923 .60947 .59633 .60446 .59103 Mtetra
.60446 .59103 .60947 .59633 .61938 .59343 .61439 .58811 Mtetra
.61439 .58811 .61938 .59343 .62931 .59051 .62435 .58517 Mtetra
.62435 .58517 .62931 .59051 .63929 .58759 .63435 .58223 Mtetra
.63435 .58223 .63929 .58759 .6493 .58465 .64438 .57927 Mtetra
.64438 .57927 .6493 .58465 .65934 .58171 .65445 .57631 Mtetra
.65445 .57631 .65934 .58171 .66942 .57875 .66455 .57333 Mtetra
.66455 .57333 .66942 .57875 .67954 .57579 .67469 .57035 Mtetra
.67469 .57035 .67954 .57579 .68969 .57281 .68487 .56735 Mtetra
.68487 .56735 .68969 .57281 .69988 .56982 .69509 .56435 Mtetra
.69509 .56435 .69988 .56982 .7101 .56683 .70534 .56133 Mtetra
.70534 .56133 .7101 .56683 .72037 .56382 .71562 .5583 Mtetra
.71562 .5583 .72037 .56382 .73066 .56081 .72595 .55527 Mtetra
.72595 .55527 .73066 .56081 .741 .55778 .73631 .55222 Mtetra
.73631 .55222 .741 .55778 .75137 .55474 .74671 .54916 Mtetra
.74671 .54916 .75137 .55474 .76179 .55169 .75715 .54609 Mtetra
.75715 .54609 .76179 .55169 .77223 .54863 .76763 .54301 Mtetra
.76763 .54301 .77223 .54863 .78272 .54556 .77814 .53992 Mtetra
.77814 .53992 .78272 .54556 .79325 .54248 .78869 .53682 Mtetra
.78869 .53682 .79325 .54248 .80381 .53939 .79928 .53371 Mtetra
.79928 .53371 .80381 .53939 .81441 .53629 .80991 .53058 Mtetra
.80991 .53058 .81441 .53629 .82505 .53317 .82058 .52745 Mtetra
.82058 .52745 .82505 .53317 .83573 .53005 .83129 .5243 Mtetra
.83129 .5243 .83573 .53005 .84645 .52691 .84204 .52114 Mtetra
.84204 .52114 .84645 .52691 .85721 .52376 .85283 .51797 Mtetra
.85283 .51797 .85721 .52376 .86801 .52061 .86365 .51479 Mtetra
.86365 .51479 .86801 .52061 .87885 .51743 .87452 .5116 Mtetra
.87452 .5116 .87885 .51743 .88973 .51425 .88543 .5084 Mtetra
.88543 .5084 .88973 .51425 .90065 .51106 .89638 .50518 Mtetra
.89638 .50518 .90065 .51106 .91161 .50785 .90737 .50195 Mtetra
.90737 .50195 .91161 .50785 .92261 .50464 .9184 .49872 Mtetra
.9184 .49872 .92261 .50464 .93365 .50141 .92947 .49546 Mtetra
.92947 .49546 .93365 .50141 .94474 .49817 .94059 .4922 Mtetra
.94059 .4922 .94474 .49817 .95586 .49491 .95174 .48893 Mtetra
.401 .481 .827 r
.35289 .65171 .35822 .6619 .36723 .66064 .36166 .65532 Mtetra
.628 .728 .919 r
.36166 .65532 .36723 .66064 .37631 .65836 .37076 .65329 Mtetra
.646 .743 .92 r
.37076 .65329 .37631 .65836 .38544 .65585 .3799 .65085 Mtetra
.652 .748 .92 r
.3799 .65085 .38544 .65585 .3946 .65323 .38908 .64826 Mtetra
.655 .75 .92 r
.38908 .64826 .3946 .65323 .4038 .65055 .3983 .64558 Mtetra
.657 .752 .92 r
.3983 .64558 .4038 .65055 .41303 .64782 .40755 .64285 Mtetra
.658 .753 .92 r
.40755 .64285 .41303 .64782 .42229 .64505 .41683 .64008 Mtetra
.659 .754 .92 r
.41683 .64008 .42229 .64505 .43159 .64227 .42614 .63728 Mtetra
.42614 .63728 .43159 .64227 .44091 .63947 .43549 .63447 Mtetra
.43549 .63447 .44091 .63947 .45027 .63667 .44487 .63165 Mtetra
.44487 .63165 .45027 .63667 .45966 .63387 .45428 .62883 Mtetra
.658 .753 .92 r
.45428 .62883 .45966 .63387 .46908 .63106 .46372 .626 Mtetra
.46372 .626 .46908 .63106 .47853 .62825 .47319 .62317 Mtetra
.47319 .62317 .47853 .62825 .48802 .62544 .4827 .62033 Mtetra
.4827 .62033 .48802 .62544 .49754 .62261 .49224 .61749 Mtetra
.49224 .61749 .49754 .62261 .50709 .61979 .50181 .61464 Mtetra
.50181 .61464 .50709 .61979 .51667 .61695 .51142 .61179 Mtetra
.51142 .61179 .51667 .61695 .52629 .6141 .52106 .60892 Mtetra
.657 .753 .92 r
.52106 .60892 .52629 .6141 .53594 .61125 .53074 .60605 Mtetra
.53074 .60605 .53594 .61125 .54563 .60839 .54044 .60317 Mtetra
.657 .752 .92 r
.54044 .60317 .54563 .60839 .55535 .60552 .55019 .60028 Mtetra
.55019 .60028 .55535 .60552 .5651 .60264 .55996 .59738 Mtetra
.55996 .59738 .5651 .60264 .57489 .59975 .56977 .59448 Mtetra
.56977 .59448 .57489 .59975 .58471 .59686 .57962 .59156 Mtetra
.57962 .59156 .58471 .59686 .59457 .59395 .5895 .58863 Mtetra
.5895 .58863 .59457 .59395 .60446 .59103 .59941 .5857 Mtetra
.59941 .5857 .60446 .59103 .61439 .58811 .60936 .58275 Mtetra
.60936 .58275 .61439 .58811 .62435 .58517 .61935 .5798 Mtetra
.61935 .5798 .62435 .58517 .63435 .58223 .62937 .57683 Mtetra
.62937 .57683 .63435 .58223 .64438 .57927 .63943 .57386 Mtetra
.63943 .57386 .64438 .57927 .65445 .57631 .64952 .57087 Mtetra
.64952 .57087 .65445 .57631 .66455 .57333 .65965 .56788 Mtetra
.65965 .56788 .66455 .57333 .67469 .57035 .66982 .56487 Mtetra
.66982 .56487 .67469 .57035 .68487 .56735 .68002 .56186 Mtetra
.68002 .56186 .68487 .56735 .69509 .56435 .69026 .55883 Mtetra
.69026 .55883 .69509 .56435 .70534 .56133 .70054 .5558 Mtetra
.70054 .5558 .70534 .56133 .71562 .5583 .71085 .55275 Mtetra
.71085 .55275 .71562 .5583 .72595 .55527 .7212 .54969 Mtetra
.7212 .54969 .72595 .55527 .73631 .55222 .73159 .54662 Mtetra
.73159 .54662 .73631 .55222 .74671 .54916 .74202 .54354 Mtetra
.74202 .54354 .74671 .54916 .75715 .54609 .75248 .54045 Mtetra
.75248 .54045 .75715 .54609 .76763 .54301 .76298 .53735 Mtetra
.76298 .53735 .76763 .54301 .77814 .53992 .77353 .53424 Mtetra
.77353 .53424 .77814 .53992 .78869 .53682 .78411 .53112 Mtetra
.78411 .53112 .78869 .53682 .79928 .53371 .79472 .52799 Mtetra
.79472 .52799 .79928 .53371 .80991 .53058 .80538 .52484 Mtetra
.80538 .52484 .80991 .53058 .82058 .52745 .81608 .52168 Mtetra
.81608 .52168 .82058 .52745 .83129 .5243 .82682 .51852 Mtetra
.82682 .51852 .83129 .5243 .84204 .52114 .83759 .51534 Mtetra
.83759 .51534 .84204 .52114 .85283 .51797 .84841 .51214 Mtetra
.84841 .51214 .85283 .51797 .86365 .51479 .85927 .50894 Mtetra
.85927 .50894 .86365 .51479 .87452 .5116 .87016 .50573 Mtetra
.87016 .50573 .87452 .5116 .88543 .5084 .8811 .5025 Mtetra
.8811 .5025 .88543 .5084 .89638 .50518 .89208 .49926 Mtetra
.89208 .49926 .89638 .50518 .90737 .50195 .9031 .49601 Mtetra
.9031 .49601 .90737 .50195 .9184 .49872 .91416 .49275 Mtetra
.91416 .49275 .9184 .49872 .92947 .49546 .92527 .48948 Mtetra
.92527 .48948 .92947 .49546 .94059 .4922 .93641 .48619 Mtetra
.93641 .48619 .94059 .4922 .95174 .48893 .9476 .48289 Mtetra
0 0 0 r
.34657 .66043 .35289 .65171 .36166 .65532 .3561 .64941 Mtetra
.596 .697 .913 r
.3561 .64941 .36166 .65532 .37076 .65329 .36517 .64811 Mtetra
.64 .738 .92 r
.36517 .64811 .37076 .65329 .3799 .65085 .37433 .64579 Mtetra
.649 .746 .92 r
.37433 .64579 .3799 .65085 .38908 .64826 .38352 .64324 Mtetra
.654 .749 .92 r
.38352 .64324 .38908 .64826 .3983 .64558 .39276 .64058 Mtetra
.656 .751 .92 r
.39276 .64058 .3983 .64558 .40755 .64285 .40203 .63785 Mtetra
.658 .753 .92 r
.40203 .63785 .40755 .64285 .41683 .64008 .41133 .63507 Mtetra
.659 .753 .92 r
.41133 .63507 .41683 .64008 .42614 .63728 .42066 .63226 Mtetra
.659 .754 .92 r
.42066 .63226 .42614 .63728 .43549 .63447 .43003 .62944 Mtetra
.43003 .62944 .43549 .63447 .44487 .63165 .43943 .6266 Mtetra
.43943 .6266 .44487 .63165 .45428 .62883 .44886 .62375 Mtetra
.659 .753 .92 r
.44886 .62375 .45428 .62883 .46372 .626 .45832 .6209 Mtetra
.658 .753 .92 r
.45832 .6209 .46372 .626 .47319 .62317 .46782 .61805 Mtetra
.46782 .61805 .47319 .62317 .4827 .62033 .47735 .6152 Mtetra
.47735 .6152 .4827 .62033 .49224 .61749 .48691 .61233 Mtetra
.48691 .61233 .49224 .61749 .50181 .61464 .49651 .60947 Mtetra
.49651 .60947 .50181 .61464 .51142 .61179 .50613 .60659 Mtetra
.50613 .60659 .51142 .61179 .52106 .60892 .5158 .60371 Mtetra
.657 .753 .92 r
.5158 .60371 .52106 .60892 .53074 .60605 .52549 .60082 Mtetra
.52549 .60082 .53074 .60605 .54044 .60317 .53522 .59792 Mtetra
.53522 .59792 .54044 .60317 .55019 .60028 .54499 .59501 Mtetra
.657 .752 .92 r
.54499 .59501 .55019 .60028 .55996 .59738 .55479 .59209 Mtetra
.55479 .59209 .55996 .59738 .56977 .59448 .56462 .58916 Mtetra
.56462 .58916 .56977 .59448 .57962 .59156 .57449 .58623 Mtetra
.57449 .58623 .57962 .59156 .5895 .58863 .58439 .58328 Mtetra
.58439 .58328 .5895 .58863 .59941 .5857 .59433 .58033 Mtetra
.59433 .58033 .59941 .5857 .60936 .58275 .60431 .57736 Mtetra
.60431 .57736 .60936 .58275 .61935 .5798 .61432 .57439 Mtetra
.61432 .57439 .61935 .5798 .62937 .57683 .62436 .5714 Mtetra
.62436 .5714 .62937 .57683 .63943 .57386 .63445 .56841 Mtetra
.63445 .56841 .63943 .57386 .64952 .57087 .64456 .5654 Mtetra
.64456 .5654 .64952 .57087 .65965 .56788 .65472 .56239 Mtetra
.65472 .56239 .65965 .56788 .66982 .56487 .66491 .55936 Mtetra
.66491 .55936 .66982 .56487 .68002 .56186 .67514 .55633 Mtetra
.67514 .55633 .68002 .56186 .69026 .55883 .6854 .55328 Mtetra
.6854 .55328 .69026 .55883 .70054 .5558 .6957 .55022 Mtetra
.6957 .55022 .70054 .5558 .71085 .55275 .70604 .54716 Mtetra
.70604 .54716 .71085 .55275 .7212 .54969 .71642 .54408 Mtetra
.71642 .54408 .7212 .54969 .73159 .54662 .72684 .54099 Mtetra
.72684 .54099 .73159 .54662 .74202 .54354 .73729 .53789 Mtetra
.73729 .53789 .74202 .54354 .75248 .54045 .74778 .53478 Mtetra
.74778 .53478 .75248 .54045 .76298 .53735 .75831 .53166 Mtetra
.75831 .53166 .76298 .53735 .77353 .53424 .76888 .52852 Mtetra
.76888 .52852 .77353 .53424 .78411 .53112 .77949 .52538 Mtetra
.77949 .52538 .78411 .53112 .79472 .52799 .79013 .52222 Mtetra
.79013 .52222 .79472 .52799 .80538 .52484 .80082 .51906 Mtetra
.80082 .51906 .80538 .52484 .81608 .52168 .81155 .51588 Mtetra
.81155 .51588 .81608 .52168 .82682 .51852 .82231 .51269 Mtetra
.82231 .51269 .82682 .51852 .83759 .51534 .83312 .50949 Mtetra
.83312 .50949 .83759 .51534 .84841 .51214 .84396 .50628 Mtetra
.84396 .50628 .84841 .51214 .85927 .50894 .85485 .50305 Mtetra
.85485 .50305 .85927 .50894 .87016 .50573 .86578 .49981 Mtetra
.86578 .49981 .87016 .50573 .8811 .5025 .87674 .49657 Mtetra
.87674 .49657 .8811 .5025 .89208 .49926 .88775 .4933 Mtetra
.88775 .4933 .89208 .49926 .9031 .49601 .8988 .49003 Mtetra
.8988 .49003 .9031 .49601 .91416 .49275 .90989 .48675 Mtetra
.90989 .48675 .91416 .49275 .92527 .48948 .92103 .48345 Mtetra
.92103 .48345 .92527 .48948 .93641 .48619 .9322 .48014 Mtetra
.9322 .48014 .93641 .48619 .9476 .48289 .94342 .47682 Mtetra
.8 .685 .738 r
.34109 .65155 .34657 .66043 .3561 .64941 .35072 .63912 Mtetra
.4 .481 .827 r
.35072 .63912 .3561 .64941 .36517 .64811 .35956 .64271 Mtetra
.628 .728 .919 r
.35956 .64271 .36517 .64811 .37433 .64579 .36872 .64065 Mtetra
.646 .743 .92 r
.36872 .64065 .37433 .64579 .38352 .64324 .37793 .63816 Mtetra
.652 .748 .92 r
.37793 .63816 .38352 .64324 .39276 .64058 .38719 .63552 Mtetra
.655 .75 .92 r
.38719 .63552 .39276 .64058 .40203 .63785 .39647 .63281 Mtetra
.657 .752 .92 r
.39647 .63281 .40203 .63785 .41133 .63507 .40579 .63003 Mtetra
.658 .753 .92 r
.40579 .63003 .41133 .63507 .42066 .63226 .41515 .62721 Mtetra
.659 .754 .92 r
.41515 .62721 .42066 .63226 .43003 .62944 .42454 .62437 Mtetra
.42454 .62437 .43003 .62944 .43943 .6266 .43396 .62151 Mtetra
.43396 .62151 .43943 .6266 .44886 .62375 .44341 .61865 Mtetra
.44341 .61865 .44886 .62375 .45832 .6209 .45289 .61578 Mtetra
.658 .753 .92 r
.45289 .61578 .45832 .6209 .46782 .61805 .46241 .6129 Mtetra
.46241 .6129 .46782 .61805 .47735 .6152 .47196 .61003 Mtetra
.47196 .61003 .47735 .6152 .48691 .61233 .48155 .60715 Mtetra
.48155 .60715 .48691 .61233 .49651 .60947 .49116 .60426 Mtetra
.49116 .60426 .49651 .60947 .50613 .60659 .50081 .60136 Mtetra
.50081 .60136 .50613 .60659 .5158 .60371 .5105 .59846 Mtetra
.5105 .59846 .5158 .60371 .52549 .60082 .52022 .59555 Mtetra
.657 .753 .92 r
.52022 .59555 .52549 .60082 .53522 .59792 .52997 .59263 Mtetra
.52997 .59263 .53522 .59792 .54499 .59501 .53976 .5897 Mtetra
.657 .752 .92 r
.53976 .5897 .54499 .59501 .55479 .59209 .54958 .58676 Mtetra
.54958 .58676 .55479 .59209 .56462 .58916 .55944 .58382 Mtetra
.55944 .58382 .56462 .58916 .57449 .58623 .56933 .58086 Mtetra
.56933 .58086 .57449 .58623 .58439 .58328 .57926 .5779 Mtetra
.57926 .5779 .58439 .58328 .59433 .58033 .58922 .57492 Mtetra
.58922 .57492 .59433 .58033 .60431 .57736 .59922 .57194 Mtetra
.59922 .57194 .60431 .57736 .61432 .57439 .60925 .56894 Mtetra
.60925 .56894 .61432 .57439 .62436 .5714 .61932 .56594 Mtetra
.61932 .56594 .62436 .5714 .63445 .56841 .62943 .56292 Mtetra
.62943 .56292 .63445 .56841 .64456 .5654 .63957 .5599 Mtetra
.63957 .5599 .64456 .5654 .65472 .56239 .64975 .55686 Mtetra
.64975 .55686 .65472 .56239 .66491 .55936 .65997 .55382 Mtetra
.65997 .55382 .66491 .55936 .67514 .55633 .67022 .55076 Mtetra
.67022 .55076 .67514 .55633 .6854 .55328 .68051 .54769 Mtetra
.68051 .54769 .6854 .55328 .6957 .55022 .69084 .54462 Mtetra
.69084 .54462 .6957 .55022 .70604 .54716 .70121 .54153 Mtetra
.70121 .54153 .70604 .54716 .71642 .54408 .71161 .53843 Mtetra
.71161 .53843 .71642 .54408 .72684 .54099 .72205 .53532 Mtetra
.72205 .53532 .72684 .54099 .73729 .53789 .73253 .5322 Mtetra
.73253 .5322 .73729 .53789 .74778 .53478 .74305 .52906 Mtetra
.74305 .52906 .74778 .53478 .75831 .53166 .75361 .52592 Mtetra
.75361 .52592 .75831 .53166 .76888 .52852 .7642 .52277 Mtetra
.7642 .52277 .76888 .52852 .77949 .52538 .77484 .5196 Mtetra
.77484 .5196 .77949 .52538 .79013 .52222 .78551 .51642 Mtetra
.78551 .51642 .79013 .52222 .80082 .51906 .79623 .51324 Mtetra
.79623 .51324 .80082 .51906 .81155 .51588 .80698 .51004 Mtetra
.80698 .51004 .81155 .51588 .82231 .51269 .81778 .50682 Mtetra
.81778 .50682 .82231 .51269 .83312 .50949 .82861 .5036 Mtetra
.82861 .5036 .83312 .50949 .84396 .50628 .83948 .50036 Mtetra
.83948 .50036 .84396 .50628 .85485 .50305 .8504 .49712 Mtetra
.8504 .49712 .85485 .50305 .86578 .49981 .86136 .49386 Mtetra
.86136 .49386 .86578 .49981 .87674 .49657 .87235 .49059 Mtetra
.87235 .49059 .87674 .49657 .88775 .4933 .88339 .4873 Mtetra
.88339 .4873 .88775 .4933 .8988 .49003 .89447 .48401 Mtetra
.89447 .48401 .8988 .49003 .90989 .48675 .9056 .4807 Mtetra
.9056 .4807 .90989 .48675 .92103 .48345 .91676 .47738 Mtetra
.91676 .47738 .92103 .48345 .9322 .48014 .92797 .47405 Mtetra
.92797 .47405 .9322 .48014 .94342 .47682 .93922 .4707 Mtetra
.339 .589 .937 r
.33543 .64568 .34109 .65155 .35072 .63912 .34433 .64782 Mtetra
0 0 0 r
.34433 .64782 .35072 .63912 .35956 .64271 .35394 .63671 Mtetra
.596 .697 .913 r
.35394 .63671 .35956 .64271 .36872 .64065 .36308 .63538 Mtetra
.64 .738 .92 r
.36308 .63538 .36872 .64065 .37793 .63816 .37231 .63302 Mtetra
.649 .746 .92 r
.37231 .63302 .37793 .63816 .38719 .63552 .38158 .63042 Mtetra
.653 .749 .92 r
.38158 .63042 .38719 .63552 .39647 .63281 .39088 .62772 Mtetra
.656 .751 .92 r
.39088 .62772 .39647 .63281 .40579 .63003 .40023 .62494 Mtetra
.658 .753 .92 r
.40023 .62494 .40579 .63003 .41515 .62721 .4096 .62212 Mtetra
.659 .753 .92 r
.4096 .62212 .41515 .62721 .42454 .62437 .41901 .61927 Mtetra
.659 .754 .92 r
.41901 .61927 .42454 .62437 .43396 .62151 .42845 .61639 Mtetra
.42845 .61639 .43396 .62151 .44341 .61865 .43792 .61351 Mtetra
.43792 .61351 .44341 .61865 .45289 .61578 .44743 .61062 Mtetra
.659 .753 .92 r
.44743 .61062 .45289 .61578 .46241 .6129 .45697 .60772 Mtetra
.658 .753 .92 r
.45697 .60772 .46241 .6129 .47196 .61003 .46654 .60483 Mtetra
.46654 .60483 .47196 .61003 .48155 .60715 .47615 .60192 Mtetra
.47615 .60192 .48155 .60715 .49116 .60426 .48579 .59901 Mtetra
.48579 .59901 .49116 .60426 .50081 .60136 .49546 .5961 Mtetra
.49546 .5961 .50081 .60136 .5105 .59846 .50517 .59318 Mtetra
.50517 .59318 .5105 .59846 .52022 .59555 .51491 .59025 Mtetra
.657 .753 .92 r
.51491 .59025 .52022 .59555 .52997 .59263 .52468 .58731 Mtetra
.52468 .58731 .52997 .59263 .53976 .5897 .53449 .58436 Mtetra
.53449 .58436 .53976 .5897 .54958 .58676 .54434 .5814 Mtetra
.657 .752 .92 r
.54434 .5814 .54958 .58676 .55944 .58382 .55422 .57843 Mtetra
.55422 .57843 .55944 .58382 .56933 .58086 .56413 .57546 Mtetra
.56413 .57546 .56933 .58086 .57926 .5779 .57409 .57247 Mtetra
.57409 .57247 .57926 .5779 .58922 .57492 .58407 .56948 Mtetra
.58407 .56948 .58922 .57492 .59922 .57194 .59409 .56647 Mtetra
.59409 .56647 .59922 .57194 .60925 .56894 .60415 .56346 Mtetra
.60415 .56346 .60925 .56894 .61932 .56594 .61425 .56043 Mtetra
.61425 .56043 .61932 .56594 .62943 .56292 .62438 .5574 Mtetra
.62438 .5574 .62943 .56292 .63957 .5599 .63455 .55435 Mtetra
.63455 .55435 .63957 .5599 .64975 .55686 .64475 .5513 Mtetra
.64475 .5513 .64975 .55686 .65997 .55382 .65499 .54823 Mtetra
.65499 .54823 .65997 .55382 .67022 .55076 .66527 .54515 Mtetra
.66527 .54515 .67022 .55076 .68051 .54769 .67559 .54207 Mtetra
.67559 .54207 .68051 .54769 .69084 .54462 .68594 .53897 Mtetra
.68594 .53897 .69084 .54462 .70121 .54153 .69633 .53586 Mtetra
.69633 .53586 .70121 .54153 .71161 .53843 .70676 .53274 Mtetra
.70676 .53274 .71161 .53843 .72205 .53532 .71723 .52961 Mtetra
.71723 .52961 .72205 .53532 .73253 .5322 .72774 .52647 Mtetra
.72774 .52647 .73253 .5322 .74305 .52906 .73829 .52331 Mtetra
.73829 .52331 .74305 .52906 .75361 .52592 .74887 .52015 Mtetra
.74887 .52015 .75361 .52592 .7642 .52277 .75949 .51697 Mtetra
.75949 .51697 .7642 .52277 .77484 .5196 .77016 .51378 Mtetra
.77016 .51378 .77484 .5196 .78551 .51642 .78086 .51058 Mtetra
.78086 .51058 .78551 .51642 .79623 .51324 .7916 .50737 Mtetra
.7916 .50737 .79623 .51324 .80698 .51004 .80238 .50415 Mtetra
.80238 .50415 .80698 .51004 .81778 .50682 .81321 .50092 Mtetra
.81321 .50092 .81778 .50682 .82861 .5036 .82407 .49767 Mtetra
.82407 .49767 .82861 .5036 .83948 .50036 .83497 .49441 Mtetra
.83497 .49441 .83948 .50036 .8504 .49712 .84592 .49114 Mtetra
.84592 .49114 .8504 .49712 .86136 .49386 .85691 .48786 Mtetra
.85691 .48786 .86136 .49386 .87235 .49059 .86793 .48457 Mtetra
.86793 .48457 .87235 .49059 .88339 .4873 .879 .48126 Mtetra
.879 .48126 .88339 .4873 .89447 .48401 .89011 .47794 Mtetra
.89011 .47794 .89447 .48401 .9056 .4807 .90127 .47461 Mtetra
.90127 .47461 .9056 .4807 .91676 .47738 .91246 .47127 Mtetra
.91246 .47127 .91676 .47738 .92797 .47405 .9237 .46791 Mtetra
.9237 .46791 .92797 .47405 .93922 .4707 .93498 .46455 Mtetra
.594 .717 .93 r
.32971 .64024 .33543 .64568 .34433 .64782 .33881 .63884 Mtetra
.8 .685 .738 r
.33881 .63884 .34433 .64782 .35394 .63671 .34851 .62632 Mtetra
.399 .48 .827 r
.34851 .62632 .35394 .63671 .36308 .63538 .35742 .6299 Mtetra
.628 .728 .919 r
.35742 .6299 .36308 .63538 .37231 .63302 .36665 .62779 Mtetra
.646 .743 .92 r
.36665 .62779 .37231 .63302 .38158 .63042 .37594 .62526 Mtetra
.652 .748 .92 r
.37594 .62526 .38158 .63042 .39088 .62772 .38526 .62258 Mtetra
.655 .75 .92 r
.38526 .62258 .39088 .62772 .40023 .62494 .39462 .61982 Mtetra
.657 .752 .92 r
.39462 .61982 .40023 .62494 .4096 .62212 .40402 .617 Mtetra
.658 .753 .92 r
.40402 .617 .4096 .62212 .41901 .61927 .41344 .61413 Mtetra
.659 .754 .92 r
.41344 .61413 .41901 .61927 .42845 .61639 .42291 .61124 Mtetra
.42291 .61124 .42845 .61639 .43792 .61351 .4324 .60834 Mtetra
.4324 .60834 .43792 .61351 .44743 .61062 .44193 .60543 Mtetra
.44193 .60543 .44743 .61062 .45697 .60772 .45149 .60251 Mtetra
.658 .753 .92 r
.45149 .60251 .45697 .60772 .46654 .60483 .46108 .59959 Mtetra
.46108 .59959 .46654 .60483 .47615 .60192 .47071 .59667 Mtetra
.47071 .59667 .47615 .60192 .48579 .59901 .48037 .59374 Mtetra
.48037 .59374 .48579 .59901 .49546 .5961 .49007 .5908 Mtetra
.49007 .5908 .49546 .5961 .50517 .59318 .4998 .58786 Mtetra
.4998 .58786 .50517 .59318 .51491 .59025 .50956 .58491 Mtetra
.50956 .58491 .51491 .59025 .52468 .58731 .51936 .58195 Mtetra
.657 .753 .92 r
.51936 .58195 .52468 .58731 .53449 .58436 .52919 .57898 Mtetra
.52919 .57898 .53449 .58436 .54434 .5814 .53906 .576 Mtetra
.657 .752 .92 r
.53906 .576 .54434 .5814 .55422 .57843 .54897 .57302 Mtetra
.54897 .57302 .55422 .57843 .56413 .57546 .5589 .57002 Mtetra
.5589 .57002 .56413 .57546 .57409 .57247 .56888 .56702 Mtetra
.56888 .56702 .57409 .57247 .58407 .56948 .57889 .564 Mtetra
.57889 .564 .58407 .56948 .59409 .56647 .58894 .56098 Mtetra
.58894 .56098 .59409 .56647 .60415 .56346 .59902 .55794 Mtetra
.59902 .55794 .60415 .56346 .61425 .56043 .60914 .55489 Mtetra
.60914 .55489 .61425 .56043 .62438 .5574 .6193 .55184 Mtetra
.6193 .55184 .62438 .5574 .63455 .55435 .62949 .54877 Mtetra
.62949 .54877 .63455 .55435 .64475 .5513 .63972 .5457 Mtetra
.63972 .5457 .64475 .5513 .65499 .54823 .64999 .54261 Mtetra
.64999 .54261 .65499 .54823 .66527 .54515 .66029 .53951 Mtetra
.66029 .53951 .66527 .54515 .67559 .54207 .67063 .5364 Mtetra
.67063 .5364 .67559 .54207 .68594 .53897 .68101 .53328 Mtetra
.68101 .53328 .68594 .53897 .69633 .53586 .69143 .53015 Mtetra
.69143 .53015 .69633 .53586 .70676 .53274 .70189 .52701 Mtetra
.70189 .52701 .70676 .53274 .71723 .52961 .71238 .52386 Mtetra
.71238 .52386 .71723 .52961 .72774 .52647 .72292 .52069 Mtetra
.72292 .52069 .72774 .52647 .73829 .52331 .73349 .51752 Mtetra
.73349 .51752 .73829 .52331 .74887 .52015 .7441 .51433 Mtetra
.7441 .51433 .74887 .52015 .75949 .51697 .75475 .51113 Mtetra
.75475 .51113 .75949 .51697 .77016 .51378 .76544 .50792 Mtetra
.76544 .50792 .77016 .51378 .78086 .51058 .77617 .5047 Mtetra
.77617 .5047 .78086 .51058 .7916 .50737 .78695 .50147 Mtetra
.78695 .50147 .7916 .50737 .80238 .50415 .79776 .49823 Mtetra
.79776 .49823 .80238 .50415 .81321 .50092 .80861 .49497 Mtetra
.80861 .49497 .81321 .50092 .82407 .49767 .8195 .4917 Mtetra
.8195 .4917 .82407 .49767 .83497 .49441 .83043 .48842 Mtetra
.83043 .48842 .83497 .49441 .84592 .49114 .84141 .48513 Mtetra
.84141 .48513 .84592 .49114 .85691 .48786 .85242 .48182 Mtetra
.85242 .48182 .85691 .48786 .86793 .48457 .86348 .47851 Mtetra
.86348 .47851 .86793 .48457 .879 .48126 .87458 .47518 Mtetra
.87458 .47518 .879 .48126 .89011 .47794 .88572 .47184 Mtetra
.88572 .47184 .89011 .47794 .90127 .47461 .89691 .46848 Mtetra
.89691 .46848 .90127 .47461 .91246 .47127 .90814 .46511 Mtetra
.90814 .46511 .91246 .47127 .9237 .46791 .91941 .46173 Mtetra
.91941 .46173 .9237 .46791 .93498 .46455 .93072 .45834 Mtetra
.625 .733 .925 r
.32394 .63493 .32971 .64024 .33881 .63884 .33309 .63289 Mtetra
.341 .589 .937 r
.33309 .63289 .33881 .63884 .34851 .62632 .34206 .635 Mtetra
0 0 0 r
.34206 .635 .34851 .62632 .35742 .6299 .35175 .62381 Mtetra
.596 .697 .913 r
.35175 .62381 .35742 .6299 .36665 .62779 .36096 .62244 Mtetra
.64 .738 .92 r
.36096 .62244 .36665 .62779 .37594 .62526 .37026 .62003 Mtetra
.649 .746 .92 r
.37026 .62003 .37594 .62526 .38526 .62258 .3796 .61739 Mtetra
.653 .749 .92 r
.3796 .61739 .38526 .62258 .39462 .61982 .38898 .61464 Mtetra
.656 .751 .92 r
.38898 .61464 .39462 .61982 .40402 .617 .39839 .61183 Mtetra
.658 .753 .92 r
.39839 .61183 .40402 .617 .41344 .61413 .40784 .60896 Mtetra
.659 .753 .92 r
.40784 .60896 .41344 .61413 .42291 .61124 .41733 .60606 Mtetra
.659 .754 .92 r
.41733 .60606 .42291 .61124 .4324 .60834 .42684 .60314 Mtetra
.42684 .60314 .4324 .60834 .44193 .60543 .43639 .60021 Mtetra
.43639 .60021 .44193 .60543 .45149 .60251 .44597 .59727 Mtetra
.659 .753 .92 r
.44597 .59727 .45149 .60251 .46108 .59959 .45559 .59433 Mtetra
.658 .753 .92 r
.45559 .59433 .46108 .59959 .47071 .59667 .46524 .59138 Mtetra
.46524 .59138 .47071 .59667 .48037 .59374 .47492 .58843 Mtetra
.47492 .58843 .48037 .59374 .49007 .5908 .48464 .58547 Mtetra
.48464 .58547 .49007 .5908 .4998 .58786 .49439 .58251 Mtetra
.49439 .58251 .4998 .58786 .50956 .58491 .50418 .57954 Mtetra
.50418 .57954 .50956 .58491 .51936 .58195 .514 .57656 Mtetra
.657 .753 .92 r
.514 .57656 .51936 .58195 .52919 .57898 .52386 .57357 Mtetra
.52386 .57357 .52919 .57898 .53906 .576 .53375 .57057 Mtetra
.53375 .57057 .53906 .576 .54897 .57302 .54368 .56756 Mtetra
.657 .752 .92 r
.54368 .56756 .54897 .57302 .5589 .57002 .55364 .56455 Mtetra
.55364 .56455 .5589 .57002 .56888 .56702 .56364 .56152 Mtetra
.56364 .56152 .56888 .56702 .57889 .564 .57367 .55849 Mtetra
.57367 .55849 .57889 .564 .58894 .56098 .58374 .55544 Mtetra
.58374 .55544 .58894 .56098 .59902 .55794 .59385 .55238 Mtetra
.59385 .55238 .59902 .55794 .60914 .55489 .604 .54932 Mtetra
.604 .54932 .60914 .55489 .6193 .55184 .61418 .54624 Mtetra
.61418 .54624 .6193 .55184 .62949 .54877 .62439 .54315 Mtetra
.62439 .54315 .62949 .54877 .63972 .5457 .63465 .54006 Mtetra
.63465 .54006 .63972 .5457 .64999 .54261 .64494 .53695 Mtetra
.64494 .53695 .64999 .54261 .66029 .53951 .65527 .53383 Mtetra
.65527 .53383 .66029 .53951 .67063 .5364 .66564 .5307 Mtetra
.66564 .5307 .67063 .5364 .68101 .53328 .67605 .52756 Mtetra
.67605 .52756 .68101 .53328 .69143 .53015 .68649 .52441 Mtetra
.68649 .52441 .69143 .53015 .70189 .52701 .69698 .52124 Mtetra
.69698 .52124 .70189 .52701 .71238 .52386 .7075 .51807 Mtetra
.7075 .51807 .71238 .52386 .72292 .52069 .71806 .51488 Mtetra
.71806 .51488 .72292 .52069 .73349 .51752 .72866 .51169 Mtetra
.72866 .51169 .73349 .51752 .7441 .51433 .7393 .50848 Mtetra
.7393 .50848 .7441 .51433 .75475 .51113 .74998 .50526 Mtetra
.74998 .50526 .75475 .51113 .76544 .50792 .7607 .50203 Mtetra
.7607 .50203 .76544 .50792 .77617 .5047 .77146 .49878 Mtetra
.77146 .49878 .77617 .5047 .78695 .50147 .78226 .49553 Mtetra
.78226 .49553 .78695 .50147 .79776 .49823 .7931 .49226 Mtetra
.7931 .49226 .79776 .49823 .80861 .49497 .80398 .48898 Mtetra
.80398 .48898 .80861 .49497 .8195 .4917 .8149 .48569 Mtetra
.8149 .48569 .8195 .4917 .83043 .48842 .82586 .48239 Mtetra
.82586 .48239 .83043 .48842 .84141 .48513 .83687 .47907 Mtetra
.83687 .47907 .84141 .48513 .85242 .48182 .84791 .47574 Mtetra
.84791 .47574 .85242 .48182 .86348 .47851 .859 .4724 Mtetra
.859 .4724 .86348 .47851 .87458 .47518 .87013 .46905 Mtetra
.87013 .46905 .87458 .47518 .88572 .47184 .8813 .46568 Mtetra
.8813 .46568 .88572 .47184 .89691 .46848 .89252 .46231 Mtetra
.89252 .46231 .89691 .46848 .90814 .46511 .90378 .45892 Mtetra
.90378 .45892 .90814 .46511 .91941 .46173 .91508 .45551 Mtetra
.91508 .45551 .91941 .46173 .93072 .45834 .92642 .4521 Mtetra
.635 .738 .923 r
.31814 .62964 .32394 .63493 .33309 .63289 .32732 .62737 Mtetra
.594 .717 .93 r
.32732 .62737 .33309 .63289 .34206 .635 .33649 .62593 Mtetra
.801 .686 .738 r
.33649 .62593 .34206 .635 .35175 .62381 .34627 .61331 Mtetra
.398 .48 .827 r
.34627 .61331 .35175 .62381 .36096 .62244 .35525 .61688 Mtetra
.628 .728 .919 r
.35525 .61688 .36096 .62244 .37026 .62003 .36455 .61472 Mtetra
.646 .743 .92 r
.36455 .61472 .37026 .62003 .3796 .61739 .37391 .61215 Mtetra
.652 .748 .92 r
.37391 .61215 .3796 .61739 .38898 .61464 .3833 .60942 Mtetra
.655 .75 .92 r
.3833 .60942 .38898 .61464 .39839 .61183 .39274 .60661 Mtetra
.657 .752 .92 r
.39274 .60661 .39839 .61183 .40784 .60896 .40221 .60375 Mtetra
.658 .753 .92 r
.40221 .60375 .40784 .60896 .41733 .60606 .41171 .60084 Mtetra
.659 .754 .92 r
.41171 .60084 .41733 .60606 .42684 .60314 .42125 .5979 Mtetra
.42125 .5979 .42684 .60314 .43639 .60021 .43082 .59495 Mtetra
.43082 .59495 .43639 .60021 .44597 .59727 .44042 .59199 Mtetra
.44042 .59199 .44597 .59727 .45559 .59433 .45006 .58903 Mtetra
.658 .753 .92 r
.45006 .58903 .45559 .59433 .46524 .59138 .45973 .58606 Mtetra
.45973 .58606 .46524 .59138 .47492 .58843 .46944 .58309 Mtetra
.46944 .58309 .47492 .58843 .48464 .58547 .47918 .58011 Mtetra
.47918 .58011 .48464 .58547 .49439 .58251 .48895 .57712 Mtetra
.48895 .57712 .49439 .58251 .50418 .57954 .49876 .57413 Mtetra
.49876 .57413 .50418 .57954 .514 .57656 .50861 .57113 Mtetra
.50861 .57113 .514 .57656 .52386 .57357 .51849 .56812 Mtetra
.657 .753 .92 r
.51849 .56812 .52386 .57357 .53375 .57057 .5284 .5651 Mtetra
.5284 .5651 .53375 .57057 .54368 .56756 .53835 .56207 Mtetra
.657 .752 .92 r
.53835 .56207 .54368 .56756 .55364 .56455 .54834 .55904 Mtetra
.54834 .55904 .55364 .56455 .56364 .56152 .55836 .55599 Mtetra
.55836 .55599 .56364 .56152 .57367 .55849 .56842 .55293 Mtetra
.56842 .55293 .57367 .55849 .58374 .55544 .57852 .54987 Mtetra
.57852 .54987 .58374 .55544 .59385 .55238 .58865 .54679 Mtetra
.58865 .54679 .59385 .55238 .604 .54932 .59882 .5437 Mtetra
.59882 .5437 .604 .54932 .61418 .54624 .60902 .54061 Mtetra
.60902 .54061 .61418 .54624 .62439 .54315 .61927 .5375 Mtetra
.61927 .5375 .62439 .54315 .63465 .54006 .62955 .53438 Mtetra
.62955 .53438 .63465 .54006 .64494 .53695 .63987 .53125 Mtetra
.63987 .53125 .64494 .53695 .65527 .53383 .65022 .52811 Mtetra
.65022 .52811 .65527 .53383 .66564 .5307 .66062 .52496 Mtetra
.66062 .52496 .66564 .5307 .67605 .52756 .67105 .5218 Mtetra
.67105 .5218 .67605 .52756 .68649 .52441 .68152 .51862 Mtetra
.68152 .51862 .68649 .52441 .69698 .52124 .69203 .51544 Mtetra
.69203 .51544 .69698 .52124 .7075 .51807 .70258 .51224 Mtetra
.70258 .51224 .7075 .51807 .71806 .51488 .71317 .50903 Mtetra
.71317 .50903 .71806 .51488 .72866 .51169 .7238 .50581 Mtetra
.7238 .50581 .72866 .51169 .7393 .50848 .73446 .50258 Mtetra
.73446 .50258 .7393 .50848 .74998 .50526 .74517 .49934 Mtetra
.74517 .49934 .74998 .50526 .7607 .50203 .75592 .49609 Mtetra
.75592 .49609 .7607 .50203 .77146 .49878 .76671 .49282 Mtetra
.76671 .49282 .77146 .49878 .78226 .49553 .77753 .48954 Mtetra
.77753 .48954 .78226 .49553 .7931 .49226 .7884 .48625 Mtetra
.7884 .48625 .7931 .49226 .80398 .48898 .79931 .48295 Mtetra
.79931 .48295 .80398 .48898 .8149 .48569 .81026 .47964 Mtetra
.81026 .47964 .8149 .48569 .82586 .48239 .82126 .47631 Mtetra
.82126 .47631 .82586 .48239 .83687 .47907 .83229 .47297 Mtetra
.83229 .47297 .83687 .47907 .84791 .47574 .84337 .46962 Mtetra
.84337 .46962 .84791 .47574 .859 .4724 .85449 .46625 Mtetra
.85449 .46625 .859 .4724 .87013 .46905 .86565 .46288 Mtetra
.86565 .46288 .87013 .46905 .8813 .46568 .87685 .45949 Mtetra
.87685 .45949 .8813 .46568 .89252 .46231 .8881 .45609 Mtetra
.8881 .45609 .89252 .46231 .90378 .45892 .89939 .45267 Mtetra
.89939 .45267 .90378 .45892 .91508 .45551 .91072 .44924 Mtetra
.91072 .44924 .91508 .45551 .92642 .4521 .9221 .4458 Mtetra
.639 .74 .922 r
.31229 .62435 .31814 .62964 .32732 .62737 .3215 .62197 Mtetra
.625 .733 .925 r
.3215 .62197 .32732 .62737 .33649 .62593 .33072 .61988 Mtetra
.342 .59 .937 r
.33072 .61988 .33649 .62593 .34627 .61331 .33975 .62197 Mtetra
0 0 0 r
.33975 .62197 .34627 .61331 .35525 .61688 .34952 .6107 Mtetra
.596 .697 .913 r
.34952 .6107 .35525 .61688 .36455 .61472 .3588 .60929 Mtetra
.64 .738 .92 r
.3588 .60929 .36455 .61472 .37391 .61215 .36818 .60684 Mtetra
.649 .746 .92 r
.36818 .60684 .37391 .61215 .3833 .60942 .37759 .60415 Mtetra
.653 .749 .92 r
.37759 .60415 .3833 .60942 .39274 .60661 .38704 .60136 Mtetra
.656 .751 .92 r
.38704 .60136 .39274 .60661 .40221 .60375 .39653 .59849 Mtetra
.658 .753 .92 r
.39653 .59849 .40221 .60375 .41171 .60084 .40606 .59558 Mtetra
.659 .753 .92 r
.40606 .59558 .41171 .60084 .42125 .5979 .41562 .59263 Mtetra
.659 .754 .92 r
.41562 .59263 .42125 .5979 .43082 .59495 .42521 .58966 Mtetra
.42521 .58966 .43082 .59495 .44042 .59199 .43483 .58668 Mtetra
.43483 .58668 .44042 .59199 .45006 .58903 .44449 .58369 Mtetra
.659 .753 .92 r
.44449 .58369 .45006 .58903 .45973 .58606 .45419 .5807 Mtetra
.658 .753 .92 r
.45419 .5807 .45973 .58606 .46944 .58309 .46392 .57771 Mtetra
.46392 .57771 .46944 .58309 .47918 .58011 .47368 .57471 Mtetra
.47368 .57471 .47918 .58011 .48895 .57712 .48348 .5717 Mtetra
.48348 .5717 .48895 .57712 .49876 .57413 .49331 .56869 Mtetra
.49331 .56869 .49876 .57413 .50861 .57113 .50318 .56567 Mtetra
.50318 .56567 .50861 .57113 .51849 .56812 .51308 .56264 Mtetra
.657 .753 .92 r
.51308 .56264 .51849 .56812 .5284 .5651 .52302 .5596 Mtetra
.52302 .5596 .5284 .5651 .53835 .56207 .53299 .55655 Mtetra
.53299 .55655 .53835 .56207 .54834 .55904 .543 .55349 Mtetra
.657 .752 .92 r
.543 .55349 .54834 .55904 .55836 .55599 .55305 .55042 Mtetra
.55305 .55042 .55836 .55599 .56842 .55293 .56313 .54735 Mtetra
.56313 .54735 .56842 .55293 .57852 .54987 .57325 .54426 Mtetra
.57325 .54426 .57852 .54987 .58865 .54679 .58341 .54116 Mtetra
.58341 .54116 .58865 .54679 .59882 .5437 .5936 .53805 Mtetra
.5936 .53805 .59882 .5437 .60902 .54061 .60384 .53493 Mtetra
.60384 .53493 .60902 .54061 .61927 .5375 .6141 .5318 Mtetra
.6141 .5318 .61927 .5375 .62955 .53438 .62441 .52866 Mtetra
.62441 .52866 .62955 .53438 .63987 .53125 .63475 .52551 Mtetra
.63475 .52551 .63987 .53125 .65022 .52811 .64514 .52235 Mtetra
.64514 .52235 .65022 .52811 .66062 .52496 .65556 .51918 Mtetra
.65556 .51918 .66062 .52496 .67105 .5218 .66602 .51599 Mtetra
.66602 .51599 .67105 .5218 .68152 .51862 .67652 .5128 Mtetra
.67652 .5128 .68152 .51862 .69203 .51544 .68705 .50959 Mtetra
.68705 .50959 .69203 .51544 .70258 .51224 .69763 .50637 Mtetra
.69763 .50637 .70258 .51224 .71317 .50903 .70824 .50314 Mtetra
.70824 .50314 .71317 .50903 .7238 .50581 .7189 .4999 Mtetra
.7189 .4999 .7238 .50581 .73446 .50258 .72959 .49665 Mtetra
.72959 .49665 .73446 .50258 .74517 .49934 .74033 .49338 Mtetra
.74033 .49338 .74517 .49934 .75592 .49609 .75111 .49011 Mtetra
.75111 .49011 .75592 .49609 .76671 .49282 .76192 .48682 Mtetra
.76192 .48682 .76671 .49282 .77753 .48954 .77278 .48352 Mtetra
.77278 .48352 .77753 .48954 .7884 .48625 .78368 .4802 Mtetra
.78368 .4802 .7884 .48625 .79931 .48295 .79462 .47688 Mtetra
.79462 .47688 .79931 .48295 .81026 .47964 .8056 .47354 Mtetra
.8056 .47354 .81026 .47964 .82126 .47631 .81662 .47019 Mtetra
.81662 .47019 .82126 .47631 .83229 .47297 .82768 .46683 Mtetra
.82768 .46683 .83229 .47297 .84337 .46962 .83879 .46345 Mtetra
.83879 .46345 .84337 .46962 .85449 .46625 .84994 .46006 Mtetra
.84994 .46006 .85449 .46625 .86565 .46288 .86113 .45666 Mtetra
.86113 .45666 .86565 .46288 .87685 .45949 .87237 .45325 Mtetra
.87237 .45325 .87685 .45949 .8881 .45609 .88365 .44982 Mtetra
.88365 .44982 .8881 .45609 .89939 .45267 .89497 .44638 Mtetra
.89497 .44638 .89939 .45267 .91072 .44924 .90633 .44293 Mtetra
.90633 .44293 .91072 .44924 .9221 .4458 .91774 .43947 Mtetra
.64 .74 .922 r
.30641 .61903 .31229 .62435 .3215 .62197 .31564 .6166 Mtetra
.635 .738 .923 r
.31564 .6166 .3215 .62197 .33072 .61988 .32489 .61427 Mtetra
.594 .717 .93 r
.32489 .61427 .33072 .61988 .33975 .62197 .33413 .61279 Mtetra
.801 .687 .738 r
.33413 .61279 .33975 .62197 .34952 .6107 .344 .60009 Mtetra
.397 .479 .827 r
.344 .60009 .34952 .6107 .3588 .60929 .35303 .60364 Mtetra
.628 .728 .919 r
.35303 .60364 .3588 .60929 .36818 .60684 .36241 .60144 Mtetra
.646 .743 .92 r
.36241 .60144 .36818 .60684 .37759 .60415 .37184 .59882 Mtetra
.652 .748 .92 r
.37184 .59882 .37759 .60415 .38704 .60136 .38131 .59605 Mtetra
.655 .75 .92 r
.38131 .59605 .38704 .60136 .39653 .59849 .39082 .59319 Mtetra
.657 .752 .92 r
.39082 .59319 .39653 .59849 .40606 .59558 .40037 .59028 Mtetra
.658 .753 .92 r
.40037 .59028 .40606 .59558 .41562 .59263 .40995 .58732 Mtetra
.659 .754 .92 r
.40995 .58732 .41562 .59263 .42521 .58966 .41956 .58433 Mtetra
.41956 .58433 .42521 .58966 .43483 .58668 .42921 .58133 Mtetra
.42921 .58133 .43483 .58668 .44449 .58369 .43889 .57833 Mtetra
.43889 .57833 .44449 .58369 .45419 .5807 .44861 .57531 Mtetra
.658 .753 .92 r
.44861 .57531 .45419 .5807 .46392 .57771 .45836 .57229 Mtetra
.45836 .57229 .46392 .57771 .47368 .57471 .46814 .56927 Mtetra
.46814 .56927 .47368 .57471 .48348 .5717 .47796 .56624 Mtetra
.47796 .56624 .48348 .5717 .49331 .56869 .48782 .56321 Mtetra
.48782 .56321 .49331 .56869 .50318 .56567 .49771 .56017 Mtetra
.49771 .56017 .50318 .56567 .51308 .56264 .50764 .55712 Mtetra
.50764 .55712 .51308 .56264 .52302 .5596 .5176 .55406 Mtetra
.657 .753 .92 r
.5176 .55406 .52302 .5596 .53299 .55655 .5276 .55099 Mtetra
.5276 .55099 .53299 .55655 .543 .55349 .53763 .54791 Mtetra
.657 .752 .92 r
.53763 .54791 .543 .55349 .55305 .55042 .5477 .54482 Mtetra
.5477 .54482 .55305 .55042 .56313 .54735 .55781 .54172 Mtetra
.55781 .54172 .56313 .54735 .57325 .54426 .56796 .53861 Mtetra
.56796 .53861 .57325 .54426 .58341 .54116 .57814 .53549 Mtetra
.57814 .53549 .58341 .54116 .5936 .53805 .58836 .53236 Mtetra
.58836 .53236 .5936 .53805 .60384 .53493 .59861 .52922 Mtetra
.59861 .52922 .60384 .53493 .6141 .5318 .60891 .52607 Mtetra
.60891 .52607 .6141 .5318 .62441 .52866 .61924 .52291 Mtetra
.61924 .52291 .62441 .52866 .63475 .52551 .62961 .51974 Mtetra
.62961 .51974 .63475 .52551 .64514 .52235 .64002 .51655 Mtetra
.64002 .51655 .64514 .52235 .65556 .51918 .65046 .51336 Mtetra
.65046 .51336 .65556 .51918 .66602 .51599 .66095 .51015 Mtetra
.66095 .51015 .66602 .51599 .67652 .5128 .67147 .50693 Mtetra
.67147 .50693 .67652 .5128 .68705 .50959 .68204 .5037 Mtetra
.68204 .5037 .68705 .50959 .69763 .50637 .69264 .50046 Mtetra
.69264 .50046 .69763 .50637 .70824 .50314 .70329 .49721 Mtetra
.70329 .49721 .70824 .50314 .7189 .4999 .71397 .49395 Mtetra
.71397 .49395 .7189 .4999 .72959 .49665 .72469 .49067 Mtetra
.72469 .49067 .72959 .49665 .74033 .49338 .73546 .48738 Mtetra
.73546 .48738 .74033 .49338 .75111 .49011 .74626 .48408 Mtetra
.74626 .48408 .75111 .49011 .76192 .48682 .7571 .48077 Mtetra
.7571 .48077 .76192 .48682 .77278 .48352 .76799 .47745 Mtetra
.76799 .47745 .77278 .48352 .78368 .4802 .77892 .47411 Mtetra
.77892 .47411 .78368 .4802 .79462 .47688 .78989 .47076 Mtetra
.78989 .47076 .79462 .47688 .8056 .47354 .8009 .4674 Mtetra
.8009 .4674 .8056 .47354 .81662 .47019 .81195 .46403 Mtetra
.81195 .46403 .81662 .47019 .82768 .46683 .82304 .46064 Mtetra
.82304 .46064 .82768 .46683 .83879 .46345 .83418 .45724 Mtetra
.83418 .45724 .83879 .46345 .84994 .46006 .84536 .45383 Mtetra
.84536 .45383 .84994 .46006 .86113 .45666 .85659 .4504 Mtetra
.85659 .4504 .86113 .45666 .87237 .45325 .86785 .44697 Mtetra
.86785 .44697 .87237 .45325 .88365 .44982 .87916 .44352 Mtetra
.87916 .44352 .88365 .44982 .89497 .44638 .89052 .44005 Mtetra
.89052 .44005 .89497 .44638 .90633 .44293 .90191 .43657 Mtetra
.90191 .43657 .90633 .44293 .91774 .43947 .91335 .43308 Mtetra
.639 .74 .921 r
.30049 .61365 .30641 .61903 .31564 .6166 .30973 .61122 Mtetra
.639 .74 .922 r
.30973 .61122 .31564 .6166 .32489 .61427 .31901 .60879 Mtetra
.625 .733 .925 r
.31901 .60879 .32489 .61427 .33413 .61279 .3283 .60666 Mtetra
.343 .59 .936 r
.3283 .60666 .33413 .61279 .344 .60009 .3374 .60873 Mtetra
0 0 0 r
.3374 .60873 .344 .60009 .35303 .60364 .34726 .59737 Mtetra
.596 .697 .913 r
.34726 .59737 .35303 .60364 .36241 .60144 .35661 .59592 Mtetra
.64 .738 .92 r
.35661 .59592 .36241 .60144 .37184 .59882 .36606 .59342 Mtetra
.649 .746 .92 r
.36606 .59342 .37184 .59882 .38131 .59605 .37555 .59069 Mtetra
.653 .749 .92 r
.37555 .59069 .38131 .59605 .39082 .59319 .38508 .58785 Mtetra
.656 .751 .92 r
.38508 .58785 .39082 .59319 .40037 .59028 .39464 .58493 Mtetra
.658 .753 .92 r
.39464 .58493 .40037 .59028 .40995 .58732 .40424 .58197 Mtetra
.659 .753 .92 r
.40424 .58197 .40995 .58732 .41956 .58433 .41388 .57897 Mtetra
.659 .754 .92 r
.41388 .57897 .41956 .58433 .42921 .58133 .42355 .57595 Mtetra
.42355 .57595 .42921 .58133 .43889 .57833 .43325 .57292 Mtetra
.43325 .57292 .43889 .57833 .44861 .57531 .44299 .56989 Mtetra
.659 .753 .92 r
.44299 .56989 .44861 .57531 .45836 .57229 .45276 .56685 Mtetra
.658 .753 .92 r
.45276 .56685 .45836 .57229 .46814 .56927 .46257 .5638 Mtetra
.46257 .5638 .46814 .56927 .47796 .56624 .47242 .56075 Mtetra
.47242 .56075 .47796 .56624 .48782 .56321 .48229 .5577 Mtetra
.48229 .5577 .48782 .56321 .49771 .56017 .49221 .55463 Mtetra
.49221 .55463 .49771 .56017 .50764 .55712 .50216 .55156 Mtetra
.50216 .55156 .50764 .55712 .5176 .55406 .51214 .54848 Mtetra
.657 .753 .92 r
.51214 .54848 .5176 .55406 .5276 .55099 .52217 .54539 Mtetra
.52217 .54539 .5276 .55099 .53763 .54791 .53222 .54229 Mtetra
.53222 .54229 .53763 .54791 .5477 .54482 .54232 .53918 Mtetra
.657 .752 .92 r
.54232 .53918 .5477 .54482 .55781 .54172 .55245 .53606 Mtetra
.55245 .53606 .55781 .54172 .56796 .53861 .56262 .53293 Mtetra
.56262 .53293 .56796 .53861 .57814 .53549 .57283 .52978 Mtetra
.57283 .52978 .57814 .53549 .58836 .53236 .58307 .52663 Mtetra
.58307 .52663 .58836 .53236 .59861 .52922 .59335 .52347 Mtetra
.59335 .52347 .59861 .52922 .60891 .52607 .60367 .5203 Mtetra
.60367 .5203 .60891 .52607 .61924 .52291 .61403 .51712 Mtetra
.61403 .51712 .61924 .52291 .62961 .51974 .62443 .51392 Mtetra
.62443 .51392 .62961 .51974 .64002 .51655 .63486 .51071 Mtetra
.63486 .51071 .64002 .51655 .65046 .51336 .64534 .5075 Mtetra
.64534 .5075 .65046 .51336 .66095 .51015 .65585 .50427 Mtetra
.65585 .50427 .66095 .51015 .67147 .50693 .6664 .50103 Mtetra
.6664 .50103 .67147 .50693 .68204 .5037 .67699 .49778 Mtetra
.67699 .49778 .68204 .5037 .69264 .50046 .68762 .49451 Mtetra
.68762 .49451 .69264 .50046 .70329 .49721 .69829 .49124 Mtetra
.69829 .49124 .70329 .49721 .71397 .49395 .709 .48795 Mtetra
.709 .48795 .71397 .49395 .72469 .49067 .71975 .48465 Mtetra
.71975 .48465 .72469 .49067 .73546 .48738 .73055 .48134 Mtetra
.73055 .48134 .73546 .48738 .74626 .48408 .74138 .47802 Mtetra
.74138 .47802 .74626 .48408 .7571 .48077 .75225 .47468 Mtetra
.75225 .47468 .7571 .48077 .76799 .47745 .76317 .47133 Mtetra
.76317 .47133 .76799 .47745 .77892 .47411 .77412 .46797 Mtetra
.77412 .46797 .77892 .47411 .78989 .47076 .78512 .4646 Mtetra
.78512 .4646 .78989 .47076 .8009 .4674 .79616 .46122 Mtetra
.79616 .46122 .8009 .4674 .81195 .46403 .80725 .45782 Mtetra
.80725 .45782 .81195 .46403 .82304 .46064 .81837 .45441 Mtetra
.81837 .45441 .82304 .46064 .83418 .45724 .82954 .45099 Mtetra
.82954 .45099 .83418 .45724 .84536 .45383 .84075 .44755 Mtetra
.84075 .44755 .84536 .45383 .85659 .4504 .85201 .4441 Mtetra
.85201 .4441 .85659 .4504 .86785 .44697 .8633 .44064 Mtetra
.8633 .44064 .86785 .44697 .87916 .44352 .87465 .43716 Mtetra
.87465 .43716 .87916 .44352 .89052 .44005 .88603 .43367 Mtetra
.88603 .43367 .89052 .44005 .90191 .43657 .89746 .43017 Mtetra
.89746 .43017 .90191 .43657 .91335 .43308 .90894 .42666 Mtetra
.636 .737 .921 r
.29454 .60819 .30049 .61365 .30973 .61122 .3038 .60581 Mtetra
.64 .74 .922 r
.3038 .60581 .30973 .61122 .31901 .60879 .31309 .60333 Mtetra
.635 .738 .923 r
.31309 .60333 .31901 .60879 .3283 .60666 .32242 .60097 Mtetra
.594 .717 .93 r
.32242 .60097 .3283 .60666 .3374 .60873 .33173 .59944 Mtetra
.802 .687 .738 r
.33173 .59944 .3374 .60873 .34726 .59737 .34168 .58665 Mtetra
.396 .479 .827 r
.34168 .58665 .34726 .59737 .35661 .59592 .35079 .59018 Mtetra
.628 .728 .919 r
.35079 .59018 .35661 .59592 .36606 .59342 .36024 .58794 Mtetra
.646 .743 .92 r
.36024 .58794 .36606 .59342 .37555 .59069 .36974 .58527 Mtetra
.652 .748 .92 r
.36974 .58527 .37555 .59069 .38508 .58785 .37929 .58245 Mtetra
.655 .75 .92 r
.37929 .58245 .38508 .58785 .39464 .58493 .38888 .57954 Mtetra
.657 .752 .92 r
.38888 .57954 .39464 .58493 .40424 .58197 .3985 .57658 Mtetra
.658 .753 .92 r
.3985 .57658 .40424 .58197 .41388 .57897 .40815 .57357 Mtetra
.659 .754 .92 r
.40815 .57357 .41388 .57897 .42355 .57595 .41785 .57054 Mtetra
.41785 .57054 .42355 .57595 .43325 .57292 .42757 .56749 Mtetra
.42757 .56749 .43325 .57292 .44299 .56989 .43733 .56443 Mtetra
.43733 .56443 .44299 .56989 .45276 .56685 .44713 .56137 Mtetra
.658 .753 .92 r
.44713 .56137 .45276 .56685 .46257 .5638 .45696 .5583 Mtetra
.45696 .5583 .46257 .5638 .47242 .56075 .46683 .55522 Mtetra
.46683 .55522 .47242 .56075 .48229 .5577 .47673 .55215 Mtetra
.47673 .55215 .48229 .5577 .49221 .55463 .48667 .54906 Mtetra
.48667 .54906 .49221 .55463 .50216 .55156 .49664 .54596 Mtetra
.49664 .54596 .50216 .55156 .51214 .54848 .50665 .54286 Mtetra
.50665 .54286 .51214 .54848 .52217 .54539 .5167 .53975 Mtetra
.657 .753 .92 r
.5167 .53975 .52217 .54539 .53222 .54229 .52678 .53663 Mtetra
.52678 .53663 .53222 .54229 .54232 .53918 .5369 .5335 Mtetra
.657 .752 .92 r
.5369 .5335 .54232 .53918 .55245 .53606 .54706 .53035 Mtetra
.54706 .53035 .55245 .53606 .56262 .53293 .55725 .5272 Mtetra
.55725 .5272 .56262 .53293 .57283 .52978 .56748 .52404 Mtetra
.56748 .52404 .57283 .52978 .58307 .52663 .57775 .52087 Mtetra
.57775 .52087 .58307 .52663 .59335 .52347 .58806 .51768 Mtetra
.58806 .51768 .59335 .52347 .60367 .5203 .5984 .51449 Mtetra
.5984 .51449 .60367 .5203 .61403 .51712 .60879 .51128 Mtetra
.60879 .51128 .61403 .51712 .62443 .51392 .61921 .50806 Mtetra
.61921 .50806 .62443 .51392 .63486 .51071 .62967 .50484 Mtetra
.62967 .50484 .63486 .51071 .64534 .5075 .64017 .5016 Mtetra
.64017 .5016 .64534 .5075 .65585 .50427 .65071 .49835 Mtetra
.65071 .49835 .65585 .50427 .6664 .50103 .66129 .49508 Mtetra
.66129 .49508 .6664 .50103 .67699 .49778 .67191 .49181 Mtetra
.67191 .49181 .67699 .49778 .68762 .49451 .68257 .48852 Mtetra
.68257 .48852 .68762 .49451 .69829 .49124 .69326 .48522 Mtetra
.69326 .48522 .69829 .49124 .709 .48795 .704 .48191 Mtetra
.704 .48191 .709 .48795 .71975 .48465 .71478 .47859 Mtetra
.71478 .47859 .71975 .48465 .73055 .48134 .7256 .47526 Mtetra
.7256 .47526 .73055 .48134 .74138 .47802 .73646 .47191 Mtetra
.73646 .47191 .74138 .47802 .75225 .47468 .74737 .46855 Mtetra
.74737 .46855 .75225 .47468 .76317 .47133 .75831 .46518 Mtetra
.75831 .46518 .76317 .47133 .77412 .46797 .7693 .4618 Mtetra
.7693 .4618 .77412 .46797 .78512 .4646 .78033 .4584 Mtetra
.78033 .4584 .78512 .4646 .79616 .46122 .7914 .45499 Mtetra
.7914 .45499 .79616 .46122 .80725 .45782 .80251 .45157 Mtetra
.80251 .45157 .80725 .45782 .81837 .45441 .81367 .44813 Mtetra
.81367 .44813 .81837 .45441 .82954 .45099 .82486 .44469 Mtetra
.82486 .44469 .82954 .45099 .84075 .44755 .83611 .44123 Mtetra
.83611 .44123 .84075 .44755 .85201 .4441 .84739 .43775 Mtetra
.84739 .43775 .85201 .4441 .8633 .44064 .85872 .43426 Mtetra
.85872 .43426 .8633 .44064 .87465 .43716 .8701 .43076 Mtetra
.8701 .43076 .87465 .43716 .88603 .43367 .88151 .42725 Mtetra
.88151 .42725 .88603 .43367 .89746 .43017 .89298 .42372 Mtetra
.89298 .42372 .89746 .43017 .90894 .42666 .90448 .42018 Mtetra
.63 .732 .921 r
.28856 .6026 .29454 .60819 .3038 .60581 .29782 .60034 Mtetra
.639 .74 .921 r
.29782 .60034 .3038 .60581 .31309 .60333 .30714 .59787 Mtetra
.639 .74 .922 r
.30714 .59787 .31309 .60333 .32242 .60097 .31648 .59539 Mtetra
.625 .733 .925 r
.31648 .59539 .32242 .60097 .33173 .59944 .32585 .59322 Mtetra
.345 .59 .936 r
.32585 .59322 .33173 .59944 .34168 .58665 .33502 .59526 Mtetra
0 0 0 r
.33502 .59526 .34168 .58665 .35079 .59018 .34496 .58382 Mtetra
.596 .697 .914 r
.34496 .58382 .35079 .59018 .36024 .58794 .35438 .58233 Mtetra
.64 .738 .92 r
.35438 .58233 .36024 .58794 .36974 .58527 .3639 .57978 Mtetra
.649 .746 .92 r
.3639 .57978 .36974 .58527 .37929 .58245 .37347 .577 Mtetra
.653 .749 .92 r
.37347 .577 .37929 .58245 .38888 .57954 .38307 .57411 Mtetra
.656 .751 .92 r
.38307 .57411 .38888 .57954 .3985 .57658 .39272 .57115 Mtetra
.658 .753 .92 r
.39272 .57115 .3985 .57658 .40815 .57357 .40239 .56813 Mtetra
.659 .753 .92 r
.40239 .56813 .40815 .57357 .41785 .57054 .41211 .56509 Mtetra
.659 .754 .92 r
.41211 .56509 .41785 .57054 .42757 .56749 .42186 .56202 Mtetra
.42186 .56202 .42757 .56749 .43733 .56443 .43164 .55894 Mtetra
.43164 .55894 .43733 .56443 .44713 .56137 .44146 .55585 Mtetra
.659 .753 .92 r
.44146 .55585 .44713 .56137 .45696 .5583 .45131 .55276 Mtetra
.658 .753 .92 r
.45131 .55276 .45696 .5583 .46683 .55522 .4612 .54966 Mtetra
.4612 .54966 .46683 .55522 .47673 .55215 .47113 .54656 Mtetra
.47113 .54656 .47673 .55215 .48667 .54906 .48109 .54345 Mtetra
.48109 .54345 .48667 .54906 .49664 .54596 .49109 .54033 Mtetra
.49109 .54033 .49664 .54596 .50665 .54286 .50112 .53721 Mtetra
.50112 .53721 .50665 .54286 .5167 .53975 .51119 .53407 Mtetra
.657 .753 .92 r
.51119 .53407 .5167 .53975 .52678 .53663 .5213 .53093 Mtetra
.5213 .53093 .52678 .53663 .5369 .5335 .53144 .52778 Mtetra
.53144 .52778 .5369 .5335 .54706 .53035 .54162 .52461 Mtetra
.657 .752 .92 r
.54162 .52461 .54706 .53035 .55725 .5272 .55184 .52144 Mtetra
.55184 .52144 .55725 .5272 .56748 .52404 .5621 .51825 Mtetra
.5621 .51825 .56748 .52404 .57775 .52087 .57239 .51506 Mtetra
.57239 .51506 .57775 .52087 .58806 .51768 .58273 .51185 Mtetra
.58273 .51185 .58806 .51768 .5984 .51449 .5931 .50864 Mtetra
.5931 .50864 .5984 .51449 .60879 .51128 .60351 .50541 Mtetra
.60351 .50541 .60879 .51128 .61921 .50806 .61396 .50217 Mtetra
.61396 .50217 .61921 .50806 .62967 .50484 .62444 .49892 Mtetra
.62444 .49892 .62967 .50484 .64017 .5016 .63497 .49565 Mtetra
.63497 .49565 .64017 .5016 .65071 .49835 .64554 .49238 Mtetra
.64554 .49238 .65071 .49835 .66129 .49508 .65614 .4891 Mtetra
.65614 .4891 .66129 .49508 .67191 .49181 .66679 .4858 Mtetra
.66679 .4858 .67191 .49181 .68257 .48852 .67747 .48249 Mtetra
.67747 .48249 .68257 .48852 .69326 .48522 .6882 .47917 Mtetra
.6882 .47917 .69326 .48522 .704 .48191 .69897 .47583 Mtetra
.69897 .47583 .704 .48191 .71478 .47859 .70978 .47249 Mtetra
.70978 .47249 .71478 .47859 .7256 .47526 .72062 .46913 Mtetra
.72062 .46913 .7256 .47526 .73646 .47191 .73152 .46576 Mtetra
.73152 .46576 .73646 .47191 .74737 .46855 .74245 .46238 Mtetra
.74245 .46238 .74737 .46855 .75831 .46518 .75342 .45898 Mtetra
.75342 .45898 .75831 .46518 .7693 .4618 .76444 .45557 Mtetra
.76444 .45557 .7693 .4618 .78033 .4584 .7755 .45215 Mtetra
.7755 .45215 .78033 .4584 .7914 .45499 .7866 .44872 Mtetra
.7866 .44872 .7914 .45499 .80251 .45157 .79774 .44527 Mtetra
.79774 .44527 .80251 .45157 .81367 .44813 .80893 .44181 Mtetra
.80893 .44181 .81367 .44813 .82486 .44469 .82016 .43834 Mtetra
.82016 .43834 .82486 .44469 .83611 .44123 .83143 .43486 Mtetra
.83143 .43486 .83611 .44123 .84739 .43775 .84275 .43136 Mtetra
.84275 .43136 .84739 .43775 .85872 .43426 .85411 .42784 Mtetra
.85411 .42784 .85872 .43426 .8701 .43076 .86551 .42432 Mtetra
.86551 .42432 .8701 .43076 .88151 .42725 .87696 .42078 Mtetra
.87696 .42078 .88151 .42725 .89298 .42372 .88846 .41723 Mtetra
.88846 .41723 .89298 .42372 .90448 .42018 .9 .41366 Mtetra
.614 .718 .919 r
.28256 .59671 .28856 .6026 .29782 .60034 .29181 .5948 Mtetra
.636 .737 .921 r
.29181 .5948 .29782 .60034 .30714 .59787 .30114 .59237 Mtetra
.64 .74 .922 r
.30114 .59237 .30714 .59787 .31648 .59539 .31051 .58985 Mtetra
.635 .738 .923 r
.31051 .58985 .31648 .59539 .32585 .59322 .3199 .58743 Mtetra
.594 .717 .93 r
.3199 .58743 .32585 .59322 .33502 .59526 .32929 .58587 Mtetra
.802 .688 .739 r
.32929 .58587 .33502 .59526 .34496 .58382 .33933 .57299 Mtetra
.395 .478 .828 r
.33933 .57299 .34496 .58382 .35438 .58233 .3485 .57649 Mtetra
.628 .728 .919 r
.3485 .57649 .35438 .58233 .3639 .57978 .35803 .57421 Mtetra
.646 .743 .92 r
.35803 .57421 .3639 .57978 .37347 .577 .36761 .57149 Mtetra
.652 .748 .92 r
.36761 .57149 .37347 .577 .38307 .57411 .37723 .56862 Mtetra
.655 .75 .92 r
.37723 .56862 .38307 .57411 .39272 .57115 .3869 .56567 Mtetra
.657 .752 .92 r
.3869 .56567 .39272 .57115 .40239 .56813 .3966 .56265 Mtetra
.658 .753 .92 r
.3966 .56265 .40239 .56813 .41211 .56509 .40633 .55959 Mtetra
.659 .754 .92 r
.40633 .55959 .41211 .56509 .42186 .56202 .4161 .55651 Mtetra
.4161 .55651 .42186 .56202 .43164 .55894 .42591 .55341 Mtetra
.42591 .55341 .43164 .55894 .44146 .55585 .43575 .5503 Mtetra
.43575 .5503 .44146 .55585 .45131 .55276 .44563 .54718 Mtetra
.658 .753 .92 r
.44563 .54718 .45131 .55276 .4612 .54966 .45554 .54406 Mtetra
.45554 .54406 .4612 .54966 .47113 .54656 .46549 .54094 Mtetra
.46549 .54094 .47113 .54656 .48109 .54345 .47547 .5378 Mtetra
.47547 .5378 .48109 .54345 .49109 .54033 .4855 .53466 Mtetra
.4855 .53466 .49109 .54033 .50112 .53721 .49555 .53152 Mtetra
.49555 .53152 .50112 .53721 .51119 .53407 .50565 .52836 Mtetra
.50565 .52836 .51119 .53407 .5213 .53093 .51578 .52519 Mtetra
.657 .753 .92 r
.51578 .52519 .5213 .53093 .53144 .52778 .52595 .52202 Mtetra
.52595 .52202 .53144 .52778 .54162 .52461 .53615 .51883 Mtetra
.657 .752 .92 r
.53615 .51883 .54162 .52461 .55184 .52144 .5464 .51564 Mtetra
.5464 .51564 .55184 .52144 .5621 .51825 .55668 .51243 Mtetra
.55668 .51243 .5621 .51825 .57239 .51506 .567 .50921 Mtetra
.567 .50921 .57239 .51506 .58273 .51185 .57736 .50598 Mtetra
.57736 .50598 .58273 .51185 .5931 .50864 .58776 .50274 Mtetra
.58776 .50274 .5931 .50864 .60351 .50541 .59819 .49949 Mtetra
.59819 .49949 .60351 .50541 .61396 .50217 .60867 .49623 Mtetra
.60867 .49623 .61396 .50217 .62444 .49892 .61918 .49296 Mtetra
.61918 .49296 .62444 .49892 .63497 .49565 .62973 .48967 Mtetra
.62973 .48967 .63497 .49565 .64554 .49238 .64033 .48637 Mtetra
.64033 .48637 .64554 .49238 .65614 .4891 .65096 .48307 Mtetra
.65096 .48307 .65614 .4891 .66679 .4858 .66163 .47975 Mtetra
.66163 .47975 .66679 .4858 .67747 .48249 .67235 .47641 Mtetra
.67235 .47641 .67747 .48249 .6882 .47917 .6831 .47307 Mtetra
.6831 .47307 .6882 .47917 .69897 .47583 .6939 .46971 Mtetra
.6939 .46971 .69897 .47583 .70978 .47249 .70473 .46634 Mtetra
.70473 .46634 .70978 .47249 .72062 .46913 .71561 .46296 Mtetra
.71561 .46296 .72062 .46913 .73152 .46576 .72653 .45957 Mtetra
.72653 .45957 .73152 .46576 .74245 .46238 .73749 .45616 Mtetra
.73749 .45616 .74245 .46238 .75342 .45898 .7485 .45274 Mtetra
.7485 .45274 .75342 .45898 .76444 .45557 .75954 .44931 Mtetra
.75954 .44931 .76444 .45557 .7755 .45215 .77063 .44586 Mtetra
.77063 .44586 .7755 .45215 .7866 .44872 .78176 .4424 Mtetra
.78176 .4424 .7866 .44872 .79774 .44527 .79293 .43893 Mtetra
.79293 .43893 .79774 .44527 .80893 .44181 .80415 .43545 Mtetra
.80415 .43545 .80893 .44181 .82016 .43834 .81541 .43195 Mtetra
.81541 .43195 .82016 .43834 .83143 .43486 .82672 .42844 Mtetra
.82672 .42844 .83143 .43486 .84275 .43136 .83807 .42492 Mtetra
.83807 .42492 .84275 .43136 .85411 .42784 .84946 .42138 Mtetra
.84946 .42138 .85411 .42784 .86551 .42432 .8609 .41783 Mtetra
.8609 .41783 .86551 .42432 .87696 .42078 .87238 .41426 Mtetra
.87238 .41426 .87696 .42078 .88846 .41723 .88391 .41068 Mtetra
.88391 .41068 .88846 .41723 .9 .41366 .89548 .40709 Mtetra
.56 .665 .908 r
.27659 .58982 .28256 .59671 .29181 .5948 .28577 .58911 Mtetra
.63 .732 .921 r
.28577 .58911 .29181 .5948 .30114 .59237 .29511 .58682 Mtetra
.639 .74 .921 r
.29511 .58682 .30114 .59237 .31051 .58985 .30449 .58429 Mtetra
.639 .74 .922 r
.30449 .58429 .31051 .58985 .3199 .58743 .31391 .58177 Mtetra
.625 .733 .925 r
.31391 .58177 .3199 .58743 .32929 .58587 .32335 .57955 Mtetra
.346 .591 .936 r
.32335 .57955 .32929 .58587 .33933 .57299 .33259 .58156 Mtetra
0 0 0 r
.33259 .58156 .33933 .57299 .3485 .57649 .34261 .57004 Mtetra
.595 .697 .914 r
.34261 .57004 .3485 .57649 .35803 .57421 .35212 .5685 Mtetra
.64 .738 .92 r
.35212 .5685 .35803 .57421 .36761 .57149 .36171 .56591 Mtetra
.649 .746 .92 r
.36171 .56591 .36761 .57149 .37723 .56862 .37135 .56308 Mtetra
.653 .749 .92 r
.37135 .56308 .37723 .56862 .3869 .56567 .38104 .56014 Mtetra
.656 .751 .92 r
.38104 .56014 .3869 .56567 .3966 .56265 .39076 .55712 Mtetra
.658 .753 .92 r
.39076 .55712 .3966 .56265 .40633 .55959 .40052 .55406 Mtetra
.659 .753 .92 r
.40052 .55406 .40633 .55959 .4161 .55651 .41031 .55096 Mtetra
.659 .754 .92 r
.41031 .55096 .4161 .55651 .42591 .55341 .42014 .54784 Mtetra
.42014 .54784 .42591 .55341 .43575 .5503 .43 .54471 Mtetra
.43 .54471 .43575 .5503 .44563 .54718 .4399 .54157 Mtetra
.659 .753 .92 r
.4399 .54157 .44563 .54718 .45554 .54406 .44984 .53842 Mtetra
.658 .753 .92 r
.44984 .53842 .45554 .54406 .46549 .54094 .45981 .53527 Mtetra
.45981 .53527 .46549 .54094 .47547 .5378 .46982 .53212 Mtetra
.46982 .53212 .47547 .5378 .4855 .53466 .47987 .52896 Mtetra
.47987 .52896 .4855 .53466 .49555 .53152 .48995 .52579 Mtetra
.48995 .52579 .49555 .53152 .50565 .52836 .50007 .52261 Mtetra
.50007 .52261 .50565 .52836 .51578 .52519 .51022 .51942 Mtetra
.657 .753 .92 r
.51022 .51942 .51578 .52519 .52595 .52202 .52042 .51622 Mtetra
.52042 .51622 .52595 .52202 .53615 .51883 .53065 .51301 Mtetra
.53065 .51301 .53615 .51883 .5464 .51564 .54092 .50979 Mtetra
.657 .752 .92 r
.54092 .50979 .5464 .51564 .55668 .51243 .55122 .50656 Mtetra
.55122 .50656 .55668 .51243 .567 .50921 .56157 .50332 Mtetra
.56157 .50332 .567 .50921 .57736 .50598 .57195 .50007 Mtetra
.57195 .50007 .57736 .50598 .58776 .50274 .58238 .49681 Mtetra
.58238 .49681 .58776 .50274 .59819 .49949 .59284 .49354 Mtetra
.59284 .49354 .59819 .49949 .60867 .49623 .60334 .49025 Mtetra
.60334 .49025 .60867 .49623 .61918 .49296 .61388 .48696 Mtetra
.61388 .48696 .61918 .49296 .62973 .48967 .62446 .48365 Mtetra
.62446 .48365 .62973 .48967 .64033 .48637 .63508 .48033 Mtetra
.63508 .48033 .64033 .48637 .65096 .48307 .64574 .47699 Mtetra
.64574 .47699 .65096 .48307 .66163 .47975 .65644 .47365 Mtetra
.65644 .47365 .66163 .47975 .67235 .47641 .66718 .47029 Mtetra
.66718 .47029 .67235 .47641 .6831 .47307 .67797 .46693 Mtetra
.67797 .46693 .6831 .47307 .6939 .46971 .68879 .46355 Mtetra
.68879 .46355 .6939 .46971 .70473 .46634 .69966 .46015 Mtetra
.69966 .46015 .70473 .46634 .71561 .46296 .71056 .45675 Mtetra
.71056 .45675 .71561 .46296 .72653 .45957 .72151 .45333 Mtetra
.72151 .45333 .72653 .45957 .73749 .45616 .7325 .4499 Mtetra
.7325 .4499 .73749 .45616 .7485 .45274 .74353 .44645 Mtetra
.74353 .44645 .7485 .45274 .75954 .44931 .75461 .443 Mtetra
.75461 .443 .75954 .44931 .77063 .44586 .76573 .43953 Mtetra
.76573 .43953 .77063 .44586 .78176 .4424 .77689 .43604 Mtetra
.77689 .43604 .78176 .4424 .79293 .43893 .7881 .43255 Mtetra
.7881 .43255 .79293 .43893 .80415 .43545 .79934 .42904 Mtetra
.79934 .42904 .80415 .43545 .81541 .43195 .81064 .42551 Mtetra
.81064 .42551 .81541 .43195 .82672 .42844 .82197 .42198 Mtetra
.82197 .42198 .82672 .42844 .83807 .42492 .83335 .41843 Mtetra
.83335 .41843 .83807 .42492 .84946 .42138 .84478 .41486 Mtetra
.84478 .41486 .84946 .42138 .8609 .41783 .85625 .41129 Mtetra
.85625 .41129 .8609 .41783 .87238 .41426 .86777 .4077 Mtetra
.86777 .4077 .87238 .41426 .88391 .41068 .87933 .40409 Mtetra
.87933 .40409 .88391 .41068 .89548 .40709 .89093 .40047 Mtetra
0 0 .468 r
.27285 .55257 .27659 .58982 .28577 .58911 .27971 .58313 Mtetra
.614 .718 .919 r
.27971 .58313 .28577 .58911 .29511 .58682 .28904 .58118 Mtetra
.636 .737 .921 r
.28904 .58118 .29511 .58682 .30449 .58429 .29844 .5787 Mtetra
.64 .74 .922 r
.29844 .5787 .30449 .58429 .31391 .58177 .30788 .57614 Mtetra
.635 .738 .923 r
.30788 .57614 .31391 .58177 .32335 .57955 .31735 .57367 Mtetra
.594 .717 .93 r
.31735 .57367 .32335 .57955 .33259 .58156 .32681 .57207 Mtetra
.803 .689 .739 r
.32681 .57207 .33259 .58156 .34261 .57004 .33694 .55909 Mtetra
.394 .478 .828 r
.33694 .55909 .34261 .57004 .35212 .5685 .34618 .56257 Mtetra
.628 .728 .919 r
.34618 .56257 .35212 .5685 .36171 .56591 .35578 .56024 Mtetra
.646 .743 .92 r
.35578 .56024 .36171 .56591 .37135 .56308 .36544 .55747 Mtetra
.652 .748 .92 r
.36544 .55747 .37135 .56308 .38104 .56014 .37514 .55455 Mtetra
.655 .75 .92 r
.37514 .55455 .38104 .56014 .39076 .55712 .38488 .55155 Mtetra
.657 .752 .92 r
.38488 .55155 .39076 .55712 .40052 .55406 .39466 .54848 Mtetra
.658 .753 .92 r
.39466 .54848 .40052 .55406 .41031 .55096 .40448 .54537 Mtetra
.659 .754 .92 r
.40448 .54537 .41031 .55096 .42014 .54784 .41433 .54224 Mtetra
.41433 .54224 .42014 .54784 .43 .54471 .42422 .53908 Mtetra
.42422 .53908 .43 .54471 .4399 .54157 .43414 .53592 Mtetra
.43414 .53592 .4399 .54157 .44984 .53842 .4441 .53275 Mtetra
.658 .753 .92 r
.4441 .53275 .44984 .53842 .45981 .53527 .4541 .52958 Mtetra
.4541 .52958 .45981 .53527 .46982 .53212 .46413 .5264 Mtetra
.46413 .5264 .46982 .53212 .47987 .52896 .4742 .52321 Mtetra
.4742 .52321 .47987 .52896 .48995 .52579 .4843 .52002 Mtetra
.4843 .52002 .48995 .52579 .50007 .52261 .49445 .51682 Mtetra
.49445 .51682 .50007 .52261 .51022 .51942 .50463 .51361 Mtetra
.50463 .51361 .51022 .51942 .52042 .51622 .51484 .51038 Mtetra
.657 .753 .92 r
.51484 .51038 .52042 .51622 .53065 .51301 .5251 .50715 Mtetra
.5251 .50715 .53065 .51301 .54092 .50979 .5354 .50391 Mtetra
.657 .752 .92 r
.5354 .50391 .54092 .50979 .55122 .50656 .54573 .50066 Mtetra
.54573 .50066 .55122 .50656 .56157 .50332 .5561 .4974 Mtetra
.5561 .4974 .56157 .50332 .57195 .50007 .56651 .49412 Mtetra
.56651 .49412 .57195 .50007 .58238 .49681 .57696 .49084 Mtetra
.57696 .49084 .58238 .49681 .59284 .49354 .58745 .48754 Mtetra
.58745 .48754 .59284 .49354 .60334 .49025 .59797 .48423 Mtetra
.59797 .48423 .60334 .49025 .61388 .48696 .60854 .48091 Mtetra
.60854 .48091 .61388 .48696 .62446 .48365 .61915 .47758 Mtetra
.61915 .47758 .62446 .48365 .63508 .48033 .6298 .47424 Mtetra
.6298 .47424 .63508 .48033 .64574 .47699 .64049 .47088 Mtetra
.64049 .47088 .64574 .47699 .65644 .47365 .65121 .46751 Mtetra
.65121 .46751 .65644 .47365 .66718 .47029 .66198 .46413 Mtetra
.66198 .46413 .66718 .47029 .67797 .46693 .6728 .46074 Mtetra
.6728 .46074 .67797 .46693 .68879 .46355 .68365 .45734 Mtetra
.68365 .45734 .68879 .46355 .69966 .46015 .69454 .45392 Mtetra
.69454 .45392 .69966 .46015 .71056 .45675 .70548 .45049 Mtetra
.70548 .45049 .71056 .45675 .72151 .45333 .71646 .44705 Mtetra
.71646 .44705 .72151 .45333 .7325 .4499 .72748 .44359 Mtetra
.72748 .44359 .7325 .4499 .74353 .44645 .73854 .44012 Mtetra
.73854 .44012 .74353 .44645 .75461 .443 .74964 .43664 Mtetra
.74964 .43664 .75461 .443 .76573 .43953 .76079 .43314 Mtetra
.76079 .43314 .76573 .43953 .77689 .43604 .77199 .42964 Mtetra
.77199 .42964 .77689 .43604 .7881 .43255 .78322 .42611 Mtetra
.78322 .42611 .7881 .43255 .79934 .42904 .7945 .42258 Mtetra
.7945 .42258 .79934 .42904 .81064 .42551 .80583 .41903 Mtetra
.80583 .41903 .81064 .42551 .82197 .42198 .81719 .41547 Mtetra
.81719 .41547 .82197 .42198 .83335 .41843 .82861 .41189 Mtetra
.82861 .41189 .83335 .41843 .84478 .41486 .84006 .4083 Mtetra
.84006 .4083 .84478 .41486 .85625 .41129 .85157 .4047 Mtetra
.85157 .4047 .85625 .41129 .86777 .4077 .86312 .40108 Mtetra
.86312 .40108 .86777 .4077 .87933 .40409 .87471 .39745 Mtetra
.87471 .39745 .87933 .40409 .89093 .40047 .88635 .39381 Mtetra
.393 .122 .38 r
.26378 .58589 .27285 .55257 .27971 .58313 .27368 .57615 Mtetra
.56 .665 .908 r
.27368 .57615 .27971 .58313 .28904 .58118 .28294 .5754 Mtetra
.63 .732 .921 r
.28294 .5754 .28904 .58118 .29844 .5787 .29234 .57306 Mtetra
.639 .74 .921 r
.29234 .57306 .29844 .5787 .30788 .57614 .3018 .57049 Mtetra
.639 .74 .922 r
.3018 .57049 .30788 .57614 .31735 .57367 .3113 .56792 Mtetra
.625 .733 .925 r
.3113 .56792 .31735 .57367 .32681 .57207 .32081 .56565 Mtetra
.348 .591 .936 r
.32081 .56565 .32681 .57207 .33694 .55909 .33012 .56764 Mtetra
0 0 0 r
.33012 .56764 .33694 .55909 .34618 .56257 .34023 .55602 Mtetra
.595 .697 .914 r
.34023 .55602 .34618 .56257 .35578 .56024 .34981 .55444 Mtetra
.64 .738 .92 r
.34981 .55444 .35578 .56024 .36544 .55747 .35948 .5518 Mtetra
.649 .746 .92 r
.35948 .5518 .36544 .55747 .37514 .55455 .3692 .54892 Mtetra
.653 .749 .92 r
.3692 .54892 .37514 .55455 .38488 .55155 .37897 .54592 Mtetra
.656 .751 .92 r
.37897 .54592 .38488 .55155 .39466 .54848 .38877 .54286 Mtetra
.658 .753 .92 r
.38877 .54286 .39466 .54848 .40448 .54537 .39861 .53974 Mtetra
.659 .753 .92 r
.39861 .53974 .40448 .54537 .41433 .54224 .40848 .53659 Mtetra
.659 .754 .92 r
.40848 .53659 .41433 .54224 .42422 .53908 .41839 .53342 Mtetra
.41839 .53342 .42422 .53908 .43414 .53592 .42834 .53023 Mtetra
.42834 .53023 .43414 .53592 .4441 .53275 .43832 .52704 Mtetra
.659 .753 .92 r
.43832 .52704 .4441 .53275 .4541 .52958 .44834 .52384 Mtetra
.658 .753 .92 r
.44834 .52384 .4541 .52958 .46413 .5264 .4584 .52064 Mtetra
.4584 .52064 .46413 .5264 .4742 .52321 .46849 .51743 Mtetra
.46849 .51743 .4742 .52321 .4843 .52002 .47862 .51421 Mtetra
.47862 .51421 .4843 .52002 .49445 .51682 .48879 .51099 Mtetra
.48879 .51099 .49445 .51682 .50463 .51361 .49899 .50775 Mtetra
.49899 .50775 .50463 .51361 .51484 .51038 .50924 .50451 Mtetra
.657 .753 .92 r
.50924 .50451 .51484 .51038 .5251 .50715 .51952 .50125 Mtetra
.51952 .50125 .5251 .50715 .5354 .50391 .52984 .49799 Mtetra
.52984 .49799 .5354 .50391 .54573 .50066 .54019 .49471 Mtetra
.657 .752 .92 r
.54019 .49471 .54573 .50066 .5561 .4974 .55059 .49143 Mtetra
.55059 .49143 .5561 .4974 .56651 .49412 .56103 .48813 Mtetra
.56103 .48813 .56651 .49412 .57696 .49084 .5715 .48482 Mtetra
.5715 .48482 .57696 .49084 .58745 .48754 .58202 .4815 Mtetra
.58202 .4815 .58745 .48754 .59797 .48423 .59257 .47817 Mtetra
.59257 .47817 .59797 .48423 .60854 .48091 .60317 .47483 Mtetra
.60317 .47483 .60854 .48091 .61915 .47758 .6138 .47147 Mtetra
.6138 .47147 .61915 .47758 .6298 .47424 .62448 .4681 Mtetra
.62448 .4681 .6298 .47424 .64049 .47088 .63519 .46472 Mtetra
.63519 .46472 .64049 .47088 .65121 .46751 .64595 .46133 Mtetra
.64595 .46133 .65121 .46751 .66198 .46413 .65675 .45793 Mtetra
.65675 .45793 .66198 .46413 .6728 .46074 .66759 .45451 Mtetra
.66759 .45451 .6728 .46074 .68365 .45734 .67847 .45108 Mtetra
.67847 .45108 .68365 .45734 .69454 .45392 .68939 .44764 Mtetra
.68939 .44764 .69454 .45392 .70548 .45049 .70036 .44419 Mtetra
.70036 .44419 .70548 .45049 .71646 .44705 .71136 .44072 Mtetra
.71136 .44072 .71646 .44705 .72748 .44359 .72241 .43724 Mtetra
.72241 .43724 .72748 .44359 .73854 .44012 .73351 .43374 Mtetra
.73351 .43374 .73854 .44012 .74964 .43664 .74464 .43024 Mtetra
.74464 .43024 .74964 .43664 .76079 .43314 .75582 .42672 Mtetra
.75582 .42672 .76079 .43314 .77199 .42964 .76704 .42318 Mtetra
.76704 .42318 .77199 .42964 .78322 .42611 .77831 .41964 Mtetra
.77831 .41964 .78322 .42611 .7945 .42258 .78962 .41607 Mtetra
.78962 .41607 .7945 .42258 .80583 .41903 .80098 .4125 Mtetra
.80098 .4125 .80583 .41903 .81719 .41547 .81238 .40891 Mtetra
.81238 .40891 .81719 .41547 .82861 .41189 .82382 .40531 Mtetra
.82382 .40531 .82861 .41189 .84006 .4083 .83531 .40169 Mtetra
.83531 .40169 .84006 .4083 .85157 .4047 .84685 .39807 Mtetra
.84685 .39807 .85157 .4047 .86312 .40108 .85843 .39442 Mtetra
.85843 .39442 .86312 .40108 .87471 .39745 .87006 .39076 Mtetra
.87006 .39076 .87471 .39745 .88635 .39381 .88173 .38709 Mtetra
.9 .711 .638 r
.25773 .57835 .26378 .58589 .27368 .57615 .26993 .53867 Mtetra
0 0 .465 r
.26993 .53867 .27368 .57615 .28294 .5754 .27681 .56933 Mtetra
.614 .718 .919 r
.27681 .56933 .28294 .5754 .29234 .57306 .28621 .56733 Mtetra
.636 .737 .921 r
.28621 .56733 .29234 .57306 .3018 .57049 .29569 .56481 Mtetra
.64 .74 .922 r
.29569 .56481 .3018 .57049 .3113 .56792 .30521 .56219 Mtetra
.635 .738 .923 r
.30521 .56219 .3113 .56792 .32081 .56565 .31475 .55968 Mtetra
.594 .717 .93 r
.31475 .55968 .32081 .56565 .33012 .56764 .32428 .55803 Mtetra
.803 .689 .739 r
.32428 .55803 .33012 .56764 .34023 .55602 .3345 .54496 Mtetra
.392 .477 .828 r
.3345 .54496 .34023 .55602 .34981 .55444 .34381 .54842 Mtetra
.628 .728 .919 r
.34381 .54842 .34981 .55444 .35948 .5518 .35349 .54603 Mtetra
.646 .743 .92 r
.35349 .54603 .35948 .5518 .3692 .54892 .36323 .54322 Mtetra
.652 .748 .92 r
.36323 .54322 .3692 .54892 .37897 .54592 .37301 .54025 Mtetra
.655 .75 .92 r
.37301 .54025 .37897 .54592 .38877 .54286 .38283 .53719 Mtetra
.657 .752 .92 r
.38283 .53719 .38877 .54286 .39861 .53974 .39269 .53407 Mtetra
.658 .753 .92 r
.39269 .53407 .39861 .53974 .40848 .53659 .40259 .53091 Mtetra
.659 .754 .92 r
.40259 .53091 .40848 .53659 .41839 .53342 .41252 .52772 Mtetra
.41252 .52772 .41839 .53342 .42834 .53023 .4225 .52451 Mtetra
.4225 .52451 .42834 .53023 .43832 .52704 .4325 .52129 Mtetra
.4325 .52129 .43832 .52704 .44834 .52384 .44255 .51807 Mtetra
.658 .753 .92 r
.44255 .51807 .44834 .52384 .4584 .52064 .45263 .51484 Mtetra
.45263 .51484 .4584 .52064 .46849 .51743 .46274 .51161 Mtetra
.46274 .51161 .46849 .51743 .47862 .51421 .4729 .50837 Mtetra
.4729 .50837 .47862 .51421 .48879 .51099 .48309 .50512 Mtetra
.48309 .50512 .48879 .51099 .49899 .50775 .49332 .50186 Mtetra
.49332 .50186 .49899 .50775 .50924 .50451 .50359 .49859 Mtetra
.50359 .49859 .50924 .50451 .51952 .50125 .51389 .49531 Mtetra
.657 .753 .92 r
.51389 .49531 .51952 .50125 .52984 .49799 .52424 .49203 Mtetra
.52424 .49203 .52984 .49799 .54019 .49471 .53462 .48873 Mtetra
.657 .752 .92 r
.53462 .48873 .54019 .49471 .55059 .49143 .54505 .48542 Mtetra
.54505 .48542 .55059 .49143 .56103 .48813 .55551 .4821 Mtetra
.55551 .4821 .56103 .48813 .5715 .48482 .56601 .47876 Mtetra
.56601 .47876 .5715 .48482 .58202 .4815 .57655 .47542 Mtetra
.57655 .47542 .58202 .4815 .59257 .47817 .58713 .47207 Mtetra
.58713 .47207 .59257 .47817 .60317 .47483 .59775 .4687 Mtetra
.59775 .4687 .60317 .47483 .6138 .47147 .60842 .46532 Mtetra
.60842 .46532 .6138 .47147 .62448 .4681 .61912 .46193 Mtetra
.61912 .46193 .62448 .4681 .63519 .46472 .62986 .45852 Mtetra
.62986 .45852 .63519 .46472 .64595 .46133 .64065 .45511 Mtetra
.64065 .45511 .64595 .46133 .65675 .45793 .65147 .45168 Mtetra
.65147 .45168 .65675 .45793 .66759 .45451 .66234 .44824 Mtetra
.66234 .44824 .66759 .45451 .67847 .45108 .67325 .44478 Mtetra
.67325 .44478 .67847 .45108 .68939 .44764 .6842 .44132 Mtetra
.6842 .44132 .68939 .44764 .70036 .44419 .6952 .43784 Mtetra
.6952 .43784 .70036 .44419 .71136 .44072 .70623 .43434 Mtetra
.70623 .43434 .71136 .44072 .72241 .43724 .71731 .43084 Mtetra
.71731 .43084 .72241 .43724 .73351 .43374 .72844 .42732 Mtetra
.72844 .42732 .73351 .43374 .74464 .43024 .7396 .42379 Mtetra
.7396 .42379 .74464 .43024 .75582 .42672 .75081 .42024 Mtetra
.75081 .42024 .75582 .42672 .76704 .42318 .76207 .41668 Mtetra
.76207 .41668 .76704 .42318 .77831 .41964 .77337 .41311 Mtetra
.77337 .41311 .77831 .41964 .78962 .41607 .78471 .40952 Mtetra
.78471 .40952 .78962 .41607 .80098 .4125 .7961 .40592 Mtetra
.7961 .40592 .80098 .4125 .81238 .40891 .80753 .40231 Mtetra
.80753 .40231 .81238 .40891 .82382 .40531 .81901 .39868 Mtetra
.81901 .39868 .82382 .40531 .83531 .40169 .83053 .39504 Mtetra
.83053 .39504 .83531 .40169 .84685 .39807 .8421 .39138 Mtetra
.8421 .39138 .84685 .39807 .85843 .39442 .85371 .38771 Mtetra
.85371 .38771 .85843 .39442 .87006 .39076 .86537 .38403 Mtetra
.86537 .38403 .87006 .39076 .88173 .38709 .87708 .38033 Mtetra
.504 .674 .94 r
.25154 .57216 .25773 .57835 .26993 .53867 .26074 .57207 Mtetra
.387 .115 .374 r
.26074 .57207 .26993 .53867 .27681 .56933 .27073 .56224 Mtetra
.559 .665 .908 r
.27073 .56224 .27681 .56933 .28621 .56733 .28005 .56146 Mtetra
.63 .732 .921 r
.28005 .56146 .28621 .56733 .29569 .56481 .28953 .55907 Mtetra
.639 .74 .921 r
.28953 .55907 .29569 .56481 .30521 .56219 .29907 .55645 Mtetra
.639 .74 .922 r
.29907 .55645 .30521 .56219 .31475 .55968 .30864 .55383 Mtetra
.625 .733 .925 r
.30864 .55383 .31475 .55968 .32428 .55803 .31823 .55152 Mtetra
.349 .592 .936 r
.31823 .55152 .32428 .55803 .3345 .54496 .32761 .55347 Mtetra
0 0 0 r
.32761 .55347 .3345 .54496 .34381 .54842 .33781 .54177 Mtetra
.595 .697 .914 r
.33781 .54177 .34381 .54842 .35349 .54603 .34747 .54014 Mtetra
.64 .738 .92 r
.34747 .54014 .35349 .54603 .36323 .54322 .35722 .53745 Mtetra
.649 .746 .92 r
.35722 .53745 .36323 .54322 .37301 .54025 .36702 .53451 Mtetra
.653 .749 .92 r
.36702 .53451 .37301 .54025 .38283 .53719 .37686 .53147 Mtetra
.656 .751 .92 r
.37686 .53147 .38283 .53719 .39269 .53407 .38674 .52835 Mtetra
.658 .753 .92 r
.38674 .52835 .39269 .53407 .40259 .53091 .39666 .52518 Mtetra
.659 .753 .92 r
.39666 .52518 .40259 .53091 .41252 .52772 .40662 .52197 Mtetra
.659 .754 .92 r
.40662 .52197 .41252 .52772 .4225 .52451 .41661 .51875 Mtetra
.41661 .51875 .4225 .52451 .4325 .52129 .42664 .51551 Mtetra
.42664 .51551 .4325 .52129 .44255 .51807 .43671 .51226 Mtetra
.659 .753 .92 r
.43671 .51226 .44255 .51807 .45263 .51484 .44681 .509 Mtetra
.658 .753 .92 r
.44681 .509 .45263 .51484 .46274 .51161 .45696 .50574 Mtetra
.45696 .50574 .46274 .51161 .4729 .50837 .46713 .50248 Mtetra
.46713 .50248 .4729 .50837 .48309 .50512 .47735 .49921 Mtetra
.47735 .49921 .48309 .50512 .49332 .50186 .48761 .49592 Mtetra
.48761 .49592 .49332 .50186 .50359 .49859 .4979 .49263 Mtetra
.4979 .49263 .50359 .49859 .51389 .49531 .50823 .48933 Mtetra
.657 .753 .92 r
.50823 .48933 .51389 .49531 .52424 .49203 .5186 .48602 Mtetra
.5186 .48602 .52424 .49203 .53462 .48873 .52901 .4827 Mtetra
.52901 .4827 .53462 .48873 .54505 .48542 .53946 .47937 Mtetra
.657 .752 .92 r
.53946 .47937 .54505 .48542 .55551 .4821 .54995 .47602 Mtetra
.54995 .47602 .55551 .4821 .56601 .47876 .56048 .47266 Mtetra
.56048 .47266 .56601 .47876 .57655 .47542 .57105 .4693 Mtetra
.57105 .4693 .57655 .47542 .58713 .47207 .58165 .46592 Mtetra
.58165 .46592 .58713 .47207 .59775 .4687 .5923 .46253 Mtetra
.5923 .46253 .59775 .4687 .60842 .46532 .60299 .45912 Mtetra
.60299 .45912 .60842 .46532 .61912 .46193 .61372 .45571 Mtetra
.61372 .45571 .61912 .46193 .62986 .45852 .62449 .45228 Mtetra
.62449 .45228 .62986 .45852 .64065 .45511 .63531 .44884 Mtetra
.63531 .44884 .64065 .45511 .65147 .45168 .64616 .44538 Mtetra
.64616 .44538 .65147 .45168 .66234 .44824 .65706 .44192 Mtetra
.65706 .44192 .66234 .44824 .67325 .44478 .668 .43844 Mtetra
.668 .43844 .67325 .44478 .6842 .44132 .67898 .43495 Mtetra
.67898 .43495 .6842 .44132 .6952 .43784 .69 .43144 Mtetra
.69 .43144 .6952 .43784 .70623 .43434 .70107 .42793 Mtetra
.70107 .42793 .70623 .43434 .71731 .43084 .71218 .42439 Mtetra
.71218 .42439 .71731 .43084 .72844 .42732 .72333 .42085 Mtetra
.72333 .42085 .72844 .42732 .7396 .42379 .73453 .41729 Mtetra
.73453 .41729 .7396 .42379 .75081 .42024 .74577 .41372 Mtetra
.74577 .41372 .75081 .42024 .76207 .41668 .75706 .41014 Mtetra
.75706 .41014 .76207 .41668 .77337 .41311 .76839 .40654 Mtetra
.76839 .40654 .77337 .41311 .78471 .40952 .77976 .40292 Mtetra
.77976 .40292 .78471 .40952 .7961 .40592 .79118 .3993 Mtetra
.79118 .3993 .7961 .40592 .80753 .40231 .80264 .39566 Mtetra
.80264 .39566 .80753 .40231 .81901 .39868 .81415 .392 Mtetra
.81415 .392 .81901 .39868 .83053 .39504 .82571 .38833 Mtetra
.82571 .38833 .83053 .39504 .8421 .39138 .83731 .38465 Mtetra
.83731 .38465 .8421 .39138 .85371 .38771 .84896 .38095 Mtetra
.84896 .38095 .85371 .38771 .86537 .38403 .86066 .37724 Mtetra
.86066 .37724 .86537 .38403 .87708 .38033 .8724 .37351 Mtetra
.602 .72 .928 r
.24528 .56623 .25154 .57216 .26074 .57207 .25463 .56443 Mtetra
.901 .711 .637 r
.25463 .56443 .26074 .57207 .27073 .56224 .26696 .52454 Mtetra
0 0 .461 r
.26696 .52454 .27073 .56224 .28005 .56146 .27387 .55529 Mtetra
.614 .718 .919 r
.27387 .55529 .28005 .56146 .28953 .55907 .28334 .55324 Mtetra
.636 .737 .921 r
.28334 .55324 .28953 .55907 .29907 .55645 .29289 .55067 Mtetra
.64 .74 .922 r
.29289 .55067 .29907 .55645 .30864 .55383 .30249 .548 Mtetra
.635 .738 .923 r
.30249 .548 .30864 .55383 .31823 .55152 .31211 .54545 Mtetra
.594 .717 .93 r
.31211 .54545 .31823 .55152 .32761 .55347 .32172 .54375 Mtetra
.804 .69 .739 r
.32172 .54375 .32761 .55347 .33781 .54177 .33203 .53058 Mtetra
.391 .477 .828 r
.33203 .53058 .33781 .54177 .34747 .54014 .34141 .53402 Mtetra
.628 .728 .919 r
.34141 .53402 .34747 .54014 .35722 .53745 .35117 .53158 Mtetra
.646 .743 .92 r
.35117 .53158 .35722 .53745 .36702 .53451 .36098 .52871 Mtetra
.652 .748 .92 r
.36098 .52871 .36702 .53451 .37686 .53147 .37085 .52569 Mtetra
.655 .75 .92 r
.37085 .52569 .37686 .53147 .38674 .52835 .38075 .52258 Mtetra
.657 .752 .92 r
.38075 .52258 .38674 .52835 .39666 .52518 .39069 .51941 Mtetra
.658 .753 .92 r
.39069 .51941 .39666 .52518 .40662 .52197 .40067 .51619 Mtetra
.659 .754 .92 r
.40067 .51619 .40662 .52197 .41661 .51875 .41069 .51294 Mtetra
.41069 .51294 .41661 .51875 .42664 .51551 .42074 .50968 Mtetra
.42074 .50968 .42664 .51551 .43671 .51226 .43083 .50641 Mtetra
.43083 .50641 .43671 .51226 .44681 .509 .44096 .50313 Mtetra
.658 .753 .92 r
.44096 .50313 .44681 .509 .45696 .50574 .45113 .49984 Mtetra
.45113 .49984 .45696 .50574 .46713 .50248 .46133 .49655 Mtetra
.46133 .49655 .46713 .50248 .47735 .49921 .47157 .49326 Mtetra
.47157 .49326 .47735 .49921 .48761 .49592 .48185 .48995 Mtetra
.48185 .48995 .48761 .49592 .4979 .49263 .49217 .48663 Mtetra
.49217 .48663 .4979 .49263 .50823 .48933 .50253 .48331 Mtetra
.50253 .48331 .50823 .48933 .5186 .48602 .51293 .47997 Mtetra
.657 .753 .92 r
.51293 .47997 .5186 .48602 .52901 .4827 .52336 .47663 Mtetra
.52336 .47663 .52901 .4827 .53946 .47937 .53384 .47327 Mtetra
.657 .752 .92 r
.53384 .47327 .53946 .47937 .54995 .47602 .54435 .4699 Mtetra
.54435 .4699 .54995 .47602 .56048 .47266 .55491 .46652 Mtetra
.55491 .46652 .56048 .47266 .57105 .4693 .5655 .46313 Mtetra
.5655 .46313 .57105 .4693 .58165 .46592 .57614 .45973 Mtetra
.57614 .45973 .58165 .46592 .5923 .46253 .58681 .45631 Mtetra
.58681 .45631 .5923 .46253 .60299 .45912 .59753 .45288 Mtetra
.59753 .45288 .60299 .45912 .61372 .45571 .60829 .44944 Mtetra
.60829 .44944 .61372 .45571 .62449 .45228 .61909 .44599 Mtetra
.61909 .44599 .62449 .45228 .63531 .44884 .62993 .44252 Mtetra
.62993 .44252 .63531 .44884 .64616 .44538 .64081 .43905 Mtetra
.64081 .43905 .64616 .44538 .65706 .44192 .65174 .43556 Mtetra
.65174 .43556 .65706 .44192 .668 .43844 .66271 .43205 Mtetra
.66271 .43205 .668 .43844 .67898 .43495 .67372 .42853 Mtetra
.67372 .42853 .67898 .43495 .69 .43144 .68477 .425 Mtetra
.68477 .425 .69 .43144 .70107 .42793 .69587 .42146 Mtetra
.69587 .42146 .70107 .42793 .71218 .42439 .70701 .4179 Mtetra
.70701 .4179 .71218 .42439 .72333 .42085 .71819 .41433 Mtetra
.71819 .41433 .72333 .42085 .73453 .41729 .72942 .41075 Mtetra
.72942 .41075 .73453 .41729 .74577 .41372 .74069 .40715 Mtetra
.74069 .40715 .74577 .41372 .75706 .41014 .75201 .40354 Mtetra
.75201 .40354 .75706 .41014 .76839 .40654 .76337 .39991 Mtetra
.76337 .39991 .76839 .40654 .77976 .40292 .77477 .39628 Mtetra
.77477 .39628 .77976 .40292 .79118 .3993 .78622 .39262 Mtetra
.78622 .39262 .79118 .3993 .80264 .39566 .79772 .38895 Mtetra
.79772 .38895 .80264 .39566 .81415 .392 .80926 .38527 Mtetra
.80926 .38527 .81415 .392 .82571 .38833 .82085 .38158 Mtetra
.82085 .38158 .82571 .38833 .83731 .38465 .83249 .37786 Mtetra
.83249 .37786 .83731 .38465 .84896 .38095 .84417 .37414 Mtetra
.84417 .37414 .84896 .38095 .86066 .37724 .8559 .3704 Mtetra
.8559 .3704 .86066 .37724 .8724 .37351 .86768 .36664 Mtetra
.621 .73 .924 r
.23898 .56035 .24528 .56623 .25463 .56443 .24838 .55814 Mtetra
.504 .674 .94 r
.24838 .55814 .25463 .56443 .26696 .52454 .25765 .55801 Mtetra
.381 .107 .368 r
.25765 .55801 .26696 .52454 .27387 .55529 .26772 .5481 Mtetra
.559 .665 .908 r
.26772 .5481 .27387 .55529 .28334 .55324 .27712 .54728 Mtetra
.63 .732 .921 r
.27712 .54728 .28334 .55324 .29289 .55067 .28668 .54484 Mtetra
.639 .74 .921 r
.28668 .54484 .29289 .55067 .30249 .548 .29629 .54217 Mtetra
.639 .74 .922 r
.29629 .54217 .30249 .548 .31211 .54545 .30594 .5395 Mtetra
.625 .733 .925 r
.30594 .5395 .31211 .54545 .32172 .54375 .3156 .53713 Mtetra
.351 .592 .936 r
.3156 .53713 .32172 .54375 .33203 .53058 .32505 .53906 Mtetra
0 0 0 r
.32505 .53906 .33203 .53058 .34141 .53402 .33535 .52726 Mtetra
.595 .697 .914 r
.33535 .52726 .34141 .53402 .35117 .53158 .34508 .52559 Mtetra
.64 .738 .92 r
.34508 .52559 .35117 .53158 .36098 .52871 .35491 .52284 Mtetra
.649 .746 .92 r
.35491 .52284 .36098 .52871 .37085 .52569 .36479 .51986 Mtetra
.653 .749 .92 r
.36479 .51986 .37085 .52569 .38075 .52258 .37472 .51676 Mtetra
.656 .751 .92 r
.37472 .51676 .38075 .52258 .39069 .51941 .38468 .51359 Mtetra
.658 .753 .92 r
.38468 .51359 .39069 .51941 .40067 .51619 .39468 .51036 Mtetra
.659 .753 .92 r
.39468 .51036 .40067 .51619 .41069 .51294 .40472 .5071 Mtetra
.659 .754 .92 r
.40472 .5071 .41069 .51294 .42074 .50968 .4148 .50382 Mtetra
.4148 .50382 .42074 .50968 .43083 .50641 .42492 .50052 Mtetra
.42492 .50052 .43083 .50641 .44096 .50313 .43507 .49721 Mtetra
.659 .753 .92 r
.43507 .49721 .44096 .50313 .45113 .49984 .44526 .4939 Mtetra
.658 .753 .92 r
.44526 .4939 .45113 .49984 .46133 .49655 .45549 .49059 Mtetra
.45549 .49059 .46133 .49655 .47157 .49326 .46576 .48727 Mtetra
.46576 .48727 .47157 .49326 .48185 .48995 .47606 .48393 Mtetra
.47606 .48393 .48185 .48995 .49217 .48663 .48641 .48059 Mtetra
.48641 .48059 .49217 .48663 .50253 .48331 .49679 .47725 Mtetra
.49679 .47725 .50253 .48331 .51293 .47997 .50721 .47389 Mtetra
.657 .753 .92 r
.50721 .47389 .51293 .47997 .52336 .47663 .51767 .47052 Mtetra
.51767 .47052 .52336 .47663 .53384 .47327 .52817 .46713 Mtetra
.52817 .46713 .53384 .47327 .54435 .4699 .53871 .46374 Mtetra
.657 .752 .92 r
.53871 .46374 .54435 .4699 .55491 .46652 .5493 .46034 Mtetra
.5493 .46034 .55491 .46652 .5655 .46313 .55992 .45692 Mtetra
.55992 .45692 .5655 .46313 .57614 .45973 .57058 .45349 Mtetra
.57058 .45349 .57614 .45973 .58681 .45631 .58128 .45005 Mtetra
.58128 .45005 .58681 .45631 .59753 .45288 .59203 .4466 Mtetra
.59203 .4466 .59753 .45288 .60829 .44944 .60281 .44313 Mtetra
.60281 .44313 .60829 .44944 .61909 .44599 .61364 .43966 Mtetra
.61364 .43966 .61909 .44599 .62993 .44252 .62451 .43617 Mtetra
.62451 .43617 .62993 .44252 .64081 .43905 .63542 .43266 Mtetra
.63542 .43266 .64081 .43905 .65174 .43556 .64638 .42915 Mtetra
.64638 .42915 .65174 .43556 .66271 .43205 .65738 .42562 Mtetra
.65738 .42562 .66271 .43205 .67372 .42853 .66842 .42207 Mtetra
.66842 .42207 .67372 .42853 .68477 .425 .6795 .41852 Mtetra
.6795 .41852 .68477 .425 .69587 .42146 .69063 .41495 Mtetra
.69063 .41495 .69587 .42146 .70701 .4179 .7018 .41137 Mtetra
.7018 .41137 .70701 .4179 .71819 .41433 .71301 .40777 Mtetra
.71301 .40777 .71819 .41433 .72942 .41075 .72427 .40416 Mtetra
.72427 .40416 .72942 .41075 .74069 .40715 .73557 .40053 Mtetra
.73557 .40053 .74069 .40715 .75201 .40354 .74692 .3969 Mtetra
.74692 .3969 .75201 .40354 .76337 .39991 .75831 .39324 Mtetra
.75831 .39324 .76337 .39991 .77477 .39628 .76975 .38958 Mtetra
.76975 .38958 .77477 .39628 .78622 .39262 .78123 .3859 Mtetra
.78123 .3859 .78622 .39262 .79772 .38895 .79276 .3822 Mtetra
.79276 .3822 .79772 .38895 .80926 .38527 .80434 .37849 Mtetra
.80434 .37849 .80926 .38527 .82085 .38158 .81596 .37477 Mtetra
.81596 .37477 .82085 .38158 .83249 .37786 .82763 .37103 Mtetra
.82763 .37103 .83249 .37786 .84417 .37414 .83935 .36728 Mtetra
.83935 .36728 .84417 .37414 .8559 .3704 .85111 .36351 Mtetra
.85111 .36351 .8559 .3704 .86768 .36664 .86292 .35973 Mtetra
.626 .731 .923 r
.23263 .55445 .23898 .56035 .24838 .55814 .24206 .55211 Mtetra
.602 .72 .928 r
.24206 .55211 .24838 .55814 .25765 .55801 .25148 .55027 Mtetra
.902 .712 .636 r
.25148 .55027 .25765 .55801 .26772 .5481 .26394 .51017 Mtetra
0 0 .458 r
.26394 .51017 .26772 .5481 .27712 .54728 .27087 .54101 Mtetra
.614 .718 .919 r
.27087 .54101 .27712 .54728 .28668 .54484 .28042 .53892 Mtetra
.636 .737 .921 r
.28042 .53892 .28668 .54484 .29629 .54217 .29005 .53629 Mtetra
.64 .74 .922 r
.29005 .53629 .29629 .54217 .30594 .5395 .29972 .53357 Mtetra
.635 .738 .923 r
.29972 .53357 .30594 .5395 .3156 .53713 .30942 .53097 Mtetra
.594 .717 .93 r
.30942 .53097 .3156 .53713 .32505 .53906 .31911 .52922 Mtetra
.805 .691 .739 r
.31911 .52922 .32505 .53906 .33535 .52726 .32951 .51596 Mtetra
.39 .476 .828 r
.32951 .51596 .33535 .52726 .34508 .52559 .33896 .51936 Mtetra
.628 .728 .919 r
.33896 .51936 .34508 .52559 .35491 .52284 .3488 .51688 Mtetra
.646 .743 .92 r
.3488 .51688 .35491 .52284 .36479 .51986 .3587 .51396 Mtetra
.652 .748 .92 r
.3587 .51396 .36479 .51986 .37472 .51676 .36864 .51088 Mtetra
.655 .75 .92 r
.36864 .51088 .37472 .51676 .38468 .51359 .37863 .50771 Mtetra
.657 .752 .92 r
.37863 .50771 .38468 .51359 .39468 .51036 .38865 .50449 Mtetra
.658 .753 .92 r
.38865 .50449 .39468 .51036 .40472 .5071 .39872 .50121 Mtetra
.659 .754 .92 r
.39872 .50121 .40472 .5071 .4148 .50382 .40882 .49791 Mtetra
.40882 .49791 .4148 .50382 .42492 .50052 .41896 .49459 Mtetra
.41896 .49459 .42492 .50052 .43507 .49721 .42914 .49126 Mtetra
.42914 .49126 .43507 .49721 .44526 .4939 .43935 .48792 Mtetra
.658 .753 .92 r
.43935 .48792 .44526 .4939 .45549 .49059 .44961 .48458 Mtetra
.44961 .48458 .45549 .49059 .46576 .48727 .4599 .48123 Mtetra
.4599 .48123 .46576 .48727 .47606 .48393 .47023 .47788 Mtetra
.47023 .47788 .47606 .48393 .48641 .48059 .4806 .47451 Mtetra
.4806 .47451 .48641 .48059 .49679 .47725 .49101 .47114 Mtetra
.49101 .47114 .49679 .47725 .50721 .47389 .50145 .46775 Mtetra
.50145 .46775 .50721 .47389 .51767 .47052 .51194 .46436 Mtetra
.657 .753 .92 r
.51194 .46436 .51767 .47052 .52817 .46713 .52247 .46095 Mtetra
.52247 .46095 .52817 .46713 .53871 .46374 .53304 .45754 Mtetra
.657 .752 .92 r
.53304 .45754 .53871 .46374 .5493 .46034 .54364 .45411 Mtetra
.54364 .45411 .5493 .46034 .55992 .45692 .55429 .45067 Mtetra
.55429 .45067 .55992 .45692 .57058 .45349 .56498 .44721 Mtetra
.56498 .44721 .57058 .45349 .58128 .45005 .57571 .44375 Mtetra
.57571 .44375 .58128 .45005 .59203 .4466 .58649 .44027 Mtetra
.58649 .44027 .59203 .4466 .60281 .44313 .5973 .43678 Mtetra
.5973 .43678 .60281 .44313 .61364 .43966 .60816 .43328 Mtetra
.60816 .43328 .61364 .43966 .62451 .43617 .61906 .42976 Mtetra
.61906 .42976 .62451 .43617 .63542 .43266 .63 .42623 Mtetra
.63 .42623 .63542 .43266 .64638 .42915 .64098 .42269 Mtetra
.64098 .42269 .64638 .42915 .65738 .42562 .65201 .41913 Mtetra
.65201 .41913 .65738 .42562 .66842 .42207 .66308 .41557 Mtetra
.66308 .41557 .66842 .42207 .6795 .41852 .67419 .41198 Mtetra
.67419 .41198 .6795 .41852 .69063 .41495 .68535 .40839 Mtetra
.68535 .40839 .69063 .41495 .7018 .41137 .69655 .40478 Mtetra
.69655 .40478 .7018 .41137 .71301 .40777 .70779 .40116 Mtetra
.70779 .40116 .71301 .40777 .72427 .40416 .71908 .39752 Mtetra
.71908 .39752 .72427 .40416 .73557 .40053 .73042 .39387 Mtetra
.73042 .39387 .73557 .40053 .74692 .3969 .7418 .3902 Mtetra
.7418 .3902 .74692 .3969 .75831 .39324 .75322 .38652 Mtetra
.75322 .38652 .75831 .39324 .76975 .38958 .76469 .38283 Mtetra
.76469 .38283 .76975 .38958 .78123 .3859 .77621 .37912 Mtetra
.77621 .37912 .78123 .3859 .79276 .3822 .78777 .3754 Mtetra
.78777 .3754 .79276 .3822 .80434 .37849 .79938 .37166 Mtetra
.79938 .37166 .80434 .37849 .81596 .37477 .81103 .36791 Mtetra
.81103 .36791 .81596 .37477 .82763 .37103 .82274 .36415 Mtetra
.82274 .36415 .82763 .37103 .83935 .36728 .83449 .36036 Mtetra
.83449 .36036 .83935 .36728 .85111 .36351 .84628 .35657 Mtetra
.84628 .35657 .85111 .36351 .86292 .35973 .85813 .35276 Mtetra
.623 .728 .922 r
.22625 .54844 .23263 .55445 .24206 .55211 .23569 .54614 Mtetra
.621 .73 .924 r
.23569 .54614 .24206 .55211 .25148 .55027 .24516 .54388 Mtetra
.505 .674 .94 r
.24516 .54388 .25148 .55027 .26394 .51017 .25451 .54371 Mtetra
.375 .099 .361 r
.25451 .54371 .26394 .51017 .27087 .54101 .26466 .53372 Mtetra
.559 .665 .908 r
.26466 .53372 .27087 .54101 .28042 .53892 .27414 .53285 Mtetra
.63 .732 .921 r
.27414 .53285 .28042 .53892 .29005 .53629 .28377 .53036 Mtetra
.639 .74 .921 r
.28377 .53036 .29005 .53629 .29972 .53357 .29346 .52764 Mtetra
.639 .74 .922 r
.29346 .52764 .29972 .53357 .30942 .53097 .30319 .52492 Mtetra
.625 .733 .925 r
.30319 .52492 .30942 .53097 .31911 .52922 .31293 .5225 Mtetra
.352 .592 .936 r
.31293 .5225 .31911 .52922 .32951 .51596 .32246 .52439 Mtetra
0 0 0 r
.32246 .52439 .32951 .51596 .33896 .51936 .33284 .51251 Mtetra
.595 .697 .914 r
.33284 .51251 .33896 .51936 .3488 .51688 .34265 .51079 Mtetra
.64 .738 .92 r
.34265 .51079 .3488 .51688 .3587 .51396 .35257 .50799 Mtetra
.649 .746 .92 r
.35257 .50799 .3587 .51396 .36864 .51088 .36253 .50494 Mtetra
.653 .749 .92 r
.36253 .50494 .36864 .51088 .37863 .50771 .37254 .50179 Mtetra
.656 .751 .92 r
.37254 .50179 .37863 .50771 .38865 .50449 .38258 .49856 Mtetra
.658 .753 .92 r
.38258 .49856 .38865 .50449 .39872 .50121 .39267 .49528 Mtetra
.659 .753 .92 r
.39267 .49528 .39872 .50121 .40882 .49791 .4028 .49196 Mtetra
.659 .754 .92 r
.4028 .49196 .40882 .49791 .41896 .49459 .41296 .48862 Mtetra
.41296 .48862 .41896 .49459 .42914 .49126 .42316 .48527 Mtetra
.42316 .48527 .42914 .49126 .43935 .48792 .4334 .4819 Mtetra
.659 .753 .92 r
.4334 .4819 .43935 .48792 .44961 .48458 .44368 .47853 Mtetra
.658 .753 .92 r
.44368 .47853 .44961 .48458 .4599 .48123 .454 .47516 Mtetra
.454 .47516 .4599 .48123 .47023 .47788 .46435 .47178 Mtetra
.46435 .47178 .47023 .47788 .4806 .47451 .47475 .46839 Mtetra
.47475 .46839 .4806 .47451 .49101 .47114 .48518 .46499 Mtetra
.48518 .46499 .49101 .47114 .50145 .46775 .49566 .46158 Mtetra
.49566 .46158 .50145 .46775 .51194 .46436 .50617 .45816 Mtetra
.657 .753 .92 r
.50617 .45816 .51194 .46436 .52247 .46095 .51672 .45473 Mtetra
.51672 .45473 .52247 .46095 .53304 .45754 .52732 .45129 Mtetra
.52732 .45129 .53304 .45754 .54364 .45411 .53795 .44783 Mtetra
.657 .752 .92 r
.53795 .44783 .54364 .45411 .55429 .45067 .54863 .44437 Mtetra
.54863 .44437 .55429 .45067 .56498 .44721 .55935 .44089 Mtetra
.55935 .44089 .56498 .44721 .57571 .44375 .57011 .4374 Mtetra
.57011 .4374 .57571 .44375 .58649 .44027 .58091 .4339 Mtetra
.58091 .4339 .58649 .44027 .5973 .43678 .59175 .43038 Mtetra
.59175 .43038 .5973 .43678 .60816 .43328 .60263 .42685 Mtetra
.60263 .42685 .60816 .43328 .61906 .42976 .61356 .42331 Mtetra
.61356 .42331 .61906 .42976 .63 .42623 .62453 .41975 Mtetra
.62453 .41975 .63 .42623 .64098 .42269 .63554 .41619 Mtetra
.63554 .41619 .64098 .42269 .65201 .41913 .6466 .41261 Mtetra
.6466 .41261 .65201 .41913 .66308 .41557 .6577 .40901 Mtetra
.6577 .40901 .66308 .41557 .67419 .41198 .66884 .4054 Mtetra
.66884 .4054 .67419 .41198 .68535 .40839 .68003 .40178 Mtetra
.68003 .40178 .68535 .40839 .69655 .40478 .69126 .39815 Mtetra
.69126 .39815 .69655 .40478 .70779 .40116 .70254 .3945 Mtetra
.70254 .3945 .70779 .40116 .71908 .39752 .71386 .39083 Mtetra
.71386 .39083 .71908 .39752 .73042 .39387 .72522 .38715 Mtetra
.72522 .38715 .73042 .39387 .7418 .3902 .73663 .38346 Mtetra
.73663 .38346 .7418 .3902 .75322 .38652 .74809 .37976 Mtetra
.74809 .37976 .75322 .38652 .76469 .38283 .75959 .37603 Mtetra
.75959 .37603 .76469 .38283 .77621 .37912 .77114 .3723 Mtetra
.77114 .3723 .77621 .37912 .78777 .3754 .78274 .36855 Mtetra
.78274 .36855 .78777 .3754 .79938 .37166 .79438 .36478 Mtetra
.79438 .36478 .79938 .37166 .81103 .36791 .80607 .361 Mtetra
.80607 .361 .81103 .36791 .82274 .36415 .8178 .35721 Mtetra
.8178 .35721 .82274 .36415 .83449 .36036 .82959 .3534 Mtetra
.82959 .3534 .83449 .36036 .84628 .35657 .84142 .34958 Mtetra
.84142 .34958 .84628 .35657 .85813 .35276 .8533 .34573 Mtetra
.611 .717 .921 r
.21984 .54219 .22625 .54844 .23569 .54614 .22928 .54014 Mtetra
.626 .731 .923 r
.22928 .54014 .23569 .54614 .24516 .54388 .23878 .53775 Mtetra
.602 .72 .928 r
.23878 .53775 .24516 .54388 .25451 .54371 .24828 .53586 Mtetra
.903 .713 .636 r
.24828 .53586 .25451 .54371 .26466 .53372 .26087 .49555 Mtetra
0 0 .454 r
.26087 .49555 .26466 .53372 .27414 .53285 .26783 .52648 Mtetra
.614 .718 .919 r
.26783 .52648 .27414 .53285 .28377 .53036 .27745 .52434 Mtetra
.636 .737 .921 r
.27745 .52434 .28377 .53036 .29346 .52764 .28716 .52166 Mtetra
.64 .74 .922 r
.28716 .52166 .29346 .52764 .30319 .52492 .29691 .51889 Mtetra
.635 .738 .923 r
.29691 .51889 .30319 .52492 .31293 .5225 .30669 .51623 Mtetra
.594 .717 .93 r
.30669 .51623 .31293 .5225 .32246 .52439 .31645 .51444 Mtetra
.805 .691 .739 r
.31645 .51444 .32246 .52439 .33284 .51251 .32695 .50108 Mtetra
.389 .476 .828 r
.32695 .50108 .33284 .51251 .34265 .51079 .33647 .50446 Mtetra
.628 .728 .919 r
.33647 .50446 .34265 .51079 .35257 .50799 .34639 .50192 Mtetra
.646 .743 .92 r
.34639 .50192 .35257 .50799 .36253 .50494 .35637 .49894 Mtetra
.652 .748 .92 r
.35637 .49894 .36253 .50494 .37254 .50179 .3664 .49581 Mtetra
.655 .75 .92 r
.3664 .49581 .37254 .50179 .38258 .49856 .37647 .49259 Mtetra
.657 .752 .92 r
.37647 .49259 .38258 .49856 .39267 .49528 .38658 .4893 Mtetra
.658 .753 .92 r
.38658 .4893 .39267 .49528 .4028 .49196 .39673 .48597 Mtetra
.659 .754 .92 r
.39673 .48597 .4028 .49196 .41296 .48862 .40692 .48261 Mtetra
.40692 .48261 .41296 .48862 .42316 .48527 .41715 .47923 Mtetra
.41715 .47923 .42316 .48527 .4334 .4819 .42741 .47584 Mtetra
.42741 .47584 .4334 .4819 .44368 .47853 .43771 .47245 Mtetra
.658 .753 .92 r
.43771 .47245 .44368 .47853 .454 .47516 .44806 .46905 Mtetra
.44806 .46905 .454 .47516 .46435 .47178 .45844 .46564 Mtetra
.45844 .46564 .46435 .47178 .47475 .46839 .46886 .46222 Mtetra
.46886 .46222 .47475 .46839 .48518 .46499 .47932 .4588 Mtetra
.47932 .4588 .48518 .46499 .49566 .46158 .48982 .45536 Mtetra
.48982 .45536 .49566 .46158 .50617 .45816 .50036 .45192 Mtetra
.50036 .45192 .50617 .45816 .51672 .45473 .51094 .44846 Mtetra
.657 .753 .92 r
.51094 .44846 .51672 .45473 .52732 .45129 .52156 .44499 Mtetra
.52156 .44499 .52732 .45129 .53795 .44783 .53222 .44151 Mtetra
.657 .752 .92 r
.53222 .44151 .53795 .44783 .54863 .44437 .54293 .43802 Mtetra
.54293 .43802 .54863 .44437 .55935 .44089 .55367 .43452 Mtetra
.55367 .43452 .55935 .44089 .57011 .4374 .56446 .431 Mtetra
.56446 .431 .57011 .4374 .58091 .4339 .57528 .42747 Mtetra
.57528 .42747 .58091 .4339 .59175 .43038 .58616 .42393 Mtetra
.58616 .42393 .59175 .43038 .60263 .42685 .59707 .42038 Mtetra
.59707 .42038 .60263 .42685 .61356 .42331 .60802 .41681 Mtetra
.60802 .41681 .61356 .42331 .62453 .41975 .61902 .41323 Mtetra
.61902 .41323 .62453 .41975 .63554 .41619 .63007 .40964 Mtetra
.63007 .40964 .63554 .41619 .6466 .41261 .64115 .40603 Mtetra
.64115 .40603 .6466 .41261 .6577 .40901 .65228 .40241 Mtetra
.65228 .40241 .6577 .40901 .66884 .4054 .66345 .39877 Mtetra
.66345 .39877 .66884 .4054 .68003 .40178 .67467 .39512 Mtetra
.67467 .39512 .68003 .40178 .69126 .39815 .68593 .39146 Mtetra
.68593 .39146 .69126 .39815 .70254 .3945 .69724 .38779 Mtetra
.69724 .38779 .70254 .3945 .71386 .39083 .70859 .38409 Mtetra
.70859 .38409 .71386 .39083 .72522 .38715 .71999 .38039 Mtetra
.71999 .38039 .72522 .38715 .73663 .38346 .73143 .37667 Mtetra
.73143 .37667 .73663 .38346 .74809 .37976 .74292 .37294 Mtetra
.74292 .37294 .74809 .37976 .75959 .37603 .75446 .36919 Mtetra
.75446 .36919 .75959 .37603 .77114 .3723 .76604 .36542 Mtetra
.76604 .36542 .77114 .3723 .78274 .36855 .77767 .36165 Mtetra
.77767 .36165 .78274 .36855 .79438 .36478 .78934 .35785 Mtetra
.78934 .35785 .79438 .36478 .80607 .361 .80107 .35404 Mtetra
.80107 .35404 .80607 .361 .8178 .35721 .81284 .35022 Mtetra
.81284 .35022 .8178 .35721 .82959 .3534 .82465 .34638 Mtetra
.82465 .34638 .82959 .3534 .84142 .34958 .83652 .34253 Mtetra
.83652 .34253 .84142 .34958 .8533 .34573 .84844 .33866 Mtetra
.568 .677 .913 r
.21347 .53513 .21984 .54219 .22928 .54014 .22283 .53403 Mtetra
.623 .728 .922 r
.22283 .53403 .22928 .54014 .23878 .53775 .23234 .53168 Mtetra
.621 .73 .924 r
.23234 .53168 .23878 .53775 .24828 .53586 .24189 .52937 Mtetra
.505 .674 .94 r
.24189 .52937 .24828 .53586 .26087 .49555 .25131 .52916 Mtetra
.368 .09 .355 r
.25131 .52916 .26087 .49555 .26783 .52648 .26155 .51909 Mtetra
.559 .665 .908 r
.26155 .51909 .26783 .52648 .27745 .52434 .2711 .51817 Mtetra
.63 .732 .921 r
.2711 .51817 .27745 .52434 .28716 .52166 .28081 .51563 Mtetra
.639 .74 .921 r
.28081 .51563 .28716 .52166 .29691 .51889 .29058 .51286 Mtetra
.639 .74 .922 r
.29058 .51286 .29691 .51889 .30669 .51623 .30039 .51008 Mtetra
.625 .733 .925 r
.30039 .51008 .30669 .51623 .31645 .51444 .31021 .50761 Mtetra
.353 .593 .936 r
.31021 .50761 .31645 .51444 .32695 .50108 .31981 .50947 Mtetra
0 0 0 r
.31981 .50947 .32695 .50108 .33647 .50446 .33029 .49749 Mtetra
.595 .697 .914 r
.33029 .49749 .33647 .50446 .34639 .50192 .34018 .49572 Mtetra
.64 .738 .92 r
.34018 .49572 .34639 .50192 .35637 .49894 .35018 .49287 Mtetra
.649 .746 .92 r
.35018 .49287 .35637 .49894 .3664 .49581 .36022 .48977 Mtetra
.653 .749 .92 r
.36022 .48977 .3664 .49581 .37647 .49259 .37032 .48656 Mtetra
.656 .751 .92 r
.37032 .48656 .37647 .49259 .38658 .4893 .38045 .48327 Mtetra
.658 .753 .92 r
.38045 .48327 .38658 .4893 .39673 .48597 .39062 .47993 Mtetra
.659 .753 .92 r
.39062 .47993 .39673 .48597 .40692 .48261 .40083 .47655 Mtetra
.659 .754 .92 r
.40083 .47655 .40692 .48261 .41715 .47923 .41109 .47315 Mtetra
.41109 .47315 .41715 .47923 .42741 .47584 .42138 .46974 Mtetra
.42138 .46974 .42741 .47584 .43771 .47245 .4317 .46632 Mtetra
.659 .753 .92 r
.4317 .46632 .43771 .47245 .44806 .46905 .44207 .46289 Mtetra
.658 .753 .92 r
.44207 .46289 .44806 .46905 .45844 .46564 .45248 .45945 Mtetra
.45248 .45945 .45844 .46564 .46886 .46222 .46292 .45601 Mtetra
.46292 .45601 .46886 .46222 .47932 .4588 .47341 .45256 Mtetra
.47341 .45256 .47932 .4588 .48982 .45536 .48394 .4491 Mtetra
.48394 .4491 .48982 .45536 .50036 .45192 .4945 .44563 Mtetra
.4945 .44563 .50036 .45192 .51094 .44846 .50511 .44215 Mtetra
.657 .753 .92 r
.50511 .44215 .51094 .44846 .52156 .44499 .51576 .43866 Mtetra
.51576 .43866 .52156 .44499 .53222 .44151 .52645 .43515 Mtetra
.52645 .43515 .53222 .44151 .54293 .43802 .53718 .43163 Mtetra
.657 .752 .92 r
.53718 .43163 .54293 .43802 .55367 .43452 .54795 .4281 Mtetra
.54795 .4281 .55367 .43452 .56446 .431 .55877 .42456 Mtetra
.55877 .42456 .56446 .431 .57528 .42747 .56962 .42101 Mtetra
.56962 .42101 .57528 .42747 .58616 .42393 .58052 .41744 Mtetra
.58052 .41744 .58616 .42393 .59707 .42038 .59146 .41386 Mtetra
.59146 .41386 .59707 .42038 .60802 .41681 .60245 .41027 Mtetra
.60245 .41027 .60802 .41681 .61902 .41323 .61348 .40666 Mtetra
.61348 .40666 .61902 .41323 .63007 .40964 .62455 .40304 Mtetra
.62455 .40304 .63007 .40964 .64115 .40603 .63566 .39941 Mtetra
.63566 .39941 .64115 .40603 .65228 .40241 .64682 .39576 Mtetra
.64682 .39576 .65228 .40241 .66345 .39877 .65803 .3921 Mtetra
.65803 .3921 .66345 .39877 .67467 .39512 .66927 .38842 Mtetra
.66927 .38842 .67467 .39512 .68593 .39146 .68057 .38473 Mtetra
.68057 .38473 .68593 .39146 .69724 .38779 .69191 .38103 Mtetra
.69191 .38103 .69724 .38779 .70859 .38409 .70329 .37731 Mtetra
.70329 .37731 .70859 .38409 .71999 .38039 .71472 .37358 Mtetra
.71472 .37358 .71999 .38039 .73143 .37667 .72619 .36983 Mtetra
.72619 .36983 .73143 .37667 .74292 .37294 .73772 .36607 Mtetra
.73772 .36607 .74292 .37294 .75446 .36919 .74928 .36229 Mtetra
.74928 .36229 .75446 .36919 .76604 .36542 .7609 .3585 Mtetra
.7609 .3585 .76604 .36542 .77767 .36165 .77256 .35469 Mtetra
.77256 .35469 .77767 .36165 .78934 .35785 .78427 .35087 Mtetra
.78427 .35087 .78934 .35785 .80107 .35404 .79603 .34703 Mtetra
.79603 .34703 .80107 .35404 .81284 .35022 .80783 .34318 Mtetra
.80783 .34318 .81284 .35022 .82465 .34638 .81968 .33931 Mtetra
.81968 .33931 .82465 .34638 .83652 .34253 .83158 .33543 Mtetra
.83158 .33543 .83652 .34253 .84844 .33866 .84353 .33153 Mtetra
.158 .237 .696 r
.20799 .51822 .21347 .53513 .22283 .53403 .21636 .52768 Mtetra
.611 .718 .921 r
.21636 .52768 .22283 .53403 .23234 .53168 .22586 .52558 Mtetra
.626 .731 .923 r
.22586 .52558 .23234 .53168 .24189 .52937 .23544 .52314 Mtetra
.602 .72 .928 r
.23544 .52314 .24189 .52937 .25131 .52916 .24501 .5212 Mtetra
.904 .713 .635 r
.24501 .5212 .25131 .52916 .26155 .51909 .25775 .48068 Mtetra
0 0 .45 r
.25775 .48068 .26155 .51909 .2711 .51817 .26473 .5117 Mtetra
.614 .718 .919 r
.26473 .5117 .2711 .51817 .28081 .51563 .27443 .50951 Mtetra
.636 .737 .921 r
.27443 .50951 .28081 .51563 .29058 .51286 .28421 .50678 Mtetra
.64 .74 .922 r
.28421 .50678 .29058 .51286 .30039 .51008 .29404 .50395 Mtetra
.635 .738 .923 r
.29404 .50395 .30039 .51008 .31021 .50761 .3039 .50124 Mtetra
.594 .717 .929 r
.3039 .50124 .31021 .50761 .31981 .50947 .31375 .49939 Mtetra
.806 .692 .739 r
.31375 .49939 .31981 .50947 .33029 .49749 .32434 .48593 Mtetra
.388 .475 .828 r
.32434 .48593 .33029 .49749 .34018 .49572 .33394 .48928 Mtetra
.628 .728 .919 r
.33394 .48928 .34018 .49572 .35018 .49287 .34394 .48669 Mtetra
.646 .743 .92 r
.34394 .48669 .35018 .49287 .36022 .48977 .35401 .48366 Mtetra
.652 .748 .92 r
.35401 .48366 .36022 .48977 .37032 .48656 .36412 .48047 Mtetra
.655 .75 .92 r
.36412 .48047 .37032 .48656 .38045 .48327 .37427 .47719 Mtetra
.657 .752 .92 r
.37427 .47719 .38045 .48327 .39062 .47993 .38447 .47384 Mtetra
.658 .753 .92 r
.38447 .47384 .39062 .47993 .40083 .47655 .39471 .47045 Mtetra
.659 .754 .92 r
.39471 .47045 .40083 .47655 .41109 .47315 .40498 .46703 Mtetra
.40498 .46703 .41109 .47315 .42138 .46974 .4153 .46359 Mtetra
.4153 .46359 .42138 .46974 .4317 .46632 .42565 .46015 Mtetra
.42565 .46015 .4317 .46632 .44207 .46289 .43604 .45669 Mtetra
.658 .753 .92 r
.43604 .45669 .44207 .46289 .45248 .45945 .44648 .45323 Mtetra
.44648 .45323 .45248 .45945 .46292 .45601 .45695 .44976 Mtetra
.45695 .44976 .46292 .45601 .47341 .45256 .46746 .44628 Mtetra
.46746 .44628 .47341 .45256 .48394 .4491 .47801 .4428 Mtetra
.47801 .4428 .48394 .4491 .4945 .44563 .48861 .4393 Mtetra
.48861 .4393 .4945 .44563 .50511 .44215 .49924 .43579 Mtetra
.49924 .43579 .50511 .44215 .51576 .43866 .50992 .43227 Mtetra
.657 .753 .92 r
.50992 .43227 .51576 .43866 .52645 .43515 .52063 .42874 Mtetra
.52063 .42874 .52645 .43515 .53718 .43163 .53139 .4252 Mtetra
.657 .752 .92 r
.53139 .4252 .53718 .43163 .54795 .4281 .54219 .42164 Mtetra
.54219 .42164 .54795 .4281 .55877 .42456 .55303 .41808 Mtetra
.55303 .41808 .55877 .42456 .56962 .42101 .56392 .41449 Mtetra
.56392 .41449 .56962 .42101 .58052 .41744 .57485 .4109 Mtetra
.57485 .4109 .58052 .41744 .59146 .41386 .58582 .40729 Mtetra
.58582 .40729 .59146 .41386 .60245 .41027 .59683 .40367 Mtetra
.59683 .40367 .60245 .41027 .61348 .40666 .60789 .40004 Mtetra
.60789 .40004 .61348 .40666 .62455 .40304 .61899 .39639 Mtetra
.61899 .39639 .62455 .40304 .63566 .39941 .63014 .39273 Mtetra
.63014 .39273 .63566 .39941 .64682 .39576 .64133 .38906 Mtetra
.64133 .38906 .64682 .39576 .65803 .3921 .65256 .38537 Mtetra
.65256 .38537 .65803 .3921 .66927 .38842 .66384 .38167 Mtetra
.66384 .38167 .66927 .38842 .68057 .38473 .67516 .37795 Mtetra
.67516 .37795 .68057 .38473 .69191 .38103 .68653 .37422 Mtetra
.68653 .37422 .69191 .38103 .70329 .37731 .69795 .37047 Mtetra
.69795 .37047 .70329 .37731 .71472 .37358 .70941 .36671 Mtetra
.70941 .36671 .71472 .37358 .72619 .36983 .72092 .36293 Mtetra
.72092 .36293 .72619 .36983 .73772 .36607 .73247 .35914 Mtetra
.73247 .35914 .73772 .36607 .74928 .36229 .74407 .35534 Mtetra
.74407 .35534 .74928 .36229 .7609 .3585 .75572 .35152 Mtetra
.75572 .35152 .7609 .3585 .77256 .35469 .76741 .34768 Mtetra
.76741 .34768 .77256 .35469 .78427 .35087 .77916 .34383 Mtetra
.77916 .34383 .78427 .35087 .79603 .34703 .79095 .33997 Mtetra
.79095 .33997 .79603 .34703 .80783 .34318 .80279 .33609 Mtetra
.80279 .33609 .80783 .34318 .81968 .33931 .81467 .33219 Mtetra
.81467 .33219 .81968 .33931 .83158 .33543 .82661 .32828 Mtetra
.82661 .32828 .83158 .33543 .84353 .33153 .8386 .32435 Mtetra
0 0 0 r
.19963 .53091 .20799 .51822 .21636 .52768 .20992 .52052 Mtetra
.567 .677 .913 r
.20992 .52052 .21636 .52768 .22586 .52558 .21935 .51937 Mtetra
.623 .728 .922 r
.21935 .51937 .22586 .52558 .23544 .52314 .22894 .51697 Mtetra
.621 .73 .924 r
.22894 .51697 .23544 .52314 .24501 .5212 .23856 .51461 Mtetra
.505 .674 .94 r
.23856 .51461 .24501 .5212 .25775 .48068 .24805 .51435 Mtetra
.361 .082 .348 r
.24805 .51435 .25775 .48068 .26473 .5117 .25839 .5042 Mtetra
.559 .665 .909 r
.25839 .5042 .26473 .5117 .27443 .50951 .26801 .50324 Mtetra
.63 .732 .921 r
.26801 .50324 .27443 .50951 .28421 .50678 .2778 .50064 Mtetra
.639 .74 .921 r
.2778 .50064 .28421 .50678 .29404 .50395 .28765 .49781 Mtetra
.639 .74 .922 r
.28765 .49781 .29404 .50395 .3039 .50124 .29754 .49498 Mtetra
.625 .733 .924 r
.29754 .49498 .3039 .50124 .31375 .49939 .30744 .49246 Mtetra
.355 .593 .936 r
.30744 .49246 .31375 .49939 .32434 .48593 .31712 .49428 Mtetra
0 0 0 r
.31712 .49428 .32434 .48593 .33394 .48928 .32769 .48221 Mtetra
.595 .697 .914 r
.32769 .48221 .33394 .48928 .34394 .48669 .33767 .48039 Mtetra
.64 .738 .92 r
.33767 .48039 .34394 .48669 .35401 .48366 .34775 .47747 Mtetra
.649 .746 .92 r
.34775 .47747 .35401 .48366 .36412 .48047 .35788 .47432 Mtetra
.653 .749 .92 r
.35788 .47432 .36412 .48047 .37427 .47719 .36806 .47105 Mtetra
.656 .751 .92 r
.36806 .47105 .37427 .47719 .38447 .47384 .37828 .4677 Mtetra
.658 .753 .92 r
.37828 .4677 .38447 .47384 .39471 .47045 .38854 .4643 Mtetra
.659 .753 .92 r
.38854 .4643 .39471 .47045 .40498 .46703 .39884 .46087 Mtetra
.659 .754 .92 r
.39884 .46087 .40498 .46703 .4153 .46359 .40918 .45741 Mtetra
.40918 .45741 .4153 .46359 .42565 .46015 .41956 .45393 Mtetra
.41956 .45393 .42565 .46015 .43604 .45669 .42997 .45045 Mtetra
.659 .753 .92 r
.42997 .45045 .43604 .45669 .44648 .45323 .44043 .44696 Mtetra
.658 .753 .92 r
.44043 .44696 .44648 .45323 .45695 .44976 .45093 .44346 Mtetra
.45093 .44346 .45695 .44976 .46746 .44628 .46147 .43996 Mtetra
.46147 .43996 .46746 .44628 .47801 .4428 .47205 .43645 Mtetra
.47205 .43645 .47801 .4428 .48861 .4393 .48267 .43292 Mtetra
.48267 .43292 .48861 .4393 .49924 .43579 .49333 .42939 Mtetra
.49333 .42939 .49924 .43579 .50992 .43227 .50403 .42584 Mtetra
.657 .753 .92 r
.50403 .42584 .50992 .43227 .52063 .42874 .51478 .42229 Mtetra
.51478 .42229 .52063 .42874 .53139 .4252 .52556 .41872 Mtetra
.52556 .41872 .53139 .4252 .54219 .42164 .53639 .41514 Mtetra
.657 .752 .92 r
.53639 .41514 .54219 .42164 .55303 .41808 .54726 .41154 Mtetra
.54726 .41154 .55303 .41808 .56392 .41449 .55817 .40793 Mtetra
.55817 .40793 .56392 .41449 .57485 .4109 .56913 .40431 Mtetra
.56913 .40431 .57485 .4109 .58582 .40729 .58013 .40068 Mtetra
.58013 .40068 .58582 .40729 .59683 .40367 .59117 .39703 Mtetra
.59117 .39703 .59683 .40367 .60789 .40004 .60226 .39337 Mtetra
.60226 .39337 .60789 .40004 .61899 .39639 .61339 .3897 Mtetra
.61339 .3897 .61899 .39639 .63014 .39273 .62457 .38601 Mtetra
.62457 .38601 .63014 .39273 .64133 .38906 .63579 .38231 Mtetra
.63579 .38231 .64133 .38906 .65256 .38537 .64705 .37859 Mtetra
.64705 .37859 .65256 .38537 .66384 .38167 .65836 .37486 Mtetra
.65836 .37486 .66384 .38167 .67516 .37795 .66972 .37112 Mtetra
.66972 .37112 .67516 .37795 .68653 .37422 .68112 .36736 Mtetra
.68112 .36736 .68653 .37422 .69795 .37047 .69256 .36358 Mtetra
.69256 .36358 .69795 .37047 .70941 .36671 .70406 .35979 Mtetra
.70406 .35979 .70941 .36671 .72092 .36293 .7156 .35599 Mtetra
.7156 .35599 .72092 .36293 .73247 .35914 .72718 .35217 Mtetra
.72718 .35217 .73247 .35914 .74407 .35534 .73882 .34834 Mtetra
.73882 .34834 .74407 .35534 .75572 .35152 .7505 .34449 Mtetra
.7505 .34449 .75572 .35152 .76741 .34768 .76223 .34062 Mtetra
.76223 .34062 .76741 .34768 .77916 .34383 .774 .33674 Mtetra
.774 .33674 .77916 .34383 .79095 .33997 .78583 .33285 Mtetra
.78583 .33285 .79095 .33997 .80279 .33609 .7977 .32894 Mtetra
.7977 .32894 .80279 .33609 .81467 .33219 .80963 .32501 Mtetra
.80963 .32501 .81467 .33219 .82661 .32828 .8216 .32107 Mtetra
.8216 .32107 .82661 .32828 .8386 .32435 .83362 .31711 Mtetra
.848 .711 .712 r
.19326 .52227 .19963 .53091 .20992 .52052 .20439 .50345 Mtetra
.154 .235 .695 r
.20439 .50345 .20992 .52052 .21935 .51937 .21281 .51291 Mtetra
.611 .718 .921 r
.21281 .51291 .21935 .51937 .22894 .51697 .22239 .51077 Mtetra
.626 .731 .923 r
.22239 .51077 .22894 .51697 .23856 .51461 .23204 .50828 Mtetra
.602 .72 .928 r
.23204 .50828 .23856 .51461 .24805 .51435 .24169 .50628 Mtetra
.905 .714 .634 r
.24169 .50628 .24805 .51435 .25839 .5042 .25457 .46555 Mtetra
0 0 .446 r
.25457 .46555 .25839 .5042 .26801 .50324 .26157 .49666 Mtetra
.614 .718 .919 r
.26157 .49666 .26801 .50324 .2778 .50064 .27135 .49441 Mtetra
.636 .737 .921 r
.27135 .49441 .2778 .50064 .28765 .49781 .28122 .49163 Mtetra
.64 .74 .922 r
.28122 .49163 .28765 .49781 .29754 .49498 .29113 .48875 Mtetra
.635 .738 .923 r
.29113 .48875 .29754 .49498 .30744 .49246 .30107 .48598 Mtetra
.594 .717 .929 r
.30107 .48598 .30744 .49246 .31712 .49428 .31099 .48408 Mtetra
.806 .693 .74 r
.31099 .48408 .31712 .49428 .32769 .48221 .32168 .47052 Mtetra
.387 .475 .828 r
.32168 .47052 .32769 .48221 .33767 .48039 .33136 .47384 Mtetra
.628 .728 .919 r
.33136 .47384 .33767 .48039 .34775 .47747 .34145 .47119 Mtetra
.646 .743 .92 r
.34145 .47119 .34775 .47747 .35788 .47432 .3516 .4681 Mtetra
.652 .748 .92 r
.3516 .4681 .35788 .47432 .36806 .47105 .3618 .46485 Mtetra
.655 .75 .92 r
.3618 .46485 .36806 .47105 .37828 .4677 .37204 .46151 Mtetra
.657 .752 .92 r
.37204 .46151 .37828 .4677 .38854 .4643 .38232 .45811 Mtetra
.658 .753 .92 r
.38232 .45811 .38854 .4643 .39884 .46087 .39265 .45466 Mtetra
.659 .754 .92 r
.39265 .45466 .39884 .46087 .40918 .45741 .40301 .45118 Mtetra
.40301 .45118 .40918 .45741 .41956 .45393 .41342 .44768 Mtetra
.41342 .44768 .41956 .45393 .42997 .45045 .42386 .44416 Mtetra
.42386 .44416 .42997 .45045 .44043 .44696 .43435 .44065 Mtetra
.658 .753 .92 r
.43435 .44065 .44043 .44696 .45093 .44346 .44487 .43712 Mtetra
.44487 .43712 .45093 .44346 .46147 .43996 .45543 .43359 Mtetra
.45543 .43359 .46147 .43996 .47205 .43645 .46604 .43005 Mtetra
.46604 .43005 .47205 .43645 .48267 .43292 .47669 .4265 Mtetra
.47669 .4265 .48267 .43292 .49333 .42939 .48738 .42294 Mtetra
.48738 .42294 .49333 .42939 .50403 .42584 .4981 .41937 Mtetra
.4981 .41937 .50403 .42584 .51478 .42229 .50888 .41578 Mtetra
.657 .753 .92 r
.50888 .41578 .51478 .42229 .52556 .41872 .51969 .41219 Mtetra
.51969 .41219 .52556 .41872 .53639 .41514 .53055 .40858 Mtetra
.657 .752 .92 r
.53055 .40858 .53639 .41514 .54726 .41154 .54145 .40496 Mtetra
.54145 .40496 .54726 .41154 .55817 .40793 .55239 .40132 Mtetra
.55239 .40132 .55817 .40793 .56913 .40431 .56337 .39768 Mtetra
.56337 .39768 .56913 .40431 .58013 .40068 .5744 .39402 Mtetra
.5744 .39402 .58013 .40068 .59117 .39703 .58547 .39034 Mtetra
.58547 .39034 .59117 .39703 .60226 .39337 .59659 .38666 Mtetra
.59659 .38666 .60226 .39337 .61339 .3897 .60775 .38295 Mtetra
.60775 .38295 .61339 .3897 .62457 .38601 .61896 .37924 Mtetra
.61896 .37924 .62457 .38601 .63579 .38231 .63021 .37551 Mtetra
.63021 .37551 .63579 .38231 .64705 .37859 .6415 .37176 Mtetra
.6415 .37176 .64705 .37859 .65836 .37486 .65284 .36801 Mtetra
.65284 .36801 .65836 .37486 .66972 .37112 .66423 .36423 Mtetra
.66423 .36423 .66972 .37112 .68112 .36736 .67566 .36044 Mtetra
.67566 .36044 .68112 .36736 .69256 .36358 .68714 .35664 Mtetra
.68714 .35664 .69256 .36358 .70406 .35979 .69867 .35282 Mtetra
.69867 .35282 .70406 .35979 .7156 .35599 .71024 .34899 Mtetra
.71024 .34899 .7156 .35599 .72718 .35217 .72186 .34514 Mtetra
.72186 .34514 .72718 .35217 .73882 .34834 .73353 .34128 Mtetra
.73353 .34128 .73882 .34834 .7505 .34449 .74524 .3374 Mtetra
.74524 .3374 .7505 .34449 .76223 .34062 .757 .33351 Mtetra
.757 .33351 .76223 .34062 .774 .33674 .76881 .3296 Mtetra
.76881 .3296 .774 .33674 .78583 .33285 .78067 .32567 Mtetra
.78067 .32567 .78583 .33285 .7977 .32894 .79258 .32173 Mtetra
.79258 .32173 .7977 .32894 .80963 .32501 .80454 .31778 Mtetra
.80454 .31778 .80963 .32501 .8216 .32107 .81655 .3138 Mtetra
.81655 .3138 .8216 .32107 .83362 .31711 .8286 .30981 Mtetra
.443 .643 .942 r
.18666 .51554 .19326 .52227 .20439 .50345 .19592 .51612 Mtetra
0 0 0 r
.19592 .51612 .20439 .50345 .21281 .51291 .2063 .50565 Mtetra
.567 .677 .913 r
.2063 .50565 .21281 .51291 .22239 .51077 .21581 .50445 Mtetra
.623 .728 .922 r
.21581 .50445 .22239 .51077 .23204 .50828 .22547 .502 Mtetra
.621 .73 .924 r
.22547 .502 .23204 .50828 .24169 .50628 .23518 .49958 Mtetra
.506 .674 .94 r
.23518 .49958 .24169 .50628 .25457 .46555 .24474 .49928 Mtetra
.354 .073 .341 r
.24474 .49928 .25457 .46555 .26157 .49666 .25517 .48904 Mtetra
.559 .665 .909 r
.25517 .48904 .26157 .49666 .27135 .49441 .26487 .48804 Mtetra
.63 .732 .921 r
.26487 .48804 .27135 .49441 .28122 .49163 .27474 .48538 Mtetra
.639 .74 .921 r
.27474 .48538 .28122 .49163 .29113 .48875 .28467 .4825 Mtetra
.639 .74 .922 r
.28467 .4825 .29113 .48875 .30107 .48598 .29464 .47961 Mtetra
.625 .733 .924 r
.29464 .47961 .30107 .48598 .31099 .48408 .30463 .47704 Mtetra
.356 .593 .935 r
.30463 .47704 .31099 .48408 .32168 .47052 .31438 .47882 Mtetra
.535 .817 .469 r
.31438 .47882 .32168 .47052 .33136 .47384 .32505 .46665 Mtetra
.595 .697 .914 r
.32505 .46665 .33136 .47384 .34145 .47119 .33511 .46478 Mtetra
.64 .738 .92 r
.33511 .46478 .34145 .47119 .3516 .4681 .34527 .46181 Mtetra
.649 .746 .92 r
.34527 .46181 .3516 .4681 .3618 .46485 .35549 .45859 Mtetra
.653 .749 .92 r
.35549 .45859 .3618 .46485 .37204 .46151 .36576 .45526 Mtetra
.656 .751 .92 r
.36576 .45526 .37204 .46151 .38232 .45811 .37606 .45186 Mtetra
.658 .753 .92 r
.37606 .45186 .38232 .45811 .39265 .45466 .38641 .4484 Mtetra
.659 .753 .92 r
.38641 .4484 .39265 .45466 .40301 .45118 .3968 .4449 Mtetra
.659 .754 .92 r
.3968 .4449 .40301 .45118 .41342 .44768 .40723 .44137 Mtetra
.40723 .44137 .41342 .44768 .42386 .44416 .4177 .43784 Mtetra
.4177 .43784 .42386 .44416 .43435 .44065 .42821 .43429 Mtetra
.659 .753 .92 r
.42821 .43429 .43435 .44065 .44487 .43712 .43876 .43074 Mtetra
.658 .753 .92 r
.43876 .43074 .44487 .43712 .45543 .43359 .44936 .42718 Mtetra
.44936 .42718 .45543 .43359 .46604 .43005 .45999 .42361 Mtetra
.45999 .42361 .46604 .43005 .47669 .4265 .47066 .42003 Mtetra
.47066 .42003 .47669 .4265 .48738 .42294 .48138 .41644 Mtetra
.48138 .41644 .48738 .42294 .4981 .41937 .49213 .41285 Mtetra
.49213 .41285 .4981 .41937 .50888 .41578 .50293 .40923 Mtetra
.657 .753 .92 r
.50293 .40923 .50888 .41578 .51969 .41219 .51378 .40561 Mtetra
.51378 .40561 .51969 .41219 .53055 .40858 .52466 .40198 Mtetra
.52466 .40198 .53055 .40858 .54145 .40496 .53559 .39833 Mtetra
.657 .752 .92 r
.53559 .39833 .54145 .40496 .55239 .40132 .54656 .39467 Mtetra
.54656 .39467 .55239 .40132 .56337 .39768 .55757 .39099 Mtetra
.55757 .39099 .56337 .39768 .5744 .39402 .56863 .38731 Mtetra
.56863 .38731 .5744 .39402 .58547 .39034 .57973 .3836 Mtetra
.57973 .3836 .58547 .39034 .59659 .38666 .59088 .37989 Mtetra
.59088 .37989 .59659 .38666 .60775 .38295 .60207 .37616 Mtetra
.60207 .37616 .60775 .38295 .61896 .37924 .6133 .37242 Mtetra
.6133 .37242 .61896 .37924 .63021 .37551 .62459 .36866 Mtetra
.62459 .36866 .63021 .37551 .6415 .37176 .63591 .36489 Mtetra
.63591 .36489 .6415 .37176 .65284 .36801 .64728 .3611 Mtetra
.64728 .3611 .65284 .36801 .66423 .36423 .6587 .3573 Mtetra
.6587 .3573 .66423 .36423 .67566 .36044 .67017 .35348 Mtetra
.67017 .35348 .67566 .36044 .68714 .35664 .68168 .34965 Mtetra
.68168 .34965 .68714 .35664 .69867 .35282 .69324 .3458 Mtetra
.69324 .3458 .69867 .35282 .71024 .34899 .70484 .34194 Mtetra
.70484 .34194 .71024 .34899 .72186 .34514 .71649 .33806 Mtetra
.71649 .33806 .72186 .34514 .73353 .34128 .72819 .33417 Mtetra
.72819 .33417 .73353 .34128 .74524 .3374 .73994 .33026 Mtetra
.73994 .33026 .74524 .3374 .757 .33351 .75174 .32634 Mtetra
.75174 .32634 .757 .33351 .76881 .3296 .76358 .3224 Mtetra
.76358 .3224 .76881 .3296 .78067 .32567 .77548 .31845 Mtetra
.77548 .31845 .78067 .32567 .79258 .32173 .78742 .31448 Mtetra
.78742 .31448 .79258 .32173 .80454 .31778 .79941 .31049 Mtetra
.79941 .31049 .80454 .31778 .81655 .3138 .81146 .30648 Mtetra
.81146 .30648 .81655 .3138 .8286 .30981 .82355 .30246 Mtetra
.589 .713 .93 r
.17999 .50912 .18666 .51554 .19592 .51612 .18949 .50737 Mtetra
.849 .712 .711 r
.18949 .50737 .19592 .51612 .2063 .50565 .20072 .48843 Mtetra
.151 .232 .694 r
.20072 .48843 .2063 .50565 .21581 .50445 .2092 .49789 Mtetra
.611 .718 .921 r
.2092 .49789 .21581 .50445 .22547 .502 .21886 .49569 Mtetra
.626 .731 .923 r
.21886 .49569 .22547 .502 .23518 .49958 .22859 .49315 Mtetra
.602 .72 .928 r
.22859 .49315 .23518 .49958 .24474 .49928 .23832 .4911 Mtetra
.906 .715 .633 r
.23832 .4911 .24474 .49928 .25517 .48904 .25134 .45015 Mtetra
0 0 .443 r
.25134 .45015 .25517 .48904 .26487 .48804 .25836 .48135 Mtetra
.614 .718 .919 r
.25836 .48135 .26487 .48804 .27474 .48538 .26822 .47905 Mtetra
.636 .737 .921 r
.26822 .47905 .27474 .48538 .28467 .4825 .27817 .47621 Mtetra
.64 .74 .922 r
.27817 .47621 .28467 .4825 .29464 .47961 .28816 .47327 Mtetra
.635 .738 .923 r
.28816 .47327 .29464 .47961 .30463 .47704 .29819 .47045 Mtetra
.594 .717 .929 r
.29819 .47045 .30463 .47704 .31438 .47882 .30819 .46849 Mtetra
.807 .694 .74 r
.30819 .46849 .31438 .47882 .32505 .46665 .31898 .45483 Mtetra
.386 .475 .828 r
.31898 .45483 .32505 .46665 .33511 .46478 .32874 .45812 Mtetra
.628 .728 .919 r
.32874 .45812 .33511 .46478 .34527 .46181 .33891 .45541 Mtetra
.646 .743 .92 r
.33891 .45541 .34527 .46181 .35549 .45859 .34914 .45226 Mtetra
.652 .748 .92 r
.34914 .45226 .35549 .45859 .36576 .45526 .35943 .44895 Mtetra
.655 .75 .92 r
.35943 .44895 .36576 .45526 .37606 .45186 .36976 .44555 Mtetra
.657 .752 .92 r
.36976 .44555 .37606 .45186 .38641 .4484 .38013 .44208 Mtetra
.658 .753 .92 r
.38013 .44208 .38641 .4484 .3968 .4449 .39055 .43857 Mtetra
.659 .754 .92 r
.39055 .43857 .3968 .4449 .40723 .44137 .40101 .43503 Mtetra
.40101 .43503 .40723 .44137 .4177 .43784 .4115 .43146 Mtetra
.4115 .43146 .4177 .43784 .42821 .43429 .42204 .42789 Mtetra
.42204 .42789 .42821 .43429 .43876 .43074 .43261 .42431 Mtetra
.658 .753 .92 r
.43261 .42431 .43876 .43074 .44936 .42718 .44323 .42072 Mtetra
.44323 .42072 .44936 .42718 .45999 .42361 .45389 .41712 Mtetra
.45389 .41712 .45999 .42361 .47066 .42003 .46459 .41352 Mtetra
.46459 .41352 .47066 .42003 .48138 .41644 .47534 .4099 Mtetra
.47534 .4099 .48138 .41644 .49213 .41285 .48612 .40628 Mtetra
.48612 .40628 .49213 .41285 .50293 .40923 .49695 .40264 Mtetra
.49695 .40264 .50293 .40923 .51378 .40561 .50782 .39899 Mtetra
.657 .753 .92 r
.50782 .39899 .51378 .40561 .52466 .40198 .51873 .39533 Mtetra
.51873 .39533 .52466 .40198 .53559 .39833 .52969 .39165 Mtetra
.657 .752 .92 r
.52969 .39165 .53559 .39833 .54656 .39467 .54068 .38796 Mtetra
.54068 .38796 .54656 .39467 .55757 .39099 .55173 .38426 Mtetra
.55173 .38426 .55757 .39099 .56863 .38731 .56282 .38054 Mtetra
.56282 .38054 .56863 .38731 .57973 .3836 .57395 .37681 Mtetra
.57395 .37681 .57973 .3836 .59088 .37989 .58512 .37307 Mtetra
.58512 .37307 .59088 .37989 .60207 .37616 .59634 .36931 Mtetra
.59634 .36931 .60207 .37616 .6133 .37242 .60761 .36554 Mtetra
.60761 .36554 .6133 .37242 .62459 .36866 .61892 .36176 Mtetra
.61892 .36176 .62459 .36866 .63591 .36489 .63028 .35796 Mtetra
.63028 .35796 .63591 .36489 .64728 .3611 .64168 .35414 Mtetra
.64168 .35414 .64728 .3611 .6587 .3573 .65313 .35031 Mtetra
.65313 .35031 .6587 .3573 .67017 .35348 .66463 .34646 Mtetra
.66463 .34646 .67017 .35348 .68168 .34965 .67617 .3426 Mtetra
.67617 .3426 .68168 .34965 .69324 .3458 .68776 .33873 Mtetra
.68776 .33873 .69324 .3458 .70484 .34194 .6994 .33484 Mtetra
.6994 .33484 .70484 .34194 .71649 .33806 .71109 .33093 Mtetra
.71109 .33093 .71649 .33806 .72819 .33417 .72282 .32701 Mtetra
.72282 .32701 .72819 .33417 .73994 .33026 .7346 .32307 Mtetra
.7346 .32307 .73994 .33026 .75174 .32634 .74643 .31912 Mtetra
.74643 .31912 .75174 .32634 .76358 .3224 .75831 .31515 Mtetra
.75831 .31515 .76358 .3224 .77548 .31845 .77024 .31116 Mtetra
.77024 .31116 .77548 .31845 .78742 .31448 .78222 .30716 Mtetra
.78222 .30716 .78742 .31448 .79941 .31049 .79425 .30314 Mtetra
.79425 .30314 .79941 .31049 .81146 .30648 .80633 .29911 Mtetra
.80633 .29911 .81146 .30648 .82355 .30246 .81846 .29506 Mtetra
.611 .723 .925 r
.17326 .50274 .17999 .50912 .18949 .50737 .18282 .50053 Mtetra
.444 .643 .942 r
.18282 .50053 .18949 .50737 .20072 .48843 .19215 .50108 Mtetra
0 0 0 r
.19215 .50108 .20072 .48843 .2092 .49789 .20262 .49051 Mtetra
.567 .677 .913 r
.20262 .49051 .2092 .49789 .21886 .49569 .2122 .48927 Mtetra
.623 .728 .922 r
.2122 .48927 .21886 .49569 .22859 .49315 .22195 .48676 Mtetra
.621 .73 .924 r
.22195 .48676 .22859 .49315 .23832 .4911 .23173 .48429 Mtetra
.506 .674 .939 r
.23173 .48429 .23832 .4911 .25134 .45015 .24137 .48395 Mtetra
.347 .064 .333 r
.24137 .48395 .25134 .45015 .25836 .48135 .25189 .47362 Mtetra
.559 .665 .909 r
.25189 .47362 .25836 .48135 .26822 .47905 .26167 .47256 Mtetra
.63 .732 .921 r
.26167 .47256 .26822 .47905 .27817 .47621 .27162 .46985 Mtetra
.639 .74 .921 r
.27162 .46985 .27817 .47621 .28816 .47327 .28164 .46691 Mtetra
.639 .74 .922 r
.28164 .46691 .28816 .47327 .29819 .47045 .29169 .46397 Mtetra
.625 .733 .924 r
.29169 .46397 .29819 .47045 .30819 .46849 .30176 .46134 Mtetra
.358 .594 .935 r
.30176 .46134 .30819 .46849 .31898 .45483 .31159 .46308 Mtetra
.547 .827 .481 r
.31159 .46308 .31898 .45483 .32874 .45812 .32236 .45081 Mtetra
.595 .697 .914 r
.32236 .45081 .32874 .45812 .33891 .45541 .3325 .44888 Mtetra
.64 .738 .92 r
.3325 .44888 .33891 .45541 .34914 .45226 .34275 .44585 Mtetra
.649 .746 .92 r
.34275 .44585 .34914 .45226 .35943 .44895 .35306 .44258 Mtetra
.653 .749 .92 r
.35306 .44258 .35943 .44895 .36976 .44555 .36341 .43919 Mtetra
.656 .751 .92 r
.36341 .43919 .36976 .44555 .38013 .44208 .37381 .43572 Mtetra
.658 .753 .92 r
.37381 .43572 .38013 .44208 .39055 .43857 .38425 .43219 Mtetra
.659 .753 .92 r
.38425 .43219 .39055 .43857 .40101 .43503 .39473 .42863 Mtetra
.659 .754 .92 r
.39473 .42863 .40101 .43503 .4115 .43146 .40525 .42505 Mtetra
.40525 .42505 .4115 .43146 .42204 .42789 .41582 .42144 Mtetra
.41582 .42144 .42204 .42789 .43261 .42431 .42642 .41783 Mtetra
.659 .753 .92 r
.42642 .41783 .43261 .42431 .44323 .42072 .43707 .41422 Mtetra
.658 .753 .92 r
.43707 .41422 .44323 .42072 .45389 .41712 .44775 .41059 Mtetra
.44775 .41059 .45389 .41712 .46459 .41352 .45848 .40696 Mtetra
.45848 .40696 .46459 .41352 .47534 .4099 .46925 .40331 Mtetra
.46925 .40331 .47534 .4099 .48612 .40628 .48006 .39966 Mtetra
.48006 .39966 .48612 .40628 .49695 .40264 .49092 .39599 Mtetra
.49092 .39599 .49695 .40264 .50782 .39899 .50181 .39232 Mtetra
.657 .753 .92 r
.50181 .39232 .50782 .39899 .51873 .39533 .51276 .38863 Mtetra
.51276 .38863 .51873 .39533 .52969 .39165 .52374 .38492 Mtetra
.52374 .38492 .52969 .39165 .54068 .38796 .53477 .38121 Mtetra
.657 .752 .92 r
.53477 .38121 .54068 .38796 .55173 .38426 .54584 .37748 Mtetra
.54584 .37748 .55173 .38426 .56282 .38054 .55696 .37373 Mtetra
.55696 .37373 .56282 .38054 .57395 .37681 .56812 .36998 Mtetra
.56812 .36998 .57395 .37681 .58512 .37307 .57933 .3662 Mtetra
.57933 .3662 .58512 .37307 .59634 .36931 .59058 .36242 Mtetra
.59058 .36242 .59634 .36931 .60761 .36554 .60187 .35862 Mtetra
.60187 .35862 .60761 .36554 .61892 .36176 .61322 .3548 Mtetra
.61322 .3548 .61892 .36176 .63028 .35796 .62461 .35097 Mtetra
.62461 .35097 .63028 .35796 .64168 .35414 .63604 .34713 Mtetra
.63604 .34713 .64168 .35414 .65313 .35031 .64752 .34327 Mtetra
.64752 .34327 .65313 .35031 .66463 .34646 .65905 .3394 Mtetra
.65905 .3394 .66463 .34646 .67617 .3426 .67063 .33551 Mtetra
.67063 .33551 .67617 .3426 .68776 .33873 .68225 .3316 Mtetra
.68225 .3316 .68776 .33873 .6994 .33484 .69392 .32768 Mtetra
.69392 .32768 .6994 .33484 .71109 .33093 .70564 .32374 Mtetra
.70564 .32374 .71109 .33093 .72282 .32701 .71741 .31979 Mtetra
.71741 .31979 .72282 .32701 .7346 .32307 .72922 .31582 Mtetra
.72922 .31582 .7346 .32307 .74643 .31912 .74109 .31184 Mtetra
.74109 .31184 .74643 .31912 .75831 .31515 .753 .30784 Mtetra
.753 .30784 .75831 .31515 .77024 .31116 .76497 .30382 Mtetra
.76497 .30382 .77024 .31116 .78222 .30716 .77698 .29979 Mtetra
.77698 .29979 .78222 .30716 .79425 .30314 .78904 .29574 Mtetra
.78904 .29574 .79425 .30314 .80633 .29911 .80116 .29168 Mtetra
.80116 .29168 .80633 .29911 .81846 .29506 .81332 .28759 Mtetra
.613 .722 .923 r
.16649 .49626 .17326 .50274 .18282 .50053 .17607 .494 Mtetra
.589 .713 .93 r
.17607 .494 .18282 .50053 .19215 .50108 .18565 .49221 Mtetra
.849 .712 .711 r
.18565 .49221 .19215 .50108 .20262 .49051 .19699 .47315 Mtetra
.147 .23 .693 r
.19699 .47315 .20262 .49051 .2122 .48927 .20552 .4826 Mtetra
.611 .718 .921 r
.20552 .4826 .2122 .48927 .22195 .48676 .21526 .48034 Mtetra
.626 .731 .923 r
.21526 .48034 .22195 .48676 .23173 .48429 .22507 .47775 Mtetra
.602 .72 .928 r
.22507 .47775 .23173 .48429 .24137 .48395 .23488 .47565 Mtetra
.907 .716 .632 r
.23488 .47565 .24137 .48395 .25189 .47362 .24805 .43449 Mtetra
0 0 .439 r
.24805 .43449 .25189 .47362 .26167 .47256 .25509 .46577 Mtetra
.614 .718 .919 r
.25509 .46577 .26167 .47256 .27162 .46985 .26504 .46341 Mtetra
.636 .737 .921 r
.26504 .46341 .27162 .46985 .28164 .46691 .27506 .46051 Mtetra
.64 .74 .922 r
.27506 .46051 .28164 .46691 .29169 .46397 .28514 .45752 Mtetra
.635 .738 .923 r
.28514 .45752 .29169 .46397 .30176 .46134 .29525 .45463 Mtetra
.594 .717 .929 r
.29525 .45463 .30176 .46134 .31159 .46308 .30534 .45262 Mtetra
.808 .694 .74 r
.30534 .45262 .31159 .46308 .32236 .45081 .31623 .43886 Mtetra
.384 .474 .829 r
.31623 .43886 .32236 .45081 .3325 .44888 .32606 .44211 Mtetra
.628 .728 .919 r
.32606 .44211 .3325 .44888 .34275 .44585 .33632 .43935 Mtetra
.646 .743 .92 r
.33632 .43935 .34275 .44585 .35306 .44258 .34665 .43613 Mtetra
.652 .748 .92 r
.34665 .43613 .35306 .44258 .36341 .43919 .35702 .43276 Mtetra
.655 .75 .92 r
.35702 .43276 .36341 .43919 .37381 .43572 .36744 .4293 Mtetra
.657 .752 .92 r
.36744 .4293 .37381 .43572 .38425 .43219 .37791 .42577 Mtetra
.658 .753 .92 r
.37791 .42577 .38425 .43219 .39473 .42863 .38841 .42219 Mtetra
.659 .754 .92 r
.38841 .42219 .39473 .42863 .40525 .42505 .39896 .41858 Mtetra
.39896 .41858 .40525 .42505 .41582 .42144 .40955 .41495 Mtetra
.40955 .41495 .41582 .42144 .42642 .41783 .42018 .41131 Mtetra
.42018 .41131 .42642 .41783 .43707 .41422 .43085 .40767 Mtetra
.658 .753 .92 r
.43085 .40767 .43707 .41422 .44775 .41059 .44157 .40401 Mtetra
.44157 .40401 .44775 .41059 .45848 .40696 .45232 .40035 Mtetra
.45232 .40035 .45848 .40696 .46925 .40331 .46312 .39668 Mtetra
.46312 .39668 .46925 .40331 .48006 .39966 .47396 .39299 Mtetra
.47396 .39299 .48006 .39966 .49092 .39599 .48484 .3893 Mtetra
.48484 .3893 .49092 .39599 .50181 .39232 .49577 .3856 Mtetra
.49577 .3856 .50181 .39232 .51276 .38863 .50674 .38188 Mtetra
.657 .753 .92 r
.50674 .38188 .51276 .38863 .52374 .38492 .51775 .37815 Mtetra
.51775 .37815 .52374 .38492 .53477 .38121 .52881 .3744 Mtetra
.657 .752 .92 r
.52881 .3744 .53477 .38121 .54584 .37748 .53991 .37064 Mtetra
.53991 .37064 .54584 .37748 .55696 .37373 .55106 .36687 Mtetra
.55106 .36687 .55696 .37373 .56812 .36998 .56225 .36309 Mtetra
.56225 .36309 .56812 .36998 .57933 .3662 .57348 .35929 Mtetra
.57348 .35929 .57933 .3662 .59058 .36242 .58477 .35547 Mtetra
.58477 .35547 .59058 .36242 .60187 .35862 .59609 .35164 Mtetra
.59609 .35164 .60187 .35862 .61322 .3548 .60747 .3478 Mtetra
.60747 .3478 .61322 .3548 .62461 .35097 .61889 .34394 Mtetra
.61889 .34394 .62461 .35097 .63604 .34713 .63035 .34007 Mtetra
.63035 .34007 .63604 .34713 .64752 .34327 .64187 .33618 Mtetra
.64187 .33618 .64752 .34327 .65905 .3394 .65343 .33227 Mtetra
.65343 .33227 .65905 .3394 .67063 .33551 .66504 .32835 Mtetra
.66504 .32835 .67063 .33551 .68225 .3316 .67669 .32442 Mtetra
.67669 .32442 .68225 .3316 .69392 .32768 .6884 .32047 Mtetra
.6884 .32047 .69392 .32768 .70564 .32374 .70015 .3165 Mtetra
.70015 .3165 .70564 .32374 .71741 .31979 .71195 .31252 Mtetra
.71195 .31252 .71741 .31979 .72922 .31582 .7238 .30852 Mtetra
.7238 .30852 .72922 .31582 .74109 .31184 .7357 .30451 Mtetra
.7357 .30451 .74109 .31184 .753 .30784 .74765 .30047 Mtetra
.74765 .30047 .753 .30784 .76497 .30382 .75965 .29643 Mtetra
.75965 .29643 .76497 .30382 .77698 .29979 .7717 .29236 Mtetra
.7717 .29236 .77698 .29979 .78904 .29574 .7838 .28828 Mtetra
.7838 .28828 .78904 .29574 .80116 .29168 .79595 .28418 Mtetra
.79595 .28418 .80116 .29168 .81332 .28759 .80815 .28007 Mtetra
.598 .708 .921 r
.1597 .48946 .16649 .49626 .17607 .494 .16927 .48752 Mtetra
.611 .723 .925 r
.16927 .48752 .17607 .494 .18565 .49221 .17891 .48526 Mtetra
.444 .643 .942 r
.17891 .48526 .18565 .49221 .19699 .47315 .18831 .48576 Mtetra
0 0 0 r
.18831 .48576 .19699 .47315 .20552 .4826 .19887 .47511 Mtetra
.567 .677 .914 r
.19887 .47511 .20552 .4826 .21526 .48034 .20853 .47382 Mtetra
.623 .728 .922 r
.20853 .47382 .21526 .48034 .22507 .47775 .21836 .47125 Mtetra
.621 .73 .924 r
.21836 .47125 .22507 .47775 .23488 .47565 .22822 .46873 Mtetra
.507 .674 .939 r
.22822 .46873 .23488 .47565 .24805 .43449 .23794 .46833 Mtetra
.34 .054 .326 r
.23794 .46833 .24805 .43449 .25509 .46577 .24855 .45792 Mtetra
.558 .665 .909 r
.24855 .45792 .25509 .46577 .26504 .46341 .25841 .45681 Mtetra
.63 .732 .921 r
.25841 .45681 .26504 .46341 .27506 .46051 .26845 .45404 Mtetra
.639 .74 .921 r
.26845 .45404 .27506 .46051 .28514 .45752 .27854 .45104 Mtetra
.639 .74 .922 r
.27854 .45104 .28514 .45752 .29525 .45463 .28868 .44804 Mtetra
.625 .733 .924 r
.28868 .44804 .29525 .45463 .30534 .45262 .29884 .44535 Mtetra
.359 .594 .935 r
.29884 .44535 .30534 .45262 .31623 .43886 .30875 .44706 Mtetra
.559 .837 .493 r
.30875 .44706 .31623 .43886 .32606 .44211 .31962 .43469 Mtetra
.595 .697 .914 r
.31962 .43469 .32606 .44211 .33632 .43935 .32985 .4327 Mtetra
.64 .738 .92 r
.32985 .4327 .33632 .43935 .34665 .43613 .34019 .42961 Mtetra
.649 .746 .92 r
.34019 .42961 .34665 .43613 .35702 .43276 .35058 .42627 Mtetra
.653 .749 .92 r
.35058 .42627 .35702 .43276 .36744 .4293 .36103 .42281 Mtetra
.656 .751 .92 r
.36103 .42281 .36744 .4293 .37791 .42577 .37152 .41928 Mtetra
.658 .753 .92 r
.37152 .41928 .37791 .42577 .38841 .42219 .38205 .41569 Mtetra
.659 .753 .92 r
.38205 .41569 .38841 .42219 .39896 .41858 .39262 .41207 Mtetra
.659 .754 .92 r
.39262 .41207 .39896 .41858 .40955 .41495 .40324 .40842 Mtetra
.40324 .40842 .40955 .41495 .42018 .41131 .4139 .40475 Mtetra
.4139 .40475 .42018 .41131 .43085 .40767 .42459 .40107 Mtetra
.659 .753 .92 r
.42459 .40107 .43085 .40767 .44157 .40401 .43533 .39739 Mtetra
.658 .753 .92 r
.43533 .39739 .44157 .40401 .45232 .40035 .44612 .39369 Mtetra
.44612 .39369 .45232 .40035 .46312 .39668 .45694 .38999 Mtetra
.45694 .38999 .46312 .39668 .47396 .39299 .46781 .38628 Mtetra
.46781 .38628 .47396 .39299 .48484 .3893 .47872 .38256 Mtetra
.47872 .38256 .48484 .3893 .49577 .3856 .48968 .37882 Mtetra
.48968 .37882 .49577 .3856 .50674 .38188 .50067 .37508 Mtetra
.657 .753 .92 r
.50067 .37508 .50674 .38188 .51775 .37815 .51172 .37132 Mtetra
.51172 .37132 .51775 .37815 .52881 .3744 .5228 .36755 Mtetra
.5228 .36755 .52881 .3744 .53991 .37064 .53393 .36376 Mtetra
.657 .752 .92 r
.53393 .36376 .53991 .37064 .55106 .36687 .54511 .35996 Mtetra
.54511 .35996 .55106 .36687 .56225 .36309 .55633 .35614 Mtetra
.55633 .35614 .56225 .36309 .57348 .35929 .5676 .35231 Mtetra
.5676 .35231 .57348 .35929 .58477 .35547 .57891 .34847 Mtetra
.57891 .34847 .58477 .35547 .59609 .35164 .59027 .34461 Mtetra
.59027 .34461 .59609 .35164 .60747 .3478 .60167 .34074 Mtetra
.60167 .34074 .60747 .3478 .61889 .34394 .61313 .33685 Mtetra
.61313 .33685 .61889 .34394 .63035 .34007 .62463 .33295 Mtetra
.62463 .33295 .63035 .34007 .64187 .33618 .63617 .32903 Mtetra
.63617 .32903 .64187 .33618 .65343 .33227 .64776 .3251 Mtetra
.64776 .3251 .65343 .33227 .66504 .32835 .6594 .32115 Mtetra
.6594 .32115 .66504 .32835 .67669 .32442 .67109 .31718 Mtetra
.67109 .31718 .67669 .32442 .6884 .32047 .68283 .3132 Mtetra
.68283 .3132 .6884 .32047 .70015 .3165 .69462 .3092 Mtetra
.69462 .3092 .70015 .3165 .71195 .31252 .70645 .30519 Mtetra
.70645 .30519 .71195 .31252 .7238 .30852 .71834 .30116 Mtetra
.71834 .30116 .7238 .30852 .7357 .30451 .73027 .29711 Mtetra
.73027 .29711 .7357 .30451 .74765 .30047 .74226 .29305 Mtetra
.74226 .29305 .74765 .30047 .75965 .29643 .75429 .28897 Mtetra
.75429 .28897 .75965 .29643 .7717 .29236 .76638 .28488 Mtetra
.76638 .28488 .7717 .29236 .7838 .28828 .77851 .28076 Mtetra
.77851 .28076 .7838 .28828 .79595 .28418 .7907 .27663 Mtetra
.7907 .27663 .79595 .28418 .80815 .28007 .80294 .27249 Mtetra
.527 .642 .906 r
.15301 .48139 .1597 .48946 .16927 .48752 .16243 .48093 Mtetra
.613 .722 .923 r
.16243 .48093 .16927 .48752 .17891 .48526 .17209 .47862 Mtetra
.589 .713 .93 r
.17209 .47862 .17891 .48526 .18831 .48576 .18174 .47677 Mtetra
.85 .713 .711 r
.18174 .47677 .18831 .48576 .19887 .47511 .1932 .45759 Mtetra
.144 .228 .693 r
.1932 .45759 .19887 .47511 .20853 .47382 .20178 .46703 Mtetra
.611 .718 .921 r
.20178 .46703 .20853 .47382 .21836 .47125 .2116 .46472 Mtetra
.626 .731 .923 r
.2116 .46472 .21836 .47125 .22822 .46873 .22149 .46207 Mtetra
.602 .72 .928 r
.22149 .46207 .22822 .46873 .23794 .46833 .23138 .45992 Mtetra
.908 .716 .631 r
.23138 .45992 .23794 .46833 .24855 .45792 .2447 .41854 Mtetra
0 0 .435 r
.2447 .41854 .24855 .45792 .25841 .45681 .25176 .4499 Mtetra
.614 .718 .919 r
.25176 .4499 .25841 .45681 .26845 .45404 .26179 .44748 Mtetra
.636 .737 .921 r
.26179 .44748 .26845 .45404 .27854 .45104 .2719 .44453 Mtetra
.64 .74 .922 r
.2719 .44453 .27854 .45104 .28868 .44804 .28206 .44147 Mtetra
.635 .738 .923 r
.28206 .44147 .28868 .44804 .29884 .44535 .29226 .43853 Mtetra
.595 .717 .929 r
.29226 .43853 .29884 .44535 .30875 .44706 .30244 .43646 Mtetra
.808 .695 .74 r
.30244 .43646 .30875 .44706 .31962 .43469 .31343 .42259 Mtetra
.383 .474 .829 r
.31343 .42259 .31962 .43469 .32985 .4327 .32334 .42581 Mtetra
.628 .728 .919 r
.32334 .42581 .32985 .4327 .34019 .42961 .33369 .42298 Mtetra
.646 .743 .92 r
.33369 .42298 .34019 .42961 .35058 .42627 .3441 .41971 Mtetra
.652 .748 .92 r
.3441 .41971 .35058 .42627 .36103 .42281 .35457 .41627 Mtetra
.655 .75 .92 r
.35457 .41627 .36103 .42281 .37152 .41928 .36508 .41274 Mtetra
.657 .752 .92 r
.36508 .41274 .37152 .41928 .38205 .41569 .37564 .40915 Mtetra
.658 .753 .92 r
.37564 .40915 .38205 .41569 .39262 .41207 .38624 .4055 Mtetra
.659 .754 .92 r
.38624 .4055 .39262 .41207 .40324 .40842 .39688 .40183 Mtetra
.39688 .40183 .40324 .40842 .4139 .40475 .40756 .39813 Mtetra
.40756 .39813 .4139 .40475 .42459 .40107 .41829 .39443 Mtetra
.41829 .39443 .42459 .40107 .43533 .39739 .42906 .39071 Mtetra
.658 .753 .92 r
.42906 .39071 .43533 .39739 .44612 .39369 .43987 .38699 Mtetra
.43987 .38699 .44612 .39369 .45694 .38999 .45072 .38326 Mtetra
.45072 .38326 .45694 .38999 .46781 .38628 .46162 .37952 Mtetra
.46162 .37952 .46781 .38628 .47872 .38256 .47256 .37577 Mtetra
.47256 .37577 .47872 .38256 .48968 .37882 .48354 .372 Mtetra
.48354 .372 .48968 .37882 .50067 .37508 .49457 .36823 Mtetra
.49457 .36823 .50067 .37508 .51172 .37132 .50564 .36444 Mtetra
.657 .753 .92 r
.50564 .36444 .51172 .37132 .5228 .36755 .51675 .36064 Mtetra
.51675 .36064 .5228 .36755 .53393 .36376 .52791 .35682 Mtetra
.657 .752 .92 r
.52791 .35682 .53393 .36376 .54511 .35996 .53912 .35299 Mtetra
.53912 .35299 .54511 .35996 .55633 .35614 .55037 .34915 Mtetra
.55037 .34915 .55633 .35614 .5676 .35231 .56167 .34529 Mtetra
.56167 .34529 .5676 .35231 .57891 .34847 .57301 .34142 Mtetra
.57301 .34142 .57891 .34847 .59027 .34461 .5844 .33753 Mtetra
.5844 .33753 .59027 .34461 .60167 .34074 .59584 .33363 Mtetra
.59584 .33363 .60167 .34074 .61313 .33685 .60732 .32971 Mtetra
.60732 .32971 .61313 .33685 .62463 .33295 .61885 .32578 Mtetra
.61885 .32578 .62463 .33295 .63617 .32903 .63043 .32183 Mtetra
.63043 .32183 .63617 .32903 .64776 .3251 .64206 .31786 Mtetra
.64206 .31786 .64776 .3251 .6594 .32115 .65373 .31388 Mtetra
.65373 .31388 .6594 .32115 .67109 .31718 .66545 .30989 Mtetra
.66545 .30989 .67109 .31718 .68283 .3132 .67722 .30588 Mtetra
.67722 .30588 .68283 .3132 .69462 .3092 .68904 .30185 Mtetra
.68904 .30185 .69462 .3092 .70645 .30519 .70091 .2978 Mtetra
.70091 .2978 .70645 .30519 .71834 .30116 .71283 .29374 Mtetra
.71283 .29374 .71834 .30116 .73027 .29711 .7248 .28967 Mtetra
.7248 .28967 .73027 .29711 .74226 .29305 .73682 .28557 Mtetra
.73682 .28557 .74226 .29305 .75429 .28897 .74889 .28146 Mtetra
.74889 .28146 .75429 .28897 .76638 .28488 .76101 .27733 Mtetra
.76101 .27733 .76638 .28488 .77851 .28076 .77318 .27319 Mtetra
.77318 .27319 .77851 .28076 .7907 .27663 .78541 .26903 Mtetra
.78541 .26903 .7907 .27663 .80294 .27249 .79768 .26485 Mtetra
0 0 0 r
.13214 .59641 .15301 .48139 .16243 .48093 .15557 .47403 Mtetra
.598 .708 .921 r
.15557 .47403 .16243 .48093 .17209 .47862 .16521 .47202 Mtetra
.611 .723 .925 r
.16521 .47202 .17209 .47862 .18174 .47677 .17493 .46971 Mtetra
.445 .643 .942 r
.17493 .46971 .18174 .47677 .1932 .45759 .1844 .47017 Mtetra
0 0 0 r
.1844 .47017 .1932 .45759 .20178 .46703 .19506 .45943 Mtetra
.567 .677 .914 r
.19506 .45943 .20178 .46703 .2116 .46472 .2048 .45808 Mtetra
.623 .728 .922 r
.2048 .45808 .2116 .46472 .22149 .46207 .2147 .45546 Mtetra
.621 .73 .924 r
.2147 .45546 .22149 .46207 .23138 .45992 .22465 .45288 Mtetra
.507 .673 .939 r
.22465 .45288 .23138 .45992 .2447 .41854 .23444 .45244 Mtetra
.332 .045 .318 r
.23444 .45244 .2447 .41854 .25176 .4499 .24516 .44193 Mtetra
.558 .665 .909 r
.24516 .44193 .25176 .4499 .26179 .44748 .25509 .44077 Mtetra
.63 .732 .921 r
.25509 .44077 .26179 .44748 .2719 .44453 .26522 .43795 Mtetra
.639 .74 .921 r
.26522 .43795 .2719 .44453 .28206 .44147 .2754 .43488 Mtetra
.639 .74 .922 r
.2754 .43488 .28206 .44147 .29226 .43853 .28562 .43182 Mtetra
.625 .733 .924 r
.28562 .43182 .29226 .43853 .30244 .43646 .29587 .42907 Mtetra
.36 .594 .935 r
.29587 .42907 .30244 .43646 .31343 .42259 .30586 .43073 Mtetra
.571 .846 .505 r
.30586 .43073 .31343 .42259 .32334 .42581 .31683 .41826 Mtetra
.595 .697 .914 r
.31683 .41826 .32334 .42581 .33369 .42298 .32714 .41622 Mtetra
.64 .739 .92 r
.32714 .41622 .33369 .42298 .3441 .41971 .33758 .41306 Mtetra
.649 .746 .92 r
.33758 .41306 .3441 .41971 .35457 .41627 .34806 .40966 Mtetra
.653 .749 .92 r
.34806 .40966 .35457 .41627 .36508 .41274 .3586 .40614 Mtetra
.656 .751 .92 r
.3586 .40614 .36508 .41274 .37564 .40915 .36918 .40254 Mtetra
.658 .753 .92 r
.36918 .40254 .37564 .40915 .38624 .4055 .37981 .39889 Mtetra
.659 .753 .92 r
.37981 .39889 .38624 .4055 .39688 .40183 .39047 .39519 Mtetra
.659 .754 .92 r
.39047 .39519 .39688 .40183 .40756 .39813 .40118 .39147 Mtetra
.40118 .39147 .40756 .39813 .41829 .39443 .41194 .38774 Mtetra
.41194 .38774 .41829 .39443 .42906 .39071 .42273 .38399 Mtetra
.659 .753 .92 r
.42273 .38399 .42906 .39071 .43987 .38699 .43357 .38024 Mtetra
.658 .753 .92 r
.43357 .38024 .43987 .38699 .45072 .38326 .44445 .37648 Mtetra
.44445 .37648 .45072 .38326 .46162 .37952 .45538 .37271 Mtetra
.45538 .37271 .46162 .37952 .47256 .37577 .46634 .36893 Mtetra
.46634 .36893 .47256 .37577 .48354 .372 .47736 .36513 Mtetra
.47736 .36513 .48354 .372 .49457 .36823 .48841 .36133 Mtetra
.48841 .36133 .49457 .36823 .50564 .36444 .49951 .35751 Mtetra
.657 .753 .92 r
.49951 .35751 .50564 .36444 .51675 .36064 .51066 .35368 Mtetra
.51066 .35368 .51675 .36064 .52791 .35682 .52185 .34983 Mtetra
.52185 .34983 .52791 .35682 .53912 .35299 .53308 .34598 Mtetra
.657 .752 .92 r
.53308 .34598 .53912 .35299 .55037 .34915 .54437 .3421 Mtetra
.54437 .3421 .55037 .34915 .56167 .34529 .55569 .33821 Mtetra
.55569 .33821 .56167 .34529 .57301 .34142 .56707 .33431 Mtetra
.56707 .33431 .57301 .34142 .5844 .33753 .57849 .33039 Mtetra
.57849 .33039 .5844 .33753 .59584 .33363 .58996 .32646 Mtetra
.58996 .32646 .59584 .33363 .60732 .32971 .60147 .32251 Mtetra
.60147 .32251 .60732 .32971 .61885 .32578 .61303 .31855 Mtetra
.61303 .31855 .61885 .32578 .63043 .32183 .62465 .31457 Mtetra
.62465 .31457 .63043 .32183 .64206 .31786 .6363 .31058 Mtetra
.6363 .31058 .64206 .31786 .65373 .31388 .64801 .30657 Mtetra
.64801 .30657 .65373 .31388 .66545 .30989 .65977 .30254 Mtetra
.65977 .30254 .66545 .30989 .67722 .30588 .67157 .2985 Mtetra
.67157 .2985 .67722 .30588 .68904 .30185 .68343 .29444 Mtetra
.68343 .29444 .68904 .30185 .70091 .2978 .69533 .29036 Mtetra
.69533 .29036 .70091 .2978 .71283 .29374 .70728 .28627 Mtetra
.70728 .28627 .71283 .29374 .7248 .28967 .71929 .28216 Mtetra
.71929 .28216 .7248 .28967 .73682 .28557 .73134 .27803 Mtetra
.73134 .27803 .73682 .28557 .74889 .28146 .74345 .27389 Mtetra
.74345 .27389 .74889 .28146 .76101 .27733 .7556 .26973 Mtetra
.7556 .26973 .76101 .27733 .77318 .27319 .76781 .26555 Mtetra
.76781 .26555 .77318 .27319 .78541 .26903 .78007 .26136 Mtetra
.78007 .26136 .78541 .26903 .79768 .26485 .79239 .25714 Mtetra
.567 .357 .555 r
.13825 .47597 .13214 .59641 .15557 .47403 .14881 .46583 Mtetra
.527 .642 .907 r
.14881 .46583 .15557 .47403 .16521 .47202 .15829 .46533 Mtetra
.613 .722 .923 r
.15829 .46533 .16521 .47202 .17493 .46971 .16803 .46296 Mtetra
.589 .713 .929 r
.16803 .46296 .17493 .46971 .1844 .47017 .17776 .46106 Mtetra
.851 .714 .711 r
.17776 .46106 .1844 .47017 .19506 .45943 .18933 .44175 Mtetra
.14 .225 .692 r
.18933 .44175 .19506 .45943 .2048 .45808 .19797 .45118 Mtetra
.611 .718 .921 r
.19797 .45118 .2048 .45808 .2147 .45546 .20787 .44882 Mtetra
.626 .731 .923 r
.20787 .44882 .2147 .45546 .22465 .45288 .21784 .44611 Mtetra
.602 .72 .928 r
.21784 .44611 .22465 .45288 .23444 .45244 .22781 .4439 Mtetra
.909 .717 .631 r
.22781 .4439 .23444 .45244 .24516 .44193 .24129 .4023 Mtetra
0 0 .431 r
.24129 .4023 .24516 .44193 .25509 .44077 .24837 .43374 Mtetra
.614 .718 .919 r
.24837 .43374 .25509 .44077 .26522 .43795 .25849 .43127 Mtetra
.636 .737 .921 r
.25849 .43127 .26522 .43795 .2754 .43488 .26868 .42825 Mtetra
.64 .74 .922 r
.26868 .42825 .2754 .43488 .28562 .43182 .27893 .42513 Mtetra
.635 .738 .923 r
.27893 .42513 .28562 .43182 .29587 .42907 .28922 .42213 Mtetra
.595 .717 .929 r
.28922 .42213 .29587 .42907 .30586 .43073 .29948 .42001 Mtetra
.809 .696 .74 r
.29948 .42001 .30586 .43073 .31683 .41826 .31058 .40602 Mtetra
.382 .473 .829 r
.31058 .40602 .31683 .41826 .32714 .41622 .32057 .4092 Mtetra
.628 .728 .919 r
.32057 .4092 .32714 .41622 .33758 .41306 .331 .40632 Mtetra
.646 .743 .92 r
.331 .40632 .33758 .41306 .34806 .40966 .34151 .40298 Mtetra
.652 .748 .92 r
.34151 .40298 .34806 .40966 .3586 .40614 .35207 .39947 Mtetra
.655 .75 .92 r
.35207 .39947 .3586 .40614 .36918 .40254 .36268 .39588 Mtetra
.657 .752 .92 r
.36268 .39588 .36918 .40254 .37981 .39889 .37333 .39221 Mtetra
.658 .753 .92 r
.37333 .39221 .37981 .39889 .39047 .39519 .38402 .3885 Mtetra
.659 .754 .92 r
.38402 .3885 .39047 .39519 .40118 .39147 .39476 .38476 Mtetra
.39476 .38476 .40118 .39147 .41194 .38774 .40554 .381 Mtetra
.40554 .381 .41194 .38774 .42273 .38399 .41636 .37722 Mtetra
.41636 .37722 .42273 .38399 .43357 .38024 .42723 .37344 Mtetra
.658 .753 .92 r
.42723 .37344 .43357 .38024 .44445 .37648 .43814 .36965 Mtetra
.43814 .36965 .44445 .37648 .45538 .37271 .44909 .36585 Mtetra
.44909 .36585 .45538 .37271 .46634 .36893 .46009 .36203 Mtetra
.46009 .36203 .46634 .36893 .47736 .36513 .47113 .35821 Mtetra
.47113 .35821 .47736 .36513 .48841 .36133 .48221 .35438 Mtetra
.48221 .35438 .48841 .36133 .49951 .35751 .49334 .35053 Mtetra
.49334 .35053 .49951 .35751 .51066 .35368 .50452 .34667 Mtetra
.657 .753 .92 r
.50452 .34667 .51066 .35368 .52185 .34983 .51574 .34279 Mtetra
.51574 .34279 .52185 .34983 .53308 .34598 .527 .33891 Mtetra
.657 .752 .92 r
.527 .33891 .53308 .34598 .54437 .3421 .53832 .335 Mtetra
.53832 .335 .54437 .3421 .55569 .33821 .54967 .33109 Mtetra
.54967 .33109 .55569 .33821 .56707 .33431 .56108 .32715 Mtetra
.56108 .32715 .56707 .33431 .57849 .33039 .57253 .3232 Mtetra
.57253 .3232 .57849 .33039 .58996 .32646 .58403 .31924 Mtetra
.58403 .31924 .58996 .32646 .60147 .32251 .59558 .31526 Mtetra
.59558 .31526 .60147 .32251 .61303 .31855 .60717 .31127 Mtetra
.60717 .31127 .61303 .31855 .62465 .31457 .61882 .30726 Mtetra
.61882 .30726 .62465 .31457 .6363 .31058 .63051 .30323 Mtetra
.63051 .30323 .6363 .31058 .64801 .30657 .64225 .29919 Mtetra
.64225 .29919 .64801 .30657 .65977 .30254 .65404 .29513 Mtetra
.65404 .29513 .65977 .30254 .67157 .2985 .66588 .29106 Mtetra
.66588 .29106 .67157 .2985 .68343 .29444 .67776 .28697 Mtetra
.67776 .28697 .68343 .29444 .69533 .29036 .6897 .28286 Mtetra
.6897 .28286 .69533 .29036 .70728 .28627 .70169 .27873 Mtetra
.70169 .27873 .70728 .28627 .71929 .28216 .71373 .27459 Mtetra
.71373 .27459 .71929 .28216 .73134 .27803 .72582 .27043 Mtetra
.72582 .27043 .73134 .27803 .74345 .27389 .73796 .26626 Mtetra
.73796 .26626 .74345 .27389 .7556 .26973 .75016 .26207 Mtetra
.75016 .26207 .7556 .26973 .76781 .26555 .7624 .25785 Mtetra
.7624 .25785 .76781 .26555 .78007 .26136 .7747 .25363 Mtetra
.7747 .25363 .78007 .26136 .79239 .25714 .78705 .24938 Mtetra
.945 .665 .477 r
.1314 .4679 .13825 .47597 .14881 .46583 .12757 .58129 Mtetra
0 0 0 r
.12757 .58129 .14881 .46583 .15829 .46533 .15136 .45831 Mtetra
.598 .708 .921 r
.15136 .45831 .15829 .46533 .16803 .46296 .16108 .45625 Mtetra
.611 .723 .925 r
.16108 .45625 .16803 .46296 .17776 .46106 .17088 .45388 Mtetra
.446 .643 .942 r
.17088 .45388 .17776 .46106 .18933 .44175 .18042 .4543 Mtetra
0 0 0 r
.18042 .4543 .18933 .44175 .19797 .45118 .19118 .44346 Mtetra
.567 .677 .914 r
.19118 .44346 .19797 .45118 .20787 .44882 .20099 .44206 Mtetra
.623 .728 .922 r
.20099 .44206 .20787 .44882 .21784 .44611 .21098 .43939 Mtetra
.621 .73 .924 r
.21098 .43939 .21784 .44611 .22781 .4439 .22101 .43674 Mtetra
.507 .673 .939 r
.22101 .43674 .22781 .4439 .24129 .4023 .23088 .43625 Mtetra
.324 .035 .31 r
.23088 .43625 .24129 .4023 .24837 .43374 .2417 .42565 Mtetra
.558 .666 .909 r
.2417 .42565 .24837 .43374 .25849 .43127 .25172 .42444 Mtetra
.63 .732 .921 r
.25172 .42444 .25849 .43127 .26868 .42825 .26192 .42155 Mtetra
.639 .74 .921 r
.26192 .42155 .26868 .42825 .27893 .42513 .27219 .41843 Mtetra
.639 .74 .922 r
.27219 .41843 .27893 .42513 .28922 .42213 .28251 .4153 Mtetra
.625 .733 .924 r
.28251 .4153 .28922 .42213 .29948 .42001 .29284 .41249 Mtetra
.362 .595 .935 r
.29284 .41249 .29948 .42001 .31058 .40602 .30291 .41411 Mtetra
.582 .855 .517 r
.30291 .41411 .31058 .40602 .32057 .4092 .31398 .40153 Mtetra
.595 .697 .914 r
.31398 .40153 .32057 .4092 .331 .40632 .32439 .39943 Mtetra
.64 .739 .92 r
.32439 .39943 .331 .40632 .34151 .40298 .33491 .39621 Mtetra
.649 .746 .92 r
.33491 .39621 .34151 .40298 .35207 .39947 .34549 .39274 Mtetra
.653 .749 .92 r
.34549 .39274 .35207 .39947 .36268 .39588 .35612 .38915 Mtetra
.656 .751 .92 r
.35612 .38915 .36268 .39588 .37333 .39221 .3668 .38549 Mtetra
.658 .753 .92 r
.3668 .38549 .37333 .39221 .38402 .3885 .37752 .38176 Mtetra
.659 .753 .92 r
.37752 .38176 .38402 .3885 .39476 .38476 .38828 .378 Mtetra
.659 .754 .92 r
.38828 .378 .39476 .38476 .40554 .381 .39909 .37421 Mtetra
.39909 .37421 .40554 .381 .41636 .37722 .40994 .3704 Mtetra
.40994 .3704 .41636 .37722 .42723 .37344 .42084 .36659 Mtetra
.659 .753 .92 r
.42084 .36659 .42723 .37344 .43814 .36965 .43177 .36277 Mtetra
.658 .753 .92 r
.43177 .36277 .43814 .36965 .44909 .36585 .44275 .35893 Mtetra
.44275 .35893 .44909 .36585 .46009 .36203 .45378 .35509 Mtetra
.45378 .35509 .46009 .36203 .47113 .35821 .46485 .35124 Mtetra
.46485 .35124 .47113 .35821 .48221 .35438 .47596 .34737 Mtetra
.47596 .34737 .48221 .35438 .49334 .35053 .48712 .3435 Mtetra
.48712 .3435 .49334 .35053 .50452 .34667 .49833 .33961 Mtetra
.657 .753 .92 r
.49833 .33961 .50452 .34667 .51574 .34279 .50958 .3357 Mtetra
.50958 .3357 .51574 .34279 .527 .33891 .52087 .33178 Mtetra
.52087 .33178 .527 .33891 .53832 .335 .53222 .32785 Mtetra
.657 .752 .92 r
.53222 .32785 .53832 .335 .54967 .33109 .54361 .3239 Mtetra
.54361 .3239 .54967 .33109 .56108 .32715 .55504 .31994 Mtetra
.55504 .31994 .56108 .32715 .57253 .3232 .56653 .31596 Mtetra
.56653 .31596 .57253 .3232 .58403 .31924 .57806 .31197 Mtetra
.57806 .31197 .58403 .31924 .59558 .31526 .58964 .30796 Mtetra
.58964 .30796 .59558 .31526 .60717 .31127 .60127 .30393 Mtetra
.60127 .30393 .60717 .31127 .61882 .30726 .61294 .29989 Mtetra
.61294 .29989 .61882 .30726 .63051 .30323 .62467 .29583 Mtetra
.62467 .29583 .63051 .30323 .64225 .29919 .63644 .29176 Mtetra
.63644 .29176 .64225 .29919 .65404 .29513 .64826 .28767 Mtetra
.64826 .28767 .65404 .29513 .66588 .29106 .66013 .28356 Mtetra
.66013 .28356 .66588 .29106 .67776 .28697 .67206 .27944 Mtetra
.67206 .27944 .67776 .28697 .6897 .28286 .68403 .2753 Mtetra
.68403 .2753 .6897 .28286 .70169 .27873 .69605 .27114 Mtetra
.69605 .27114 .70169 .27873 .71373 .27459 .70813 .26697 Mtetra
.70813 .26697 .71373 .27459 .72582 .27043 .72026 .26278 Mtetra
.72026 .26278 .72582 .27043 .73796 .26626 .73243 .25857 Mtetra
.73243 .25857 .73796 .26626 .75016 .26207 .74466 .25434 Mtetra
.74466 .25434 .75016 .26207 .7624 .25785 .75695 .2501 Mtetra
.75695 .2501 .7624 .25785 .7747 .25363 .76928 .24584 Mtetra
.76928 .24584 .7747 .25363 .78705 .24938 .78167 .24156 Mtetra
.517 .679 .939 r
.12438 .46087 .1314 .4679 .12757 .58129 .13387 .46022 Mtetra
.565 .354 .553 r
.13387 .46022 .12757 .58129 .15136 .45831 .14452 .45 Mtetra
.527 .642 .907 r
.14452 .45 .15136 .45831 .16108 .45625 .15408 .44944 Mtetra
.613 .722 .923 r
.15408 .44944 .16108 .45625 .17088 .45388 .1639 .44702 Mtetra
.589 .713 .929 r
.1639 .44702 .17088 .45388 .18042 .4543 .17371 .44506 Mtetra
.852 .715 .711 r
.17371 .44506 .18042 .4543 .19118 .44346 .1854 .42562 Mtetra
.137 .223 .691 r
.1854 .42562 .19118 .44346 .20099 .44206 .19409 .43505 Mtetra
.611 .718 .921 r
.19409 .43505 .20099 .44206 .21098 .43939 .20407 .43263 Mtetra
.626 .731 .923 r
.20407 .43263 .21098 .43939 .22101 .43674 .21413 .42985 Mtetra
.602 .72 .928 r
.21413 .42985 .22101 .43674 .23088 .43625 .22418 .42758 Mtetra
.91 .718 .63 r
.22418 .42758 .23088 .43625 .2417 .42565 .23782 .38577 Mtetra
0 0 .426 r
.23782 .38577 .2417 .42565 .25172 .42444 .24492 .41729 Mtetra
.614 .718 .919 r
.24492 .41729 .25172 .42444 .26192 .42155 .25512 .41475 Mtetra
.636 .737 .921 r
.25512 .41475 .26192 .42155 .27219 .41843 .26541 .41167 Mtetra
.64 .74 .922 r
.26541 .41167 .27219 .41843 .28251 .4153 .27574 .40849 Mtetra
.635 .738 .923 r
.27574 .40849 .28251 .4153 .29284 .41249 .28611 .40542 Mtetra
.595 .717 .929 r
.28611 .40542 .29284 .41249 .30291 .41411 .29647 .40324 Mtetra
.809 .697 .74 r
.29647 .40324 .30291 .41411 .31398 .40153 .30767 .38915 Mtetra
.381 .473 .829 r
.30767 .38915 .31398 .40153 .32439 .39943 .31774 .39229 Mtetra
.628 .728 .919 r
.31774 .39229 .32439 .39943 .33491 .39621 .32827 .38934 Mtetra
.646 .743 .92 r
.32827 .38934 .33491 .39621 .34549 .39274 .33887 .38593 Mtetra
.652 .748 .92 r
.33887 .38593 .34549 .39274 .35612 .38915 .34952 .38236 Mtetra
.655 .75 .92 r
.34952 .38236 .35612 .38915 .3668 .38549 .36022 .3787 Mtetra
.657 .752 .92 r
.36022 .3787 .3668 .38549 .37752 .38176 .37097 .37496 Mtetra
.658 .753 .92 r
.37097 .37496 .37752 .38176 .38828 .378 .38176 .37118 Mtetra
.659 .754 .92 r
.38176 .37118 .38828 .378 .39909 .37421 .3926 .36737 Mtetra
.3926 .36737 .39909 .37421 .40994 .3704 .40348 .36354 Mtetra
.40348 .36354 .40994 .3704 .42084 .36659 .4144 .35969 Mtetra
.4144 .35969 .42084 .36659 .43177 .36277 .42536 .35583 Mtetra
.658 .753 .92 r
.42536 .35583 .43177 .36277 .44275 .35893 .43637 .35197 Mtetra
.43637 .35197 .44275 .35893 .45378 .35509 .44743 .3481 Mtetra
.44743 .3481 .45378 .35509 .46485 .35124 .45852 .34421 Mtetra
.45852 .34421 .46485 .35124 .47596 .34737 .46967 .34032 Mtetra
.46967 .34032 .47596 .34737 .48712 .3435 .48086 .33641 Mtetra
.48086 .33641 .48712 .3435 .49833 .33961 .49209 .33249 Mtetra
.49209 .33249 .49833 .33961 .50958 .3357 .50337 .32855 Mtetra
.657 .753 .92 r
.50337 .32855 .50958 .3357 .52087 .33178 .5147 .3246 Mtetra
.5147 .3246 .52087 .33178 .53222 .32785 .52607 .32064 Mtetra
.657 .752 .92 r
.52607 .32064 .53222 .32785 .54361 .3239 .53749 .31666 Mtetra
.53749 .31666 .54361 .3239 .55504 .31994 .54896 .31267 Mtetra
.54896 .31267 .55504 .31994 .56653 .31596 .56048 .30866 Mtetra
.56048 .30866 .56653 .31596 .57806 .31197 .57204 .30463 Mtetra
.57204 .30463 .57806 .31197 .58964 .30796 .58365 .30059 Mtetra
.58365 .30059 .58964 .30796 .60127 .30393 .59531 .29654 Mtetra
.59531 .29654 .60127 .30393 .61294 .29989 .60702 .29246 Mtetra
.60702 .29246 .61294 .29989 .62467 .29583 .61878 .28837 Mtetra
.61878 .28837 .62467 .29583 .63644 .29176 .63059 .28427 Mtetra
.63059 .28427 .63644 .29176 .64826 .28767 .64244 .28015 Mtetra
.64244 .28015 .64826 .28767 .66013 .28356 .65435 .27601 Mtetra
.65435 .27601 .66013 .28356 .67206 .27944 .66631 .27185 Mtetra
.66631 .27185 .67206 .27944 .68403 .2753 .67832 .26768 Mtetra
.67832 .26768 .68403 .2753 .69605 .27114 .69037 .26349 Mtetra
.69037 .26349 .69605 .27114 .70813 .26697 .70248 .25928 Mtetra
.70248 .25928 .70813 .26697 .72026 .26278 .71465 .25506 Mtetra
.71465 .25506 .72026 .26278 .73243 .25857 .72686 .25082 Mtetra
.72686 .25082 .73243 .25857 .74466 .25434 .73913 .24656 Mtetra
.73913 .24656 .74466 .25434 .75695 .2501 .75145 .24228 Mtetra
.75145 .24228 .75695 .2501 .76928 .24584 .76382 .23798 Mtetra
.76382 .23798 .76928 .24584 .78167 .24156 .77624 .23367 Mtetra
.592 .714 .928 r
.11728 .45402 .12438 .46087 .13387 .46022 .12694 .45203 Mtetra
.946 .665 .474 r
.12694 .45203 .13387 .46022 .14452 .45 .12291 .56589 Mtetra
0 0 0 r
.12291 .56589 .14452 .45 .15408 .44944 .14707 .4423 Mtetra
.598 .708 .921 r
.14707 .4423 .15408 .44944 .1639 .44702 .15687 .44019 Mtetra
.611 .723 .925 r
.15687 .44019 .1639 .44702 .17371 .44506 .16675 .43776 Mtetra
.446 .643 .941 r
.16675 .43776 .17371 .44506 .1854 .42562 .17637 .43813 Mtetra
0 0 0 r
.17637 .43813 .1854 .42562 .19409 .43505 .18723 .4272 Mtetra
.567 .677 .914 r
.18723 .4272 .19409 .43505 .20407 .43263 .19712 .42575 Mtetra
.623 .728 .922 r
.19712 .42575 .20407 .43263 .21413 .42985 .20719 .42301 Mtetra
.621 .73 .924 r
.20719 .42301 .21413 .42985 .22418 .42758 .2173 .42031 Mtetra
.508 .673 .939 r
.2173 .42031 .22418 .42758 .23782 .38577 .22726 .41976 Mtetra
.316 .024 .301 r
.22726 .41976 .23782 .38577 .24492 .41729 .23817 .40907 Mtetra
.558 .666 .909 r
.23817 .40907 .24492 .41729 .25512 .41475 .24828 .4078 Mtetra
.63 .732 .921 r
.24828 .4078 .25512 .41475 .26541 .41167 .25857 .40485 Mtetra
.639 .74 .921 r
.25857 .40485 .26541 .41167 .27574 .40849 .26893 .40166 Mtetra
.639 .74 .922 r
.26893 .40166 .27574 .40849 .28611 .40542 .27933 .39847 Mtetra
.625 .733 .924 r
.27933 .39847 .28611 .40542 .29647 .40324 .28975 .39559 Mtetra
.363 .595 .935 r
.28975 .39559 .29647 .40324 .30767 .38915 .29991 .39717 Mtetra
.594 .864 .528 r
.29991 .39717 .30767 .38915 .31774 .39229 .31109 .38449 Mtetra
.595 .697 .914 r
.31109 .38449 .31774 .39229 .32827 .38934 .32159 .38232 Mtetra
.64 .739 .92 r
.32159 .38232 .32827 .38934 .33887 .38593 .3322 .37904 Mtetra
.649 .746 .92 r
.3322 .37904 .33887 .38593 .34952 .38236 .34288 .3755 Mtetra
.653 .749 .92 r
.34288 .3755 .34952 .38236 .36022 .3787 .3536 .37184 Mtetra
.656 .751 .92 r
.3536 .37184 .36022 .3787 .37097 .37496 .36437 .36811 Mtetra
.658 .753 .92 r
.36437 .36811 .37097 .37496 .38176 .37118 .37519 .36431 Mtetra
.659 .753 .92 r
.37519 .36431 .38176 .37118 .3926 .36737 .38605 .36048 Mtetra
.659 .754 .92 r
.38605 .36048 .3926 .36737 .40348 .36354 .39696 .35662 Mtetra
.39696 .35662 .40348 .36354 .4144 .35969 .40791 .35274 Mtetra
.40791 .35274 .4144 .35969 .42536 .35583 .4189 .34885 Mtetra
.659 .753 .92 r
.4189 .34885 .42536 .35583 .43637 .35197 .42994 .34496 Mtetra
.658 .753 .92 r
.42994 .34496 .43637 .35197 .44743 .3481 .44102 .34105 Mtetra
.44102 .34105 .44743 .3481 .45852 .34421 .45215 .33714 Mtetra
.45215 .33714 .45852 .34421 .46967 .34032 .46333 .33321 Mtetra
.46333 .33321 .46967 .34032 .48086 .33641 .47454 .32927 Mtetra
.47454 .32927 .48086 .33641 .49209 .33249 .48581 .32532 Mtetra
.48581 .32532 .49209 .33249 .50337 .32855 .49712 .32135 Mtetra
.657 .753 .92 r
.49712 .32135 .50337 .32855 .5147 .3246 .50848 .31737 Mtetra
.50848 .31737 .5147 .3246 .52607 .32064 .51988 .31338 Mtetra
.51988 .31338 .52607 .32064 .53749 .31666 .53133 .30937 Mtetra
.657 .752 .92 r
.53133 .30937 .53749 .31666 .54896 .31267 .54283 .30534 Mtetra
.54283 .30534 .54896 .31267 .56048 .30866 .55438 .3013 Mtetra
.55438 .3013 .56048 .30866 .57204 .30463 .56598 .29725 Mtetra
.56598 .29725 .57204 .30463 .58365 .30059 .57762 .29317 Mtetra
.57762 .29317 .58365 .30059 .59531 .29654 .58931 .28908 Mtetra
.58931 .28908 .59531 .29654 .60702 .29246 .60105 .28498 Mtetra
.60105 .28498 .60702 .29246 .61878 .28837 .61285 .28086 Mtetra
.61285 .28086 .61878 .28837 .63059 .28427 .62469 .27672 Mtetra
.62469 .27672 .63059 .28427 .64244 .28015 .63658 .27257 Mtetra
.63658 .27257 .64244 .28015 .65435 .27601 .64852 .2684 Mtetra
.64852 .2684 .65435 .27601 .66631 .27185 .66051 .26421 Mtetra
.66051 .26421 .66631 .27185 .67832 .26768 .67255 .26 Mtetra
.67255 .26 .67832 .26768 .69037 .26349 .68465 .25578 Mtetra
.68465 .25578 .69037 .26349 .70248 .25928 .69679 .25154 Mtetra
.69679 .25154 .70248 .25928 .71465 .25506 .70899 .24728 Mtetra
.70899 .24728 .71465 .25506 .72686 .25082 .72124 .243 Mtetra
.72124 .243 .72686 .25082 .73913 .24656 .73355 .23871 Mtetra
.73355 .23871 .73913 .24656 .75145 .24228 .7459 .2344 Mtetra
.7459 .2344 .75145 .24228 .76382 .23798 .75831 .23007 Mtetra
.75831 .23007 .76382 .23798 .77624 .23367 .77078 .22572 Mtetra
.602 .716 .925 r
.11014 .4471 .11728 .45402 .12694 .45203 .11984 .44488 Mtetra
.517 .679 .938 r
.11984 .44488 .12694 .45203 .12291 .56589 .12941 .44419 Mtetra
.563 .35 .55 r
.12941 .44419 .12291 .56589 .14707 .4423 .14016 .43387 Mtetra
.527 .643 .907 r
.14016 .43387 .14707 .4423 .15687 .44019 .1498 .43326 Mtetra
.613 .722 .923 r
.1498 .43326 .15687 .44019 .16675 .43776 .1597 .43078 Mtetra
.589 .713 .929 r
.1597 .43078 .16675 .43776 .17637 .43813 .16959 .42877 Mtetra
.853 .716 .711 r
.16959 .42877 .17637 .43813 .18723 .4272 .18139 .4092 Mtetra
.133 .221 .69 r
.18139 .4092 .18723 .4272 .19712 .42575 .19014 .41861 Mtetra
.611 .718 .921 r
.19014 .41861 .19712 .42575 .20719 .42301 .20021 .41613 Mtetra
.626 .731 .923 r
.20021 .41613 .20719 .42301 .2173 .42031 .21035 .4133 Mtetra
.602 .72 .928 r
.21035 .4133 .2173 .42031 .22726 .41976 .22048 .41097 Mtetra
.911 .718 .629 r
.22048 .41097 .22726 .41976 .23817 .40907 .23428 .36894 Mtetra
0 0 .422 r
.23428 .36894 .23817 .40907 .24828 .4078 .24141 .40052 Mtetra
.614 .718 .92 r
.24141 .40052 .24828 .4078 .25857 .40485 .25169 .39793 Mtetra
.636 .737 .921 r
.25169 .39793 .25857 .40485 .26893 .40166 .26207 .39478 Mtetra
.64 .74 .922 r
.26207 .39478 .26893 .40166 .27933 .39847 .27249 .39154 Mtetra
.635 .738 .923 r
.27249 .39154 .27933 .39847 .28975 .39559 .28295 .3884 Mtetra
.595 .717 .929 r
.28295 .3884 .28975 .39559 .29991 .39717 .2934 .38616 Mtetra
.81 .697 .741 r
.2934 .38616 .29991 .39717 .31109 .38449 .30471 .37196 Mtetra
.38 .472 .829 r
.30471 .37196 .31109 .38449 .32159 .38232 .31487 .37505 Mtetra
.628 .728 .919 r
.31487 .37505 .32159 .38232 .3322 .37904 .32549 .37204 Mtetra
.646 .743 .92 r
.32549 .37204 .3322 .37904 .34288 .3755 .33618 .36856 Mtetra
.652 .748 .92 r
.33618 .36856 .34288 .3755 .3536 .37184 .34693 .36492 Mtetra
.655 .75 .92 r
.34693 .36492 .3536 .37184 .36437 .36811 .35773 .36119 Mtetra
.657 .752 .92 r
.35773 .36119 .36437 .36811 .37519 .36431 .36857 .35738 Mtetra
.658 .753 .92 r
.36857 .35738 .37519 .36431 .38605 .36048 .37946 .35353 Mtetra
.659 .754 .92 r
.37946 .35353 .38605 .36048 .39696 .35662 .39039 .34965 Mtetra
.39039 .34965 .39696 .35662 .40791 .35274 .40137 .34574 Mtetra
.40137 .34574 .40791 .35274 .4189 .34885 .4124 .34182 Mtetra
.4124 .34182 .4189 .34885 .42994 .34496 .42346 .33789 Mtetra
.658 .753 .92 r
.42346 .33789 .42994 .34496 .44102 .34105 .43457 .33395 Mtetra
.43457 .33395 .44102 .34105 .45215 .33714 .44573 .33001 Mtetra
.44573 .33001 .45215 .33714 .46333 .33321 .45693 .32605 Mtetra
.45693 .32605 .46333 .33321 .47454 .32927 .46818 .32208 Mtetra
.46818 .32208 .47454 .32927 .48581 .32532 .47948 .31809 Mtetra
.47948 .31809 .48581 .32532 .49712 .32135 .49082 .3141 Mtetra
.49082 .3141 .49712 .32135 .50848 .31737 .50221 .31008 Mtetra
.657 .753 .92 r
.50221 .31008 .50848 .31737 .51988 .31338 .51364 .30606 Mtetra
.51364 .30606 .51988 .31338 .53133 .30937 .52513 .30202 Mtetra
.657 .752 .92 r
.52513 .30202 .53133 .30937 .54283 .30534 .53666 .29796 Mtetra
.53666 .29796 .54283 .30534 .55438 .3013 .54824 .29389 Mtetra
.54824 .29389 .55438 .3013 .56598 .29725 .55986 .2898 Mtetra
.55986 .2898 .56598 .29725 .57762 .29317 .57154 .2857 Mtetra
.57154 .2857 .57762 .29317 .58931 .28908 .58327 .28157 Mtetra
.58327 .28157 .58931 .28908 .60105 .28498 .59504 .27744 Mtetra
.59504 .27744 .60105 .28498 .61285 .28086 .60687 .27328 Mtetra
.60687 .27328 .61285 .28086 .62469 .27672 .61874 .26911 Mtetra
.61874 .26911 .62469 .27672 .63658 .27257 .63067 .26493 Mtetra
.63067 .26493 .63658 .27257 .64852 .2684 .64264 .26072 Mtetra
.64264 .26072 .64852 .2684 .66051 .26421 .65467 .2565 Mtetra
.65467 .2565 .66051 .26421 .67255 .26 .66675 .25226 Mtetra
.66675 .25226 .67255 .26 .68465 .25578 .67888 .248 Mtetra
.67888 .248 .68465 .25578 .69679 .25154 .69106 .24373 Mtetra
.69106 .24373 .69679 .25154 .70899 .24728 .70329 .23944 Mtetra
.70329 .23944 .70899 .24728 .72124 .243 .71558 .23513 Mtetra
.71558 .23513 .72124 .243 .73355 .23871 .72792 .2308 Mtetra
.72792 .2308 .73355 .23871 .7459 .2344 .74032 .22645 Mtetra
.74032 .22645 .7459 .2344 .75831 .23007 .75276 .22209 Mtetra
.75276 .22209 .75831 .23007 .77078 .22572 .76527 .2177 Mtetra
.587 .701 .922 r
.10299 .43982 .11014 .4471 .11984 .44488 .11266 .43792 Mtetra
.592 .714 .928 r
.11266 .43792 .11984 .44488 .12941 .44419 .12241 .43587 Mtetra
.947 .665 .471 r
.12241 .43587 .12941 .44419 .14016 .43387 .11816 .55019 Mtetra
0 0 0 r
.11816 .55019 .14016 .43387 .1498 .43326 .14271 .42601 Mtetra
.598 .708 .921 r
.14271 .42601 .1498 .43326 .1597 .43078 .15259 .42384 Mtetra
.611 .723 .925 r
.15259 .42384 .1597 .43078 .16959 .42877 .16254 .42135 Mtetra
.447 .643 .941 r
.16254 .42135 .16959 .42877 .18139 .4092 .17224 .42167 Mtetra
0 0 0 r
.17224 .42167 .18139 .4092 .19014 .41861 .1832 .41064 Mtetra
.567 .677 .914 r
.1832 .41064 .19014 .41861 .20021 .41613 .19318 .40913 Mtetra
.623 .728 .922 r
.19318 .40913 .20021 .41613 .21035 .4133 .20333 .40633 Mtetra
.621 .73 .924 r
.20333 .40633 .21035 .4133 .22048 .41097 .21353 .40357 Mtetra
.508 .673 .939 r
.21353 .40357 .22048 .41097 .23428 .36894 .22357 .40297 Mtetra
.307 .014 .292 r
.22357 .40297 .23428 .36894 .24141 .40052 .23458 .39218 Mtetra
.558 .666 .909 r
.23458 .39218 .24141 .40052 .25169 .39793 .24477 .39085 Mtetra
.63 .732 .921 r
.24477 .39085 .25169 .39793 .26207 .39478 .25515 .38784 Mtetra
.639 .74 .921 r
.25515 .38784 .26207 .39478 .27249 .39154 .2656 .38458 Mtetra
.639 .74 .922 r
.2656 .38458 .27249 .39154 .28295 .3884 .2761 .38132 Mtetra
.625 .733 .924 r
.2761 .38132 .28295 .3884 .2934 .38616 .28661 .37838 Mtetra
.364 .595 .935 r
.28661 .37838 .2934 .38616 .30471 .37196 .29685 .37991 Mtetra
.605 .872 .54 r
.29685 .37991 .30471 .37196 .31487 .37505 .30814 .36712 Mtetra
.595 .697 .914 r
.30814 .36712 .31487 .37505 .32549 .37204 .31873 .36489 Mtetra
.64 .739 .92 r
.31873 .36489 .32549 .37204 .33618 .36856 .32944 .36154 Mtetra
.649 .746 .92 r
.32944 .36154 .33618 .36856 .34693 .36492 .34021 .35793 Mtetra
.653 .749 .92 r
.34021 .35793 .34693 .36492 .35773 .36119 .35103 .3542 Mtetra
.656 .751 .92 r
.35103 .3542 .35773 .36119 .36857 .35738 .3619 .35039 Mtetra
.658 .753 .92 r
.3619 .35039 .36857 .35738 .37946 .35353 .37282 .34653 Mtetra
.659 .753 .92 r
.37282 .34653 .37946 .35353 .39039 .34965 .38378 .34262 Mtetra
.659 .754 .92 r
.38378 .34262 .39039 .34965 .40137 .34574 .39479 .33869 Mtetra
.39479 .33869 .40137 .34574 .4124 .34182 .40584 .33474 Mtetra
.40584 .33474 .4124 .34182 .42346 .33789 .41693 .33077 Mtetra
.659 .753 .92 r
.41693 .33077 .42346 .33789 .43457 .33395 .42807 .3268 Mtetra
.658 .753 .92 r
.42807 .3268 .43457 .33395 .44573 .33001 .43926 .32282 Mtetra
.43926 .32282 .44573 .33001 .45693 .32605 .45049 .31883 Mtetra
.45049 .31883 .45693 .32605 .46818 .32208 .46177 .31483 Mtetra
.46177 .31483 .46818 .32208 .47948 .31809 .4731 .31081 Mtetra
.4731 .31081 .47948 .31809 .49082 .3141 .48447 .30678 Mtetra
.48447 .30678 .49082 .3141 .50221 .31008 .49589 .30274 Mtetra
.657 .753 .92 r
.49589 .30274 .50221 .31008 .51364 .30606 .50736 .29868 Mtetra
.50736 .29868 .51364 .30606 .52513 .30202 .51887 .29461 Mtetra
.51887 .29461 .52513 .30202 .53666 .29796 .53043 .29052 Mtetra
.657 .752 .92 r
.53043 .29052 .53666 .29796 .54824 .29389 .54204 .28642 Mtetra
.54204 .28642 .54824 .29389 .55986 .2898 .5537 .2823 Mtetra
.5537 .2823 .55986 .2898 .57154 .2857 .56541 .27816 Mtetra
.56541 .27816 .57154 .2857 .58327 .28157 .57717 .27401 Mtetra
.57717 .27401 .58327 .28157 .59504 .27744 .58898 .26984 Mtetra
.58898 .26984 .59504 .27744 .60687 .27328 .60084 .26565 Mtetra
.60084 .26565 .60687 .27328 .61874 .26911 .61275 .26145 Mtetra
.61275 .26145 .61874 .26911 .63067 .26493 .62471 .25723 Mtetra
.62471 .25723 .63067 .26493 .64264 .26072 .63672 .25299 Mtetra
.63672 .25299 .64264 .26072 .65467 .2565 .64878 .24873 Mtetra
.64878 .24873 .65467 .2565 .66675 .25226 .66089 .24446 Mtetra
.66089 .24446 .66675 .25226 .67888 .248 .67306 .24017 Mtetra
.67306 .24017 .67888 .248 .69106 .24373 .68528 .23586 Mtetra
.68528 .23586 .69106 .24373 .70329 .23944 .69755 .23153 Mtetra
.69755 .23153 .70329 .23944 .71558 .23513 .70987 .22719 Mtetra
.70987 .22719 .71558 .23513 .72792 .2308 .72225 .22282 Mtetra
.72225 .22282 .72792 .2308 .74032 .22645 .73468 .21844 Mtetra
.73468 .21844 .74032 .22645 .75276 .22209 .74717 .21404 Mtetra
.74717 .21404 .75276 .22209 .76527 .2177 .75971 .20962 Mtetra
.491 .613 .9 r
.09601 .43083 .10299 .43982 .11266 .43792 .10544 .43088 Mtetra
.602 .716 .925 r
.10544 .43088 .11266 .43792 .12241 .43587 .11523 .4286 Mtetra
.517 .679 .938 r
.11523 .4286 .12241 .43587 .11816 .55019 .12487 .42786 Mtetra
.56 .347 .548 r
.12487 .42786 .11816 .55019 .14271 .42601 .13572 .41745 Mtetra
.526 .643 .907 r
.13572 .41745 .14271 .42601 .15259 .42384 .14543 .41679 Mtetra
.613 .722 .923 r
.14543 .41679 .15259 .42384 .16254 .42135 .15541 .41424 Mtetra
.589 .713 .929 r
.15541 .41424 .16254 .42135 .17224 .42167 .16539 .41217 Mtetra
.853 .716 .711 r
.16539 .41217 .17224 .42167 .1832 .41064 .17731 .39247 Mtetra
.129 .218 .689 r
.17731 .39247 .1832 .41064 .19318 .40913 .18612 .40187 Mtetra
.611 .718 .921 r
.18612 .40187 .19318 .40913 .20333 .40633 .19627 .39933 Mtetra
.626 .731 .923 r
.19627 .39933 .20333 .40633 .21353 .40357 .20649 .39643 Mtetra
.602 .72 .928 r
.20649 .39643 .21353 .40357 .22357 .40297 .21672 .39404 Mtetra
.913 .719 .628 r
.21672 .39404 .22357 .40297 .23458 .39218 .23068 .35179 Mtetra
0 0 .418 r
.23068 .35179 .23458 .39218 .24477 .39085 .23783 .38345 Mtetra
.614 .718 .92 r
.23783 .38345 .24477 .39085 .25515 .38784 .2482 .38079 Mtetra
.636 .737 .921 r
.2482 .38079 .25515 .38784 .2656 .38458 .25866 .37758 Mtetra
.64 .74 .922 r
.25866 .37758 .2656 .38458 .2761 .38132 .26918 .37426 Mtetra
.635 .738 .923 r
.26918 .37426 .2761 .38132 .28661 .37838 .27973 .37106 Mtetra
.595 .717 .929 r
.27973 .37106 .28661 .37838 .29685 .37991 .29027 .36875 Mtetra
.811 .698 .741 r
.29027 .36875 .29685 .37991 .30814 .36712 .30169 .35444 Mtetra
.379 .472 .829 r
.30169 .35444 .30814 .36712 .31873 .36489 .31193 .35749 Mtetra
.628 .728 .919 r
.31193 .35749 .31873 .36489 .32944 .36154 .32265 .35441 Mtetra
.646 .743 .92 r
.32265 .35441 .32944 .36154 .34021 .35793 .33344 .35086 Mtetra
.652 .748 .92 r
.33344 .35086 .34021 .35793 .35103 .3542 .34429 .34715 Mtetra
.655 .75 .92 r
.34429 .34715 .35103 .3542 .3619 .35039 .35518 .34334 Mtetra
.657 .752 .92 r
.35518 .34334 .3619 .35039 .37282 .34653 .36612 .33946 Mtetra
.658 .753 .92 r
.36612 .33946 .37282 .34653 .38378 .34262 .37711 .33554 Mtetra
.659 .754 .92 r
.37711 .33554 .38378 .34262 .39479 .33869 .38815 .33158 Mtetra
.38815 .33158 .39479 .33869 .40584 .33474 .39923 .3276 Mtetra
.39923 .3276 .40584 .33474 .41693 .33077 .41035 .3236 Mtetra
.41035 .3236 .41693 .33077 .42807 .3268 .42152 .3196 Mtetra
.658 .753 .92 r
.42152 .3196 .42807 .3268 .43926 .32282 .43274 .31559 Mtetra
.43274 .31559 .43926 .32282 .45049 .31883 .444 .31156 Mtetra
.444 .31156 .45049 .31883 .46177 .31483 .45531 .30753 Mtetra
.45531 .30753 .46177 .31483 .4731 .31081 .46667 .30348 Mtetra
.46667 .30348 .4731 .31081 .48447 .30678 .47807 .29942 Mtetra
.47807 .29942 .48447 .30678 .49589 .30274 .48952 .29534 Mtetra
.48952 .29534 .49589 .30274 .50736 .29868 .50102 .29125 Mtetra
.657 .753 .92 r
.50102 .29125 .50736 .29868 .51887 .29461 .51257 .28715 Mtetra
.51257 .28715 .51887 .29461 .53043 .29052 .52416 .28302 Mtetra
.657 .752 .92 r
.52416 .28302 .53043 .29052 .54204 .28642 .5358 .27889 Mtetra
.5358 .27889 .54204 .28642 .5537 .2823 .5475 .27473 Mtetra
.5475 .27473 .5537 .2823 .56541 .27816 .55924 .27056 Mtetra
.55924 .27056 .56541 .27816 .57717 .27401 .57103 .26638 Mtetra
.57103 .26638 .57717 .27401 .58898 .26984 .58287 .26218 Mtetra
.58287 .26218 .58898 .26984 .60084 .26565 .59477 .25796 Mtetra
.59477 .25796 .60084 .26565 .61275 .26145 .60671 .25372 Mtetra
.60671 .25372 .61275 .26145 .62471 .25723 .6187 .24946 Mtetra
.6187 .24946 .62471 .25723 .63672 .25299 .63075 .24519 Mtetra
.63075 .24519 .63672 .25299 .64878 .24873 .64285 .2409 Mtetra
.64285 .2409 .64878 .24873 .66089 .24446 .65499 .2366 Mtetra
.65499 .2366 .66089 .24446 .67306 .24017 .6672 .23227 Mtetra
.6672 .23227 .67306 .24017 .68528 .23586 .67945 .22793 Mtetra
.67945 .22793 .68528 .23586 .69755 .23153 .69176 .22357 Mtetra
.69176 .22357 .69755 .23153 .70987 .22719 .70412 .21919 Mtetra
.70412 .21919 .70987 .22719 .72225 .22282 .71654 .21479 Mtetra
.71654 .21479 .72225 .22282 .73468 .21844 .72901 .21037 Mtetra
.72901 .21037 .73468 .21844 .74717 .21404 .74153 .20593 Mtetra
.74153 .20593 .74717 .21404 .75971 .20962 .75411 .20148 Mtetra
.786 .876 .447 r
.08523 .44978 .09601 .43083 .10544 .43088 .09821 .42348 Mtetra
.587 .701 .922 r
.09821 .42348 .10544 .43088 .11523 .4286 .10797 .42152 Mtetra
.592 .714 .928 r
.10797 .42152 .11523 .4286 .12487 .42786 .11779 .41941 Mtetra
.948 .665 .468 r
.11779 .41941 .12487 .42786 .13572 .41745 .11332 .5342 Mtetra
0 0 0 r
.11332 .5342 .13572 .41745 .14543 .41679 .13826 .40941 Mtetra
.598 .708 .921 r
.13826 .40941 .14543 .41679 .15541 .41424 .14822 .40718 Mtetra
.611 .723 .925 r
.14822 .40718 .15541 .41424 .16539 .41217 .15826 .40463 Mtetra
.448 .643 .941 r
.15826 .40463 .16539 .41217 .17731 .39247 .16804 .4049 Mtetra
0 0 0 r
.16804 .4049 .17731 .39247 .18612 .40187 .1791 .39377 Mtetra
.567 .677 .914 r
.1791 .39377 .18612 .40187 .19627 .39933 .18916 .39221 Mtetra
.623 .728 .922 r
.18916 .39221 .19627 .39933 .20649 .39643 .1994 .38934 Mtetra
.621 .73 .924 r
.1994 .38934 .20649 .39643 .21672 .39404 .20968 .38651 Mtetra
.508 .673 .939 r
.20968 .38651 .21672 .39404 .23068 .35179 .2198 .38586 Mtetra
.299 .003 .283 r
.2198 .38586 .23068 .35179 .23783 .38345 .23093 .37497 Mtetra
.558 .666 .909 r
.23093 .37497 .23783 .38345 .2482 .38079 .2412 .37358 Mtetra
.63 .732 .921 r
.2412 .37358 .2482 .38079 .25866 .37758 .25167 .3705 Mtetra
.639 .74 .921 r
.25167 .3705 .25866 .37758 .26918 .37426 .26221 .36718 Mtetra
.639 .74 .922 r
.26221 .36718 .26918 .37426 .27973 .37106 .2728 .36385 Mtetra
.625 .733 .924 r
.2728 .36385 .27973 .37106 .29027 .36875 .2834 .36084 Mtetra
.366 .596 .934 r
.2834 .36084 .29027 .36875 .30169 .35444 .29373 .36231 Mtetra
.616 .881 .551 r
.29373 .36231 .30169 .35444 .31193 .35749 .30513 .34942 Mtetra
.594 .697 .915 r
.30513 .34942 .31193 .35749 .32265 .35441 .31581 .34713 Mtetra
.64 .739 .92 r
.31581 .34713 .32265 .35441 .33344 .35086 .32662 .3437 Mtetra
.649 .746 .92 r
.32662 .3437 .33344 .35086 .34429 .34715 .33749 .34002 Mtetra
.653 .749 .92 r
.33749 .34002 .34429 .34715 .35518 .34334 .34841 .33622 Mtetra
.656 .751 .92 r
.34841 .33622 .35518 .34334 .36612 .33946 .35938 .33234 Mtetra
.658 .753 .92 r
.35938 .33234 .36612 .33946 .37711 .33554 .3704 .3284 Mtetra
.659 .753 .92 r
.3704 .3284 .37711 .33554 .38815 .33158 .38146 .32442 Mtetra
.659 .754 .92 r
.38146 .32442 .38815 .33158 .39923 .3276 .39257 .32041 Mtetra
.39257 .32041 .39923 .3276 .41035 .3236 .40372 .31638 Mtetra
.40372 .31638 .41035 .3236 .42152 .3196 .41492 .31234 Mtetra
.659 .753 .92 r
.41492 .31234 .42152 .3196 .43274 .31559 .42617 .30829 Mtetra
.658 .753 .92 r
.42617 .30829 .43274 .31559 .444 .31156 .43746 .30424 Mtetra
.43746 .30424 .444 .31156 .45531 .30753 .4488 .30017 Mtetra
.4488 .30017 .45531 .30753 .46667 .30348 .46019 .29609 Mtetra
.46019 .29609 .46667 .30348 .47807 .29942 .47162 .29199 Mtetra
.47162 .29199 .47807 .29942 .48952 .29534 .4831 .28788 Mtetra
.4831 .28788 .48952 .29534 .50102 .29125 .49463 .28376 Mtetra
.657 .753 .92 r
.49463 .28376 .50102 .29125 .51257 .28715 .50621 .27962 Mtetra
.50621 .27962 .51257 .28715 .52416 .28302 .51784 .27547 Mtetra
.51784 .27547 .52416 .28302 .5358 .27889 .52951 .2713 Mtetra
.657 .752 .92 r
.52951 .2713 .5358 .27889 .5475 .27473 .54124 .26711 Mtetra
.54124 .26711 .5475 .27473 .55924 .27056 .55302 .26291 Mtetra
.55302 .26291 .55924 .27056 .57103 .26638 .56484 .25869 Mtetra
.56484 .25869 .57103 .26638 .58287 .26218 .57672 .25445 Mtetra
.57672 .25445 .58287 .26218 .59477 .25796 .58864 .2502 Mtetra
.58864 .2502 .59477 .25796 .60671 .25372 .60062 .24593 Mtetra
.60062 .24593 .60671 .25372 .6187 .24946 .61265 .24164 Mtetra
.61265 .24164 .6187 .24946 .63075 .24519 .62473 .23733 Mtetra
.62473 .23733 .63075 .24519 .64285 .2409 .63686 .23301 Mtetra
.63686 .23301 .64285 .2409 .65499 .2366 .64905 .22867 Mtetra
.64905 .22867 .65499 .2366 .6672 .23227 .66129 .22431 Mtetra
.66129 .22431 .6672 .23227 .67945 .22793 .67358 .21993 Mtetra
.67358 .21993 .67945 .22793 .69176 .22357 .68592 .21553 Mtetra
.68592 .21553 .69176 .22357 .70412 .21919 .69832 .21112 Mtetra
.69832 .21112 .70412 .21919 .71654 .21479 .71077 .20668 Mtetra
.71077 .20668 .71654 .21479 .72901 .21037 .72328 .20223 Mtetra
.72328 .20223 .72901 .21037 .74153 .20593 .73584 .19776 Mtetra
.73584 .19776 .74153 .20593 .75411 .20148 .74846 .19327 Mtetra
.68 .526 .669 r
.08026 .42493 .08523 .44978 .09821 .42348 .09115 .41436 Mtetra
.491 .613 .9 r
.09115 .41436 .09821 .42348 .10797 .42152 .10066 .41436 Mtetra
.602 .716 .925 r
.10066 .41436 .10797 .42152 .11779 .41941 .11052 .41202 Mtetra
.518 .679 .938 r
.11052 .41202 .11779 .41941 .11332 .5342 .12024 .41122 Mtetra
.558 .343 .545 r
.12024 .41122 .11332 .5342 .13826 .40941 .1312 .40072 Mtetra
.526 .643 .907 r
.1312 .40072 .13826 .40941 .14822 .40718 .14099 .4 Mtetra
.613 .722 .923 r
.14099 .4 .14822 .40718 .15826 .40463 .15105 .3974 Mtetra
.589 .713 .929 r
.15105 .3974 .15826 .40463 .16804 .4049 .1611 .39526 Mtetra
.854 .717 .711 r
.1611 .39526 .16804 .4049 .1791 .39377 .17316 .37543 Mtetra
.126 .216 .688 r
.17316 .37543 .1791 .39377 .18916 .39221 .18202 .38482 Mtetra
.611 .718 .921 r
.18202 .38482 .18916 .39221 .1994 .38934 .19225 .38221 Mtetra
.626 .731 .923 r
.19225 .38221 .1994 .38934 .20968 .38651 .20257 .37925 Mtetra
.602 .72 .928 r
.20257 .37925 .20968 .38651 .2198 .38586 .21288 .37679 Mtetra
.914 .72 .627 r
.21288 .37679 .2198 .38586 .23093 .37497 .22701 .33432 Mtetra
0 0 .414 r
.22701 .33432 .23093 .37497 .2412 .37358 .23418 .36605 Mtetra
.614 .718 .92 r
.23418 .36605 .2412 .37358 .25167 .3705 .24464 .36332 Mtetra
.636 .737 .921 r
.24464 .36332 .25167 .3705 .26221 .36718 .2552 .36004 Mtetra
.64 .74 .922 r
.2552 .36004 .26221 .36718 .2728 .36385 .26581 .35666 Mtetra
.635 .738 .923 r
.26581 .35666 .2728 .36385 .2834 .36084 .27645 .35338 Mtetra
.595 .717 .929 r
.27645 .35338 .2834 .36084 .29373 .36231 .28708 .35101 Mtetra
.811 .699 .741 r
.28708 .35101 .29373 .36231 .30513 .34942 .29862 .33658 Mtetra
.377 .471 .829 r
.29862 .33658 .30513 .34942 .31581 .34713 .30894 .33959 Mtetra
.628 .728 .919 r
.30894 .33959 .31581 .34713 .32662 .3437 .31976 .33643 Mtetra
.646 .743 .92 r
.31976 .33643 .32662 .3437 .33749 .34002 .33065 .33282 Mtetra
.652 .748 .92 r
.33065 .33282 .33749 .34002 .34841 .33622 .34159 .32903 Mtetra
.655 .75 .92 r
.34159 .32903 .34841 .33622 .35938 .33234 .35259 .32515 Mtetra
.657 .752 .92 r
.35259 .32515 .35938 .33234 .3704 .3284 .36363 .3212 Mtetra
.658 .753 .92 r
.36363 .3212 .3704 .3284 .38146 .32442 .37472 .3172 Mtetra
.659 .754 .92 r
.37472 .3172 .38146 .32442 .39257 .32041 .38586 .31316 Mtetra
.38586 .31316 .39257 .32041 .40372 .31638 .39704 .3091 Mtetra
.39704 .3091 .40372 .31638 .41492 .31234 .40827 .30503 Mtetra
.40827 .30503 .41492 .31234 .42617 .30829 .41955 .30095 Mtetra
.658 .753 .92 r
.41955 .30095 .42617 .30829 .43746 .30424 .43087 .29686 Mtetra
.43087 .29686 .43746 .30424 .4488 .30017 .44224 .29275 Mtetra
.44224 .29275 .4488 .30017 .46019 .29609 .45366 .28864 Mtetra
.45366 .28864 .46019 .29609 .47162 .29199 .46512 .28451 Mtetra
.46512 .28451 .47162 .29199 .4831 .28788 .47664 .28037 Mtetra
.47664 .28037 .4831 .28788 .49463 .28376 .4882 .27621 Mtetra
.4882 .27621 .49463 .28376 .50621 .27962 .49981 .27204 Mtetra
.657 .753 .92 r
.49981 .27204 .50621 .27962 .51784 .27547 .51147 .26785 Mtetra
.51147 .26785 .51784 .27547 .52951 .2713 .52318 .26365 Mtetra
.657 .752 .92 r
.52318 .26365 .52951 .2713 .54124 .26711 .53493 .25943 Mtetra
.53493 .25943 .54124 .26711 .55302 .26291 .54674 .25519 Mtetra
.54674 .25519 .55302 .26291 .56484 .25869 .5586 .25094 Mtetra
.5586 .25094 .56484 .25869 .57672 .25445 .57051 .24667 Mtetra
.57051 .24667 .57672 .25445 .58864 .2502 .58247 .24238 Mtetra
.58247 .24238 .58864 .2502 .60062 .24593 .59448 .23808 Mtetra
.59448 .23808 .60062 .24593 .61265 .24164 .60655 .23376 Mtetra
.60655 .23376 .61265 .24164 .62473 .23733 .61866 .22941 Mtetra
.61866 .22941 .62473 .23733 .63686 .23301 .63083 .22506 Mtetra
.63083 .22506 .63686 .23301 .64905 .22867 .64305 .22068 Mtetra
.64305 .22068 .64905 .22867 .66129 .22431 .65533 .21628 Mtetra
.65533 .21628 .66129 .22431 .67358 .21993 .66766 .21187 Mtetra
.66766 .21187 .67358 .21993 .68592 .21553 .68004 .20744 Mtetra
.68004 .20744 .68592 .21553 .69832 .21112 .69247 .20299 Mtetra
.69247 .20299 .69832 .21112 .71077 .20668 .70496 .19851 Mtetra
.70496 .19851 .71077 .20668 .72328 .20223 .71751 .19402 Mtetra
.71751 .19402 .72328 .20223 .73584 .19776 .73011 .18952 Mtetra
.73011 .18952 .73584 .19776 .74846 .19327 .74277 .18499 Mtetra
.859 .417 .008 r
.073 .41672 .08026 .42493 .09115 .41436 .08022 .4333 Mtetra
.793 .881 .454 r
.08022 .4333 .09115 .41436 .10066 .41436 .09335 .40683 Mtetra
.586 .701 .922 r
.09335 .40683 .10066 .41436 .11052 .41202 .10318 .40481 Mtetra
.592 .714 .928 r
.10318 .40481 .11052 .41202 .12024 .41122 .11308 .40265 Mtetra
.949 .665 .466 r
.11308 .40265 .12024 .41122 .1312 .40072 .10839 .51789 Mtetra
0 0 0 r
.10839 .51789 .1312 .40072 .14099 .4 .13373 .3925 Mtetra
.598 .708 .921 r
.13373 .3925 .14099 .4 .15105 .3974 .14378 .3902 Mtetra
.611 .723 .925 r
.14378 .3902 .15105 .3974 .1611 .39526 .1539 .38759 Mtetra
.448 .643 .941 r
.1539 .38759 .1611 .39526 .17316 .37543 .16375 .38781 Mtetra
0 0 0 r
.16375 .38781 .17316 .37543 .18202 .38482 .17492 .37659 Mtetra
.566 .677 .914 r
.17492 .37659 .18202 .38482 .19225 .38221 .18506 .37496 Mtetra
.623 .728 .922 r
.18506 .37496 .19225 .38221 .20257 .37925 .19539 .37203 Mtetra
.621 .73 .924 r
.19539 .37203 .20257 .37925 .21288 .37679 .20576 .36913 Mtetra
.509 .673 .938 r
.20576 .36913 .21288 .37679 .22701 .33432 .21597 .36842 Mtetra
.289 0 .274 r
.21597 .36842 .22701 .33432 .23418 .36605 .2272 .35743 Mtetra
.557 .666 .909 r
.2272 .35743 .23418 .36605 .24464 .36332 .23756 .35598 Mtetra
.63 .732 .921 r
.23756 .35598 .24464 .36332 .2552 .36004 .24813 .35283 Mtetra
.639 .74 .921 r
.24813 .35283 .2552 .36004 .26581 .35666 .25876 .34944 Mtetra
.639 .74 .922 r
.25876 .34944 .26581 .35666 .27645 .35338 .26944 .34604 Mtetra
.625 .733 .924 r
.26944 .34604 .27645 .35338 .28708 .35101 .28014 .34296 Mtetra
.367 .596 .934 r
.28014 .34296 .28708 .35101 .29862 .33658 .29055 .34438 Mtetra
.627 .889 .562 r
.29055 .34438 .29862 .33658 .30894 .33959 .30207 .33138 Mtetra
.594 .697 .915 r
.30207 .33138 .30894 .33959 .31976 .33643 .31284 .32902 Mtetra
.64 .739 .92 r
.31284 .32902 .31976 .33643 .33065 .33282 .32375 .32552 Mtetra
.649 .746 .92 r
.32375 .32552 .33065 .33282 .34159 .32903 .33472 .32176 Mtetra
.653 .749 .92 r
.33472 .32176 .34159 .32903 .35259 .32515 .34574 .31789 Mtetra
.656 .751 .92 r
.34574 .31789 .35259 .32515 .36363 .3212 .35681 .31393 Mtetra
.658 .753 .92 r
.35681 .31393 .36363 .3212 .37472 .3172 .36793 .30991 Mtetra
.659 .753 .92 r
.36793 .30991 .37472 .3172 .38586 .31316 .3791 .30586 Mtetra
.659 .754 .92 r
.3791 .30586 .38586 .31316 .39704 .3091 .39031 .30177 Mtetra
.39031 .30177 .39704 .3091 .40827 .30503 .40157 .29766 Mtetra
.40157 .29766 .40827 .30503 .41955 .30095 .41288 .29355 Mtetra
.659 .753 .92 r
.41288 .29355 .41955 .30095 .43087 .29686 .42423 .28942 Mtetra
.658 .753 .92 r
.42423 .28942 .43087 .29686 .44224 .29275 .43563 .28528 Mtetra
.43563 .28528 .44224 .29275 .45366 .28864 .44708 .28113 Mtetra
.44708 .28113 .45366 .28864 .46512 .28451 .45857 .27697 Mtetra
.45857 .27697 .46512 .28451 .47664 .28037 .47012 .2728 Mtetra
.47012 .2728 .47664 .28037 .4882 .27621 .48171 .26861 Mtetra
.48171 .26861 .4882 .27621 .49981 .27204 .49335 .2644 Mtetra
.657 .753 .92 r
.49335 .2644 .49981 .27204 .51147 .26785 .50504 .26018 Mtetra
.50504 .26018 .51147 .26785 .52318 .26365 .51679 .25594 Mtetra
.51679 .25594 .52318 .26365 .53493 .25943 .52858 .25169 Mtetra
.657 .752 .92 r
.52858 .25169 .53493 .25943 .54674 .25519 .54042 .24742 Mtetra
.54042 .24742 .54674 .25519 .5586 .25094 .55231 .24313 Mtetra
.55231 .24313 .5586 .25094 .57051 .24667 .56426 .23883 Mtetra
.56426 .23883 .57051 .24667 .58247 .24238 .57625 .2345 Mtetra
.57625 .2345 .58247 .24238 .59448 .23808 .5883 .23016 Mtetra
.5883 .23016 .59448 .23808 .60655 .23376 .6004 .22581 Mtetra
.6004 .22581 .60655 .23376 .61866 .22941 .61255 .22143 Mtetra
.61255 .22143 .61866 .22941 .63083 .22506 .62475 .21704 Mtetra
.62475 .21704 .63083 .22506 .64305 .22068 .63701 .21262 Mtetra
.63701 .21262 .64305 .22068 .65533 .21628 .64932 .20819 Mtetra
.64932 .20819 .65533 .21628 .66766 .21187 .66169 .20374 Mtetra
.66169 .20374 .66766 .21187 .68004 .20744 .6741 .19927 Mtetra
.6741 .19927 .68004 .20744 .69247 .20299 .68658 .19479 Mtetra
.68658 .19479 .69247 .20299 .70496 .19851 .69911 .19028 Mtetra
.69911 .19028 .70496 .19851 .71751 .19402 .71169 .18575 Mtetra
.71169 .18575 .71751 .19402 .73011 .18952 .72433 .18121 Mtetra
.72433 .18121 .73011 .18952 .74277 .18499 .73703 .17664 Mtetra
.532 .685 .937 r
.06557 .40932 .073 .41672 .08022 .4333 .07521 .40824 Mtetra
.68 .525 .669 r
.07521 .40824 .08022 .4333 .09335 .40683 .08621 .39759 Mtetra
.491 .613 .9 r
.08621 .39759 .09335 .40683 .10318 .40481 .09579 .39753 Mtetra
.602 .716 .925 r
.09579 .39753 .10318 .40481 .11308 .40265 .10573 .39513 Mtetra
.518 .679 .938 r
.10573 .39513 .11308 .40265 .10839 .51789 .11553 .39427 Mtetra
.556 .34 .542 r
.11553 .39427 .10839 .51789 .13373 .3925 .12659 .38367 Mtetra
.526 .643 .907 r
.12659 .38367 .13373 .3925 .14378 .3902 .13646 .3829 Mtetra
.612 .722 .923 r
.13646 .3829 .14378 .3902 .1539 .38759 .1466 .38024 Mtetra
.589 .713 .929 r
.1466 .38024 .1539 .38759 .16375 .38781 .15674 .37804 Mtetra
.855 .718 .711 r
.15674 .37804 .16375 .38781 .17492 .37659 .16892 .35807 Mtetra
.122 .213 .686 r
.16892 .35807 .17492 .37659 .18506 .37496 .17784 .36744 Mtetra
.611 .718 .921 r
.17784 .36744 .18506 .37496 .19539 .37203 .18816 .36477 Mtetra
.626 .731 .923 r
.18816 .36477 .19539 .37203 .20576 .36913 .19857 .36173 Mtetra
.602 .72 .928 r
.19857 .36173 .20576 .36913 .21597 .36842 .20897 .35921 Mtetra
.915 .721 .626 r
.20897 .35921 .21597 .36842 .2272 .35743 .22327 .31652 Mtetra
0 0 .409 r
.22327 .31652 .2272 .35743 .23756 .35598 .23046 .34831 Mtetra
.614 .718 .92 r
.23046 .34831 .23756 .35598 .24813 .35283 .24101 .34552 Mtetra
.636 .737 .921 r
.24101 .34552 .24813 .35283 .25876 .34944 .25166 .34217 Mtetra
.64 .74 .922 r
.25166 .34217 .25876 .34944 .26944 .34604 .26237 .33871 Mtetra
.635 .738 .923 r
.26237 .33871 .26944 .34604 .28014 .34296 .27311 .33537 Mtetra
.595 .717 .929 r
.27311 .33537 .28014 .34296 .29055 .34438 .28383 .33293 Mtetra
.812 .7 .741 r
.28383 .33293 .29055 .34438 .30207 .33138 .29549 .31838 Mtetra
.376 .471 .829 r
.29549 .31838 .30207 .33138 .31284 .32902 .3059 .32134 Mtetra
.628 .728 .919 r
.3059 .32134 .31284 .32902 .32375 .32552 .31681 .31811 Mtetra
.646 .743 .92 r
.31681 .31811 .32375 .32552 .33472 .32176 .3278 .31442 Mtetra
.652 .748 .92 r
.3278 .31442 .33472 .32176 .34574 .31789 .33884 .31056 Mtetra
.655 .75 .92 r
.33884 .31056 .34574 .31789 .35681 .31393 .34994 .3066 Mtetra
.657 .752 .92 r
.34994 .3066 .35681 .31393 .36793 .30991 .36109 .30257 Mtetra
.658 .753 .92 r
.36109 .30257 .36793 .30991 .3791 .30586 .37228 .29849 Mtetra
.659 .754 .92 r
.37228 .29849 .3791 .30586 .39031 .30177 .38352 .29438 Mtetra
.38352 .29438 .39031 .30177 .40157 .29766 .39481 .29024 Mtetra
.39481 .29024 .40157 .29766 .41288 .29355 .40615 .28609 Mtetra
.40615 .28609 .41288 .29355 .42423 .28942 .41753 .28193 Mtetra
.658 .753 .92 r
.41753 .28193 .42423 .28942 .43563 .28528 .42897 .27775 Mtetra
.42897 .27775 .43563 .28528 .44708 .28113 .44044 .27357 Mtetra
.44044 .27357 .44708 .28113 .45857 .27697 .45197 .26937 Mtetra
.45197 .26937 .45857 .27697 .47012 .2728 .46355 .26516 Mtetra
.46355 .26516 .47012 .2728 .48171 .26861 .47517 .26094 Mtetra
.47517 .26094 .48171 .26861 .49335 .2644 .48685 .2567 Mtetra
.48685 .2567 .49335 .2644 .50504 .26018 .49857 .25244 Mtetra
.657 .753 .92 r
.49857 .25244 .50504 .26018 .51679 .25594 .51035 .24817 Mtetra
.51035 .24817 .51679 .25594 .52858 .25169 .52217 .24389 Mtetra
.657 .752 .92 r
.52217 .24389 .52858 .25169 .54042 .24742 .53405 .23958 Mtetra
.53405 .23958 .54042 .24742 .55231 .24313 .54597 .23526 Mtetra
.54597 .23526 .55231 .24313 .56426 .23883 .55795 .23092 Mtetra
.55795 .23092 .56426 .23883 .57625 .2345 .56998 .22656 Mtetra
.56998 .22656 .57625 .2345 .5883 .23016 .58206 .22219 Mtetra
.58206 .22219 .5883 .23016 .6004 .22581 .5942 .21779 Mtetra
.5942 .21779 .6004 .22581 .61255 .22143 .60638 .21338 Mtetra
.60638 .21338 .61255 .22143 .62475 .21704 .61862 .20895 Mtetra
.61862 .20895 .62475 .21704 .63701 .21262 .63092 .2045 Mtetra
.63092 .2045 .63701 .21262 .64932 .20819 .64326 .20004 Mtetra
.64326 .20004 .64932 .20819 .66169 .20374 .65567 .19555 Mtetra
.65567 .19555 .66169 .20374 .6741 .19927 .66812 .19104 Mtetra
.66812 .19104 .6741 .19927 .68658 .19479 .68064 .18652 Mtetra
.68064 .18652 .68658 .19479 .69911 .19028 .6932 .18198 Mtetra
.6932 .18198 .69911 .19028 .71169 .18575 .70583 .17741 Mtetra
.70583 .17741 .71169 .18575 .72433 .18121 .7185 .17283 Mtetra
.7185 .17283 .72433 .18121 .73703 .17664 .73124 .16822 Mtetra
.587 .71 .928 r
.05808 .402 .06557 .40932 .07521 .40824 .06787 .39991 Mtetra
.855 .413 0 r
.06787 .39991 .07521 .40824 .08621 .39759 .07511 .4165 Mtetra
.799 .886 .462 r
.07511 .4165 .08621 .39759 .09579 .39753 .08839 .38987 Mtetra
.586 .701 .922 r
.08839 .38987 .09579 .39753 .10573 .39513 .09831 .38779 Mtetra
.592 .713 .928 r
.09831 .38779 .10573 .39513 .11553 .39427 .10829 .38557 Mtetra
.95 .665 .463 r
.10829 .38557 .11553 .39427 .12659 .38367 .10336 .50127 Mtetra
0 0 0 r
.10336 .50127 .12659 .38367 .13646 .3829 .12912 .37527 Mtetra
.598 .708 .921 r
.12912 .37527 .13646 .3829 .1466 .38024 .13924 .37291 Mtetra
.611 .723 .925 r
.13924 .37291 .1466 .38024 .15674 .37804 .14946 .37023 Mtetra
.449 .644 .941 r
.14946 .37023 .15674 .37804 .16892 .35807 .15939 .3704 Mtetra
0 0 0 r
.15939 .3704 .16892 .35807 .17784 .36744 .17066 .35907 Mtetra
.566 .677 .914 r
.17066 .35907 .17784 .36744 .18816 .36477 .18089 .35738 Mtetra
.623 .728 .922 r
.18089 .35738 .18816 .36477 .19857 .36173 .19131 .35438 Mtetra
.621 .73 .924 r
.19131 .35438 .19857 .36173 .20897 .35921 .20177 .35142 Mtetra
.509 .673 .938 r
.20177 .35142 .20897 .35921 .22327 .31652 .21206 .35065 Mtetra
.28 0 .264 r
.21206 .35065 .22327 .31652 .23046 .34831 .2234 .33956 Mtetra
.557 .666 .91 r
.2234 .33956 .23046 .34831 .24101 .34552 .23385 .33804 Mtetra
.63 .732 .921 r
.23385 .33804 .24101 .34552 .25166 .34217 .24451 .33482 Mtetra
.639 .74 .921 r
.24451 .33482 .25166 .34217 .26237 .33871 .25524 .33136 Mtetra
.639 .74 .922 r
.25524 .33136 .26237 .33871 .27311 .33537 .26601 .32789 Mtetra
.625 .733 .924 r
.26601 .32789 .27311 .33537 .28383 .33293 .27681 .32473 Mtetra
.368 .596 .934 r
.27681 .32473 .28383 .33293 .29549 .31838 .28731 .3261 Mtetra
.638 .896 .573 r
.28731 .3261 .29549 .31838 .3059 .32134 .29894 .31299 Mtetra
.594 .697 .915 r
.29894 .31299 .3059 .32134 .31681 .31811 .30982 .31056 Mtetra
.64 .739 .92 r
.30982 .31056 .31681 .31811 .3278 .31442 .32082 .30698 Mtetra
.649 .746 .92 r
.32082 .30698 .3278 .31442 .33884 .31056 .33189 .30315 Mtetra
.653 .749 .92 r
.33189 .30315 .33884 .31056 .34994 .3066 .34302 .2992 Mtetra
.656 .751 .92 r
.34302 .2992 .34994 .3066 .36109 .30257 .35419 .29516 Mtetra
.658 .753 .92 r
.35419 .29516 .36109 .30257 .37228 .29849 .36541 .29107 Mtetra
.659 .753 .92 r
.36541 .29107 .37228 .29849 .38352 .29438 .37669 .28693 Mtetra
.659 .754 .92 r
.37669 .28693 .38352 .29438 .39481 .29024 .38801 .28276 Mtetra
.38801 .28276 .39481 .29024 .40615 .28609 .39937 .27857 Mtetra
.39937 .27857 .40615 .28609 .41753 .28193 .41079 .27438 Mtetra
.659 .753 .92 r
.41079 .27438 .41753 .28193 .42897 .27775 .42225 .27017 Mtetra
.658 .753 .92 r
.42225 .27017 .42897 .27775 .44044 .27357 .43376 .26595 Mtetra
.43376 .26595 .44044 .27357 .45197 .26937 .44532 .26172 Mtetra
.44532 .26172 .45197 .26937 .46355 .26516 .45693 .25747 Mtetra
.45693 .25747 .46355 .26516 .47517 .26094 .46858 .25321 Mtetra
.46858 .25321 .47517 .26094 .48685 .2567 .48029 .24894 Mtetra
.48029 .24894 .48685 .2567 .49857 .25244 .49205 .24465 Mtetra
.657 .753 .92 r
.49205 .24465 .49857 .25244 .51035 .24817 .50385 .24034 Mtetra
.50385 .24034 .51035 .24817 .52217 .24389 .51571 .23602 Mtetra
.51571 .23602 .52217 .24389 .53405 .23958 .52762 .23168 Mtetra
.657 .752 .92 r
.52762 .23168 .53405 .23958 .54597 .23526 .53958 .22732 Mtetra
.53958 .22732 .54597 .23526 .55795 .23092 .55159 .22295 Mtetra
.55159 .22295 .55795 .23092 .56998 .22656 .56366 .21856 Mtetra
.56366 .21856 .56998 .22656 .58206 .22219 .57577 .21414 Mtetra
.57577 .21414 .58206 .22219 .5942 .21779 .58794 .20972 Mtetra
.58794 .20972 .5942 .21779 .60638 .21338 .60017 .20527 Mtetra
.60017 .20527 .60638 .21338 .61862 .20895 .61244 .2008 Mtetra
.61244 .2008 .61862 .20895 .63092 .2045 .62477 .19632 Mtetra
.62477 .19632 .63092 .2045 .64326 .20004 .63716 .19181 Mtetra
.63716 .19181 .64326 .20004 .65567 .19555 .6496 .18729 Mtetra
.6496 .18729 .65567 .19555 .66812 .19104 .66209 .18275 Mtetra
.66209 .18275 .66812 .19104 .68064 .18652 .67464 .17819 Mtetra
.67464 .17819 .68064 .18652 .6932 .18198 .68725 .1736 Mtetra
.68725 .1736 .6932 .18198 .70583 .17741 .69991 .169 Mtetra
.69991 .169 .70583 .17741 .7185 .17283 .71263 .16438 Mtetra
.71263 .16438 .7185 .17283 .73124 .16822 .7254 .15974 Mtetra
.586 .704 .924 r
.05056 .39445 .05808 .402 .06787 .39991 .06036 .39238 Mtetra
.532 .685 .937 r
.06036 .39238 .06787 .39991 .07511 .4165 .07007 .39125 Mtetra
.679 .524 .669 r
.07007 .39125 .07511 .4165 .08839 .38987 .08117 .38049 Mtetra
.49 .613 .9 r
.08117 .38049 .08839 .38987 .09831 .38779 .09083 .38038 Mtetra
.602 .716 .925 r
.09083 .38038 .09831 .38779 .10829 .38557 .10085 .37792 Mtetra
.518 .679 .938 r
.10085 .37792 .10829 .38557 .10336 .50127 .11073 .37701 Mtetra
.553 .336 .54 r
.11073 .37701 .10336 .50127 .12912 .37527 .12189 .36631 Mtetra
.526 .643 .907 r
.12189 .36631 .12912 .37527 .13924 .37291 .13184 .36548 Mtetra
.612 .722 .923 r
.13184 .36548 .13924 .37291 .14946 .37023 .14207 .36274 Mtetra
.59 .713 .929 r
.14207 .36274 .14946 .37023 .15939 .3704 .1523 .36048 Mtetra
.856 .719 .71 r
.1523 .36048 .15939 .3704 .17066 .35907 .1646 .34038 Mtetra
.118 .211 .685 r
.1646 .34038 .17066 .35907 .18089 .35738 .17359 .34973 Mtetra
.611 .718 .921 r
.17359 .34973 .18089 .35738 .19131 .35438 .184 .34699 Mtetra
.626 .731 .923 r
.184 .34699 .19131 .35438 .20177 .35142 .19449 .34389 Mtetra
.602 .72 .928 r
.19449 .34389 .20177 .35142 .21206 .35065 .20498 .3413 Mtetra
.916 .721 .625 r
.20498 .3413 .21206 .35065 .2234 .33956 .21946 .29838 Mtetra
0 0 .405 r
.21946 .29838 .2234 .33956 .23385 .33804 .22666 .33024 Mtetra
.614 .718 .92 r
.22666 .33024 .23385 .33804 .24451 .33482 .23731 .32737 Mtetra
.636 .737 .921 r
.23731 .32737 .24451 .33482 .25524 .33136 .24806 .32395 Mtetra
.64 .74 .922 r
.24806 .32395 .25524 .33136 .26601 .32789 .25886 .32042 Mtetra
.635 .738 .923 r
.25886 .32042 .26601 .32789 .27681 .32473 .2697 .317 Mtetra
.595 .717 .929 r
.2697 .317 .27681 .32473 .28731 .3261 .28052 .31449 Mtetra
.813 .701 .741 r
.28052 .31449 .28731 .3261 .29894 .31299 .29229 .29983 Mtetra
.375 .47 .829 r
.29229 .29983 .29894 .31299 .30982 .31056 .30279 .30274 Mtetra
.628 .728 .919 r
.30279 .30274 .30982 .31056 .32082 .30698 .3138 .29943 Mtetra
.646 .743 .92 r
.3138 .29943 .32082 .30698 .33189 .30315 .32489 .29566 Mtetra
.652 .748 .92 r
.32489 .29566 .33189 .30315 .34302 .2992 .33604 .29172 Mtetra
.655 .75 .92 r
.33604 .29172 .34302 .2992 .35419 .29516 .34724 .28768 Mtetra
.657 .752 .92 r
.34724 .28768 .35419 .29516 .36541 .29107 .35849 .28357 Mtetra
.658 .753 .92 r
.35849 .28357 .36541 .29107 .37669 .28693 .36979 .27941 Mtetra
.659 .754 .92 r
.36979 .27941 .37669 .28693 .38801 .28276 .38114 .27522 Mtetra
.38114 .27522 .38801 .28276 .39937 .27857 .39254 .271 Mtetra
.39254 .271 .39937 .27857 .41079 .27438 .40399 .26677 Mtetra
.40399 .26677 .41079 .27438 .42225 .27017 .41548 .26252 Mtetra
.658 .753 .92 r
.41548 .26252 .42225 .27017 .43376 .26595 .42702 .25827 Mtetra
.42702 .25827 .43376 .26595 .44532 .26172 .43861 .254 Mtetra
.43861 .254 .44532 .26172 .45693 .25747 .45025 .24972 Mtetra
.45025 .24972 .45693 .25747 .46858 .25321 .46194 .24543 Mtetra
.46194 .24543 .46858 .25321 .48029 .24894 .47368 .24112 Mtetra
.47368 .24112 .48029 .24894 .49205 .24465 .48547 .23679 Mtetra
.48547 .23679 .49205 .24465 .50385 .24034 .49731 .23245 Mtetra
.657 .753 .92 r
.49731 .23245 .50385 .24034 .51571 .23602 .5092 .22809 Mtetra
.5092 .22809 .51571 .23602 .52762 .23168 .52114 .22372 Mtetra
.657 .752 .92 r
.52114 .22372 .52762 .23168 .53958 .22732 .53314 .21932 Mtetra
.53314 .21932 .53958 .22732 .55159 .22295 .54519 .21491 Mtetra
.54519 .21491 .55159 .22295 .56366 .21856 .55729 .21048 Mtetra
.55729 .21048 .56366 .21856 .57577 .21414 .56944 .20604 Mtetra
.56944 .20604 .57577 .21414 .58794 .20972 .58164 .20157 Mtetra
.58164 .20157 .58794 .20972 .60017 .20527 .5939 .19709 Mtetra
.5939 .19709 .60017 .20527 .61244 .2008 .60621 .19259 Mtetra
.60621 .19259 .61244 .2008 .62477 .19632 .61858 .18806 Mtetra
.61858 .18806 .62477 .19632 .63716 .19181 .631 .18352 Mtetra
.631 .18352 .63716 .19181 .6496 .18729 .64348 .17896 Mtetra
.64348 .17896 .6496 .18729 .66209 .18275 .65601 .17438 Mtetra
.65601 .17438 .66209 .18275 .67464 .17819 .6686 .16978 Mtetra
.6686 .16978 .67464 .17819 .68725 .1736 .68125 .16516 Mtetra
.68125 .16516 .68725 .1736 .69991 .169 .69395 .16052 Mtetra
.69395 .16052 .69991 .169 .71263 .16438 .70671 .15586 Mtetra
.70671 .15586 .71263 .16438 .7254 .15974 .71952 .15118 Mtetra
.529 .652 .913 r
.04313 .38587 .05056 .39445 .06036 .39238 .05277 .38493 Mtetra
.587 .71 .928 r
.05277 .38493 .06036 .39238 .07007 .39125 .06264 .38278 Mtetra
.852 .409 0 r
.06264 .38278 .07007 .39125 .08117 .38049 .06991 .39939 Mtetra
.806 .89 .47 r
.06991 .39939 .08117 .38049 .09083 .38038 .08334 .3726 Mtetra
.586 .701 .922 r
.08334 .3726 .09083 .38038 .10085 .37792 .09334 .37045 Mtetra
.592 .713 .928 r
.09334 .37045 .10085 .37792 .11073 .37701 .1034 .36816 Mtetra
.951 .665 .46 r
.1034 .36816 .11073 .37701 .12189 .36631 .09823 .48431 Mtetra
0 0 0 r
.09823 .48431 .12189 .36631 .13184 .36548 .12442 .35771 Mtetra
.597 .708 .921 r
.12442 .35771 .13184 .36548 .14207 .36274 .13463 .35529 Mtetra
.611 .723 .925 r
.13463 .35529 .14207 .36274 .1523 .36048 .14493 .35254 Mtetra
.449 .644 .94 r
.14493 .35254 .1523 .36048 .1646 .34038 .15494 .35265 Mtetra
0 0 0 r
.15494 .35265 .1646 .34038 .17359 .34973 .16632 .34122 Mtetra
.566 .677 .914 r
.16632 .34122 .17359 .34973 .184 .34699 .17664 .33947 Mtetra
.623 .728 .922 r
.17664 .33947 .184 .34699 .19449 .34389 .18715 .3364 Mtetra
.621 .73 .924 r
.18715 .3364 .19449 .34389 .20498 .3413 .1977 .33336 Mtetra
.509 .673 .938 r
.1977 .33336 .20498 .3413 .21946 .29838 .20808 .33253 Mtetra
.27 0 .254 r
.20808 .33253 .21946 .29838 .22666 .33024 .21953 .32134 Mtetra
.557 .666 .91 r
.21953 .32134 .22666 .33024 .23731 .32737 .23007 .31976 Mtetra
.63 .732 .921 r
.23007 .31976 .23731 .32737 .24806 .32395 .24082 .31646 Mtetra
.639 .74 .921 r
.24082 .31646 .24806 .32395 .25886 .32042 .25165 .31292 Mtetra
.639 .74 .922 r
.25165 .31292 .25886 .32042 .2697 .317 .26252 .30938 Mtetra
.625 .733 .924 r
.26252 .30938 .2697 .317 .28052 .31449 .27342 .30615 Mtetra
.37 .596 .934 r
.27342 .30615 .28052 .31449 .29229 .29983 .28401 .30746 Mtetra
.648 .904 .583 r
.28401 .30746 .29229 .29983 .30279 .30274 .29575 .29424 Mtetra
.594 .697 .915 r
.29575 .29424 .30279 .30274 .3138 .29943 .30673 .29173 Mtetra
.64 .739 .92 r
.30673 .29173 .3138 .29943 .32489 .29566 .31784 .28808 Mtetra
.649 .746 .92 r
.31784 .28808 .32489 .29566 .33604 .29172 .32901 .28417 Mtetra
.653 .749 .92 r
.32901 .28417 .33604 .29172 .34724 .28768 .34024 .28013 Mtetra
.656 .751 .92 r
.34024 .28013 .34724 .28768 .35849 .28357 .35152 .27602 Mtetra
.658 .753 .92 r
.35152 .27602 .35849 .28357 .36979 .27941 .36285 .27184 Mtetra
.659 .753 .92 r
.36285 .27184 .36979 .27941 .38114 .27522 .37423 .26762 Mtetra
.659 .754 .92 r
.37423 .26762 .38114 .27522 .39254 .271 .38566 .26337 Mtetra
.38566 .26337 .39254 .271 .40399 .26677 .39713 .2591 Mtetra
.39713 .2591 .40399 .26677 .41548 .26252 .40866 .25482 Mtetra
.659 .753 .92 r
.40866 .25482 .41548 .26252 .42702 .25827 .42023 .25053 Mtetra
.658 .753 .92 r
.42023 .25053 .42702 .25827 .43861 .254 .43185 .24622 Mtetra
.43185 .24622 .43861 .254 .45025 .24972 .44352 .24191 Mtetra
.44352 .24191 .45025 .24972 .46194 .24543 .45524 .23758 Mtetra
.45524 .23758 .46194 .24543 .47368 .24112 .46702 .23323 Mtetra
.46702 .23323 .47368 .24112 .48547 .23679 .47884 .22887 Mtetra
.47884 .22887 .48547 .23679 .49731 .23245 .49071 .22449 Mtetra
.657 .753 .92 r
.49071 .22449 .49731 .23245 .5092 .22809 .50264 .2201 Mtetra
.50264 .2201 .5092 .22809 .52114 .22372 .51462 .21569 Mtetra
.51462 .21569 .52114 .22372 .53314 .21932 .52664 .21126 Mtetra
.657 .752 .92 r
.52664 .21126 .53314 .21932 .54519 .21491 .53873 .20681 Mtetra
.53873 .20681 .54519 .21491 .55729 .21048 .55086 .20235 Mtetra
.55086 .20235 .55729 .21048 .56944 .20604 .56305 .19786 Mtetra
.56305 .19786 .56944 .20604 .58164 .20157 .57529 .19336 Mtetra
.57529 .19336 .58164 .20157 .5939 .19709 .58758 .18884 Mtetra
.58758 .18884 .5939 .19709 .60621 .19259 .59993 .1843 Mtetra
.59993 .1843 .60621 .19259 .61858 .18806 .61234 .17974 Mtetra
.61234 .17974 .61858 .18806 .631 .18352 .6248 .17516 Mtetra
.6248 .17516 .631 .18352 .64348 .17896 .63731 .17057 Mtetra
.63731 .17057 .64348 .17896 .65601 .17438 .64988 .16595 Mtetra
.64988 .16595 .65601 .17438 .6686 .16978 .66251 .16131 Mtetra
.66251 .16131 .6686 .16978 .68125 .16516 .67519 .15665 Mtetra
.67519 .15665 .68125 .16516 .69395 .16052 .68793 .15197 Mtetra
.68793 .15197 .69395 .16052 .70671 .15586 .70073 .14727 Mtetra
.70073 .14727 .70671 .15586 .71952 .15118 .71359 .14255 Mtetra
0 0 .268 r
.04106 .34189 .04313 .38587 .05277 .38493 .04516 .37726 Mtetra
.586 .704 .924 r
.04516 .37726 .05277 .38493 .06264 .38278 .05504 .37512 Mtetra
.533 .685 .936 r
.05504 .37512 .06264 .38278 .06991 .39939 .06483 .37393 Mtetra
.679 .524 .668 r
.06483 .37393 .06991 .39939 .08334 .3726 .07604 .36308 Mtetra
.49 .613 .9 r
.07604 .36308 .08334 .3726 .09334 .37045 .08577 .36291 Mtetra
.602 .716 .925 r
.08577 .36291 .09334 .37045 .1034 .36816 .09588 .36038 Mtetra
.518 .679 .938 r
.09588 .36038 .1034 .36816 .09823 .48431 .10583 .35941 Mtetra
.55 .332 .537 r
.10583 .35941 .09823 .48431 .12442 .35771 .11711 .34861 Mtetra
.525 .643 .907 r
.11711 .34861 .12442 .35771 .13463 .35529 .12714 .34772 Mtetra
.612 .722 .923 r
.12714 .34772 .13463 .35529 .14493 .35254 .13746 .34492 Mtetra
.59 .713 .929 r
.13746 .34492 .14493 .35254 .15494 .35265 .14777 .34259 Mtetra
.857 .72 .71 r
.14777 .34259 .15494 .35265 .16632 .34122 .16021 .32235 Mtetra
.114 .208 .684 r
.16021 .32235 .16632 .34122 .17664 .33947 .16925 .33168 Mtetra
.611 .718 .921 r
.16925 .33168 .17664 .33947 .18715 .3364 .17975 .32887 Mtetra
.626 .731 .923 r
.17975 .32887 .18715 .3364 .1977 .33336 .19033 .32569 Mtetra
.602 .72 .928 r
.19033 .32569 .1977 .33336 .20808 .33253 .20091 .32303 Mtetra
.917 .722 .624 r
.20091 .32303 .20808 .33253 .21953 .32134 .21558 .27989 Mtetra
0 0 .4 r
.21558 .27989 .21953 .32134 .23007 .31976 .2228 .31181 Mtetra
.614 .718 .92 r
.2228 .31181 .23007 .31976 .24082 .31646 .23354 .30887 Mtetra
.636 .737 .921 r
.23354 .30887 .24082 .31646 .25165 .31292 .24438 .30537 Mtetra
.64 .74 .922 r
.24438 .30537 .25165 .31292 .26252 .30938 .25528 .30177 Mtetra
.635 .738 .923 r
.25528 .30177 .26252 .30938 .27342 .30615 .26622 .29827 Mtetra
.595 .717 .929 r
.26622 .29827 .27342 .30615 .28401 .30746 .27714 .29568 Mtetra
.813 .701 .741 r
.27714 .29568 .28401 .30746 .29575 .29424 .28903 .2809 Mtetra
.374 .469 .83 r
.28903 .2809 .29575 .29424 .30673 .29173 .29962 .28376 Mtetra
.628 .728 .919 r
.29962 .28376 .30673 .29173 .31784 .28808 .31073 .28038 Mtetra
.646 .743 .92 r
.31073 .28038 .31784 .28808 .32901 .28417 .32193 .27653 Mtetra
.652 .748 .92 r
.32193 .27653 .32901 .28417 .34024 .28013 .33318 .27251 Mtetra
.655 .75 .92 r
.33318 .27251 .34024 .28013 .35152 .27602 .34449 .26839 Mtetra
.657 .752 .92 r
.34449 .26839 .35152 .27602 .36285 .27184 .35585 .2642 Mtetra
.658 .753 .92 r
.35585 .2642 .36285 .27184 .37423 .26762 .36726 .25996 Mtetra
.659 .754 .92 r
.36726 .25996 .37423 .26762 .38566 .26337 .37872 .25568 Mtetra
.37872 .25568 .38566 .26337 .39713 .2591 .39022 .25137 Mtetra
.39022 .25137 .39713 .2591 .40866 .25482 .40178 .24706 Mtetra
.40178 .24706 .40866 .25482 .42023 .25053 .41338 .24273 Mtetra
.658 .753 .92 r
.41338 .24273 .42023 .25053 .43185 .24622 .42504 .23838 Mtetra
.42504 .23838 .43185 .24622 .44352 .24191 .43674 .23403 Mtetra
.43674 .23403 .44352 .24191 .45524 .23758 .4485 .22966 Mtetra
.4485 .22966 .45524 .23758 .46702 .23323 .4603 .22528 Mtetra
.4603 .22528 .46702 .23323 .47884 .22887 .47216 .22089 Mtetra
.47216 .22089 .47884 .22887 .49071 .22449 .48406 .21647 Mtetra
.48406 .21647 .49071 .22449 .50264 .2201 .49602 .21204 Mtetra
.657 .753 .92 r
.49602 .21204 .50264 .2201 .51462 .21569 .50803 .2076 Mtetra
.50803 .2076 .51462 .21569 .52664 .21126 .5201 .20313 Mtetra
.657 .752 .92 r
.5201 .20313 .52664 .21126 .53873 .20681 .53221 .19865 Mtetra
.53221 .19865 .53873 .20681 .55086 .20235 .54438 .19415 Mtetra
.54438 .19415 .55086 .20235 .56305 .19786 .55661 .18962 Mtetra
.55661 .18962 .56305 .19786 .57529 .19336 .56888 .18509 Mtetra
.56888 .18509 .57529 .19336 .58758 .18884 .58122 .18053 Mtetra
.58122 .18053 .58758 .18884 .59993 .1843 .5936 .17595 Mtetra
.5936 .17595 .59993 .1843 .61234 .17974 .60604 .17135 Mtetra
.60604 .17135 .61234 .17974 .6248 .17516 .61854 .16674 Mtetra
.61854 .16674 .6248 .17516 .63731 .17057 .63109 .1621 Mtetra
.63109 .1621 .63731 .17057 .64988 .16595 .6437 .15744 Mtetra
.6437 .15744 .64988 .16595 .66251 .16131 .65637 .15277 Mtetra
.65637 .15277 .66251 .16131 .67519 .15665 .66909 .14807 Mtetra
.66909 .14807 .67519 .15665 .68793 .15197 .68187 .14335 Mtetra
.68187 .14335 .68793 .15197 .70073 .14727 .69471 .13861 Mtetra
.69471 .13861 .70073 .14727 .71359 .14255 .7076 .13385 Mtetra
.277 0 .256 r
.02649 .37914 .04106 .34189 .04516 .37726 .03765 .36854 Mtetra
.529 .653 .914 r
.03765 .36854 .04516 .37726 .05504 .37512 .04737 .36754 Mtetra
.587 .71 .928 r
.04737 .36754 .05504 .37512 .06483 .37393 .05732 .36533 Mtetra
.849 .405 0 r
.05732 .36533 .06483 .37393 .07604 .36308 .06461 .38194 Mtetra
.812 .894 .477 r
.06461 .38194 .07604 .36308 .08577 .36291 .0782 .35499 Mtetra
.586 .701 .922 r
.0782 .35499 .08577 .36291 .09588 .36038 .08827 .35278 Mtetra
.592 .713 .928 r
.08827 .35278 .09588 .36038 .10583 .35941 .09842 .35042 Mtetra
.952 .665 .457 r
.09842 .35042 .10583 .35941 .11711 .34861 .093 .46702 Mtetra
0 0 0 r
.093 .46702 .11711 .34861 .12714 .34772 .11963 .33981 Mtetra
.597 .708 .921 r
.11963 .33981 .12714 .34772 .13746 .34492 .12992 .33733 Mtetra
.611 .723 .925 r
.12992 .33733 .13746 .34492 .14777 .34259 .14031 .33451 Mtetra
.45 .644 .94 r
.14031 .33451 .14777 .34259 .16021 .32235 .1504 .33456 Mtetra
0 0 0 r
.1504 .33456 .16021 .32235 .16925 .33168 .1619 .32303 Mtetra
.566 .678 .914 r
.1619 .32303 .16925 .33168 .17975 .32887 .1723 .32121 Mtetra
.623 .728 .922 r
.1723 .32121 .17975 .32887 .19033 .32569 .1829 .31806 Mtetra
.621 .73 .924 r
.1829 .31806 .19033 .32569 .20091 .32303 .19355 .31495 Mtetra
.51 .673 .938 r
.19355 .31495 .20091 .32303 .21558 .27989 .20402 .31406 Mtetra
.26 0 .243 r
.20402 .31406 .21558 .27989 .2228 .31181 .21558 .30276 Mtetra
.557 .666 .91 r
.21558 .30276 .2228 .31181 .23354 .30887 .22621 .30111 Mtetra
.63 .732 .921 r
.22621 .30111 .23354 .30887 .24438 .30537 .23707 .29774 Mtetra
.639 .74 .921 r
.23707 .29774 .24438 .30537 .25528 .30177 .24799 .29412 Mtetra
.639 .74 .922 r
.24799 .29412 .25528 .30177 .26622 .29827 .25896 .2905 Mtetra
.625 .733 .924 r
.25896 .2905 .26622 .29827 .27714 .29568 .26995 .2872 Mtetra
.371 .597 .934 r
.26995 .2872 .27714 .29568 .28903 .2809 .28064 .28845 Mtetra
.658 .911 .594 r
.28064 .28845 .28903 .2809 .29962 .28376 .2925 .27511 Mtetra
.594 .697 .915 r
.2925 .27511 .29962 .28376 .31073 .28038 .30358 .27253 Mtetra
.64 .739 .92 r
.30358 .27253 .31073 .28038 .32193 .27653 .31479 .26879 Mtetra
.649 .746 .92 r
.31479 .26879 .32193 .27653 .33318 .27251 .32607 .2648 Mtetra
.653 .749 .92 r
.32607 .2648 .33318 .27251 .34449 .26839 .33741 .26069 Mtetra
.656 .751 .92 r
.33741 .26069 .34449 .26839 .35585 .2642 .34879 .25649 Mtetra
.658 .753 .92 r
.34879 .25649 .35585 .2642 .36726 .25996 .36023 .25223 Mtetra
.659 .753 .92 r
.36023 .25223 .36726 .25996 .37872 .25568 .37172 .24792 Mtetra
.659 .754 .92 r
.37172 .24792 .37872 .25568 .39022 .25137 .38326 .24359 Mtetra
.38326 .24359 .39022 .25137 .40178 .24706 .39484 .23923 Mtetra
.39484 .23923 .40178 .24706 .41338 .24273 .40648 .23486 Mtetra
.659 .753 .92 r
.40648 .23486 .41338 .24273 .42504 .23838 .41817 .23049 Mtetra
.658 .753 .92 r
.41817 .23049 .42504 .23838 .43674 .23403 .4299 .22609 Mtetra
.4299 .22609 .43674 .23403 .4485 .22966 .44169 .22169 Mtetra
.44169 .22169 .4485 .22966 .4603 .22528 .45353 .21727 Mtetra
.45353 .21727 .4603 .22528 .47216 .22089 .46542 .21284 Mtetra
.46542 .21284 .47216 .22089 .48406 .21647 .47736 .20839 Mtetra
.47736 .20839 .48406 .21647 .49602 .21204 .48935 .20392 Mtetra
.657 .753 .92 r
.48935 .20392 .49602 .21204 .50803 .2076 .5014 .19944 Mtetra
.5014 .19944 .50803 .2076 .5201 .20313 .5135 .19494 Mtetra
.5135 .19494 .5201 .20313 .53221 .19865 .52565 .19041 Mtetra
.657 .752 .92 r
.52565 .19041 .53221 .19865 .54438 .19415 .53785 .18588 Mtetra
.53785 .18588 .54438 .19415 .55661 .18962 .55011 .18132 Mtetra
.55011 .18132 .55661 .18962 .56888 .18509 .56243 .17674 Mtetra
.56243 .17674 .56888 .18509 .58122 .18053 .57479 .17215 Mtetra
.57479 .17215 .58122 .18053 .5936 .17595 .58722 .16753 Mtetra
.58722 .16753 .5936 .17595 .60604 .17135 .5997 .16289 Mtetra
.5997 .16289 .60604 .17135 .61854 .16674 .61223 .15824 Mtetra
.61223 .15824 .61854 .16674 .63109 .1621 .62482 .15356 Mtetra
.62482 .15356 .63109 .1621 .6437 .15744 .63747 .14887 Mtetra
.63747 .14887 .6437 .15744 .65637 .15277 .65017 .14415 Mtetra
.65017 .14415 .65637 .15277 .66909 .14807 .66294 .13942 Mtetra
.66294 .13942 .66909 .14807 .68187 .14335 .67575 .13466 Mtetra
.67575 .13466 .68187 .14335 .69471 .13861 .68863 .12988 Mtetra
.68863 .12988 .69471 .13861 .7076 .13385 .70157 .12508 Mtetra
.903 .71 .631 r
.01898 .36988 .02649 .37914 .03765 .36854 .03561 .32428 Mtetra
0 0 .262 r
.03561 .32428 .03765 .36854 .04737 .36754 .03966 .35973 Mtetra
.586 .704 .924 r
.03966 .35973 .04737 .36754 .05732 .36533 .04962 .35753 Mtetra
.533 .685 .936 r
.04962 .35753 .05732 .36533 .06461 .38194 .05949 .35628 Mtetra
.679 .523 .668 r
.05949 .35628 .06461 .38194 .0782 .35499 .07081 .34533 Mtetra
.49 .613 .901 r
.07081 .34533 .0782 .35499 .08827 .35278 .08062 .3451 Mtetra
.602 .716 .925 r
.08062 .3451 .08827 .35278 .09842 .35042 .09081 .34251 Mtetra
.519 .679 .938 r
.09081 .34251 .09842 .35042 .093 .46702 .10085 .34147 Mtetra
.548 .328 .534 r
.10085 .34147 .093 .46702 .11963 .33981 .11223 .33057 Mtetra
.525 .643 .908 r
.11223 .33057 .11963 .33981 .12992 .33733 .12234 .32962 Mtetra
.612 .722 .923 r
.12234 .32962 .12992 .33733 .14031 .33451 .13275 .32675 Mtetra
.59 .713 .929 r
.13275 .32675 .14031 .33451 .1504 .33456 .14315 .32435 Mtetra
.858 .721 .71 r
.14315 .32435 .1504 .33456 .1619 .32303 .15572 .30397 Mtetra
.111 .205 .683 r
.15572 .30397 .1619 .32303 .1723 .32121 .16482 .31327 Mtetra
.611 .718 .921 r
.16482 .31327 .1723 .32121 .1829 .31806 .17542 .31039 Mtetra
.626 .731 .923 r
.17542 .31039 .1829 .31806 .19355 .31495 .1861 .30714 Mtetra
.602 .72 .927 r
.1861 .30714 .19355 .31495 .20402 .31406 .19677 .30441 Mtetra
.918 .723 .623 r
.19677 .30441 .20402 .31406 .21558 .30276 .21162 .26105 Mtetra
0 0 .395 r
.21162 .26105 .21558 .30276 .22621 .30111 .21886 .29301 Mtetra
.614 .718 .92 r
.21886 .29301 .22621 .30111 .23707 .29774 .2297 .29 Mtetra
.636 .737 .921 r
.2297 .29 .23707 .29774 .24799 .29412 .24064 .28642 Mtetra
.64 .74 .922 r
.24064 .28642 .24799 .29412 .25896 .2905 .25164 .28274 Mtetra
.635 .738 .923 r
.25164 .28274 .25896 .2905 .26995 .2872 .26268 .27917 Mtetra
.595 .717 .929 r
.26268 .27917 .26995 .2872 .28064 .28845 .27369 .27651 Mtetra
.814 .702 .742 r
.27369 .27651 .28064 .28845 .2925 .27511 .28571 .26161 Mtetra
.372 .469 .83 r
.28571 .26161 .2925 .27511 .30358 .27253 .29639 .2644 Mtetra
.628 .728 .919 r
.29639 .2644 .30358 .27253 .31479 .26879 .30761 .26094 Mtetra
.646 .743 .92 r
.30761 .26094 .31479 .26879 .32607 .2648 .31891 .25701 Mtetra
.652 .748 .92 r
.31891 .25701 .32607 .2648 .33741 .26069 .33027 .25291 Mtetra
.655 .75 .92 r
.33027 .25291 .33741 .26069 .34879 .25649 .34168 .2487 Mtetra
.657 .752 .92 r
.34168 .2487 .34879 .25649 .36023 .25223 .35315 .24443 Mtetra
.658 .753 .92 r
.35315 .24443 .36023 .25223 .37172 .24792 .36467 .2401 Mtetra
.659 .754 .92 r
.36467 .2401 .37172 .24792 .38326 .24359 .37624 .23574 Mtetra
.37624 .23574 .38326 .24359 .39484 .23923 .38786 .23135 Mtetra
.38786 .23135 .39484 .23923 .40648 .23486 .39952 .22694 Mtetra
.39952 .22694 .40648 .23486 .41817 .23049 .41124 .22252 Mtetra
.658 .753 .92 r
.41124 .22252 .41817 .23049 .4299 .22609 .42301 .2181 Mtetra
.42301 .2181 .4299 .22609 .44169 .22169 .43483 .21365 Mtetra
.43483 .21365 .44169 .22169 .45353 .21727 .4467 .2092 Mtetra
.4467 .2092 .45353 .21727 .46542 .21284 .45863 .20473 Mtetra
.45863 .20473 .46542 .21284 .47736 .20839 .4706 .20024 Mtetra
.4706 .20024 .47736 .20839 .48935 .20392 .48263 .19573 Mtetra
.48263 .19573 .48935 .20392 .5014 .19944 .49471 .19121 Mtetra
.657 .753 .92 r
.49471 .19121 .5014 .19944 .5135 .19494 .50684 .18667 Mtetra
.50684 .18667 .5135 .19494 .52565 .19041 .51903 .18212 Mtetra
.657 .752 .92 r
.51903 .18212 .52565 .19041 .53785 .18588 .53127 .17754 Mtetra
.53127 .17754 .53785 .18588 .55011 .18132 .54356 .17294 Mtetra
.54356 .17294 .55011 .18132 .56243 .17674 .55591 .16833 Mtetra
.55591 .16833 .56243 .17674 .57479 .17215 .56832 .16369 Mtetra
.56832 .16369 .57479 .17215 .58722 .16753 .58078 .15904 Mtetra
.58078 .15904 .58722 .16753 .5997 .16289 .5933 .15437 Mtetra
.5933 .15437 .5997 .16289 .61223 .15824 .60587 .14967 Mtetra
.60587 .14967 .61223 .15824 .62482 .15356 .6185 .14496 Mtetra
.6185 .14496 .62482 .15356 .63747 .14887 .63118 .14022 Mtetra
.63118 .14022 .63747 .14887 .65017 .14415 .64393 .13547 Mtetra
.64393 .13547 .65017 .14415 .66294 .13942 .65673 .13069 Mtetra
.65673 .13069 .66294 .13942 .67575 .13466 .66959 .12589 Mtetra
.66959 .12589 .67575 .13466 .68863 .12988 .68251 .12107 Mtetra
.68251 .12107 .68863 .12988 .70157 .12508 .69548 .11623 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{Inherited, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05Yoo`0JD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoAMo
o`03001oogoo04Moo`00Qgoo0`001Woo00<007ooOol0F7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069o
o`0PD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoAIoo`03001oogoo04Ioo`00PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eo
o`00P7oo0P00Hgoo02EBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_`005;lD_d00e;l00=BoE;lOol05Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1M
Ool0;5;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00HGoo
03ABo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo049o
o`00Lgoo0`00HGoo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00ABoE;lD_aB
o1Moo`03001oogoo045oo`00LGoo0P00HWoo03UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo0`00@Woo001^Ool3001POol2D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001oogoo
041oo`00Jgoo0`00HGoo045Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo03moo`00JGoo0P000goo00<007oo
Ool0Fgoo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_`005;m00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`0oOol006Ioo`<005moo`19D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d05Woo00<007ooOol0?Woo001TOol2001POol00e;lD_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aB
o5;m00=Bo005D_eBo5;lD_aBo@02D_`FOol00`00Oomoo`0mOol0065oo`<0061oo`1?D_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
05;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d05Goo00<007ooOol09Goo0`005Goo000eOol4000V
Ool2001OOol00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`00e;m
D_aoo`0EOol00`00Oomoo`0VOol00`00Oomoo`0COol003Aoo`03001oogoo009oo`03001oogoo021o
o`<0061oo`1ED_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
5Woo00<007ooOol09Goo00<007ooOol04goo000iOol00`00Oomoo`0NOol20002Ool00`00Oomoo`1L
Ool2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l
5Goo00<007ooOol097oo00<007oo000057oo000/Ool60007Ool00`00Oomoo`0KOol3001OOol0G5;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_dFOol00`00Oomoo`0SOol00`00Ool0000DOol003Eoo`@001aoo`80061oo`9Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Io
o`03001oogoo025oo`05001oogooOol0000COol003Eoo`03001oogoo01Yoo`<0061oo`1RD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoAAoo`8002=oo`05001oogooOol0000COol003Eoo`03001oogoo01Moo`<005moo`9B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0OOol3000017oo000000004Woo000e
Ool5000COol2001POol0JE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0g
Ool004Yoo`<00003Ool007oo05eoo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`EOol00`00Oomoo`08Ool4000[Ool004Qoo`8005moo`1`D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0XOol0
04Eoo`<005moo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02
D_`FOol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004=oo`80061oo`1eD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo02Qoo`00@7oo0`00GWoo00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol0:7oo000nOol2001MOol0Oe;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00>goo1000GGoo0e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
D_aoo`0DOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003Uoo`8000Aoo`03001o
ogoo05Qoo`24DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol00goo1000:goo000fOol3
001MOol3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01=oo`800003Ool007oo039oo`00<goo
0`00GWoo08]BoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0a
Ool0035oo`8005moo`03D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00P0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d05Goo00<007ooOol0<7oo000^Ool3001MOol0Le;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00<0000MD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0_Ool002aoo`@005aoo`03D_aB
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00`0000IBoE;lD_aB
o5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol0
0`00Oomoo`0_Ool002Yoo`8005ioo`1aD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@03000095;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02ioo`00:Woo0P00Fgoo00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`00000D_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003
D_eBo5;l01Eoo`03001oogoo02ioo`0047oo1@000goo100017oo10001Woo00<007oo0000EWoo07=>
g5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0030000:U;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo02eoo`004Woo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo00=oo`800003Ool007oo04aoo`04I[L]fBgJ;MT2C]`01TkM
C]a>g5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_`000020003D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Eoo`03001oogoo02aoo`004Woo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`8000=oo`03001oogoo035oo`03M]<02goo
01Eoo`1fI]MV]VKG;MT]fRWIC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`30000<U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`0/
Ool000Moo`H000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool00g;C00aoo`0EOol01fJgI]MV]RgJ;MT]fRgI009>g005
C]e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_`000020003D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0DOol00`00Oomoo`0[Ool0019oo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0_Ool0
0gKcL]=oo`0DOol0LFJfI]MV]VKGI[H]fRgI;MXYfE;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
0`0003UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
4goo00<007oo0000;7oo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol00Woo0P001Woo0P00;goo0W;C57oo00=V]fKGI[H00VJg00=VedZlB[`00dZl0Tkl00EBoDkL
C_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;l00000P000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00IBoE;lD_aBo5;mD_`DOol00`00Oomoo`0ZOol0011oo`<000Aoo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0[Ool017;CM]=bdP0<
3goo00U:gD[LB]e:_4[MI[IVefJfI]L00U>B06E:_4[MB[a:gDkLD_e>g5;mC]aBoDklD_e>g5;mC_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00<00010D_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_dEOol00`00Oomoo`0YOol0019oo`03001oogoo00=oo`@000Aoo`@000Eoo`03001oogoo00Qo
o`03001oogoo02Yoo`9bd`03M]<02goo00]oo`04C_e>g4kmC]`3B]d014[LI[MV]fKG0e>B1DZl00E>
o5;lD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aB
o5;lD_eBo0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol0:7oo000XOol00`00Oomoo`0:
Ool00`00Oomoo`0YOol017;BM_=bd`0<2Woo071>g5;mC]aBoDkLD_e>g4[MB]a:gDZlI]MCTVKGI[H]
fRgIC_e>g4kmC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@800017D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00EOol00`00Oomoo`0XOol002Qo
o`<000]oo`03001oogoo02Moo`06L]=fdg;CL]<031`71goo00YBoDkLC_e>o5;mC]a>oDkLC_e>g0=:
g@08;UeV]fJgI]L]fBgJ;MU>g@=>g005C]eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00U;l0`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`EOol00`00Oomo
o`0WOol002Qoo`03001oogoo00aoo`03001oogoo02Ioo`06M_=bdgKCL]80300;0goo071>g5;mC]aB
oDkLD_e>g5;mC]aBoD[LC_e>g4kmB]`^GBYM;UeV]VKGI[IVebWI;MX]fBgJC]aBoDkLD_e>g5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@<0001>D_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol09Woo000XOol00`00Oomoo`0=Ool00`00Oomoo`0U
Ool3L]<01WKCL]<034kLC]e:g09>g00=C_e>g4klC]aBoDkLC_e>o5;mC]a>gDkLC_d00RiM00=V]fKG
I[H00VJg1DZl00A>g4klC_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00<0009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Aoo`03001oogoo02Ioo`00
:7oo0P003goo00<007ooOol097oo07=fdg;BM_=bdgKC00/034[LC]e:_4kMB]aBoDkLD_e>g5;mC]aB
oDkLD_e:g4kmC]a>oFJfI]MV]VKGI[ICTTnAB]e:_4[MB[aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@030000EU;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`DOol00`00Oomoo`0UOol002Qoo`03001oogoo00moo`03001oogoo029oo`9bd`09
M]=bdg;CL]<0300;00a>g4km00=>g00:D_e>g4klC_aBoDkLC_e>g4kmB]`3B]d01VJfI[MV]e>BCi5C
TPE:_005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00<0009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Eoo`03001oogoo02Aoo`00:7oo
00<007ooOol047oo00<007ooOol08Goo06ibdWKcL]=fdg;BM_=2W4Jl@Ya6_4kLC_e>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLD_e:_4[MB]aVefJfDi9V]VKG:MT]fTkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m0`0005eBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d04goo0P009Woo000WOol00`00Oomoo`0BOol00`00Oomoo`0AOol00f[E
3=Eoo`08Ool00d[MB]a:g@02B]d3L]<00gKCL]=bd`04AY`03dkLC_e>g4kLC_aBoDkLC_e>o4kmC]a>
oDkLC_e:g002B]d02BiMI[IV]fJg;MX]fBgJC]a>g@03C]`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00<0009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`DOol00`00Oomoo`0SOol002Moo`<001=oo`03001oogoo011oo`03K]IZe@cE00Eo
o`1_C_e>g4kmC]a>gD[LC]e:g7KCL]9flg;CM]=bdTJl@Ya6_4:LA[a>g5;mC]aBoDkLD_e>g5;mC]a>
oD[LC_e>g4km:U`^GBYMI]MV]VKGI[H]fRWI;MX]fE;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00<0001TD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`EOol00`00Oomoo`0ROol002Moo`03001oogoo01Aoo`03001oogoo00ioo`9ZeP0>
K]H8]@cEB]a>gD[LC]a:g4kmC]a>gDkLB]e:g09:g@03M]=bdg;C009bd`0500a>g4kLC]e:g002C]`0
34kmC]a>o4kLD_e>g4kmC_a>oDkLC]e>g08^G@9V]`03I]MV]VJg00E:_005D_e>g4klC_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0P000U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00IBoE;lD_aBo5;mD_`DOol00`00Oomoo`0ROol001Eoo`@000Aoo`@000Ioo`03001o
ogoo01Eoo`03001oogoo00eoo`1cJ]E^eV[E3=D8]0cEB]a>gDZlC]e>g4kmC]a>oDkLC]e:g4kML]=f
dg;BM]=bd`0<00]>gD[LC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmC]aVefJfI]MV]VKGCg5C
TTZlB]e:_4[MC]aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`00`0006YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
05;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo
025oo`0057oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo01Ioo`80
00aoo`0;J]I^eV[EJ]H8]@cE2;D<eD[LC]e:g002C]`01TkMC]a>gDkL?[dnW@Ebd`@03007C]a>oDkL
C]a>o5;mC]`00Tkl00IBoDkLC_e>o4[MB]`2B]d01VKGI[IV]dnADi5?L@E:_003D_aBoDkl009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`300000e;lD_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04goo00<007ooOol087oo000IOol01000
Oomoo`0017oo00<007ooOol00goo0P006Goo00<007ooOol02Goo06i^eV[EK]IZeFkF2;@<e@Rd3=E>
g4kmB]a>oD[LC_e:g4km?Yefdg;BM]=bdgKCL]96_4:LA[a2W4JlC]a>oDkLD_e>g5;mC]aBoDkLD_e>
g5;mC]a:gDZlB]eV]VKGI[IVefJf;MX]fDkmC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l0`00079Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`0POol000aoo`H000Moo`04001oogoo0004Ool00`00Oomo
o`02Ool00`00Oomoo`0JOol00`00Oomoo`07Ool01VkFJ]EZeV[FK]IZe@=6_00:AYa6_4kLC]e>g4kM
C]a>gDkLC]d7L]<4AY`2C]`05TkmC]a>oDklD_e>g4kmC]a>oDkLC_e>g4[MB]a:gFJgI]MV]VJg;MT]
fRgI0TkL00E>gDkLC]aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo0<00003D_aB
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo
00<007ooOol07goo000EOol40003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0KOol0
0`00Oomoo`03Ool0K4[MA[a:gDZlK]IZeFkFJ]E^eV[EA[e6W4JlAYa6_DkLC_e>g4kmB]a>gD[LC]eb
dgKCL]9fdg;CM]=2W4Jl@Ya6_4:LD_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e>g2iM:U`^GFJfI]MR
]VKG;MT]fRgIC_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0<0001iD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo
00<007ooOol07goo000EOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool200000goo
L]=oo`0JOol03000B]a>gD[LC]e:g4[MB]a:gF[FK]HfO@9ZeP06K]H8]@cEB]a>gD[L0TkL00=>oDkL
C]d00T[M00=:g7;CL]<017;C00X034[LC]a>g4kMB]a>o4kLC_e>g09>o007D_e>g4kmC]a>oDkLC]d0
0RiM00UV]VJgI[MVefJf;MX]fBgJ;MT00Tkl00EBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l0`00
00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0NOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`04001oogooK[<HOol09DE@@C12W3il@Ya:g4kMB]a>gD[LB]e6_4[M=We^eV[EK]IZ
e@cE2;@<eD[LC]e:_4kmC]a>oDkLC_e:g4kMB]afdg;CM]=bdWKC00803017B[a>gD[LC]e:_5;mC]aB
oDkLD_e>g5;mC]aBoDkLC_e:g4kmI[IVef:fI]MV]TnACg1:gDZlB]e:_5;mC]aBoDkLD_e>o5;mC]aB
oE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo0030000PE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0MOol001Eoo`D000=oo`@0
00Eoo`04001oog;CL]<GOol03TE@@C15<49l@Ya2O4:L@Wa>gD[LC]e:g3ZM=Wd2J]H00fkFJ]EZeP02
3=D030ReC]a:g4kMB]a>gDkLC]e>g4kM?Ydn_@Ebd`@0309>g00;C_e>g4klC_aBoDkLC_e>o5;mC]a>
o@02B]d01D[LB]eV]fKGI[H00Tma00=?TDZlB[`00dZl0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`300000e;lD_eB
o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eBo5;l01=oo`8001moo`009Woo00@007ooL]Ab/aIoo`1[AE11<4E@@C15
D4ZlB]e:_4[MB[a>gD[LC_dfOCZMJ]E^eV[EK]IZeFkF2;D<e@RdC_e>g4kmB]a>oD[LC_e:g4:mL]=f
dg;BM]=bdgKC@Ya6_4:LA[a2W5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a:gDZlI]MV]VKGH[IV
ebgI;MY>g4kmC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBo@020000R5;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m57oo00<007ooOol077oo000UOol01P00Ool007:cL]<01aAoo`0:AE11<4D`@C15D44`001:g4[M
B[`2B]`01TkMB]a>gF[FK]IZe@9ZeP03K]IZeDJl0096_009AYa>gDkLC]e>g4kMC]a>gDkL00Mbd`A6
W0=>g00;C_e>g4kmC_aBoDkLC_e>g4kmC]a>o@02B]d024[LI[MV]fJgI[H]fRgI;MX3C]`01DkMC]aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
o@00000005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Aoo`03001oogoo00Mo
o`D000moo`009Goo0P0000Ab/g;CK[<020eoo`0=C]e:_4kMB]a>gCjM@[e1<4E@@C15D44`AE000P00
05i:_4[MB[a:gDZlB]e6_4[MJ]E^eV[EK]IZeFkF2;A6_DJLA[a6W4kmC]a>oDkLC_e:g4kMB]afdg;C
M]=bdWKCL]<034:LA[a2W4JlC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmB]a>oBYM;UdZG6KGI[IVef:f
;MX]fBgJ;MUBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBo@<0002>D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`D
Ool00`00Oomoo`07Ool01@00Oomoogoo00003goo000UOol00`00Oombd`02L]<00`07Oomoo`07Ool0
45HDEQDjG3il?Ua:gD[LB]e:g4:m?Ye5<44`AE11<4D`100000A:g4kMB]a>g@9:g@05B]a:gF[FK]IZ
e@02J]H23=D024kLB]a>gD[LC]e>g4kmC]`3B]d00d[LL]=bd`04L]<04P0<B]a>g4kLC]e>g4klC]a>
oDkLC_e>o5;mC]a>gDkLC_e>g08^G@03I[MV]VJg009V]`E:_09>o005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d00000001Bo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Aoo`03001oogoo00Moo`03001oogoo011oo`00
9Goo00L007;CK[=be7:c00PL1`06Ool0=eHEDOAF5E7dEQDjFcil>U/nO4ZlC]e:g4:m@C15D44`AE11
<4EA?Wa2W3il@Ya:g4kMB]a>gD[LB]e6_4[M=We^eV[EK]H8]@cE2;A>gD[LC]e:_4kmC]a>oDkLC]e:
g4kMB]afdg;CM]=bdgKC0080300dB[a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e:g6KGI[IV
ef:fI]M;L4maB[a:gDZlB]e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d30000UU;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo1Aoo`03001oogoo00Moo`03001oogoo00moo`009Goo00L007;CL]=b/g;C00LP1`05
Ool2EQ@07UHEDOAF55HDEQE:_4ZmB[a:gD[LB]dn_DE@@C15<44`AE11<4E@@Wa2W49l@Ya:g4kMB]a>
gD[L=YdfO@9ZeP03K]IZeF[F008<e@0;B]a>g4[LC]e:g4kMC]a>gDkL?[dnW@06L]<300`3C]`02Tkm
C]a>o4klD_e>g4kmC_aBoDkL0d[M00E:g6JgI[MV]d]`009?L@E:_004C_aBo5;lD_d3D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00<00005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0BOol00`00Oomoo`08Ool00`00Oomo
o`0>Ool002Eoo`07001be7:cL]=^/`0870L00Woo0d:m06QAm5HEDOAF5E7dEQEWKVN?A[a:gDJlB]e6
_4:m@C15D44`AE11<4E@@C15DDZlB]e:_4[MB]a>gD[LC_dfOCZMJ]E^eV[EK]IZe@cE2;D<eD[LC_e>
g4kmB]a>oD[LC_e:g4kmL]=fdg;CM]=bdgKC@Ya6_4:LA[a>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>
g4[MB]a:gF:fI]M;L6KGH[HafRgIC_e>g4kmC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;m0`0009eBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0DOol00`00Oomoo`08Ool00`00Oomoo`0=Ool002Eoo`03001b
/g;C009bd`0500M:gDZlB]e:_002@[d06UHEDOAF55HDEQEAm6N>Ifi:gDZlB[e:_4[M?Ye5<44`AE11
<4D`@C15D44`001:g4[MB[`2B]`01TkMB]a>gF[FK]IZe@9ZeP033=D004Jl0096_005C]a>gDkLC]e>
g003B]d00d[LB]ebd`05L]<3AY`03TkmC]a>g4kLC_e>g4kmC_aBoDkLC_e>g4kmC]`3B]d022YMI[MV
]fJg;MT]fRgIC]d3C]`01DkMD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00<00005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l5Goo00<007ooOol00goo00D007ooOomoo`0000moo`0097oo044007:cL]=^/g;DL[<02007
B]e6_4[MA[a:gD:mEQEAm5HEDOAWSf=^IhmWKTkMB[a>gD[LAE11<4E@@C15D44`AE51<4E@001:gDZl
B]e:_4[MB[a:gDJlB]eZeFkFJ]E^eV[E3=E6W4JmAYa6_4JLC_e>g4kmC]a>gD[LC]e:g7KC00=bd`0[
M]=bddJl@Ya6_4:LD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e:g2iM:Ud^GF:fI]MV]VKG;MTafRgI
;MY>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_d00`000:ABoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
57oo00<007ooOol017oo0`0047oo000TOol02@00L]=bdg;CL[=bd`0700P01`03B]d01DZl@[eF55HE
DO@00UHD00mF5CYL?W`nG4[MB]a:gD4`AE11<4D`@C15D44`AE000`0000E>gD[LC]e:g4kM009:g@03
B]aZeV[F00=ZeP8<e@09B]a>g4[LC]e:g4kMC]a>oDkL00=:g@03B]abdg;C00=bd`0300a>gD[L009>
g00?C_e>g4klC]a>oDkLC_e>o5;mC]a>gDkLC_dZGBiM009V]`03I[IV]fJg00E:_004C]a>o4klD_d3
D_`01E;mD_`00000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00
Ool05goo000TOol01`00K[=be7:cL]=^/d:M0092W00j?Wa:gDJlB]e6_5HEDOAF5F=^EQEAm3il>U/n
O3YK?Wa6_4E@@C15D44`AE11<4E@@C15DCil@Y`nO4kMB]a>gD[LC]e:_4[MA[`jWF[EK]IZ]@cE3;D<
eDZlC]e:g4kMC]a>oDkLC_e>g4:m?Ye2_G;CM]<3L]<0900=00a>gDZlC]e:g4kMC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4kmH[IVefJfI]MR]TmaBg1:g4ZlB]e:_5;mC]aBoDkLD_e>g0<0002[C]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01Eoo`006Woo10001Woo
00<007;CL[<00W;C0Woo14:L0d[M00EAm5HDEQAF5E8D009F500IB]e:_4ZmB[a:gD4`AC11<4E@@C15
D44`AE11D4:L@Wa2W49l@Ya:g4kMB]a>gCIm=Yd01F[F0`cE00Y:g4kLB]a>gDkLC]e>g4kMC]`n_@Ib
d`<03006C_e>g4kLC]a>oDkL0Tkl00IBoDkLC_e>g4kmC]`3B]d00fJfI[MV]`03Bg05B[`00e;mC_`0
00020003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4goo00<0
07ooOol05Goo000IOol00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oombdfjc17oo00@024:L@Y`n
O0=2_@0bDOAF5E7dEQEAm5HEHfi:gDJlB]e6_4E@@C15D44`AE11<4EA@C15DD4`C]e:_4[MB[a>gD[L
C]e:g3ZM=We^eVZeK]IZeFkF2;@<e@be3=E:g4kmC]a>oD[LC_e:g4kmB]afd`=bd`0PM]=bddJl@Ya6
_4:LC_e>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e:_4[MB]aVef:fCg5V]VKG;MTafTkLC_e>g0<0002c
C]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00C
Ool00`00Oomoo`0DOol001Uoo`03001oogoo009oo`03001oogoo00=oo`8000Ioo`0500L024ZlB]e:
_002@[d01EHEDQAF55HDEQD00fM^00YWSTZlB[e1<4E@@C15<44`AE11<0=5D005001:g4[LB]e:_002
B]`00dkMB]aZeP05J]H00`cEAYa6_002A[`01DkLC]e>g4kMB]`00d[M00=:g7;CL]<017;C0dJL00m>
g4kmC]a>o4kLC_e>g4kmC_aBoDkLC_e>g4kmB]`00T[M00H^GFJfI[MV]bgJ;MT30003C]`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`057oo00<0
07ooOol04goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0700800M:gDJl
B]e6_4[M@[eF5E7dEQEAm5HEDO@nO3YK?W`nWDE@@C15D44`AE51<4E@@C15DD4`0`0001a:g4kMB]a>
gDJlB]e6_6kFJ]E^eVZeK]IZe@cEAYa6_DJLA[a>g4kmC]a>oD[LC]e:g4kML]=fd`=bd`0HM]<034Jl
@Ya6_4kLD_e>g5;mC]aBoDkLD_e>g5;mB]a>oDkLC_dZG2iMI[IVef:f0`000;X]fC7J;MUBoDkLD_e>
g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dC
Ool00`00Oomoo`0COol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Ioo`0300L0
200700=:g@0MB[a2_EHDEQEB56M^EQAF5CYL?W`nG4:m@C15<44`AE11<4E@@C15D45@0015D4:L@Wa2
W4[LC]e:g003B]d00d[LJ]IZeP03J]H23=D02D[LC]a:g4kMC]a>gDkLC_e>g003B]d5L]<200`04TkM
B]a>g4kLC_e>g4klC]aBoDkLC_e>o5;mC]a>gDkLC_eV]P<00003I[IV]dZl00A:_005D_e>g4klC_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aB
o5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01=o
o`03001oogoo019oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo02]2O4:L
?Wa:gDJlB]e6_5HEDOAF5E7dEQEAm5HE>U/nO3jMAE11<4E@@C15D44`AE51<4EA0015DCil@Y`nO4kM
B]a>gD[LB]e6_4[MA[a^eV[EK]IZ]@033=D02dZlC]e:g4kMB]a>oD[LC_e:g4:m?Yd00W;C01Afdg;C
L]<0300=B]a>gDZlC]e:g5;mC]aBoDkLD_e>g5;mC]aBoDZl0`000<5R]VKGI[IVed]?Bg1:_4[LB[a:
gDZlD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo00DOol00`00Oomoo`0AOol001Uoo`03001oogoo009oo`03001oogoo009oo`8000Uoo`A2
W09:g@05DQAF56M^EQEB5002EQ@02T[MB[a2_D4`AE11<4E@@C15D44`1DE@00Y2O4:L@Wa>gD[LC]e:
g3JM=WdfW@EZeP<<e@09C]a>gDkLC]e>g4kMC]a>gCjM00Ibd`0500d0300<C]a>o@03C]`01U;mC]a>
o4klC_e>g0<00005B]a:gD[MI[MV]P03I[L012gI;MY>g4kM0dkL00EBoDklD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1=oo`03001oogoo015o
o`006Woo10001Goo00<007ooOol02Goo00A6_4[MA[a:g@92_@0bDOAF5E7dEQEAm5HEHfe:gCjMAE11
<4E@@C15DD4`AE51<4EA@E15DD4`001:_4[MB[a>oD[LC]e:g4kmJ]E^eVZeK]IZeFkFAYa:_DJLA[a:
g4kmC]a>oD[LC_e:g4kmL]=fd`=bd`0=M]AbddJl@Ya6_4kLC_e>g5;mC]aBoDkLD_d00P000<Q>g5;m
C]aBoDZlB]e:g6KGH[IVefJf;MX]fC7jC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m4Woo0`004Woo0005Ool200000goo0000
000IOol00`00Oomoo`0:Ool00dZlB]e:_002@[d03VN>DQAF55HDEQESKVM^Hfi2_D4`AC11<4E@@C03
AE001D5@AE15D4E@00000T[L00=:gDZlB]`00T[M00=:g4[MJ]H016[F00X<eDJLA[a6_4kMC]a>gDkL
C]e:g0=:g@Ibd`E6W003C_e>g4kl00<0000<C_e>o5;mC]a>gDkLC_dZGBiM:UeV]fJf0VJg00D]fRgI
;MY>g4kM009>g003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`00e;mOomoo`0AOol00`00Oomoo`0@Ool000Aoo`03001oogoo008001Yoo`03
001oogoo00Yoo`04B]e6_4[MA[`2@[d04eHEDOAF5E7dEQDjFcil?Ye5D44`AE11<4E@@C15DD4`0011
<4EA00<0000=C]e:g4kMB]a>gDJlB]e6_6kFJ]E^eVZeK]H00PcE00]6W4ZmAYa>oDkLC_e>g4kmB]a>
gD[L009bd`09M]Abdg;CL[<03D[LC]e:_4kM00<0003?D_e>g5;mC]aBoDkLD_e:g4kmC]`^GBYLI]MV
]VKGH[IVebgI;MX]fC7jC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01=oo`03001oogoo00moo`0017oo00D007ooOomoo`00
01Uoo`<000aoo`=:g@05B[a2_EHDEQEB5002EQ@035HE>Ua2_D4`AE11<4E@@C15D45@AE0000=5D008
@Wa2W49lC]e:g4kMB]a>g@9:g@03B]`fWF[F009ZeP<<e@09B]a>g4[LC_e>g4kMC]a>oD[L009:g@Eb
d`0300`03@000080009>g00>D_e>g4klC_aBoDkLC_e>o4kmC]a>gDkLI[MV]P=V]`03Adm;D4Zl00=:
_006C_aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eoogoo015oo`03001oogoo00ioo`0017oo00D007ooOomoo`0001Uoo`03001o
ogoo00eoo`0eB]e6_4[M@YaF5E7dEQEAm5HEDOAF5D4`AE11<4E@@C15DD4`AE51<4EA@E15DD4`@Y`n
O4:L?Wa2W4[LC]e:g4km=WdjWFZeK]IZeFkFJ[D@e@cEC]e:_4kMB]a>gD[LC_e:g4km?Yefe002L]<0
0g:cM]@000020000eP0=00a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDZlB]e:g6KGH[IVedM?Bg17
Cd[MB[a:g4ZlB]e>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l4goo00<007ooOol03Woo0004Ool01@00Oomoogoo00006Goo00<0
07ooOol03Woo0d[M00A2_EHDEQAF5@9F5007Hfe5D44`AC11<4E@@C001TE@00I5DDE@B]a:g4[MB[`2
B]`014kMB]`fWCIm1F[F0`cE00U>gDkLC]e>g4kMC]a>gDkLC]d00W;C0`0000=bddJLAY`00dJL00I>
oDkLC]a>o5;mC]`2C_`01dkmC]a>oDkLB]e:g4[M009V]`05AdmV]fJg;MX]f@02C]`01TkMC]a>g5;l
D_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
15;mD_aBo5;l4goo00<007ooOol03Goo0003Ool20002Ool2000IOol00`00Oomoo`0?Ool3@[d0;U7d
EQEAm5HEDOAWST4`AE11<4EA@C15D44`AE51<4EA@C15DD5@AE4004kMB[a:gDZlC_e:g4kMB]a^eV[E
K]IZ]FkFJ]D@eDJLB[e6W4kmB]a>oDkLC_e:g4kM0`000=ife7;CL]=b/g;D@Ya6_4:LA[a>g4kmC]aB
oDkLD_e>g5;mC]aBoDkLD_e>g4[MB[a:gBYMI]MR]VKG;MT]fRgIC_e>g4kmC]a>oDkLD_e>g5;mD_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`C
Ool00`00Oomoo`0<Ool0029oo`80019oo`03@[eF5EHD009F500;IfiSKDD`@C15D44`AE11<4E@@E00
0005AE0300000d[LB]e:_003B]d00d[LJ]IZeP03J]H00`cEA[a6W003A[`00dkLC]d000020003B]d5
L]<5AY`00dkLC_e>g002C_`02U;mC]a>oDklC_e>g4kMC]`^GBYM0fJg00EV]VJg;MT]fRgI009>o005
D_e>g4klD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00ABoE;lD_aBo19oo`03001oogoo00aoo`008Woo00<007ooOol04Goo02U2_E7dEQEAm5HE
DOAF5D4`AE0nWDE@@C15DD4`AE4004EA@E15DD4`000nO4:L?Wa2W4[LC]e:g4[MA[a:gDJlK]IZeFkF
J[E^ePcEC]e:_4kM00<00009C_e>g4kMB]a>gD[LC]eb/g;D009bd`3J00a>gD[LC]e:_4kMC]aBoDkL
D_e>g5;mC]aBoDkLC_e:g4kmC]aVef:fI]MV]VKGH[I:gDZlB]a:_5;mC]aBoDkLD_e>o5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA=o
o`03001oogoo00]oo`008Goo00<007ooOol04goo00A2_EHDEQESK@9F5006AE11<4:m@C15D44`1TE@
00Y5D@00AE52O4:L@Wa>gD[LC]e:g0=:g@03B]aZeV[F009ZeP8<e@80000:C]a:g4kMC]a>gDkL?[dn
WCjm?Yd4L]<02P0=00a>g4kLC]e:g4kLC_aBoDkL0Tkl00IBoDkLC_e>o4[MB]`2B]d016JgI[IV]fJg
0TM?1DZl00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`04Woo0P0037oo000QOol00`00Ool0000COol08d:LEQEA
m5HEDOAF5D4`AE11<4EA@C15DD4`AE51D4EA@C15DD5@0011D4EA?Wa2W3ilC_e:g4kMB]`jWCIm>YeZ
]FkFJ]D00`0000`<eA3EB]a>oDkLC_e:g4kmB]a2_CjML]@2L]<0gG:cL]@0300=00`03DkLC_e>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLB]e:_4[MI[IVef:fI]MR]S7J;MU>oDkLC_e>g4kmC]aBoDkLD_eBo5;m
C]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`04goo00<007ooOol02Woo000QOol2000DOol02T:mEQAF55HDEQEF54D`@C15D44`0dE@00=1D4E@
AE0014E@00a5DDE@001:g4[MB[a>gD[LC]e:g4kMJ]H300000f[FA[a6W003A[`024kLC]e>g4kMC]a>
gDkLC]d6L]<4AY`044kLC_e>g4kLC_aBoDkLC_e>o4kmC]a>oDkLB]e:g4[M0VJg00EV]VJg;MT]fRgI
009>g005C]e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0AOol2000;Ool000moo`@000Aoo`@000Ioo`03001o
ogoo01Aoo`0LEQEAm5HEDOAF5D4`AE11<4E@@C15DD4`0011<4EA@E15DD4`AE55D4EA001>gDZlB]e:
_4[MA[`3000056[EK]IZ]FkFJ]E6_4JLB[e6W4kmB]a>oDkLC]e:g4kMB]a>gG:cL]@2L]<0gG:c00e2
W4Jl@Ya6_4kLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oDkL;UdZG2iMH[IV]f:fI]L]fC7JC]a>oDkLC_e>
g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`03Woo0`0000=oo`00Ool02Woo000>Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol00goo00<007ooOol05Goo00aF5EHDEQAF54E@>Ua5D44`AE11D4E@0004AE00
0`00AE15D@0300000dkMB]`000020002B]d00d[LJ]IZeP03J]H00`cE4=E6W002A[`01TkmC]a>gDkL
B]e:g09:g@Ebd`803@03C]a>gD[L009>g00>C_e>g4klC_aBoDkLC_e>o4kmC]a>gBYM;UeV]P=V]`09
I[H]fRgI;MY>g4klC]aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol027oo100017oo00<007ooOol02Goo
000COol01000Oomoo`0017oo00<007ooOol00goo00<007ooOol05Goo01EAm5HEDOAood4`Oom1<4EA
@C15DD4`AE51D4EA@C15D@00AE51D4Ea?W`00`000?Y:g4kMB]a>gDJlB]e6_3ZMJ]E^eVZe4?D<eA3E
B[a>gD[LC_e>g4kmC]a>oD[LC]e:g7;CL[=be7;C00d0300=B]a>gDZlC]e>g5;mC]aBoDkLD_e>g5;m
C]a>oD[LC_eR]VJgH[IVef:fAdm3;T[MB[a:g4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@Ioo`<000Qo
o`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03001oogoo009oo`<001Ioo`9F5006EQDnWDD`
Oom5D44`1TE@00A5DDE@0015D0<0000:@Wa2W49lC]e:g4kMB]a>gCIm=Yd5J]H23=D02TkMB]a>g4[L
C]e>g4kMC]a>gCjM1G;C100=00M>g4kmC]a>g4klD_e>g002C_`00e;mC]a>o@02B]d01D[LB]eV]fJg
I[H00dM?14Zl00E>o5;lD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0goo0`0037oo00<007ooOol027oo000?Ool4
0003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol03UHEOom2_D4`Oom1<4E@@C15
DD4`AE51<4EA@E03000084E@AE55D4kMB[a:gDZlC_e:g4kMB]`jWCImK]IZ]FkFJ]E^ePcE4?D<eDkm
B]a>oDkLC_e:g4kmB]a>oG:cL]@2L]<0gg:cA[a2W4Jl@Ya6_4kLC_e>g5;mC]aBoDkLD_e>g5;mC]aB
oD[LB]e:_6KGH[I7Cf:fI]L]fC7JC]a>oDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l008000moo`03
001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
5goo00UF57oo?[e5D7ooAE11<4E@@E000TE@0`0000M5D4EAAE15DDE@AE400002B]`01T[MB[a:g4[L
C]e:g0EZeP033=D004JL0096_006C]e>g4kMC]a>gD[L0d[M1G;C1DJL00=>g4kmC]`00Tkl00MBoDkL
C_e>g4kmC]a>o@02B]d024[L:UeV]fJgI[H]fRgI;MX3C]`01DkMC]aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`@
Ool00`00Oomoo`08Ool000moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo01Uoo`07AE1oogoo@C15DD4`AE400P0000U1D4EA@C0004E@AE55D4EaAE000`0001a:g4kMB]a>
gDJlB]e6_6kFJ]E^eVZeK]H<eDJlAYa:_DJLC_e>g4kmC]a>oD[LC]e:g7;CL[=be09bd`3OL[<03D[L
C]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4km:Ud^GF:fI]MR]VJgH[HanRgI<MY>g5;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`03goo00<007ooOol027oo000?Ool50003Ool40005Ool2000JOol0
144`OomoodE@0`0014E@00i5D@00AE55D4EAAE15DD9l@Ya2O4:LB]a>gD[L0d[M1F[F0PcE00Y>gD[L
C]a:g4kmC]a>gDkLC_e:g09:g@Ebd`803@0@C]a>gD[LC_a>g4kmC]a>oDklD_e>g4kmC]a>oDkLC]d2
I[L016JfI[MV]fJg14Zl00E>g4klC]aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`03goo00<007ooOol0
27oo000POol00`00Oomoo`0IOol0;dE@00000000Oom1<4EA@E15DD4`AE51D4EA@E15DDE@AE55D4Ea
?Wa2W3il@Ya:g4kMB]a:gDJlB]eZ]FkFJ[EZeVZe4?H<eDkMB[a>gD[LC_e:g4kmB]a>oCjM@[d00W;C
0>9b/g;DL]<03@0<C]e:g4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e:g4[MB[a:gF:fI[MR]VKG@bi7CdZl
B]e:_4[LC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@ioo`03001oogoo00Qoo`0087oo00<007oo
Ool05goo0`0000IoocjMAE1oodE@@E06AE002TEAAE15DDE@AE55D4EAB]a:gDZl0T[L00A>gD[L=Ydf
O@EZeP<<e@09C]e>g4kMC]a>gDkLC]e>g3jm00Ibd`<03@9>g00;C_e>g4klC_aBoDkLC_a>g4kmC]a>
o@02B]d024[LI[MV]fJgI[IV]bgI;MX3C]`01TkMC_aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0
3Goo00<007ooOol027oo000OOol00`00Oomoo`0EOol30004Ool0;d:m@C1ood4`AE51<4EA@E15DD4`
AE55D4EAAE15LDE@AG55D000B[a:gDZlC_e:g4kMB]a^eVZeJ]IZ]FkF3=D004JLB[e6W4kmB]a>oDkL
C_e:g4kmB]abdg:cL]@00W;C0>9b/`0=@Ya6_4:LD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4[M
B[aVef:fI[MR]S7j;MTafTkLC_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@eoo`03001o
ogoo00Moo`007goo0P004goo0`001goo00Dn_DE@Oom5D3jm00A5D0060015D4EAAE15DDE@0dEA0P00
00=:g4[MB[`00d[M00=:g6[FJ]H00f[F00<<eDJlAY`00TJl00I>oDkLC]e>g4kmB]`2B]d6L]<0500=
AYa6W4JLC_a>g4kmC]a>oDklD_e>g4kmC]a>oDkLC]dZGBiMI[H3I[L026Jf;MT]fBgJC]a>o4kLD_d3
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00aoo`03001oogoo00Moo`007goo00<007ooOol0
3goo0`002Woo0355DGooOom1<4:m@E15DD4`AE4004EA@E15LDE@AG55D4EaAE12W3il@Ya:g4kMB]a:
gDJlB]e6_6kFJ[EZeVZe4?H<eDkMB[a>gD[LC_e>g4kmC]a>oD[LC]e:g7;CL[=be002L]<200d0gd[L
C]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmH[IV]f:fI]MR]VJgB[a:gDZlB]a>g5;mC]aBoDkL
D_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00aoo`03001oogoo00Moo`007goo00<007ooOol037oo0`00
3Goo00E1<7ooAE15D3jM0095D006AE55D4EAAE15DDE@0dEA00U5D4EA@Wa2W49lC]e:g4kMB]`00d[M
019:g6[FJ]IZePcE4=D<eDkMB]a>g4[LC]e>g4kMC]a>gCjM?[d5L]<200d2C]`02dkMB]a>o4klD_e>
g4kmC_aBoDkLC_d00T[M00I:g4[MI[MV]fJfI[L2@bh4B[`014klD_aBo5;m0e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo003D_eBo7oo00Yoo`03001oogoo00Moo`007goo00<007ooOol02Goo0`0047oo02m5D7ooAE51
<4:m@C15DD5@AE51D4EAAE15DDE@AG55D4EaAE19LCil@Y`nO4kmB]a>gD[L>YhfOCJMJ[E^eVZeJ]H<
eA3f3=E>oD[LC_e>g4kmB]a>oD[L?[eb/g;D009bd`03L[=be00=00803@3PD_e>g4kmC]aBoDkLD_e>
g5;mC]aBoDkLD_e:g4[MB[aVef:fI[MR]VKG;MTafTkLC_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo0Yoo`03001oogoo00Moo`007goo0P0027oo0P004goo00E1<7oo@E15D3jm00A5
D006AE55D4EAAE15DDE@0TEA00]5LDEA001:g4[MB[a>gD[LC]e:g4kM00EZeP0<A[a6W4JlA[a>gDkL
C]e>g4kMC]a>gDkL1g;C0dJL0TkL00]>oDkLC_e>o5;mC]a>oDkLC_e>g4km009:g@05B]aV]fJgI[MV
]P02;MT01C7JC]a>g4kLC]d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol027oo00<0
07ooOol01goo000NOol00`00Oomoo`05Ool3000GOol04DEAOom2_D5@AE51<4EAAE15DDE@AG55D4Ea
AE15LDE@AG400P000?m:_4[MB[a:gDJlB]e6_4[MJ[EZeVZeK]IZ]DJlAYa:_DJLA[a>g4kmC]a>oD[L
C]e:g7;CL[=be7;CL]A^/dJlAYa6_4:LD_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_dZGBiMH[IVef:f
I[MR]S7j;MTafTkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`000=BoE;lD_d02Woo00<0
07ooOol01Woo000NOol00`00Oomoo`02Ool3000JOol00dE@OolnW@02AE001TEA0015DDE@AE55D0E5
D@07@Wa2W49l@Ya:g4kMB]`014[M1F[F00/@eDkMB]a>g4[LC]e>g4kMC]a:gD[L009:g@Ebd`0B00e>
g4kLC]e:g4klC]a>oDkLC_e>o5;mC]a>oDkLC_e>g4kM0VJg00AV]VJgI[MV]`A:_004C]a>o4kLD_d3
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`:Ool00`00Oomoo`06Ool001ioo`03001oo`00008001eo
o`0bAE5ood:m@C15DD5@AE51D4EAAE15DDE@AG55D4EaAE1oocil@Y`nNd:LB]a>gD[LC]e6_4[MA[a^
eVZeJ]IZ]A3f3=E>gDZlC]e:g4kMC]a>oDkL?[dnWD:mL]=be6jcL]Abd`803@0EC]e:g4kMB[aBoDkL
D_e>g5;mC]aBoDkLD_e:g4[MB[a:gF:fI[MR]VKG0080003;B[a:gDZlB]a>g5;mC]aBoDkLD_e>o5;m
C]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo009Ool00`00Oomoo`06Ool001ioo`<001moo`03@E1oodE@00A5
D006AE55D4EAAE15DDE@0TEA00e5LGooOom2O4:L@Wa2W4[LC]e:g4kM=WdfW@05J]H34=D024kLC]e>
g4kMC]a>gDkL?[d6L]<300d2C]`02dkmC]a>o4klD_e>g4klC]a>oDkLC_d00T[M00E:g6JgI[MV]fJf
008]f@06<MY>g4kLC]a>gDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IB
oE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`8Ool0
0`00Oomoo`06Ool001moo`03001oogoo01ioo`0@AE5oodEA@E15DD4`AE55D4EAAE15LDE@AG55D4Ua
AE03Ool0odZlB]e:_4kMB]a>gD[LC_eZ]F[FJ[E^eVZeJ]I6W4ZmAYa6_4[LC_e>g4kmB]a>oD[LL]A^
/g;DL]=be6jcL]A6W4Jl@YaBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LB]e:_6KGH[IV]f:f<OX]
fC7JC]a>oDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0001U;mD_aBoE;lD_eBo0Moo`03001o
ogoo00Ioo`0017oo1@000goo100017oo100027oo0P0087oo0dE@00I5DDE@AE55D4EAAE05AE45Ool0
0d[MB[a:g004B]d5J]H00a3eAYa6_002A[`01DkLC]e>g4kmB]`00T[M1W;C14JL00e>o4kLC_e>g4km
C_aBoDkLC_e>g4kmC]a>g@03:Ud3I[L3;MT01C7JC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lD_`01goo00<007ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol01goo00<007ooOol07Goo00e5DGooAE4004EA@E15LDE@AG55D4Ea
AE15L@07Ool0odkMB]a>gDJlB]e6_6kFJ[EZeVZeK]H<eA3eB[a>gD[LC]e>g4kmC]a>gD[LC]e:g7;D
K[=be7:cL]@03DkMB]a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[L;UdZGFJgH[IVef:fB]a:_4[M
B[a:g4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0015;lD_eBo5;m1Woo00<007oo
Ool01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol027oo
00<007ooOol077oo00M5D7ooAE12_DE@AE55D003AE400dE@AE55D@07Ool014[LC]e:g4kM0d[M16[F
0Q3E00/@mD[LC]a:g4kMC]a>gDkL?[dnWCjm00Ebd`803@9>g00>C]e:g4klC_aBoDkLC_e>o5;mC]a>
oDkLC_e>g0=V]`03I[H0000000E:_004C_aBo5;lD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
0e;mD_aoo`06Ool00`00Oomoo`05Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`09Ool00`00Oomoo`0KOol03DEAOom5DCjMAE55D4EAAE15LDE@AG55D4Ua00Qo
o`3oB]a>gD[LC_dfOCJMJ[E^eVZeJ]IZ]A3f3=D@mD[LC_e>g4kmB]a>oD[L?[e^/g;DL[=be6jcL]@0
3@0>00eBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LB]e:_6KGH[IV]f:f<OX]fDkmC]a>oDkLC_e>
g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0004D_eBo5;mD_`6Ool00`00Oomoo`05Ool0
00Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0:Ool2000KOol3
AE001T:mAE15DDE@AE55D095D@03AG55DGoo00Qoo`04B]a>gD[LC]d6J]H02dJLA[a6_4JlC]a>gDkL
C]e>g4kMC]`01g;C0dJL0TkL00]>oDkLC_e>o5;mC]a>oDkLC_e>g4km009:g@04I[IV]fJgI[L3;MT0
1DkMC]a>g4kLC]d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0
17oo00<007ooOol01Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol037oo00<007ooOol067oo00e5DD4`AE4nWDEA@E15LDE@AG55D4EaAE15L@0:Ool0odJlB]e6
_4[MJ[EZeVZeK]IZ]A3eAYa:_DJLA[a>g4kmC]a>oD[LC]e:g7;DK[=be7:cL]A^/dJlAYa6_4:LD_e>
g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_dZGBiMH[IV]f:fI[L]fC7j;MTafTkLD_e>g5;mC]aBoDkLD_e>
g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00015;mD_aBoE;l17oo00<007ooOol01Goo0004Ool30004
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol03Goo00<007ooOol067oo00I5DGoo@[e5
D4EAAE05AE4<Ool3B]d5J]H02a3E4?E:g4kLB]a>gDkLC]e>g4[MB]`00T[M1G;C01803DkLC]a>gD[L
C_a>g4kmC]a>oDklD_e>g4kmC]a>oDkLC]d2I[L00fJfI[MV]`05B[`014kLC_a>g5;m0e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`02Ool00`00Oomoo`05Ool000Ioo`03001o
ogoo00=oo`@000Aoo`@0015oo`03001oogoo01Moo`0;@E1oocjMAE55D4EAAE15LDE@AG55D00=Ool0
;dJlB]e6_6kFJ[EZeVZeK]H@eA3eB[a>gD[LC]e>g4kmC]`n_CjM@[eb/g;DK[=be7:c00h03DkMB]a>
gDZlD_e>g5;mC]aBoDkLD_e>g5;mB]a:gDZlB]eR]VJgH[H00P000=5:g4ZlB]e:_4[LC]aBoDkLD_e>
g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00=oo`03001oogoo00Eoo`00:Woo
00<007ooOol05Woo00Q5D7oo@[e5D4EAAE15DDE@0TEA00=5LGooOol037oo00<fOCJMJ]H016[F00/@
mA3E4?E>g4kMC]a>gDkLC]e>g3jm00Ibd`0300d03P0=009>g00;C_e>g4klC_aBoDkLC_e>g4kmC]a>
o@03B]d3I[L016Jf;MT]fDkM0dkL00E>gDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l0goo00<007ooOol01Goo000[Ool2000FOol02d4`Oom5D4EAAE15LDE@AG55D4UaAE00
3goo0?mZ]F[FJ[E^eVZe4?H004ZmAYa6_4[LC_e>g4kmB]a>oD[LL]A^/g;DL[=be6jcL]A6W4Jl@YaB
oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LB]e:_6JgH[IV]bgI<OX]fDkmC]a>oDkLC_e>g5;mC]aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00E;m0E;l0goo00<007ooOol017oo000]
Ool00`00Oomoo`0COol01TEAOom5DDE@AE55D0E5DA1oo`AZeP03Ool@mDJL00=6_005C]a>gDkLC_e:
g002B]d6L]<04@0>AYa6W4JLC_a>g4kmC]a>oDklD_e>g4kmC]a>oDkLC]d00RYM00AV]VJgI[MV]`<]
f@05D_e>g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0Woo
00<007ooOol017oo000^Ool00`00Oomoo`0DOol0245@Oom5D4:mAE15LDE@AG4BOol0ofZeJ]Ioogoo
4=D@mTZlC]e:g4kMC]a>oDkLC_e:g4kMB]a>gFjcL]Ab/g;D00d03T[LC]e:_5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e:g4kmH[IV]f:fI[MR]T[LB[a:gDZlD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo00015;mD_aoo`001Woo000_Ool00`00Oomoo`0COol01TEAOom5
DCjmAE55D095DAMoo`0<4=D@mD[LC]a:g4kMC]a>gDkLC]dnWCjm1G;C00H03P0=C]a>g4kMB]`2C_`0
1e;mC]a>oDklD_e>g4km00A:g@9V]`03I[H0000000A:_005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00=oo`00Ool01Goo000`Ool2000COol024E@Oom5
D4:mAE15LDE@BG4GOol0oQ3f4=D@mT[LC_e>g4kmB]a>oD[LC_e:g7;DL[=be6jcL]@03@0>00eBoDkL
C_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LB]e:_6JgH[IV]f:f<OX]fDkmC]a>oDkLD_e>g5;mC]aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0006Ool0039oo`03001oogoo
011oo`04AE55D4EA?Yd2AE400dEaAE5oo`0GOol3A[`01DkLC]e>g4kMB]`00d[M00=:g7;CL]<00g;C
14JL00a>g4kmC]a>oDklD_e>g4kmC]a>oDkLC_d3B]d3I[L012gI<MT]fDkM0dkL00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00=oo`03001oogoo00Aoo`00<goo00<0
07ooOol03goo00Q1D4EaAE12_DE@AG55D4Ea67oo0296W4ZmAYa6_4kLC_e>g4kmB]a>gD[LC]e^/g;D
K[=be6jc00i:g4kMB[a>gDkLD_e>g5;mC]aBoDkLC_e>g4kmB]a>o@8ZG@3AH[IV]f:fI[L]fC7j;MUB
oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo008Ool00`00Oomoo`03Ool0
03Aoo`03001oogoo00moo`03AE1oocjm00=5DAYoo`09B]a>g4[LC]e>g4kMC]a>oD[L00=:g@Abd`05
00d03TkLC]e:g002C]`02dkmC]a>oDklD_e>g4kMC]a>oDkLC]d00VJg00AR]VJg000000=:_005D_e>
g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@0<Ool00`00Oomoo`03Ool003Eoo`8000moo`06
AE5ood:mAE15LDE@6goo0>a:_4kMB]a>gD[LC_e:g4km?Ye2_FjcL]A^/g;DK[<03P0=00i>g4kmC]aB
oDkLD_e>g5;mC]aBoDkLB]e:g4[MB[a:gF:fI[MR]VJg001:g4ZlB]e:_5;mC]aBoDkLD_e>g5;mC_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001B
oE;lD_eBo5;m3goo00<007ooOol00goo000gOol00`00Oomoo`0<Ool00dE@OolnW@02AE400dEaOomo
o`0JOol02DkLC]e>g4kMC]a>gDkLC]e>g005L]<4AY`02dkLC_e>g4kLC_aBoDkLC_e>g4kmC]`014[M
0fJg00AR]S7I;MU>g@=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_`001=oo`03001oogoo00=oo`00>7oo00<007oo
Ool02goo00I5LGooAG55D4UaAE0MOol0hd[LC_e>g4kmB]a>gD[LC]e:g7;DK[=be6jcL]A6W4Jl@Ya6
_4kLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gD[LB]e:_6JgH[IV]f:f<OX]fDkmC]a>oDkLD_e>g5;mC]aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
0goo00<007ooOol047oo00<007ooOol00goo000iOol00`00Oomoo`0:Ool00dE@Oom5D@03AE4NOol0
1DkLC]e>g4kmB]`00d[M0g;C00Ibe7;C00i>g4kMB]`2C]`02TkmC]a>o4klD_e>g4kmC]a>oDkL0RYM
00=V]f:fI[L00VJg00P]fC7I;MUBoDkLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo0Qoo`03001oogoo00moo`03001oogoo00=oo`00>Woo0P00
37oo00=5LGooAG4087oo029>g4kmC]a>oDkLC]e:g4kMK[=be6jcL]@03@0>B]a>gDZlC]e>g5;mC]aB
oDkLD_e>g5;mC]a>oD[LI[MR]VJgH[IV]`80002fB[a:gDZlD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@]oo`03001oogoo00moo`03001oogoo00=o
o`00?7oo00<007ooOol02Goo00=5D7ooAE408Goo00Q>g4kMC]a>gDkL?[ebdg;D0g;C0`0>00a>g4km
C]a>g4klD_e>g4klC]a>oDkLC_d3B]d3I[L016:fI[L]fC7J0dZl00EBoDklD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`@Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool003eo
o`03001oogoo00Qoo`03AG5oodUa02Aoo`3?B]a>oD[LL]A^/g;DK[=be6jcA[a2W4JlC]a>oDkLD_e>
g5;mC]aBoDkLD_e>g5;mB]a:gF:fI[MR]VJgH[HanRgI<OY>g4kmC]a>oDkLD_e>g5;mC]aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo00ioo`03001oogoo009oo`00?Woo00<007oo
Ool01goo00=5DDEaAE409Goo0T[M00A:g7;CL]=be09bd`0700i6W4JLAYa>g4kmC]`00Tkl00MBoDkL
C_e>g4kmC]a>g@02:Ud036:fI[MV]fJgH[HafBgI<MY>g4klC]aBo@=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00=BoGooOol05goo00<007ooOol03Goo00<007ooOol00Woo000oOol00`00Oomoo`06Ool00dEa
AE15L@0VOol01d[LC]e:g7;DK[=be6jc00803P2mC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4km
H[IV]f:fI[MR]VJgB[a:gDZlB]a>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01aoo`03001oogoo
00eoo`03001oogoo009oo`00@7oo0P001goo00=5DGooOol09Woo00<nWG;DL]<00W;C00Ybe00>00h0
3TkMB]a>g4klD_e>g09>o003D_e>g4km00A:g@9V]`04H[IV]`000004B[`014klD_aBo5;m0e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eoogoo01ioo`03001oogoo00aoo`03001oogoo009oo`00@Woo00<007ooOol017oo00=5D7oo
Ool09goo0;e^/g;DK[=be6jcA[a2W4JlAYa>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a:gDZlI[MR]VJg
H[HanRgIC_e>g4kmC]a>oDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`09Goo00<007ooOol02goo00<007ooOol00Woo0013Ool0
0`00Oomoo`03Ool00dEaOomoo`0XOol00g;CL]Abd`02Ool4AY`02dkmC]a>g4klD_e>g4kmC]a>oDkL
C_d00d[M0fJg00@]fC7I<MU>g@=>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`XOol00`00Oomoo`0;Ool00`00Oomoo`02Ool004Aoo`03
001oogoo009oo`03AE1oogoo02Qoo`03L]A^/goo009oo`0@00i>gDZlC]e:g5;mC]aBoDkLD_e>g5;m
C]a>oD[LC_d2:Ud0WV:fI[MR]VJg;MTanRgID_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d]Ool00`00Oomoo`0;Ool00`00Oomoo`01Ool004Eo
o`80009oo`03AE5oogoo02eoo`803P06C]e:g4kLC]aBoDkL0Tkl00MBoDkLC_e>o4kmC]a>g@02I[L0
16:fI[L000000dZl00EBoDkLC_a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoE;lD_`0<Goo00<007ooOol02Woo00<007ooOol00Goo0017Ool00`00Oomoo`0_Ool0ZP0=00h0
3TkmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MB[a:gF:fI[MR]VJg;MTanTZlB]e:_5;mC]aBoDkLD_e>
g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_deOol00`00Oomoo`09Ool00`00Oomoo`01
Ool004Qoo`03001oogoo02moo`=6W00<C_e>g4kLC]aBoDkLC_e>o4kmC]a>oDkL0T[M0fJg00AR]S7I
<MTafP=>g005C]e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0>7oo00<007ooOol0
2Goo00<007ooOol00Goo0019Ool00`00Oomoo`0_Ool0XD:LA[a6W5;mC]aBoDkLD_e>g5;mC]a>oD[L
C_e>g2YM:SaV]f:fI[MRUS7j;MTanTkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0?Goo
00<007ooOol027oo00<007ooOol00Goo001:Ool2000`Ool054[LC]a>g4kmC]a>o4kLD_e>g4kmC_a>
oDkLC]e>g6JgH[IV]fJfI[L4B[`014kLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_a1Ool00`00Oomoo`07
Ool00`00Oomoo`01Ool004aoo`03001oogoo02ioo`0BB[a>gD[LD_e>g5;mC]aBoDkLD_e>g4[MB[a:
gD[LI[MRUVJg0P0008A:_4[MB[a:g4kLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_e6Ool00`00Oomoo`06Ool00`00Oomo
o`01Ool004eoo`03001oogoo02ioo`=>g008C_e>g4klC_a>oDkLC_e>g0=:g@06I[IV]f:fI[LafC7J
0dkL00E>gDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m04Uoo`03001oogoo00Moo`40005oo`5oo`00CWoo00<007ooOol0;Woo091>
g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e:_4[M:UeV]f:F<OX]fC7jC]a>oDkLC_e>g5;mC]aBoDkLD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_e=Ool00`00Oomoo`06
Ool10001Ool1Ool004moo`8002moo`0;C]a>o4kLC_e>g4kmC_aBoDkLC]e>g002:Ud016JgI[IV]f:f
0S7I00DafTkLC_a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;lDWoo00<007ooOol01Goo0@000Goo0Goo001AOol00`00Oomoo`0]Ool03dkLD_e>g5;mC]aBoDkL
D_e:g4kmC]aV]f:FI[MR]P020000MT[MB[a:g4ZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lEGoo00<007ooOol01Goo0@000Goo0Goo001BOol00`00Oomoo`0]Ool0
24kLC_a>o5;mC]a>oDkLC_d3B]d01VJgH[IV]fJf<MX]f@9>g006C]e>g5;lD_aBoDkl0U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo5Uoo`03001oogoo00Aoo`40005oo`5oo`00Dgoo00<007ooOol0
;Goo07m>g5;mC]aBoDkLD_e>g5;mB[a:gF:fI[MRUVJg;MTanRgIC_e>g4kmC]aBoDkLD_e>g5;mD_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo01MOol00`00Oomoo`03Ool10001Ool1Ool005Aoo`03001oogoo02eo
o`0EC]a>oDklD_e>g4kMC]a>oBYMI[MV]VJgH[IV]c7I<MX]fDklC]aBoDkL009Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo5;l069oo`03001oogoo00=oo`40005oo`00EGoo0P00;Woo00a>g5;mC]aBoD[LC_e>g6Jg
HYIV]f:fI[L20000IDZlB]a:_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0J7oo00<007ooOol00goo0@000Goo001G
Ool00`00Oomoo`0/Ool00dkLC_e>o004B]d01VJgH[IV]f:f<MXaf@=:_004C_aBo5;lD_d3D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo6aoo`03001o
ogoo009oo`40005oo`00F7oo00<007ooOol0;7oo06Y>g5;mC]aBoDZlB]eR]VJgHYIV]bgI<OX]fDkm
C]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoG5oo`05001oogooOol00001Ool005Uoo`03001oogoo02aoo`04C]a>gDkLC_d2:Ud02f:fI[MR
]VJg<MTafS7IC_a>g5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo5;l07Eoo`04001oogoo0001Ool005Yoo`8002eoo`1RB]a>oDkLC_eRUVJgH[IV]f:FB]e:
_4[LB[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoGQoo`04
001oogoo0001Ool005aoo`03001oogoo02]oo`A:g@05H[IV]f:fI[L00004B[`2D_`01E;mC_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lO7oo00<007oo00000Goo001MOol00`00Oomoo`0[
Ool0FTZlB]e:g6JgHYIV]f:f<OX]fDkmC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoH1oo`40005oo`400000GWoo00<007ooOol0:goo0d[M00EV]f:fI[MR]S7j008af@03C]a>gDkL
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo8Aoo`800000Ggoo0P00;7oo054V?2YMH[IV]f:FI[M:
_4[LB[a:gDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0R7oo0P00001QOol00`00Oomoo`0ZOol016:fI[MR
]VJg0P0014Zl00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;lRgoo0P00001ROol00`00Oomoo`0ZOol0AV:FI[Moogoo
;MTanTkLC_e>g4kmC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mSGoo10000Woo001SOol00`00Oomoo`0]Ool01C7j<MTafC7IC]d00TkL00=Bo5;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0S7oo10001Woo
001TOol2000^Ool0>d[LB[a:gDZlD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d0Rgoo10002Woo001VOol00`00Oomoo`0/Ool3B[`00e;lD_e>o002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b:Ool4000>Ool006Moo`03001oogoo02]oo`0dC]a>
oDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_f:Ool3000BOol006Qoo`03001o
ogoo02]oo`06C]a>gDkLC]aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b9Ool4000EOol006Uoo`80
02aoo`0/C]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoHQoo`@001Uoo`00Jgoo00<007ooOol0:goo
00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_b:Ool4000MOol006aoo`03001oogoo02]oo`0PD_e>g5;mC]aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo8Uoo`@0025oo`00KGoo
00<007ooOol0:goo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00ABoE;lD_aBo8Uoo`<002Eoo`00KWoo00<007ooOol0;7oo01M>g5;mC]aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l08Qoo`@002Qoo`00Kgoo0P00;Goo0e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_b7Ool4000/Ool0075oo`03001oogoo02Yoo`0@D_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_b6Ool4000`Ool0079oo`03001oogoo02Yoo`05D_eBo5;lD_aBo@03
D_`015;mD_aBo5;lQGoo1000=7oo001cOol00`00Oomoo`0ZOol01E;mC]aBoE;lD_d0Qgoo1000>7oo
001dOol2000/Ool00`00Oomoo`24Ool3000lOol007Ioo`03001oogoo02Uoo`03001oogoo081oo`@0
03moo`00Mgoo00<007ooOol0:7oo00<007ooOol0O7oo1000@goo001hOol00`00Oomoo`0WOol00`00
Oomoo`1hOol40017Ool007Uoo`8002Moo`03001oogoo07Aoo`@004]oo`00Ngoo00<007ooOol097oo
00<007ooOol0LGoo0`00Cgoo001lOol00`00Oomoo`0SOol00`00Oomoo`1]Ool4001BOol007eoo`03
001oogoo029oo`03001oogoo06Uoo`@005Ioo`00OWoo0P008Woo00<007ooOol0IGoo1000FWoo0020
Ool00`00Oomoo`0OOol00`00Oomoo`1QOol4001NOol0085oo`03001oogoo01ioo`03001oogoo05io
o`<0069oo`00PWoo00<007ooOol07Goo00<007ooOol0FWoo1000IGoo0023Ool00`00Oomoo`0LOol0
0`00Oomoo`1FOol4001YOol008Aoo`8001aoo`03001oogoo059oo`@006eoo`00QWoo00<007ooOol0
6Goo00<007ooOol0CWoo1000LGoo0027Ool00`00Oomoo`0HOol00`00Oomoo`1;Ool3001eOol008Qo
o`03001oogoo01Moo`03001oogoo04Moo`@007Qoo`00RGoo0P005goo00<007ooOol0@goo1000O7oo
002;Ool00`00Oomoo`0DOol00`00Oomoo`0oOol40020Ool008aoo`03001oogoo019oo`03001oogoo
03aoo`@008Aoo`00SGoo00<007ooOol04Goo00<007ooOol0>Goo0`00R7oo002>Ool2000AOol00`00
Oomoo`0eOol4002;Ool0091oo`03001oogoo00ioo`03001oogoo035oo`@008moo`00TGoo00<007oo
Ool03Goo00<007ooOol0;Goo1000Tgoo002BOol00`00Oomoo`0<Ool00`00Oomoo`0YOol4002GOol0
09=oo`8000aoo`03001oogoo02Eoo`@009]oo`00UGoo00<007ooOol02Goo00<007ooOol08Woo0`00
Wgoo002FOol00`00Oomoo`08Ool00`00Oomoo`0NOol4002ROol009Moo`03001oogoo00Moo`03001o
ogoo01Yoo`@00:Ioo`00V7oo00<007ooOol01Woo00<007ooOol05Woo1000ZWoo002IOol20006Ool0
0`00Oomoo`0BOol4002^Ool009]oo`03001oogoo00=oo`03001oogoo00moo`<00;9oo`00W7oo00<0
07ooOol00Woo00<007ooOol02goo1000]Goo002MOol01@00Oomoogoo00002Goo1000^Goo002NOol2
00000goo001oo`04Ool4002mOol00:1oo`800003Ool0000000800<5oo`00XGoo0P00aGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.0882282, 0.0218253, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.651 .747 .92 r
.39637 .69709 .40169 .70181 .41061 .69936 .4053 .69467 Mtetra
.654 .75 .92 r
.4053 .69467 .41061 .69936 .41956 .69684 .41427 .69216 Mtetra
.657 .752 .92 r
.41427 .69216 .41956 .69684 .42855 .69427 .42327 .6896 Mtetra
.658 .753 .92 r
.42327 .6896 .42855 .69427 .43756 .69167 .43231 .68699 Mtetra
.659 .753 .92 r
.43231 .68699 .43756 .69167 .4466 .68904 .44137 .68435 Mtetra
.659 .754 .92 r
.44137 .68435 .4466 .68904 .45568 .68641 .45046 .6817 Mtetra
.45046 .6817 .45568 .68641 .46478 .68377 .45958 .67904 Mtetra
.45958 .67904 .46478 .68377 .47391 .68113 .46874 .67638 Mtetra
.658 .753 .92 r
.46874 .67638 .47391 .68113 .48308 .67848 .47792 .67372 Mtetra
.47792 .67372 .48308 .67848 .49227 .67583 .48714 .67105 Mtetra
.48714 .67105 .49227 .67583 .5015 .67318 .49638 .66838 Mtetra
.49638 .66838 .5015 .67318 .51075 .67052 .50566 .6657 Mtetra
.50566 .6657 .51075 .67052 .52004 .66786 .51496 .66302 Mtetra
.51496 .66302 .52004 .66786 .52936 .66519 .5243 .66033 Mtetra
.5243 .66033 .52936 .66519 .5387 .66251 .53367 .65764 Mtetra
.657 .753 .92 r
.53367 .65764 .5387 .66251 .54809 .65983 .54307 .65494 Mtetra
.54307 .65494 .54809 .65983 .5575 .65713 .55251 .65223 Mtetra
.657 .752 .92 r
.55251 .65223 .5575 .65713 .56694 .65443 .56197 .64951 Mtetra
.56197 .64951 .56694 .65443 .57642 .65173 .57147 .64678 Mtetra
.57147 .64678 .57642 .65173 .58593 .64901 .581 .64405 Mtetra
.581 .64405 .58593 .64901 .59547 .64628 .59057 .64131 Mtetra
.59057 .64131 .59547 .64628 .60505 .64355 .60016 .63855 Mtetra
.60016 .63855 .60505 .64355 .61465 .64081 .60979 .63579 Mtetra
.60979 .63579 .61465 .64081 .62429 .63806 .61946 .63303 Mtetra
.61946 .63303 .62429 .63806 .63397 .6353 .62915 .63025 Mtetra
.62915 .63025 .63397 .6353 .64367 .63253 .63888 .62746 Mtetra
.63888 .62746 .64367 .63253 .65341 .62975 .64864 .62467 Mtetra
.64864 .62467 .65341 .62975 .66319 .62697 .65844 .62186 Mtetra
.65844 .62186 .66319 .62697 .67299 .62417 .66827 .61905 Mtetra
.66827 .61905 .67299 .62417 .68283 .62137 .67814 .61623 Mtetra
.67814 .61623 .68283 .62137 .69271 .61855 .68804 .6134 Mtetra
.68804 .6134 .69271 .61855 .70262 .61573 .69797 .61055 Mtetra
.69797 .61055 .70262 .61573 .71257 .6129 .70794 .6077 Mtetra
.70794 .6077 .71257 .6129 .72255 .61005 .71794 .60484 Mtetra
.71794 .60484 .72255 .61005 .73256 .6072 .72798 .60197 Mtetra
.72798 .60197 .73256 .6072 .74261 .60434 .73806 .59909 Mtetra
.73806 .59909 .74261 .60434 .75269 .60147 .74817 .5962 Mtetra
.74817 .5962 .75269 .60147 .76282 .59859 .75831 .5933 Mtetra
.75831 .5933 .76282 .59859 .77297 .5957 .76849 .59039 Mtetra
.76849 .59039 .77297 .5957 .78316 .5928 .77871 .58747 Mtetra
.77871 .58747 .78316 .5928 .79339 .58989 .78897 .58454 Mtetra
.78897 .58454 .79339 .58989 .80366 .58697 .79926 .5816 Mtetra
.79926 .5816 .80366 .58697 .81396 .58404 .80958 .57865 Mtetra
.80958 .57865 .81396 .58404 .8243 .5811 .81995 .57569 Mtetra
.81995 .57569 .8243 .5811 .83467 .57815 .83035 .57272 Mtetra
.83035 .57272 .83467 .57815 .84508 .57519 .84079 .56974 Mtetra
.84079 .56974 .84508 .57519 .85553 .57221 .85126 .56675 Mtetra
.85126 .56675 .85553 .57221 .86602 .56923 .86178 .56375 Mtetra
.86178 .56375 .86602 .56923 .87654 .56624 .87233 .56074 Mtetra
.87233 .56074 .87654 .56624 .8871 .56324 .88292 .55772 Mtetra
.88292 .55772 .8871 .56324 .8977 .56022 .89355 .55468 Mtetra
.89355 .55468 .8977 .56022 .90834 .5572 .90421 .55164 Mtetra
.90421 .55164 .90834 .5572 .91902 .55416 .91492 .54858 Mtetra
.91492 .54858 .91902 .55416 .92974 .55112 .92566 .54552 Mtetra
.92566 .54552 .92974 .55112 .94049 .54806 .93645 .54244 Mtetra
.93645 .54244 .94049 .54806 .95128 .545 .94727 .53935 Mtetra
.94727 .53935 .95128 .545 .96212 .54192 .95813 .53625 Mtetra
.95813 .53625 .96212 .54192 .97299 .53883 .96904 .53314 Mtetra
.96904 .53314 .97299 .53883 .9839 .53573 .97998 .53002 Mtetra
.648 .745 .92 r
.39101 .6923 .39637 .69709 .4053 .69467 .39996 .68993 Mtetra
.653 .749 .92 r
.39996 .68993 .4053 .69467 .41427 .69216 .40895 .68744 Mtetra
.656 .751 .92 r
.40895 .68744 .41427 .69216 .42327 .6896 .41797 .68488 Mtetra
.657 .752 .92 r
.41797 .68488 .42327 .6896 .43231 .68699 .42702 .68227 Mtetra
.658 .753 .92 r
.42702 .68227 .43231 .68699 .44137 .68435 .4361 .67963 Mtetra
.659 .754 .92 r
.4361 .67963 .44137 .68435 .45046 .6817 .44521 .67697 Mtetra
.44521 .67697 .45046 .6817 .45958 .67904 .45436 .67429 Mtetra
.45436 .67429 .45958 .67904 .46874 .67638 .46353 .67161 Mtetra
.659 .753 .92 r
.46353 .67161 .46874 .67638 .47792 .67372 .47273 .66893 Mtetra
.658 .753 .92 r
.47273 .66893 .47792 .67372 .48714 .67105 .48197 .66624 Mtetra
.48197 .66624 .48714 .67105 .49638 .66838 .49123 .66355 Mtetra
.49123 .66355 .49638 .66838 .50566 .6657 .50053 .66086 Mtetra
.50053 .66086 .50566 .6657 .51496 .66302 .50986 .65816 Mtetra
.50986 .65816 .51496 .66302 .5243 .66033 .51922 .65545 Mtetra
.51922 .65545 .5243 .66033 .53367 .65764 .52861 .65274 Mtetra
.657 .753 .92 r
.52861 .65274 .53367 .65764 .54307 .65494 .53803 .65002 Mtetra
.53803 .65002 .54307 .65494 .55251 .65223 .54749 .64729 Mtetra
.54749 .64729 .55251 .65223 .56197 .64951 .55697 .64455 Mtetra
.657 .752 .92 r
.55697 .64455 .56197 .64951 .57147 .64678 .56649 .64181 Mtetra
.56649 .64181 .57147 .64678 .581 .64405 .57605 .63906 Mtetra
.57605 .63906 .581 .64405 .59057 .64131 .58563 .6363 Mtetra
.58563 .6363 .59057 .64131 .60016 .63855 .59525 .63353 Mtetra
.59525 .63353 .60016 .63855 .60979 .63579 .6049 .63075 Mtetra
.6049 .63075 .60979 .63579 .61946 .63303 .61459 .62796 Mtetra
.61459 .62796 .61946 .63303 .62915 .63025 .62431 .62517 Mtetra
.62431 .62517 .62915 .63025 .63888 .62746 .63406 .62236 Mtetra
.63406 .62236 .63888 .62746 .64864 .62467 .64384 .61955 Mtetra
.64384 .61955 .64864 .62467 .65844 .62186 .65366 .61673 Mtetra
.65366 .61673 .65844 .62186 .66827 .61905 .66352 .6139 Mtetra
.66352 .6139 .66827 .61905 .67814 .61623 .67341 .61106 Mtetra
.67341 .61106 .67814 .61623 .68804 .6134 .68333 .6082 Mtetra
.68333 .6082 .68804 .6134 .69797 .61055 .69329 .60534 Mtetra
.69329 .60534 .69797 .61055 .70794 .6077 .70328 .60247 Mtetra
.70328 .60247 .70794 .6077 .71794 .60484 .71331 .5996 Mtetra
.71331 .5996 .71794 .60484 .72798 .60197 .72338 .59671 Mtetra
.72338 .59671 .72798 .60197 .73806 .59909 .73347 .59381 Mtetra
.73347 .59381 .73806 .59909 .74817 .5962 .74361 .5909 Mtetra
.74361 .5909 .74817 .5962 .75831 .5933 .75378 .58798 Mtetra
.75378 .58798 .75831 .5933 .76849 .59039 .76399 .58505 Mtetra
.76399 .58505 .76849 .59039 .77871 .58747 .77423 .58211 Mtetra
.77423 .58211 .77871 .58747 .78897 .58454 .78451 .57916 Mtetra
.78451 .57916 .78897 .58454 .79926 .5816 .79483 .5762 Mtetra
.79483 .5762 .79926 .5816 .80958 .57865 .80518 .57324 Mtetra
.80518 .57324 .80958 .57865 .81995 .57569 .81557 .57026 Mtetra
.81557 .57026 .81995 .57569 .83035 .57272 .826 .56727 Mtetra
.826 .56727 .83035 .57272 .84079 .56974 .83647 .56426 Mtetra
.83647 .56426 .84079 .56974 .85126 .56675 .84697 .56125 Mtetra
.84697 .56125 .85126 .56675 .86178 .56375 .85751 .55823 Mtetra
.85751 .55823 .86178 .56375 .87233 .56074 .86809 .5552 Mtetra
.86809 .5552 .87233 .56074 .88292 .55772 .87871 .55216 Mtetra
.87871 .55216 .88292 .55772 .89355 .55468 .88936 .5491 Mtetra
.88936 .5491 .89355 .55468 .90421 .55164 .90006 .54604 Mtetra
.90006 .54604 .90421 .55164 .91492 .54858 .91079 .54296 Mtetra
.91079 .54296 .91492 .54858 .92566 .54552 .92157 .53987 Mtetra
.92157 .53987 .92566 .54552 .93645 .54244 .93238 .53678 Mtetra
.93238 .53678 .93645 .54244 .94727 .53935 .94323 .53367 Mtetra
.94323 .53367 .94727 .53935 .95813 .53625 .95412 .53055 Mtetra
.95412 .53055 .95813 .53625 .96904 .53314 .96506 .52741 Mtetra
.96506 .52741 .96904 .53314 .97998 .53002 .97603 .52427 Mtetra
.644 .742 .92 r
.38562 .68743 .39101 .6923 .39996 .68993 .39459 .68514 Mtetra
.651 .747 .92 r
.39459 .68514 .39996 .68993 .40895 .68744 .40359 .68268 Mtetra
.654 .75 .92 r
.40359 .68268 .40895 .68744 .41797 .68488 .41263 .68013 Mtetra
.657 .752 .92 r
.41263 .68013 .41797 .68488 .42702 .68227 .4217 .67753 Mtetra
.658 .753 .92 r
.4217 .67753 .42702 .68227 .4361 .67963 .4308 .67488 Mtetra
.659 .753 .92 r
.4308 .67488 .4361 .67963 .44521 .67697 .43993 .6722 Mtetra
.659 .754 .92 r
.43993 .6722 .44521 .67697 .45436 .67429 .4491 .66951 Mtetra
.4491 .66951 .45436 .67429 .46353 .67161 .45829 .66681 Mtetra
.45829 .66681 .46353 .67161 .47273 .66893 .46751 .66411 Mtetra
.658 .753 .92 r
.46751 .66411 .47273 .66893 .48197 .66624 .47677 .6614 Mtetra
.47677 .6614 .48197 .66624 .49123 .66355 .48605 .65869 Mtetra
.48605 .65869 .49123 .66355 .50053 .66086 .49537 .65598 Mtetra
.49537 .65598 .50053 .66086 .50986 .65816 .50472 .65326 Mtetra
.50472 .65326 .50986 .65816 .51922 .65545 .5141 .65054 Mtetra
.5141 .65054 .51922 .65545 .52861 .65274 .52351 .6478 Mtetra
.52351 .6478 .52861 .65274 .53803 .65002 .53296 .64507 Mtetra
.657 .753 .92 r
.53296 .64507 .53803 .65002 .54749 .64729 .54243 .64232 Mtetra
.54243 .64232 .54749 .64729 .55697 .64455 .55194 .63957 Mtetra
.657 .752 .92 r
.55194 .63957 .55697 .64455 .56649 .64181 .56148 .6368 Mtetra
.56148 .6368 .56649 .64181 .57605 .63906 .57106 .63403 Mtetra
.57106 .63403 .57605 .63906 .58563 .6363 .58067 .63126 Mtetra
.58067 .63126 .58563 .6363 .59525 .63353 .59031 .62847 Mtetra
.59031 .62847 .59525 .63353 .6049 .63075 .59998 .62567 Mtetra
.59998 .62567 .6049 .63075 .61459 .62796 .60969 .62287 Mtetra
.60969 .62287 .61459 .62796 .62431 .62517 .61943 .62005 Mtetra
.61943 .62005 .62431 .62517 .63406 .62236 .62921 .61723 Mtetra
.62921 .61723 .63406 .62236 .64384 .61955 .63901 .6144 Mtetra
.63901 .6144 .64384 .61955 .65366 .61673 .64886 .61156 Mtetra
.64886 .61156 .65366 .61673 .66352 .6139 .65874 .60871 Mtetra
.65874 .60871 .66352 .6139 .67341 .61106 .66865 .60585 Mtetra
.66865 .60585 .67341 .61106 .68333 .6082 .6786 .60298 Mtetra
.6786 .60298 .68333 .6082 .69329 .60534 .68858 .6001 Mtetra
.68858 .6001 .69329 .60534 .70328 .60247 .6986 .59721 Mtetra
.6986 .59721 .70328 .60247 .71331 .5996 .70865 .59431 Mtetra
.70865 .59431 .71331 .5996 .72338 .59671 .71874 .59141 Mtetra
.71874 .59141 .72338 .59671 .73347 .59381 .72886 .58849 Mtetra
.72886 .58849 .73347 .59381 .74361 .5909 .73902 .58556 Mtetra
.73902 .58556 .74361 .5909 .75378 .58798 .74922 .58262 Mtetra
.74922 .58262 .75378 .58798 .76399 .58505 .75945 .57967 Mtetra
.75945 .57967 .76399 .58505 .77423 .58211 .76972 .57672 Mtetra
.76972 .57672 .77423 .58211 .78451 .57916 .78003 .57375 Mtetra
.78003 .57375 .78451 .57916 .79483 .5762 .79037 .57077 Mtetra
.79037 .57077 .79483 .5762 .80518 .57324 .80075 .56778 Mtetra
.80075 .56778 .80518 .57324 .81557 .57026 .81117 .56478 Mtetra
.81117 .56478 .81557 .57026 .826 .56727 .82162 .56177 Mtetra
.82162 .56177 .826 .56727 .83647 .56426 .83212 .55875 Mtetra
.83212 .55875 .83647 .56426 .84697 .56125 .84265 .55572 Mtetra
.84265 .55572 .84697 .56125 .85751 .55823 .85321 .55268 Mtetra
.85321 .55268 .85751 .55823 .86809 .5552 .86382 .54962 Mtetra
.86382 .54962 .86809 .5552 .87871 .55216 .87447 .54656 Mtetra
.87447 .54656 .87871 .55216 .88936 .5491 .88515 .54348 Mtetra
.88515 .54348 .88936 .5491 .90006 .54604 .89588 .5404 Mtetra
.89588 .5404 .90006 .54604 .91079 .54296 .90664 .5373 Mtetra
.90664 .5373 .91079 .54296 .92157 .53987 .91744 .53419 Mtetra
.91744 .53419 .92157 .53987 .93238 .53678 .92828 .53107 Mtetra
.92828 .53107 .93238 .53678 .94323 .53367 .93916 .52794 Mtetra
.93916 .52794 .94323 .53367 .95412 .53055 .95009 .5248 Mtetra
.95009 .5248 .95412 .53055 .96506 .52741 .96105 .52165 Mtetra
.96105 .52165 .96506 .52741 .97603 .52427 .97205 .51849 Mtetra
.637 .736 .92 r
.38021 .68242 .38562 .68743 .39459 .68514 .38918 .68028 Mtetra
.648 .745 .92 r
.38918 .68028 .39459 .68514 .40359 .68268 .3982 .67787 Mtetra
.653 .749 .92 r
.3982 .67787 .40359 .68268 .41263 .68013 .40726 .67534 Mtetra
.656 .751 .92 r
.40726 .67534 .41263 .68013 .4217 .67753 .41635 .67274 Mtetra
.657 .752 .92 r
.41635 .67274 .4217 .67753 .4308 .67488 .42547 .67009 Mtetra
.658 .753 .92 r
.42547 .67009 .4308 .67488 .43993 .6722 .43462 .6674 Mtetra
.659 .754 .92 r
.43462 .6674 .43993 .6722 .4491 .66951 .4438 .6647 Mtetra
.4438 .6647 .4491 .66951 .45829 .66681 .45301 .66198 Mtetra
.45301 .66198 .45829 .66681 .46751 .66411 .46226 .65926 Mtetra
.659 .753 .92 r
.46226 .65926 .46751 .66411 .47677 .6614 .47153 .65653 Mtetra
.658 .753 .92 r
.47153 .65653 .47677 .6614 .48605 .65869 .48084 .6538 Mtetra
.48084 .6538 .48605 .65869 .49537 .65598 .49018 .65107 Mtetra
.49018 .65107 .49537 .65598 .50472 .65326 .49955 .64833 Mtetra
.49955 .64833 .50472 .65326 .5141 .65054 .50895 .64559 Mtetra
.50895 .64559 .5141 .65054 .52351 .6478 .51838 .64284 Mtetra
.51838 .64284 .52351 .6478 .53296 .64507 .52785 .64008 Mtetra
.657 .753 .92 r
.52785 .64008 .53296 .64507 .54243 .64232 .53735 .63732 Mtetra
.53735 .63732 .54243 .64232 .55194 .63957 .54688 .63455 Mtetra
.54688 .63455 .55194 .63957 .56148 .6368 .55644 .63177 Mtetra
.657 .752 .92 r
.55644 .63177 .56148 .6368 .57106 .63403 .56604 .62898 Mtetra
.56604 .62898 .57106 .63403 .58067 .63126 .57567 .62618 Mtetra
.57567 .62618 .58067 .63126 .59031 .62847 .58533 .62338 Mtetra
.58533 .62338 .59031 .62847 .59998 .62567 .59503 .62056 Mtetra
.59503 .62056 .59998 .62567 .60969 .62287 .60476 .61774 Mtetra
.60476 .61774 .60969 .62287 .61943 .62005 .61452 .61491 Mtetra
.61452 .61491 .61943 .62005 .62921 .61723 .62432 .61207 Mtetra
.62432 .61207 .62921 .61723 .63901 .6144 .63415 .60922 Mtetra
.63415 .60922 .63901 .6144 .64886 .61156 .64402 .60636 Mtetra
.64402 .60636 .64886 .61156 .65874 .60871 .65392 .60349 Mtetra
.65392 .60349 .65874 .60871 .66865 .60585 .66386 .60061 Mtetra
.66386 .60061 .66865 .60585 .6786 .60298 .67383 .59772 Mtetra
.67383 .59772 .6786 .60298 .68858 .6001 .68384 .59482 Mtetra
.68384 .59482 .68858 .6001 .6986 .59721 .69388 .59192 Mtetra
.69388 .59192 .6986 .59721 .70865 .59431 .70396 .589 Mtetra
.70396 .589 .70865 .59431 .71874 .59141 .71407 .58607 Mtetra
.71407 .58607 .71874 .59141 .72886 .58849 .72422 .58313 Mtetra
.72422 .58313 .72886 .58849 .73902 .58556 .73441 .58019 Mtetra
.73441 .58019 .73902 .58556 .74922 .58262 .74463 .57723 Mtetra
.74463 .57723 .74922 .58262 .75945 .57967 .75489 .57426 Mtetra
.75489 .57426 .75945 .57967 .76972 .57672 .76518 .57128 Mtetra
.76518 .57128 .76972 .57672 .78003 .57375 .77551 .5683 Mtetra
.77551 .5683 .78003 .57375 .79037 .57077 .78588 .5653 Mtetra
.78588 .5653 .79037 .57077 .80075 .56778 .79629 .56229 Mtetra
.79629 .56229 .80075 .56778 .81117 .56478 .80673 .55927 Mtetra
.80673 .55927 .81117 .56478 .82162 .56177 .81721 .55624 Mtetra
.81721 .55624 .82162 .56177 .83212 .55875 .82773 .5532 Mtetra
.82773 .5532 .83212 .55875 .84265 .55572 .83829 .55014 Mtetra
.83829 .55014 .84265 .55572 .85321 .55268 .84889 .54708 Mtetra
.84889 .54708 .85321 .55268 .86382 .54962 .85952 .54401 Mtetra
.85952 .54401 .86382 .54962 .87447 .54656 .8702 .54092 Mtetra
.8702 .54092 .87447 .54656 .88515 .54348 .88091 .53783 Mtetra
.88091 .53783 .88515 .54348 .89588 .5404 .89166 .53472 Mtetra
.89166 .53472 .89588 .5404 .90664 .5373 .90245 .5316 Mtetra
.90245 .5316 .90664 .5373 .91744 .53419 .91329 .52848 Mtetra
.91329 .52848 .91744 .53419 .92828 .53107 .92416 .52534 Mtetra
.92416 .52534 .92828 .53107 .93916 .52794 .93507 .52218 Mtetra
.93507 .52218 .93916 .52794 .95009 .5248 .94602 .51902 Mtetra
.94602 .51902 .95009 .5248 .96105 .52165 .95701 .51585 Mtetra
.95701 .51585 .96105 .52165 .97205 .51849 .96805 .51266 Mtetra
.621 .721 .918 r
.37477 .67712 .38021 .68242 .38918 .68028 .38375 .67533 Mtetra
.644 .742 .92 r
.38375 .67533 .38918 .68028 .3982 .67787 .39278 .673 Mtetra
.651 .747 .92 r
.39278 .673 .3982 .67787 .40726 .67534 .40186 .6705 Mtetra
.654 .75 .92 r
.40186 .6705 .40726 .67534 .41635 .67274 .41096 .66791 Mtetra
.657 .752 .92 r
.41096 .66791 .41635 .67274 .42547 .67009 .4201 .66526 Mtetra
.658 .753 .92 r
.4201 .66526 .42547 .67009 .43462 .6674 .42927 .66257 Mtetra
.659 .753 .92 r
.42927 .66257 .43462 .6674 .4438 .6647 .43847 .65985 Mtetra
.659 .754 .92 r
.43847 .65985 .4438 .6647 .45301 .66198 .44771 .65712 Mtetra
.44771 .65712 .45301 .66198 .46226 .65926 .45697 .65438 Mtetra
.45697 .65438 .46226 .65926 .47153 .65653 .46627 .65163 Mtetra
.658 .753 .92 r
.46627 .65163 .47153 .65653 .48084 .6538 .47559 .64888 Mtetra
.47559 .64888 .48084 .6538 .49018 .65107 .48495 .64613 Mtetra
.48495 .64613 .49018 .65107 .49955 .64833 .49434 .64338 Mtetra
.49434 .64338 .49955 .64833 .50895 .64559 .50377 .64061 Mtetra
.50377 .64061 .50895 .64559 .51838 .64284 .51322 .63785 Mtetra
.51322 .63785 .51838 .64284 .52785 .64008 .52271 .63507 Mtetra
.52271 .63507 .52785 .64008 .53735 .63732 .53223 .63229 Mtetra
.657 .753 .92 r
.53223 .63229 .53735 .63732 .54688 .63455 .54178 .6295 Mtetra
.54178 .6295 .54688 .63455 .55644 .63177 .55137 .6267 Mtetra
.657 .752 .92 r
.55137 .6267 .55644 .63177 .56604 .62898 .56098 .62389 Mtetra
.56098 .62389 .56604 .62898 .57567 .62618 .57064 .62108 Mtetra
.57064 .62108 .57567 .62618 .58533 .62338 .58032 .61825 Mtetra
.58032 .61825 .58533 .62338 .59503 .62056 .59004 .61542 Mtetra
.59004 .61542 .59503 .62056 .60476 .61774 .5998 .61258 Mtetra
.5998 .61258 .60476 .61774 .61452 .61491 .60958 .60973 Mtetra
.60958 .60973 .61452 .61491 .62432 .61207 .6194 .60687 Mtetra
.6194 .60687 .62432 .61207 .63415 .60922 .62926 .604 Mtetra
.62926 .604 .63415 .60922 .64402 .60636 .63915 .60112 Mtetra
.63915 .60112 .64402 .60636 .65392 .60349 .64908 .59823 Mtetra
.64908 .59823 .65392 .60349 .66386 .60061 .65904 .59534 Mtetra
.65904 .59534 .66386 .60061 .67383 .59772 .66903 .59243 Mtetra
.66903 .59243 .67383 .59772 .68384 .59482 .67906 .58951 Mtetra
.67906 .58951 .68384 .59482 .69388 .59192 .68913 .58659 Mtetra
.68913 .58659 .69388 .59192 .70396 .589 .69923 .58365 Mtetra
.69923 .58365 .70396 .589 .71407 .58607 .70937 .5807 Mtetra
.70937 .5807 .71407 .58607 .72422 .58313 .71955 .57775 Mtetra
.71955 .57775 .72422 .58313 .73441 .58019 .72976 .57478 Mtetra
.72976 .57478 .73441 .58019 .74463 .57723 .74 .5718 Mtetra
.74 .5718 .74463 .57723 .75489 .57426 .75029 .56881 Mtetra
.75029 .56881 .75489 .57426 .76518 .57128 .76061 .56582 Mtetra
.76061 .56582 .76518 .57128 .77551 .5683 .77097 .56281 Mtetra
.77097 .56281 .77551 .5683 .78588 .5653 .78136 .55979 Mtetra
.78136 .55979 .78588 .5653 .79629 .56229 .7918 .55676 Mtetra
.7918 .55676 .79629 .56229 .80673 .55927 .80227 .55372 Mtetra
.80227 .55372 .80673 .55927 .81721 .55624 .81278 .55067 Mtetra
.81278 .55067 .81721 .55624 .82773 .5532 .82333 .54761 Mtetra
.82333 .54761 .82773 .5532 .83829 .55014 .83391 .54453 Mtetra
.83391 .54453 .83829 .55014 .84889 .54708 .84454 .54145 Mtetra
.84454 .54145 .84889 .54708 .85952 .54401 .8552 .53836 Mtetra
.8552 .53836 .85952 .54401 .8702 .54092 .8659 .53525 Mtetra
.8659 .53525 .8702 .54092 .88091 .53783 .87664 .53214 Mtetra
.87664 .53214 .88091 .53783 .89166 .53472 .88742 .52901 Mtetra
.88742 .52901 .89166 .53472 .90245 .5316 .89824 .52587 Mtetra
.89824 .52587 .90245 .5316 .91329 .52848 .9091 .52272 Mtetra
.9091 .52272 .91329 .52848 .92416 .52534 .92 .51956 Mtetra
.92 .51956 .92416 .52534 .93507 .52218 .93095 .51638 Mtetra
.93095 .51638 .93507 .52218 .94602 .51902 .94193 .5132 Mtetra
.94193 .5132 .94602 .51902 .95701 .51585 .95295 .51 Mtetra
.95295 .51 .95701 .51585 .96805 .51266 .96401 .50679 Mtetra
.569 .668 .905 r
.36934 .67084 .37477 .67712 .38375 .67533 .37828 .67024 Mtetra
.637 .736 .92 r
.37828 .67024 .38375 .67533 .39278 .673 .38733 .66806 Mtetra
.648 .745 .92 r
.38733 .66806 .39278 .673 .40186 .6705 .39642 .66561 Mtetra
.653 .749 .92 r
.39642 .66561 .40186 .6705 .41096 .66791 .40554 .66304 Mtetra
.656 .751 .92 r
.40554 .66304 .41096 .66791 .4201 .66526 .4147 .6604 Mtetra
.657 .752 .92 r
.4147 .6604 .4201 .66526 .42927 .66257 .42389 .65771 Mtetra
.658 .753 .92 r
.42389 .65771 .42927 .66257 .43847 .65985 .43311 .65498 Mtetra
.659 .754 .92 r
.43311 .65498 .43847 .65985 .44771 .65712 .44237 .65223 Mtetra
.44237 .65223 .44771 .65712 .45697 .65438 .45165 .64947 Mtetra
.45165 .64947 .45697 .65438 .46627 .65163 .46097 .6467 Mtetra
.659 .753 .92 r
.46097 .6467 .46627 .65163 .47559 .64888 .47032 .64394 Mtetra
.658 .753 .92 r
.47032 .64394 .47559 .64888 .48495 .64613 .4797 .64116 Mtetra
.4797 .64116 .48495 .64613 .49434 .64338 .48911 .63839 Mtetra
.48911 .63839 .49434 .64338 .50377 .64061 .49855 .63561 Mtetra
.49855 .63561 .50377 .64061 .51322 .63785 .50803 .63282 Mtetra
.50803 .63282 .51322 .63785 .52271 .63507 .51753 .63002 Mtetra
.51753 .63002 .52271 .63507 .53223 .63229 .52708 .62722 Mtetra
.657 .753 .92 r
.52708 .62722 .53223 .63229 .54178 .6295 .53665 .62441 Mtetra
.53665 .62441 .54178 .6295 .55137 .6267 .54626 .6216 Mtetra
.54626 .6216 .55137 .6267 .56098 .62389 .5559 .61877 Mtetra
.657 .752 .92 r
.5559 .61877 .56098 .62389 .57064 .62108 .56557 .61594 Mtetra
.56557 .61594 .57064 .62108 .58032 .61825 .57528 .6131 Mtetra
.57528 .6131 .58032 .61825 .59004 .61542 .58502 .61025 Mtetra
.58502 .61025 .59004 .61542 .5998 .61258 .5948 .60739 Mtetra
.5948 .60739 .5998 .61258 .60958 .60973 .60461 .60452 Mtetra
.60461 .60452 .60958 .60973 .6194 .60687 .61446 .60164 Mtetra
.61446 .60164 .6194 .60687 .62926 .604 .62434 .59875 Mtetra
.62434 .59875 .62926 .604 .63915 .60112 .63425 .59585 Mtetra
.63425 .59585 .63915 .60112 .64908 .59823 .6442 .59294 Mtetra
.6442 .59294 .64908 .59823 .65904 .59534 .65418 .59003 Mtetra
.65418 .59003 .65904 .59534 .66903 .59243 .6642 .5871 Mtetra
.6642 .5871 .66903 .59243 .67906 .58951 .67426 .58417 Mtetra
.67426 .58417 .67906 .58951 .68913 .58659 .68435 .58122 Mtetra
.68435 .58122 .68913 .58659 .69923 .58365 .69448 .57826 Mtetra
.69448 .57826 .69923 .58365 .70937 .5807 .70464 .5753 Mtetra
.70464 .5753 .70937 .5807 .71955 .57775 .71484 .57232 Mtetra
.71484 .57232 .71955 .57775 .72976 .57478 .72508 .56933 Mtetra
.72508 .56933 .72976 .57478 .74 .5718 .73535 .56634 Mtetra
.73535 .56634 .74 .5718 .75029 .56881 .74566 .56333 Mtetra
.74566 .56333 .75029 .56881 .76061 .56582 .75601 .56031 Mtetra
.75601 .56031 .76061 .56582 .77097 .56281 .76639 .55728 Mtetra
.76639 .55728 .77097 .56281 .78136 .55979 .77682 .55424 Mtetra
.77682 .55424 .78136 .55979 .7918 .55676 .78728 .55119 Mtetra
.78728 .55119 .7918 .55676 .80227 .55372 .79777 .54813 Mtetra
.79777 .54813 .80227 .55372 .81278 .55067 .80831 .54506 Mtetra
.80831 .54506 .81278 .55067 .82333 .54761 .81889 .54198 Mtetra
.81889 .54198 .82333 .54761 .83391 .54453 .8295 .53889 Mtetra
.8295 .53889 .83391 .54453 .84454 .54145 .84015 .53578 Mtetra
.84015 .53578 .84454 .54145 .8552 .53836 .85084 .53267 Mtetra
.85084 .53267 .8552 .53836 .8659 .53525 .86157 .52954 Mtetra
.86157 .52954 .8659 .53525 .87664 .53214 .87234 .5264 Mtetra
.87234 .5264 .87664 .53214 .88742 .52901 .88315 .52325 Mtetra
.88315 .52325 .88742 .52901 .89824 .52587 .894 .52009 Mtetra
.894 .52009 .89824 .52587 .9091 .52272 .90489 .51692 Mtetra
.90489 .51692 .9091 .52272 .92 .51956 .91582 .51374 Mtetra
.91582 .51374 .92 .51956 .93095 .51638 .92679 .51054 Mtetra
.92679 .51054 .93095 .51638 .94193 .5132 .93781 .50734 Mtetra
.93781 .50734 .94193 .5132 .95295 .51 .94886 .50412 Mtetra
.94886 .50412 .95295 .51 .96401 .50679 .95995 .50089 Mtetra
.029 .024 .514 r
.3653 .63393 .36934 .67084 .37828 .67024 .3728 .66487 Mtetra
.621 .721 .918 r
.3728 .66487 .37828 .67024 .38733 .66806 .38185 .66304 Mtetra
.644 .742 .92 r
.38185 .66304 .38733 .66806 .39642 .66561 .39095 .66067 Mtetra
.651 .747 .92 r
.39095 .66067 .39642 .66561 .40554 .66304 .40009 .65812 Mtetra
.654 .75 .92 r
.40009 .65812 .40554 .66304 .4147 .6604 .40927 .65549 Mtetra
.657 .752 .92 r
.40927 .65549 .4147 .6604 .42389 .65771 .41848 .6528 Mtetra
.658 .753 .92 r
.41848 .6528 .42389 .65771 .43311 .65498 .42772 .65007 Mtetra
.659 .753 .92 r
.42772 .65007 .43311 .65498 .44237 .65223 .43699 .64731 Mtetra
.659 .754 .92 r
.43699 .64731 .44237 .65223 .45165 .64947 .4463 .64453 Mtetra
.4463 .64453 .45165 .64947 .46097 .6467 .45563 .64175 Mtetra
.45563 .64175 .46097 .6467 .47032 .64394 .465 .63896 Mtetra
.658 .753 .92 r
.465 .63896 .47032 .64394 .4797 .64116 .4744 .63616 Mtetra
.4744 .63616 .4797 .64116 .48911 .63839 .48384 .63337 Mtetra
.48384 .63337 .48911 .63839 .49855 .63561 .4933 .63057 Mtetra
.4933 .63057 .49855 .63561 .50803 .63282 .5028 .62776 Mtetra
.5028 .62776 .50803 .63282 .51753 .63002 .51233 .62495 Mtetra
.51233 .62495 .51753 .63002 .52708 .62722 .52189 .62213 Mtetra
.52189 .62213 .52708 .62722 .53665 .62441 .53149 .6193 Mtetra
.657 .753 .92 r
.53149 .6193 .53665 .62441 .54626 .6216 .54112 .61646 Mtetra
.54112 .61646 .54626 .6216 .5559 .61877 .55078 .61362 Mtetra
.657 .752 .92 r
.55078 .61362 .5559 .61877 .56557 .61594 .56048 .61077 Mtetra
.56048 .61077 .56557 .61594 .57528 .6131 .57021 .60791 Mtetra
.57021 .60791 .57528 .6131 .58502 .61025 .57997 .60504 Mtetra
.57997 .60504 .58502 .61025 .5948 .60739 .58977 .60216 Mtetra
.58977 .60216 .5948 .60739 .60461 .60452 .59961 .59927 Mtetra
.59961 .59927 .60461 .60452 .61446 .60164 .60947 .59637 Mtetra
.60947 .59637 .61446 .60164 .62434 .59875 .61938 .59346 Mtetra
.61938 .59346 .62434 .59875 .63425 .59585 .62932 .59055 Mtetra
.62932 .59055 .63425 .59585 .6442 .59294 .63929 .58762 Mtetra
.63929 .58762 .6442 .59294 .65418 .59003 .6493 .58468 Mtetra
.6493 .58468 .65418 .59003 .6642 .5871 .65934 .58174 Mtetra
.65934 .58174 .6642 .5871 .67426 .58417 .66942 .57878 Mtetra
.66942 .57878 .67426 .58417 .68435 .58122 .67954 .57582 Mtetra
.67954 .57582 .68435 .58122 .69448 .57826 .68969 .57284 Mtetra
.68969 .57284 .69448 .57826 .70464 .5753 .69988 .56986 Mtetra
.69988 .56986 .70464 .5753 .71484 .57232 .71011 .56686 Mtetra
.71011 .56686 .71484 .57232 .72508 .56933 .72037 .56385 Mtetra
.72037 .56385 .72508 .56933 .73535 .56634 .73067 .56084 Mtetra
.73067 .56084 .73535 .56634 .74566 .56333 .741 .55781 Mtetra
.741 .55781 .74566 .56333 .75601 .56031 .75138 .55477 Mtetra
.75138 .55477 .75601 .56031 .76639 .55728 .76179 .55172 Mtetra
.76179 .55172 .76639 .55728 .77682 .55424 .77224 .54866 Mtetra
.77224 .54866 .77682 .55424 .78728 .55119 .78272 .54559 Mtetra
.78272 .54559 .78728 .55119 .79777 .54813 .79325 .54251 Mtetra
.79325 .54251 .79777 .54813 .80831 .54506 .80381 .53942 Mtetra
.80381 .53942 .80831 .54506 .81889 .54198 .81442 .53631 Mtetra
.81442 .53631 .81889 .54198 .8295 .53889 .82506 .5332 Mtetra
.82506 .5332 .8295 .53889 .84015 .53578 .83574 .53007 Mtetra
.83574 .53007 .84015 .53578 .85084 .53267 .84646 .52694 Mtetra
.84646 .52694 .85084 .53267 .86157 .52954 .85722 .52379 Mtetra
.85722 .52379 .86157 .52954 .87234 .5264 .86801 .52063 Mtetra
.86801 .52063 .87234 .5264 .88315 .52325 .87885 .51746 Mtetra
.87885 .51746 .88315 .52325 .894 .52009 .88973 .51428 Mtetra
.88973 .51428 .894 .52009 .90489 .51692 .90065 .51108 Mtetra
.90065 .51108 .90489 .51692 .91582 .51374 .91161 .50788 Mtetra
.91161 .50788 .91582 .51374 .92679 .51054 .92261 .50466 Mtetra
.92261 .50466 .92679 .51054 .93781 .50734 .93366 .50143 Mtetra
.93366 .50143 .93781 .50734 .94886 .50412 .94474 .49819 Mtetra
.94474 .49819 .94886 .50412 .95995 .50089 .95586 .49494 Mtetra
.441 .186 .431 r
.35793 .66788 .3653 .63393 .3728 .66487 .36732 .6585 Mtetra
.569 .668 .905 r
.36732 .6585 .3728 .66487 .38185 .66304 .37633 .65787 Mtetra
.637 .736 .92 r
.37633 .65787 .38185 .66304 .39095 .66067 .38545 .65565 Mtetra
.648 .745 .92 r
.38545 .65565 .39095 .66067 .40009 .65812 .3946 .65316 Mtetra
.653 .749 .92 r
.3946 .65316 .40009 .65812 .40927 .65549 .4038 .65055 Mtetra
.656 .751 .92 r
.4038 .65055 .40927 .65549 .41848 .6528 .41303 .64786 Mtetra
.657 .752 .92 r
.41303 .64786 .41848 .6528 .42772 .65007 .42229 .64513 Mtetra
.658 .753 .92 r
.42229 .64513 .42772 .65007 .43699 .64731 .43158 .64236 Mtetra
.659 .754 .92 r
.43158 .64236 .43699 .64731 .4463 .64453 .44091 .63956 Mtetra
.44091 .63956 .4463 .64453 .45563 .64175 .45027 .63676 Mtetra
.45027 .63676 .45563 .64175 .465 .63896 .45966 .63395 Mtetra
.659 .753 .92 r
.45966 .63395 .465 .63896 .4744 .63616 .46908 .63113 Mtetra
.658 .753 .92 r
.46908 .63113 .4744 .63616 .48384 .63337 .47853 .62832 Mtetra
.47853 .62832 .48384 .63337 .4933 .63057 .48802 .6255 Mtetra
.48802 .6255 .4933 .63057 .5028 .62776 .49754 .62267 Mtetra
.49754 .62267 .5028 .62776 .51233 .62495 .50709 .61984 Mtetra
.50709 .61984 .51233 .62495 .52189 .62213 .51667 .617 Mtetra
.51667 .617 .52189 .62213 .53149 .6193 .52629 .61415 Mtetra
.657 .753 .92 r
.52629 .61415 .53149 .6193 .54112 .61646 .53594 .6113 Mtetra
.53594 .6113 .54112 .61646 .55078 .61362 .54563 .60843 Mtetra
.54563 .60843 .55078 .61362 .56048 .61077 .55535 .60556 Mtetra
.657 .752 .92 r
.55535 .60556 .56048 .61077 .57021 .60791 .5651 .60268 Mtetra
.5651 .60268 .57021 .60791 .57997 .60504 .57489 .59979 Mtetra
.57489 .59979 .57997 .60504 .58977 .60216 .58471 .5969 Mtetra
.58471 .5969 .58977 .60216 .59961 .59927 .59457 .59399 Mtetra
.59457 .59399 .59961 .59927 .60947 .59637 .60446 .59107 Mtetra
.60446 .59107 .60947 .59637 .61938 .59346 .61439 .58814 Mtetra
.61439 .58814 .61938 .59346 .62932 .59055 .62435 .58521 Mtetra
.62435 .58521 .62932 .59055 .63929 .58762 .63435 .58226 Mtetra
.63435 .58226 .63929 .58762 .6493 .58468 .64438 .57931 Mtetra
.64438 .57931 .6493 .58468 .65934 .58174 .65445 .57634 Mtetra
.65445 .57634 .65934 .58174 .66942 .57878 .66455 .57337 Mtetra
.66455 .57337 .66942 .57878 .67954 .57582 .6747 .57038 Mtetra
.6747 .57038 .67954 .57582 .68969 .57284 .68487 .56738 Mtetra
.68487 .56738 .68969 .57284 .69988 .56986 .69509 .56438 Mtetra
.69509 .56438 .69988 .56986 .71011 .56686 .70534 .56136 Mtetra
.70534 .56136 .71011 .56686 .72037 .56385 .71563 .55833 Mtetra
.71563 .55833 .72037 .56385 .73067 .56084 .72595 .5553 Mtetra
.72595 .5553 .73067 .56084 .741 .55781 .73631 .55225 Mtetra
.73631 .55225 .741 .55781 .75138 .55477 .74671 .54919 Mtetra
.74671 .54919 .75138 .55477 .76179 .55172 .75715 .54612 Mtetra
.75715 .54612 .76179 .55172 .77224 .54866 .76763 .54304 Mtetra
.76763 .54304 .77224 .54866 .78272 .54559 .77814 .53995 Mtetra
.77814 .53995 .78272 .54559 .79325 .54251 .78869 .53685 Mtetra
.78869 .53685 .79325 .54251 .80381 .53942 .79929 .53373 Mtetra
.79929 .53373 .80381 .53942 .81442 .53631 .80992 .53061 Mtetra
.80992 .53061 .81442 .53631 .82506 .5332 .82058 .52747 Mtetra
.82058 .52747 .82506 .5332 .83574 .53007 .83129 .52433 Mtetra
.83129 .52433 .83574 .53007 .84646 .52694 .84204 .52117 Mtetra
.84204 .52117 .84646 .52694 .85722 .52379 .85283 .518 Mtetra
.85283 .518 .85722 .52379 .86801 .52063 .86366 .51482 Mtetra
.86366 .51482 .86801 .52063 .87885 .51746 .87453 .51163 Mtetra
.87453 .51163 .87885 .51746 .88973 .51428 .88543 .50842 Mtetra
.88543 .50842 .88973 .51428 .90065 .51108 .89638 .50521 Mtetra
.89638 .50521 .90065 .51108 .91161 .50788 .90737 .50198 Mtetra
.90737 .50198 .91161 .50788 .92261 .50466 .9184 .49874 Mtetra
.9184 .49874 .92261 .50466 .93366 .50143 .92948 .49549 Mtetra
.92948 .49549 .93366 .50143 .94474 .49819 .94059 .49222 Mtetra
.94059 .49222 .94474 .49819 .95586 .49494 .95175 .48895 Mtetra
.9 .71 .636 r
.35243 .661 .35793 .66788 .36732 .6585 .36326 .62138 Mtetra
.023 .019 .512 r
.36326 .62138 .36732 .6585 .37633 .65787 .3708 .65242 Mtetra
.621 .721 .918 r
.3708 .65242 .37633 .65787 .38545 .65565 .37991 .65055 Mtetra
.644 .742 .92 r
.37991 .65055 .38545 .65565 .3946 .65316 .38909 .64813 Mtetra
.651 .747 .92 r
.38909 .64813 .3946 .65316 .4038 .65055 .3983 .64555 Mtetra
.654 .75 .92 r
.3983 .64555 .4038 .65055 .41303 .64786 .40754 .64288 Mtetra
.657 .752 .92 r
.40754 .64288 .41303 .64786 .42229 .64513 .41683 .64014 Mtetra
.658 .753 .92 r
.41683 .64014 .42229 .64513 .43158 .64236 .42614 .63737 Mtetra
.659 .753 .92 r
.42614 .63737 .43158 .64236 .44091 .63956 .43549 .63456 Mtetra
.659 .754 .92 r
.43549 .63456 .44091 .63956 .45027 .63676 .44486 .63174 Mtetra
.44486 .63174 .45027 .63676 .45966 .63395 .45427 .62891 Mtetra
.45427 .62891 .45966 .63395 .46908 .63113 .46372 .62607 Mtetra
.658 .753 .92 r
.46372 .62607 .46908 .63113 .47853 .62832 .47319 .62324 Mtetra
.47319 .62324 .47853 .62832 .48802 .6255 .4827 .6204 Mtetra
.4827 .6204 .48802 .6255 .49754 .62267 .49224 .61755 Mtetra
.49224 .61755 .49754 .62267 .50709 .61984 .50181 .6147 Mtetra
.50181 .6147 .50709 .61984 .51667 .617 .51142 .61184 Mtetra
.51142 .61184 .51667 .617 .52629 .61415 .52106 .60897 Mtetra
.52106 .60897 .52629 .61415 .53594 .6113 .53074 .6061 Mtetra
.657 .753 .92 r
.53074 .6061 .53594 .6113 .54563 .60843 .54044 .60322 Mtetra
.54044 .60322 .54563 .60843 .55535 .60556 .55019 .60032 Mtetra
.657 .752 .92 r
.55019 .60032 .55535 .60556 .5651 .60268 .55996 .59743 Mtetra
.55996 .59743 .5651 .60268 .57489 .59979 .56977 .59452 Mtetra
.56977 .59452 .57489 .59979 .58471 .5969 .57962 .5916 Mtetra
.57962 .5916 .58471 .5969 .59457 .59399 .5895 .58867 Mtetra
.5895 .58867 .59457 .59399 .60446 .59107 .59941 .58574 Mtetra
.59941 .58574 .60446 .59107 .61439 .58814 .60937 .58279 Mtetra
.60937 .58279 .61439 .58814 .62435 .58521 .61935 .57983 Mtetra
.61935 .57983 .62435 .58521 .63435 .58226 .62937 .57687 Mtetra
.62937 .57687 .63435 .58226 .64438 .57931 .63943 .57389 Mtetra
.63943 .57389 .64438 .57931 .65445 .57634 .64952 .57091 Mtetra
.64952 .57091 .65445 .57634 .66455 .57337 .65965 .56791 Mtetra
.65965 .56791 .66455 .57337 .6747 .57038 .66982 .56491 Mtetra
.66982 .56491 .6747 .57038 .68487 .56738 .68002 .56189 Mtetra
.68002 .56189 .68487 .56738 .69509 .56438 .69026 .55886 Mtetra
.69026 .55886 .69509 .56438 .70534 .56136 .70054 .55583 Mtetra
.70054 .55583 .70534 .56136 .71563 .55833 .71085 .55278 Mtetra
.71085 .55278 .71563 .55833 .72595 .5553 .7212 .54972 Mtetra
.7212 .54972 .72595 .5553 .73631 .55225 .73159 .54665 Mtetra
.73159 .54665 .73631 .55225 .74671 .54919 .74202 .54357 Mtetra
.74202 .54357 .74671 .54919 .75715 .54612 .75248 .54048 Mtetra
.75248 .54048 .75715 .54612 .76763 .54304 .76299 .53738 Mtetra
.76299 .53738 .76763 .54304 .77814 .53995 .77353 .53427 Mtetra
.77353 .53427 .77814 .53995 .78869 .53685 .78411 .53115 Mtetra
.78411 .53115 .78869 .53685 .79929 .53373 .79473 .52801 Mtetra
.79473 .52801 .79929 .53373 .80992 .53061 .80538 .52487 Mtetra
.80538 .52487 .80992 .53061 .82058 .52747 .81608 .52171 Mtetra
.81608 .52171 .82058 .52747 .83129 .52433 .82682 .51854 Mtetra
.82682 .51854 .83129 .52433 .84204 .52117 .8376 .51536 Mtetra
.8376 .51536 .84204 .52117 .85283 .518 .84841 .51217 Mtetra
.84841 .51217 .85283 .518 .86366 .51482 .85927 .50897 Mtetra
.85927 .50897 .86366 .51482 .87453 .51163 .87017 .50575 Mtetra
.87017 .50575 .87453 .51163 .88543 .50842 .8811 .50253 Mtetra
.8811 .50253 .88543 .50842 .89638 .50521 .89208 .49929 Mtetra
.89208 .49929 .89638 .50521 .90737 .50198 .9031 .49604 Mtetra
.9031 .49604 .90737 .50198 .9184 .49874 .91417 .49278 Mtetra
.91417 .49278 .9184 .49874 .92948 .49549 .92527 .4895 Mtetra
.92527 .4895 .92948 .49549 .94059 .49222 .93641 .48622 Mtetra
.93641 .48622 .94059 .49222 .95175 .48895 .9476 .48292 Mtetra
.515 .679 .94 r
.34682 .65543 .35243 .661 .36326 .62138 .35581 .65542 Mtetra
.436 .18 .426 r
.35581 .65542 .36326 .62138 .3708 .65242 .36527 .64597 Mtetra
.569 .668 .906 r
.36527 .64597 .3708 .65242 .37991 .65055 .37435 .6453 Mtetra
.637 .736 .92 r
.37435 .6453 .37991 .65055 .38909 .64813 .38353 .64304 Mtetra
.648 .745 .92 r
.38353 .64304 .38909 .64813 .3983 .64555 .39276 .6405 Mtetra
.653 .749 .92 r
.39276 .6405 .3983 .64555 .40754 .64288 .40203 .63785 Mtetra
.656 .751 .92 r
.40203 .63785 .40754 .64288 .41683 .64014 .41133 .63512 Mtetra
.657 .752 .92 r
.41133 .63512 .41683 .64014 .42614 .63737 .42066 .63234 Mtetra
.658 .753 .92 r
.42066 .63234 .42614 .63737 .43549 .63456 .43003 .62953 Mtetra
.659 .754 .92 r
.43003 .62953 .43549 .63456 .44486 .63174 .43943 .62669 Mtetra
.43943 .62669 .44486 .63174 .45427 .62891 .44886 .62384 Mtetra
.44886 .62384 .45427 .62891 .46372 .62607 .45832 .62098 Mtetra
.659 .753 .92 r
.45832 .62098 .46372 .62607 .47319 .62324 .46782 .61812 Mtetra
.658 .753 .92 r
.46782 .61812 .47319 .62324 .4827 .6204 .47735 .61526 Mtetra
.47735 .61526 .4827 .6204 .49224 .61755 .48691 .6124 Mtetra
.48691 .6124 .49224 .61755 .50181 .6147 .49651 .60952 Mtetra
.49651 .60952 .50181 .6147 .51142 .61184 .50613 .60664 Mtetra
.50613 .60664 .51142 .61184 .52106 .60897 .5158 .60376 Mtetra
.5158 .60376 .52106 .60897 .53074 .6061 .52549 .60086 Mtetra
.657 .753 .92 r
.52549 .60086 .53074 .6061 .54044 .60322 .53522 .59796 Mtetra
.53522 .59796 .54044 .60322 .55019 .60032 .54499 .59505 Mtetra
.54499 .59505 .55019 .60032 .55996 .59743 .55479 .59213 Mtetra
.657 .752 .92 r
.55479 .59213 .55996 .59743 .56977 .59452 .56462 .58921 Mtetra
.56462 .58921 .56977 .59452 .57962 .5916 .57449 .58627 Mtetra
.57449 .58627 .57962 .5916 .5895 .58867 .5844 .58332 Mtetra
.5844 .58332 .5895 .58867 .59941 .58574 .59433 .58037 Mtetra
.59433 .58037 .59941 .58574 .60937 .58279 .60431 .5774 Mtetra
.60431 .5774 .60937 .58279 .61935 .57983 .61432 .57442 Mtetra
.61432 .57442 .61935 .57983 .62937 .57687 .62437 .57144 Mtetra
.62437 .57144 .62937 .57687 .63943 .57389 .63445 .56844 Mtetra
.63445 .56844 .63943 .57389 .64952 .57091 .64457 .56544 Mtetra
.64457 .56544 .64952 .57091 .65965 .56791 .65472 .56242 Mtetra
.65472 .56242 .65965 .56791 .66982 .56491 .66491 .5594 Mtetra
.66491 .5594 .66982 .56491 .68002 .56189 .67514 .55636 Mtetra
.67514 .55636 .68002 .56189 .69026 .55886 .6854 .55331 Mtetra
.6854 .55331 .69026 .55886 .70054 .55583 .69571 .55026 Mtetra
.69571 .55026 .70054 .55583 .71085 .55278 .70605 .54719 Mtetra
.70605 .54719 .71085 .55278 .7212 .54972 .71642 .54411 Mtetra
.71642 .54411 .7212 .54972 .73159 .54665 .72684 .54102 Mtetra
.72684 .54102 .73159 .54665 .74202 .54357 .73729 .53792 Mtetra
.73729 .53792 .74202 .54357 .75248 .54048 .74778 .53481 Mtetra
.74778 .53481 .75248 .54048 .76299 .53738 .75831 .53169 Mtetra
.75831 .53169 .76299 .53738 .77353 .53427 .76888 .52855 Mtetra
.76888 .52855 .77353 .53427 .78411 .53115 .77949 .52541 Mtetra
.77949 .52541 .78411 .53115 .79473 .52801 .79014 .52225 Mtetra
.79014 .52225 .79473 .52801 .80538 .52487 .80082 .51909 Mtetra
.80082 .51909 .80538 .52487 .81608 .52171 .81155 .51591 Mtetra
.81155 .51591 .81608 .52171 .82682 .51854 .82231 .51272 Mtetra
.82231 .51272 .82682 .51854 .8376 .51536 .83312 .50951 Mtetra
.83312 .50951 .8376 .51536 .84841 .51217 .84396 .5063 Mtetra
.84396 .5063 .84841 .51217 .85927 .50897 .85485 .50308 Mtetra
.85485 .50308 .85927 .50897 .87017 .50575 .86578 .49984 Mtetra
.86578 .49984 .87017 .50575 .8811 .50253 .87675 .49659 Mtetra
.87675 .49659 .8811 .50253 .89208 .49929 .88775 .49333 Mtetra
.88775 .49333 .89208 .49929 .9031 .49604 .8988 .49006 Mtetra
.8988 .49006 .9031 .49604 .91417 .49278 .9099 .48677 Mtetra
.9099 .48677 .91417 .49278 .92527 .4895 .92103 .48348 Mtetra
.92103 .48348 .92527 .4895 .93641 .48622 .93221 .48017 Mtetra
.93221 .48017 .93641 .48622 .9476 .48292 .94342 .47685 Mtetra
.609 .725 .927 r
.34117 .65013 .34682 .65543 .35581 .65542 .35025 .64845 Mtetra
.901 .711 .635 r
.35025 .64845 .35581 .65542 .36527 .64597 .36119 .60862 Mtetra
.018 .015 .509 r
.36119 .60862 .36527 .64597 .37435 .6453 .36876 .63976 Mtetra
.621 .721 .918 r
.36876 .63976 .37435 .6453 .38353 .64304 .37795 .63786 Mtetra
.644 .742 .92 r
.37795 .63786 .38353 .64304 .39276 .6405 .38719 .6354 Mtetra
.651 .747 .92 r
.38719 .6354 .39276 .6405 .40203 .63785 .39647 .63277 Mtetra
.654 .75 .92 r
.39647 .63277 .40203 .63785 .41133 .63512 .40579 .63006 Mtetra
.657 .752 .92 r
.40579 .63006 .41133 .63512 .42066 .63234 .41515 .62728 Mtetra
.658 .753 .92 r
.41515 .62728 .42066 .63234 .43003 .62953 .42453 .62445 Mtetra
.659 .753 .92 r
.42453 .62445 .43003 .62953 .43943 .62669 .43395 .6216 Mtetra
.659 .754 .92 r
.43395 .6216 .43943 .62669 .44886 .62384 .44341 .61874 Mtetra
.44341 .61874 .44886 .62384 .45832 .62098 .45289 .61586 Mtetra
.45289 .61586 .45832 .62098 .46782 .61812 .46241 .61298 Mtetra
.658 .753 .92 r
.46241 .61298 .46782 .61812 .47735 .61526 .47196 .6101 Mtetra
.47196 .6101 .47735 .61526 .48691 .6124 .48155 .60721 Mtetra
.48155 .60721 .48691 .6124 .49651 .60952 .49116 .60432 Mtetra
.49116 .60432 .49651 .60952 .50613 .60664 .50081 .60142 Mtetra
.50081 .60142 .50613 .60664 .5158 .60376 .5105 .59851 Mtetra
.5105 .59851 .5158 .60376 .52549 .60086 .52022 .5956 Mtetra
.52022 .5956 .52549 .60086 .53522 .59796 .52997 .59268 Mtetra
.657 .753 .92 r
.52997 .59268 .53522 .59796 .54499 .59505 .53976 .58975 Mtetra
.53976 .58975 .54499 .59505 .55479 .59213 .54958 .58681 Mtetra
.657 .752 .92 r
.54958 .58681 .55479 .59213 .56462 .58921 .55944 .58386 Mtetra
.55944 .58386 .56462 .58921 .57449 .58627 .56933 .5809 Mtetra
.56933 .5809 .57449 .58627 .5844 .58332 .57926 .57794 Mtetra
.57926 .57794 .5844 .58332 .59433 .58037 .58922 .57496 Mtetra
.58922 .57496 .59433 .58037 .60431 .5774 .59922 .57197 Mtetra
.59922 .57197 .60431 .5774 .61432 .57442 .60925 .56898 Mtetra
.60925 .56898 .61432 .57442 .62437 .57144 .61932 .56597 Mtetra
.61932 .56597 .62437 .57144 .63445 .56844 .62943 .56296 Mtetra
.62943 .56296 .63445 .56844 .64457 .56544 .63957 .55993 Mtetra
.63957 .55993 .64457 .56544 .65472 .56242 .64975 .5569 Mtetra
.64975 .5569 .65472 .56242 .66491 .5594 .65997 .55385 Mtetra
.65997 .55385 .66491 .5594 .67514 .55636 .67022 .55079 Mtetra
.67022 .55079 .67514 .55636 .6854 .55331 .68051 .54773 Mtetra
.68051 .54773 .6854 .55331 .69571 .55026 .69084 .54465 Mtetra
.69084 .54465 .69571 .55026 .70605 .54719 .70121 .54156 Mtetra
.70121 .54156 .70605 .54719 .71642 .54411 .71161 .53846 Mtetra
.71161 .53846 .71642 .54411 .72684 .54102 .72205 .53535 Mtetra
.72205 .53535 .72684 .54102 .73729 .53792 .73253 .53223 Mtetra
.73253 .53223 .73729 .53792 .74778 .53481 .74305 .52909 Mtetra
.74305 .52909 .74778 .53481 .75831 .53169 .75361 .52595 Mtetra
.75361 .52595 .75831 .53169 .76888 .52855 .76421 .5228 Mtetra
.76421 .5228 .76888 .52855 .77949 .52541 .77484 .51963 Mtetra
.77484 .51963 .77949 .52541 .79014 .52225 .78552 .51645 Mtetra
.78552 .51645 .79014 .52225 .80082 .51909 .79623 .51326 Mtetra
.79623 .51326 .80082 .51909 .81155 .51591 .80698 .51006 Mtetra
.80698 .51006 .81155 .51591 .82231 .51272 .81778 .50685 Mtetra
.81778 .50685 .82231 .51272 .83312 .50951 .82861 .50363 Mtetra
.82861 .50363 .83312 .50951 .84396 .5063 .83949 .50039 Mtetra
.83949 .50039 .84396 .5063 .85485 .50308 .8504 .49714 Mtetra
.8504 .49714 .85485 .50308 .86578 .49984 .86136 .49388 Mtetra
.86136 .49388 .86578 .49984 .87675 .49659 .87236 .49061 Mtetra
.87236 .49061 .87675 .49659 .88775 .49333 .8834 .48733 Mtetra
.8834 .48733 .88775 .49333 .8988 .49006 .89448 .48403 Mtetra
.89448 .48403 .8988 .49006 .9099 .48677 .9056 .48073 Mtetra
.9056 .48073 .9099 .48677 .92103 .48348 .91676 .47741 Mtetra
.91676 .47741 .92103 .48348 .93221 .48017 .92797 .47407 Mtetra
.92797 .47407 .93221 .48017 .94342 .47685 .93922 .47073 Mtetra
.629 .735 .924 r
.33547 .64491 .34117 .65013 .35025 .64845 .34459 .6428 Mtetra
.515 .679 .94 r
.34459 .6428 .35025 .64845 .36119 .60862 .35364 .64275 Mtetra
.432 .174 .421 r
.35364 .64275 .36119 .60862 .36876 .63976 .36318 .63323 Mtetra
.569 .668 .906 r
.36318 .63323 .36876 .63976 .37795 .63786 .37233 .63253 Mtetra
.637 .736 .92 r
.37233 .63253 .37795 .63786 .38719 .6354 .38159 .63022 Mtetra
.648 .745 .92 r
.38159 .63022 .38719 .6354 .39647 .63277 .39089 .62764 Mtetra
.653 .749 .92 r
.39089 .62764 .39647 .63277 .40579 .63006 .40023 .62494 Mtetra
.656 .751 .92 r
.40023 .62494 .40579 .63006 .41515 .62728 .4096 .62217 Mtetra
.657 .752 .92 r
.4096 .62217 .41515 .62728 .42453 .62445 .41901 .61935 Mtetra
.658 .753 .92 r
.41901 .61935 .42453 .62445 .43395 .6216 .42845 .61649 Mtetra
.659 .754 .92 r
.42845 .61649 .43395 .6216 .44341 .61874 .43792 .6136 Mtetra
.43792 .6136 .44341 .61874 .45289 .61586 .44743 .61071 Mtetra
.44743 .61071 .45289 .61586 .46241 .61298 .45697 .6078 Mtetra
.659 .753 .92 r
.45697 .6078 .46241 .61298 .47196 .6101 .46654 .6049 Mtetra
.658 .753 .92 r
.46654 .6049 .47196 .6101 .48155 .60721 .47615 .60199 Mtetra
.47615 .60199 .48155 .60721 .49116 .60432 .48578 .59908 Mtetra
.48578 .59908 .49116 .60432 .50081 .60142 .49546 .59616 Mtetra
.49546 .59616 .50081 .60142 .5105 .59851 .50517 .59323 Mtetra
.50517 .59323 .5105 .59851 .52022 .5956 .51491 .5903 Mtetra
.51491 .5903 .52022 .5956 .52997 .59268 .52468 .58735 Mtetra
.657 .753 .92 r
.52468 .58735 .52997 .59268 .53976 .58975 .53449 .5844 Mtetra
.53449 .5844 .53976 .58975 .54958 .58681 .54434 .58145 Mtetra
.54434 .58145 .54958 .58681 .55944 .58386 .55422 .57848 Mtetra
.657 .752 .92 r
.55422 .57848 .55944 .58386 .56933 .5809 .56414 .5755 Mtetra
.56414 .5755 .56933 .5809 .57926 .57794 .57409 .57251 Mtetra
.57409 .57251 .57926 .57794 .58922 .57496 .58407 .56952 Mtetra
.58407 .56952 .58922 .57496 .59922 .57197 .5941 .56651 Mtetra
.5941 .56651 .59922 .57197 .60925 .56898 .60415 .5635 Mtetra
.60415 .5635 .60925 .56898 .61932 .56597 .61425 .56047 Mtetra
.61425 .56047 .61932 .56597 .62943 .56296 .62438 .55744 Mtetra
.62438 .55744 .62943 .56296 .63957 .55993 .63455 .55439 Mtetra
.63455 .55439 .63957 .55993 .64975 .5569 .64475 .55133 Mtetra
.64475 .55133 .64975 .5569 .65997 .55385 .65499 .54827 Mtetra
.65499 .54827 .65997 .55385 .67022 .55079 .66527 .54519 Mtetra
.66527 .54519 .67022 .55079 .68051 .54773 .67559 .5421 Mtetra
.67559 .5421 .68051 .54773 .69084 .54465 .68594 .539 Mtetra
.68594 .539 .69084 .54465 .70121 .54156 .69634 .53589 Mtetra
.69634 .53589 .70121 .54156 .71161 .53846 .70677 .53277 Mtetra
.70677 .53277 .71161 .53846 .72205 .53535 .71724 .52964 Mtetra
.71724 .52964 .72205 .53535 .73253 .53223 .72774 .5265 Mtetra
.72774 .5265 .73253 .53223 .74305 .52909 .73829 .52334 Mtetra
.73829 .52334 .74305 .52909 .75361 .52595 .74887 .52018 Mtetra
.74887 .52018 .75361 .52595 .76421 .5228 .7595 .517 Mtetra
.7595 .517 .76421 .5228 .77484 .51963 .77016 .51381 Mtetra
.77016 .51381 .77484 .51963 .78552 .51645 .78086 .51061 Mtetra
.78086 .51061 .78552 .51645 .79623 .51326 .7916 .5074 Mtetra
.7916 .5074 .79623 .51326 .80698 .51006 .80239 .50418 Mtetra
.80239 .50418 .80698 .51006 .81778 .50685 .81321 .50094 Mtetra
.81321 .50094 .81778 .50685 .82861 .50363 .82407 .4977 Mtetra
.82407 .4977 .82861 .50363 .83949 .50039 .83498 .49444 Mtetra
.83498 .49444 .83949 .50039 .8504 .49714 .84592 .49117 Mtetra
.84592 .49117 .8504 .49714 .86136 .49388 .85691 .48789 Mtetra
.85691 .48789 .86136 .49388 .87236 .49061 .86794 .48459 Mtetra
.86794 .48459 .87236 .49061 .8834 .48733 .87901 .48129 Mtetra
.87901 .48129 .8834 .48733 .89448 .48403 .89012 .47797 Mtetra
.89012 .47797 .89448 .48403 .9056 .48073 .90127 .47464 Mtetra
.90127 .47464 .9056 .48073 .91676 .47741 .91247 .47129 Mtetra
.91247 .47129 .91676 .47741 .92797 .47407 .9237 .46794 Mtetra
.9237 .46794 .92797 .47407 .93922 .47073 .93499 .46457 Mtetra
.636 .739 .922 r
.32974 .6397 .33547 .64491 .34459 .6428 .33888 .63741 Mtetra
.609 .725 .927 r
.33888 .63741 .34459 .6428 .35364 .64275 .34803 .63569 Mtetra
.902 .711 .634 r
.34803 .63569 .35364 .64275 .36318 .63323 .35908 .59566 Mtetra
.012 .01 .506 r
.35908 .59566 .36318 .63323 .37233 .63253 .36669 .6269 Mtetra
.621 .721 .918 r
.36669 .6269 .37233 .63253 .38159 .63022 .37595 .62496 Mtetra
.644 .742 .92 r
.37595 .62496 .38159 .63022 .39089 .62764 .38527 .62246 Mtetra
.651 .747 .92 r
.38527 .62246 .39089 .62764 .40023 .62494 .39462 .61978 Mtetra
.654 .75 .92 r
.39462 .61978 .40023 .62494 .4096 .62217 .40401 .61702 Mtetra
.657 .752 .92 r
.40401 .61702 .4096 .62217 .41901 .61935 .41344 .6142 Mtetra
.658 .753 .92 r
.41344 .6142 .41901 .61935 .42845 .61649 .4229 .61133 Mtetra
.659 .753 .92 r
.4229 .61133 .42845 .61649 .43792 .6136 .4324 .60843 Mtetra
.659 .754 .92 r
.4324 .60843 .43792 .6136 .44743 .61071 .44193 .60552 Mtetra
.44193 .60552 .44743 .61071 .45697 .6078 .45149 .6026 Mtetra
.45149 .6026 .45697 .6078 .46654 .6049 .46108 .59967 Mtetra
.658 .753 .92 r
.46108 .59967 .46654 .6049 .47615 .60199 .47071 .59674 Mtetra
.47071 .59674 .47615 .60199 .48578 .59908 .48037 .5938 Mtetra
.48037 .5938 .48578 .59908 .49546 .59616 .49007 .59086 Mtetra
.49007 .59086 .49546 .59616 .50517 .59323 .4998 .58791 Mtetra
.4998 .58791 .50517 .59323 .51491 .5903 .50956 .58496 Mtetra
.50956 .58496 .51491 .5903 .52468 .58735 .51936 .582 Mtetra
.51936 .582 .52468 .58735 .53449 .5844 .52919 .57903 Mtetra
.657 .753 .92 r
.52919 .57903 .53449 .5844 .54434 .58145 .53906 .57605 Mtetra
.53906 .57605 .54434 .58145 .55422 .57848 .54897 .57306 Mtetra
.657 .752 .92 r
.54897 .57306 .55422 .57848 .56414 .5755 .55891 .57006 Mtetra
.55891 .57006 .56414 .5755 .57409 .57251 .56888 .56706 Mtetra
.56888 .56706 .57409 .57251 .58407 .56952 .57889 .56404 Mtetra
.57889 .56404 .58407 .56952 .5941 .56651 .58894 .56101 Mtetra
.58894 .56101 .5941 .56651 .60415 .5635 .59902 .55798 Mtetra
.59902 .55798 .60415 .5635 .61425 .56047 .60914 .55493 Mtetra
.60914 .55493 .61425 .56047 .62438 .55744 .6193 .55188 Mtetra
.6193 .55188 .62438 .55744 .63455 .55439 .62949 .54881 Mtetra
.62949 .54881 .63455 .55439 .64475 .55133 .63972 .54573 Mtetra
.63972 .54573 .64475 .55133 .65499 .54827 .64999 .54264 Mtetra
.64999 .54264 .65499 .54827 .66527 .54519 .66029 .53954 Mtetra
.66029 .53954 .66527 .54519 .67559 .5421 .67063 .53644 Mtetra
.67063 .53644 .67559 .5421 .68594 .539 .68101 .53332 Mtetra
.68101 .53332 .68594 .539 .69634 .53589 .69143 .53018 Mtetra
.69143 .53018 .69634 .53589 .70677 .53277 .70189 .52704 Mtetra
.70189 .52704 .70677 .53277 .71724 .52964 .71238 .52389 Mtetra
.71238 .52389 .71724 .52964 .72774 .5265 .72292 .52072 Mtetra
.72292 .52072 .72774 .5265 .73829 .52334 .73349 .51755 Mtetra
.73349 .51755 .73829 .52334 .74887 .52018 .7441 .51436 Mtetra
.7441 .51436 .74887 .52018 .7595 .517 .75475 .51116 Mtetra
.75475 .51116 .7595 .517 .77016 .51381 .76545 .50795 Mtetra
.76545 .50795 .77016 .51381 .78086 .51061 .77618 .50473 Mtetra
.77618 .50473 .78086 .51061 .7916 .5074 .78695 .5015 Mtetra
.78695 .5015 .7916 .5074 .80239 .50418 .79776 .49825 Mtetra
.79776 .49825 .80239 .50418 .81321 .50094 .80861 .495 Mtetra
.80861 .495 .81321 .50094 .82407 .4977 .8195 .49173 Mtetra
.8195 .49173 .82407 .4977 .83498 .49444 .83044 .48845 Mtetra
.83044 .48845 .83498 .49444 .84592 .49117 .84141 .48515 Mtetra
.84141 .48515 .84592 .49117 .85691 .48789 .85243 .48185 Mtetra
.85243 .48185 .85691 .48789 .86794 .48459 .86349 .47853 Mtetra
.86349 .47853 .86794 .48459 .87901 .48129 .87459 .4752 Mtetra
.87459 .4752 .87901 .48129 .89012 .47797 .88573 .47186 Mtetra
.88573 .47186 .89012 .47797 .90127 .47464 .89691 .46851 Mtetra
.89691 .46851 .90127 .47464 .91247 .47129 .90814 .46514 Mtetra
.90814 .46514 .91247 .47129 .9237 .46794 .91941 .46176 Mtetra
.91941 .46176 .9237 .46794 .93499 .46457 .93072 .45837 Mtetra
.639 .74 .922 r
.32397 .63447 .32974 .6397 .33888 .63741 .33314 .63211 Mtetra
.629 .735 .924 r
.33314 .63211 .33888 .63741 .34803 .63569 .34233 .62995 Mtetra
.515 .679 .94 r
.34233 .62995 .34803 .63569 .35908 .59566 .35145 .62988 Mtetra
.427 .168 .417 r
.35145 .62988 .35908 .59566 .36669 .6269 .36106 .62028 Mtetra
.568 .668 .906 r
.36106 .62028 .36669 .6269 .37595 .62496 .37028 .61954 Mtetra
.637 .736 .92 r
.37028 .61954 .37595 .62496 .38527 .62246 .37961 .6172 Mtetra
.648 .745 .92 r
.37961 .6172 .38527 .62246 .39462 .61978 .38898 .61457 Mtetra
.653 .749 .92 r
.38898 .61457 .39462 .61978 .40401 .61702 .39839 .61183 Mtetra
.656 .751 .92 r
.39839 .61183 .40401 .61702 .41344 .6142 .40784 .60901 Mtetra
.657 .752 .92 r
.40784 .60901 .41344 .6142 .4229 .61133 .41732 .60614 Mtetra
.658 .753 .92 r
.41732 .60614 .4229 .61133 .4324 .60843 .42684 .60323 Mtetra
.659 .754 .92 r
.42684 .60323 .4324 .60843 .44193 .60552 .43639 .6003 Mtetra
.43639 .6003 .44193 .60552 .45149 .6026 .44597 .59736 Mtetra
.44597 .59736 .45149 .6026 .46108 .59967 .45559 .59441 Mtetra
.659 .753 .92 r
.45559 .59441 .46108 .59967 .47071 .59674 .46524 .59145 Mtetra
.658 .753 .92 r
.46524 .59145 .47071 .59674 .48037 .5938 .47492 .5885 Mtetra
.47492 .5885 .48037 .5938 .49007 .59086 .48464 .58553 Mtetra
.48464 .58553 .49007 .59086 .4998 .58791 .49439 .58257 Mtetra
.49439 .58257 .4998 .58791 .50956 .58496 .50418 .57959 Mtetra
.50418 .57959 .50956 .58496 .51936 .582 .514 .57661 Mtetra
.514 .57661 .51936 .582 .52919 .57903 .52386 .57362 Mtetra
.657 .753 .92 r
.52386 .57362 .52919 .57903 .53906 .57605 .53375 .57062 Mtetra
.53375 .57062 .53906 .57605 .54897 .57306 .54368 .56761 Mtetra
.54368 .56761 .54897 .57306 .55891 .57006 .55364 .56459 Mtetra
.657 .752 .92 r
.55364 .56459 .55891 .57006 .56888 .56706 .56364 .56156 Mtetra
.56364 .56156 .56888 .56706 .57889 .56404 .57367 .55853 Mtetra
.57367 .55853 .57889 .56404 .58894 .56101 .58375 .55548 Mtetra
.58375 .55548 .58894 .56101 .59902 .55798 .59385 .55242 Mtetra
.59385 .55242 .59902 .55798 .60914 .55493 .604 .54936 Mtetra
.604 .54936 .60914 .55493 .6193 .55188 .61418 .54628 Mtetra
.61418 .54628 .6193 .55188 .62949 .54881 .6244 .54319 Mtetra
.6244 .54319 .62949 .54881 .63972 .54573 .63465 .54009 Mtetra
.63465 .54009 .63972 .54573 .64999 .54264 .64494 .53698 Mtetra
.64494 .53698 .64999 .54264 .66029 .53954 .65527 .53386 Mtetra
.65527 .53386 .66029 .53954 .67063 .53644 .66564 .53073 Mtetra
.66564 .53073 .67063 .53644 .68101 .53332 .67605 .52759 Mtetra
.67605 .52759 .68101 .53332 .69143 .53018 .68649 .52444 Mtetra
.68649 .52444 .69143 .53018 .70189 .52704 .69698 .52128 Mtetra
.69698 .52128 .70189 .52704 .71238 .52389 .7075 .5181 Mtetra
.7075 .5181 .71238 .52389 .72292 .52072 .71806 .51491 Mtetra
.71806 .51491 .72292 .52072 .73349 .51755 .72866 .51172 Mtetra
.72866 .51172 .73349 .51755 .7441 .51436 .7393 .50851 Mtetra
.7393 .50851 .7441 .51436 .75475 .51116 .74998 .50529 Mtetra
.74998 .50529 .75475 .51116 .76545 .50795 .7607 .50206 Mtetra
.7607 .50206 .76545 .50795 .77618 .50473 .77146 .49881 Mtetra
.77146 .49881 .77618 .50473 .78695 .5015 .78226 .49556 Mtetra
.78226 .49556 .78695 .5015 .79776 .49825 .7931 .49229 Mtetra
.7931 .49229 .79776 .49825 .80861 .495 .80398 .48901 Mtetra
.80398 .48901 .80861 .495 .8195 .49173 .8149 .48572 Mtetra
.8149 .48572 .8195 .49173 .83044 .48845 .82586 .48241 Mtetra
.82586 .48241 .83044 .48845 .84141 .48515 .83687 .4791 Mtetra
.83687 .4791 .84141 .48515 .85243 .48185 .84791 .47577 Mtetra
.84791 .47577 .85243 .48185 .86349 .47853 .859 .47243 Mtetra
.859 .47243 .86349 .47853 .87459 .4752 .87013 .46908 Mtetra
.87013 .46908 .87459 .4752 .88573 .47186 .88131 .46571 Mtetra
.88131 .46571 .88573 .47186 .89691 .46851 .89252 .46233 Mtetra
.89252 .46233 .89691 .46851 .90814 .46514 .90378 .45894 Mtetra
.90378 .45894 .90814 .46514 .91941 .46176 .91508 .45554 Mtetra
.91508 .45554 .91941 .46176 .93072 .45837 .92643 .45212 Mtetra
.64 .74 .921 r
.31816 .62921 .32397 .63447 .33314 .63211 .32735 .62682 Mtetra
.637 .739 .922 r
.32735 .62682 .33314 .63211 .34233 .62995 .33656 .62449 Mtetra
.609 .725 .927 r
.33656 .62449 .34233 .62995 .35145 .62988 .34579 .62273 Mtetra
.904 .712 .634 r
.34579 .62273 .35145 .62988 .36106 .62028 .35694 .58249 Mtetra
.006 .005 .503 r
.35694 .58249 .36106 .62028 .37028 .61954 .36459 .61383 Mtetra
.621 .721 .918 r
.36459 .61383 .37028 .61954 .37961 .6172 .37392 .61184 Mtetra
.644 .742 .92 r
.37392 .61184 .37961 .6172 .38898 .61457 .38331 .6093 Mtetra
.651 .747 .92 r
.38331 .6093 .38898 .61457 .39839 .61183 .39274 .60658 Mtetra
.654 .75 .92 r
.39274 .60658 .39839 .61183 .40784 .60901 .40221 .60377 Mtetra
.657 .752 .92 r
.40221 .60377 .40784 .60901 .41732 .60614 .41171 .6009 Mtetra
.658 .753 .92 r
.41171 .6009 .41732 .60614 .42684 .60323 .42124 .59799 Mtetra
.659 .753 .92 r
.42124 .59799 .42684 .60323 .43639 .6003 .43082 .59504 Mtetra
.659 .754 .92 r
.43082 .59504 .43639 .6003 .44597 .59736 .44042 .59208 Mtetra
.44042 .59208 .44597 .59736 .45559 .59441 .45006 .58911 Mtetra
.45006 .58911 .45559 .59441 .46524 .59145 .45973 .58613 Mtetra
.658 .753 .92 r
.45973 .58613 .46524 .59145 .47492 .5885 .46944 .58315 Mtetra
.46944 .58315 .47492 .5885 .48464 .58553 .47918 .58017 Mtetra
.47918 .58017 .48464 .58553 .49439 .58257 .48895 .57718 Mtetra
.48895 .57718 .49439 .58257 .50418 .57959 .49876 .57419 Mtetra
.49876 .57419 .50418 .57959 .514 .57661 .50861 .57118 Mtetra
.50861 .57118 .514 .57661 .52386 .57362 .51849 .56817 Mtetra
.51849 .56817 .52386 .57362 .53375 .57062 .5284 .56515 Mtetra
.657 .753 .92 r
.5284 .56515 .53375 .57062 .54368 .56761 .53835 .56212 Mtetra
.53835 .56212 .54368 .56761 .55364 .56459 .54834 .55908 Mtetra
.657 .752 .92 r
.54834 .55908 .55364 .56459 .56364 .56156 .55836 .55603 Mtetra
.55836 .55603 .56364 .56156 .57367 .55853 .56842 .55298 Mtetra
.56842 .55298 .57367 .55853 .58375 .55548 .57852 .54991 Mtetra
.57852 .54991 .58375 .55548 .59385 .55242 .58865 .54683 Mtetra
.58865 .54683 .59385 .55242 .604 .54936 .59882 .54374 Mtetra
.59882 .54374 .604 .54936 .61418 .54628 .60902 .54064 Mtetra
.60902 .54064 .61418 .54628 .6244 .54319 .61927 .53754 Mtetra
.61927 .53754 .6244 .54319 .63465 .54009 .62955 .53442 Mtetra
.62955 .53442 .63465 .54009 .64494 .53698 .63987 .53129 Mtetra
.63987 .53129 .64494 .53698 .65527 .53386 .65022 .52814 Mtetra
.65022 .52814 .65527 .53386 .66564 .53073 .66062 .52499 Mtetra
.66062 .52499 .66564 .53073 .67605 .52759 .67105 .52183 Mtetra
.67105 .52183 .67605 .52759 .68649 .52444 .68152 .51866 Mtetra
.68152 .51866 .68649 .52444 .69698 .52128 .69203 .51547 Mtetra
.69203 .51547 .69698 .52128 .7075 .5181 .70258 .51227 Mtetra
.70258 .51227 .7075 .5181 .71806 .51491 .71317 .50906 Mtetra
.71317 .50906 .71806 .51491 .72866 .51172 .7238 .50584 Mtetra
.7238 .50584 .72866 .51172 .7393 .50851 .73447 .50261 Mtetra
.73447 .50261 .7393 .50851 .74998 .50529 .74517 .49937 Mtetra
.74517 .49937 .74998 .50529 .7607 .50206 .75592 .49612 Mtetra
.75592 .49612 .7607 .50206 .77146 .49881 .76671 .49285 Mtetra
.76671 .49285 .77146 .49881 .78226 .49556 .77754 .48957 Mtetra
.77754 .48957 .78226 .49556 .7931 .49229 .78841 .48628 Mtetra
.78841 .48628 .7931 .49229 .80398 .48901 .79932 .48298 Mtetra
.79932 .48298 .80398 .48901 .8149 .48572 .81027 .47966 Mtetra
.81027 .47966 .8149 .48572 .82586 .48241 .82126 .47634 Mtetra
.82126 .47634 .82586 .48241 .83687 .4791 .83229 .473 Mtetra
.83229 .473 .83687 .4791 .84791 .47577 .84337 .46965 Mtetra
.84337 .46965 .84791 .47577 .859 .47243 .85449 .46628 Mtetra
.85449 .46628 .859 .47243 .87013 .46908 .86565 .4629 Mtetra
.86565 .4629 .87013 .46908 .88131 .46571 .87685 .45951 Mtetra
.87685 .45951 .88131 .46571 .89252 .46233 .8881 .45611 Mtetra
.8881 .45611 .89252 .46233 .90378 .45894 .89939 .4527 Mtetra
.89939 .4527 .90378 .45894 .91508 .45554 .91072 .44927 Mtetra
.91072 .44927 .91508 .45554 .92643 .45212 .9221 .44583 Mtetra
.639 .739 .921 r
.31232 .62389 .31816 .62921 .32735 .62682 .32152 .62151 Mtetra
.639 .74 .922 r
.32152 .62151 .32735 .62682 .33656 .62449 .33076 .6191 Mtetra
.629 .735 .924 r
.33076 .6191 .33656 .62449 .34579 .62273 .34002 .6169 Mtetra
.516 .679 .939 r
.34002 .6169 .34579 .62273 .35694 .58249 .34921 .61679 Mtetra
.422 .162 .412 r
.34921 .61679 .35694 .58249 .36459 .61383 .35891 .60712 Mtetra
.568 .668 .906 r
.35891 .60712 .36459 .61383 .37392 .61184 .3682 .60635 Mtetra
.637 .736 .92 r
.3682 .60635 .37392 .61184 .38331 .6093 .3776 .60395 Mtetra
.648 .745 .92 r
.3776 .60395 .38331 .6093 .39274 .60658 .38705 .60128 Mtetra
.653 .749 .92 r
.38705 .60128 .39274 .60658 .40221 .60377 .39653 .59849 Mtetra
.656 .751 .92 r
.39653 .59849 .40221 .60377 .41171 .6009 .40606 .59563 Mtetra
.657 .752 .92 r
.40606 .59563 .41171 .6009 .42124 .59799 .41561 .59271 Mtetra
.658 .753 .92 r
.41561 .59271 .42124 .59799 .43082 .59504 .42521 .58975 Mtetra
.659 .754 .92 r
.42521 .58975 .43082 .59504 .44042 .59208 .43483 .58677 Mtetra
.43483 .58677 .44042 .59208 .45006 .58911 .44449 .58378 Mtetra
.44449 .58378 .45006 .58911 .45973 .58613 .45419 .58078 Mtetra
.659 .753 .92 r
.45419 .58078 .45973 .58613 .46944 .58315 .46392 .57778 Mtetra
.658 .753 .92 r
.46392 .57778 .46944 .58315 .47918 .58017 .47368 .57477 Mtetra
.47368 .57477 .47918 .58017 .48895 .57718 .48348 .57176 Mtetra
.48348 .57176 .48895 .57718 .49876 .57419 .49331 .56874 Mtetra
.49331 .56874 .49876 .57419 .50861 .57118 .50318 .56572 Mtetra
.50318 .56572 .50861 .57118 .51849 .56817 .51308 .56269 Mtetra
.51308 .56269 .51849 .56817 .5284 .56515 .52302 .55965 Mtetra
.657 .753 .92 r
.52302 .55965 .5284 .56515 .53835 .56212 .53299 .5566 Mtetra
.53299 .5566 .53835 .56212 .54834 .55908 .543 .55354 Mtetra
.543 .55354 .54834 .55908 .55836 .55603 .55305 .55047 Mtetra
.657 .752 .92 r
.55305 .55047 .55836 .55603 .56842 .55298 .56313 .54739 Mtetra
.56313 .54739 .56842 .55298 .57852 .54991 .57325 .5443 Mtetra
.57325 .5443 .57852 .54991 .58865 .54683 .58341 .5412 Mtetra
.58341 .5412 .58865 .54683 .59882 .54374 .59361 .53809 Mtetra
.59361 .53809 .59882 .54374 .60902 .54064 .60384 .53497 Mtetra
.60384 .53497 .60902 .54064 .61927 .53754 .61411 .53184 Mtetra
.61411 .53184 .61927 .53754 .62955 .53442 .62441 .5287 Mtetra
.62441 .5287 .62955 .53442 .63987 .53129 .63476 .52555 Mtetra
.63476 .52555 .63987 .53129 .65022 .52814 .64514 .52239 Mtetra
.64514 .52239 .65022 .52814 .66062 .52499 .65556 .51921 Mtetra
.65556 .51921 .66062 .52499 .67105 .52183 .66602 .51603 Mtetra
.66602 .51603 .67105 .52183 .68152 .51866 .67652 .51283 Mtetra
.67652 .51283 .68152 .51866 .69203 .51547 .68705 .50962 Mtetra
.68705 .50962 .69203 .51547 .70258 .51227 .69763 .5064 Mtetra
.69763 .5064 .70258 .51227 .71317 .50906 .70825 .50317 Mtetra
.70825 .50317 .71317 .50906 .7238 .50584 .7189 .49993 Mtetra
.7189 .49993 .7238 .50584 .73447 .50261 .7296 .49668 Mtetra
.7296 .49668 .73447 .50261 .74517 .49937 .74033 .49341 Mtetra
.74033 .49341 .74517 .49937 .75592 .49612 .75111 .49014 Mtetra
.75111 .49014 .75592 .49612 .76671 .49285 .76192 .48685 Mtetra
.76192 .48685 .76671 .49285 .77754 .48957 .77278 .48354 Mtetra
.77278 .48354 .77754 .48957 .78841 .48628 .78368 .48023 Mtetra
.78368 .48023 .78841 .48628 .79932 .48298 .79462 .47691 Mtetra
.79462 .47691 .79932 .48298 .81027 .47966 .8056 .47357 Mtetra
.8056 .47357 .81027 .47966 .82126 .47634 .81662 .47022 Mtetra
.81662 .47022 .82126 .47634 .83229 .473 .82769 .46685 Mtetra
.82769 .46685 .83229 .473 .84337 .46965 .83879 .46348 Mtetra
.83879 .46348 .84337 .46965 .85449 .46628 .84994 .46009 Mtetra
.84994 .46009 .85449 .46628 .86565 .4629 .86114 .45669 Mtetra
.86114 .45669 .86565 .4629 .87685 .45951 .87237 .45328 Mtetra
.87237 .45328 .87685 .45951 .8881 .45611 .88365 .44985 Mtetra
.88365 .44985 .8881 .45611 .89939 .4527 .89497 .44641 Mtetra
.89497 .44641 .89939 .4527 .91072 .44927 .90634 .44296 Mtetra
.90634 .44296 .91072 .44927 .9221 .44583 .91775 .43949 Mtetra
.635 .736 .921 r
.30645 .61847 .31232 .62389 .32152 .62151 .31566 .61616 Mtetra
.64 .74 .921 r
.31566 .61616 .32152 .62151 .33076 .6191 .32492 .61372 Mtetra
.637 .739 .922 r
.32492 .61372 .33076 .6191 .34002 .6169 .33421 .61135 Mtetra
.609 .725 .927 r
.33421 .61135 .34002 .6169 .34921 .61679 .3435 .60955 Mtetra
.905 .713 .633 r
.3435 .60955 .34921 .61679 .35891 .60712 .35477 .5691 Mtetra
0 .001 .501 r
.35477 .5691 .35891 .60712 .3682 .60635 .36245 .60055 Mtetra
.621 .721 .918 r
.36245 .60055 .3682 .60635 .3776 .60395 .37186 .59851 Mtetra
.644 .742 .92 r
.37186 .59851 .3776 .60395 .38705 .60128 .38132 .59592 Mtetra
.651 .747 .92 r
.38132 .59592 .38705 .60128 .39653 .59849 .39082 .59316 Mtetra
.654 .75 .92 r
.39082 .59316 .39653 .59849 .40606 .59563 .40037 .5903 Mtetra
.657 .752 .92 r
.40037 .5903 .40606 .59563 .41561 .59271 .40994 .58738 Mtetra
.658 .753 .92 r
.40994 .58738 .41561 .59271 .42521 .58975 .41956 .58442 Mtetra
.659 .753 .92 r
.41956 .58442 .42521 .58975 .43483 .58677 .42921 .58143 Mtetra
.659 .754 .92 r
.42921 .58143 .43483 .58677 .44449 .58378 .43889 .57842 Mtetra
.43889 .57842 .44449 .58378 .45419 .58078 .44861 .5754 Mtetra
.44861 .5754 .45419 .58078 .46392 .57778 .45836 .57237 Mtetra
.658 .753 .92 r
.45836 .57237 .46392 .57778 .47368 .57477 .46814 .56934 Mtetra
.46814 .56934 .47368 .57477 .48348 .57176 .47796 .56631 Mtetra
.47796 .56631 .48348 .57176 .49331 .56874 .48782 .56327 Mtetra
.48782 .56327 .49331 .56874 .50318 .56572 .49771 .56022 Mtetra
.49771 .56022 .50318 .56572 .51308 .56269 .50764 .55717 Mtetra
.50764 .55717 .51308 .56269 .52302 .55965 .5176 .55411 Mtetra
.5176 .55411 .52302 .55965 .53299 .5566 .5276 .55103 Mtetra
.657 .753 .92 r
.5276 .55103 .53299 .5566 .543 .55354 .53763 .54795 Mtetra
.53763 .54795 .543 .55354 .55305 .55047 .5477 .54486 Mtetra
.657 .752 .92 r
.5477 .54486 .55305 .55047 .56313 .54739 .55781 .54176 Mtetra
.55781 .54176 .56313 .54739 .57325 .5443 .56796 .53865 Mtetra
.56796 .53865 .57325 .5443 .58341 .5412 .57814 .53553 Mtetra
.57814 .53553 .58341 .5412 .59361 .53809 .58836 .5324 Mtetra
.58836 .5324 .59361 .53809 .60384 .53497 .59861 .52926 Mtetra
.59861 .52926 .60384 .53497 .61411 .53184 .60891 .52611 Mtetra
.60891 .52611 .61411 .53184 .62441 .5287 .61924 .52295 Mtetra
.61924 .52295 .62441 .5287 .63476 .52555 .62961 .51977 Mtetra
.62961 .51977 .63476 .52555 .64514 .52239 .64002 .51659 Mtetra
.64002 .51659 .64514 .52239 .65556 .51921 .65047 .51339 Mtetra
.65047 .51339 .65556 .51921 .66602 .51603 .66095 .51019 Mtetra
.66095 .51019 .66602 .51603 .67652 .51283 .67148 .50697 Mtetra
.67148 .50697 .67652 .51283 .68705 .50962 .68204 .50374 Mtetra
.68204 .50374 .68705 .50962 .69763 .5064 .69264 .5005 Mtetra
.69264 .5005 .69763 .5064 .70825 .50317 .70329 .49724 Mtetra
.70329 .49724 .70825 .50317 .7189 .49993 .71397 .49398 Mtetra
.71397 .49398 .7189 .49993 .7296 .49668 .72469 .4907 Mtetra
.72469 .4907 .7296 .49668 .74033 .49341 .73546 .48741 Mtetra
.73546 .48741 .74033 .49341 .75111 .49014 .74626 .48411 Mtetra
.74626 .48411 .75111 .49014 .76192 .48685 .75711 .4808 Mtetra
.75711 .4808 .76192 .48685 .77278 .48354 .76799 .47748 Mtetra
.76799 .47748 .77278 .48354 .78368 .48023 .77892 .47414 Mtetra
.77892 .47414 .78368 .48023 .79462 .47691 .78989 .47079 Mtetra
.78989 .47079 .79462 .47691 .8056 .47357 .8009 .46743 Mtetra
.8009 .46743 .8056 .47357 .81662 .47022 .81195 .46405 Mtetra
.81195 .46405 .81662 .47022 .82769 .46685 .82305 .46067 Mtetra
.82305 .46067 .82769 .46685 .83879 .46348 .83418 .45727 Mtetra
.83418 .45727 .83879 .46348 .84994 .46009 .84536 .45386 Mtetra
.84536 .45386 .84994 .46009 .86114 .45669 .85659 .45043 Mtetra
.85659 .45043 .86114 .45669 .87237 .45328 .86785 .44699 Mtetra
.86785 .44699 .87237 .45328 .88365 .44985 .87916 .44354 Mtetra
.87916 .44354 .88365 .44985 .89497 .44641 .89052 .44008 Mtetra
.89052 .44008 .89497 .44641 .90634 .44296 .90192 .4366 Mtetra
.90192 .4366 .90634 .44296 .91775 .43949 .91336 .43311 Mtetra
.626 .728 .92 r
.30054 .61288 .30645 .61847 .31566 .61616 .30976 .61075 Mtetra
.639 .739 .921 r
.30976 .61075 .31566 .61616 .32492 .61372 .31904 .60833 Mtetra
.639 .74 .922 r
.31904 .60833 .32492 .61372 .33421 .61135 .32835 .60587 Mtetra
.629 .735 .924 r
.32835 .60587 .33421 .61135 .3435 .60955 .33768 .60364 Mtetra
.516 .679 .939 r
.33768 .60364 .3435 .60955 .35477 .5691 .34694 .60349 Mtetra
.417 .155 .407 r
.34694 .60349 .35477 .5691 .36245 .60055 .35672 .59374 Mtetra
.568 .668 .906 r
.35672 .59374 .36245 .60055 .37186 .59851 .36608 .59293 Mtetra
.637 .736 .92 r
.36608 .59293 .37186 .59851 .38132 .59592 .37556 .59049 Mtetra
.648 .745 .92 r
.37556 .59049 .38132 .59592 .39082 .59316 .38508 .58777 Mtetra
.653 .749 .92 r
.38508 .58777 .39082 .59316 .40037 .5903 .39464 .58493 Mtetra
.656 .751 .92 r
.39464 .58493 .40037 .5903 .40994 .58738 .40424 .58202 Mtetra
.657 .752 .92 r
.40424 .58202 .40994 .58738 .41956 .58442 .41387 .57905 Mtetra
.658 .753 .92 r
.41387 .57905 .41956 .58442 .42921 .58143 .42354 .57605 Mtetra
.659 .754 .92 r
.42354 .57605 .42921 .58143 .43889 .57842 .43325 .57302 Mtetra
.43325 .57302 .43889 .57842 .44861 .5754 .44299 .56998 Mtetra
.44299 .56998 .44861 .5754 .45836 .57237 .45276 .56693 Mtetra
.659 .753 .92 r
.45276 .56693 .45836 .57237 .46814 .56934 .46257 .56388 Mtetra
.658 .753 .92 r
.46257 .56388 .46814 .56934 .47796 .56631 .47241 .56082 Mtetra
.47241 .56082 .47796 .56631 .48782 .56327 .48229 .55776 Mtetra
.48229 .55776 .48782 .56327 .49771 .56022 .49221 .55469 Mtetra
.49221 .55469 .49771 .56022 .50764 .55717 .50216 .55161 Mtetra
.50216 .55161 .50764 .55717 .5176 .55411 .51214 .54853 Mtetra
.51214 .54853 .5176 .55411 .5276 .55103 .52217 .54544 Mtetra
.657 .753 .92 r
.52217 .54544 .5276 .55103 .53763 .54795 .53222 .54233 Mtetra
.53222 .54233 .53763 .54795 .5477 .54486 .54232 .53922 Mtetra
.54232 .53922 .5477 .54486 .55781 .54176 .55245 .5361 Mtetra
.657 .752 .92 r
.55245 .5361 .55781 .54176 .56796 .53865 .56262 .53297 Mtetra
.56262 .53297 .56796 .53865 .57814 .53553 .57283 .52983 Mtetra
.57283 .52983 .57814 .53553 .58836 .5324 .58307 .52667 Mtetra
.58307 .52667 .58836 .5324 .59861 .52926 .59335 .52351 Mtetra
.59335 .52351 .59861 .52926 .60891 .52611 .60367 .52034 Mtetra
.60367 .52034 .60891 .52611 .61924 .52295 .61403 .51715 Mtetra
.61403 .51715 .61924 .52295 .62961 .51977 .62443 .51396 Mtetra
.62443 .51396 .62961 .51977 .64002 .51659 .63486 .51075 Mtetra
.63486 .51075 .64002 .51659 .65047 .51339 .64534 .50753 Mtetra
.64534 .50753 .65047 .51339 .66095 .51019 .65585 .5043 Mtetra
.65585 .5043 .66095 .51019 .67148 .50697 .6664 .50106 Mtetra
.6664 .50106 .67148 .50697 .68204 .50374 .67699 .49781 Mtetra
.67699 .49781 .68204 .50374 .69264 .5005 .68762 .49455 Mtetra
.68762 .49455 .69264 .5005 .70329 .49724 .69829 .49127 Mtetra
.69829 .49127 .70329 .49724 .71397 .49398 .709 .48798 Mtetra
.709 .48798 .71397 .49398 .72469 .4907 .71976 .48468 Mtetra
.71976 .48468 .72469 .4907 .73546 .48741 .73055 .48137 Mtetra
.73055 .48137 .73546 .48741 .74626 .48411 .74138 .47805 Mtetra
.74138 .47805 .74626 .48411 .75711 .4808 .75226 .47471 Mtetra
.75226 .47471 .75711 .4808 .76799 .47748 .76317 .47136 Mtetra
.76317 .47136 .76799 .47748 .77892 .47414 .77413 .468 Mtetra
.77413 .468 .77892 .47414 .78989 .47079 .78513 .46463 Mtetra
.78513 .46463 .78989 .47079 .8009 .46743 .79617 .46125 Mtetra
.79617 .46125 .8009 .46743 .81195 .46405 .80725 .45785 Mtetra
.80725 .45785 .81195 .46405 .82305 .46067 .81837 .45444 Mtetra
.81837 .45444 .82305 .46067 .83418 .45727 .82954 .45101 Mtetra
.82954 .45101 .83418 .45727 .84536 .45386 .84075 .44758 Mtetra
.84075 .44758 .84536 .45386 .85659 .45043 .85201 .44413 Mtetra
.85201 .44413 .85659 .45043 .86785 .44699 .86331 .44066 Mtetra
.86331 .44066 .86785 .44699 .87916 .44354 .87465 .43719 Mtetra
.87465 .43719 .87916 .44354 .89052 .44008 .88603 .4337 Mtetra
.88603 .4337 .89052 .44008 .90192 .4366 .89746 .4302 Mtetra
.89746 .4302 .90192 .4366 .91336 .43311 .90894 .42668 Mtetra
.604 .707 .917 r
.29463 .60688 .30054 .61288 .30976 .61075 .30383 .60525 Mtetra
.635 .736 .921 r
.30383 .60525 .30976 .61075 .31904 .60833 .31312 .6029 Mtetra
.64 .74 .921 r
.31312 .6029 .31904 .60833 .32835 .60587 .32245 .60041 Mtetra
.637 .739 .922 r
.32245 .60041 .32835 .60587 .33768 .60364 .33181 .59799 Mtetra
.609 .725 .927 r
.33181 .59799 .33768 .60364 .34694 .60349 .34117 .59615 Mtetra
.906 .714 .632 r
.34117 .59615 .34694 .60349 .35672 .59374 .35256 .5555 Mtetra
0 0 .498 r
.35256 .5555 .35672 .59374 .36608 .59293 .36028 .58704 Mtetra
.621 .721 .918 r
.36028 .58704 .36608 .59293 .37556 .59049 .36976 .58496 Mtetra
.644 .742 .92 r
.36976 .58496 .37556 .59049 .38508 .58777 .3793 .58232 Mtetra
.651 .747 .92 r
.3793 .58232 .38508 .58777 .39464 .58493 .38888 .57951 Mtetra
.654 .75 .92 r
.38888 .57951 .39464 .58493 .40424 .58202 .3985 .57661 Mtetra
.657 .752 .92 r
.3985 .57661 .40424 .58202 .41387 .57905 .40815 .57364 Mtetra
.658 .753 .92 r
.40815 .57364 .41387 .57905 .42354 .57605 .41784 .57063 Mtetra
.659 .753 .92 r
.41784 .57063 .42354 .57605 .43325 .57302 .42757 .56758 Mtetra
.659 .754 .92 r
.42757 .56758 .43325 .57302 .44299 .56998 .43733 .56452 Mtetra
.43733 .56452 .44299 .56998 .45276 .56693 .44713 .56145 Mtetra
.44713 .56145 .45276 .56693 .46257 .56388 .45696 .55837 Mtetra
.658 .753 .92 r
.45696 .55837 .46257 .56388 .47241 .56082 .46683 .55529 Mtetra
.46683 .55529 .47241 .56082 .48229 .55776 .47673 .55221 Mtetra
.47673 .55221 .48229 .55776 .49221 .55469 .48667 .54912 Mtetra
.48667 .54912 .49221 .55469 .50216 .55161 .49664 .54602 Mtetra
.49664 .54602 .50216 .55161 .51214 .54853 .50665 .54291 Mtetra
.50665 .54291 .51214 .54853 .52217 .54544 .5167 .5398 Mtetra
.5167 .5398 .52217 .54544 .53222 .54233 .52678 .53668 Mtetra
.657 .753 .92 r
.52678 .53668 .53222 .54233 .54232 .53922 .5369 .53354 Mtetra
.5369 .53354 .54232 .53922 .55245 .5361 .54706 .5304 Mtetra
.657 .752 .92 r
.54706 .5304 .55245 .5361 .56262 .53297 .55725 .52725 Mtetra
.55725 .52725 .56262 .53297 .57283 .52983 .56748 .52408 Mtetra
.56748 .52408 .57283 .52983 .58307 .52667 .57775 .52091 Mtetra
.57775 .52091 .58307 .52667 .59335 .52351 .58806 .51772 Mtetra
.58806 .51772 .59335 .52351 .60367 .52034 .5984 .51453 Mtetra
.5984 .51453 .60367 .52034 .61403 .51715 .60879 .51132 Mtetra
.60879 .51132 .61403 .51715 .62443 .51396 .61921 .5081 Mtetra
.61921 .5081 .62443 .51396 .63486 .51075 .62967 .50487 Mtetra
.62967 .50487 .63486 .51075 .64534 .50753 .64017 .50163 Mtetra
.64017 .50163 .64534 .50753 .65585 .5043 .65071 .49838 Mtetra
.65071 .49838 .65585 .5043 .6664 .50106 .66129 .49512 Mtetra
.66129 .49512 .6664 .50106 .67699 .49781 .67191 .49184 Mtetra
.67191 .49184 .67699 .49781 .68762 .49455 .68257 .48855 Mtetra
.68257 .48855 .68762 .49455 .69829 .49127 .69327 .48526 Mtetra
.69327 .48526 .69829 .49127 .709 .48798 .704 .48195 Mtetra
.704 .48195 .709 .48798 .71976 .48468 .71478 .47862 Mtetra
.71478 .47862 .71976 .48468 .73055 .48137 .7256 .47529 Mtetra
.7256 .47529 .73055 .48137 .74138 .47805 .73647 .47194 Mtetra
.73647 .47194 .74138 .47805 .75226 .47471 .74737 .46858 Mtetra
.74737 .46858 .75226 .47471 .76317 .47136 .75831 .46521 Mtetra
.75831 .46521 .76317 .47136 .77413 .468 .7693 .46183 Mtetra
.7693 .46183 .77413 .468 .78513 .46463 .78033 .45843 Mtetra
.78033 .45843 .78513 .46463 .79617 .46125 .7914 .45502 Mtetra
.7914 .45502 .79617 .46125 .80725 .45785 .80251 .4516 Mtetra
.80251 .4516 .80725 .45785 .81837 .45444 .81367 .44816 Mtetra
.81367 .44816 .81837 .45444 .82954 .45101 .82487 .44471 Mtetra
.82487 .44471 .82954 .45101 .84075 .44758 .83611 .44125 Mtetra
.83611 .44125 .84075 .44758 .85201 .44413 .8474 .43778 Mtetra
.8474 .43778 .85201 .44413 .86331 .44066 .85873 .43429 Mtetra
.85873 .43429 .86331 .44066 .87465 .43719 .8701 .43079 Mtetra
.8701 .43079 .87465 .43719 .88603 .4337 .88152 .42728 Mtetra
.88152 .42728 .88603 .4337 .89746 .4302 .89298 .42375 Mtetra
.89298 .42375 .89746 .4302 .90894 .42668 .90449 .42021 Mtetra
.503 .605 .888 r
.28881 .59894 .29463 .60688 .30383 .60525 .29787 .59957 Mtetra
.626 .728 .92 r
.29787 .59957 .30383 .60525 .31312 .6029 .30716 .5974 Mtetra
.639 .739 .921 r
.30716 .5974 .31312 .6029 .32245 .60041 .31651 .59493 Mtetra
.639 .74 .922 r
.31651 .59493 .32245 .60041 .33181 .59799 .32589 .59243 Mtetra
.629 .735 .924 r
.32589 .59243 .33181 .59799 .34117 .59615 .3353 .59015 Mtetra
.516 .679 .939 r
.3353 .59015 .34117 .59615 .35256 .5555 .34463 .58996 Mtetra
.412 .149 .401 r
.34463 .58996 .35256 .5555 .36028 .58704 .35449 .58013 Mtetra
.568 .669 .906 r
.35449 .58013 .36028 .58704 .36976 .58496 .36393 .57928 Mtetra
.637 .736 .92 r
.36393 .57928 .36976 .58496 .3793 .58232 .37348 .5768 Mtetra
.648 .745 .92 r
.37348 .5768 .3793 .58232 .38888 .57951 .38308 .57403 Mtetra
.653 .749 .92 r
.38308 .57403 .38888 .57951 .3985 .57661 .39272 .57115 Mtetra
.656 .751 .92 r
.39272 .57115 .3985 .57661 .40815 .57364 .40239 .56818 Mtetra
.657 .752 .92 r
.40239 .56818 .40815 .57364 .41784 .57063 .41211 .56516 Mtetra
.658 .753 .92 r
.41211 .56516 .41784 .57063 .42757 .56758 .42185 .56211 Mtetra
.659 .754 .92 r
.42185 .56211 .42757 .56758 .43733 .56452 .43164 .55903 Mtetra
.43164 .55903 .43733 .56452 .44713 .56145 .44146 .55594 Mtetra
.44146 .55594 .44713 .56145 .45696 .55837 .45131 .55284 Mtetra
.659 .753 .92 r
.45131 .55284 .45696 .55837 .46683 .55529 .4612 .54973 Mtetra
.658 .753 .92 r
.4612 .54973 .46683 .55529 .47673 .55221 .47113 .54663 Mtetra
.47113 .54663 .47673 .55221 .48667 .54912 .48109 .54351 Mtetra
.48109 .54351 .48667 .54912 .49664 .54602 .49109 .54039 Mtetra
.49109 .54039 .49664 .54602 .50665 .54291 .50112 .53726 Mtetra
.50112 .53726 .50665 .54291 .5167 .5398 .51119 .53413 Mtetra
.51119 .53413 .5167 .5398 .52678 .53668 .5213 .53098 Mtetra
.657 .753 .92 r
.5213 .53098 .52678 .53668 .5369 .53354 .53144 .52782 Mtetra
.53144 .52782 .5369 .53354 .54706 .5304 .54162 .52466 Mtetra
.54162 .52466 .54706 .5304 .55725 .52725 .55184 .52148 Mtetra
.657 .752 .92 r
.55184 .52148 .55725 .52725 .56748 .52408 .5621 .5183 Mtetra
.5621 .5183 .56748 .52408 .57775 .52091 .57239 .5151 Mtetra
.57239 .5151 .57775 .52091 .58806 .51772 .58273 .51189 Mtetra
.58273 .51189 .58806 .51772 .5984 .51453 .5931 .50868 Mtetra
.5931 .50868 .5984 .51453 .60879 .51132 .60351 .50545 Mtetra
.60351 .50545 .60879 .51132 .61921 .5081 .61396 .50221 Mtetra
.61396 .50221 .61921 .5081 .62967 .50487 .62444 .49895 Mtetra
.62444 .49895 .62967 .50487 .64017 .50163 .63497 .49569 Mtetra
.63497 .49569 .64017 .50163 .65071 .49838 .64554 .49242 Mtetra
.64554 .49242 .65071 .49838 .66129 .49512 .65614 .48913 Mtetra
.65614 .48913 .66129 .49512 .67191 .49184 .66679 .48583 Mtetra
.66679 .48583 .67191 .49184 .68257 .48855 .67748 .48252 Mtetra
.67748 .48252 .68257 .48855 .69327 .48526 .6882 .4792 Mtetra
.6882 .4792 .69327 .48526 .704 .48195 .69897 .47587 Mtetra
.69897 .47587 .704 .48195 .71478 .47862 .70978 .47252 Mtetra
.70978 .47252 .71478 .47862 .7256 .47529 .72063 .46916 Mtetra
.72063 .46916 .7256 .47529 .73647 .47194 .73152 .46579 Mtetra
.73152 .46579 .73647 .47194 .74737 .46858 .74245 .46241 Mtetra
.74245 .46241 .74737 .46858 .75831 .46521 .75342 .45901 Mtetra
.75342 .45901 .75831 .46521 .7693 .46183 .76444 .4556 Mtetra
.76444 .4556 .7693 .46183 .78033 .45843 .7755 .45218 Mtetra
.7755 .45218 .78033 .45843 .7914 .45502 .7866 .44875 Mtetra
.7866 .44875 .7914 .45502 .80251 .4516 .79774 .4453 Mtetra
.79774 .4453 .80251 .4516 .81367 .44816 .80893 .44184 Mtetra
.80893 .44184 .81367 .44816 .82487 .44471 .82016 .43837 Mtetra
.82016 .43837 .82487 .44471 .83611 .44125 .83143 .43488 Mtetra
.83143 .43488 .83611 .44125 .8474 .43778 .84275 .43138 Mtetra
.84275 .43138 .8474 .43778 .85873 .43429 .85411 .42787 Mtetra
.85411 .42787 .85873 .43429 .8701 .43079 .86552 .42435 Mtetra
.86552 .42435 .8701 .43079 .88152 .42728 .87697 .42081 Mtetra
.87697 .42081 .88152 .42728 .89298 .42375 .88846 .41725 Mtetra
.88846 .41725 .89298 .42375 .90449 .42021 .9 .41369 Mtetra
0 0 0 r
.28147 .61199 .28881 .59894 .29787 .59957 .2919 .59348 Mtetra
.603 .707 .917 r
.2919 .59348 .29787 .59957 .30716 .5974 .30118 .59181 Mtetra
.635 .736 .921 r
.30118 .59181 .30716 .5974 .31651 .59493 .31054 .58941 Mtetra
.64 .74 .921 r
.31054 .58941 .31651 .59493 .32589 .59243 .31994 .58688 Mtetra
.637 .739 .922 r
.31994 .58688 .32589 .59243 .3353 .59015 .32937 .58441 Mtetra
.609 .725 .927 r
.32937 .58441 .3353 .59015 .34463 .58996 .33881 .58253 Mtetra
.907 .714 .631 r
.33881 .58253 .34463 .58996 .35449 .58013 .35031 .54166 Mtetra
0 0 .495 r
.35031 .54166 .35449 .58013 .36393 .57928 .35807 .5733 Mtetra
.621 .721 .918 r
.35807 .5733 .36393 .57928 .37348 .5768 .36762 .57118 Mtetra
.644 .742 .92 r
.36762 .57118 .37348 .5768 .38308 .57403 .37724 .56849 Mtetra
.651 .747 .92 r
.37724 .56849 .38308 .57403 .39272 .57115 .3869 .56563 Mtetra
.654 .75 .92 r
.3869 .56563 .39272 .57115 .40239 .56818 .39659 .56268 Mtetra
.657 .752 .92 r
.39659 .56268 .40239 .56818 .41211 .56516 .40633 .55966 Mtetra
.658 .753 .92 r
.40633 .55966 .41211 .56516 .42185 .56211 .4161 .5566 Mtetra
.659 .753 .92 r
.4161 .5566 .42185 .56211 .43164 .55903 .42591 .5535 Mtetra
.659 .754 .92 r
.42591 .5535 .43164 .55903 .44146 .55594 .43575 .55039 Mtetra
.43575 .55039 .44146 .55594 .45131 .55284 .44563 .54727 Mtetra
.44563 .54727 .45131 .55284 .4612 .54973 .45554 .54414 Mtetra
.658 .753 .92 r
.45554 .54414 .4612 .54973 .47113 .54663 .46549 .54101 Mtetra
.46549 .54101 .47113 .54663 .48109 .54351 .47547 .53787 Mtetra
.47547 .53787 .48109 .54351 .49109 .54039 .48549 .53472 Mtetra
.48549 .53472 .49109 .54039 .50112 .53726 .49555 .53157 Mtetra
.49555 .53157 .50112 .53726 .51119 .53413 .50565 .52841 Mtetra
.50565 .52841 .51119 .53413 .5213 .53098 .51578 .52524 Mtetra
.51578 .52524 .5213 .53098 .53144 .52782 .52595 .52207 Mtetra
.657 .753 .92 r
.52595 .52207 .53144 .52782 .54162 .52466 .53615 .51888 Mtetra
.53615 .51888 .54162 .52466 .55184 .52148 .5464 .51568 Mtetra
.657 .752 .92 r
.5464 .51568 .55184 .52148 .5621 .5183 .55668 .51247 Mtetra
.55668 .51247 .5621 .5183 .57239 .5151 .567 .50925 Mtetra
.567 .50925 .57239 .5151 .58273 .51189 .57736 .50602 Mtetra
.57736 .50602 .58273 .51189 .5931 .50868 .58776 .50278 Mtetra
.58776 .50278 .5931 .50868 .60351 .50545 .59819 .49953 Mtetra
.59819 .49953 .60351 .50545 .61396 .50221 .60867 .49627 Mtetra
.60867 .49627 .61396 .50221 .62444 .49895 .61918 .49299 Mtetra
.61918 .49299 .62444 .49895 .63497 .49569 .62973 .48971 Mtetra
.62973 .48971 .63497 .49569 .64554 .49242 .64033 .48641 Mtetra
.64033 .48641 .64554 .49242 .65614 .48913 .65096 .4831 Mtetra
.65096 .4831 .65614 .48913 .66679 .48583 .66163 .47978 Mtetra
.66163 .47978 .66679 .48583 .67748 .48252 .67235 .47645 Mtetra
.67235 .47645 .67748 .48252 .6882 .4792 .6831 .4731 Mtetra
.6831 .4731 .6882 .4792 .69897 .47587 .6939 .46974 Mtetra
.6939 .46974 .69897 .47587 .70978 .47252 .70474 .46637 Mtetra
.70474 .46637 .70978 .47252 .72063 .46916 .71561 .46299 Mtetra
.71561 .46299 .72063 .46916 .73152 .46579 .72653 .4596 Mtetra
.72653 .4596 .73152 .46579 .74245 .46241 .73749 .45619 Mtetra
.73749 .45619 .74245 .46241 .75342 .45901 .7485 .45277 Mtetra
.7485 .45277 .75342 .45901 .76444 .4556 .75954 .44934 Mtetra
.75954 .44934 .76444 .4556 .7755 .45218 .77063 .44589 Mtetra
.77063 .44589 .7755 .45218 .7866 .44875 .78176 .44243 Mtetra
.78176 .44243 .7866 .44875 .79774 .4453 .79294 .43896 Mtetra
.79294 .43896 .79774 .4453 .80893 .44184 .80415 .43548 Mtetra
.80415 .43548 .80893 .44184 .82016 .43837 .81542 .43198 Mtetra
.81542 .43198 .82016 .43837 .83143 .43488 .82672 .42847 Mtetra
.82672 .42847 .83143 .43488 .84275 .43138 .83807 .42494 Mtetra
.83807 .42494 .84275 .43138 .85411 .42787 .84946 .4214 Mtetra
.84946 .4214 .85411 .42787 .86552 .42435 .8609 .41785 Mtetra
.8609 .41785 .86552 .42435 .87697 .42081 .87238 .41429 Mtetra
.87238 .41429 .87697 .42081 .88846 .41725 .88391 .41071 Mtetra
.88391 .41071 .88846 .41725 .9 .41369 .89549 .40712 Mtetra
.719 .584 .704 r
.27617 .59551 .28147 .61199 .2919 .59348 .28603 .58544 Mtetra
.502 .605 .888 r
.28603 .58544 .2919 .59348 .30118 .59181 .29516 .58604 Mtetra
.626 .728 .92 r
.29516 .58604 .30118 .59181 .31054 .58941 .30452 .58382 Mtetra
.639 .739 .921 r
.30452 .58382 .31054 .58941 .31994 .58688 .31394 .58131 Mtetra
.639 .74 .922 r
.31394 .58131 .31994 .58688 .32937 .58441 .3234 .57876 Mtetra
.629 .735 .924 r
.3234 .57876 .32937 .58441 .33881 .58253 .33288 .57643 Mtetra
.517 .679 .939 r
.33288 .57643 .33881 .58253 .35031 .54166 .34228 .57621 Mtetra
.407 .142 .396 r
.34228 .57621 .35031 .54166 .35807 .5733 .35223 .5663 Mtetra
.568 .669 .906 r
.35223 .5663 .35807 .5733 .36762 .57118 .36174 .56541 Mtetra
.637 .736 .92 r
.36174 .56541 .36762 .57118 .37724 .56849 .37136 .56288 Mtetra
.648 .745 .92 r
.37136 .56288 .37724 .56849 .3869 .56563 .38104 .56006 Mtetra
.653 .749 .92 r
.38104 .56006 .3869 .56563 .39659 .56268 .39076 .55712 Mtetra
.656 .751 .92 r
.39076 .55712 .39659 .56268 .40633 .55966 .40051 .55411 Mtetra
.657 .752 .92 r
.40051 .55411 .40633 .55966 .4161 .5566 .41031 .55104 Mtetra
.658 .753 .92 r
.41031 .55104 .4161 .5566 .42591 .5535 .42014 .54793 Mtetra
.659 .754 .92 r
.42014 .54793 .42591 .5535 .43575 .55039 .43 .5448 Mtetra
.43 .5448 .43575 .55039 .44563 .54727 .4399 .54166 Mtetra
.4399 .54166 .44563 .54727 .45554 .54414 .44984 .53851 Mtetra
.659 .753 .92 r
.44984 .53851 .45554 .54414 .46549 .54101 .45981 .53535 Mtetra
.658 .753 .92 r
.45981 .53535 .46549 .54101 .47547 .53787 .46982 .53219 Mtetra
.46982 .53219 .47547 .53787 .48549 .53472 .47986 .52902 Mtetra
.47986 .52902 .48549 .53472 .49555 .53157 .48995 .52585 Mtetra
.48995 .52585 .49555 .53157 .50565 .52841 .50007 .52266 Mtetra
.50007 .52266 .50565 .52841 .51578 .52524 .51022 .51947 Mtetra
.51022 .51947 .51578 .52524 .52595 .52207 .52042 .51627 Mtetra
.657 .753 .92 r
.52042 .51627 .52595 .52207 .53615 .51888 .53065 .51306 Mtetra
.53065 .51306 .53615 .51888 .5464 .51568 .54092 .50984 Mtetra
.54092 .50984 .5464 .51568 .55668 .51247 .55122 .50661 Mtetra
.657 .752 .92 r
.55122 .50661 .55668 .51247 .567 .50925 .56157 .50337 Mtetra
.56157 .50337 .567 .50925 .57736 .50602 .57195 .50012 Mtetra
.57195 .50012 .57736 .50602 .58776 .50278 .58238 .49685 Mtetra
.58238 .49685 .58776 .50278 .59819 .49953 .59284 .49358 Mtetra
.59284 .49358 .59819 .49953 .60867 .49627 .60334 .49029 Mtetra
.60334 .49029 .60867 .49627 .61918 .49299 .61388 .48699 Mtetra
.61388 .48699 .61918 .49299 .62973 .48971 .62446 .48368 Mtetra
.62446 .48368 .62973 .48971 .64033 .48641 .63508 .48036 Mtetra
.63508 .48036 .64033 .48641 .65096 .4831 .64574 .47703 Mtetra
.64574 .47703 .65096 .4831 .66163 .47978 .65644 .47369 Mtetra
.65644 .47369 .66163 .47978 .67235 .47645 .66719 .47033 Mtetra
.66719 .47033 .67235 .47645 .6831 .4731 .67797 .46696 Mtetra
.67797 .46696 .6831 .4731 .6939 .46974 .68879 .46358 Mtetra
.68879 .46358 .6939 .46974 .70474 .46637 .69966 .46018 Mtetra
.69966 .46018 .70474 .46637 .71561 .46299 .71056 .45678 Mtetra
.71056 .45678 .71561 .46299 .72653 .4596 .72151 .45336 Mtetra
.72151 .45336 .72653 .4596 .73749 .45619 .7325 .44993 Mtetra
.7325 .44993 .73749 .45619 .7485 .45277 .74354 .44648 Mtetra
.74354 .44648 .7485 .45277 .75954 .44934 .75461 .44303 Mtetra
.75461 .44303 .75954 .44934 .77063 .44589 .76573 .43956 Mtetra
.76573 .43956 .77063 .44589 .78176 .44243 .77689 .43607 Mtetra
.77689 .43607 .78176 .44243 .79294 .43896 .7881 .43258 Mtetra
.7881 .43258 .79294 .43896 .80415 .43548 .79935 .42907 Mtetra
.79935 .42907 .80415 .43548 .81542 .43198 .81064 .42554 Mtetra
.81064 .42554 .81542 .43198 .82672 .42847 .82198 .42201 Mtetra
.82198 .42201 .82672 .42847 .83807 .42494 .83336 .41846 Mtetra
.83336 .41846 .83807 .42494 .84946 .4214 .84478 .41489 Mtetra
.84478 .41489 .84946 .4214 .8609 .41785 .85625 .41131 Mtetra
.85625 .41131 .8609 .41785 .87238 .41429 .86777 .40772 Mtetra
.86777 .40772 .87238 .41429 .88391 .41071 .87933 .40412 Mtetra
.87933 .40412 .88391 .41071 .89549 .40712 .89094 .4005 Mtetra
.549 .064 0 r
.27014 .58883 .27617 .59551 .28603 .58544 .2786 .59848 Mtetra
.624 .793 .355 r
.2786 .59848 .28603 .58544 .29516 .58604 .28913 .57986 Mtetra
.603 .707 .917 r
.28913 .57986 .29516 .58604 .30452 .58382 .29847 .57814 Mtetra
.635 .736 .921 r
.29847 .57814 .30452 .58382 .31394 .58131 .30791 .57569 Mtetra
.64 .74 .921 r
.30791 .57569 .31394 .58131 .3234 .57876 .31738 .57312 Mtetra
.637 .739 .922 r
.31738 .57312 .3234 .57876 .33288 .57643 .32689 .5706 Mtetra
.61 .725 .927 r
.32689 .5706 .33288 .57643 .34228 .57621 .3364 .56867 Mtetra
.908 .715 .63 r
.3364 .56867 .34228 .57621 .35223 .5663 .34802 .5276 Mtetra
0 0 .492 r
.34802 .5276 .35223 .5663 .36174 .56541 .35582 .55933 Mtetra
.621 .721 .918 r
.35582 .55933 .36174 .56541 .37136 .56288 .36545 .55716 Mtetra
.644 .742 .92 r
.36545 .55716 .37136 .56288 .38104 .56006 .37515 .55443 Mtetra
.651 .747 .92 r
.37515 .55443 .38104 .56006 .39076 .55712 .38488 .55152 Mtetra
.654 .75 .92 r
.38488 .55152 .39076 .55712 .40051 .55411 .39466 .54851 Mtetra
.657 .752 .92 r
.39466 .54851 .40051 .55411 .41031 .55104 .40447 .54544 Mtetra
.658 .753 .92 r
.40447 .54544 .41031 .55104 .42014 .54793 .41433 .54232 Mtetra
.659 .753 .92 r
.41433 .54232 .42014 .54793 .43 .5448 .42421 .53918 Mtetra
.659 .754 .92 r
.42421 .53918 .43 .5448 .4399 .54166 .43414 .53601 Mtetra
.43414 .53601 .4399 .54166 .44984 .53851 .4441 .53284 Mtetra
.4441 .53284 .44984 .53851 .45981 .53535 .45409 .52965 Mtetra
.658 .753 .92 r
.45409 .52965 .45981 .53535 .46982 .53219 .46413 .52647 Mtetra
.46413 .52647 .46982 .53219 .47986 .52902 .4742 .52328 Mtetra
.4742 .52328 .47986 .52902 .48995 .52585 .4843 .52008 Mtetra
.4843 .52008 .48995 .52585 .50007 .52266 .49445 .51687 Mtetra
.49445 .51687 .50007 .52266 .51022 .51947 .50463 .51366 Mtetra
.50463 .51366 .51022 .51947 .52042 .51627 .51484 .51044 Mtetra
.51484 .51044 .52042 .51627 .53065 .51306 .5251 .5072 Mtetra
.657 .753 .92 r
.5251 .5072 .53065 .51306 .54092 .50984 .5354 .50396 Mtetra
.5354 .50396 .54092 .50984 .55122 .50661 .54573 .50071 Mtetra
.657 .752 .92 r
.54573 .50071 .55122 .50661 .56157 .50337 .5561 .49744 Mtetra
.5561 .49744 .56157 .50337 .57195 .50012 .56651 .49417 Mtetra
.56651 .49417 .57195 .50012 .58238 .49685 .57696 .49088 Mtetra
.57696 .49088 .58238 .49685 .59284 .49358 .58745 .48758 Mtetra
.58745 .48758 .59284 .49358 .60334 .49029 .59798 .48427 Mtetra
.59798 .48427 .60334 .49029 .61388 .48699 .60854 .48095 Mtetra
.60854 .48095 .61388 .48699 .62446 .48368 .61915 .47762 Mtetra
.61915 .47762 .62446 .48368 .63508 .48036 .6298 .47427 Mtetra
.6298 .47427 .63508 .48036 .64574 .47703 .64049 .47092 Mtetra
.64049 .47092 .64574 .47703 .65644 .47369 .65122 .46755 Mtetra
.65122 .46755 .65644 .47369 .66719 .47033 .66199 .46417 Mtetra
.66199 .46417 .66719 .47033 .67797 .46696 .6728 .46077 Mtetra
.6728 .46077 .67797 .46696 .68879 .46358 .68365 .45737 Mtetra
.68365 .45737 .68879 .46358 .69966 .46018 .69454 .45395 Mtetra
.69454 .45395 .69966 .46018 .71056 .45678 .70548 .45052 Mtetra
.70548 .45052 .71056 .45678 .72151 .45336 .71646 .44708 Mtetra
.71646 .44708 .72151 .45336 .7325 .44993 .72748 .44362 Mtetra
.72748 .44362 .7325 .44993 .74354 .44648 .73854 .44015 Mtetra
.73854 .44015 .74354 .44648 .75461 .44303 .74965 .43667 Mtetra
.74965 .43667 .75461 .44303 .76573 .43956 .7608 .43317 Mtetra
.7608 .43317 .76573 .43956 .77689 .43607 .77199 .42967 Mtetra
.77199 .42967 .77689 .43607 .7881 .43258 .78322 .42614 Mtetra
.78322 .42614 .7881 .43258 .79935 .42907 .7945 .42261 Mtetra
.7945 .42261 .79935 .42907 .81064 .42554 .80583 .41906 Mtetra
.80583 .41906 .81064 .42554 .82198 .42201 .8172 .4155 Mtetra
.8172 .4155 .82198 .42201 .83336 .41846 .82861 .41192 Mtetra
.82861 .41192 .83336 .41846 .84478 .41489 .84007 .40833 Mtetra
.84007 .40833 .84478 .41489 .85625 .41131 .85157 .40473 Mtetra
.85157 .40473 .85625 .41131 .86777 .40772 .86312 .40111 Mtetra
.86312 .40111 .86777 .40772 .87933 .40412 .87471 .39748 Mtetra
.87471 .39748 .87933 .40412 .89094 .4005 .88635 .39383 Mtetra
.562 .701 .934 r
.26402 .58286 .27014 .58883 .2786 .59848 .27326 .58186 Mtetra
.719 .584 .704 r
.27326 .58186 .2786 .59848 .28913 .57986 .2832 .57172 Mtetra
.502 .605 .888 r
.2832 .57172 .28913 .57986 .29847 .57814 .2924 .57228 Mtetra
.626 .728 .92 r
.2924 .57228 .29847 .57814 .30791 .57569 .30183 .57002 Mtetra
.639 .739 .921 r
.30183 .57002 .30791 .57569 .31738 .57312 .31133 .56745 Mtetra
.639 .74 .922 r
.31133 .56745 .31738 .57312 .32689 .5706 .32086 .56486 Mtetra
.629 .735 .924 r
.32086 .56486 .32689 .5706 .3364 .56867 .33042 .56248 Mtetra
.517 .679 .939 r
.33042 .56248 .3364 .56867 .34802 .5276 .33989 .56222 Mtetra
.402 .135 .39 r
.33989 .56222 .34802 .5276 .35582 .55933 .34993 .55223 Mtetra
.568 .669 .906 r
.34993 .55223 .35582 .55933 .36545 .55716 .35951 .5513 Mtetra
.637 .736 .92 r
.35951 .5513 .36545 .55716 .37515 .55443 .36921 .54872 Mtetra
.648 .745 .92 r
.36921 .54872 .37515 .55443 .38488 .55152 .37897 .54585 Mtetra
.653 .749 .92 r
.37897 .54585 .38488 .55152 .39466 .54851 .38877 .54286 Mtetra
.656 .751 .92 r
.38877 .54286 .39466 .54851 .40447 .54544 .3986 .53979 Mtetra
.657 .752 .92 r
.3986 .53979 .40447 .54544 .41433 .54232 .40848 .53667 Mtetra
.658 .753 .92 r
.40848 .53667 .41433 .54232 .42421 .53918 .41839 .53351 Mtetra
.659 .754 .92 r
.41839 .53351 .42421 .53918 .43414 .53601 .42834 .53033 Mtetra
.42834 .53033 .43414 .53601 .4441 .53284 .43832 .52713 Mtetra
.43832 .52713 .4441 .53284 .45409 .52965 .44834 .52392 Mtetra
.659 .753 .92 r
.44834 .52392 .45409 .52965 .46413 .52647 .4584 .52071 Mtetra
.658 .753 .92 r
.4584 .52071 .46413 .52647 .4742 .52328 .46849 .5175 Mtetra
.46849 .5175 .4742 .52328 .4843 .52008 .47862 .51427 Mtetra
.47862 .51427 .4843 .52008 .49445 .51687 .48879 .51104 Mtetra
.48879 .51104 .49445 .51687 .50463 .51366 .49899 .50781 Mtetra
.49899 .50781 .50463 .51366 .51484 .51044 .50924 .50456 Mtetra
.50924 .50456 .51484 .51044 .5251 .5072 .51952 .5013 Mtetra
.657 .753 .92 r
.51952 .5013 .5251 .5072 .5354 .50396 .52984 .49804 Mtetra
.52984 .49804 .5354 .50396 .54573 .50071 .54019 .49476 Mtetra
.54019 .49476 .54573 .50071 .5561 .49744 .55059 .49147 Mtetra
.657 .752 .92 r
.55059 .49147 .5561 .49744 .56651 .49417 .56103 .48817 Mtetra
.56103 .48817 .56651 .49417 .57696 .49088 .5715 .48486 Mtetra
.5715 .48486 .57696 .49088 .58745 .48758 .58202 .48154 Mtetra
.58202 .48154 .58745 .48758 .59798 .48427 .59257 .47821 Mtetra
.59257 .47821 .59798 .48427 .60854 .48095 .60317 .47487 Mtetra
.60317 .47487 .60854 .48095 .61915 .47762 .6138 .47151 Mtetra
.6138 .47151 .61915 .47762 .6298 .47427 .62448 .46814 Mtetra
.62448 .46814 .6298 .47427 .64049 .47092 .63519 .46476 Mtetra
.63519 .46476 .64049 .47092 .65122 .46755 .64595 .46137 Mtetra
.64595 .46137 .65122 .46755 .66199 .46417 .65675 .45796 Mtetra
.65675 .45796 .66199 .46417 .6728 .46077 .66759 .45455 Mtetra
.66759 .45455 .6728 .46077 .68365 .45737 .67847 .45112 Mtetra
.67847 .45112 .68365 .45737 .69454 .45395 .68939 .44767 Mtetra
.68939 .44767 .69454 .45395 .70548 .45052 .70036 .44422 Mtetra
.70036 .44422 .70548 .45052 .71646 .44708 .71137 .44075 Mtetra
.71137 .44075 .71646 .44708 .72748 .44362 .72242 .43727 Mtetra
.72242 .43727 .72748 .44362 .73854 .44015 .73351 .43377 Mtetra
.73351 .43377 .73854 .44015 .74965 .43667 .74464 .43027 Mtetra
.74464 .43027 .74965 .43667 .7608 .43317 .75582 .42675 Mtetra
.75582 .42675 .7608 .43317 .77199 .42967 .76705 .42321 Mtetra
.76705 .42321 .77199 .42967 .78322 .42614 .77831 .41966 Mtetra
.77831 .41966 .78322 .42614 .7945 .42261 .78963 .4161 Mtetra
.78963 .4161 .7945 .42261 .80583 .41906 .80098 .41253 Mtetra
.80098 .41253 .80583 .41906 .8172 .4155 .81238 .40894 Mtetra
.81238 .40894 .8172 .4155 .82861 .41192 .82383 .40534 Mtetra
.82383 .40534 .82861 .41192 .84007 .40833 .83532 .40172 Mtetra
.83532 .40172 .84007 .40833 .85157 .40473 .84685 .39809 Mtetra
.84685 .39809 .85157 .40473 .86312 .40111 .85844 .39445 Mtetra
.85844 .39445 .86312 .40111 .87471 .39748 .87006 .39079 Mtetra
.87006 .39079 .87471 .39748 .88635 .39383 .88174 .38712 Mtetra
.611 .725 .926 r
.25784 .57704 .26402 .58286 .27326 .58186 .26717 .57509 Mtetra
.541 .058 0 r
.26717 .57509 .27326 .58186 .2832 .57172 .27569 .58474 Mtetra
.633 .801 .365 r
.27569 .58474 .2832 .57172 .2924 .57228 .28631 .566 Mtetra
.603 .707 .917 r
.28631 .566 .2924 .57228 .30183 .57002 .29573 .56424 Mtetra
.635 .736 .921 r
.29573 .56424 .30183 .57002 .31133 .56745 .30523 .56175 Mtetra
.64 .74 .921 r
.30523 .56175 .31133 .56745 .32086 .56486 .31479 .55912 Mtetra
.637 .739 .922 r
.31479 .55912 .32086 .56486 .33042 .56248 .32437 .55656 Mtetra
.61 .725 .927 r
.32437 .55656 .33042 .56248 .33989 .56222 .33396 .55458 Mtetra
.909 .716 .629 r
.33396 .55458 .33989 .56222 .34993 .55223 .3457 .51329 Mtetra
0 0 .489 r
.3457 .51329 .34993 .55223 .35951 .5513 .35354 .54512 Mtetra
.621 .721 .918 r
.35354 .54512 .35951 .5513 .36921 .54872 .36325 .54291 Mtetra
.644 .742 .92 r
.36325 .54291 .36921 .54872 .37897 .54585 .37302 .54012 Mtetra
.651 .747 .92 r
.37302 .54012 .37897 .54585 .38877 .54286 .38284 .53716 Mtetra
.654 .75 .92 r
.38284 .53716 .38877 .54286 .3986 .53979 .39269 .5341 Mtetra
.657 .752 .92 r
.39269 .5341 .3986 .53979 .40848 .53667 .40259 .53097 Mtetra
.658 .753 .92 r
.40259 .53097 .40848 .53667 .41839 .53351 .41252 .5278 Mtetra
.659 .753 .92 r
.41252 .5278 .41839 .53351 .42834 .53033 .42249 .5246 Mtetra
.659 .754 .92 r
.42249 .5246 .42834 .53033 .43832 .52713 .4325 .52138 Mtetra
.4325 .52138 .43832 .52713 .44834 .52392 .44254 .51815 Mtetra
.44254 .51815 .44834 .52392 .4584 .52071 .45262 .51492 Mtetra
.658 .753 .92 r
.45262 .51492 .4584 .52071 .46849 .5175 .46274 .51168 Mtetra
.46274 .51168 .46849 .5175 .47862 .51427 .4729 .50843 Mtetra
.4729 .50843 .47862 .51427 .48879 .51104 .48309 .50518 Mtetra
.48309 .50518 .48879 .51104 .49899 .50781 .49332 .50192 Mtetra
.49332 .50192 .49899 .50781 .50924 .50456 .50359 .49864 Mtetra
.50359 .49864 .50924 .50456 .51952 .5013 .51389 .49536 Mtetra
.51389 .49536 .51952 .5013 .52984 .49804 .52424 .49207 Mtetra
.657 .753 .92 r
.52424 .49207 .52984 .49804 .54019 .49476 .53462 .48877 Mtetra
.53462 .48877 .54019 .49476 .55059 .49147 .54505 .48546 Mtetra
.657 .752 .92 r
.54505 .48546 .55059 .49147 .56103 .48817 .55551 .48214 Mtetra
.55551 .48214 .56103 .48817 .5715 .48486 .56601 .47881 Mtetra
.56601 .47881 .5715 .48486 .58202 .48154 .57655 .47546 Mtetra
.57655 .47546 .58202 .48154 .59257 .47821 .58713 .47211 Mtetra
.58713 .47211 .59257 .47821 .60317 .47487 .59776 .46874 Mtetra
.59776 .46874 .60317 .47487 .6138 .47151 .60842 .46536 Mtetra
.60842 .46536 .6138 .47151 .62448 .46814 .61912 .46196 Mtetra
.61912 .46196 .62448 .46814 .63519 .46476 .62986 .45856 Mtetra
.62986 .45856 .63519 .46476 .64595 .46137 .64065 .45514 Mtetra
.64065 .45514 .64595 .46137 .65675 .45796 .65148 .45171 Mtetra
.65148 .45171 .65675 .45796 .66759 .45455 .66234 .44827 Mtetra
.66234 .44827 .66759 .45455 .67847 .45112 .67325 .44482 Mtetra
.67325 .44482 .67847 .45112 .68939 .44767 .68421 .44135 Mtetra
.68421 .44135 .68939 .44767 .70036 .44422 .6952 .43787 Mtetra
.6952 .43787 .70036 .44422 .71137 .44075 .70624 .43438 Mtetra
.70624 .43438 .71137 .44075 .72242 .43727 .71732 .43087 Mtetra
.71732 .43087 .72242 .43727 .73351 .43377 .72844 .42735 Mtetra
.72844 .42735 .73351 .43377 .74464 .43027 .73961 .42382 Mtetra
.73961 .42382 .74464 .43027 .75582 .42675 .75082 .42027 Mtetra
.75082 .42027 .75582 .42675 .76705 .42321 .76207 .41671 Mtetra
.76207 .41671 .76705 .42321 .77831 .41966 .77337 .41314 Mtetra
.77337 .41314 .77831 .41966 .78963 .4161 .78471 .40955 Mtetra
.78471 .40955 .78963 .4161 .80098 .41253 .7961 .40595 Mtetra
.7961 .40595 .80098 .41253 .81238 .40894 .80753 .40234 Mtetra
.80753 .40234 .81238 .40894 .82383 .40534 .81901 .39871 Mtetra
.81901 .39871 .82383 .40534 .83532 .40172 .83053 .39507 Mtetra
.83053 .39507 .83532 .40172 .84685 .39809 .8421 .39141 Mtetra
.8421 .39141 .84685 .39809 .85844 .39445 .85372 .38774 Mtetra
.85372 .38774 .85844 .39445 .87006 .39079 .86538 .38405 Mtetra
.86538 .38405 .87006 .39079 .88174 .38712 .87709 .38035 Mtetra
.624 .731 .924 r
.25161 .57125 .25784 .57704 .26717 .57509 .26098 .56902 Mtetra
.562 .701 .934 r
.26098 .56902 .26717 .57509 .27569 .58474 .2703 .56798 Mtetra
.719 .584 .704 r
.2703 .56798 .27569 .58474 .28631 .566 .28032 .55776 Mtetra
.502 .605 .888 r
.28032 .55776 .28631 .566 .29573 .56424 .28959 .55829 Mtetra
.626 .728 .92 r
.28959 .55829 .29573 .56424 .30523 .56175 .2991 .55597 Mtetra
.639 .739 .921 r
.2991 .55597 .30523 .56175 .31479 .55912 .30867 .55336 Mtetra
.639 .74 .922 r
.30867 .55336 .31479 .55912 .32437 .55656 .31828 .55072 Mtetra
.629 .735 .924 r
.31828 .55072 .32437 .55656 .33396 .55458 .32791 .54829 Mtetra
.517 .679 .939 r
.32791 .54829 .33396 .55458 .3457 .51329 .33746 .54799 Mtetra
.396 .127 .384 r
.33746 .54799 .3457 .51329 .35354 .54512 .34758 .53792 Mtetra
.568 .669 .906 r
.34758 .53792 .35354 .54512 .36325 .54291 .35724 .53694 Mtetra
.637 .736 .92 r
.35724 .53694 .36325 .54291 .37302 .54012 .36703 .53431 Mtetra
.648 .745 .92 r
.36703 .53431 .37302 .54012 .38284 .53716 .37686 .53139 Mtetra
.653 .749 .92 r
.37686 .53139 .38284 .53716 .39269 .5341 .38674 .52835 Mtetra
.656 .751 .92 r
.38674 .52835 .39269 .5341 .40259 .53097 .39666 .52523 Mtetra
.657 .752 .92 r
.39666 .52523 .40259 .53097 .41252 .5278 .40662 .52205 Mtetra
.658 .753 .92 r
.40662 .52205 .41252 .5278 .42249 .5246 .41661 .51884 Mtetra
.659 .754 .92 r
.41661 .51884 .42249 .5246 .4325 .52138 .42664 .5156 Mtetra
.42664 .5156 .4325 .52138 .44254 .51815 .43671 .51235 Mtetra
.43671 .51235 .44254 .51815 .45262 .51492 .44681 .50909 Mtetra
.659 .753 .92 r
.44681 .50909 .45262 .51492 .46274 .51168 .45695 .50582 Mtetra
.658 .753 .92 r
.45695 .50582 .46274 .51168 .4729 .50843 .46713 .50255 Mtetra
.46713 .50255 .4729 .50843 .48309 .50518 .47735 .49927 Mtetra
.47735 .49927 .48309 .50518 .49332 .50192 .48761 .49598 Mtetra
.48761 .49598 .49332 .50192 .50359 .49864 .4979 .49269 Mtetra
.4979 .49269 .50359 .49864 .51389 .49536 .50823 .48938 Mtetra
.50823 .48938 .51389 .49536 .52424 .49207 .5186 .48607 Mtetra
.657 .753 .92 r
.5186 .48607 .52424 .49207 .53462 .48877 .52901 .48275 Mtetra
.52901 .48275 .53462 .48877 .54505 .48546 .53946 .47941 Mtetra
.53946 .47941 .54505 .48546 .55551 .48214 .54995 .47607 Mtetra
.657 .752 .92 r
.54995 .47607 .55551 .48214 .56601 .47881 .56048 .47271 Mtetra
.56048 .47271 .56601 .47881 .57655 .47546 .57105 .46934 Mtetra
.57105 .46934 .57655 .47546 .58713 .47211 .58165 .46596 Mtetra
.58165 .46596 .58713 .47211 .59776 .46874 .5923 .46257 Mtetra
.5923 .46257 .59776 .46874 .60842 .46536 .60299 .45916 Mtetra
.60299 .45916 .60842 .46536 .61912 .46196 .61372 .45575 Mtetra
.61372 .45575 .61912 .46196 .62986 .45856 .6245 .45232 Mtetra
.6245 .45232 .62986 .45856 .64065 .45514 .63531 .44887 Mtetra
.63531 .44887 .64065 .45514 .65148 .45171 .64616 .44542 Mtetra
.64616 .44542 .65148 .45171 .66234 .44827 .65706 .44195 Mtetra
.65706 .44195 .66234 .44827 .67325 .44482 .668 .43847 Mtetra
.668 .43847 .67325 .44482 .68421 .44135 .67898 .43498 Mtetra
.67898 .43498 .68421 .44135 .6952 .43787 .69 .43148 Mtetra
.69 .43148 .6952 .43787 .70624 .43438 .70107 .42796 Mtetra
.70107 .42796 .70624 .43438 .71732 .43087 .71218 .42443 Mtetra
.71218 .42443 .71732 .43087 .72844 .42735 .72333 .42088 Mtetra
.72333 .42088 .72844 .42735 .73961 .42382 .73453 .41732 Mtetra
.73453 .41732 .73961 .42382 .75082 .42027 .74577 .41375 Mtetra
.74577 .41375 .75082 .42027 .76207 .41671 .75706 .41017 Mtetra
.75706 .41017 .76207 .41671 .77337 .41314 .76839 .40657 Mtetra
.76839 .40657 .77337 .41314 .78471 .40955 .77976 .40295 Mtetra
.77976 .40295 .78471 .40955 .7961 .40595 .79118 .39933 Mtetra
.79118 .39933 .7961 .40595 .80753 .40234 .80265 .39568 Mtetra
.80265 .39568 .80753 .40234 .81901 .39871 .81416 .39203 Mtetra
.81416 .39203 .81901 .39871 .83053 .39507 .82571 .38836 Mtetra
.82571 .38836 .83053 .39507 .8421 .39141 .83731 .38468 Mtetra
.83731 .38468 .8421 .39141 .85372 .38774 .84896 .38098 Mtetra
.84896 .38098 .85372 .38774 .86538 .38405 .86066 .37726 Mtetra
.86066 .37726 .86538 .38405 .87709 .38035 .8724 .37354 Mtetra
.626 .731 .923 r
.24535 .56541 .25161 .57125 .26098 .56902 .25474 .56311 Mtetra
.611 .725 .926 r
.25474 .56311 .26098 .56902 .2703 .56798 .26414 .56111 Mtetra
.534 .051 0 r
.26414 .56111 .2703 .56798 .28032 .55776 .27272 .57077 Mtetra
.643 .808 .374 r
.27272 .57077 .28032 .55776 .28959 .55829 .28344 .55191 Mtetra
.603 .707 .917 r
.28344 .55191 .28959 .55829 .2991 .55597 .29293 .5501 Mtetra
.635 .736 .921 r
.29293 .5501 .2991 .55597 .30867 .55336 .30252 .54756 Mtetra
.64 .74 .921 r
.30252 .54756 .30867 .55336 .31828 .55072 .31214 .54488 Mtetra
.637 .739 .922 r
.31214 .54488 .31828 .55072 .32791 .54829 .32181 .54227 Mtetra
.61 .725 .927 r
.32181 .54227 .32791 .54829 .33746 .54799 .33147 .54025 Mtetra
.91 .716 .628 r
.33147 .54025 .33746 .54799 .34758 .53792 .34334 .49874 Mtetra
0 0 .485 r
.34334 .49874 .34758 .53792 .35724 .53694 .35121 .53067 Mtetra
.621 .721 .918 r
.35121 .53067 .35724 .53694 .36703 .53431 .361 .5284 Mtetra
.644 .742 .92 r
.361 .5284 .36703 .53431 .37686 .53139 .37085 .52556 Mtetra
.651 .747 .92 r
.37085 .52556 .37686 .53139 .38674 .52835 .38075 .52255 Mtetra
.654 .75 .92 r
.38075 .52255 .38674 .52835 .39666 .52523 .39069 .51943 Mtetra
.657 .752 .92 r
.39069 .51943 .39666 .52523 .40662 .52205 .40067 .51626 Mtetra
.658 .753 .92 r
.40067 .51626 .40662 .52205 .41661 .51884 .41069 .51303 Mtetra
.659 .754 .92 r
.41069 .51303 .41661 .51884 .42664 .5156 .42074 .50978 Mtetra
.42074 .50978 .42664 .5156 .43671 .51235 .43083 .5065 Mtetra
.43083 .5065 .43671 .51235 .44681 .50909 .44096 .50321 Mtetra
.44096 .50321 .44681 .50909 .45695 .50582 .45113 .49992 Mtetra
.658 .753 .92 r
.45113 .49992 .45695 .50582 .46713 .50255 .46133 .49662 Mtetra
.46133 .49662 .46713 .50255 .47735 .49927 .47157 .49332 Mtetra
.47157 .49332 .47735 .49927 .48761 .49598 .48185 .49001 Mtetra
.48185 .49001 .48761 .49598 .4979 .49269 .49217 .48669 Mtetra
.49217 .48669 .4979 .49269 .50823 .48938 .50253 .48336 Mtetra
.50253 .48336 .50823 .48938 .5186 .48607 .51293 .48003 Mtetra
.51293 .48003 .5186 .48607 .52901 .48275 .52336 .47668 Mtetra
.657 .753 .92 r
.52336 .47668 .52901 .48275 .53946 .47941 .53384 .47332 Mtetra
.53384 .47332 .53946 .47941 .54995 .47607 .54435 .46995 Mtetra
.657 .752 .92 r
.54435 .46995 .54995 .47607 .56048 .47271 .55491 .46657 Mtetra
.55491 .46657 .56048 .47271 .57105 .46934 .5655 .46317 Mtetra
.5655 .46317 .57105 .46934 .58165 .46596 .57614 .45977 Mtetra
.57614 .45977 .58165 .46596 .5923 .46257 .58681 .45635 Mtetra
.58681 .45635 .5923 .46257 .60299 .45916 .59753 .45292 Mtetra
.59753 .45292 .60299 .45916 .61372 .45575 .60829 .44948 Mtetra
.60829 .44948 .61372 .45575 .6245 .45232 .61909 .44603 Mtetra
.61909 .44603 .6245 .45232 .63531 .44887 .62993 .44256 Mtetra
.62993 .44256 .63531 .44887 .64616 .44542 .64081 .43908 Mtetra
.64081 .43908 .64616 .44542 .65706 .44195 .65174 .43559 Mtetra
.65174 .43559 .65706 .44195 .668 .43847 .66271 .43209 Mtetra
.66271 .43209 .668 .43847 .67898 .43498 .67372 .42857 Mtetra
.67372 .42857 .67898 .43498 .69 .43148 .68477 .42504 Mtetra
.68477 .42504 .69 .43148 .70107 .42796 .69587 .42149 Mtetra
.69587 .42149 .70107 .42796 .71218 .42443 .70701 .41794 Mtetra
.70701 .41794 .71218 .42443 .72333 .42088 .71819 .41437 Mtetra
.71819 .41437 .72333 .42088 .73453 .41732 .72942 .41078 Mtetra
.72942 .41078 .73453 .41732 .74577 .41375 .74069 .40718 Mtetra
.74069 .40718 .74577 .41375 .75706 .41017 .75201 .40357 Mtetra
.75201 .40357 .75706 .41017 .76839 .40657 .76337 .39994 Mtetra
.76337 .39994 .76839 .40657 .77976 .40295 .77478 .39631 Mtetra
.77478 .39631 .77976 .40295 .79118 .39933 .78623 .39265 Mtetra
.78623 .39265 .79118 .39933 .80265 .39568 .79772 .38898 Mtetra
.79772 .38898 .80265 .39568 .81416 .39203 .80927 .3853 Mtetra
.80927 .3853 .81416 .39203 .82571 .38836 .82086 .3816 Mtetra
.82086 .3816 .82571 .38836 .83731 .38468 .83249 .37789 Mtetra
.83249 .37789 .83731 .38468 .84896 .38098 .84417 .37417 Mtetra
.84417 .37417 .84896 .38098 .86066 .37726 .8559 .37043 Mtetra
.8559 .37043 .86066 .37726 .8724 .37354 .86768 .36667 Mtetra
.621 .726 .922 r
.23906 .55943 .24535 .56541 .25474 .56311 .24845 .55723 Mtetra
.624 .731 .924 r
.24845 .55723 .25474 .56311 .26414 .56111 .25789 .55495 Mtetra
.562 .701 .934 r
.25789 .55495 .26414 .56111 .27272 .57077 .26728 .55387 Mtetra
.719 .584 .704 r
.26728 .55387 .27272 .57077 .28344 .55191 .27739 .54356 Mtetra
.501 .605 .888 r
.27739 .54356 .28344 .55191 .29293 .5501 .28673 .54405 Mtetra
.626 .728 .92 r
.28673 .54405 .29293 .5501 .30252 .54756 .29632 .54169 Mtetra
.639 .739 .921 r
.29632 .54169 .30252 .54756 .31214 .54488 .30597 .53903 Mtetra
.639 .74 .922 r
.30597 .53903 .31214 .54488 .32181 .54227 .31565 .53633 Mtetra
.629 .735 .924 r
.31565 .53633 .32181 .54227 .33147 .54025 .32536 .53385 Mtetra
.518 .679 .938 r
.32536 .53385 .33147 .54025 .34334 .49874 .33499 .53351 Mtetra
.39 .12 .379 r
.33499 .53351 .34334 .49874 .35121 .53067 .3452 .52336 Mtetra
.567 .669 .907 r
.3452 .52336 .35121 .53067 .361 .5284 .35494 .52234 Mtetra
.637 .736 .92 r
.35494 .52234 .361 .5284 .37085 .52556 .3648 .51966 Mtetra
.648 .745 .92 r
.3648 .51966 .37085 .52556 .38075 .52255 .37472 .51668 Mtetra
.653 .749 .92 r
.37472 .51668 .38075 .52255 .39069 .51943 .38468 .51359 Mtetra
.656 .751 .92 r
.38468 .51359 .39069 .51943 .40067 .51626 .39468 .51041 Mtetra
.657 .752 .92 r
.39468 .51041 .40067 .51626 .41069 .51303 .40472 .50718 Mtetra
.658 .753 .92 r
.40472 .50718 .41069 .51303 .42074 .50978 .4148 .50391 Mtetra
.659 .754 .92 r
.4148 .50391 .42074 .50978 .43083 .5065 .42491 .50061 Mtetra
.42491 .50061 .43083 .5065 .44096 .50321 .43507 .4973 Mtetra
.43507 .4973 .44096 .50321 .45113 .49992 .44526 .49399 Mtetra
.659 .753 .92 r
.44526 .49399 .45113 .49992 .46133 .49662 .45549 .49066 Mtetra
.658 .753 .92 r
.45549 .49066 .46133 .49662 .47157 .49332 .46576 .48733 Mtetra
.46576 .48733 .47157 .49332 .48185 .49001 .47606 .484 Mtetra
.47606 .484 .48185 .49001 .49217 .48669 .4864 .48065 Mtetra
.4864 .48065 .49217 .48669 .50253 .48336 .49679 .4773 Mtetra
.49679 .4773 .50253 .48336 .51293 .48003 .50721 .47394 Mtetra
.50721 .47394 .51293 .48003 .52336 .47668 .51767 .47057 Mtetra
.657 .753 .92 r
.51767 .47057 .52336 .47668 .53384 .47332 .52817 .46718 Mtetra
.52817 .46718 .53384 .47332 .54435 .46995 .53871 .46379 Mtetra
.53871 .46379 .54435 .46995 .55491 .46657 .5493 .46038 Mtetra
.657 .752 .92 r
.5493 .46038 .55491 .46657 .5655 .46317 .55992 .45696 Mtetra
.55992 .45696 .5655 .46317 .57614 .45977 .57058 .45353 Mtetra
.57058 .45353 .57614 .45977 .58681 .45635 .58128 .45009 Mtetra
.58128 .45009 .58681 .45635 .59753 .45292 .59203 .44664 Mtetra
.59203 .44664 .59753 .45292 .60829 .44948 .60282 .44317 Mtetra
.60282 .44317 .60829 .44948 .61909 .44603 .61364 .43969 Mtetra
.61364 .43969 .61909 .44603 .62993 .44256 .62451 .4362 Mtetra
.62451 .4362 .62993 .44256 .64081 .43908 .63543 .4327 Mtetra
.63543 .4327 .64081 .43908 .65174 .43559 .64638 .42918 Mtetra
.64638 .42918 .65174 .43559 .66271 .43209 .65738 .42565 Mtetra
.65738 .42565 .66271 .43209 .67372 .42857 .66842 .42211 Mtetra
.66842 .42211 .67372 .42857 .68477 .42504 .6795 .41855 Mtetra
.6795 .41855 .68477 .42504 .69587 .42149 .69063 .41498 Mtetra
.69063 .41498 .69587 .42149 .70701 .41794 .7018 .4114 Mtetra
.7018 .4114 .70701 .41794 .71819 .41437 .71301 .4078 Mtetra
.71301 .4078 .71819 .41437 .72942 .41078 .72427 .40419 Mtetra
.72427 .40419 .72942 .41078 .74069 .40718 .73557 .40057 Mtetra
.73557 .40057 .74069 .40718 .75201 .40357 .74692 .39693 Mtetra
.74692 .39693 .75201 .40357 .76337 .39994 .75831 .39327 Mtetra
.75831 .39327 .76337 .39994 .77478 .39631 .76975 .38961 Mtetra
.76975 .38961 .77478 .39631 .78623 .39265 .78124 .38593 Mtetra
.78124 .38593 .78623 .39265 .79772 .38898 .79277 .38223 Mtetra
.79277 .38223 .79772 .38898 .80927 .3853 .80434 .37852 Mtetra
.80434 .37852 .80927 .3853 .82086 .3816 .81596 .3748 Mtetra
.81596 .3748 .82086 .3816 .83249 .37789 .82763 .37106 Mtetra
.82763 .37106 .83249 .37789 .84417 .37417 .83935 .36731 Mtetra
.83935 .36731 .84417 .37417 .8559 .37043 .85111 .36354 Mtetra
.85111 .36354 .8559 .37043 .86768 .36667 .86292 .35975 Mtetra
.603 .709 .919 r
.23275 .5531 .23906 .55943 .24845 .55723 .24213 .55129 Mtetra
.626 .731 .923 r
.24213 .55129 .24845 .55723 .25789 .55495 .25159 .54895 Mtetra
.611 .725 .926 r
.25159 .54895 .25789 .55495 .26728 .55387 .26107 .54689 Mtetra
0 0 .472 r
.26107 .54689 .26728 .55387 .27739 .54356 .2697 .55656 Mtetra
.652 .816 .384 r
.2697 .55656 .27739 .54356 .28673 .54405 .28052 .53758 Mtetra
.603 .707 .918 r
.28052 .53758 .28673 .54405 .29632 .54169 .29009 .53572 Mtetra
.635 .736 .921 r
.29009 .53572 .29632 .54169 .30597 .53903 .29975 .53313 Mtetra
.64 .74 .921 r
.29975 .53313 .30597 .53903 .31565 .53633 .30946 .5304 Mtetra
.637 .739 .922 r
.30946 .5304 .31565 .53633 .32536 .53385 .3192 .52774 Mtetra
.61 .725 .927 r
.3192 .52774 .32536 .53385 .33499 .53351 .32894 .52566 Mtetra
.911 .717 .627 r
.32894 .52566 .33499 .53351 .3452 .52336 .34093 .48394 Mtetra
0 0 .482 r
.34093 .48394 .3452 .52336 .35494 .52234 .34885 .51596 Mtetra
.621 .721 .918 r
.34885 .51596 .35494 .52234 .3648 .51966 .35871 .51365 Mtetra
.644 .742 .92 r
.35871 .51365 .3648 .51966 .37472 .51668 .36865 .51075 Mtetra
.651 .747 .92 r
.36865 .51075 .37472 .51668 .38468 .51359 .37863 .50768 Mtetra
.654 .75 .92 r
.37863 .50768 .38468 .51359 .39468 .51041 .38865 .50451 Mtetra
.657 .752 .92 r
.38865 .50451 .39468 .51041 .40472 .50718 .39872 .50128 Mtetra
.658 .753 .92 r
.39872 .50128 .40472 .50718 .4148 .50391 .40882 .498 Mtetra
.659 .754 .92 r
.40882 .498 .4148 .50391 .42491 .50061 .41896 .49469 Mtetra
.41896 .49469 .42491 .50061 .43507 .4973 .42913 .49135 Mtetra
.42913 .49135 .43507 .4973 .44526 .49399 .43935 .48801 Mtetra
.43935 .48801 .44526 .49399 .45549 .49066 .4496 .48466 Mtetra
.658 .753 .92 r
.4496 .48466 .45549 .49066 .46576 .48733 .4599 .4813 Mtetra
.4599 .4813 .46576 .48733 .47606 .484 .47023 .47794 Mtetra
.47023 .47794 .47606 .484 .4864 .48065 .4806 .47457 Mtetra
.4806 .47457 .4864 .48065 .49679 .4773 .491 .4712 Mtetra
.491 .4712 .49679 .4773 .50721 .47394 .50145 .46781 Mtetra
.50145 .46781 .50721 .47394 .51767 .47057 .51194 .46441 Mtetra
.51194 .46441 .51767 .47057 .52817 .46718 .52247 .461 Mtetra
.657 .753 .92 r
.52247 .461 .52817 .46718 .53871 .46379 .53304 .45758 Mtetra
.53304 .45758 .53871 .46379 .5493 .46038 .54364 .45415 Mtetra
.657 .752 .92 r
.54364 .45415 .5493 .46038 .55992 .45696 .55429 .45071 Mtetra
.55429 .45071 .55992 .45696 .57058 .45353 .56498 .44726 Mtetra
.56498 .44726 .57058 .45353 .58128 .45009 .57572 .44379 Mtetra
.57572 .44379 .58128 .45009 .59203 .44664 .58649 .44031 Mtetra
.58649 .44031 .59203 .44664 .60282 .44317 .5973 .43682 Mtetra
.5973 .43682 .60282 .44317 .61364 .43969 .60816 .43332 Mtetra
.60816 .43332 .61364 .43969 .62451 .4362 .61906 .4298 Mtetra
.61906 .4298 .62451 .4362 .63543 .4327 .63 .42627 Mtetra
.63 .42627 .63543 .4327 .64638 .42918 .64098 .42273 Mtetra
.64098 .42273 .64638 .42918 .65738 .42565 .65201 .41917 Mtetra
.65201 .41917 .65738 .42565 .66842 .42211 .66308 .4156 Mtetra
.66308 .4156 .66842 .42211 .6795 .41855 .67419 .41202 Mtetra
.67419 .41202 .6795 .41855 .69063 .41498 .68535 .40842 Mtetra
.68535 .40842 .69063 .41498 .7018 .4114 .69655 .40481 Mtetra
.69655 .40481 .7018 .4114 .71301 .4078 .70779 .40119 Mtetra
.70779 .40119 .71301 .4078 .72427 .40419 .71908 .39755 Mtetra
.71908 .39755 .72427 .40419 .73557 .40057 .73042 .3939 Mtetra
.73042 .3939 .73557 .40057 .74692 .39693 .7418 .39024 Mtetra
.7418 .39024 .74692 .39693 .75831 .39327 .75322 .38656 Mtetra
.75322 .38656 .75831 .39327 .76975 .38961 .76469 .38286 Mtetra
.76469 .38286 .76975 .38961 .78124 .38593 .77621 .37915 Mtetra
.77621 .37915 .78124 .38593 .79277 .38223 .78777 .37543 Mtetra
.78777 .37543 .79277 .38223 .80434 .37852 .79938 .37169 Mtetra
.79938 .37169 .80434 .37852 .81596 .3748 .81104 .36794 Mtetra
.81104 .36794 .81596 .3748 .82763 .37106 .82274 .36417 Mtetra
.82274 .36417 .82763 .37106 .83935 .36731 .83449 .36039 Mtetra
.83449 .36039 .83935 .36731 .85111 .36354 .84629 .3566 Mtetra
.84629 .3566 .85111 .36354 .86292 .35975 .85813 .35278 Mtetra
.525 .635 .901 r
.22652 .54534 .23275 .5531 .24213 .55129 .23577 .54521 Mtetra
.621 .726 .922 r
.23577 .54521 .24213 .55129 .25159 .54895 .24524 .54296 Mtetra
.624 .731 .924 r
.24524 .54296 .25159 .54895 .26107 .54689 .25476 .54063 Mtetra
.562 .701 .934 r
.25476 .54063 .26107 .54689 .2697 .55656 .26422 .53951 Mtetra
.719 .584 .704 r
.26422 .53951 .2697 .55656 .28052 .53758 .27441 .52912 Mtetra
.501 .605 .889 r
.27441 .52912 .28052 .53758 .29009 .53572 .28383 .52957 Mtetra
.626 .728 .92 r
.28383 .52957 .29009 .53572 .29975 .53313 .29349 .52716 Mtetra
.639 .739 .921 r
.29349 .52716 .29975 .53313 .30946 .5304 .30322 .52444 Mtetra
.639 .74 .922 r
.30322 .52444 .30946 .5304 .3192 .52774 .31298 .5217 Mtetra
.629 .735 .924 r
.31298 .5217 .3192 .52774 .32894 .52566 .32277 .51917 Mtetra
.518 .679 .938 r
.32277 .51917 .32894 .52566 .34093 .48394 .33248 .51879 Mtetra
.384 .112 .372 r
.33248 .51879 .34093 .48394 .34885 .51596 .34277 .50854 Mtetra
.567 .669 .907 r
.34277 .50854 .34885 .51596 .35871 .51365 .35259 .50748 Mtetra
.637 .736 .92 r
.35259 .50748 .35871 .51365 .36865 .51075 .36254 .50474 Mtetra
.648 .745 .92 r
.36254 .50474 .36865 .51075 .37863 .50768 .37254 .50171 Mtetra
.653 .749 .92 r
.37254 .50171 .37863 .50768 .38865 .50451 .38258 .49856 Mtetra
.656 .751 .92 r
.38258 .49856 .38865 .50451 .39872 .50128 .39267 .49533 Mtetra
.657 .752 .92 r
.39267 .49533 .39872 .50128 .40882 .498 .40279 .49204 Mtetra
.658 .753 .92 r
.40279 .49204 .40882 .498 .41896 .49469 .41296 .48871 Mtetra
.659 .754 .92 r
.41296 .48871 .41896 .49469 .42913 .49135 .42316 .48536 Mtetra
.42316 .48536 .42913 .49135 .43935 .48801 .4334 .48199 Mtetra
.4334 .48199 .43935 .48801 .4496 .48466 .44368 .47862 Mtetra
.659 .753 .92 r
.44368 .47862 .4496 .48466 .4599 .4813 .454 .47524 Mtetra
.658 .753 .92 r
.454 .47524 .4599 .4813 .47023 .47794 .46435 .47185 Mtetra
.46435 .47185 .47023 .47794 .4806 .47457 .47475 .46845 Mtetra
.47475 .46845 .4806 .47457 .491 .4712 .48518 .46505 Mtetra
.48518 .46505 .491 .4712 .50145 .46781 .49566 .46164 Mtetra
.49566 .46164 .50145 .46781 .51194 .46441 .50617 .45821 Mtetra
.50617 .45821 .51194 .46441 .52247 .461 .51672 .45478 Mtetra
.657 .753 .92 r
.51672 .45478 .52247 .461 .53304 .45758 .52732 .45134 Mtetra
.52732 .45134 .53304 .45758 .54364 .45415 .53795 .44788 Mtetra
.53795 .44788 .54364 .45415 .55429 .45071 .54863 .44441 Mtetra
.657 .752 .92 r
.54863 .44441 .55429 .45071 .56498 .44726 .55935 .44093 Mtetra
.55935 .44093 .56498 .44726 .57572 .44379 .57011 .43744 Mtetra
.57011 .43744 .57572 .44379 .58649 .44031 .58091 .43394 Mtetra
.58091 .43394 .58649 .44031 .5973 .43682 .59175 .43042 Mtetra
.59175 .43042 .5973 .43682 .60816 .43332 .60263 .42689 Mtetra
.60263 .42689 .60816 .43332 .61906 .4298 .61356 .42335 Mtetra
.61356 .42335 .61906 .4298 .63 .42627 .62453 .41979 Mtetra
.62453 .41979 .63 .42627 .64098 .42273 .63554 .41622 Mtetra
.63554 .41622 .64098 .42273 .65201 .41917 .6466 .41264 Mtetra
.6466 .41264 .65201 .41917 .66308 .4156 .6577 .40905 Mtetra
.6577 .40905 .66308 .4156 .67419 .41202 .66884 .40544 Mtetra
.66884 .40544 .67419 .41202 .68535 .40842 .68003 .40182 Mtetra
.68003 .40182 .68535 .40842 .69655 .40481 .69126 .39818 Mtetra
.69126 .39818 .69655 .40481 .70779 .40119 .70254 .39453 Mtetra
.70254 .39453 .70779 .40119 .71908 .39755 .71386 .39086 Mtetra
.71386 .39086 .71908 .39755 .73042 .3939 .72522 .38719 Mtetra
.72522 .38719 .73042 .3939 .7418 .39024 .73664 .38349 Mtetra
.73664 .38349 .7418 .39024 .75322 .38656 .74809 .37979 Mtetra
.74809 .37979 .75322 .38656 .76469 .38286 .7596 .37607 Mtetra
.7596 .37607 .76469 .38286 .77621 .37915 .77114 .37233 Mtetra
.77114 .37233 .77621 .37915 .78777 .37543 .78274 .36858 Mtetra
.78274 .36858 .78777 .37543 .79938 .37169 .79438 .36481 Mtetra
.79438 .36481 .79938 .37169 .81104 .36794 .80607 .36103 Mtetra
.80607 .36103 .81104 .36794 .82274 .36417 .81781 .35724 Mtetra
.81781 .35724 .82274 .36417 .83449 .36039 .82959 .35343 Mtetra
.82959 .35343 .83449 .36039 .84629 .3566 .84142 .3496 Mtetra
.84142 .3496 .84629 .3566 .85813 .35278 .8533 .34576 Mtetra
0 0 0 r
.21636 .58058 .22652 .54534 .23577 .54521 .2294 .53878 Mtetra
.602 .709 .919 r
.2294 .53878 .23577 .54521 .24524 .54296 .23885 .53693 Mtetra
.626 .731 .923 r
.23885 .53693 .24524 .54296 .25476 .54063 .24839 .53453 Mtetra
.611 .725 .926 r
.24839 .53453 .25476 .54063 .26422 .53951 .25794 .53243 Mtetra
0 0 .48 r
.25794 .53243 .26422 .53951 .27441 .52912 .26663 .5421 Mtetra
.661 .823 .393 r
.26663 .5421 .27441 .52912 .28383 .52957 .27755 .52299 Mtetra
.603 .708 .918 r
.27755 .52299 .28383 .52957 .29349 .52716 .2872 .52109 Mtetra
.635 .736 .921 r
.2872 .52109 .29349 .52716 .30322 .52444 .29694 .51844 Mtetra
.64 .74 .921 r
.29694 .51844 .30322 .52444 .31298 .5217 .30672 .51566 Mtetra
.637 .739 .922 r
.30672 .51566 .31298 .5217 .32277 .51917 .31654 .51295 Mtetra
.61 .725 .927 r
.31654 .51295 .32277 .51917 .33248 .51879 .32637 .51082 Mtetra
.912 .718 .626 r
.32637 .51082 .33248 .51879 .34277 .50854 .33849 .46889 Mtetra
0 0 .479 r
.33849 .46889 .34277 .50854 .35259 .50748 .34644 .501 Mtetra
.621 .721 .918 r
.34644 .501 .35259 .50748 .36254 .50474 .35639 .49863 Mtetra
.644 .742 .92 r
.35639 .49863 .36254 .50474 .37254 .50171 .36641 .49568 Mtetra
.651 .747 .92 r
.36641 .49568 .37254 .50171 .38258 .49856 .37647 .49255 Mtetra
.654 .75 .92 r
.37647 .49255 .38258 .49856 .39267 .49533 .38658 .48933 Mtetra
.657 .752 .92 r
.38658 .48933 .39267 .49533 .40279 .49204 .39673 .48604 Mtetra
.658 .753 .92 r
.39673 .48604 .40279 .49204 .41296 .48871 .40692 .4827 Mtetra
.659 .754 .92 r
.40692 .4827 .41296 .48871 .42316 .48536 .41714 .47933 Mtetra
.41714 .47933 .42316 .48536 .4334 .48199 .42741 .47594 Mtetra
.42741 .47594 .4334 .48199 .44368 .47862 .43771 .47253 Mtetra
.43771 .47253 .44368 .47862 .454 .47524 .44805 .46912 Mtetra
.658 .753 .92 r
.44805 .46912 .454 .47524 .46435 .47185 .45844 .46571 Mtetra
.45844 .46571 .46435 .47185 .47475 .46845 .46886 .46229 Mtetra
.46886 .46229 .47475 .46845 .48518 .46505 .47932 .45886 Mtetra
.47932 .45886 .48518 .46505 .49566 .46164 .48982 .45542 Mtetra
.48982 .45542 .49566 .46164 .50617 .45821 .50036 .45197 Mtetra
.50036 .45197 .50617 .45821 .51672 .45478 .51094 .44851 Mtetra
.51094 .44851 .51672 .45478 .52732 .45134 .52156 .44504 Mtetra
.657 .753 .92 r
.52156 .44504 .52732 .45134 .53795 .44788 .53222 .44156 Mtetra
.53222 .44156 .53795 .44788 .54863 .44441 .54293 .43807 Mtetra
.657 .752 .92 r
.54293 .43807 .54863 .44441 .55935 .44093 .55367 .43456 Mtetra
.55367 .43456 .55935 .44093 .57011 .43744 .56446 .43105 Mtetra
.56446 .43105 .57011 .43744 .58091 .43394 .57529 .42752 Mtetra
.57529 .42752 .58091 .43394 .59175 .43042 .58616 .42397 Mtetra
.58616 .42397 .59175 .43042 .60263 .42689 .59707 .42042 Mtetra
.59707 .42042 .60263 .42689 .61356 .42335 .60803 .41685 Mtetra
.60803 .41685 .61356 .42335 .62453 .41979 .61902 .41327 Mtetra
.61902 .41327 .62453 .41979 .63554 .41622 .63007 .40967 Mtetra
.63007 .40967 .63554 .41622 .6466 .41264 .64115 .40607 Mtetra
.64115 .40607 .6466 .41264 .6577 .40905 .65228 .40244 Mtetra
.65228 .40244 .6577 .40905 .66884 .40544 .66346 .39881 Mtetra
.66346 .39881 .66884 .40544 .68003 .40182 .67467 .39516 Mtetra
.67467 .39516 .68003 .40182 .69126 .39818 .68594 .3915 Mtetra
.68594 .3915 .69126 .39818 .70254 .39453 .69724 .38782 Mtetra
.69724 .38782 .70254 .39453 .71386 .39086 .70859 .38413 Mtetra
.70859 .38413 .71386 .39086 .72522 .38719 .71999 .38042 Mtetra
.71999 .38042 .72522 .38719 .73664 .38349 .73144 .3767 Mtetra
.73144 .3767 .73664 .38349 .74809 .37979 .74292 .37297 Mtetra
.74292 .37297 .74809 .37979 .7596 .37607 .75446 .36922 Mtetra
.75446 .36922 .7596 .37607 .77114 .37233 .76604 .36545 Mtetra
.76604 .36545 .77114 .37233 .78274 .36858 .77767 .36168 Mtetra
.77767 .36168 .78274 .36858 .79438 .36481 .78935 .35788 Mtetra
.78935 .35788 .79438 .36481 .80607 .36103 .80107 .35407 Mtetra
.80107 .35407 .80607 .36103 .81781 .35724 .81284 .35025 Mtetra
.81284 .35025 .81781 .35724 .82959 .35343 .82466 .34641 Mtetra
.82466 .34641 .82959 .35343 .84142 .3496 .83652 .34256 Mtetra
.83652 .34256 .84142 .3496 .8533 .34576 .84844 .33869 Mtetra
.636 .459 .626 r
.21294 .54082 .21636 .58058 .2294 .53878 .22311 .53092 Mtetra
.525 .635 .901 r
.22311 .53092 .2294 .53878 .23885 .53693 .23242 .53075 Mtetra
.621 .726 .922 r
.23242 .53075 .23885 .53693 .24839 .53453 .24197 .52845 Mtetra
.624 .731 .924 r
.24197 .52845 .24839 .53453 .25794 .53243 .25156 .52607 Mtetra
.562 .701 .934 r
.25156 .52607 .25794 .53243 .26663 .5421 .2611 .5249 Mtetra
.719 .585 .704 r
.2611 .5249 .26663 .5421 .27755 .52299 .27139 .51442 Mtetra
.5 .605 .889 r
.27139 .51442 .27755 .52299 .2872 .52109 .28087 .51484 Mtetra
.626 .728 .92 r
.28087 .51484 .2872 .52109 .29694 .51844 .29061 .51238 Mtetra
.639 .739 .921 r
.29061 .51238 .29694 .51844 .30672 .51566 .30042 .50961 Mtetra
.639 .74 .922 r
.30042 .50961 .30672 .51566 .31654 .51295 .31026 .5068 Mtetra
.629 .735 .924 r
.31026 .5068 .31654 .51295 .32637 .51082 .32013 .50422 Mtetra
.518 .679 .938 r
.32013 .50422 .32637 .51082 .33849 .46889 .32992 .5038 Mtetra
.378 .104 .366 r
.32992 .5038 .33849 .46889 .34644 .501 .34031 .49347 Mtetra
.567 .669 .907 r
.34031 .49347 .34644 .501 .35639 .49863 .3502 .49236 Mtetra
.637 .736 .92 r
.3502 .49236 .35639 .49863 .36641 .49568 .36024 .48956 Mtetra
.648 .745 .92 r
.36024 .48956 .36641 .49568 .37647 .49255 .37032 .48648 Mtetra
.653 .749 .92 r
.37032 .48648 .37647 .49255 .38658 .48933 .38045 .48327 Mtetra
.656 .751 .92 r
.38045 .48327 .38658 .48933 .39673 .48604 .39062 .47998 Mtetra
.657 .752 .92 r
.39062 .47998 .39673 .48604 .40692 .4827 .40083 .47663 Mtetra
.658 .753 .92 r
.40083 .47663 .40692 .4827 .41714 .47933 .41108 .47325 Mtetra
.659 .754 .92 r
.41108 .47325 .41714 .47933 .42741 .47594 .42137 .46984 Mtetra
.42137 .46984 .42741 .47594 .43771 .47253 .4317 .46641 Mtetra
.4317 .46641 .43771 .47253 .44805 .46912 .44207 .46297 Mtetra
.659 .753 .92 r
.44207 .46297 .44805 .46912 .45844 .46571 .45248 .45953 Mtetra
.658 .753 .92 r
.45248 .45953 .45844 .46571 .46886 .46229 .46292 .45608 Mtetra
.46292 .45608 .46886 .46229 .47932 .45886 .47341 .45262 Mtetra
.47341 .45262 .47932 .45886 .48982 .45542 .48394 .44916 Mtetra
.48394 .44916 .48982 .45542 .50036 .45197 .4945 .44569 Mtetra
.4945 .44569 .50036 .45197 .51094 .44851 .50511 .4422 Mtetra
.50511 .4422 .51094 .44851 .52156 .44504 .51576 .43871 Mtetra
.657 .753 .92 r
.51576 .43871 .52156 .44504 .53222 .44156 .52645 .4352 Mtetra
.52645 .4352 .53222 .44156 .54293 .43807 .53718 .43168 Mtetra
.53718 .43168 .54293 .43807 .55367 .43456 .54795 .42815 Mtetra
.657 .752 .92 r
.54795 .42815 .55367 .43456 .56446 .43105 .55877 .42461 Mtetra
.55877 .42461 .56446 .43105 .57529 .42752 .56962 .42105 Mtetra
.56962 .42105 .57529 .42752 .58616 .42397 .58052 .41748 Mtetra
.58052 .41748 .58616 .42397 .59707 .42042 .59146 .4139 Mtetra
.59146 .4139 .59707 .42042 .60803 .41685 .60245 .41031 Mtetra
.60245 .41031 .60803 .41685 .61902 .41327 .61348 .4067 Mtetra
.61348 .4067 .61902 .41327 .63007 .40967 .62455 .40308 Mtetra
.62455 .40308 .63007 .40967 .64115 .40607 .63566 .39944 Mtetra
.63566 .39944 .64115 .40607 .65228 .40244 .64682 .39579 Mtetra
.64682 .39579 .65228 .40244 .66346 .39881 .65803 .39213 Mtetra
.65803 .39213 .66346 .39881 .67467 .39516 .66928 .38845 Mtetra
.66928 .38845 .67467 .39516 .68594 .3915 .68057 .38476 Mtetra
.68057 .38476 .68594 .3915 .69724 .38782 .69191 .38106 Mtetra
.69191 .38106 .69724 .38782 .70859 .38413 .70329 .37734 Mtetra
.70329 .37734 .70859 .38413 .71999 .38042 .71472 .37361 Mtetra
.71472 .37361 .71999 .38042 .73144 .3767 .7262 .36986 Mtetra
.7262 .36986 .73144 .3767 .74292 .37297 .73772 .3661 Mtetra
.73772 .3661 .74292 .37297 .75446 .36922 .74929 .36232 Mtetra
.74929 .36232 .75446 .36922 .76604 .36545 .7609 .35853 Mtetra
.7609 .35853 .76604 .36545 .77767 .36168 .77256 .35472 Mtetra
.77256 .35472 .77767 .36168 .78935 .35788 .78427 .3509 Mtetra
.78427 .3509 .78935 .35788 .80107 .35407 .79603 .34706 Mtetra
.79603 .34706 .80107 .35407 .81284 .35025 .80783 .34321 Mtetra
.80783 .34321 .81284 .35025 .82466 .34641 .81969 .33934 Mtetra
.81969 .33934 .82466 .34641 .83652 .34256 .83159 .33546 Mtetra
.83159 .33546 .83652 .34256 .84844 .33869 .84354 .33156 Mtetra
.945 .594 .313 r
.20654 .53342 .21294 .54082 .22311 .53092 .21281 .56624 Mtetra
0 0 0 r
.21281 .56624 .22311 .53092 .23242 .53075 .22599 .52422 Mtetra
.602 .709 .919 r
.22599 .52422 .23242 .53075 .24197 .52845 .23551 .52231 Mtetra
.626 .731 .923 r
.23551 .52231 .24197 .52845 .25156 .52607 .24513 .51987 Mtetra
.611 .725 .926 r
.24513 .51987 .25156 .52607 .2611 .5249 .25475 .51772 Mtetra
0 0 .487 r
.25475 .51772 .2611 .5249 .27139 .51442 .2635 .52738 Mtetra
.67 .83 .403 r
.2635 .52738 .27139 .51442 .28087 .51484 .27453 .50816 Mtetra
.603 .708 .918 r
.27453 .50816 .28087 .51484 .29061 .51238 .28425 .5062 Mtetra
.635 .736 .921 r
.28425 .5062 .29061 .51238 .30042 .50961 .29407 .5035 Mtetra
.64 .74 .921 r
.29407 .5035 .30042 .50961 .31026 .5068 .30394 .50067 Mtetra
.637 .739 .922 r
.30394 .50067 .31026 .5068 .32013 .50422 .31384 .4979 Mtetra
.61 .725 .927 r
.31384 .4979 .32013 .50422 .32992 .5038 .32375 .49572 Mtetra
.913 .719 .626 r
.32375 .49572 .32992 .5038 .34031 .49347 .336 .45356 Mtetra
0 0 .476 r
.336 .45356 .34031 .49347 .3502 .49236 .34399 .48577 Mtetra
.621 .721 .918 r
.34399 .48577 .3502 .49236 .36024 .48956 .35402 .48334 Mtetra
.644 .742 .92 r
.35402 .48334 .36024 .48956 .37032 .48648 .36413 .48034 Mtetra
.651 .747 .92 r
.36413 .48034 .37032 .48648 .38045 .48327 .37428 .47715 Mtetra
.654 .75 .92 r
.37428 .47715 .38045 .48327 .39062 .47998 .38447 .47387 Mtetra
.657 .752 .92 r
.38447 .47387 .39062 .47998 .40083 .47663 .3947 .47052 Mtetra
.658 .753 .92 r
.3947 .47052 .40083 .47663 .41108 .47325 .40498 .46712 Mtetra
.659 .754 .92 r
.40498 .46712 .41108 .47325 .42137 .46984 .41529 .46369 Mtetra
.41529 .46369 .42137 .46984 .4317 .46641 .42565 .46024 Mtetra
.42565 .46024 .4317 .46641 .44207 .46297 .43604 .45678 Mtetra
.43604 .45678 .44207 .46297 .45248 .45953 .44648 .45331 Mtetra
.658 .753 .92 r
.44648 .45331 .45248 .45953 .46292 .45608 .45695 .44983 Mtetra
.45695 .44983 .46292 .45608 .47341 .45262 .46746 .44635 Mtetra
.46746 .44635 .47341 .45262 .48394 .44916 .47801 .44286 Mtetra
.47801 .44286 .48394 .44916 .4945 .44569 .48861 .43936 Mtetra
.48861 .43936 .4945 .44569 .50511 .4422 .49924 .43585 Mtetra
.49924 .43585 .50511 .4422 .51576 .43871 .50992 .43232 Mtetra
.50992 .43232 .51576 .43871 .52645 .4352 .52063 .42879 Mtetra
.657 .753 .92 r
.52063 .42879 .52645 .4352 .53718 .43168 .53139 .42525 Mtetra
.53139 .42525 .53718 .43168 .54795 .42815 .54219 .42169 Mtetra
.657 .752 .92 r
.54219 .42169 .54795 .42815 .55877 .42461 .55303 .41812 Mtetra
.55303 .41812 .55877 .42461 .56962 .42105 .56392 .41454 Mtetra
.56392 .41454 .56962 .42105 .58052 .41748 .57485 .41094 Mtetra
.57485 .41094 .58052 .41748 .59146 .4139 .58582 .40734 Mtetra
.58582 .40734 .59146 .4139 .60245 .41031 .59683 .40371 Mtetra
.59683 .40371 .60245 .41031 .61348 .4067 .60789 .40008 Mtetra
.60789 .40008 .61348 .4067 .62455 .40308 .61899 .39643 Mtetra
.61899 .39643 .62455 .40308 .63566 .39944 .63014 .39277 Mtetra
.63014 .39277 .63566 .39944 .64682 .39579 .64133 .38909 Mtetra
.64133 .38909 .64682 .39579 .65803 .39213 .65256 .3854 Mtetra
.65256 .3854 .65803 .39213 .66928 .38845 .66384 .3817 Mtetra
.66384 .3817 .66928 .38845 .68057 .38476 .67516 .37798 Mtetra
.67516 .37798 .68057 .38476 .69191 .38106 .68653 .37425 Mtetra
.68653 .37425 .69191 .38106 .70329 .37734 .69795 .3705 Mtetra
.69795 .3705 .70329 .37734 .71472 .37361 .70941 .36674 Mtetra
.70941 .36674 .71472 .37361 .7262 .36986 .72092 .36297 Mtetra
.72092 .36297 .7262 .36986 .73772 .3661 .73247 .35918 Mtetra
.73247 .35918 .73772 .3661 .74929 .36232 .74407 .35537 Mtetra
.74407 .35537 .74929 .36232 .7609 .35853 .75572 .35155 Mtetra
.75572 .35155 .7609 .35853 .77256 .35472 .76742 .34771 Mtetra
.76742 .34771 .77256 .35472 .78427 .3509 .77916 .34386 Mtetra
.77916 .34386 .78427 .3509 .79603 .34706 .79095 .34 Mtetra
.79095 .34 .79603 .34706 .80783 .34321 .80279 .33612 Mtetra
.80279 .33612 .80783 .34321 .81969 .33934 .81468 .33222 Mtetra
.81468 .33222 .81969 .33934 .83159 .33546 .82661 .3283 Mtetra
.82661 .3283 .83159 .33546 .84354 .33156 .8386 .32438 Mtetra
.535 .688 .937 r
.20002 .52695 .20654 .53342 .21281 .56624 .20938 .52623 Mtetra
.636 .457 .625 r
.20938 .52623 .21281 .56624 .22599 .52422 .21963 .51625 Mtetra
.525 .635 .901 r
.21963 .51625 .22599 .52422 .23551 .52231 .22902 .51603 Mtetra
.621 .726 .922 r
.22902 .51603 .23551 .52231 .24513 .51987 .23864 .51368 Mtetra
.624 .731 .924 r
.23864 .51368 .24513 .51987 .25475 .51772 .24831 .51125 Mtetra
.563 .701 .934 r
.24831 .51125 .25475 .51772 .2635 .52738 .25792 .51003 Mtetra
.719 .585 .704 r
.25792 .51003 .2635 .52738 .27453 .50816 .2683 .49947 Mtetra
.5 .605 .889 r
.2683 .49947 .27453 .50816 .28425 .5062 .27786 .49985 Mtetra
.626 .728 .92 r
.27786 .49985 .28425 .5062 .29407 .5035 .28769 .49733 Mtetra
.639 .739 .921 r
.28769 .49733 .29407 .5035 .30394 .50067 .29757 .49451 Mtetra
.639 .74 .922 r
.29757 .49451 .30394 .50067 .31384 .4979 .3075 .49165 Mtetra
.629 .735 .924 r
.3075 .49165 .31384 .4979 .32375 .49572 .31745 .48901 Mtetra
.519 .679 .938 r
.31745 .48901 .32375 .49572 .336 .45356 .32731 .48854 Mtetra
.372 .096 .359 r
.32731 .48854 .336 .45356 .34399 .48577 .33779 .47813 Mtetra
.567 .669 .907 r
.33779 .47813 .34399 .48577 .35402 .48334 .34777 .47696 Mtetra
.637 .736 .92 r
.34777 .47696 .35402 .48334 .36413 .48034 .35789 .47411 Mtetra
.648 .745 .92 r
.35789 .47411 .36413 .48034 .37428 .47715 .36806 .47097 Mtetra
.653 .749 .92 r
.36806 .47097 .37428 .47715 .38447 .47387 .37828 .4677 Mtetra
.656 .751 .92 r
.37828 .4677 .38447 .47387 .3947 .47052 .38853 .46435 Mtetra
.657 .752 .92 r
.38853 .46435 .3947 .47052 .40498 .46712 .39883 .46095 Mtetra
.658 .753 .92 r
.39883 .46095 .40498 .46712 .41529 .46369 .40917 .4575 Mtetra
.659 .754 .92 r
.40917 .4575 .41529 .46369 .42565 .46024 .41955 .45403 Mtetra
.41955 .45403 .42565 .46024 .43604 .45678 .42997 .45054 Mtetra
.42997 .45054 .43604 .45678 .44648 .45331 .44043 .44704 Mtetra
.659 .753 .92 r
.44043 .44704 .44648 .45331 .45695 .44983 .45093 .44354 Mtetra
.658 .753 .92 r
.45093 .44354 .45695 .44983 .46746 .44635 .46147 .44003 Mtetra
.46147 .44003 .46746 .44635 .47801 .44286 .47205 .43651 Mtetra
.47205 .43651 .47801 .44286 .48861 .43936 .48267 .43298 Mtetra
.48267 .43298 .48861 .43936 .49924 .43585 .49333 .42944 Mtetra
.49333 .42944 .49924 .43585 .50992 .43232 .50403 .4259 Mtetra
.50403 .4259 .50992 .43232 .52063 .42879 .51478 .42234 Mtetra
.657 .753 .92 r
.51478 .42234 .52063 .42879 .53139 .42525 .52556 .41877 Mtetra
.52556 .41877 .53139 .42525 .54219 .42169 .53639 .41518 Mtetra
.53639 .41518 .54219 .42169 .55303 .41812 .54726 .41159 Mtetra
.657 .752 .92 r
.54726 .41159 .55303 .41812 .56392 .41454 .55818 .40798 Mtetra
.55818 .40798 .56392 .41454 .57485 .41094 .56913 .40436 Mtetra
.56913 .40436 .57485 .41094 .58582 .40734 .58013 .40072 Mtetra
.58013 .40072 .58582 .40734 .59683 .40371 .59117 .39707 Mtetra
.59117 .39707 .59683 .40371 .60789 .40008 .60226 .39341 Mtetra
.60226 .39341 .60789 .40008 .61899 .39643 .61339 .38974 Mtetra
.61339 .38974 .61899 .39643 .63014 .39277 .62457 .38605 Mtetra
.62457 .38605 .63014 .39277 .64133 .38909 .63579 .38234 Mtetra
.63579 .38234 .64133 .38909 .65256 .3854 .64705 .37863 Mtetra
.64705 .37863 .65256 .3854 .66384 .3817 .65836 .3749 Mtetra
.65836 .3749 .66384 .3817 .67516 .37798 .66972 .37115 Mtetra
.66972 .37115 .67516 .37798 .68653 .37425 .68112 .36739 Mtetra
.68112 .36739 .68653 .37425 .69795 .3705 .69257 .36362 Mtetra
.69257 .36362 .69795 .3705 .70941 .36674 .70406 .35983 Mtetra
.70406 .35983 .70941 .36674 .72092 .36297 .7156 .35602 Mtetra
.7156 .35602 .72092 .36297 .73247 .35918 .72719 .3522 Mtetra
.72719 .3522 .73247 .35918 .74407 .35537 .73882 .34837 Mtetra
.73882 .34837 .74407 .35537 .75572 .35155 .7505 .34452 Mtetra
.7505 .34452 .75572 .35155 .76742 .34771 .76223 .34065 Mtetra
.76223 .34065 .76742 .34771 .77916 .34386 .77401 .33677 Mtetra
.77401 .33677 .77916 .34386 .79095 .34 .78583 .33288 Mtetra
.78583 .33288 .79095 .34 .80279 .33612 .79771 .32897 Mtetra
.79771 .32897 .80279 .33612 .81468 .33222 .80963 .32504 Mtetra
.80963 .32504 .81468 .33222 .82661 .3283 .8216 .3211 Mtetra
.8216 .3211 .82661 .3283 .8386 .32438 .83362 .31714 Mtetra
.601 .719 .927 r
.19342 .52066 .20002 .52695 .20938 .52623 .20291 .51873 Mtetra
.945 .592 .308 r
.20291 .51873 .20938 .52623 .21963 .51625 .20918 .55164 Mtetra
0 0 0 r
.20918 .55164 .21963 .51625 .22902 .51603 .22251 .5094 Mtetra
.602 .709 .919 r
.22251 .5094 .22902 .51603 .23864 .51368 .23212 .50744 Mtetra
.626 .731 .923 r
.23212 .50744 .23864 .51368 .24831 .51125 .24181 .50494 Mtetra
.611 .725 .926 r
.24181 .50494 .24831 .51125 .25792 .51003 .25152 .50274 Mtetra
0 0 .495 r
.25152 .50274 .25792 .51003 .2683 .49947 .26032 .51241 Mtetra
.679 .837 .412 r
.26032 .51241 .2683 .49947 .27786 .49985 .27146 .49305 Mtetra
.603 .708 .918 r
.27146 .49305 .27786 .49985 .28769 .49733 .28126 .49105 Mtetra
.635 .736 .921 r
.28126 .49105 .28769 .49733 .29757 .49451 .29116 .4883 Mtetra
.64 .74 .921 r
.29116 .4883 .29757 .49451 .3075 .49165 .30111 .48541 Mtetra
.637 .739 .922 r
.30111 .48541 .3075 .49165 .31745 .48901 .31109 .48258 Mtetra
.61 .725 .927 r
.31109 .48258 .31745 .48901 .32731 .48854 .32108 .48035 Mtetra
.915 .719 .625 r
.32108 .48035 .32731 .48854 .33779 .47813 .33347 .43797 Mtetra
0 0 .472 r
.33347 .43797 .33779 .47813 .34777 .47696 .3415 .47026 Mtetra
.621 .721 .918 r
.3415 .47026 .34777 .47696 .35789 .47411 .35161 .46778 Mtetra
.644 .742 .92 r
.35161 .46778 .35789 .47411 .36806 .47097 .3618 .46472 Mtetra
.651 .747 .92 r
.3618 .46472 .36806 .47097 .37828 .4677 .37204 .46148 Mtetra
.654 .75 .92 r
.37204 .46148 .37828 .4677 .38853 .46435 .38232 .45813 Mtetra
.657 .752 .92 r
.38232 .45813 .38853 .46435 .39883 .46095 .39264 .45472 Mtetra
.658 .753 .92 r
.39264 .45472 .39883 .46095 .40917 .4575 .40301 .45126 Mtetra
.659 .754 .92 r
.40301 .45126 .40917 .4575 .41955 .45403 .41341 .44777 Mtetra
.41341 .44777 .41955 .45403 .42997 .45054 .42386 .44426 Mtetra
.42386 .44426 .42997 .45054 .44043 .44704 .43434 .44073 Mtetra
.43434 .44073 .44043 .44704 .45093 .44354 .44487 .4372 Mtetra
.658 .753 .92 r
.44487 .4372 .45093 .44354 .46147 .44003 .45543 .43366 Mtetra
.45543 .43366 .46147 .44003 .47205 .43651 .46604 .43012 Mtetra
.46604 .43012 .47205 .43651 .48267 .43298 .47669 .42656 Mtetra
.47669 .42656 .48267 .43298 .49333 .42944 .48737 .423 Mtetra
.48737 .423 .49333 .42944 .50403 .4259 .4981 .41942 Mtetra
.4981 .41942 .50403 .4259 .51478 .42234 .50888 .41584 Mtetra
.50888 .41584 .51478 .42234 .52556 .41877 .51969 .41224 Mtetra
.657 .753 .92 r
.51969 .41224 .52556 .41877 .53639 .41518 .53055 .40863 Mtetra
.53055 .40863 .53639 .41518 .54726 .41159 .54145 .40501 Mtetra
.657 .752 .92 r
.54145 .40501 .54726 .41159 .55818 .40798 .55239 .40137 Mtetra
.55239 .40137 .55818 .40798 .56913 .40436 .56337 .39772 Mtetra
.56337 .39772 .56913 .40436 .58013 .40072 .5744 .39406 Mtetra
.5744 .39406 .58013 .40072 .59117 .39707 .58547 .39038 Mtetra
.58547 .39038 .59117 .39707 .60226 .39341 .59659 .3867 Mtetra
.59659 .3867 .60226 .39341 .61339 .38974 .60775 .38299 Mtetra
.60775 .38299 .61339 .38974 .62457 .38605 .61896 .37928 Mtetra
.61896 .37928 .62457 .38605 .63579 .38234 .63021 .37555 Mtetra
.63021 .37555 .63579 .38234 .64705 .37863 .6415 .3718 Mtetra
.6415 .3718 .64705 .37863 .65836 .3749 .65285 .36804 Mtetra
.65285 .36804 .65836 .3749 .66972 .37115 .66423 .36427 Mtetra
.66423 .36427 .66972 .37115 .68112 .36739 .67566 .36048 Mtetra
.67566 .36048 .68112 .36739 .69257 .36362 .68714 .35668 Mtetra
.68714 .35668 .69257 .36362 .70406 .35983 .69867 .35286 Mtetra
.69867 .35286 .70406 .35983 .7156 .35602 .71024 .34902 Mtetra
.71024 .34902 .7156 .35602 .72719 .3522 .72186 .34518 Mtetra
.72186 .34518 .72719 .3522 .73882 .34837 .73353 .34131 Mtetra
.73353 .34131 .73882 .34837 .7505 .34452 .74524 .33743 Mtetra
.74524 .33743 .7505 .34452 .76223 .34065 .75701 .33354 Mtetra
.75701 .33354 .76223 .34065 .77401 .33677 .76882 .32963 Mtetra
.76882 .32963 .77401 .33677 .78583 .33288 .78068 .32571 Mtetra
.78068 .32571 .78583 .33288 .79771 .32897 .79258 .32176 Mtetra
.79258 .32176 .79771 .32897 .80963 .32504 .80454 .31781 Mtetra
.80454 .31781 .80963 .32504 .8216 .3211 .81655 .31383 Mtetra
.81655 .31383 .8216 .3211 .83362 .31714 .82861 .30984 Mtetra
.613 .724 .924 r
.18678 .51436 .19342 .52066 .20291 .51873 .19632 .51215 Mtetra
.535 .688 .937 r
.19632 .51215 .20291 .51873 .20918 .55164 .20575 .51138 Mtetra
.635 .456 .624 r
.20575 .51138 .20918 .55164 .22251 .5094 .2161 .50131 Mtetra
.524 .635 .901 r
.2161 .50131 .22251 .5094 .23212 .50744 .22556 .50106 Mtetra
.621 .726 .922 r
.22556 .50106 .23212 .50744 .24181 .50494 .23526 .49866 Mtetra
.624 .731 .924 r
.23526 .49866 .24181 .50494 .25152 .50274 .245 .49617 Mtetra
.563 .701 .934 r
.245 .49617 .25152 .50274 .26032 .51241 .25469 .49491 Mtetra
.72 .585 .703 r
.25469 .49491 .26032 .51241 .27146 .49305 .26517 .48425 Mtetra
.5 .605 .889 r
.26517 .48425 .27146 .49305 .28126 .49105 .2748 .48459 Mtetra
.626 .728 .92 r
.2748 .48459 .28126 .49105 .29116 .4883 .28471 .48202 Mtetra
.639 .739 .921 r
.28471 .48202 .29116 .4883 .30111 .48541 .29467 .47914 Mtetra
.639 .74 .922 r
.29467 .47914 .30111 .48541 .31109 .48258 .30468 .47622 Mtetra
.629 .735 .924 r
.30468 .47622 .31109 .48258 .32108 .48035 .31472 .47353 Mtetra
.519 .679 .938 r
.31472 .47353 .32108 .48035 .33347 .43797 .32466 .47301 Mtetra
.365 .087 .353 r
.32466 .47301 .33347 .43797 .3415 .47026 .33524 .46251 Mtetra
.567 .669 .907 r
.33524 .46251 .3415 .47026 .35161 .46778 .3453 .46129 Mtetra
.637 .736 .92 r
.3453 .46129 .35161 .46778 .3618 .46472 .3555 .45839 Mtetra
.648 .745 .92 r
.3555 .45839 .3618 .46472 .37204 .46148 .36576 .45518 Mtetra
.653 .749 .92 r
.36576 .45518 .37204 .46148 .38232 .45813 .37606 .45185 Mtetra
.656 .751 .92 r
.37606 .45185 .38232 .45813 .39264 .45472 .38641 .44845 Mtetra
.657 .752 .92 r
.38641 .44845 .39264 .45472 .40301 .45126 .3968 .44498 Mtetra
.658 .753 .92 r
.3968 .44498 .40301 .45126 .41341 .44777 .40723 .44147 Mtetra
.659 .754 .92 r
.40723 .44147 .41341 .44777 .42386 .44426 .4177 .43793 Mtetra
.4177 .43793 .42386 .44426 .43434 .44073 .42821 .43438 Mtetra
.42821 .43438 .43434 .44073 .44487 .4372 .43876 .43082 Mtetra
.659 .753 .92 r
.43876 .43082 .44487 .4372 .45543 .43366 .44935 .42725 Mtetra
.658 .753 .92 r
.44935 .42725 .45543 .43366 .46604 .43012 .45999 .42368 Mtetra
.45999 .42368 .46604 .43012 .47669 .42656 .47066 .4201 Mtetra
.47066 .4201 .47669 .42656 .48737 .423 .48138 .4165 Mtetra
.48138 .4165 .48737 .423 .4981 .41942 .49213 .4129 Mtetra
.49213 .4129 .4981 .41942 .50888 .41584 .50293 .40929 Mtetra
.50293 .40929 .50888 .41584 .51969 .41224 .51378 .40566 Mtetra
.657 .753 .92 r
.51378 .40566 .51969 .41224 .53055 .40863 .52466 .40203 Mtetra
.52466 .40203 .53055 .40863 .54145 .40501 .53559 .39838 Mtetra
.53559 .39838 .54145 .40501 .55239 .40137 .54656 .39471 Mtetra
.657 .752 .92 r
.54656 .39471 .55239 .40137 .56337 .39772 .55757 .39104 Mtetra
.55757 .39104 .56337 .39772 .5744 .39406 .56863 .38735 Mtetra
.56863 .38735 .5744 .39406 .58547 .39038 .57973 .38365 Mtetra
.57973 .38365 .58547 .39038 .59659 .3867 .59088 .37993 Mtetra
.59088 .37993 .59659 .3867 .60775 .38299 .60207 .3762 Mtetra
.60207 .3762 .60775 .38299 .61896 .37928 .61331 .37245 Mtetra
.61331 .37245 .61896 .37928 .63021 .37555 .62459 .3687 Mtetra
.62459 .3687 .63021 .37555 .6415 .3718 .63591 .36492 Mtetra
.63591 .36492 .6415 .3718 .65285 .36804 .64729 .36114 Mtetra
.64729 .36114 .65285 .36804 .66423 .36427 .6587 .35733 Mtetra
.6587 .35733 .66423 .36427 .67566 .36048 .67017 .35352 Mtetra
.67017 .35352 .67566 .36048 .68714 .35668 .68168 .34968 Mtetra
.68168 .34968 .68714 .35668 .69867 .35286 .69324 .34584 Mtetra
.69324 .34584 .69867 .35286 .71024 .34902 .70484 .34198 Mtetra
.70484 .34198 .71024 .34902 .72186 .34518 .7165 .3381 Mtetra
.7165 .3381 .72186 .34518 .73353 .34131 .7282 .3342 Mtetra
.7282 .3342 .73353 .34131 .74524 .33743 .73994 .3303 Mtetra
.73994 .3303 .74524 .33743 .75701 .33354 .75174 .32637 Mtetra
.75174 .32637 .75701 .33354 .76882 .32963 .76359 .32243 Mtetra
.76359 .32243 .76882 .32963 .78068 .32571 .77548 .31848 Mtetra
.77548 .31848 .78068 .32571 .79258 .32176 .78742 .31451 Mtetra
.78742 .31451 .79258 .32176 .80454 .31781 .79942 .31052 Mtetra
.79942 .31052 .80454 .31781 .81655 .31383 .81146 .30651 Mtetra
.81146 .30651 .81655 .31383 .82861 .30984 .82355 .30249 Mtetra
.61 .719 .923 r
.18011 .50791 .18678 .51436 .19632 .51215 .18965 .50575 Mtetra
.601 .719 .927 r
.18965 .50575 .19632 .51215 .20575 .51138 .19922 .50377 Mtetra
.944 .591 .303 r
.19922 .50377 .20575 .51138 .2161 .50131 .2055 .53679 Mtetra
0 0 0 r
.2055 .53679 .2161 .50131 .22556 .50106 .21898 .49432 Mtetra
.602 .709 .919 r
.21898 .49432 .22556 .50106 .23526 .49866 .22866 .49231 Mtetra
.626 .731 .923 r
.22866 .49231 .23526 .49866 .245 .49617 .23843 .48976 Mtetra
.611 .725 .926 r
.23843 .48976 .245 .49617 .25469 .49491 .24822 .4875 Mtetra
0 0 .502 r
.24822 .4875 .25469 .49491 .26517 .48425 .25708 .49717 Mtetra
.688 .844 .421 r
.25708 .49717 .26517 .48425 .2748 .48459 .26833 .47769 Mtetra
.603 .708 .918 r
.26833 .47769 .2748 .48459 .28471 .48202 .27821 .47563 Mtetra
.635 .736 .921 r
.27821 .47563 .28471 .48202 .29467 .47914 .28819 .47282 Mtetra
.64 .74 .921 r
.28819 .47282 .29467 .47914 .30468 .47622 .29823 .46987 Mtetra
.637 .739 .922 r
.29823 .46987 .30468 .47622 .31472 .47353 .30829 .46699 Mtetra
.61 .725 .927 r
.30829 .46699 .31472 .47353 .32466 .47301 .31836 .4647 Mtetra
.916 .72 .624 r
.31836 .4647 .32466 .47301 .33524 .46251 .33089 .4221 Mtetra
0 0 .469 r
.33089 .4221 .33524 .46251 .3453 .46129 .33896 .45448 Mtetra
.621 .721 .918 r
.33896 .45448 .3453 .46129 .3555 .45839 .34916 .45194 Mtetra
.644 .742 .92 r
.34916 .45194 .3555 .45839 .36576 .45518 .35944 .44882 Mtetra
.651 .747 .92 r
.35944 .44882 .36576 .45518 .37606 .45185 .36976 .44551 Mtetra
.654 .75 .92 r
.36976 .44551 .37606 .45185 .38641 .44845 .38013 .44211 Mtetra
.657 .752 .92 r
.38013 .44211 .38641 .44845 .3968 .44498 .39055 .43864 Mtetra
.658 .753 .92 r
.39055 .43864 .3968 .44498 .40723 .44147 .401 .43512 Mtetra
.659 .754 .92 r
.401 .43512 .40723 .44147 .4177 .43793 .4115 .43156 Mtetra
.4115 .43156 .4177 .43793 .42821 .43438 .42203 .42799 Mtetra
.42203 .42799 .42821 .43438 .43876 .43082 .43261 .4244 Mtetra
.43261 .4244 .43876 .43082 .44935 .42725 .44323 .4208 Mtetra
.658 .753 .92 r
.44323 .4208 .44935 .42725 .45999 .42368 .45389 .4172 Mtetra
.45389 .4172 .45999 .42368 .47066 .4201 .46459 .41358 Mtetra
.46459 .41358 .47066 .4201 .48138 .4165 .47533 .40996 Mtetra
.47533 .40996 .48138 .4165 .49213 .4129 .48612 .40633 Mtetra
.48612 .40633 .49213 .4129 .50293 .40929 .49695 .40269 Mtetra
.49695 .40269 .50293 .40929 .51378 .40566 .50782 .39904 Mtetra
.50782 .39904 .51378 .40566 .52466 .40203 .51873 .39538 Mtetra
.657 .753 .92 r
.51873 .39538 .52466 .40203 .53559 .39838 .52969 .3917 Mtetra
.52969 .3917 .53559 .39838 .54656 .39471 .54069 .38801 Mtetra
.657 .752 .92 r
.54069 .38801 .54656 .39471 .55757 .39104 .55173 .3843 Mtetra
.55173 .3843 .55757 .39104 .56863 .38735 .56282 .38059 Mtetra
.56282 .38059 .56863 .38735 .57973 .38365 .57395 .37686 Mtetra
.57395 .37686 .57973 .38365 .59088 .37993 .58512 .37311 Mtetra
.58512 .37311 .59088 .37993 .60207 .3762 .59635 .36935 Mtetra
.59635 .36935 .60207 .3762 .61331 .37245 .60761 .36558 Mtetra
.60761 .36558 .61331 .37245 .62459 .3687 .61892 .36179 Mtetra
.61892 .36179 .62459 .3687 .63591 .36492 .63028 .35799 Mtetra
.63028 .35799 .63591 .36492 .64729 .36114 .64168 .35418 Mtetra
.64168 .35418 .64729 .36114 .6587 .35733 .65313 .35035 Mtetra
.65313 .35035 .6587 .35733 .67017 .35352 .66463 .3465 Mtetra
.66463 .3465 .67017 .35352 .68168 .34968 .67617 .34264 Mtetra
.67617 .34264 .68168 .34968 .69324 .34584 .68777 .33876 Mtetra
.68777 .33876 .69324 .34584 .70484 .34198 .6994 .33487 Mtetra
.6994 .33487 .70484 .34198 .7165 .3381 .71109 .33096 Mtetra
.71109 .33096 .7165 .3381 .7282 .3342 .72282 .32704 Mtetra
.72282 .32704 .7282 .3342 .73994 .3303 .7346 .3231 Mtetra
.7346 .3231 .73994 .3303 .75174 .32637 .74644 .31915 Mtetra
.74644 .31915 .75174 .32637 .76359 .32243 .75832 .31518 Mtetra
.75832 .31518 .76359 .32243 .77548 .31848 .77024 .31119 Mtetra
.77024 .31119 .77548 .31848 .78742 .31451 .78222 .30719 Mtetra
.78222 .30719 .78742 .31451 .79942 .31052 .79425 .30317 Mtetra
.79425 .30317 .79942 .31052 .81146 .30651 .80633 .29914 Mtetra
.80633 .29914 .81146 .30651 .82355 .30249 .81846 .29509 Mtetra
.585 .696 .919 r
.17344 .50098 .18011 .50791 .18965 .50575 .18294 .49935 Mtetra
.613 .724 .924 r
.18294 .49935 .18965 .50575 .19922 .50377 .19255 .49709 Mtetra
.536 .688 .937 r
.19255 .49709 .19922 .50377 .2055 .53679 .20206 .49627 Mtetra
.634 .455 .623 r
.20206 .49627 .2055 .53679 .21898 .49432 .2125 .48612 Mtetra
.524 .635 .902 r
.2125 .48612 .21898 .49432 .22866 .49231 .22203 .48582 Mtetra
.621 .726 .922 r
.22203 .48582 .22866 .49231 .23843 .48976 .23181 .48336 Mtetra
.624 .731 .924 r
.23181 .48336 .23843 .48976 .24822 .4875 .24164 .48082 Mtetra
.563 .701 .934 r
.24164 .48082 .24822 .4875 .25708 .49717 .2514 .47951 Mtetra
.72 .585 .703 r
.2514 .47951 .25708 .49717 .26833 .47769 .26197 .46876 Mtetra
.499 .605 .889 r
.26197 .46876 .26833 .47769 .27821 .47563 .27168 .46905 Mtetra
.626 .728 .92 r
.27168 .46905 .27821 .47563 .28819 .47282 .28167 .46643 Mtetra
.639 .739 .921 r
.28167 .46643 .28819 .47282 .29823 .46987 .29172 .46349 Mtetra
.639 .74 .922 r
.29172 .46349 .29823 .46987 .30829 .46699 .30182 .46052 Mtetra
.629 .735 .924 r
.30182 .46052 .30829 .46699 .31836 .4647 .31194 .45777 Mtetra
.519 .679 .938 r
.31194 .45777 .31836 .4647 .33089 .4221 .32196 .4572 Mtetra
.358 .079 .346 r
.32196 .4572 .33089 .4221 .33896 .45448 .33263 .4466 Mtetra
.567 .669 .907 r
.33263 .4466 .33896 .45448 .34916 .45194 .34278 .44534 Mtetra
.637 .736 .92 r
.34278 .44534 .34916 .45194 .35944 .44882 .35307 .44237 Mtetra
.648 .745 .92 r
.35307 .44237 .35944 .44882 .36976 .44551 .36342 .43911 Mtetra
.653 .749 .92 r
.36342 .43911 .36976 .44551 .38013 .44211 .37381 .43572 Mtetra
.656 .751 .92 r
.37381 .43572 .38013 .44211 .39055 .43864 .38425 .43224 Mtetra
.657 .752 .92 r
.38425 .43224 .39055 .43864 .401 .43512 .39473 .42871 Mtetra
.658 .753 .92 r
.39473 .42871 .401 .43512 .4115 .43156 .40525 .42514 Mtetra
.659 .754 .92 r
.40525 .42514 .4115 .43156 .42203 .42799 .41581 .42154 Mtetra
.41581 .42154 .42203 .42799 .43261 .4244 .42642 .41793 Mtetra
.42642 .41793 .43261 .4244 .44323 .4208 .43706 .4143 Mtetra
.659 .753 .92 r
.43706 .4143 .44323 .4208 .45389 .4172 .44775 .41067 Mtetra
.658 .753 .92 r
.44775 .41067 .45389 .4172 .46459 .41358 .45848 .40703 Mtetra
.45848 .40703 .46459 .41358 .47533 .40996 .46925 .40338 Mtetra
.46925 .40338 .47533 .40996 .48612 .40633 .48006 .39972 Mtetra
.48006 .39972 .48612 .40633 .49695 .40269 .49092 .39605 Mtetra
.49092 .39605 .49695 .40269 .50782 .39904 .50181 .39237 Mtetra
.50181 .39237 .50782 .39904 .51873 .39538 .51276 .38868 Mtetra
.657 .753 .92 r
.51276 .38868 .51873 .39538 .52969 .3917 .52374 .38497 Mtetra
.52374 .38497 .52969 .3917 .54069 .38801 .53477 .38125 Mtetra
.53477 .38125 .54069 .38801 .55173 .3843 .54584 .37752 Mtetra
.657 .752 .92 r
.54584 .37752 .55173 .3843 .56282 .38059 .55696 .37378 Mtetra
.55696 .37378 .56282 .38059 .57395 .37686 .56812 .37002 Mtetra
.56812 .37002 .57395 .37686 .58512 .37311 .57933 .36625 Mtetra
.57933 .36625 .58512 .37311 .59635 .36935 .59058 .36246 Mtetra
.59058 .36246 .59635 .36935 .60761 .36558 .60187 .35866 Mtetra
.60187 .35866 .60761 .36558 .61892 .36179 .61322 .35484 Mtetra
.61322 .35484 .61892 .36179 .63028 .35799 .62461 .35101 Mtetra
.62461 .35101 .63028 .35799 .64168 .35418 .63604 .34717 Mtetra
.63604 .34717 .64168 .35418 .65313 .35035 .64752 .34331 Mtetra
.64752 .34331 .65313 .35035 .66463 .3465 .65905 .33943 Mtetra
.65905 .33943 .66463 .3465 .67617 .34264 .67063 .33554 Mtetra
.67063 .33554 .67617 .34264 .68777 .33876 .68225 .33164 Mtetra
.68225 .33164 .68777 .33876 .6994 .33487 .69392 .32771 Mtetra
.69392 .32771 .6994 .33487 .71109 .33096 .70564 .32378 Mtetra
.70564 .32378 .71109 .33096 .72282 .32704 .71741 .31982 Mtetra
.71741 .31982 .72282 .32704 .7346 .3231 .72922 .31586 Mtetra
.72922 .31586 .7346 .3231 .74644 .31915 .74109 .31187 Mtetra
.74109 .31187 .74644 .31915 .75832 .31518 .753 .30787 Mtetra
.753 .30787 .75832 .31518 .77024 .31119 .76497 .30385 Mtetra
.76497 .30385 .77024 .31119 .78222 .30719 .77698 .29982 Mtetra
.77698 .29982 .78222 .30719 .79425 .30317 .78905 .29577 Mtetra
.78905 .29577 .79425 .30317 .80633 .29914 .80116 .29171 Mtetra
.80116 .29171 .80633 .29914 .81846 .29509 .81333 .28762 Mtetra
.44 .554 .875 r
.16702 .49135 .17344 .50098 .18294 .49935 .1762 .49279 Mtetra
.61 .719 .923 r
.1762 .49279 .18294 .49935 .19255 .49709 .18582 .49058 Mtetra
.601 .719 .927 r
.18582 .49058 .19255 .49709 .20206 .49627 .19546 .48855 Mtetra
.944 .59 .298 r
.19546 .48855 .20206 .49627 .2125 .48612 .20175 .52167 Mtetra
0 0 0 r
.20175 .52167 .2125 .48612 .22203 .48582 .21539 .47897 Mtetra
.602 .709 .92 r
.21539 .47897 .22203 .48582 .23181 .48336 .22515 .47691 Mtetra
.626 .731 .923 r
.22515 .47691 .23181 .48336 .24164 .48082 .235 .4743 Mtetra
.612 .725 .926 r
.235 .4743 .24164 .48082 .2514 .47951 .24486 .47199 Mtetra
0 0 .509 r
.24486 .47199 .2514 .47951 .26197 .46876 .25379 .48165 Mtetra
.697 .85 .43 r
.25379 .48165 .26197 .46876 .27168 .46905 .26514 .46204 Mtetra
.603 .708 .918 r
.26514 .46204 .27168 .46905 .28167 .46643 .27511 .45993 Mtetra
.635 .736 .921 r
.27511 .45993 .28167 .46643 .29172 .46349 .28517 .45706 Mtetra
.64 .74 .921 r
.28517 .45706 .29172 .46349 .30182 .46052 .29529 .45405 Mtetra
.637 .739 .922 r
.29529 .45405 .30182 .46052 .31194 .45777 .30544 .45111 Mtetra
.61 .725 .927 r
.30544 .45111 .31194 .45777 .32196 .4572 .3156 .44877 Mtetra
.917 .721 .622 r
.3156 .44877 .32196 .4572 .33263 .4466 .32826 .40595 Mtetra
0 0 .466 r
.32826 .40595 .33263 .4466 .34278 .44534 .33637 .43841 Mtetra
.621 .721 .918 r
.33637 .43841 .34278 .44534 .35307 .44237 .34666 .43581 Mtetra
.644 .742 .92 r
.34666 .43581 .35307 .44237 .36342 .43911 .35703 .43263 Mtetra
.651 .747 .92 r
.35703 .43263 .36342 .43911 .37381 .43572 .36744 .42926 Mtetra
.654 .75 .92 r
.36744 .42926 .37381 .43572 .38425 .43224 .37791 .42579 Mtetra
.657 .752 .92 r
.37791 .42579 .38425 .43224 .39473 .42871 .38841 .42226 Mtetra
.658 .753 .92 r
.38841 .42226 .39473 .42871 .40525 .42514 .39896 .41867 Mtetra
.659 .754 .92 r
.39896 .41867 .40525 .42514 .41581 .42154 .40955 .41505 Mtetra
.40955 .41505 .41581 .42154 .42642 .41793 .42018 .41141 Mtetra
.42018 .41141 .42642 .41793 .43706 .4143 .43085 .40776 Mtetra
.43085 .40776 .43706 .4143 .44775 .41067 .44156 .40409 Mtetra
.658 .753 .92 r
.44156 .40409 .44775 .41067 .45848 .40703 .45232 .40042 Mtetra
.45232 .40042 .45848 .40703 .46925 .40338 .46312 .39674 Mtetra
.46312 .39674 .46925 .40338 .48006 .39972 .47396 .39306 Mtetra
.47396 .39306 .48006 .39972 .49092 .39605 .48484 .38936 Mtetra
.48484 .38936 .49092 .39605 .50181 .39237 .49577 .38565 Mtetra
.49577 .38565 .50181 .39237 .51276 .38868 .50674 .38193 Mtetra
.50674 .38193 .51276 .38868 .52374 .38497 .51775 .3782 Mtetra
.657 .753 .92 r
.51775 .3782 .52374 .38497 .53477 .38125 .52881 .37445 Mtetra
.52881 .37445 .53477 .38125 .54584 .37752 .53991 .37069 Mtetra
.657 .752 .92 r
.53991 .37069 .54584 .37752 .55696 .37378 .55106 .36692 Mtetra
.55106 .36692 .55696 .37378 .56812 .37002 .56225 .36313 Mtetra
.56225 .36313 .56812 .37002 .57933 .36625 .57348 .35933 Mtetra
.57348 .35933 .57933 .36625 .59058 .36246 .58477 .35551 Mtetra
.58477 .35551 .59058 .36246 .60187 .35866 .59609 .35168 Mtetra
.59609 .35168 .60187 .35866 .61322 .35484 .60747 .34784 Mtetra
.60747 .34784 .61322 .35484 .62461 .35101 .61889 .34398 Mtetra
.61889 .34398 .62461 .35101 .63604 .34717 .63036 .3401 Mtetra
.63036 .3401 .63604 .34717 .64752 .34331 .64187 .33621 Mtetra
.64187 .33621 .64752 .34331 .65905 .33943 .65343 .33231 Mtetra
.65343 .33231 .65905 .33943 .67063 .33554 .66504 .32839 Mtetra
.66504 .32839 .67063 .33554 .68225 .33164 .67669 .32445 Mtetra
.67669 .32445 .68225 .33164 .69392 .32771 .6884 .3205 Mtetra
.6884 .3205 .69392 .32771 .70564 .32378 .70015 .31653 Mtetra
.70015 .31653 .70564 .32378 .71741 .31982 .71195 .31255 Mtetra
.71195 .31255 .71741 .31982 .72922 .31586 .7238 .30855 Mtetra
.7238 .30855 .72922 .31586 .74109 .31187 .7357 .30454 Mtetra
.7357 .30454 .74109 .31187 .753 .30787 .74765 .30051 Mtetra
.74765 .30051 .753 .30787 .76497 .30385 .75965 .29646 Mtetra
.75965 .29646 .76497 .30385 .77698 .29982 .7717 .29239 Mtetra
.7717 .29239 .77698 .29982 .78905 .29577 .7838 .28831 Mtetra
.7838 .28831 .78905 .29577 .80116 .29171 .79595 .28421 Mtetra
.79595 .28421 .80116 .29171 .81333 .28762 .80815 .2801 Mtetra
.747 .936 .596 r
.15851 .50033 .16702 .49135 .1762 .49279 .16946 .48575 Mtetra
.585 .697 .919 r
.16946 .48575 .1762 .49279 .18582 .49058 .17903 .48407 Mtetra
.613 .724 .924 r
.17903 .48407 .18582 .49058 .19546 .48855 .18872 .48175 Mtetra
.536 .688 .937 r
.18872 .48175 .19546 .48855 .20175 .52167 .1983 .48089 Mtetra
.633 .453 .622 r
.1983 .48089 .20175 .52167 .21539 .47897 .20884 .47065 Mtetra
.524 .635 .902 r
.20884 .47065 .21539 .47897 .22515 .47691 .21845 .47031 Mtetra
.621 .726 .922 r
.21845 .47031 .22515 .47691 .235 .4743 .2283 .46779 Mtetra
.624 .731 .924 r
.2283 .46779 .235 .4743 .24486 .47199 .23821 .4652 Mtetra
.563 .701 .933 r
.23821 .4652 .24486 .47199 .25379 .48165 .24806 .46383 Mtetra
.72 .585 .703 r
.24806 .46383 .25379 .48165 .26514 .46204 .25872 .45299 Mtetra
.499 .605 .889 r
.25872 .45299 .26514 .46204 .27511 .45993 .26851 .45324 Mtetra
.626 .728 .92 r
.26851 .45324 .27511 .45993 .28517 .45706 .27858 .45056 Mtetra
.639 .739 .921 r
.27858 .45056 .28517 .45706 .29529 .45405 .28872 .44756 Mtetra
.639 .74 .922 r
.28872 .44756 .29529 .45405 .30544 .45111 .2989 .44453 Mtetra
.629 .735 .924 r
.2989 .44453 .30544 .45111 .3156 .44877 .3091 .44172 Mtetra
.52 .679 .937 r
.3091 .44172 .3156 .44877 .32826 .40595 .31921 .4411 Mtetra
.351 .069 .338 r
.31921 .4411 .32826 .40595 .33637 .43841 .32998 .43041 Mtetra
.567 .669 .907 r
.32998 .43041 .33637 .43841 .34666 .43581 .34022 .42909 Mtetra
.637 .736 .92 r
.34022 .42909 .34666 .43581 .35703 .43263 .3506 .42606 Mtetra
.648 .745 .92 r
.3506 .42606 .35703 .43263 .36744 .42926 .36103 .42274 Mtetra
.653 .749 .92 r
.36103 .42274 .36744 .42926 .37791 .42579 .37152 .41928 Mtetra
.656 .751 .92 r
.37152 .41928 .37791 .42579 .38841 .42226 .38205 .41574 Mtetra
.657 .752 .92 r
.38205 .41574 .38841 .42226 .39896 .41867 .39262 .41215 Mtetra
.658 .753 .92 r
.39262 .41215 .39896 .41867 .40955 .41505 .40323 .40851 Mtetra
.659 .754 .92 r
.40323 .40851 .40955 .41505 .42018 .41141 .41389 .40485 Mtetra
.41389 .40485 .42018 .41141 .43085 .40776 .42459 .40116 Mtetra
.42459 .40116 .43085 .40776 .44156 .40409 .43533 .39747 Mtetra
.659 .753 .92 r
.43533 .39747 .44156 .40409 .45232 .40042 .44611 .39377 Mtetra
.658 .753 .92 r
.44611 .39377 .45232 .40042 .46312 .39674 .45694 .39006 Mtetra
.45694 .39006 .46312 .39674 .47396 .39306 .46781 .38635 Mtetra
.46781 .38635 .47396 .39306 .48484 .38936 .47872 .38262 Mtetra
.47872 .38262 .48484 .38936 .49577 .38565 .48968 .37888 Mtetra
.48968 .37888 .49577 .38565 .50674 .38193 .50067 .37513 Mtetra
.50067 .37513 .50674 .38193 .51775 .3782 .51172 .37137 Mtetra
.657 .753 .92 r
.51172 .37137 .51775 .3782 .52881 .37445 .5228 .36759 Mtetra
.5228 .36759 .52881 .37445 .53991 .37069 .53393 .36381 Mtetra
.53393 .36381 .53991 .37069 .55106 .36692 .54511 .36 Mtetra
.657 .752 .92 r
.54511 .36 .55106 .36692 .56225 .36313 .55633 .35619 Mtetra
.55633 .35619 .56225 .36313 .57348 .35933 .5676 .35236 Mtetra
.5676 .35236 .57348 .35933 .58477 .35551 .57891 .34851 Mtetra
.57891 .34851 .58477 .35551 .59609 .35168 .59027 .34465 Mtetra
.59027 .34465 .59609 .35168 .60747 .34784 .60168 .34078 Mtetra
.60168 .34078 .60747 .34784 .61889 .34398 .61313 .33689 Mtetra
.61313 .33689 .61889 .34398 .63036 .3401 .62463 .33299 Mtetra
.62463 .33299 .63036 .3401 .64187 .33621 .63617 .32907 Mtetra
.63617 .32907 .64187 .33621 .65343 .33231 .64777 .32513 Mtetra
.64777 .32513 .65343 .33231 .66504 .32839 .65941 .32118 Mtetra
.65941 .32118 .66504 .32839 .67669 .32445 .6711 .31722 Mtetra
.6711 .31722 .67669 .32445 .6884 .3205 .68283 .31323 Mtetra
.68283 .31323 .6884 .3205 .70015 .31653 .69462 .30924 Mtetra
.69462 .30924 .70015 .31653 .71195 .31255 .70645 .30522 Mtetra
.70645 .30522 .71195 .31255 .7238 .30855 .71834 .30119 Mtetra
.71834 .30119 .7238 .30855 .7357 .30454 .73027 .29715 Mtetra
.73027 .29715 .7357 .30454 .74765 .30051 .74226 .29308 Mtetra
.74226 .29308 .74765 .30051 .75965 .29646 .75429 .289 Mtetra
.75429 .289 .75965 .29646 .7717 .29239 .76638 .28491 Mtetra
.76638 .28491 .7717 .29239 .7838 .28831 .77851 .28079 Mtetra
.77851 .28079 .7838 .28831 .79595 .28421 .7907 .27666 Mtetra
.7907 .27666 .79595 .28421 .80815 .2801 .80294 .27252 Mtetra
.757 .64 .732 r
.15236 .48723 .15851 .50033 .16946 .48575 .16297 .476 Mtetra
.44 .554 .875 r
.16297 .476 .16946 .48575 .17903 .48407 .17222 .4774 Mtetra
.61 .719 .923 r
.17222 .4774 .17903 .48407 .18872 .48175 .18191 .47514 Mtetra
.601 .719 .927 r
.18191 .47514 .18872 .48175 .1983 .48089 .19163 .47305 Mtetra
.944 .588 .293 r
.19163 .47305 .1983 .48089 .20884 .47065 .19793 .50627 Mtetra
0 0 0 r
.19793 .50627 .20884 .47065 .21845 .47031 .21173 .46334 Mtetra
.602 .709 .92 r
.21173 .46334 .21845 .47031 .2283 .46779 .22157 .46123 Mtetra
.626 .731 .923 r
.22157 .46123 .2283 .46779 .23821 .4652 .2315 .45856 Mtetra
.612 .725 .926 r
.2315 .45856 .23821 .4652 .24806 .46383 .24144 .4562 Mtetra
0 0 .516 r
.24144 .4562 .24806 .46383 .25872 .45299 .25043 .46585 Mtetra
.705 .857 .439 r
.25043 .46585 .25872 .45299 .26851 .45324 .2619 .44611 Mtetra
.603 .708 .918 r
.2619 .44611 .26851 .45324 .27858 .45056 .27195 .44394 Mtetra
.635 .736 .921 r
.27195 .44394 .27858 .45056 .28872 .44756 .2821 .44101 Mtetra
.64 .74 .921 r
.2821 .44101 .28872 .44756 .2989 .44453 .2923 .43795 Mtetra
.637 .739 .922 r
.2923 .43795 .2989 .44453 .3091 .44172 .30254 .43494 Mtetra
.61 .725 .927 r
.30254 .43494 .3091 .44172 .31921 .4411 .31278 .43254 Mtetra
.918 .721 .621 r
.31278 .43254 .31921 .4411 .32998 .43041 .32559 .3895 Mtetra
0 0 .462 r
.32559 .3895 .32998 .43041 .34022 .42909 .33374 .42204 Mtetra
.621 .721 .918 r
.33374 .42204 .34022 .42909 .3506 .42606 .34412 .41939 Mtetra
.644 .742 .92 r
.34412 .41939 .3506 .42606 .36103 .42274 .35458 .41614 Mtetra
.651 .747 .92 r
.35458 .41614 .36103 .42274 .37152 .41928 .36508 .41271 Mtetra
.654 .75 .92 r
.36508 .41271 .37152 .41928 .38205 .41574 .37564 .40917 Mtetra
.657 .752 .92 r
.37564 .40917 .38205 .41574 .39262 .41215 .38623 .40557 Mtetra
.658 .753 .92 r
.38623 .40557 .39262 .41215 .40323 .40851 .39688 .40192 Mtetra
.659 .754 .92 r
.39688 .40192 .40323 .40851 .41389 .40485 .40756 .39823 Mtetra
.40756 .39823 .41389 .40485 .42459 .40116 .41829 .39452 Mtetra
.41829 .39452 .42459 .40116 .43533 .39747 .42905 .3908 Mtetra
.42905 .3908 .43533 .39747 .44611 .39377 .43986 .38707 Mtetra
.658 .753 .92 r
.43986 .38707 .44611 .39377 .45694 .39006 .45072 .38333 Mtetra
.45072 .38333 .45694 .39006 .46781 .38635 .46161 .37959 Mtetra
.46161 .37959 .46781 .38635 .47872 .38262 .47255 .37583 Mtetra
.47255 .37583 .47872 .38262 .48968 .37888 .48354 .37206 Mtetra
.48354 .37206 .48968 .37888 .50067 .37513 .49457 .36828 Mtetra
.49457 .36828 .50067 .37513 .51172 .37137 .50564 .36449 Mtetra
.50564 .36449 .51172 .37137 .5228 .36759 .51675 .36069 Mtetra
.657 .753 .92 r
.51675 .36069 .5228 .36759 .53393 .36381 .52791 .35687 Mtetra
.52791 .35687 .53393 .36381 .54511 .36 .53912 .35304 Mtetra
.657 .752 .92 r
.53912 .35304 .54511 .36 .55633 .35619 .55037 .34919 Mtetra
.55037 .34919 .55633 .35619 .5676 .35236 .56167 .34534 Mtetra
.56167 .34534 .5676 .35236 .57891 .34851 .57301 .34146 Mtetra
.57301 .34146 .57891 .34851 .59027 .34465 .5844 .33757 Mtetra
.5844 .33757 .59027 .34465 .60168 .34078 .59584 .33367 Mtetra
.59584 .33367 .60168 .34078 .61313 .33689 .60732 .32975 Mtetra
.60732 .32975 .61313 .33689 .62463 .33299 .61885 .32582 Mtetra
.61885 .32582 .62463 .33299 .63617 .32907 .63043 .32187 Mtetra
.63043 .32187 .63617 .32907 .64777 .32513 .64206 .3179 Mtetra
.64206 .3179 .64777 .32513 .65941 .32118 .65373 .31392 Mtetra
.65373 .31392 .65941 .32118 .6711 .31722 .66545 .30992 Mtetra
.66545 .30992 .6711 .31722 .68283 .31323 .67722 .30591 Mtetra
.67722 .30591 .68283 .31323 .69462 .30924 .68904 .30188 Mtetra
.68904 .30188 .69462 .30924 .70645 .30522 .70091 .29784 Mtetra
.70091 .29784 .70645 .30522 .71834 .30119 .71283 .29378 Mtetra
.71283 .29378 .71834 .30119 .73027 .29715 .7248 .2897 Mtetra
.7248 .2897 .73027 .29715 .74226 .29308 .73682 .2856 Mtetra
.73682 .2856 .74226 .29308 .75429 .289 .74889 .28149 Mtetra
.74889 .28149 .75429 .289 .76638 .28491 .76101 .27736 Mtetra
.76101 .27736 .76638 .28491 .77851 .28079 .77319 .27322 Mtetra
.77319 .27322 .77851 .28079 .7907 .27666 .78541 .26906 Mtetra
.78541 .26906 .7907 .27666 .80294 .27252 .79769 .26488 Mtetra
0 .347 .821 r
.14553 .47985 .15236 .48723 .16297 .476 .15435 .48493 Mtetra
.754 .94 .604 r
.15435 .48493 .16297 .476 .17222 .4774 .1654 .47025 Mtetra
.585 .697 .919 r
.1654 .47025 .17222 .4774 .18191 .47514 .17506 .46852 Mtetra
.613 .724 .924 r
.17506 .46852 .18191 .47514 .19163 .47305 .18482 .46615 Mtetra
.536 .688 .937 r
.18482 .46615 .19163 .47305 .19793 .50627 .19448 .46524 Mtetra
.632 .451 .62 r
.19448 .46524 .19793 .50627 .21173 .46334 .20511 .4549 Mtetra
.524 .635 .902 r
.20511 .4549 .21173 .46334 .22157 .46123 .21479 .45451 Mtetra
.621 .726 .922 r
.21479 .45451 .22157 .46123 .2315 .45856 .22473 .45194 Mtetra
.624 .731 .924 r
.22473 .45194 .2315 .45856 .24144 .4562 .23472 .44929 Mtetra
.563 .701 .933 r
.23472 .44929 .24144 .4562 .25043 .46585 .24465 .44787 Mtetra
.72 .585 .703 r
.24465 .44787 .25043 .46585 .2619 .44611 .25541 .43694 Mtetra
.499 .605 .89 r
.25541 .43694 .2619 .44611 .27195 .44394 .26528 .43714 Mtetra
.626 .728 .92 r
.26528 .43714 .27195 .44394 .2821 .44101 .27544 .43439 Mtetra
.639 .739 .921 r
.27544 .43439 .2821 .44101 .2923 .43795 .28566 .43133 Mtetra
.639 .74 .922 r
.28566 .43133 .2923 .43795 .30254 .43494 .29592 .42824 Mtetra
.629 .735 .924 r
.29592 .42824 .30254 .43494 .31278 .43254 .30622 .42537 Mtetra
.52 .679 .937 r
.30622 .42537 .31278 .43254 .32559 .3895 .31641 .4247 Mtetra
.344 .06 .331 r
.31641 .4247 .32559 .3895 .33374 .42204 .32728 .41392 Mtetra
.566 .669 .907 r
.32728 .41392 .33374 .42204 .34412 .41939 .33761 .41254 Mtetra
.637 .736 .92 r
.33761 .41254 .34412 .41939 .35458 .41614 .34807 .40945 Mtetra
.648 .745 .92 r
.34807 .40945 .35458 .41614 .36508 .41271 .3586 .40606 Mtetra
.653 .749 .92 r
.3586 .40606 .36508 .41271 .37564 .40917 .36918 .40254 Mtetra
.656 .751 .92 r
.36918 .40254 .37564 .40917 .38623 .40557 .3798 .39894 Mtetra
.657 .752 .92 r
.3798 .39894 .38623 .40557 .39688 .40192 .39047 .39527 Mtetra
.658 .753 .92 r
.39047 .39527 .39688 .40192 .40756 .39823 .40118 .39157 Mtetra
.659 .754 .92 r
.40118 .39157 .40756 .39823 .41829 .39452 .41193 .38784 Mtetra
.41193 .38784 .41829 .39452 .42905 .3908 .42273 .38409 Mtetra
.42273 .38409 .42905 .3908 .43986 .38707 .43357 .38032 Mtetra
.659 .753 .92 r
.43357 .38032 .43986 .38707 .45072 .38333 .44445 .37655 Mtetra
.658 .753 .92 r
.44445 .37655 .45072 .38333 .46161 .37959 .45537 .37278 Mtetra
.45537 .37278 .46161 .37959 .47255 .37583 .46634 .36899 Mtetra
.46634 .36899 .47255 .37583 .48354 .37206 .47735 .36519 Mtetra
.47735 .36519 .48354 .37206 .49457 .36828 .48841 .36139 Mtetra
.48841 .36139 .49457 .36828 .50564 .36449 .49951 .35757 Mtetra
.49951 .35757 .50564 .36449 .51675 .36069 .51066 .35373 Mtetra
.657 .753 .92 r
.51066 .35373 .51675 .36069 .52791 .35687 .52185 .34988 Mtetra
.52185 .34988 .52791 .35687 .53912 .35304 .53308 .34602 Mtetra
.53308 .34602 .53912 .35304 .55037 .34919 .54437 .34215 Mtetra
.657 .752 .92 r
.54437 .34215 .55037 .34919 .56167 .34534 .55569 .33826 Mtetra
.55569 .33826 .56167 .34534 .57301 .34146 .56707 .33436 Mtetra
.56707 .33436 .57301 .34146 .5844 .33757 .57849 .33044 Mtetra
.57849 .33044 .5844 .33757 .59584 .33367 .58996 .3265 Mtetra
.58996 .3265 .59584 .33367 .60732 .32975 .60147 .32255 Mtetra
.60147 .32255 .60732 .32975 .61885 .32582 .61304 .31859 Mtetra
.61304 .31859 .61885 .32582 .63043 .32187 .62465 .31461 Mtetra
.62465 .31461 .63043 .32187 .64206 .3179 .63631 .31061 Mtetra
.63631 .31061 .64206 .3179 .65373 .31392 .64801 .3066 Mtetra
.64801 .3066 .65373 .31392 .66545 .30992 .65977 .30258 Mtetra
.65977 .30258 .66545 .30992 .67722 .30591 .67157 .29853 Mtetra
.67157 .29853 .67722 .30591 .68904 .30188 .68343 .29447 Mtetra
.68343 .29447 .68904 .30188 .70091 .29784 .69533 .29039 Mtetra
.69533 .29039 .70091 .29784 .71283 .29378 .70728 .2863 Mtetra
.70728 .2863 .71283 .29378 .7248 .2897 .71929 .28219 Mtetra
.71929 .28219 .7248 .2897 .73682 .2856 .73134 .27807 Mtetra
.73134 .27807 .73682 .2856 .74889 .28149 .74345 .27392 Mtetra
.74345 .27392 .74889 .28149 .76101 .27736 .75561 .26976 Mtetra
.75561 .26976 .76101 .27736 .77319 .27322 .76782 .26558 Mtetra
.76782 .26558 .77319 .27322 .78541 .26906 .78008 .26139 Mtetra
.78008 .26139 .78541 .26906 .79769 .26488 .79239 .25717 Mtetra
.561 .699 .933 r
.13859 .47303 .14553 .47985 .15435 .48493 .14814 .4717 Mtetra
.757 .64 .732 r
.14814 .4717 .15435 .48493 .1654 .47025 .15884 .46037 Mtetra
.439 .554 .875 r
.15884 .46037 .1654 .47025 .17506 .46852 .16816 .46174 Mtetra
.61 .719 .923 r
.16816 .46174 .17506 .46852 .18482 .46615 .17794 .45942 Mtetra
.601 .719 .927 r
.17794 .45942 .18482 .46615 .19448 .46524 .18774 .45728 Mtetra
.944 .587 .288 r
.18774 .45728 .19448 .46524 .20511 .4549 .19404 .49059 Mtetra
0 0 0 r
.19404 .49059 .20511 .4549 .21479 .45451 .208 .44743 Mtetra
.602 .709 .92 r
.208 .44743 .21479 .45451 .22473 .45194 .21792 .44526 Mtetra
.626 .731 .923 r
.21792 .44526 .22473 .45194 .23472 .44929 .22794 .44254 Mtetra
.612 .725 .926 r
.22794 .44254 .23472 .44929 .24465 .44787 .23796 .44011 Mtetra
0 0 .524 r
.23796 .44011 .24465 .44787 .25541 .43694 .24701 .44976 Mtetra
.714 .863 .448 r
.24701 .44976 .25541 .43694 .26528 .43714 .2586 .42989 Mtetra
.603 .708 .918 r
.2586 .42989 .26528 .43714 .27544 .43439 .26873 .42766 Mtetra
.635 .736 .921 r
.26873 .42766 .27544 .43439 .28566 .43133 .27897 .42467 Mtetra
.64 .74 .921 r
.27897 .42467 .28566 .43133 .29592 .42824 .28926 .42154 Mtetra
.637 .739 .922 r
.28926 .42154 .29592 .42824 .30622 .42537 .29958 .41848 Mtetra
.61 .725 .927 r
.29958 .41848 .30622 .42537 .31641 .4247 .30991 .41602 Mtetra
.919 .722 .62 r
.30991 .41602 .31641 .4247 .32728 .41392 .32287 .37275 Mtetra
0 0 .458 r
.32287 .37275 .32728 .41392 .33761 .41254 .33106 .40537 Mtetra
.621 .721 .918 r
.33106 .40537 .33761 .41254 .34807 .40945 .34153 .40265 Mtetra
.644 .742 .92 r
.34153 .40265 .34807 .40945 .3586 .40606 .35208 .39934 Mtetra
.651 .747 .92 r
.35208 .39934 .3586 .40606 .36918 .40254 .36268 .39584 Mtetra
.654 .75 .92 r
.36268 .39584 .36918 .40254 .3798 .39894 .37332 .39224 Mtetra
.657 .752 .92 r
.37332 .39224 .3798 .39894 .39047 .39527 .38402 .38857 Mtetra
.658 .753 .92 r
.38402 .38857 .39047 .39527 .40118 .39157 .39475 .38485 Mtetra
.659 .754 .92 r
.39475 .38485 .40118 .39157 .41193 .38784 .40553 .3811 Mtetra
.40553 .3811 .41193 .38784 .42273 .38409 .41636 .37732 Mtetra
.41636 .37732 .42273 .38409 .43357 .38032 .42722 .37353 Mtetra
.42722 .37353 .43357 .38032 .44445 .37655 .43813 .36973 Mtetra
.658 .753 .92 r
.43813 .36973 .44445 .37655 .45537 .37278 .44909 .36592 Mtetra
.44909 .36592 .45537 .37278 .46634 .36899 .46008 .3621 Mtetra
.46008 .3621 .46634 .36899 .47735 .36519 .47112 .35827 Mtetra
.47112 .35827 .47735 .36519 .48841 .36139 .48221 .35444 Mtetra
.48221 .35444 .48841 .36139 .49951 .35757 .49334 .35059 Mtetra
.49334 .35059 .49951 .35757 .51066 .35373 .50452 .34672 Mtetra
.50452 .34672 .51066 .35373 .52185 .34988 .51574 .34285 Mtetra
.657 .753 .92 r
.51574 .34285 .52185 .34988 .53308 .34602 .527 .33895 Mtetra
.527 .33895 .53308 .34602 .54437 .34215 .53832 .33505 Mtetra
.657 .752 .92 r
.53832 .33505 .54437 .34215 .55569 .33826 .54967 .33113 Mtetra
.54967 .33113 .55569 .33826 .56707 .33436 .56108 .3272 Mtetra
.56108 .3272 .56707 .33436 .57849 .33044 .57253 .32325 Mtetra
.57253 .32325 .57849 .33044 .58996 .3265 .58403 .31928 Mtetra
.58403 .31928 .58996 .3265 .60147 .32255 .59558 .3153 Mtetra
.59558 .3153 .60147 .32255 .61304 .31859 .60717 .31131 Mtetra
.60717 .31131 .61304 .31859 .62465 .31461 .61882 .3073 Mtetra
.61882 .3073 .62465 .31461 .63631 .31061 .63051 .30327 Mtetra
.63051 .30327 .63631 .31061 .64801 .3066 .64225 .29923 Mtetra
.64225 .29923 .64801 .3066 .65977 .30258 .65404 .29517 Mtetra
.65404 .29517 .65977 .30258 .67157 .29853 .66588 .29109 Mtetra
.66588 .29109 .67157 .29853 .68343 .29447 .67777 .287 Mtetra
.67777 .287 .68343 .29447 .69533 .29039 .6897 .28289 Mtetra
.6897 .28289 .69533 .29039 .70728 .2863 .70169 .27877 Mtetra
.70169 .27877 .70728 .2863 .71929 .28219 .71373 .27463 Mtetra
.71373 .27463 .71929 .28219 .73134 .27807 .72582 .27047 Mtetra
.72582 .27047 .73134 .27807 .74345 .27392 .73796 .26629 Mtetra
.73796 .26629 .74345 .27392 .75561 .26976 .75016 .2621 Mtetra
.75016 .2621 .75561 .26976 .76782 .26558 .7624 .25789 Mtetra
.7624 .25789 .76782 .26558 .78008 .26139 .7747 .25366 Mtetra
.7747 .25366 .78008 .26139 .79239 .25717 .78705 .24941 Mtetra
.599 .716 .927 r
.13159 .46628 .13859 .47303 .14814 .4717 .14124 .4642 Mtetra
0 .35 .823 r
.14124 .4642 .14814 .4717 .15884 .46037 .15011 .46926 Mtetra
.761 .944 .612 r
.15011 .46926 .15884 .46037 .16816 .46174 .16128 .45447 Mtetra
.585 .697 .919 r
.16128 .45447 .16816 .46174 .17794 .45942 .17101 .45268 Mtetra
.613 .724 .924 r
.17101 .45268 .17794 .45942 .18774 .45728 .18085 .45026 Mtetra
.536 .688 .936 r
.18085 .45026 .18774 .45728 .19404 .49059 .19058 .4493 Mtetra
.631 .45 .619 r
.19058 .4493 .19404 .49059 .208 .44743 .20131 .43887 Mtetra
.523 .635 .902 r
.20131 .43887 .208 .44743 .21792 .44526 .21107 .43843 Mtetra
.621 .726 .922 r
.21107 .43843 .21792 .44526 .22794 .44254 .2211 .4358 Mtetra
.624 .731 .924 r
.2211 .4358 .22794 .44254 .23796 .44011 .23117 .43309 Mtetra
.563 .701 .933 r
.23117 .43309 .23796 .44011 .24701 .44976 .24118 .43161 Mtetra
.72 .585 .703 r
.24118 .43161 .24701 .44976 .2586 .42989 .25204 .42059 Mtetra
.498 .605 .89 r
.25204 .42059 .2586 .42989 .26873 .42766 .26199 .42074 Mtetra
.626 .728 .921 r
.26199 .42074 .26873 .42766 .27897 .42467 .27223 .41793 Mtetra
.639 .739 .921 r
.27223 .41793 .27897 .42467 .28926 .42154 .28254 .41481 Mtetra
.639 .74 .922 r
.28254 .41481 .28926 .42154 .29958 .41848 .2929 .41166 Mtetra
.629 .735 .924 r
.2929 .41166 .29958 .41848 .30991 .41602 .30328 .40872 Mtetra
.52 .679 .937 r
.30328 .40872 .30991 .41602 .32287 .37275 .31356 .408 Mtetra
.336 .051 .323 r
.31356 .408 .32287 .37275 .33106 .40537 .32453 .39712 Mtetra
.566 .669 .907 r
.32453 .39712 .33106 .40537 .34153 .40265 .33494 .39569 Mtetra
.637 .736 .92 r
.33494 .39569 .34153 .40265 .35208 .39934 .34551 .39253 Mtetra
.648 .745 .92 r
.34551 .39253 .35208 .39934 .36268 .39584 .35613 .38907 Mtetra
.653 .749 .92 r
.35613 .38907 .36268 .39584 .37332 .39224 .3668 .38548 Mtetra
.656 .751 .92 r
.3668 .38548 .37332 .39224 .38402 .38857 .37752 .38181 Mtetra
.657 .752 .92 r
.37752 .38181 .38402 .38857 .39475 .38485 .38828 .37808 Mtetra
.658 .753 .92 r
.38828 .37808 .39475 .38485 .40553 .3811 .39909 .37431 Mtetra
.659 .754 .92 r
.39909 .37431 .40553 .3811 .41636 .37732 .40994 .3705 Mtetra
.40994 .3705 .41636 .37732 .42722 .37353 .42083 .36668 Mtetra
.42083 .36668 .42722 .37353 .43813 .36973 .43177 .36285 Mtetra
.659 .753 .92 r
.43177 .36285 .43813 .36973 .44909 .36592 .44275 .35901 Mtetra
.658 .753 .92 r
.44275 .35901 .44909 .36592 .46008 .3621 .45378 .35516 Mtetra
.45378 .35516 .46008 .3621 .47112 .35827 .46485 .3513 Mtetra
.46485 .3513 .47112 .35827 .48221 .35444 .47596 .34743 Mtetra
.47596 .34743 .48221 .35444 .49334 .35059 .48712 .34355 Mtetra
.48712 .34355 .49334 .35059 .50452 .34672 .49833 .33966 Mtetra
.49833 .33966 .50452 .34672 .51574 .34285 .50958 .33575 Mtetra
.657 .753 .92 r
.50958 .33575 .51574 .34285 .527 .33895 .52087 .33183 Mtetra
.52087 .33183 .527 .33895 .53832 .33505 .53222 .3279 Mtetra
.53222 .3279 .53832 .33505 .54967 .33113 .54361 .32395 Mtetra
.657 .752 .92 r
.54361 .32395 .54967 .33113 .56108 .3272 .55504 .31998 Mtetra
.55504 .31998 .56108 .3272 .57253 .32325 .56653 .316 Mtetra
.56653 .316 .57253 .32325 .58403 .31928 .57806 .31201 Mtetra
.57806 .31201 .58403 .31928 .59558 .3153 .58964 .308 Mtetra
.58964 .308 .59558 .3153 .60717 .31131 .60127 .30397 Mtetra
.60127 .30397 .60717 .31131 .61882 .3073 .61294 .29993 Mtetra
.61294 .29993 .61882 .3073 .63051 .30327 .62467 .29587 Mtetra
.62467 .29587 .63051 .30327 .64225 .29923 .63644 .2918 Mtetra
.63644 .2918 .64225 .29923 .65404 .29517 .64826 .28771 Mtetra
.64826 .28771 .65404 .29517 .66588 .29109 .66014 .2836 Mtetra
.66014 .2836 .66588 .29109 .67777 .287 .67206 .27948 Mtetra
.67206 .27948 .67777 .287 .6897 .28289 .68403 .27533 Mtetra
.68403 .27533 .6897 .28289 .70169 .27877 .69606 .27118 Mtetra
.69606 .27118 .70169 .27877 .71373 .27463 .70813 .267 Mtetra
.70813 .267 .71373 .27463 .72582 .27047 .72026 .26281 Mtetra
.72026 .26281 .72582 .27047 .73796 .26629 .73244 .2586 Mtetra
.73244 .2586 .73796 .26629 .75016 .2621 .74467 .25437 Mtetra
.74467 .25437 .75016 .2621 .7624 .25789 .75695 .25013 Mtetra
.75695 .25013 .7624 .25789 .7747 .25366 .76928 .24587 Mtetra
.76928 .24587 .7747 .25366 .78705 .24941 .78167 .24159 Mtetra
.6 .713 .924 r
.12456 .45939 .13159 .46628 .14124 .4642 .13422 .45727 Mtetra
.561 .699 .933 r
.13422 .45727 .14124 .4642 .15011 .46926 .14384 .45588 Mtetra
.757 .641 .732 r
.14384 .45588 .15011 .46926 .16128 .45447 .15465 .44447 Mtetra
.438 .554 .875 r
.15465 .44447 .16128 .45447 .17101 .45268 .16404 .44579 Mtetra
.61 .719 .923 r
.16404 .44579 .17101 .45268 .18085 .45026 .17389 .44342 Mtetra
.601 .719 .927 r
.17389 .44342 .18085 .45026 .19058 .4493 .18377 .44121 Mtetra
.944 .585 .283 r
.18377 .44121 .19058 .4493 .20131 .43887 .19008 .47462 Mtetra
0 0 0 r
.19008 .47462 .20131 .43887 .21107 .43843 .20421 .43123 Mtetra
.602 .71 .92 r
.20421 .43123 .21107 .43843 .2211 .4358 .21421 .429 Mtetra
.626 .731 .923 r
.21421 .429 .2211 .4358 .23117 .43309 .22431 .42622 Mtetra
.612 .725 .926 r
.22431 .42622 .23117 .43309 .24118 .43161 .23442 .42373 Mtetra
0 .004 .531 r
.23442 .42373 .24118 .43161 .25204 .42059 .24353 .43337 Mtetra
.722 .869 .457 r
.24353 .43337 .25204 .42059 .26199 .42074 .25523 .41337 Mtetra
.603 .708 .918 r
.25523 .41337 .26199 .42074 .27223 .41793 .26545 .41108 Mtetra
.635 .736 .921 r
.26545 .41108 .27223 .41793 .28254 .41481 .27578 .40803 Mtetra
.64 .74 .921 r
.27578 .40803 .28254 .41481 .2929 .41166 .28616 .40483 Mtetra
.637 .739 .922 r
.28616 .40483 .2929 .41166 .30328 .40872 .29657 .40171 Mtetra
.61 .725 .927 r
.29657 .40171 .30328 .40872 .31356 .408 .30699 .39918 Mtetra
.92 .723 .619 r
.30699 .39918 .31356 .408 .32453 .39712 .3201 .35569 Mtetra
0 0 .455 r
.3201 .35569 .32453 .39712 .33494 .39569 .32833 .38839 Mtetra
.621 .721 .918 r
.32833 .38839 .33494 .39569 .34551 .39253 .33889 .38561 Mtetra
.644 .742 .92 r
.33889 .38561 .34551 .39253 .35613 .38907 .34953 .38223 Mtetra
.651 .747 .92 r
.34953 .38223 .35613 .38907 .3668 .38548 .36023 .37866 Mtetra
.654 .75 .92 r
.36023 .37866 .3668 .38548 .37752 .38181 .37097 .37499 Mtetra
.657 .752 .92 r
.37097 .37499 .37752 .38181 .38828 .37808 .38176 .37125 Mtetra
.658 .753 .92 r
.38176 .37125 .38828 .37808 .39909 .37431 .39259 .36746 Mtetra
.659 .754 .92 r
.39259 .36746 .39909 .37431 .40994 .3705 .40347 .36364 Mtetra
.40347 .36364 .40994 .3705 .42083 .36668 .41439 .35979 Mtetra
.41439 .35979 .42083 .36668 .43177 .36285 .42536 .35592 Mtetra
.42536 .35592 .43177 .36285 .44275 .35901 .43637 .35205 Mtetra
.658 .753 .92 r
.43637 .35205 .44275 .35901 .45378 .35516 .44742 .34817 Mtetra
.44742 .34817 .45378 .35516 .46485 .3513 .45852 .34428 Mtetra
.45852 .34428 .46485 .3513 .47596 .34743 .46967 .34038 Mtetra
.46967 .34038 .47596 .34743 .48712 .34355 .48086 .33647 Mtetra
.48086 .33647 .48712 .34355 .49833 .33966 .49209 .33255 Mtetra
.49209 .33255 .49833 .33966 .50958 .33575 .50337 .32861 Mtetra
.50337 .32861 .50958 .33575 .52087 .33183 .5147 .32466 Mtetra
.657 .753 .92 r
.5147 .32466 .52087 .33183 .53222 .3279 .52607 .32069 Mtetra
.52607 .32069 .53222 .3279 .54361 .32395 .53749 .31671 Mtetra
.657 .752 .92 r
.53749 .31671 .54361 .32395 .55504 .31998 .54896 .31271 Mtetra
.54896 .31271 .55504 .31998 .56653 .316 .56048 .3087 Mtetra
.56048 .3087 .56653 .316 .57806 .31201 .57204 .30468 Mtetra
.57204 .30468 .57806 .31201 .58964 .308 .58365 .30064 Mtetra
.58365 .30064 .58964 .308 .60127 .30397 .59531 .29658 Mtetra
.59531 .29658 .60127 .30397 .61294 .29993 .60702 .2925 Mtetra
.60702 .2925 .61294 .29993 .62467 .29587 .61878 .28841 Mtetra
.61878 .28841 .62467 .29587 .63644 .2918 .63059 .28431 Mtetra
.63059 .28431 .63644 .2918 .64826 .28771 .64244 .28019 Mtetra
.64244 .28019 .64826 .28771 .66014 .2836 .65435 .27605 Mtetra
.65435 .27605 .66014 .2836 .67206 .27948 .66631 .27189 Mtetra
.66631 .27189 .67206 .27948 .68403 .27533 .67832 .26772 Mtetra
.67832 .26772 .68403 .27533 .69606 .27118 .69038 .26353 Mtetra
.69038 .26353 .69606 .27118 .70813 .267 .70249 .25932 Mtetra
.70249 .25932 .70813 .267 .72026 .26281 .71465 .25509 Mtetra
.71465 .25509 .72026 .26281 .73244 .2586 .72686 .25085 Mtetra
.72686 .25085 .73244 .2586 .74467 .25437 .73913 .24659 Mtetra
.73913 .24659 .74467 .25437 .75695 .25013 .75145 .24231 Mtetra
.75145 .24231 .75695 .25013 .76928 .24587 .76382 .23801 Mtetra
.76382 .23801 .76928 .24587 .78167 .24159 .77625 .2337 Mtetra
.571 .687 .919 r
.11754 .45193 .12456 .45939 .13422 .45727 .12714 .45041 Mtetra
.599 .716 .927 r
.12714 .45041 .13422 .45727 .14384 .45588 .13686 .44827 Mtetra
0 .353 .825 r
.13686 .44827 .14384 .45588 .15465 .44447 .1458 .4533 Mtetra
.768 .948 .619 r
.1458 .4533 .15465 .44447 .16404 .44579 .15707 .4384 Mtetra
.585 .697 .919 r
.15707 .4384 .16404 .44579 .17389 .44342 .16688 .43656 Mtetra
.613 .724 .924 r
.16688 .43656 .17389 .44342 .18377 .44121 .1768 .43407 Mtetra
.536 .688 .936 r
.1768 .43407 .18377 .44121 .19008 .47462 .18662 .43306 Mtetra
.63 .448 .618 r
.18662 .43306 .19008 .47462 .20421 .43123 .19744 .42255 Mtetra
.523 .635 .902 r
.19744 .42255 .20421 .43123 .21421 .429 .20729 .42205 Mtetra
.621 .726 .922 r
.20729 .42205 .21421 .429 .22431 .42622 .21739 .41936 Mtetra
.624 .731 .924 r
.21739 .41936 .22431 .42622 .23442 .42373 .22755 .41658 Mtetra
.563 .701 .933 r
.22755 .41658 .23442 .42373 .24353 .43337 .23764 .41505 Mtetra
.72 .585 .703 r
.23764 .41505 .24353 .43337 .25523 .41337 .24861 .40394 Mtetra
.498 .605 .89 r
.24861 .40394 .25523 .41337 .26545 .41108 .25864 .40404 Mtetra
.626 .728 .921 r
.25864 .40404 .26545 .41108 .27578 .40803 .26897 .40117 Mtetra
.639 .739 .921 r
.26897 .40117 .27578 .40803 .28616 .40483 .27937 .39798 Mtetra
.639 .74 .922 r
.27937 .39798 .28616 .40483 .29657 .40171 .28981 .39476 Mtetra
.629 .735 .924 r
.28981 .39476 .29657 .40171 .30699 .39918 .30029 .39176 Mtetra
.521 .679 .937 r
.30029 .39176 .30699 .39918 .3201 .35569 .31066 .39098 Mtetra
.328 .041 .315 r
.31066 .39098 .3201 .35569 .32833 .38839 .32173 .38 Mtetra
.566 .669 .907 r
.32173 .38 .32833 .38839 .33889 .38561 .33223 .37851 Mtetra
.637 .736 .92 r
.33223 .37851 .33889 .38561 .34953 .38223 .34289 .37529 Mtetra
.648 .745 .92 r
.34289 .37529 .34953 .38223 .36023 .37866 .35361 .37176 Mtetra
.653 .749 .92 r
.35361 .37176 .36023 .37866 .37097 .37499 .36437 .3681 Mtetra
.656 .751 .92 r
.36437 .3681 .37097 .37499 .38176 .37125 .37519 .36436 Mtetra
.657 .752 .92 r
.37519 .36436 .38176 .37125 .39259 .36746 .38605 .36056 Mtetra
.658 .753 .92 r
.38605 .36056 .39259 .36746 .40347 .36364 .39696 .35672 Mtetra
.659 .754 .92 r
.39696 .35672 .40347 .36364 .41439 .35979 .40791 .35284 Mtetra
.40791 .35284 .41439 .35979 .42536 .35592 .4189 .34895 Mtetra
.4189 .34895 .42536 .35592 .43637 .35205 .42994 .34504 Mtetra
.659 .753 .92 r
.42994 .34504 .43637 .35205 .44742 .34817 .44102 .34113 Mtetra
.658 .753 .92 r
.44102 .34113 .44742 .34817 .45852 .34428 .45215 .33721 Mtetra
.45215 .33721 .45852 .34428 .46967 .34038 .46332 .33328 Mtetra
.46332 .33328 .46967 .34038 .48086 .33647 .47454 .32933 Mtetra
.47454 .32933 .48086 .33647 .49209 .33255 .48581 .32538 Mtetra
.48581 .32538 .49209 .33255 .50337 .32861 .49712 .32141 Mtetra
.49712 .32141 .50337 .32861 .5147 .32466 .50848 .31742 Mtetra
.657 .753 .92 r
.50848 .31742 .5147 .32466 .52607 .32069 .51988 .31343 Mtetra
.51988 .31343 .52607 .32069 .53749 .31671 .53133 .30942 Mtetra
.53133 .30942 .53749 .31671 .54896 .31271 .54283 .30539 Mtetra
.657 .752 .92 r
.54283 .30539 .54896 .31271 .56048 .3087 .55438 .30135 Mtetra
.55438 .30135 .56048 .3087 .57204 .30468 .56598 .29729 Mtetra
.56598 .29729 .57204 .30468 .58365 .30064 .57762 .29322 Mtetra
.57762 .29322 .58365 .30064 .59531 .29658 .58931 .28913 Mtetra
.58931 .28913 .59531 .29658 .60702 .2925 .60106 .28502 Mtetra
.60106 .28502 .60702 .2925 .61878 .28841 .61285 .2809 Mtetra
.61285 .2809 .61878 .28841 .63059 .28431 .62469 .27676 Mtetra
.62469 .27676 .63059 .28431 .64244 .28019 .63658 .2726 Mtetra
.63658 .2726 .64244 .28019 .65435 .27605 .64852 .26843 Mtetra
.64852 .26843 .65435 .27605 .66631 .27189 .66051 .26424 Mtetra
.66051 .26424 .66631 .27189 .67832 .26772 .67256 .26004 Mtetra
.67256 .26004 .67832 .26772 .69038 .26353 .68465 .25581 Mtetra
.68465 .25581 .69038 .26353 .70249 .25932 .6968 .25157 Mtetra
.6968 .25157 .70249 .25932 .71465 .25509 .709 .24731 Mtetra
.709 .24731 .71465 .25509 .72686 .25085 .72125 .24304 Mtetra
.72125 .24304 .72686 .25085 .73913 .24659 .73355 .23874 Mtetra
.73355 .23874 .73913 .24659 .75145 .24231 .74591 .23443 Mtetra
.74591 .23443 .75145 .24231 .76382 .23801 .75832 .2301 Mtetra
.75832 .2301 .76382 .23801 .77625 .2337 .77078 .22575 Mtetra
.351 .47 .841 r
.11099 .44039 .11754 .45193 .12714 .45041 .12003 .4434 Mtetra
.6 .713 .924 r
.12003 .4434 .12714 .45041 .13686 .44827 .12977 .44122 Mtetra
.561 .699 .933 r
.12977 .44122 .13686 .44827 .1458 .4533 .13947 .43978 Mtetra
.758 .641 .732 r
.13947 .43978 .1458 .4533 .15707 .4384 .15037 .42827 Mtetra
.438 .554 .875 r
.15037 .42827 .15707 .4384 .16688 .43656 .15984 .42955 Mtetra
.61 .719 .923 r
.15984 .42955 .16688 .43656 .1768 .43407 .16977 .42712 Mtetra
.601 .719 .927 r
.16977 .42712 .1768 .43407 .18662 .43306 .17973 .42486 Mtetra
.943 .583 .278 r
.17973 .42486 .18662 .43306 .19744 .42255 .18604 .45836 Mtetra
0 0 0 r
.18604 .45836 .19744 .42255 .20729 .42205 .20035 .41473 Mtetra
.602 .71 .92 r
.20035 .41473 .20729 .42205 .21739 .41936 .21043 .41244 Mtetra
.626 .731 .923 r
.21043 .41244 .21739 .41936 .22755 .41658 .22061 .40959 Mtetra
.612 .725 .926 r
.22061 .40959 .22755 .41658 .23764 .41505 .23081 .40705 Mtetra
0 .01 .538 r
.23081 .40705 .23764 .41505 .24861 .40394 .23999 .41668 Mtetra
.73 .875 .465 r
.23999 .41668 .24861 .40394 .25864 .40404 .25181 .39654 Mtetra
.603 .708 .918 r
.25181 .39654 .25864 .40404 .26897 .40117 .26211 .39419 Mtetra
.635 .736 .921 r
.26211 .39419 .26897 .40117 .27937 .39798 .27253 .39107 Mtetra
.64 .74 .921 r
.27253 .39107 .27937 .39798 .28981 .39476 .283 .38781 Mtetra
.637 .739 .922 r
.283 .38781 .28981 .39476 .30029 .39176 .29351 .38462 Mtetra
.61 .725 .927 r
.29351 .38462 .30029 .39176 .31066 .39098 .30402 .38203 Mtetra
.922 .724 .618 r
.30402 .38203 .31066 .39098 .32173 .38 .31728 .33831 Mtetra
0 0 .451 r
.31728 .33831 .32173 .38 .33223 .37851 .32555 .37108 Mtetra
.621 .721 .918 r
.32555 .37108 .33223 .37851 .34289 .37529 .3362 .36824 Mtetra
.644 .742 .92 r
.3362 .36824 .34289 .37529 .35361 .37176 .34694 .36479 Mtetra
.651 .747 .92 r
.34694 .36479 .35361 .37176 .36437 .3681 .35773 .36115 Mtetra
.654 .75 .92 r
.35773 .36115 .36437 .3681 .37519 .36436 .36857 .35741 Mtetra
.657 .752 .92 r
.36857 .35741 .37519 .36436 .38605 .36056 .37946 .3536 Mtetra
.658 .753 .92 r
.37946 .3536 .38605 .36056 .39696 .35672 .39039 .34974 Mtetra
.659 .754 .92 r
.39039 .34974 .39696 .35672 .40791 .35284 .40137 .34584 Mtetra
.40137 .34584 .40791 .35284 .4189 .34895 .41239 .34192 Mtetra
.41239 .34192 .4189 .34895 .42994 .34504 .42346 .33798 Mtetra
.42346 .33798 .42994 .34504 .44102 .34113 .43457 .33404 Mtetra
.658 .753 .92 r
.43457 .33404 .44102 .34113 .45215 .33721 .44573 .33008 Mtetra
.44573 .33008 .45215 .33721 .46332 .33328 .45693 .32612 Mtetra
.45693 .32612 .46332 .33328 .47454 .32933 .46818 .32214 Mtetra
.46818 .32214 .47454 .32933 .48581 .32538 .47948 .31815 Mtetra
.47948 .31815 .48581 .32538 .49712 .32141 .49082 .31415 Mtetra
.49082 .31415 .49712 .32141 .50848 .31742 .50221 .31014 Mtetra
.50221 .31014 .50848 .31742 .51988 .31343 .51364 .30611 Mtetra
.657 .753 .92 r
.51364 .30611 .51988 .31343 .53133 .30942 .52513 .30207 Mtetra
.52513 .30207 .53133 .30942 .54283 .30539 .53666 .29801 Mtetra
.657 .752 .92 r
.53666 .29801 .54283 .30539 .55438 .30135 .54824 .29393 Mtetra
.54824 .29393 .55438 .30135 .56598 .29729 .55986 .28984 Mtetra
.55986 .28984 .56598 .29729 .57762 .29322 .57154 .28574 Mtetra
.57154 .28574 .57762 .29322 .58931 .28913 .58327 .28162 Mtetra
.58327 .28162 .58931 .28913 .60106 .28502 .59504 .27748 Mtetra
.59504 .27748 .60106 .28502 .61285 .2809 .60687 .27332 Mtetra
.60687 .27332 .61285 .2809 .62469 .27676 .61874 .26915 Mtetra
.61874 .26915 .62469 .27676 .63658 .2726 .63067 .26496 Mtetra
.63067 .26496 .63658 .2726 .64852 .26843 .64264 .26076 Mtetra
.64264 .26076 .64852 .26843 .66051 .26424 .65467 .25654 Mtetra
.65467 .25654 .66051 .26424 .67256 .26004 .66675 .2523 Mtetra
.66675 .2523 .67256 .26004 .68465 .25581 .67888 .24804 Mtetra
.67888 .24804 .68465 .25581 .6968 .25157 .69106 .24376 Mtetra
.69106 .24376 .6968 .25157 .709 .24731 .7033 .23947 Mtetra
.7033 .23947 .709 .24731 .72125 .24304 .71558 .23516 Mtetra
.71558 .23516 .72125 .24304 .73355 .23874 .72792 .23083 Mtetra
.72792 .23083 .73355 .23874 .74591 .23443 .74032 .22648 Mtetra
.74032 .22648 .74591 .23443 .75832 .2301 .75277 .22212 Mtetra
.75277 .22212 .75832 .2301 .77078 .22575 .76527 .21773 Mtetra
.715 .946 .648 r
.1019 .44825 .11099 .44039 .12003 .4434 .11293 .43582 Mtetra
.571 .687 .919 r
.11293 .43582 .12003 .4434 .12977 .44122 .12261 .43424 Mtetra
.599 .716 .927 r
.12261 .43424 .12977 .44122 .13947 .43978 .13241 .43205 Mtetra
0 .356 .827 r
.13241 .43205 .13947 .43978 .15037 .42827 .14141 .43705 Mtetra
.774 .952 .626 r
.14141 .43705 .15037 .42827 .15984 .42955 .15279 .42204 Mtetra
.585 .697 .919 r
.15279 .42204 .15984 .42955 .16977 .42712 .16268 .42014 Mtetra
.613 .724 .924 r
.16268 .42014 .16977 .42712 .17973 .42486 .17269 .41759 Mtetra
.537 .688 .936 r
.17269 .41759 .17973 .42486 .18604 .45836 .18258 .41653 Mtetra
.629 .447 .617 r
.18258 .41653 .18604 .45836 .20035 .41473 .19351 .40592 Mtetra
.523 .635 .902 r
.19351 .40592 .20035 .41473 .21043 .41244 .20343 .40537 Mtetra
.621 .726 .922 r
.20343 .40537 .21043 .41244 .22061 .40959 .21362 .40262 Mtetra
.624 .731 .924 r
.21362 .40262 .22061 .40959 .23081 .40705 .22386 .39978 Mtetra
.563 .701 .933 r
.22386 .39978 .23081 .40705 .23999 .41668 .23404 .39819 Mtetra
.72 .585 .703 r
.23404 .39819 .23999 .41668 .25181 .39654 .24511 .38697 Mtetra
.497 .605 .89 r
.24511 .38697 .25181 .39654 .26211 .39419 .25522 .38702 Mtetra
.626 .728 .921 r
.25522 .38702 .26211 .39419 .27253 .39107 .26564 .38408 Mtetra
.639 .739 .921 r
.26564 .38408 .27253 .39107 .283 .38781 .27613 .38083 Mtetra
.639 .74 .922 r
.27613 .38083 .283 .38781 .29351 .38462 .28667 .37754 Mtetra
.629 .735 .924 r
.28667 .37754 .29351 .38462 .30402 .38203 .29723 .37448 Mtetra
.521 .679 .937 r
.29723 .37448 .30402 .38203 .31728 .33831 .30769 .37364 Mtetra
.32 .03 .307 r
.30769 .37364 .31728 .33831 .32555 .37108 .31888 .36256 Mtetra
.566 .669 .908 r
.31888 .36256 .32555 .37108 .3362 .36824 .32947 .36101 Mtetra
.637 .736 .92 r
.32947 .36101 .3362 .36824 .34694 .36479 .34022 .35772 Mtetra
.648 .745 .92 r
.34022 .35772 .34694 .36479 .35773 .36115 .35104 .35412 Mtetra
.653 .749 .92 r
.35104 .35412 .35773 .36115 .36857 .35741 .3619 .35039 Mtetra
.656 .751 .92 r
.3619 .35039 .36857 .35741 .37946 .3536 .37281 .34658 Mtetra
.657 .752 .92 r
.37281 .34658 .37946 .3536 .39039 .34974 .38378 .3427 Mtetra
.658 .753 .92 r
.38378 .3427 .39039 .34974 .40137 .34584 .39478 .33878 Mtetra
.659 .754 .92 r
.39478 .33878 .40137 .34584 .41239 .34192 .40583 .33484 Mtetra
.40583 .33484 .41239 .34192 .42346 .33798 .41693 .33087 Mtetra
.41693 .33087 .42346 .33798 .43457 .33404 .42807 .32689 Mtetra
.659 .753 .92 r
.42807 .32689 .43457 .33404 .44573 .33008 .43926 .3229 Mtetra
.658 .753 .92 r
.43926 .3229 .44573 .33008 .45693 .32612 .45049 .3189 Mtetra
.45049 .3189 .45693 .32612 .46818 .32214 .46177 .3149 Mtetra
.46177 .3149 .46818 .32214 .47948 .31815 .4731 .31088 Mtetra
.4731 .31088 .47948 .31815 .49082 .31415 .48447 .30684 Mtetra
.48447 .30684 .49082 .31415 .50221 .31014 .49589 .3028 Mtetra
.49589 .3028 .50221 .31014 .51364 .30611 .50736 .29874 Mtetra
.657 .753 .92 r
.50736 .29874 .51364 .30611 .52513 .30207 .51887 .29466 Mtetra
.51887 .29466 .52513 .30207 .53666 .29801 .53043 .29057 Mtetra
.53043 .29057 .53666 .29801 .54824 .29393 .54204 .28646 Mtetra
.657 .752 .92 r
.54204 .28646 .54824 .29393 .55986 .28984 .55371 .28234 Mtetra
.55371 .28234 .55986 .28984 .57154 .28574 .56541 .2782 Mtetra
.56541 .2782 .57154 .28574 .58327 .28162 .57717 .27405 Mtetra
.57717 .27405 .58327 .28162 .59504 .27748 .58898 .26988 Mtetra
.58898 .26988 .59504 .27748 .60687 .27332 .60084 .26569 Mtetra
.60084 .26569 .60687 .27332 .61874 .26915 .61275 .26149 Mtetra
.61275 .26149 .61874 .26915 .63067 .26496 .62471 .25726 Mtetra
.62471 .25726 .63067 .26496 .64264 .26076 .63672 .25303 Mtetra
.63672 .25303 .64264 .26076 .65467 .25654 .64878 .24877 Mtetra
.64878 .24877 .65467 .25654 .66675 .2523 .6609 .2445 Mtetra
.6609 .2445 .66675 .2523 .67888 .24804 .67306 .2402 Mtetra
.67306 .2402 .67888 .24804 .69106 .24376 .68528 .2359 Mtetra
.68528 .2359 .69106 .24376 .7033 .23947 .69755 .23157 Mtetra
.69755 .23157 .7033 .23947 .71558 .23516 .70988 .22722 Mtetra
.70988 .22722 .71558 .23516 .72792 .23083 .72225 .22286 Mtetra
.72225 .22286 .72792 .23083 .74032 .22648 .73469 .21848 Mtetra
.73469 .21848 .74032 .22648 .75277 .22212 .74717 .21408 Mtetra
.74717 .21408 .75277 .22212 .76527 .21773 .75971 .20966 Mtetra
.791 .679 .741 r
.09519 .43705 .1019 .44825 .11293 .43582 .10631 .42414 Mtetra
.35 .47 .841 r
.10631 .42414 .11293 .43582 .12261 .43424 .11541 .42711 Mtetra
.6 .713 .924 r
.11541 .42711 .12261 .43424 .13241 .43205 .12523 .42488 Mtetra
.561 .699 .933 r
.12523 .42488 .13241 .43205 .14141 .43705 .13501 .42338 Mtetra
.758 .642 .732 r
.13501 .42338 .14141 .43705 .15279 .42204 .14602 .41177 Mtetra
.437 .553 .876 r
.14602 .41177 .15279 .42204 .16268 .42014 .15555 .413 Mtetra
.61 .719 .923 r
.15555 .413 .16268 .42014 .17269 .41759 .16557 .41051 Mtetra
.601 .719 .927 r
.16557 .41051 .17269 .41759 .18258 .41653 .17561 .40819 Mtetra
.943 .582 .272 r
.17561 .40819 .18258 .41653 .19351 .40592 .18193 .44178 Mtetra
0 0 0 r
.18193 .44178 .19351 .40592 .20343 .40537 .19641 .39792 Mtetra
.602 .71 .92 r
.19641 .39792 .20343 .40537 .21362 .40262 .20658 .39557 Mtetra
.626 .731 .923 r
.20658 .39557 .21362 .40262 .22386 .39978 .21685 .39266 Mtetra
.612 .725 .926 r
.21685 .39266 .22386 .39978 .23404 .39819 .22713 .39005 Mtetra
0 .016 .545 r
.22713 .39005 .23404 .39819 .24511 .38697 .23637 .39967 Mtetra
.738 .881 .474 r
.23637 .39967 .24511 .38697 .25522 .38702 .24832 .37939 Mtetra
.603 .708 .918 r
.24832 .37939 .25522 .38702 .26564 .38408 .25871 .37698 Mtetra
.635 .736 .921 r
.25871 .37698 .26564 .38408 .27613 .38083 .26922 .37379 Mtetra
.64 .74 .921 r
.26922 .37379 .27613 .38083 .28667 .37754 .27978 .37047 Mtetra
.637 .739 .922 r
.27978 .37047 .28667 .37754 .29723 .37448 .29038 .3672 Mtetra
.61 .725 .927 r
.29038 .3672 .29723 .37448 .30769 .37364 .30098 .36455 Mtetra
.923 .725 .617 r
.30098 .36455 .30769 .37364 .31888 .36256 .3144 .32061 Mtetra
0 0 .447 r
.3144 .32061 .31888 .36256 .32947 .36101 .32271 .35345 Mtetra
.621 .721 .918 r
.32271 .35345 .32947 .36101 .34022 .35772 .33346 .35053 Mtetra
.644 .742 .92 r
.33346 .35053 .34022 .35772 .35104 .35412 .34429 .34701 Mtetra
.651 .748 .92 r
.34429 .34701 .35104 .35412 .3619 .35039 .35518 .3433 Mtetra
.654 .75 .92 r
.35518 .3433 .3619 .35039 .37281 .34658 .36612 .33949 Mtetra
.657 .752 .92 r
.36612 .33949 .37281 .34658 .38378 .3427 .37711 .33561 Mtetra
.658 .753 .92 r
.37711 .33561 .38378 .3427 .39478 .33878 .38814 .33167 Mtetra
.659 .754 .92 r
.38814 .33167 .39478 .33878 .40583 .33484 .39922 .3277 Mtetra
.39922 .3277 .40583 .33484 .41693 .33087 .41035 .3237 Mtetra
.41035 .3237 .41693 .33087 .42807 .32689 .42152 .31969 Mtetra
.42152 .31969 .42807 .32689 .43926 .3229 .43274 .31567 Mtetra
.658 .753 .92 r
.43274 .31567 .43926 .3229 .45049 .3189 .444 .31164 Mtetra
.444 .31164 .45049 .3189 .46177 .3149 .45531 .30759 Mtetra
.45531 .30759 .46177 .3149 .4731 .31088 .46667 .30354 Mtetra
.46667 .30354 .4731 .31088 .48447 .30684 .47807 .29948 Mtetra
.47807 .29948 .48447 .30684 .49589 .3028 .48952 .2954 Mtetra
.48952 .2954 .49589 .3028 .50736 .29874 .50102 .2913 Mtetra
.50102 .2913 .50736 .29874 .51887 .29466 .51257 .2872 Mtetra
.657 .753 .92 r
.51257 .2872 .51887 .29466 .53043 .29057 .52416 .28307 Mtetra
.52416 .28307 .53043 .29057 .54204 .28646 .5358 .27893 Mtetra
.657 .752 .92 r
.5358 .27893 .54204 .28646 .55371 .28234 .5475 .27478 Mtetra
.5475 .27478 .55371 .28234 .56541 .2782 .55924 .27061 Mtetra
.55924 .27061 .56541 .2782 .57717 .27405 .57103 .26642 Mtetra
.57103 .26642 .57717 .27405 .58898 .26988 .58287 .26222 Mtetra
.58287 .26222 .58898 .26988 .60084 .26569 .59477 .258 Mtetra
.59477 .258 .60084 .26569 .61275 .26149 .60671 .25376 Mtetra
.60671 .25376 .61275 .26149 .62471 .25726 .6187 .2495 Mtetra
.6187 .2495 .62471 .25726 .63672 .25303 .63075 .24523 Mtetra
.63075 .24523 .63672 .25303 .64878 .24877 .64285 .24094 Mtetra
.64285 .24094 .64878 .24877 .6609 .2445 .655 .23663 Mtetra
.655 .23663 .6609 .2445 .67306 .2402 .6672 .23231 Mtetra
.6672 .23231 .67306 .2402 .68528 .2359 .67945 .22796 Mtetra
.67945 .22796 .68528 .2359 .69755 .23157 .69176 .2236 Mtetra
.69176 .2236 .69755 .23157 .70988 .22722 .70412 .21922 Mtetra
.70412 .21922 .70988 .22722 .72225 .22286 .71654 .21482 Mtetra
.71654 .21482 .72225 .22286 .73469 .21848 .72901 .2104 Mtetra
.72901 .2104 .73469 .21848 .74717 .21408 .74153 .20597 Mtetra
.74153 .20597 .74717 .21408 .75971 .20966 .75411 .20151 Mtetra
.243 .533 .92 r
.08797 .42941 .09519 .43705 .10631 .42414 .0971 .43194 Mtetra
.723 .951 .656 r
.0971 .43194 .10631 .42414 .11541 .42711 .10824 .41941 Mtetra
.571 .687 .919 r
.10824 .41941 .11541 .42711 .12523 .42488 .11799 .41778 Mtetra
.599 .716 .927 r
.11799 .41778 .12523 .42488 .13501 .42338 .12787 .41552 Mtetra
0 .358 .829 r
.12787 .41552 .13501 .42338 .14602 .41177 .13694 .4205 Mtetra
.781 .956 .633 r
.13694 .4205 .14602 .41177 .15555 .413 .14843 .40537 Mtetra
.585 .697 .919 r
.14843 .40537 .15555 .413 .16557 .41051 .1584 .40341 Mtetra
.613 .724 .924 r
.1584 .40341 .16557 .41051 .17561 .40819 .16849 .40081 Mtetra
.537 .688 .936 r
.16849 .40081 .17561 .40819 .18193 .44178 .17846 .39968 Mtetra
.628 .445 .616 r
.17846 .39968 .18193 .44178 .19641 .39792 .18949 .38898 Mtetra
.523 .635 .902 r
.18949 .38898 .19641 .39792 .20658 .39557 .1995 .38837 Mtetra
.621 .726 .922 r
.1995 .38837 .20658 .39557 .21685 .39266 .20978 .38556 Mtetra
.624 .731 .924 r
.20978 .38556 .21685 .39266 .22713 .39005 .22011 .38265 Mtetra
.564 .701 .933 r
.22011 .38265 .22713 .39005 .23637 .39967 .23037 .381 Mtetra
.72 .585 .703 r
.23037 .381 .23637 .39967 .24832 .37939 .24154 .36969 Mtetra
.497 .605 .89 r
.24154 .36969 .24832 .37939 .25871 .37698 .25174 .36968 Mtetra
.626 .728 .921 r
.25174 .36968 .25871 .37698 .26922 .37379 .26225 .36668 Mtetra
.639 .739 .921 r
.26225 .36668 .26922 .37379 .27978 .37047 .27284 .36336 Mtetra
.639 .74 .922 r
.27284 .36336 .27978 .37047 .29038 .3672 .28347 .36 Mtetra
.629 .735 .924 r
.28347 .36 .29038 .3672 .30098 .36455 .29413 .35687 Mtetra
.521 .679 .937 r
.29413 .35687 .30098 .36455 .3144 .32061 .30468 .35597 Mtetra
.312 .02 .298 r
.30468 .35597 .3144 .32061 .32271 .35345 .31597 .34479 Mtetra
.566 .669 .908 r
.31597 .34479 .32271 .35345 .33346 .35053 .32665 .34317 Mtetra
.637 .736 .92 r
.32665 .34317 .33346 .35053 .34429 .34701 .3375 .33981 Mtetra
.648 .745 .92 r
.3375 .33981 .34429 .34701 .35518 .3433 .34842 .33614 Mtetra
.653 .749 .92 r
.34842 .33614 .35518 .3433 .36612 .33949 .35938 .33234 Mtetra
.656 .751 .92 r
.35938 .33234 .36612 .33949 .37711 .33561 .37039 .32845 Mtetra
.657 .752 .92 r
.37039 .32845 .37711 .33561 .38814 .33167 .38146 .3245 Mtetra
.658 .753 .92 r
.38146 .3245 .38814 .33167 .39922 .3277 .39257 .32051 Mtetra
.659 .754 .92 r
.39257 .32051 .39922 .3277 .41035 .3237 .40372 .31648 Mtetra
.40372 .31648 .41035 .3237 .42152 .31969 .41492 .31244 Mtetra
.41492 .31244 .42152 .31969 .43274 .31567 .42617 .30838 Mtetra
.659 .753 .92 r
.42617 .30838 .43274 .31567 .444 .31164 .43746 .30431 Mtetra
.658 .753 .92 r
.43746 .30431 .444 .31164 .45531 .30759 .4488 .30024 Mtetra
.4488 .30024 .45531 .30759 .46667 .30354 .46019 .29615 Mtetra
.46019 .29615 .46667 .30354 .47807 .29948 .47162 .29205 Mtetra
.47162 .29205 .47807 .29948 .48952 .2954 .4831 .28794 Mtetra
.4831 .28794 .48952 .2954 .50102 .2913 .49463 .28382 Mtetra
.49463 .28382 .50102 .2913 .51257 .2872 .50621 .27968 Mtetra
.657 .753 .92 r
.50621 .27968 .51257 .2872 .52416 .28307 .51784 .27552 Mtetra
.51784 .27552 .52416 .28307 .5358 .27893 .52951 .27135 Mtetra
.52951 .27135 .5358 .27893 .5475 .27478 .54124 .26716 Mtetra
.657 .752 .92 r
.54124 .26716 .5475 .27478 .55924 .27061 .55302 .26296 Mtetra
.55302 .26296 .55924 .27061 .57103 .26642 .56484 .25873 Mtetra
.56484 .25873 .57103 .26642 .58287 .26222 .57672 .2545 Mtetra
.57672 .2545 .58287 .26222 .59477 .258 .58864 .25024 Mtetra
.58864 .25024 .59477 .258 .60671 .25376 .60062 .24597 Mtetra
.60062 .24597 .60671 .25376 .6187 .2495 .61265 .24168 Mtetra
.61265 .24168 .6187 .2495 .63075 .24523 .62473 .23737 Mtetra
.62473 .23737 .63075 .24523 .64285 .24094 .63686 .23305 Mtetra
.63686 .23305 .64285 .24094 .655 .23663 .64905 .22871 Mtetra
.64905 .22871 .655 .23663 .6672 .23231 .66129 .22435 Mtetra
.66129 .22435 .6672 .23231 .67945 .22796 .67358 .21997 Mtetra
.67358 .21997 .67945 .22796 .69176 .2236 .68592 .21557 Mtetra
.68592 .21557 .69176 .2236 .70412 .21922 .69832 .21115 Mtetra
.69832 .21115 .70412 .21922 .71654 .21482 .71078 .20672 Mtetra
.71078 .20672 .71654 .21482 .72901 .2104 .72328 .20226 Mtetra
.72328 .20226 .72901 .2104 .74153 .20597 .73585 .19779 Mtetra
.73585 .19779 .74153 .20597 .75411 .20151 .74846 .1933 Mtetra
.564 .7 .932 r
.08063 .42219 .08797 .42941 .0971 .43194 .09032 .42061 Mtetra
.791 .68 .741 r
.09032 .42061 .0971 .43194 .10824 .41941 .10155 .40759 Mtetra
.348 .469 .841 r
.10155 .40759 .10824 .41941 .11799 .41778 .11072 .41053 Mtetra
.6 .713 .924 r
.11072 .41053 .11799 .41778 .12787 .41552 .12062 .40823 Mtetra
.561 .699 .933 r
.12062 .40823 .12787 .41552 .13694 .4205 .13047 .40668 Mtetra
.759 .642 .732 r
.13047 .40668 .13694 .4205 .14843 .40537 .14159 .39497 Mtetra
.436 .553 .876 r
.14159 .39497 .14843 .40537 .1584 .40341 .15119 .39615 Mtetra
.61 .719 .923 r
.15119 .39615 .1584 .40341 .16849 .40081 .16129 .3936 Mtetra
.601 .719 .927 r
.16129 .3936 .16849 .40081 .17846 .39968 .17142 .39122 Mtetra
.943 .58 .267 r
.17142 .39122 .17846 .39968 .18949 .38898 .17774 .4249 Mtetra
0 0 0 r
.17774 .4249 .18949 .38898 .1995 .38837 .1924 .3808 Mtetra
.602 .71 .92 r
.1924 .3808 .1995 .38837 .20978 .38556 .20265 .37839 Mtetra
.626 .731 .923 r
.20265 .37839 .20978 .38556 .22011 .38265 .21301 .37541 Mtetra
.612 .725 .926 r
.21301 .37541 .22011 .38265 .23037 .381 .22339 .37274 Mtetra
0 .023 .551 r
.22339 .37274 .23037 .381 .24154 .36969 .23269 .38233 Mtetra
.745 .886 .482 r
.23269 .38233 .24154 .36969 .25174 .36968 .24476 .36192 Mtetra
.603 .708 .918 r
.24476 .36192 .25174 .36968 .26225 .36668 .25525 .35944 Mtetra
.635 .736 .921 r
.25525 .35944 .26225 .36668 .27284 .36336 .26584 .35619 Mtetra
.64 .74 .921 r
.26584 .35619 .27284 .36336 .28347 .36 .2765 .35279 Mtetra
.637 .739 .922 r
.2765 .35279 .28347 .36 .29413 .35687 .2872 .34946 Mtetra
.61 .724 .927 r
.2872 .34946 .29413 .35687 .30468 .35597 .29789 .34674 Mtetra
.924 .725 .616 r
.29789 .34674 .30468 .35597 .31597 .34479 .31147 .30257 Mtetra
0 0 .443 r
.31147 .30257 .31597 .34479 .32665 .34317 .31982 .33547 Mtetra
.621 .721 .918 r
.31982 .33547 .32665 .34317 .3375 .33981 .33067 .33249 Mtetra
.644 .742 .92 r
.33067 .33249 .3375 .33981 .34842 .33614 .3416 .32889 Mtetra
.651 .748 .92 r
.3416 .32889 .34842 .33614 .35938 .33234 .35259 .32511 Mtetra
.654 .75 .92 r
.35259 .32511 .35938 .33234 .37039 .32845 .36363 .32122 Mtetra
.657 .752 .92 r
.36363 .32122 .37039 .32845 .38146 .3245 .37472 .31727 Mtetra
.658 .753 .92 r
.37472 .31727 .38146 .3245 .39257 .32051 .38586 .31325 Mtetra
.659 .754 .92 r
.38586 .31325 .39257 .32051 .40372 .31648 .39704 .3092 Mtetra
.39704 .3092 .40372 .31648 .41492 .31244 .40827 .30513 Mtetra
.40827 .30513 .41492 .31244 .42617 .30838 .41955 .30104 Mtetra
.41955 .30104 .42617 .30838 .43746 .30431 .43087 .29694 Mtetra
.658 .753 .92 r
.43087 .29694 .43746 .30431 .4488 .30024 .44224 .29283 Mtetra
.44224 .29283 .4488 .30024 .46019 .29615 .45366 .28871 Mtetra
.45366 .28871 .46019 .29615 .47162 .29205 .46512 .28457 Mtetra
.46512 .28457 .47162 .29205 .4831 .28794 .47664 .28043 Mtetra
.47664 .28043 .4831 .28794 .49463 .28382 .4882 .27627 Mtetra
.4882 .27627 .49463 .28382 .50621 .27968 .49981 .2721 Mtetra
.49981 .2721 .50621 .27968 .51784 .27552 .51147 .26791 Mtetra
.657 .753 .92 r
.51147 .26791 .51784 .27552 .52951 .27135 .52318 .2637 Mtetra
.52318 .2637 .52951 .27135 .54124 .26716 .53493 .25948 Mtetra
.657 .752 .92 r
.53493 .25948 .54124 .26716 .55302 .26296 .54674 .25524 Mtetra
.54674 .25524 .55302 .26296 .56484 .25873 .5586 .25099 Mtetra
.5586 .25099 .56484 .25873 .57672 .2545 .57051 .24671 Mtetra
.57051 .24671 .57672 .2545 .58864 .25024 .58247 .24243 Mtetra
.58247 .24243 .58864 .25024 .60062 .24597 .59448 .23812 Mtetra
.59448 .23812 .60062 .24597 .61265 .24168 .60655 .2338 Mtetra
.60655 .2338 .61265 .24168 .62473 .23737 .61866 .22945 Mtetra
.61866 .22945 .62473 .23737 .63686 .23305 .63083 .22509 Mtetra
.63083 .22509 .63686 .23305 .64905 .22871 .64305 .22072 Mtetra
.64305 .22072 .64905 .22871 .66129 .22435 .65533 .21632 Mtetra
.65533 .21632 .66129 .22435 .67358 .21997 .66766 .21191 Mtetra
.66766 .21191 .67358 .21997 .68592 .21557 .68004 .20747 Mtetra
.68004 .20747 .68592 .21557 .69832 .21115 .69248 .20302 Mtetra
.69248 .20302 .69832 .21115 .71078 .20672 .70497 .19855 Mtetra
.70497 .19855 .71078 .20672 .72328 .20226 .71751 .19406 Mtetra
.71751 .19406 .72328 .20226 .73585 .19779 .73011 .18955 Mtetra
.73011 .18955 .73585 .19779 .74846 .1933 .74277 .18502 Mtetra
.591 .71 .926 r
.07325 .41495 .08063 .42219 .09032 .42061 .08301 .41284 Mtetra
.245 .533 .92 r
.08301 .41284 .09032 .42061 .10155 .40759 .09221 .41533 Mtetra
.73 .956 .664 r
.09221 .41533 .10155 .40759 .11072 .41053 .10346 .4027 Mtetra
.571 .687 .919 r
.10346 .4027 .11072 .41053 .12062 .40823 .11329 .40101 Mtetra
.599 .716 .926 r
.11329 .40101 .12062 .40823 .13047 .40668 .12325 .39869 Mtetra
0 .361 .83 r
.12325 .39869 .13047 .40668 .14159 .39497 .13238 .40363 Mtetra
.787 .959 .64 r
.13238 .40363 .14159 .39497 .15119 .39615 .14399 .38839 Mtetra
.585 .697 .919 r
.14399 .38839 .15119 .39615 .16129 .3936 .15404 .38637 Mtetra
.613 .724 .924 r
.15404 .38637 .16129 .3936 .17142 .39122 .16422 .3837 Mtetra
.537 .688 .936 r
.16422 .3837 .17142 .39122 .17774 .4249 .17427 .38252 Mtetra
.627 .443 .615 r
.17427 .38252 .17774 .4249 .1924 .3808 .18541 .37172 Mtetra
.522 .635 .903 r
.18541 .37172 .1924 .3808 .20265 .37839 .19549 .37106 Mtetra
.621 .726 .922 r
.19549 .37106 .20265 .37839 .21301 .37541 .20586 .36817 Mtetra
.624 .731 .924 r
.20586 .36817 .21301 .37541 .22339 .37274 .21628 .3652 Mtetra
.564 .701 .933 r
.21628 .3652 .22339 .37274 .23269 .38233 .22663 .36349 Mtetra
.721 .585 .703 r
.22663 .36349 .23269 .38233 .24476 .36192 .23791 .35207 Mtetra
.497 .605 .89 r
.23791 .35207 .24476 .36192 .25525 .35944 .2482 .35201 Mtetra
.626 .728 .921 r
.2482 .35201 .25525 .35944 .26584 .35619 .2588 .34894 Mtetra
.639 .739 .921 r
.2588 .34894 .26584 .35619 .2765 .35279 .26948 .34555 Mtetra
.639 .74 .922 r
.26948 .34555 .2765 .35279 .2872 .34946 .2802 .34212 Mtetra
.629 .735 .923 r
.2802 .34212 .2872 .34946 .29789 .34674 .29096 .33891 Mtetra
.522 .679 .937 r
.29096 .33891 .29789 .34674 .31147 .30257 .3016 .33795 Mtetra
.303 .009 .289 r
.3016 .33795 .31147 .30257 .31982 .33547 .313 .32667 Mtetra
.566 .669 .908 r
.313 .32667 .31982 .33547 .33067 .33249 .32378 .32499 Mtetra
.637 .736 .92 r
.32378 .32499 .33067 .33249 .3416 .32889 .33473 .32155 Mtetra
.648 .745 .92 r
.33473 .32155 .3416 .32889 .35259 .32511 .34574 .31781 Mtetra
.653 .749 .92 r
.34574 .31781 .35259 .32511 .36363 .32122 .35681 .31393 Mtetra
.656 .751 .92 r
.35681 .31393 .36363 .32122 .37472 .31727 .36793 .30997 Mtetra
.657 .752 .92 r
.36793 .30997 .37472 .31727 .38586 .31325 .37909 .30594 Mtetra
.658 .753 .92 r
.37909 .30594 .38586 .31325 .39704 .3092 .39031 .30187 Mtetra
.659 .754 .92 r
.39031 .30187 .39704 .3092 .40827 .30513 .40157 .29776 Mtetra
.40157 .29776 .40827 .30513 .41955 .30104 .41287 .29364 Mtetra
.41287 .29364 .41955 .30104 .43087 .29694 .42423 .28951 Mtetra
.659 .753 .92 r
.42423 .28951 .43087 .29694 .44224 .29283 .43563 .28536 Mtetra
.658 .753 .92 r
.43563 .28536 .44224 .29283 .45366 .28871 .44708 .2812 Mtetra
.44708 .2812 .45366 .28871 .46512 .28457 .45857 .27704 Mtetra
.45857 .27704 .46512 .28457 .47664 .28043 .47012 .27286 Mtetra
.47012 .27286 .47664 .28043 .4882 .27627 .48171 .26866 Mtetra
.48171 .26866 .4882 .27627 .49981 .2721 .49335 .26446 Mtetra
.49335 .26446 .49981 .2721 .51147 .26791 .50504 .26023 Mtetra
.657 .753 .92 r
.50504 .26023 .51147 .26791 .52318 .2637 .51679 .25599 Mtetra
.51679 .25599 .52318 .2637 .53493 .25948 .52858 .25174 Mtetra
.52858 .25174 .53493 .25948 .54674 .25524 .54042 .24747 Mtetra
.657 .752 .92 r
.54042 .24747 .54674 .25524 .5586 .25099 .55231 .24318 Mtetra
.55231 .24318 .5586 .25099 .57051 .24671 .56426 .23887 Mtetra
.56426 .23887 .57051 .24671 .58247 .24243 .57625 .23455 Mtetra
.57625 .23455 .58247 .24243 .59448 .23812 .5883 .23021 Mtetra
.5883 .23021 .59448 .23812 .60655 .2338 .6004 .22585 Mtetra
.6004 .22585 .60655 .2338 .61866 .22945 .61255 .22147 Mtetra
.61255 .22147 .61866 .22945 .63083 .22509 .62475 .21708 Mtetra
.62475 .21708 .63083 .22509 .64305 .22072 .63701 .21266 Mtetra
.63701 .21266 .64305 .22072 .65533 .21632 .64932 .20823 Mtetra
.64932 .20823 .65533 .21632 .66766 .21191 .66169 .20378 Mtetra
.66169 .20378 .66766 .21191 .68004 .20747 .67411 .19931 Mtetra
.67411 .19931 .68004 .20747 .69248 .20302 .68658 .19482 Mtetra
.68658 .19482 .69248 .20302 .70497 .19855 .69911 .19031 Mtetra
.69911 .19031 .70497 .19855 .71751 .19406 .71169 .18579 Mtetra
.71169 .18579 .71751 .19406 .73011 .18955 .72433 .18124 Mtetra
.72433 .18124 .73011 .18955 .74277 .18502 .73703 .17667 Mtetra
.577 .695 .922 r
.06586 .40732 .07325 .41495 .08301 .41284 .07559 .40549 Mtetra
.564 .7 .932 r
.07559 .40549 .08301 .41284 .09221 .41533 .08536 .40385 Mtetra
.792 .68 .742 r
.08536 .40385 .09221 .41533 .10346 .4027 .09669 .39074 Mtetra
.347 .468 .841 r
.09669 .39074 .10346 .4027 .11329 .40101 .10593 .39363 Mtetra
.6 .713 .924 r
.10593 .39363 .11329 .40101 .12325 .39869 .11591 .39127 Mtetra
.561 .699 .933 r
.11591 .39127 .12325 .39869 .13238 .40363 .12585 .38966 Mtetra
.759 .643 .733 r
.12585 .38966 .13238 .40363 .14399 .38839 .13707 .37785 Mtetra
.436 .553 .876 r
.13707 .37785 .14399 .38839 .15404 .38637 .14675 .37898 Mtetra
.61 .719 .923 r
.14675 .37898 .15404 .38637 .16422 .3837 .15694 .37637 Mtetra
.601 .719 .927 r
.15694 .37637 .16422 .3837 .17427 .38252 .16715 .37392 Mtetra
.942 .578 .261 r
.16715 .37392 .17427 .38252 .18541 .37172 .17347 .40768 Mtetra
0 0 0 r
.17347 .40768 .18541 .37172 .19549 .37106 .18831 .36335 Mtetra
.602 .71 .92 r
.18831 .36335 .19549 .37106 .20586 .36817 .19866 .36087 Mtetra
.626 .731 .923 r
.19866 .36087 .20586 .36817 .21628 .3652 .2091 .35782 Mtetra
.612 .725 .926 r
.2091 .35782 .21628 .3652 .22663 .36349 .21957 .35509 Mtetra
0 .029 .558 r
.21957 .35509 .22663 .36349 .23791 .35207 .22894 .36466 Mtetra
.753 .892 .49 r
.22894 .36466 .23791 .35207 .2482 .35201 .24114 .34411 Mtetra
.603 .708 .918 r
.24114 .34411 .2482 .35201 .2588 .34894 .25171 .34157 Mtetra
.635 .736 .921 r
.25171 .34157 .2588 .34894 .26948 .34555 .26241 .33824 Mtetra
.64 .74 .921 r
.26241 .33824 .26948 .34555 .2802 .34212 .27316 .33477 Mtetra
.637 .739 .922 r
.27316 .33477 .2802 .34212 .29096 .33891 .28395 .33137 Mtetra
.61 .724 .926 r
.28395 .33137 .29096 .33891 .3016 .33795 .29474 .32858 Mtetra
.925 .726 .615 r
.29474 .32858 .3016 .33795 .313 .32667 .30848 .28418 Mtetra
0 0 .44 r
.30848 .28418 .313 .32667 .32378 .32499 .31687 .31715 Mtetra
.621 .721 .919 r
.31687 .31715 .32378 .32499 .33473 .32155 .32782 .31409 Mtetra
.644 .742 .92 r
.32782 .31409 .33473 .32155 .34574 .31781 .33885 .31042 Mtetra
.651 .748 .92 r
.33885 .31042 .34574 .31781 .35681 .31393 .34994 .30656 Mtetra
.654 .75 .92 r
.34994 .30656 .35681 .31393 .36793 .30997 .36109 .3026 Mtetra
.657 .752 .92 r
.36109 .3026 .36793 .30997 .37909 .30594 .37228 .29856 Mtetra
.658 .753 .92 r
.37228 .29856 .37909 .30594 .39031 .30187 .38352 .29447 Mtetra
.659 .754 .92 r
.38352 .29447 .39031 .30187 .40157 .29776 .39481 .29034 Mtetra
.39481 .29034 .40157 .29776 .41287 .29364 .40615 .28619 Mtetra
.40615 .28619 .41287 .29364 .42423 .28951 .41753 .28202 Mtetra
.41753 .28202 .42423 .28951 .43563 .28536 .42896 .27784 Mtetra
.658 .753 .92 r
.42896 .27784 .43563 .28536 .44708 .2812 .44044 .27364 Mtetra
.44044 .27364 .44708 .2812 .45857 .27704 .45197 .26944 Mtetra
.45197 .26944 .45857 .27704 .47012 .27286 .46355 .26523 Mtetra
.46355 .26523 .47012 .27286 .48171 .26866 .47517 .261 Mtetra
.47517 .261 .48171 .26866 .49335 .26446 .48685 .25676 Mtetra
.48685 .25676 .49335 .26446 .50504 .26023 .49857 .2525 Mtetra
.49857 .2525 .50504 .26023 .51679 .25599 .51035 .24823 Mtetra
.657 .753 .92 r
.51035 .24823 .51679 .25599 .52858 .25174 .52217 .24394 Mtetra
.52217 .24394 .52858 .25174 .54042 .24747 .53405 .23963 Mtetra
.657 .752 .92 r
.53405 .23963 .54042 .24747 .55231 .24318 .54597 .2353 Mtetra
.54597 .2353 .55231 .24318 .56426 .23887 .55795 .23096 Mtetra
.55795 .23096 .56426 .23887 .57625 .23455 .56998 .22661 Mtetra
.56998 .22661 .57625 .23455 .5883 .23021 .58206 .22223 Mtetra
.58206 .22223 .5883 .23021 .6004 .22585 .5942 .21783 Mtetra
.5942 .21783 .6004 .22585 .61255 .22147 .60638 .21342 Mtetra
.60638 .21342 .61255 .22147 .62475 .21708 .61862 .20899 Mtetra
.61862 .20899 .62475 .21708 .63701 .21266 .63092 .20454 Mtetra
.63092 .20454 .63701 .21266 .64932 .20823 .64327 .20007 Mtetra
.64327 .20007 .64932 .20823 .66169 .20378 .65567 .19559 Mtetra
.65567 .19559 .66169 .20378 .67411 .19931 .66813 .19108 Mtetra
.66813 .19108 .67411 .19931 .68658 .19482 .68064 .18656 Mtetra
.68064 .18656 .68658 .19482 .69911 .19031 .6932 .18201 Mtetra
.6932 .18201 .69911 .19031 .71169 .18579 .70583 .17745 Mtetra
.70583 .17745 .71169 .18579 .72433 .18124 .71851 .17286 Mtetra
.71851 .17286 .72433 .18124 .73703 .17667 .73124 .16826 Mtetra
.46 .587 .893 r
.05871 .39763 .06586 .40732 .07559 .40549 .06812 .39813 Mtetra
.591 .71 .926 r
.06812 .39813 .07559 .40549 .08536 .40385 .07797 .39596 Mtetra
.247 .534 .92 r
.07797 .39596 .08536 .40385 .09669 .39074 .08723 .39841 Mtetra
.738 .96 .672 r
.08723 .39841 .09669 .39074 .10593 .39363 .09859 .38567 Mtetra
.571 .687 .919 r
.09859 .38567 .10593 .39363 .11591 .39127 .1085 .38392 Mtetra
.599 .716 .926 r
.1085 .38392 .11591 .39127 .12585 .38966 .11855 .38154 Mtetra
0 .364 .832 r
.11855 .38154 .12585 .38966 .13707 .37785 .12774 .38645 Mtetra
.793 .962 .646 r
.12774 .38645 .13707 .37785 .14675 .37898 .13946 .37109 Mtetra
.585 .697 .919 r
.13946 .37109 .14675 .37898 .15694 .37637 .1496 .36901 Mtetra
.613 .724 .924 r
.1496 .36901 .15694 .37637 .16715 .37392 .15986 .36627 Mtetra
.537 .688 .936 r
.15986 .36627 .16715 .37392 .17347 .40768 .17 .36503 Mtetra
.626 .441 .613 r
.17 .36503 .17347 .40768 .18831 .36335 .18124 .35413 Mtetra
.522 .635 .903 r
.18124 .35413 .18831 .36335 .19866 .36087 .19141 .35341 Mtetra
.621 .726 .922 r
.19141 .35341 .19866 .36087 .2091 .35782 .20187 .35046 Mtetra
.624 .731 .924 r
.20187 .35046 .2091 .35782 .21957 .35509 .21238 .34742 Mtetra
.564 .701 .933 r
.21238 .34742 .21957 .35509 .22894 .36466 .22282 .34564 Mtetra
.721 .585 .703 r
.22282 .34564 .22894 .36466 .24114 .34411 .23421 .33412 Mtetra
.496 .605 .891 r
.23421 .33412 .24114 .34411 .25171 .34157 .24458 .334 Mtetra
.626 .728 .921 r
.24458 .334 .25171 .34157 .26241 .33824 .25528 .33085 Mtetra
.639 .739 .921 r
.25528 .33085 .26241 .33824 .27316 .33477 .26605 .32739 Mtetra
.639 .74 .922 r
.26605 .32739 .27316 .33477 .28395 .33137 .27688 .32389 Mtetra
.63 .735 .923 r
.27688 .32389 .28395 .33137 .29474 .32858 .28773 .32061 Mtetra
.522 .679 .936 r
.28773 .32061 .29474 .32858 .30848 .28418 .29847 .31959 Mtetra
.294 0 .28 r
.29847 .31959 .30848 .28418 .31687 .31715 .30998 .3082 Mtetra
.566 .669 .908 r
.30998 .3082 .31687 .31715 .32782 .31409 .32086 .30645 Mtetra
.637 .736 .92 r
.32086 .30645 .32782 .31409 .33885 .31042 .33191 .30294 Mtetra
.648 .745 .92 r
.33191 .30294 .33885 .31042 .34994 .30656 .34302 .29912 Mtetra
.653 .749 .92 r
.34302 .29912 .34994 .30656 .36109 .3026 .35419 .29516 Mtetra
.656 .751 .92 r
.35419 .29516 .36109 .3026 .37228 .29856 .36541 .29112 Mtetra
.657 .752 .92 r
.36541 .29112 .37228 .29856 .38352 .29447 .37668 .28701 Mtetra
.658 .753 .92 r
.37668 .28701 .38352 .29447 .39481 .29034 .388 .28286 Mtetra
.659 .754 .92 r
.388 .28286 .39481 .29034 .40615 .28619 .39937 .27867 Mtetra
.39937 .27867 .40615 .28619 .41753 .28202 .41078 .27447 Mtetra
.41078 .27447 .41753 .28202 .42896 .27784 .42225 .27025 Mtetra
.659 .753 .92 r
.42225 .27025 .42896 .27784 .44044 .27364 .43376 .26603 Mtetra
.658 .753 .92 r
.43376 .26603 .44044 .27364 .45197 .26944 .44532 .26179 Mtetra
.44532 .26179 .45197 .26944 .46355 .26523 .45692 .25754 Mtetra
.45692 .25754 .46355 .26523 .47517 .261 .46858 .25327 Mtetra
.46858 .25327 .47517 .261 .48685 .25676 .48029 .249 Mtetra
.48029 .249 .48685 .25676 .49857 .2525 .49205 .2447 Mtetra
.49205 .2447 .49857 .2525 .51035 .24823 .50385 .2404 Mtetra
.657 .753 .92 r
.50385 .2404 .51035 .24823 .52217 .24394 .51571 .23607 Mtetra
.51571 .23607 .52217 .24394 .53405 .23963 .52762 .23173 Mtetra
.52762 .23173 .53405 .23963 .54597 .2353 .53958 .22737 Mtetra
.657 .752 .92 r
.53958 .22737 .54597 .2353 .55795 .23096 .55159 .22299 Mtetra
.55159 .22299 .55795 .23096 .56998 .22661 .56366 .2186 Mtetra
.56366 .2186 .56998 .22661 .58206 .22223 .57578 .21419 Mtetra
.57578 .21419 .58206 .22223 .5942 .21783 .58795 .20976 Mtetra
.58795 .20976 .5942 .21783 .60638 .21342 .60017 .20531 Mtetra
.60017 .20531 .60638 .21342 .61862 .20899 .61245 .20084 Mtetra
.61245 .20084 .61862 .20899 .63092 .20454 .62478 .19636 Mtetra
.62478 .19636 .63092 .20454 .64327 .20007 .63716 .19185 Mtetra
.63716 .19185 .64327 .20007 .65567 .19559 .6496 .18733 Mtetra
.6496 .18733 .65567 .19559 .66813 .19108 .6621 .18278 Mtetra
.6621 .18278 .66813 .19108 .68064 .18656 .67465 .17822 Mtetra
.67465 .17822 .68064 .18656 .6932 .18201 .68725 .17364 Mtetra
.68725 .17364 .6932 .18201 .70583 .17745 .69991 .16904 Mtetra
.69991 .16904 .70583 .17745 .71851 .17286 .71263 .16441 Mtetra
.71263 .16441 .71851 .17286 .73124 .16826 .72541 .15977 Mtetra
.833 .95 .598 r
.04829 .40979 .05871 .39763 .06812 .39813 .06065 .39038 Mtetra
.577 .695 .922 r
.06065 .39038 .06812 .39813 .07797 .39596 .07046 .38849 Mtetra
.564 .7 .932 r
.07046 .38849 .07797 .39596 .08723 .39841 .0803 .38679 Mtetra
.792 .681 .742 r
.0803 .38679 .08723 .39841 .09859 .38567 .09175 .37356 Mtetra
.346 .468 .841 r
.09175 .37356 .09859 .38567 .1085 .38392 .10105 .37641 Mtetra
.6 .713 .924 r
.10105 .37641 .1085 .38392 .11855 .38154 .11112 .37399 Mtetra
.561 .699 .933 r
.11112 .37399 .11855 .38154 .12774 .38645 .12113 .37232 Mtetra
.759 .643 .733 r
.12113 .37232 .12774 .38645 .13946 .37109 .13247 .3604 Mtetra
.435 .553 .876 r
.13247 .3604 .13946 .37109 .1496 .36901 .14222 .36149 Mtetra
.61 .719 .923 r
.14222 .36149 .1496 .36901 .15986 .36627 .15249 .3588 Mtetra
.601 .719 .927 r
.15249 .3588 .15986 .36627 .17 .36503 .16279 .35629 Mtetra
.942 .576 .255 r
.16279 .35629 .17 .36503 .18124 .35413 .16911 .39014 Mtetra
0 0 0 r
.16911 .39014 .18124 .35413 .19141 .35341 .18415 .34556 Mtetra
.602 .71 .92 r
.18415 .34556 .19141 .35341 .20187 .35046 .19458 .34302 Mtetra
.626 .731 .923 r
.19458 .34302 .20187 .35046 .21238 .34742 .20512 .3399 Mtetra
.612 .725 .926 r
.20512 .3399 .21238 .34742 .22282 .34564 .21568 .33709 Mtetra
0 .035 .565 r
.21568 .33709 .22282 .34564 .23421 .33412 .22511 .34665 Mtetra
.76 .897 .498 r
.22511 .34665 .23421 .33412 .24458 .334 .23744 .32596 Mtetra
.603 .708 .918 r
.23744 .32596 .24458 .334 .25528 .33085 .24811 .32335 Mtetra
.635 .736 .921 r
.24811 .32335 .25528 .33085 .26605 .32739 .2589 .31995 Mtetra
.64 .74 .921 r
.2589 .31995 .26605 .32739 .27688 .32389 .26975 .3164 Mtetra
.637 .739 .922 r
.26975 .3164 .27688 .32389 .28773 .32061 .28064 .31292 Mtetra
.61 .724 .926 r
.28064 .31292 .28773 .32061 .29847 .31959 .29153 .31006 Mtetra
.926 .727 .613 r
.29153 .31006 .29847 .31959 .30998 .3082 .30544 .26543 Mtetra
0 0 .436 r
.30544 .26543 .30998 .3082 .32086 .30645 .31387 .29846 Mtetra
.621 .722 .919 r
.31387 .29846 .32086 .30645 .33191 .30294 .32491 .29533 Mtetra
.644 .742 .92 r
.32491 .29533 .33191 .30294 .34302 .29912 .33605 .29158 Mtetra
.651 .748 .92 r
.33605 .29158 .34302 .29912 .35419 .29516 .34724 .28765 Mtetra
.654 .75 .92 r
.34724 .28765 .35419 .29516 .36541 .29112 .35849 .2836 Mtetra
.657 .752 .92 r
.35849 .2836 .36541 .29112 .37668 .28701 .36979 .27949 Mtetra
.658 .753 .92 r
.36979 .27949 .37668 .28701 .388 .28286 .38114 .27531 Mtetra
.659 .754 .92 r
.38114 .27531 .388 .28286 .39937 .27867 .39254 .2711 Mtetra
.39254 .2711 .39937 .27867 .41078 .27447 .40398 .26687 Mtetra
.40398 .26687 .41078 .27447 .42225 .27025 .41548 .26261 Mtetra
.41548 .26261 .42225 .27025 .43376 .26603 .42702 .25835 Mtetra
.658 .753 .92 r
.42702 .25835 .43376 .26603 .44532 .26179 .43861 .25407 Mtetra
.43861 .25407 .44532 .26179 .45692 .25754 .45025 .24979 Mtetra
.45025 .24979 .45692 .25754 .46858 .25327 .46194 .24549 Mtetra
.46194 .24549 .46858 .25327 .48029 .249 .47368 .24118 Mtetra
.47368 .24118 .48029 .249 .49205 .2447 .48547 .23685 Mtetra
.48547 .23685 .49205 .2447 .50385 .2404 .49731 .2325 Mtetra
.49731 .2325 .50385 .2404 .51571 .23607 .5092 .22814 Mtetra
.657 .753 .92 r
.5092 .22814 .51571 .23607 .52762 .23173 .52114 .22377 Mtetra
.52114 .22377 .52762 .23173 .53958 .22737 .53314 .21937 Mtetra
.657 .752 .92 r
.53314 .21937 .53958 .22737 .55159 .22299 .54519 .21496 Mtetra
.54519 .21496 .55159 .22299 .56366 .2186 .55729 .21053 Mtetra
.55729 .21053 .56366 .2186 .57578 .21419 .56944 .20608 Mtetra
.56944 .20608 .57578 .21419 .58795 .20976 .58164 .20162 Mtetra
.58164 .20162 .58795 .20976 .60017 .20531 .5939 .19713 Mtetra
.5939 .19713 .60017 .20531 .61245 .20084 .60622 .19263 Mtetra
.60622 .19263 .61245 .20084 .62478 .19636 .61858 .1881 Mtetra
.61858 .1881 .62478 .19636 .63716 .19185 .63101 .18356 Mtetra
.63101 .18356 .63716 .19185 .6496 .18733 .64348 .179 Mtetra
.64348 .179 .6496 .18733 .6621 .18278 .65602 .17442 Mtetra
.65602 .17442 .6621 .18278 .67465 .17822 .6686 .16982 Mtetra
.6686 .16982 .67465 .17822 .68725 .17364 .68125 .1652 Mtetra
.68125 .1652 .68725 .17364 .69991 .16904 .69395 .16056 Mtetra
.69395 .16056 .69991 .16904 .71263 .16441 .70671 .1559 Mtetra
.70671 .1559 .71263 .16441 .72541 .15977 .71952 .15122 Mtetra
.719 .587 .706 r
.04228 .39153 .04829 .40979 .06065 .39038 .05342 .38055 Mtetra
.46 .587 .893 r
.05342 .38055 .06065 .39038 .07046 .38849 .0629 .38099 Mtetra
.591 .71 .926 r
.0629 .38099 .07046 .38849 .0803 .38679 .07283 .37876 Mtetra
.249 .535 .92 r
.07283 .37876 .0803 .38679 .09175 .37356 .08216 .38117 Mtetra
.745 .964 .68 r
.08216 .38117 .09175 .37356 .10105 .37641 .09363 .36832 Mtetra
.571 .687 .919 r
.09363 .36832 .10105 .37641 .11112 .37399 .10362 .36651 Mtetra
.599 .716 .926 r
.10362 .36651 .11112 .37399 .12113 .37232 .11375 .36407 Mtetra
0 .366 .834 r
.11375 .36407 .12113 .37232 .13247 .3604 .123 .36894 Mtetra
.798 .965 .653 r
.123 .36894 .13247 .3604 .14222 .36149 .13485 .35346 Mtetra
.585 .697 .919 r
.13485 .35346 .14222 .36149 .15249 .3588 .14507 .35132 Mtetra
.613 .724 .924 r
.14507 .35132 .15249 .3588 .16279 .35629 .15542 .34851 Mtetra
.538 .688 .936 r
.15542 .34851 .16279 .35629 .16911 .39014 .16565 .3472 Mtetra
.624 .44 .612 r
.16565 .3472 .16911 .39014 .18415 .34556 .177 .3362 Mtetra
.522 .635 .903 r
.177 .3362 .18415 .34556 .19458 .34302 .18725 .33542 Mtetra
.621 .726 .922 r
.18725 .33542 .19458 .34302 .20512 .3399 .1978 .3324 Mtetra
.624 .731 .924 r
.1978 .3324 .20512 .3399 .21568 .33709 .2084 .32929 Mtetra
.564 .701 .933 r
.2084 .32929 .21568 .33709 .22511 .34665 .21893 .32744 Mtetra
.721 .585 .703 r
.21893 .32744 .22511 .34665 .23744 .32596 .23044 .31582 Mtetra
.496 .604 .891 r
.23044 .31582 .23744 .32596 .24811 .32335 .2409 .31563 Mtetra
.626 .728 .921 r
.2409 .31563 .24811 .32335 .2589 .31995 .25169 .31242 Mtetra
.639 .739 .921 r
.25169 .31242 .2589 .31995 .26975 .3164 .26256 .30888 Mtetra
.639 .74 .922 r
.26256 .30888 .26975 .3164 .28064 .31292 .27348 .3053 Mtetra
.63 .735 .923 r
.27348 .3053 .28064 .31292 .29153 .31006 .28443 .30195 Mtetra
.522 .679 .936 r
.28443 .30195 .29153 .31006 .30544 .26543 .29527 .30086 Mtetra
.285 0 .27 r
.29527 .30086 .30544 .26543 .31387 .29846 .3069 .28936 Mtetra
.565 .669 .908 r
.3069 .28936 .31387 .29846 .32491 .29533 .31787 .28754 Mtetra
.637 .736 .92 r
.31787 .28754 .32491 .29533 .33605 .29158 .32902 .28395 Mtetra
.648 .745 .92 r
.32902 .28395 .33605 .29158 .34724 .28765 .34024 .28005 Mtetra
.653 .749 .92 r
.34024 .28005 .34724 .28765 .35849 .2836 .35152 .27602 Mtetra
.656 .751 .92 r
.35152 .27602 .35849 .2836 .36979 .27949 .36285 .27189 Mtetra
.657 .752 .92 r
.36285 .27189 .36979 .27949 .38114 .27531 .37422 .2677 Mtetra
.658 .753 .92 r
.37422 .2677 .38114 .27531 .39254 .2711 .38565 .26347 Mtetra
.659 .754 .92 r
.38565 .26347 .39254 .2711 .40398 .26687 .39713 .2592 Mtetra
.39713 .2592 .40398 .26687 .41548 .26261 .40865 .25491 Mtetra
.40865 .25491 .41548 .26261 .42702 .25835 .42023 .25061 Mtetra
.659 .753 .92 r
.42023 .25061 .42702 .25835 .43861 .25407 .43185 .2463 Mtetra
.658 .753 .92 r
.43185 .2463 .43861 .25407 .45025 .24979 .44352 .24198 Mtetra
.44352 .24198 .45025 .24979 .46194 .24549 .45524 .23764 Mtetra
.45524 .23764 .46194 .24549 .47368 .24118 .46702 .23329 Mtetra
.46702 .23329 .47368 .24118 .48547 .23685 .47884 .22893 Mtetra
.47884 .22893 .48547 .23685 .49731 .2325 .49071 .22455 Mtetra
.49071 .22455 .49731 .2325 .5092 .22814 .50264 .22015 Mtetra
.657 .753 .92 r
.50264 .22015 .5092 .22814 .52114 .22377 .51462 .21574 Mtetra
.51462 .21574 .52114 .22377 .53314 .21937 .52664 .21131 Mtetra
.52664 .21131 .53314 .21937 .54519 .21496 .53873 .20686 Mtetra
.657 .752 .92 r
.53873 .20686 .54519 .21496 .55729 .21053 .55086 .20239 Mtetra
.55086 .20239 .55729 .21053 .56944 .20608 .56305 .19791 Mtetra
.56305 .19791 .56944 .20608 .58164 .20162 .57529 .19341 Mtetra
.57529 .19341 .58164 .20162 .5939 .19713 .58759 .18888 Mtetra
.58759 .18888 .5939 .19713 .60622 .19263 .59994 .18434 Mtetra
.59994 .18434 .60622 .19263 .61858 .1881 .61234 .17978 Mtetra
.61234 .17978 .61858 .1881 .63101 .18356 .6248 .1752 Mtetra
.6248 .1752 .63101 .18356 .64348 .179 .63731 .1706 Mtetra
.63731 .1706 .64348 .179 .65602 .17442 .64988 .16599 Mtetra
.64988 .16599 .65602 .17442 .6686 .16982 .66251 .16135 Mtetra
.66251 .16135 .6686 .16982 .68125 .1652 .6752 .15669 Mtetra
.6752 .15669 .68125 .1652 .69395 .16056 .68794 .15201 Mtetra
.68794 .15201 .69395 .16056 .70671 .1559 .70073 .14731 Mtetra
.70073 .14731 .70671 .1559 .71952 .15122 .71359 .14259 Mtetra
.561 .076 0 r
.03475 .38318 .04228 .39153 .05342 .38055 .04285 .39266 Mtetra
.838 .952 .604 r
.04285 .39266 .05342 .38055 .0629 .38099 .05534 .37311 Mtetra
.577 .695 .922 r
.05534 .37311 .0629 .38099 .07283 .37876 .06523 .37116 Mtetra
.564 .7 .932 r
.06523 .37116 .07283 .37876 .08216 .38117 .07515 .3694 Mtetra
.793 .682 .742 r
.07515 .3694 .08216 .38117 .09363 .36832 .08671 .35606 Mtetra
.344 .467 .841 r
.08671 .35606 .09363 .36832 .10362 .36651 .09608 .35887 Mtetra
.6 .713 .924 r
.09608 .35887 .10362 .36651 .11375 .36407 .10623 .35638 Mtetra
.561 .699 .933 r
.10623 .35638 .11375 .36407 .123 .36894 .11633 .35464 Mtetra
.76 .644 .733 r
.11633 .35464 .123 .36894 .13485 .35346 .12777 .34263 Mtetra
.434 .553 .876 r
.12777 .34263 .13485 .35346 .14507 .35132 .13761 .34366 Mtetra
.61 .719 .923 r
.13761 .34366 .14507 .35132 .15542 .34851 .14797 .3409 Mtetra
.601 .719 .927 r
.14797 .3409 .15542 .34851 .16565 .3472 .15835 .33832 Mtetra
.941 .574 .25 r
.15835 .33832 .16565 .3472 .177 .3362 .16467 .37225 Mtetra
.677 .738 .234 r
.16467 .37225 .177 .3362 .18725 .33542 .1799 .32744 Mtetra
.602 .71 .92 r
.1799 .32744 .18725 .33542 .1978 .3324 .19043 .32482 Mtetra
.626 .731 .923 r
.19043 .32482 .1978 .3324 .2084 .32929 .20106 .32163 Mtetra
.612 .725 .926 r
.20106 .32163 .2084 .32929 .21893 .32744 .21171 .31875 Mtetra
0 .041 .572 r
.21171 .31875 .21893 .32744 .23044 .31582 .22121 .32829 Mtetra
.767 .902 .506 r
.22121 .32829 .23044 .31582 .2409 .31563 .23367 .30745 Mtetra
.603 .708 .918 r
.23367 .30745 .2409 .31563 .25169 .31242 .24444 .30477 Mtetra
.635 .736 .921 r
.24444 .30477 .25169 .31242 .26256 .30888 .25532 .30129 Mtetra
.64 .74 .921 r
.25532 .30129 .26256 .30888 .27348 .3053 .26627 .29767 Mtetra
.637 .739 .922 r
.26627 .29767 .27348 .3053 .28443 .30195 .27726 .29411 Mtetra
.61 .724 .926 r
.27726 .29411 .28443 .30195 .29527 .30086 .28825 .29118 Mtetra
.928 .728 .612 r
.28825 .29118 .29527 .30086 .3069 .28936 .30234 .24632 Mtetra
0 0 .432 r
.30234 .24632 .3069 .28936 .31787 .28754 .3108 .27941 Mtetra
.62 .722 .919 r
.3108 .27941 .31787 .28754 .32902 .28395 .32195 .2762 Mtetra
.644 .742 .92 r
.32195 .2762 .32902 .28395 .34024 .28005 .33319 .27237 Mtetra
.651 .748 .92 r
.33319 .27237 .34024 .28005 .35152 .27602 .34449 .26835 Mtetra
.654 .75 .92 r
.34449 .26835 .35152 .27602 .36285 .27189 .35585 .26423 Mtetra
.657 .752 .92 r
.35585 .26423 .36285 .27189 .37422 .2677 .36725 .26003 Mtetra
.658 .753 .92 r
.36725 .26003 .37422 .2677 .38565 .26347 .37871 .25577 Mtetra
.659 .754 .92 r
.37871 .25577 .38565 .26347 .39713 .2592 .39022 .25148 Mtetra
.39022 .25148 .39713 .2592 .40865 .25491 .40177 .24716 Mtetra
.40177 .24716 .40865 .25491 .42023 .25061 .41338 .24282 Mtetra
.41338 .24282 .42023 .25061 .43185 .2463 .42503 .23847 Mtetra
.658 .753 .92 r
.42503 .23847 .43185 .2463 .44352 .24198 .43674 .23411 Mtetra
.43674 .23411 .44352 .24198 .45524 .23764 .44849 .22973 Mtetra
.44849 .22973 .45524 .23764 .46702 .23329 .4603 .22535 Mtetra
.4603 .22535 .46702 .23329 .47884 .22893 .47216 .22095 Mtetra
.47216 .22095 .47884 .22893 .49071 .22455 .48406 .21653 Mtetra
.48406 .21653 .49071 .22455 .50264 .22015 .49602 .2121 Mtetra
.49602 .2121 .50264 .22015 .51462 .21574 .50803 .20765 Mtetra
.657 .753 .92 r
.50803 .20765 .51462 .21574 .52664 .21131 .5201 .20318 Mtetra
.5201 .20318 .52664 .21131 .53873 .20686 .53221 .1987 Mtetra
.657 .752 .92 r
.53221 .1987 .53873 .20686 .55086 .20239 .54438 .19419 Mtetra
.54438 .19419 .55086 .20239 .56305 .19791 .55661 .18967 Mtetra
.55661 .18967 .56305 .19791 .57529 .19341 .56888 .18513 Mtetra
.56888 .18513 .57529 .19341 .58759 .18888 .58122 .18057 Mtetra
.58122 .18057 .58759 .18888 .59994 .18434 .5936 .17599 Mtetra
.5936 .17599 .59994 .18434 .61234 .17978 .60604 .17139 Mtetra
.60604 .17139 .61234 .17978 .6248 .1752 .61854 .16678 Mtetra
.61854 .16678 .6248 .1752 .63731 .1706 .63109 .16214 Mtetra
.63109 .16214 .63731 .1706 .64988 .16599 .6437 .15748 Mtetra
.6437 .15748 .64988 .16599 .66251 .16135 .65637 .1528 Mtetra
.65637 .1528 .66251 .16135 .6752 .15669 .66909 .14811 Mtetra
.66909 .14811 .6752 .15669 .68794 .15201 .68187 .14339 Mtetra
.68187 .14339 .68794 .15201 .70073 .14731 .69471 .13865 Mtetra
.69471 .13865 .70073 .14731 .71359 .14259 .70761 .13389 Mtetra
.536 .686 .936 r
.02706 .37549 .03475 .38318 .04285 .39266 .03678 .37422 Mtetra
.719 .587 .706 r
.03678 .37422 .04285 .39266 .05534 .37311 .04802 .36314 Mtetra
.459 .586 .893 r
.04802 .36314 .05534 .37311 .06523 .37116 .05758 .36353 Mtetra
.591 .71 .926 r
.05758 .36353 .06523 .37116 .07515 .3694 .06759 .36124 Mtetra
.251 .535 .921 r
.06759 .36124 .07515 .3694 .08671 .35606 .07699 .36359 Mtetra
.752 .968 .687 r
.07699 .36359 .08671 .35606 .09608 .35887 .08857 .35064 Mtetra
.571 .687 .919 r
.08857 .35064 .09608 .35887 .10623 .35638 .09865 .34876 Mtetra
.599 .716 .926 r
.09865 .34876 .10623 .35638 .11633 .35464 .10886 .34625 Mtetra
0 .369 .836 r
.10886 .34625 .11633 .35464 .12777 .34263 .11818 .35109 Mtetra
.804 .968 .659 r
.11818 .35109 .12777 .34263 .13761 .34366 .13015 .33549 Mtetra
.585 .697 .919 r
.13015 .33549 .13761 .34366 .14797 .3409 .14046 .33328 Mtetra
.613 .724 .924 r
.14046 .33328 .14797 .3409 .15835 .33832 .15089 .3304 Mtetra
.538 .687 .936 r
.15089 .3304 .15835 .33832 .16467 .37225 .16121 .32903 Mtetra
.623 .438 .611 r
.16121 .32903 .16467 .37225 .1799 .32744 .17267 .31792 Mtetra
.522 .635 .903 r
.17267 .31792 .1799 .32744 .19043 .32482 .18301 .31708 Mtetra
.621 .726 .922 r
.18301 .31708 .19043 .32482 .20106 .32163 .19365 .31399 Mtetra
.624 .731 .924 r
.19365 .31399 .20106 .32163 .21171 .31875 .20435 .3108 Mtetra
.564 .701 .933 r
.20435 .3108 .21171 .31875 .22121 .32829 .21497 .30889 Mtetra
.721 .585 .703 r
.21497 .30889 .22121 .32829 .23367 .30745 .22659 .29716 Mtetra
.495 .604 .891 r
.22659 .29716 .23367 .30745 .24444 .30477 .23714 .29691 Mtetra
.626 .728 .921 r
.23714 .29691 .24444 .30477 .25532 .30129 .24803 .29362 Mtetra
.638 .739 .921 r
.24803 .29362 .25532 .30129 .26627 .29767 .259 .29 Mtetra
.639 .74 .922 r
.259 .29 .26627 .29767 .27726 .29411 .27002 .28634 Mtetra
.63 .735 .923 r
.27002 .28634 .27726 .29411 .28825 .29118 .28107 .28292 Mtetra
.522 .679 .936 r
.28107 .28292 .28825 .29118 .30234 .24632 .29201 .28175 Mtetra
.275 0 .26 r
.29201 .28175 .30234 .24632 .3108 .27941 .30375 .27015 Mtetra
.565 .669 .908 r
.30375 .27015 .3108 .27941 .32195 .2762 .31483 .26826 Mtetra
.637 .736 .92 r
.31483 .26826 .32195 .2762 .33319 .27237 .32608 .26459 Mtetra
.648 .745 .92 r
.32608 .26459 .33319 .27237 .34449 .26835 .33741 .26061 Mtetra
.653 .749 .92 r
.33741 .26061 .34449 .26835 .35585 .26423 .34879 .25649 Mtetra
.656 .751 .92 r
.34879 .25649 .35585 .26423 .36725 .26003 .36023 .25228 Mtetra
.657 .752 .92 r
.36023 .25228 .36725 .26003 .37871 .25577 .37172 .24801 Mtetra
.658 .753 .92 r
.37172 .24801 .37871 .25577 .39022 .25148 .38325 .24369 Mtetra
.659 .754 .92 r
.38325 .24369 .39022 .25148 .40177 .24716 .39484 .23933 Mtetra
.39484 .23933 .40177 .24716 .41338 .24282 .40648 .23496 Mtetra
.40648 .23496 .41338 .24282 .42503 .23847 .41816 .23057 Mtetra
.659 .753 .92 r
.41816 .23057 .42503 .23847 .43674 .23411 .4299 .22617 Mtetra
.658 .753 .92 r
.4299 .22617 .43674 .23411 .44849 .22973 .44169 .22176 Mtetra
.44169 .22176 .44849 .22973 .4603 .22535 .45353 .21734 Mtetra
.45353 .21734 .4603 .22535 .47216 .22095 .46542 .2129 Mtetra
.46542 .2129 .47216 .22095 .48406 .21653 .47736 .20845 Mtetra
.47736 .20845 .48406 .21653 .49602 .2121 .48935 .20398 Mtetra
.48935 .20398 .49602 .2121 .50803 .20765 .5014 .19949 Mtetra
.657 .753 .92 r
.5014 .19949 .50803 .20765 .5201 .20318 .5135 .19499 Mtetra
.5135 .19499 .5201 .20318 .53221 .1987 .52565 .19046 Mtetra
.52565 .19046 .53221 .1987 .54438 .19419 .53785 .18592 Mtetra
.657 .752 .92 r
.53785 .18592 .54438 .19419 .55661 .18967 .55011 .18136 Mtetra
.55011 .18136 .55661 .18967 .56888 .18513 .56243 .17679 Mtetra
.56243 .17679 .56888 .18513 .58122 .18057 .57479 .17219 Mtetra
.57479 .17219 .58122 .18057 .5936 .17599 .58722 .16757 Mtetra
.58722 .16757 .5936 .17599 .60604 .17139 .5997 .16294 Mtetra
.5997 .16294 .60604 .17139 .61854 .16678 .61223 .15828 Mtetra
.61223 .15828 .61854 .16678 .63109 .16214 .62482 .1536 Mtetra
.62482 .1536 .63109 .16214 .6437 .15748 .63747 .14891 Mtetra
.63747 .14891 .6437 .15748 .65637 .1528 .65017 .14419 Mtetra
.65017 .14419 .65637 .1528 .66909 .14811 .66294 .13945 Mtetra
.66294 .13945 .66909 .14811 .68187 .14339 .67576 .1347 Mtetra
.67576 .1347 .68187 .14339 .69471 .13865 .68863 .12992 Mtetra
.68863 .12992 .69471 .13865 .70761 .13389 .70157 .12512 Mtetra
.579 .704 .928 r
.01931 .36779 .02706 .37549 .03678 .37422 .02916 .36574 Mtetra
.554 .07 0 r
.02916 .36574 .03678 .37422 .04802 .36314 .03731 .37519 Mtetra
.843 .955 .61 r
.03731 .37519 .04802 .36314 .05758 .36353 .04993 .35551 Mtetra
.577 .695 .922 r
.04993 .35551 .05758 .36353 .06759 .36124 .0599 .3535 Mtetra
.564 .7 .932 r
.0599 .3535 .06759 .36124 .07699 .36359 .0699 .35167 Mtetra
.793 .683 .742 r
.0699 .35167 .07699 .36359 .08857 .35064 .08158 .33823 Mtetra
.343 .467 .841 r
.08158 .33823 .08857 .35064 .09865 .34876 .09102 .34099 Mtetra
.6 .713 .924 r
.09102 .34099 .09865 .34876 .10886 .34625 .10125 .33843 Mtetra
.561 .699 .933 r
.10125 .33843 .10886 .34625 .11818 .35109 .11144 .33663 Mtetra
.76 .644 .733 r
.11144 .33663 .11818 .35109 .13015 .33549 .12299 .3245 Mtetra
.433 .553 .876 r
.12299 .3245 .13015 .33549 .14046 .33328 .13291 .32548 Mtetra
.61 .719 .923 r
.13291 .32548 .14046 .33328 .15089 .3304 .14335 .32266 Mtetra
.601 .719 .927 r
.14335 .32266 .15089 .3304 .16121 .32903 .15383 .32 Mtetra
.94 .572 .244 r
.15383 .32 .16121 .32903 .17267 .31792 .16015 .354 Mtetra
.686 .745 .243 r
.16015 .354 .17267 .31792 .18301 .31708 .17558 .30895 Mtetra
.602 .71 .92 r
.17558 .30895 .18301 .31708 .19365 .31399 .18619 .30627 Mtetra
.626 .731 .923 r
.18619 .30627 .19365 .31399 .20435 .3108 .19692 .303 Mtetra
.612 .725 .926 r
.19692 .303 .20435 .3108 .21497 .30889 .20766 .30005 Mtetra
0 .047 .578 r
.20766 .30005 .21497 .30889 .22659 .29716 .21723 .30956 Mtetra
.774 .906 .514 r
.21723 .30956 .22659 .29716 .23714 .29691 .22983 .28858 Mtetra
.603 .708 .918 r
.22983 .28858 .23714 .29691 .24803 .29362 .24069 .28582 Mtetra
.635 .736 .921 r
.24069 .28582 .24803 .29362 .259 .29 .25168 .28227 Mtetra
.64 .74 .921 r
.25168 .28227 .259 .29 .27002 .28634 .26273 .27857 Mtetra
.637 .739 .922 r
.26273 .27857 .27002 .28634 .28107 .28292 .27382 .27493 Mtetra
.61 .724 .926 r
.27382 .27493 .28107 .28292 .29201 .28175 .28491 .27192 Mtetra
.929 .728 .611 r
.28491 .27192 .29201 .28175 .30375 .27015 .29917 .22683 Mtetra
0 0 .427 r
.29917 .22683 .30375 .27015 .31483 .26826 .30767 .25997 Mtetra
.62 .722 .919 r
.30767 .25997 .31483 .26826 .32608 .26459 .31893 .25668 Mtetra
.644 .742 .92 r
.31893 .25668 .32608 .26459 .33741 .26061 .33027 .25277 Mtetra
.651 .748 .92 r
.33027 .25277 .33741 .26061 .34879 .25649 .34168 .24867 Mtetra
.654 .75 .92 r
.34168 .24867 .34879 .25649 .36023 .25228 .35315 .24446 Mtetra
.657 .752 .92 r
.35315 .24446 .36023 .25228 .37172 .24801 .36466 .24017 Mtetra
.658 .753 .92 r
.36466 .24017 .37172 .24801 .38325 .24369 .37623 .23583 Mtetra
.659 .754 .92 r
.37623 .23583 .38325 .24369 .39484 .23933 .38785 .23145 Mtetra
.38785 .23145 .39484 .23933 .40648 .23496 .39952 .22704 Mtetra
.39952 .22704 .40648 .23496 .41816 .23057 .41124 .22262 Mtetra
.41124 .22262 .41816 .23057 .4299 .22617 .42301 .21818 Mtetra
.658 .753 .92 r
.42301 .21818 .4299 .22617 .44169 .22176 .43483 .21373 Mtetra
.43483 .21373 .44169 .22176 .45353 .21734 .4467 .20927 Mtetra
.4467 .20927 .45353 .21734 .46542 .2129 .45862 .20479 Mtetra
.45862 .20479 .46542 .2129 .47736 .20845 .4706 .2003 Mtetra
.4706 .2003 .47736 .20845 .48935 .20398 .48263 .19579 Mtetra
.48263 .19579 .48935 .20398 .5014 .19949 .49471 .19127 Mtetra
.49471 .19127 .5014 .19949 .5135 .19499 .50684 .18673 Mtetra
.657 .753 .92 r
.50684 .18673 .5135 .19499 .52565 .19046 .51903 .18217 Mtetra
.51903 .18217 .52565 .19046 .53785 .18592 .53127 .17759 Mtetra
.657 .752 .92 r
.53127 .17759 .53785 .18592 .55011 .18136 .54356 .17299 Mtetra
.54356 .17299 .55011 .18136 .56243 .17679 .55591 .16837 Mtetra
.55591 .16837 .56243 .17679 .57479 .17219 .56832 .16374 Mtetra
.56832 .16374 .57479 .17219 .58722 .16757 .58078 .15908 Mtetra
.58078 .15908 .58722 .16757 .5997 .16294 .5933 .15441 Mtetra
.5933 .15441 .5997 .16294 .61223 .15828 .60587 .14971 Mtetra
.60587 .14971 .61223 .15828 .62482 .1536 .6185 .145 Mtetra
.6185 .145 .62482 .1536 .63747 .14891 .63119 .14026 Mtetra
.63119 .14026 .63747 .14891 .65017 .14419 .64393 .1355 Mtetra
.64393 .1355 .65017 .14419 .66294 .13945 .65673 .13073 Mtetra
.65673 .13073 .66294 .13945 .67576 .1347 .66959 .12593 Mtetra
.66959 .12593 .67576 .1347 .68863 .12992 .68251 .12111 Mtetra
.68251 .12111 .68863 .12992 .70157 .12512 .69549 .11627 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05Yoo`0JD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoAMo
o`03001oogoo04Moo`00Qgoo0`00HGoo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
2E;mD_aBo5;lD_eBo000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069oo`0PD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoAIoo`03
001oogoo04Ioo`00PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eoo`00P7oo0P00Hgoo
02EBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d0
0e;l00=BoE;lOol05Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1MOol0;5;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;l00000e;l00EBoE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00HGoo03ABo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo049oo`00Lgoo0`00HGoo
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00ABoE;lD_aBo1Moo`03001oogoo
045oo`00LGoo0P00HWoo03UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aB
oE;lD_eBo5;mD_`05Goo00<007oo0000@Woo001^Ool3001POol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001oogoo041oo`00
Jgoo0`00HGoo045Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001B
o5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo03moo`00JGoo0P000goo00<007ooOol0Fgoo
00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m
00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`0oOol006Ioo`<005moo`19D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d05Woo00<007ooOol0?Woo001TOol2001POol00e;lD_eBo002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=B
o005D_eBo5;lD_aBo@02D_`FOol00`00Oomoo`0mOol0065oo`<0061oo`1?D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d05Goo00<007ooOol09Goo0`005Goo000eOol4000VOol2001O
Ool00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0E
Ool00`00Oomoo`0VOol00`00Oomoo`0COol003Aoo`03001oogoo009oo`03001oogoo021oo`<0061o
o`1ED_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<0
07ooOol09Goo00<007ooOol04goo000iOol00`00Oomoo`0NOol20002Ool00`00Oomoo`1LOol2D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l5Goo00<0
07ooOol097oo00<007oo000057oo000/Ool60007Ool00`00Oomoo`0KOol3001OOol0G5;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dFOol0
0`00Oomoo`0SOol00`00Ool0000DOol003Eoo`@001aoo`80061oo`9Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Ioo`03001o
ogoo025oo`05001oogooOol0000COol003Eoo`03001oogoo01Yoo`<0061oo`1RD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoAAoo`8002=oo`05001oogooOol0000COol003Eoo`03001oogoo01Moo`<005moo`9Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0OOol3000017oo000000004Woo000eOol5000C
Ool2001POol0JE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0gOol004Yo
o`<00003Ool007oo05eoo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol0
0`00Oomoo`08Ool4000[Ool004Qoo`8005moo`1`D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004Eoo`<0
05moo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`FOol0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004=oo`80061oo`1eD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo00Eoo`03
001oogoo009oo`03001oogoo02Qoo`00@7oo0`00GWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol0:7oo000nOol2001MOol0Oe;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo02Qoo`00>goo1000@7oo00=fd`0<Ool06Woo0e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_aoo`0DOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003Uoo`8000Ao
o`03001oogoo03eoo`03L]803Goo01Qoo`24DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007oo
Ool00goo1000:goo000fOol30016Ool00gKCM]9oo`0DOol3D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m01=oo`800003Ool007oo039oo`00<goo0`00BGoo00=bdWKcOol04Woo08]BoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0aOol0035oo`8004]oo`04M]9f
dg;B00d@Ool00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00800003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
01Eoo`03001oogoo031oo`00;Woo0`00CGoo00Aflg;BM_<030aoo`1cD_eBo5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d00`0001eBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Eoo`03001oogoo02moo`00;7oo1000
CWoo00AbdWKCM]803@Qoo`=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBo@00000005;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo004D_eBo5;lD_`EOol00`00Oomoo`0_Ool002Yoo`80059oo`04M_=bdWKc00`7Ool0LTkL
D_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@<0000TD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l5Goo00<007ooOol0;Woo000ZOol2001AOol017KCM]9fdg;B0P0=17oo00EBoDkLD_a>o5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`00000D_d00e;l00EBoE;lD_aBo5;m00=B
o005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Eo
o`03001oogoo02ioo`0047oo1@000goo100017oo10001Woo00<007oo0000D7oo07UbdWKcL]9flg;B
00e:g4kMB]a>gD[LD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0030000:U;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo02eoo`004Woo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo00=oo`800003Ool007oo04ioo`09M]=bdWKCM]9fd`0<
00e>g4kM00=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_`000020003D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eBo5;l01Eoo`03001oogoo02aoo`004Woo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo009oo`8000=oo`03001oogoo04aoo`1cL]9flg;BM_=b
dP0=00a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`00039Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol0;7oo0007Ool60005Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool0BWoo00IbdWKCM]9fdg;BM]<200d02@0<C_a>g5;mC]a>o5;lD_e>o002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l0`00
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol057oo00<007ooOol0
:goo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol0BGoo06iflg;BM_=bdWKcL]803DJLA[a6W5;mC]aBoDkLD_e>o5;mC]aB
oDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l0`0003UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`04goo00<007oo0000;7oo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo
00<007ooOol00Woo0P001Woo0P00AGoo00]:gDkMB]a>gD[MM]=bdWKCM]9fd`0=0096W006A[a6W4JL
C_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_`000020003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01U;mD_aBo5;lD_eBo1Aoo`03001oogoo02Yoo`0047oo0`0017oo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo03ioo`1`D_e>g5;mC]aB
oD[LC]e:g4kmL]9flg;BM_=bdWKc00a>gD[LC]e:g4kMC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`30000@5;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<007ooOol0
:Goo000BOol00`00Oomoo`03Ool40004Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`0jOol2C_`0
45;mC]a>oDklD_e>g4kmB]e>gD[LC]efdWKCL]9fdgKB0P0=0TkL00I>gDkLD_a>o5;mC_`2D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l00000P000e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@0EOol00`00Oomoo`0XOol002Qoo`03001oogoo00Yoo`03001oogoo03Eoo`1bC]aBoDkL
D_e>g5;mC]aBoDkLD_e>g4kmC]aBoCjM@[dnW7KcL]9flg;BM_<0300=B]a>gD[LC]e:g5;mC]aBoDkL
D_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0P0004MBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l01Eoo`03001oogoo02Qoo`00:7oo0`002goo00<007ooOol0<7oo00Y:gDZlB]a:g4[M
C]a>o4kLC_e>g09>o00>D_e>g4kmC]a>oDkLC_e2_GKCL]9fdgKBM]=bdP<03@05C]a>o4kLD_e>g002
D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l0`000U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`EOol00`00Oomoo`0WOol002Qoo`03001oogoo00aoo`03001oogoo02ioo`1a
Hi1OSdkMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mL]9flg;BM_=bdWKc00a6_4JL
A[a>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@030000CU;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02Ioo`00:7oo00<007ooOol03Goo
00<007ooOol0;Goo0f>?00I:gDZlB]a:g5;mC]`2C_`04E;mC]a>oDklD_e>g4kMB]e>gD[LC]efdWKC
L]9fdgKB00d00dJL00I6_4JLD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol002Qo
o`8000moo`03001oogoo02]oo`0LGhmST5m_Hi1OSdkmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>
oD[LC]e:g7KcL]9flg;BM_<200d0CT[LC]e:g4kMB]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@<0
001FD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03
001oogoo02Eoo`00:7oo00<007ooOol03goo00<007ooOol0:Woo0UYE00DnG3iK?U`nFdkM00=>g00C
C]e>g4klC_aBoDkLC_e>o5;mB]a>gD[MC]e:g7KCM]9fdg;BM]<00P0=0dkL00I>gDkLD_a>o5;mC]`2
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m009Bo0<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m009Bo1Eoo`03001oogoo02Aoo`00:7oo00<007ooOol047oo00<007ooOol08Goo00A:
g4kmB]a>g@=oo`0NHi1J=EYFFSDnO3YK?Wa>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;m?Ya2_CjM
@[ebdWKcL]9flg;B0P0=04M>gD[LC]e:g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00<0001MD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01=oo`8002Io
o`009goo00<007ooOol04Woo00<007ooOol077oo00U>oDkLC]e>g4kmB]a>gD[MC]d00Woo00=JEEYF
FSD00UYE00XnG3iK?Ua>g4kmC]a>o4kLD_e>g09>o00=D_e>g4kmC]a>oCjM@[efdWKCL]9fdgKBM]<0
0`0=00IBoDkLC_a>g5;mC_`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoE;lD_`00`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Aoo`03001oogoo02=oo`009goo
0`004goo00<007ooOol067oo06m>gDZlC]e:_4kmC]a>oDkLC]e:g4kmB]a>gEXeFUIJ=EYFFSEST5m_
C]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLM_=bdWKcL]9flg;BA[a6W4JlAYaBoDkL
D_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d00`0006ABoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo029oo`009goo00<007ooOol057oo
00<007ooOol05goo00=Fid[MB[`00T[L00E>oDkLC]e>g4KM00=6_@0:FUIJ=EYEFUEJEUn?Hhm:g4[M
B[`2B]`05E;mC]a>o4klD_e>g4kmC_aBoD[LC]e:gDkMB]afdgKBM]=bdWKC00e6_003AY`01E;mC]a>
o4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo080009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol08Woo000EOol40004Ool40006Ool0
0`00Oomoo`0EOol00`00Oomoo`0EOol0Je;6E^M:_4kMB[a>gDZlC_e:g4kmC]a6gDJlA]e6_5YFFSEJ
EUm_HhmOKf>@C]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4kML]9flg;BM]=bdP0=AYa6
_4JLA[a6W5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
0`0006YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo025oo`0057oo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo01Ioo`8001Eoo`=Fi`0:C]a>
gDkLC]e>g4kmC]a>gDkLA]d2A[d00eYEFUIJ=@02FUD01CiL?U/nG4kLC]d00TkL00=>o5;mC]`00Tkl
015BoDkLC_e>o4kMB]a>gD[MC]ebdWKCL]=fdg;B00e>g4kM00=>g005D_e>g5;lC_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoGooOol04goo00<007ooOol087oo000IOol01000Oomoo`0017oo00<007ooOol0
0goo0P006Goo00<007ooOol04Goo02mfAdfb@Y`nNd:LB]a>gD[LC_e:g4kMB]a>oD[LA]e6_5YFFSES
SeXeFUHjFcil>U]>oDkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkL@[dnW4:m?Yefdg;BM_=bdWKC0080
3@0eB]a>gD[LC]e:g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0030000LU;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03001oogoo021oo`00
37oo1P001goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo00Aoo`07
B]a>gD[LC]e:g4[MMRL017oo00=f9dfbCK<00T9l00dnO49l@Wa>oDkLC]e>g4kMB]a>gD[M0356_@02
FUD02UYFFSEJECiK?U`nFdklC]a>oDkL0Tkl011BoDkLC_a>o4kmC]a>oDkL@[dnWGKCL]=fdg;BM]=b
d`<03@07C]aBoDkLC_a>g5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`300000e;lD_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001B
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo
01moo`005Goo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol06goo00h005ifHYLb
6cHk<Q/f>d[LC]e:g4kMB]a>gGHV0Woo069fAgHVCK=9/TfcB[a>gDZlC]e:_4kmC]a>oD[LC]e:g4km
B]aJEUXeFUIJ=EYFGfiSSdZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mC]a>oG;BM_=bdWKC
L]9fldJLA[a6W4JlC]aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0`0007UBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomo
o`0OOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`8001eoo`04GYINMUjG
=Q/2=S/01TkMB]a>gD[LC]e:g0Ef9`0>CK9=/dfbE^I:g4[MB[a:g4kLC_e>g4kMA[e6g@96_@03FUEJ
EUXe009JE@0:GhmOKd[LB]a:gDZlB]a>o5;mC]`2C_`04E;mC]a>oDklC]e:g4kMB]e>gG;BM]=bdgKC
L]803DJLA[`00TJL00I>g5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0`0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomo
o`0NOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01]oo`1/
HYMNMV:GGWHf>c8K=S/b6dkMB]a>oD[LC]ef9WI7MRIfAdVbCK==/UKWD/I>gDZlC]e:_4kMC]a>oD[L
C_e6_4KMA[a6gEXeFUIJ=F>?GfmSSem^C_e>g4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[L
M]=bdWKcL]9fd`0=A[a6W4JlAYa6_4kLD_e>g5;mC_aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l0`00085Bo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
57oo00<007ooOol07Goo000EOol50003Ool40005Ool00`00Oomoo`0JOol025jFGWINUeifGYINMTZm
A[`2B[`014kMB]a>gD[L17HW019=/dfbCK=FaUKWD/I>gDkLC]e>g4kMC]a>oDkLC]e>g4KMA[d2FUD0
1UYFFSEJECiK?U`nF`9>g006C]e>g4klC_aBoDkL0Tkl00iBoDkLC_e>o4kMB]a>gD[MM]=bdWKCL]=f
d`0=0TkL00I>gDkLC]a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`015;mD_aBo5;l0`0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;m
D_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00COol2000O
Ool002Ioo`03001oogoo01Ioo`17@[a6gDJlA]eNMV:GGWIRUeifImASe4[MA[a:gDJlB]e:g4kmB]af
AgHVMTM=/TfcBK9=/cil@Y`nNdkmB]a>gD[LC_e:g4kMB]a>oD[LA]eJ=EYFGfmJEUXe?W`jFcil>U]>
oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkL@[dnW4:mL]9fdg;BM_=bdP0200d08dkMB]a>gD[LC]e>
g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_d0
0P0008QBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03001oogoo01aoo`009Goo00<0
07oo000047oo00=R]V:g:MX00RWJ00=:gD[LB]d014Jm00ENMUjFGWIWe6?D009We007C]e:g4kMB]a>
gD[LB]d00WHW00E=/TfcCK9=/dfb00=2O00=?Wa2O4kLC_e>g4kMB]e>gD[LC]d0<DKMFSD00UYE00YJ
EUXe?U`nFciL?U]>o4kLC_e>g09>o00?D_e>g4klC]a>oDkLC_e>g4:mL]9fdg;CM]=bdWKC00<03@08
C_a>g5;mC]a>o5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00<00005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol0
1goo1@003goo000UOol2000@Ool00f:FI[MRUP03:MX0J4ZlC]e:_4[MB[a6gDJlHYMNMV:GGWIRUc8K
=S/f6dkMB]a>gD[LB]e:g7I7MRI=/dVbCK==/TfcBK9>gDZlC]e:_4kMC]a>oDkLC_e:g4kMB]a>oEXe
FUIJ=EYFFSEOSem^C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkLM]=bdWKcL]9fdg;B
A[a6W4JlAYaBoDkLD_e>g5;mC_aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_d30000SU;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007oo
Ool01goo00D007ooOomoo`0000moo`009Goo00<007ooOol03Woo00ER]V:gH[MV]f:f00<YfP05B]a:
gD[MB]e:g002A[d01UjGGWINUUif=S/f6`8f>`05C]e:g4kMB]a2_@02MRL01dfbCK==/TfcCK9=/`00
009:g00:B]e:_4kMC]a>oDkLC]e6_DKMA[d2FUD01UYFFSEJEEm_Ghm:_09:g00FB]e:_4klC_aBoDkL
C_e>o5;mC]a>oD[MC]e:g4kMB]efdg;BM]=bdgKC00d2AY`01TJlC]a>o4kLD_e>g09Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00000005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol01goo00<007ooOol047oo000UOol0
0`00Oomoo`0=Ool096:FI[MRUVJgHYIV]dJLB[e6_4ZmB[a>gD[LB]d1F@5jGWIRUeifHYMNMSHk<Q/f
>cHKC]e:g4kmB]a2_D:LCK==/TfcBK9=/`<00013C]e:_4kMB[a>oDkLC_e:g4kmA[a6gDJlFUIJ=EYF
GfiOSem^Ghm>g4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC_ebdWKCL]9flg;B00i6W4Jl
AYa6_4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_d00`0009IBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomo
o`07Ool00`00Oomoo`0?Ool002Eoo`8000]oo`08A[e6gDJmA[eR]fJgH[IR]`9Oe@=6_003A[e6_4[M
009:g@09GWINUUifGYMNMUjFB[a:_DJl009:_00:C]e:g4kMB]a2_DfbCK==/TfcCK84000034kMC]a>
gDkLC]e>g4kmC]a>gDJmA]eJ=@9JE@05FUIJ=CiK?U/nG003C]`01TkMC]a>o4klD_e>g09>o00=D_e>
g4kmB]e>gD[LC]ebdgKCL]9fdg;C00d00dkL00I>gDkLD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l
00EBo@00000005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@0DOol00`00Oomoo`08Ool00`00Oomoo`0>Ool002Eoo`03001oogoo00Eo
o`0>Ik9[ddJlB[e6_4[MA[a6gDJlI[MRUVJgHYIV]`8YfP1L:KU>gDZlB]e:_4KMA[aRUeifHYMNMV:G
Hk=We4JlB]e6_4[MA[a:gD[LC]e2_DfcBK9=/dfbCK==/T:L?Wa2W3ikC_e:g4kMB]a>oD[LC]e:g4km
A[aJEUXeGhmJ=EYF>U/nO3iK?W`jFe;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;m?Ye2_CjLM_=bdWKC
L]9fl`0=00i:g4kMB]a>gD[LD_e>g5;mC]aBoE;lD_e>g5;mD_aBo@<0002MD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
57oo00<007ooOol027oo00<007ooOol03Goo000UOol00`00Oomoo`05Ool01V_CJk9[ddJlB[e6_096
_@07A]e6_F:g7QaV]f:fH[L00bWJ00=:gD[LB]d00dJm01INUeifGYISe6ODHmAWe6?DC]e:g4kMB]a:
gD[L@[e=/TfcCK9=/dfbCK==/P=2O00=?Wa>gDkLC_e>g4kMB]e>gD[L0356_EYFFSD00UYE00YJETZl
B]a:g4[MB[a>o4kLC_e>g09>o00>D_e>g4kmC]a>oDkLC_e2_GKCL]9fdg;CM]=bdP<03@05C]a>o4kL
D_e>g002D_`01E;mC_aBo5;lD_d00`0000EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`03Ool0
1@00Oomoogoo00003goo000TOol00`00Oomoo`05Ool046_CJk9[dfNbJm=:_4[MA[a:gAhL7QdN76Jg
HYIV]f:F0bWJ05A:_4kMB[a:gD:lA]eNMV:GGWIRUeif=S/b6cHk=Q]>gD[LC]e:g4[M@Ya=/dfbCK=9
/TfcCK9=/dfbC]e:_4kMB[a>oDkLC_e>g4kmB]a>gD[LFUIJ=EYFFSEJEU]^Ghm:_4kMB[a>gDkLD_e>
g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_ebdWKCL]9flg;BM]=6W4JlAYa6_4kLD_e>g5;mC]aBoDklD_d3
0000Y5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`04Ool3000@Ool002Aoo`<0
00Eoo`06Jk9JEUYE>U`fFcYL0T[M00E:_4[M7Q`N7F:f009R]`03I[MR]RWJ008YfP04B]a:gD[MB]d2
A[d035if0GYNMUjFGWHf>cHK=S]:g4kMB]a>g@92_@09CK9=/dfbCK==/TfcCK9=/`00009:g00:B]e:
_4[LC]a>oDkLC]e6_DKMFSD2FUD01UYFFSEOKUm^Gfm:_09:g00EB]e>g4klC_aBoDkLC_e>o5;mC]a>
gD[MC]e:g4kML]=fdg;BM]=bd`0>00=6W006A[a>g5;lC_aBoDkL0P0000EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00Ool05goo000TOol01@00A[a:gDJlB]d0
0Woo02Q[/UYFFSEJESHk>U`f>cYLB[a:gDJlB]eRUVJgHYIV]f:FGmEK]4ZmA[a:_DZlC]e:g4[M0ET1
NUifHYMNMV:GGWHf>c8K=S]:g4kMB]a>o@92_@06BK9=/dfbCK==/Tfc0`00031>oD[LC]e:g4kmC]a>
oD[LA]e6_4KMFSEJEUXeGhmKKUn?FfiOSdkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kMB]af
lg;BM]=bdWKcL]803T[LC]e:g4kMC]`30000ZdkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo00DOol00`00Oomoo`0EOol001Yoo`@000Ioo`0?001oodJlB]e6_D@P@21JEUYEFUIJ
EEYFA[a:_DJl0096_@06A]e6_DJmH[MV]f:f0eoE0dJl00=6_D[LB]d00T[M00ENMUjFGWINUeif009S
e00>B[e6_4ZlB]a>gD[LC]e2_DfcCK9=/dfbCK==/P=2O009?Wa>gDkLC]e>g4kMC]a>oDkL0096_@05
FUIJ=EYEFUEJEP03?U/01SiLC]a>g4kLC]e>g09>o00BD_e>g4kmC_aBoDkLC_e:gDkMB]afdg;CM]=b
dgKC00d03TkL0`0000A>g5;lC_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00AB
oE;lD_aBo1=oo`03001oogoo01Eoo`006Goo00<007ooOol00Woo00<007ooOol00goo01T007ooOom2
W4Jm@[eJEUXeFUIJ=EYFIk9[ddJlB[e6_4[MA[a6gDJlI[MRUVJgHYIV]`02:MX0BDZlC]e:_4[M@[a6
gDJlA]eNMV:GGWIWe6>cImA6_4[MA[a:gD[LB]e:g4JmCK9=/dfbCK==/TfcCK92W3il@Y`nNdkmB]a>
gD[LC_e:g4kMB]a6gEXeFUIKKUYFFSEJESYK?W`nFcilC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aB
oCjM@[ebdWKcL]9fdg;B00<0002cB]a>gD[LC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Oomoo`0DOol001Uoo`03001oogoo009oo`03001oogoo
00=oo`80009oo`=2_@05FUIJEEYFFUE[dP02Jk800dJlB[e6_002A[d00dKMA[eR]`02H[L026:f:MXY
fRWJB]a:gD[LB]d3A[d02ejGGWINUV?DImASdf?DB]a>gD[LC]d00T[M00E2_DfcCK9=/dfb00==/`0A
?Wa2O49l@W`nO4kMC]a>oDkLC]e:gDkMB]a6_EYEFUIJ=@02FUD02UYFB[a:g4[LB]e>g4klC]a>oDkL
0Tkl00YBoDkLC_e>g4kmC]a2_G;CM]=bd`<000<03@06D_e>g4klC]aBoDkl0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol04goo000IOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool05D:LA[eJ=EYFFSEJEUXe>U`f>cYLB[a:gDJlB]dN
71hMHYIV]f:FI[MRUP03:MX0@DZlC]e:_4[M@[a6gDJlHYMS/f:GGWHf>c8K=S]:g4kMB]a>gD[LB]e9
/TfcCK9=/dfbCM==/TfcB[a>gDZlC]e:_4kmC]a>oDkLC_e:g4kMB]aJEUXeFUIJ=EYFFfiOKTZlC]e:
_5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]`00`000;YbdWKcL]803TJLA[a6W5;mC]aBoDkLD_e>
g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001B
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dCOol00`00Oomoo`0C
Ool001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`0:@[eJEUYEJm9JEEYFFUDj
G3IK>U`2B]d01DZlB]eR]f:gH[H00f:g12WJ00Y:g4[MB]e:g@5I0GYNMUjGGWINUP8f>`0==Q/f>cHk
C]e:g4kMB]a=/d:mCK==/TfcCK800Tfc00X004ZlB]a:g4[MB[a>gDkLC_e>g096_@0:A]eJ=EYEFUEJ
EUXeGfiKKT[MB[`2B]`02U;mC]a>o4klD_e>g4kmC_aBoD[L0`0000A:g7KCL]=fd`9bd`0300e6_4JL
0096W005D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
D_aoo`0COol00`00Oomoo`0BOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eo
o`0Z@YaJEUXeFUIJ=EYF=S/jG3Hk>Ua6_4KMA[a6gF:FI[MRUVJgFkAOeDJLB[e6_4ZmB[a>gD[LB]eN
MV:GGWIRUeifHYM6_4[MA[a:gDJlC]e:g4km0T:m00E=/TfcCK9=/dfb00<0000MB]a>oD[LC]e:g4km
C]a>oD[LA]e6_4KMFSEJEUXeGfiKKUn?Ffi>oDkLC_e>g5;mC]aBoDkLD_e>g0030000`D[LC_e:g4kM
L]9flg;BM]=bdWKc00e>gD[LC]e:g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo015oo`006Goo00<007ooOol00Woo00<007ooOol0
0Woo0P001goo00UJEEYFFUEJEUYEFUI6_4ZmA[`00TJm00=6gDJmA[d00V:g00AR]UoEFmAOe@=6_0A6
_@0BGYMNMUjFGWINUf>cHm=:_4ZmA[a:_4[LC]e:g4kM@[e=/dfb0dfc00e=/T9l@Wa2O4kLC]e>g4kM
C]a>gDkLC_e>g002A[d01EYFFSEJEEYE?U`00ciK00I>gDkLC]a>g5;mC]`3000024kLC_e>o5;mC]a>
gD[MC]d3L]<01GKCL]<03P0=C]d00dkL00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo003D_eBo7oo019oo`03001oogoo015oo`006Woo10001Goo00<007ooOol0
1Woo01=JEUXeFUIJ=EYFIk9[ddJlB[e6_4[MA[a6gDJlI[MRUUoEHYIV]`02:MX0=TZlC]e:_4[M@[a6
gDJlHYMNMV:GHk=Se6>cImA6_4[MA[a:gD[LB]e:g4JmCK9=/dfbCM==/Tfc?W]2W3ik@Y`nNdkmC]a>
oDkLC_e:g4kMB]a6gEXeFUIJ=EYFFSDnO3YK?W`nFe;mC]aBo@800038C]aBoDkLD_e>g5;mC]a>oDkL
@[dnWGKCL]9flg;BM]<03@0>00eBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoA9oo`<0019oo`001Goo0P0000=oo`0000006Goo00<007ooOol0
1goo00MJEUYEFUIJEF_BIk9[/P02B]d014ZlB]e:gAhM0QhL0V:g00QR]RWJ:MXYfT[LB]e:g4[M0TJm
00aNMUjGGWINUUif=S/f6cHkB]a>gD[LC]d2B]d01D:mCK==/dfcCK800dfc015:_4[LB]a:gDZlC]e>
g4kmB]a>gD[MC]e:g4JmFUEJEUXe009JE@03B]e:_4[L00<0000<C_a>g4kmC]a>oDklD_e>g4kmC]a>
oCjM0W;C00Efdg;CL]=bddJl00=6W006D_e>g4klC]aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0COol00`00Oomoo`0@Ool000Aoo`03001oogoo0080
01Yoo`03001oogoo00Moo`03FSEJEUXe009oo`0>>U`f>cYLB[a:gDJlB]dN71hMHYIV]f:FI[MRUP<Y
fP0^B[a>gD[LB]e2_4KMGWH1NUifHYMNMSHk<Q/f>d[LC]e:g4kMB]a:gDfbCM==/TfcCK9=ddfb001:
_4kMB[a>gDkLC_e>g4kmA[a6gDJlA]eJ=EYFFSEJEUXeGfh30000cdkMB[aBoDkLD_e>g5;mC]aBoDkL
D_e>g5;mC]a>oG;BM_=bdWKCL]9fd`0=A[a6W4JlC]aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkl
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol00`00Oomoo`0?Ool000Aoo`05001o
ogooOol0000IOol30008Ool00eYFFUE[dP03Ool00cYL=U/jG002B]d01DZlB]eR]f:gH[H00f:g0dJl
00=6_D[LB]d00T[M00H1F@5jGWINUeifGYH2=S/01SHK=S]:g4kMB]a>g@92_@05CK9=/dfcCK==/P03
000024ZlB]a:g4[MC]a>gDkLC_d3A[d00dKMFSEJE@030002Ffh01TkMC]a>g4kLD_e>g09>o009D_e>
g4kmC_aBoD[LC]e:gDkM00=bd`05M]=bd`0>AYa6_002AY`01TklD_e>g5;lC_aBo@=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0COol00`00Oomoo`0>Ool000Ao
o`05001oogooOol0000IOol00`00Oomoo`09Ool00eYFOomoo`03Ool0:CYL=S/jG4JlA]e6_4KMHYIV
]f:FI[MK]5oDAYa:_DJlB[e:_4kMB]a:gEifHYMNMV:GGWIRUdJlB]e6_4[MB]a>gD[LC_e2_DfcCK9=
ddfbCK<0100000Y:g4kmB]a>gD[LC_e>g4kmB]a6g@<0003FFUIJ=EYF>U/nO3iKC_e>g4kmC]a>oDkL
D_e>g5;mC]aBoDkLD_e:g4kmB]a>gG;BM]=bdWKC00d03T[LC]e:g4kMC]aBoDkLD_e>g5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`COol00`00Oomoo`0>Ool0
00Aoo`05001oogooOol0000IOol00`00Oomoo`0@Ool01TZmA[a6_DJmA]e6_@=R]`04H[IR]bWJ:MX3
A[`4A[d03ejGGWINUUifGYMS/f?CB[a:_DJlB[a:g4kMB]a2_@02CK<01DfbCK==/`00CK800d9l00I>
g4kMC]a>gD[LC]d3000014JmFUEJEU]^0UYE00XnG3iK?U/nFdkmC]a>o4kLC_e>g09>o006D_e>g4km
C_aBoCjM0T:m00Ufdg;CL]=bd`0>00d03TkLC]d00TkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo00eoo`00
0goo0P000Woo0P006Goo00<007ooOol047oo00a6_4ZmA[a:gDJlA]e6_6Jg6QaV]f:F;MX2:MX08TZl
C]e:_4[M@[a6gDJlHYMNMV:GHk=Se5ncHmA:g4kMB]a>gD[LB]e2_4gCCK9=/dfbCM==/TgC?W]2W3ik
@Ya>g4km0`000=i>oD[LC]d044KMFSEJEUXeFUIJ=DkMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g4kmC]aB
oDkLC_dnW7KCL]9fdg;BM]<03@0>00d03TkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`COol00`00Oomoo`0<Ool0029oo`80019o
o`9:g@05B[a:gAhL7QdN7003H[L026:f:MXYfRWJB]a:gD[LB]d2A[d03eifGYMNMUjFGWHf>cHK=S]:
g4kMB]a>gD[M@[e=/P03CK<01P00CK==/dfcB[a:g0<00008C]e>g4kmC]a>gD[MC]eJ=@9JE@0EFUIJ
=E]^Ffe:gDZlB]a>g4kmC]a>o4kLD_e>g4kmC_a>oDkLC_e>g4km00=bd`05M]=bdg;CAYa6_002AY`0
1TkLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`BOol00`00Oomoo`0<Ool0029oo`03001oogoo019oo`0<B[a:gDJlB]dJ71hM
HYIV]f:FI[LYfBgJ0RWJ01Y:_4kMB]a:gD:lA]eNMV:GGWIRUcHK=S/b6cHkB]a>gD[LC]e2_DfcCK9=
ddfb001=/U7C0`000>E>gDZlC]e:g4kmC]a>oD[LA]e6_5YFFSEJEUXeFUIKCE]^B[a>gDZlC]e>g5;m
C]aBoDkLD_e>g5;mC]a>gD[LC_e:g4kML]9fdg;BM]=bdP0>AYa6_4JLA[a>g5;mC]aBoDklD_e>g5;m
C_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol00`00
Oomoo`0;Ool0025oo`03001oogoo01Aoo`9:g@08B[a:gF:gH[MR]V:gFkAKe0=6_00CA[e:g4[MB]d1
NP5IGYINMUjGGWINUTZlB[e6_4ZlB]a>gD[LC]d00T:m00==/TfcCK<01@0000Q>g4kMC]a>gDkLC]e>
g4km0dJm00UJEUXeFUEKKE]^FfeKKTkLC]d00TkL00=>o5;mC]`00Tkl00UBoDkLC_e>o4kMB]a>gD[M
M]<00g;C00Efd`0>00i>g4kM009>g006C_aBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00BOol2000<Ool0025oo`03001oo`0001Eoo`0Q
A[a6gDJlA]eRUVJgHYIOe5^dFmA6W4ZmA[a:_DZlC]e:g6:GGWIRUeifHYMO/f?CA[a:gDJlB]e:g4kM
B]a>oD:m00<0003[CK9=ddfb@Y`nNd:LB]a>oD[LC]e:g4kmC]a>oDJlA]eJ=EYFFSEJEUXe?W`jFcil
C]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g7KCL]9fdg;B00h03@0>B]a>gD[LC]e>g5;m
C]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`04goo00<007ooOol02Woo000QOol2000HOol01dKMA[eR]f:gFmARUV:g008YfP04B]a:gD[LB]d3
A[d01UjGGWINUV>cHm=S/`9:_004B[e6_4ZlB]d300000dfc001=/P03CK<03Cil@Wa2O49lC]a>gDkL
C_e>g4kMB]e>gDJm009JE@05FfiJ=EYE?U/nG002?U/01dkLC_e>g4klC]aBoDkL009>o009C_e>g4km
C]a>oCjM@[ebdgKC009bd`@03P07C]aBoDkLC_aBo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo015oo`8000]oo`003goo100017oo
10001Woo00<007ooOol067oo00LN7AXL7QeRUVJgHYH]fP02:MX03dZlC]e:_4[M@[a6gEifHYMNMV:G
GWHf>cHJC]e:g0030000ld[LB]e2_4gCCK9=ddfbDM==/TgCB[a>gDZlC]e>g4kmC]a>oD[LC_e:g4kM
A[aJEUXeFUIJ=EYFB[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4:mL]9fdg;BM]=bdTZl
AYa6_4JLB[a>g5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo00>Ool300000goo001oo`0:Ool000ioo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00ahL7QeRUP03H[L01F:F:MXYfRWJB]`0
0d[M0TJm00ENMP5jGWINUUif00<00007B]a>gD[LC]e:gD:mCK801Tfc00T004ZlB]a:g4[MC]a>gDkL
C_d00dJm00iJEUXeFUEJEEYFFdeKKD[LB]e:_4[LC_aBoDkL0Tkl00UBoDkLC_e>o4kmC]a>oDkLM]<0
1G;C0TJL00I6_4JLC_a>g5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0:Ool40004Ool00`00Oomoo`09Ool001=oo`04001o
ogoo0004Ool00`00Oomoo`03Ool2000JOol04F:FI[MRUVJgHYIV]dJLB[e6_4ZmB[a>gD[LB]d1F@5j
GWH00`0000mNMSHk=QXf>d[LC]e:g4km@[e=/dfbDM==/TgCCK800`000>Q:_4kMB[a>gD[LC_e>g4km
A[a6gDJlFUIJ=EYFFSEKKUM=Ffi>g4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[LM]=bdWKC
L]=fd`0=B[a6W4JlAYaBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@Ioo`<000Qoo`03001oogoo00Uoo`004goo00@007oo
Ool000Aoo`03001oogoo009oo`8001aoo`9R]`04HYIR]e^dFk@3A[`014JmA[a:gD[M0`0000mNMUjG
GWIS/encB[e6_4ZlB]a>gD[LC]e2_DfcCK800dfc00`nO49l@Wa2O4kLC]e>g4kMC]a>gDkLC_d2A[d0
0eYEFUIJ=@02FUD01CiL?U/nFdkLC]d00dkL00aBoDkLC_a>o5;mC]a>oD[MC]e:g4kMB]d4L]<200h2
C]`01TkMC]aBo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00ABoE;lD_aBo0=oo`<000aoo`03001oogoo00Qoo`003goo10000goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol06goo00=V]f:FI[L00Woo0RWJ00=:_4kMB[`00`000416
_4KMGWIRUeifHm=O/V?CA[a:gDJlB]e:g4[MB]a6_DfbCM==/U7CCK9=dcik@Y`nNd:LB]a>oD[LC]e:
g4kmB]a>gDJlFUIJ=E]^FSEJESiK?W`jFcilC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;m?Ye2_CjL@[eb
dgKCL]9fd`803P2o00e>gD[LC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo002000?Ool00`00Oomoo`08Ool000moo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01aoo`03H[Moogoo009oo`06
:MX00000001:g4[M0dJm00]NUeifGYINMUjG=Q/f>d[LC]e:g4kM009:g@03@[e=/dfc00A=/`03CM<n
O49l0092O009C]a>gDkLC_e:g4kMB]d044Jm009JE@0CFUIJ=EYEB]a:gDZlB]a>g4kmC]a>o4kLD_e>
g4kmC_a>oDkLC_d00T:m1G;C100>00A>o4kLD_e>g09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l47oo00<007ooOol027oo000?
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0POol20002:MX0obWI
C]e:_4[M@[a6gDJlHYMNMV:GGWHf>cHJ=S]:g4kMB]a>gD[L@[e=/U7CCK9=ddfbDM==/P00B[a>gDZl
C]e>g4kmC]a>oD[LC_e:g5YFFSEJEUXeFUIGCE]]B[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL
D_e>g7KCL]9fdg;CM]=bdTZlAYa6_4JLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00025;mD_aBoE;lD_eBo5;mD_`?Ool00`00Oomoo`08
Ool000moo`D000=oo`@000Eoo`8001ioo`<0009oo`96_003A[e6_4[M009:g@81F@0=GWINUeifGYIN
MSHk=Q/f>d[LC]e:g4kM@[d014fc00==ddfc00000P0000Q:_4[LB]a:gDkLC]e>g4km0TJm00=JEEYF
FSD00UYE00EKKEM=Fde>g4kM009>g003C_aBoDkL009>o008D_e>g4kmB]e>gD[LC]e:g@Ebd`=6W006
A[a6W5;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@02D_`?Ool00`00Oomoo`08Ool0021oo`03001oogoo01Yoo`<000Io
o`0KB[e6_4ZmB[a>gD[LB]eNMV:GGWINUeifHYM6_4[MA[a:gD[LC]e:g4km@[e=ddfbDM==/TgC00@0
003ZB]a>oD[LC]e:g4kmC]a>oDJlA]eJ=EYFFSEJEUXe?W`jFcilC]a>oDkLC_e>g5;mC]aBoDkLD_e>
g5;mB]a>gD[LC_ebdgKCL]9fdg;C00i:g4kMB]a>gD[LD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m3Woo00<007oo
Ool027oo000POol00`00Oomoo`0GOol3000:Ool2A[`4A[d03ejGGWINUUifGYMO/UncB[a:_DJlB[a:
g4kMB]a2_@05CK<00dgC@Wa2O002@W`02DkLC]e>g4kMB]a>gD[MC]e6_@02FUD01U]]FSEJECiK?U`n
F`9>g006C]e>g4kLC_aBoDkL0Tkl00MBoDkLC_e:gDkMB]a>g@04L]<200h3C]`01TkMC]aBo5;lD_e>
o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aBo00=Ool00`00Oomoo`08Ool001moo`03001oogoo01Eoo`<000ioo`14C]e:
_4[M@[a6gDJlGYMNMV:GGk9S/enbHm=:g4kMB]a>gD[LB]e2_57CCK9=ddfbDM==/TgC?W]2W3ik@Ya>
g4kmC]a>oD[LC_e:g00@A[aJEUXeFUIJ=EYF?U/nO3YKD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_dn
WD:mL]9fdg;CM]=bdP<03P32C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@eoo`03001oogoo00Mo
o`007goo0P004goo0`004Goo00A:g4[MB]a:g@96_@03GWINUeif009NMP09=S/f6cHkB]a>gD[LC]e:
gD:m00==/`06CM==/dfcCK==ddZl0T[L00Y:gDkLC]e>g4kmB]a>gD[MFUIJ=@9JE@0:FUIGCEM=B]a:
gDZlC_a>g4kmC]`2C_`025;mC]a>oDkLC_e>g4kmC]`6L]<2AY`01TJlC]a>o4kLD_e>g09Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00=BoE;lOol037oo00<007ooOol01goo000OOol00`00Oomoo`0?Ool3000EOol0odZlC]e:g4[M
@[a6gEifGYMNMV:G=Q/f>cHJ=S]:g4kMB]a>gD:mCM==/U7CCK9=ddfbDM==/P00B[a>gDZlC]e:g4km
C]a>oDJlA]eJ=EYFFSEJEUXeFdeGC4kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC_e:g7KC
L]9fdg;CM]=6W4ZlAYa6_4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo0002U;mD_aBoE;lD_eBo5;mD_aBoE;l37oo00<007ooOol01goo
000OOol00`00Oomoo`0<Ool3000IOol01D[LB]e:gD[MB]`00Uif00]NUeifGWI:_4ZmA[a:_4[LC]e:
g4kM0092_@==/`03CM==/`0000800008C]a>gDkLC]e>g4kMC]a>o@96_@03FUEJEUXe009JE@06?U`n
FdkLC]a>gDkL0Tkl00]BoDkLC_a>o5;mC]a>oD[MC]e:g4kM00Ebd`0:00i>g4kLC]a>gDkLD_a>o5;m
C]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eBo7oo00Yoo`03001oogoo00Moo`007goo00<007ooOol02Goo0`007Goo
0492_4KMA[a6gEifHYMNMUjGGk9S/dJlB]e6_4[MB]a>gD[LC_e2_DgCCK9AddfbCM==/T:L?W]2W4[L
C_e:g4kMB]a>oD[LC]e6_5YFFSEJEUXeFUHnFcil>U]>oDkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoD[L
C]e:g4kmL]=fdg;BM]<200h0aD[LC]e:g4kMB]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`02Woo00<0
07ooOol01goo000OOol20008Ool2000QOol4A[d3GWH4Gk800dZmA[a:_002B]d014[L@[e=/dgC0dfc
00==dd9l@W`00T9l00U>g4kMC]a>oD[LC]e:gDkMFSD00UYE00YJEUXeFUDnFciL?U]>o4kLC_e>g09>
o008D_e>g4klC]a>oDkLC_dn_@Ibd`<03P05C]a>o4kLD_e>g002D_`01E;mC_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oGooOol027oo00<007ooOol01goo000NOol00`00Oomoo`05Ool3000UOol0?DKMA[aNUeifHYMNMSHk
=QXf>cHKC]e:g4kMB]a:gD:lDM==/TgCCK9AddfcDM=:_4kMB[a>gDkLC_e>g4kmB]a>oD[LA]eJ=EYF
FSEJEUM<Ede:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoG;CM]=bdWKC009bd`3800i:_4JL
A[a>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@Yoo`03001oogoo00Ioo`007Woo00<007oo
Ool00Woo0`00:Goo0TJm00INUeifGWINMSHk=Q/2=S/00dkMB]a>g@02@[d3CK<01TgCCK==/dfc001:
_09:g005B]e>g4kMC]a>o@03A[d01UYFFSEJEEYEEdeGC09:g006B]e:_4klC_aBoDkL0Tkl00MBoDkL
C_e:gDkMB]a>g@05L]<02P0>AYa6W4JLA[a>g5;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo0Yo
o`03001oogoo00Ioo`007Woo00<007oo00000P00;Goo01ARUeifGYMNMV:GGWI:gDJlB]e6_4kMB]a>
oD:mCM==/U7CCK9Addfb0`00029:g4kmB]a>gD[LC_e>g4KMA[a6gEXeFUIJ=EM=EdaGCEM<C_e>g4km
C]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]afd`=bd`3:M]=bd`0>B]a>gD[LC]e>g5;mC]aBoDkLD_eB
o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`9Ool00`00Oomoo`06Ool001ioo`<002moo`=NMP0=GYMNMUnbGk9:_DJl
B[a:g4kMB]a>gD:mCM<00dfc00==ddfc@W`00T9l00Q>g4kMC]a>gDkLC]e>g4KM0TJm00MJEEYFFSEJ
ECiK?U`nF`02C]`01TkMC]a>g4klD_e>g09>o006D_e>g4kmB]e>gD[L1G;C0P0>0dkL00I>gDklD_aB
o5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l27oo00<007ooOol01Woo0004Ool50003Ool40004Ool4
0007Ool00`00Oomoo`0_Ool01EifHYMNMUnbFi800Unb031:gDJlB]e:g4[MB]a6_DfbCM==/U7CCK=A
dcik@Y`nNd:LC]a>oDkLC_e:g4kmB]a6gDJlFUIGC5YFFSEJESiK?W`jFe;mC]aBoDkLD_e>g5;mC]aB
oDkLC_e>g5;m?Yd2L]<01GKCL]=bdg;C00l00P0>0<M>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo007Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`05Ool2000_Ool00ejGGWINMP02Ool01SHK=S/f>dkMB]a>g@9:g@09@[e=
/dfcCM==/dgCCK==ddZl009:g00:B]e>g4kMC]a>oD[LC]e:gDKMFSD2FUD02UYFDdaGC4[LB]e:_4kl
C]a>oDkL0Tkl00MBoDkLC_e>g4kmC]a>o@06L]<3AY`01DJlC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00U;l1goo00<007ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`0017oo00<007ooOol01goo00<007ooOol0;Goo00]NUgooOomoocHk=QXf>cHKC]e:g4kM0092
_@0ZCK9AddfcDM==/U7CCK<004ZlC]e:_4kMB]a>oDkLC_e6_4KMA[eJEUXeFUIJ=EM<Dba>gDZlC]e:
_5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4km0g;C0<efdg;CL]=6W4ZlAYa6_4kLD_e>g5;mC]aBoDkl
D_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@06Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo0004Ool00`00Oomoo`08Ool00`00Oomoo`0aOol02DZmA[a:_4ZlC]e:g4kM
@[e=d`03CK<00dgCCK<00002000024kLC]e>g4kMC]a>gDkLC_d2A[d00eYEFUIJ=@03Ed`01E=<C]a>
g4kMC]`00Tkl00YBoDkLC_a>o5;mC]a>oD[MC]e:g0Ibd`0900i>g4kLC]a>gDkLD_a>o5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol01Woo00<007ooOol01Goo0006Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol02Goo00<007ooOol0<Goo03=:gDJlB]e:g4kM
B]a>oD:mDM==/U7CCK=Addfb@Y`nNd:LB]a>oD[LC]e:g4kmC]a>oDJlA]eJ=EYFFSEJESiK?W`jFdkm
C]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LM]<00W;C0<eb/gKC00h03d[LC]e:g4kMC]aBoDkL
D_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo006Ool00`00Oomoo`05Ool000Ioo`03001oogoo009o
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0:Ool2000bOol00dZmA[a:_002B]d024[L
@[e=/dgCCK==ddfcCM<4@W`05DkLC]e>g4kmB]a>gD[MC]e6_EYEEdaJEUXeFUHnFciL?U]>o4kLC_e>
g002C_`025;mC]a>o4kLC_e>g4km?[d6L]<300h01DkLC_a>g5;mC_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoE;lOol017oo00<007ooOol01Goo0004Ool30004Ool00`00Oomoo`02Ool01000
Oomoo`0017oo00<007ooOol037oo00<007ooOol0<7oo02m>gD[LC]e:g4[M@[aAddfcDM==/U7CCK=A
ddZlC]e:_4kMC]a>oDkLC_e>g4kmB]a6gEXeFUIJ=EYFFSEGC4ZlC]e:_5;mC]aBoDkLD_e>g5;mC]aB
oDkLC_e>g5;m009bd`3AL[=fdg;CL]<03TZlAYa6_4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo004Ool00`00Oomoo`05Ool000Ioo`03001oogoo00=oo`@000Aoo`@0011oo`03
001oogoo031oo`03C]e:g4kM0092_@09CK==ddfcCM==/dgCCK<004Zl009:g006B]e>g4kMC]a>oDkL
0TJm00IJEUXeFUIJEEM<Db`2B]`01T[MB[a>o4klD_e>g09>o007D_e>g4kmB]e>gD[LC]d01G;C00T0
3dJLAYa6W4JlC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol00Woo00<0
07ooOol01Goo000YOol00`00Oomoo`0`Ool02TkMB]a>oD:mDM==/U7CCK=Addfb0`00029:g4kmB]a>
gD[LC_e>g4kmB]a6gDJmFUIJ=EYFFSDnO3YKC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]af
d`9bd`3@L[=fd`0>00m:g4kMB]a>gDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d3Ool00`00Oomoo`05Ool002Yoo`03001oogoo031oo`0:C]e:g4kM@[e=ddfcCM==/dgCCK<3@W`0
4DkLC]e>g4kMB]a>gD[MC]e:g4JmFUEJEUXeFUHnFciL?U/00TkL00I>gDkLC_a>o5;mC]`2C_`01U;m
C]a>oD[MC]e:g0Abd`803P0600m>g4kLC]a>gDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`3Ool00`00Oomoo`05Ool002]oo`80035oo`0_B]e:g4JmCK=AddfbDM==/e7C?W]2W3ik@Ya>
g4kmC]a>oD[LC_e:g4kM00iJEUXeFUIJ=EYF?U/nO3YKD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_dn
WG;CL[=fd`02L]<0c`0>00l03P0?C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo003Ool00`00Oomoo`04Ool002eoo`03001oogoo02moo`0:B]e2_DgCCK==ddfcCM==/dgC
B[`2B]`05T[MC]a>gDkLC_e>g4kMB]e>gDJmFUIJEEYFFSEC;4[LB]e:_4klC]a>oDkL0Tkl00MBoDkL
C_e>g4kmC]a>o@06L]<3AY`01DJlC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004
D_eBo5;lD_`2Ool00`00Oomoo`04Ool002ioo`03001oogoo02moo`0[@[e=/U7CCK=AddfbDM==/`00
B[a>gDZlC]e:g4kmC]a>oD[LA]e6_EYFFSEJEUXeDdaC:eM<B[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;m
B]a>gD[LC_d00W;C0=Eb/g;CL]=6_4JLB[a6W4JlC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo7oo00001Woo000_Ool00`00Oomoo`0_Ool01TgC@[e=ddfcCM==/`<00009
C]a>gDkLC]e>g4kMC]a>oDkL0096_@05FUIJ=EYFFUDnG002?U/00dkLC]e>g002C_`02U;mC]a>o4kl
D_e>g4kmB]e>gD[L1G;C00<03TkMC]`00TkL00E>gDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo7oo00001Woo000`Ool2000`Ool0:T:mCK9AddfcDM==/d:L?W]2W4[LC_e:
g4kMB]a>oD[LC]e:g4KMFSEJEUXeFUHnFcil?U/nO4kLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:
g0=bd`3CL[<03`0>C]e:g4kMB]a>gDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m00001Woo000bOol00`00Oomoo`0]Ool01d:mCM==/dgCCK==ddfc00=2O00EC]a>gDkLC_e>
g4kMB]e>g@0>FUIJEEYFFSEJETZlB]e:_4[LC]a>oDkL009>o008D_e>g4klC]a>oDkLC_dn_@Ebd`09
00h03`0>D_e>g4klC]aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00=oo`03
001oogoo00Aoo`00<goo00<007ooOol0;7oo02U2_DfcDM==/U7CCK=Ad`00C]e:_4kMC]a>oDkLC_e>
g4kmB]a>gD:lFUIJ=EYFFSEC;4ZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;m009bd`3=L[=b
dg;CL]=6VdZlAYaBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`027oo00<007ooOol0
0goo000dOol00`00Oomoo`0[Ool01T:mCM==/dgCCK==d`800009B[a:g4[LB]e:_4kMC]a>oDkL0096
_@04FUIJ=EYFFUD3Db/01dkLC]e>g4kLC_aBoDkL009>o007D_e>g4kmB]e>gD[LC]d01G;C00U6_4JL
AYa6W5;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`00e;mOomoo`0:Ool00`00Oomoo`03Ool003Eoo`8002ao
o`05CK9AddfcDM==/`0300008T[LC_e:g4kMB]a>oDkLC_e:g4KMA[eJEUXeFUIJ=Cil?U/nO4kLC_e>
g4kmC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4km0W;C0<Ab/g;D00i>gD[LC]e:g5;mC]aBoDkLD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBo@moo`03001oogoo00=oo`00=goo00<007ooOol0:Goo00=2_DfcCM<00TgC01Aood9l@Wa2O4kL
C]e>g4kMC]a>gD[MC]e:g4JmFUEJEUXeFUHnFciL0SiK00=>g4kmC]`00Tkl00YBoDkLC_a>o5;mC]a>
oCjm@[dnW@Abd`803`06C]e>g4kLC]aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;l000COol00`00Oomoo`03Ool003Qoo`03001oogoo
02Qoo`05@[eAddfcDM==/`02Ool09D:L?W]2W4kLC_e>g4kmC]a>oD[LC]e:g4KMFSEJEUXeFUI:_4kM
B[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoCjML]=b/g;D009bd`2k00h03`0>D_e>g5;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00goo
00<007ooOol047oo00<007ooOol00goo000iOol00`00Oomoo`0WOol014:mCK==ddfc17oo0T[L00I:
gDZlB]a>g4kmC]`2A[d03TKMFSEJEUYEFUIJ=E<[B[a:g4ZlB]a>o5;mC]`2C_`01e;mC]a>oDklC_e>
g4km00Ibd`=6W005A[a>g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_aBo008Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003Yoo`8002Qoo`03DM==/e7C00Eo
o`0QC_e:g4kMB]a>oDkLC_e:g4KMA[e6gEXeFUIJ=E<[C`YC:dkLC_e>g4kmC]aBoDkLD_e>g5;mC]aB
oDkLC]e:g4km009bd`2fL[=be7;C00m:g4kMB]a>gDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@]oo`03001oogoo00moo`03001oogoo00=oo`00?7oo00<007ooOol0
9Woo0TgC1Woo00Q>gDkLC]e>g4kMC]a>oDkL0TJm00EJEUXeFUIJECiL008nF`07C]a>gDkLC]a>o5;m
C]`00Tkl00MBoDkLC_e:gDkMB]a>g@04L]<200l3C]`01DkMC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool003eoo`03001oogoo02Eo
o`03CK=oogoo00Moo`0PC]a>oDkLC_e:g4kMB]a6gEXeFUIJ=EYFFSDnO3iK?Wa>g5;mC]aBoDkLD_e>
g5;mC]a>oDkLD_dnWG;CL[=be09bd`2]L[<03`0>00m>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo00DOol00`00Oomoo`0>Ool00`00Oomoo`02Ool003ioo`03001oogoo02Aoo`03CM=o
ogoo00Qoo`0CC]a>oDkLC]e:gDkMB]a6_EYEFUIJ=EYFCb]:g4ZlB]a>g4kmC]`00Tkl00MBoDkLC_e>
g4kmC]a>o@06L]<0200?AYa6W4JlC]a>o4kLD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Uoo`03001oogoo
00eoo`03001oogoo009oo`00?goo00<007ooOol08goo00==/gooOol02Goo01a>g4kmB]a>oDJmA]eJ
=EYFFSEJETl:Db]?2TkMB[a>gDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>o@9bd`2XL[=be7:c00m6VdZl
AYa6_4kLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m77oo00<007ooOol03Goo00<007ooOol00Woo0010Ool2000S
Ool00dgCOomoo`0:Ool02TkLC_e>g4kMA[e6gEXeFUIJEEYF0ciK00I>gDkLC]a>o5;mC]`2C_`01U;m
C]a>oD[MC]e:g0Ebd`803`=>g005C]e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d087oo00<007ooOol037oo00<007ooOol0
0Woo0012Ool00`00Oomoo`0^Ool0_D[LC]e:g4kmA[eJEUXeFUIJ=Cil?U/nO3iKC_e>g4kmC]aBoDkL
D_e>g5;mC]aBoD[LC]e:g7;DL[=bdg:c00l03P0?B]a>gD[LC]e>g5;mC]aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00UOol00`00Oomoo`0;Ool00`00
Oomoo`02Ool004=oo`03001oogoo02ioo`0IB]e>gD[L@21JEEYFFSEJEUYEB]a:_4[LB[a>oDkLC_a>
g5;mC]a>o4kLC_e>g4km?[d01G;C100?00E>g4klC]aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo2Qoo`03001oogoo00]oo`03001oogoo009oo`00A7oo
00<007ooOol0;Woo0;A:g4kMB]a6gEXeFUIJ=Dl[C`Y>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]a>oDkL
D_eb/g;CL[=be7:cL]=6VdZlAYa6_4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d]Ool00`00Oomoo`0;Ool00`00Oomoo`01Ool004Eoo`8002moo`06A[e6gEXe
FUIJEEYF0dl:00I>gDkLC]a>g5;mC]`2C_`01e;mC]a>oDklC]e:g4[M00Ebd`0900m6W4JLAYaBoDkL
D_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l<Goo00<007ooOol02Woo00<0
07ooOol00Goo0017Ool00`00Oomoo`0]Ool074JmFUIJ=EYFFSEJESiK?W`nFdkmC]a>oDkLD_e>g5;m
C]aBoDkLD_e>g4kMB]a>oG:cL]=^/g;D0P0?08i:g4kMB]a>gDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoCEoo`03001oogoo00Uoo`03001oogoo005oo`00B7oo00<007ooOol0;Goo00I6
_EYFC`YJEUYEFUH3?U/01TkmC]a>o4kLD_e>g09>o005C_e>g4kmC]a2_@05L]<300l01DkLC_a>g5;m
C_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo03Qoo`03001oogoo00Uoo`03001oogoo005oo`00
BGoo00<007ooOol0;7oo00E6gEXeFUIJ=EYF0080002MB[a>gDZlD_e>g5;mC]aBoDkLD_e>g4kmC]aB
oDkLL]=^/g;DL[=be00?B[a6W4JlC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0?Goo00<007ooOol0
27oo00<007ooOol00Goo001:Ool2000]Ool015YFFUEJEUXe0`0000E:_4[LB[aBoDkL009>o006D_e>
g4kmC_a>gD[L0T[M1G;C0dJL00E6_4kLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo041oo`03001oogoo00Moo`03
001oogoo005oo`00C7oo00<007ooOol0:Woo00=J=EYFFSD00Woo09LnO3iK?Wa>g4kmC]a>oDkLD_e>
g5;mC]aBoDkLC]e:g4kmL[=bdfjcL]Ab/`0?B]a>gD[LC]e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@16Ool00`00Oomoo`06Ool0
0`00Oomoo`01Ool004eoo`03001oogoo02Yoo`04FSD007ooOol3?U/01SiLC]a>o4kLC_e>g09>o007
D_e>g4kmC_a>gD[LB]d017;C0P0?0dkL00E>gDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol0Agoo00<007ooOol01goo0@000Goo0Goo001>
Ool00`00Oomoo`0YOol00eYFOomoo`02Ool05DZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4:m
K[=be7:cL]A^/`0300l0N4kLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoDeoo`03001oogoo00Ioo`40005oo`5oo`00Cgoo0P00;goo00E:_4[LB[a:
g4kL009>o008D_e>g4kmC_aBoDkLC_e>g0Ibd`96W005A[a6W4klC]aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo59oo`03001oogoo00Eoo`40005oo`5oo`00DGoo00<007oo
Ool0;Goo08M>g4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]abe6jcL]Ab/g;D00m>gD[LC]e:g5;m
C]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0EGoo00<007ooOol01Goo0@000Goo
0Goo001BOol00`00Oomoo`0]Ool3C]`02TkMC]a>o4klD_e>g4kmC_aBoD[L0T[M17;C0P0?0TkL00I>
gDkLD_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;lFGoo00<007ooOol017oo0@000Goo0Goo
001COol00`00Oomoo`0]Ool04TkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oCjML]Ab/g;DK[=be0<03`1Z
D_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aMOol00`00Oomoo`03Ool10001Ool1Ool005Ao
o`03001oogoo02ioo`0;C_a>g4kmC]a>oDklD_e>g4kmC]a>o@05L]<0200?AYa6_4JLC_a>g5;mC]`2
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@02D_aROol00`00Oomoo`03Ool10001Ool005Eoo`8002moo`1bD_e>g5;mC]aBoDkL
D_e:g4kmB]a>gFjcL]A^/g;D00m:_4JLA[a>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lJ7oo00<007ooOol00goo0@000Goo001G
Ool00`00Oomoo`0/Ool02DkLC_a>o5;mC]a>oDklD_e:g002B]d4L]<02@@?00m>g4kLC]e>g5;lC_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo6aoo`03
001oogoo009oo`40005oo`00F7oo00<007ooOol0;7oo06Y>g5;mC]aBoDkLD_e>g4km?Yebe6jcL]A^
/g;D00l4;`0?D_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoG5oo`05001oogooOol00001Ool005Uoo`03001oogoo02aoo`08C]a>oDklD_e>g4kmC]a>
o@Ibd`07AYa6_4JLC_a>g5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
009Bo7Eoo`04001oogoo0001Ool005Yoo`8002eoo`1RC]aBoDkLD_e:g4kmB]a>gFjcL]A^/g;DK[=:
_4JLA[a6Ve;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoGQoo`04001oogoo
0001Ool005aoo`03001oogoo02]oo`05C]a>oDklC_e:g002B]d5L]<02@0?C]a>g4kMC]aBo4klD_e>
g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_alOol00`00Ool00001Ool005eoo`03001oogoo02ao
o`1ID_e>g5;mB]a>oD[LL]A^/g;DK[<4<00?131:g4kMB]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@20Ool10001Ool1000005ioo`03001oogoo02aoo`04C_e>g4kmC]`5L]<02TJLA[a6W4JLC]aBoDkL
C_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@02D_b4Ool2000005moo`8002eoo`1@C_e:g4kMB]abe6jcL]A^/g;DAYa6_4JK
B[a>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo8Qoo`800000HGoo00<007ooOol0:goo0T[M00=>gG;CL]<00W;C00Ab/`@_
C]a>g@9>g003C_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mD_aoo`2:Ool20000069oo`03001oogoo02]oo`15C_e:g4kMK[=be6jcL]@0
3`@`B]a>gD[LC]e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m08eoo`@0009oo`00Hgoo00<007ooOol0:goo00@n_G;CL]=b/`9bd`0:13003`@_C]aBoDkLC_aB
o5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b<Ool40006Ool006Aoo`80
02aoo`0mL]A^/g;DK[=oo`@?A[a6VdZlC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d0Rgoo10002Woo001VOol00`00Oomoo`0ZOol2L]<2Ool00`@_C]a>g@02C]`00dklD_e>
g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Yoo`@000ioo`00Igoo00<007ooOol0;Goo
03803`@`B]a>gD[LC]e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mRWoo0`004Woo001XOol00`00
Oomoo`0/Ool02P@`12l4;dkLD_e>g4klD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Uoo`@001Eoo`00JGoo
0P00;Goo02]6_4JKB[a6W5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@28Ool4000IOol006]oo`03001oogoo02]o
o`09C]e>g4kLC]aBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo8Yoo`@001eoo`00K7oo00<007ooOol0:goo021>gD[LC]e:g5;mC]aBoDkLD_e>
g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lRGoo10008Goo001]Ool0
0`00Oomoo`0[Ool01U;mC]a>o4kLD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00ABoE;lD_aBo8Uoo`<002Eoo`00KWoo00<007ooOol0;7oo01M>g5;mC]aBoDkLD_e>o5;mC_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l08Qoo`@002Qoo`00Kgoo0P00;Goo00A>g5;lC_aBo@=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;lQgoo1000;7oo001aOol00`00Oomoo`0ZOol045;mC]aBoDkL
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lQWoo1000<7oo001bOol00`00Oomoo`0[Ool014klD_aBo5;m
0e;l00ABoE;lD_aBo8Eoo`@003Aoo`00Lgoo00<007ooOol0:goo00A>g5;mC_aBoHMoo`@003Qoo`00
M7oo0P00;7oo00<007ooOol0Q7oo0`00?7oo001fOol00`00Oomoo`0YOol00`00Oomoo`20Ool4000o
Ool007Moo`03001oogoo02Qoo`03001oogoo07aoo`@004=oo`00N7oo00<007ooOol09goo00<007oo
Ool0N7oo1000Agoo001iOol2000WOol00`00Oomoo`1dOol4001;Ool007]oo`03001oogoo02Aoo`03
001oogoo075oo`<004moo`00O7oo00<007ooOol08goo00<007ooOol0KGoo1000DWoo001mOol00`00
Oomoo`0ROol00`00Oomoo`1YOol4001FOol007ioo`80029oo`03001oogoo06Eoo`@005Yoo`00P7oo
00<007ooOol07goo00<007ooOol0HGoo1000GWoo0021Ool00`00Oomoo`0NOol00`00Oomoo`1NOol3
001ROol0089oo`03001oogoo01eoo`03001oogoo05Yoo`@006Eoo`00Pgoo00<007ooOol077oo00<0
07ooOol0EWoo1000JGoo0024Ool2000LOol00`00Oomoo`1BOol4001]Ool008Ioo`03001oogoo01Uo
o`03001oogoo04ioo`@0075oo`00Qgoo00<007ooOol067oo00<007ooOol0Bgoo0`00MGoo0028Ool0
0`00Oomoo`0GOol00`00Oomoo`17Ool4001hOol008Uoo`8001Moo`03001oogoo04=oo`@007aoo`00
Rgoo00<007ooOol057oo00<007ooOol0?goo1000P7oo002<Ool00`00Oomoo`0BOol00`00Oomoo`0l
Ool40024Ool008eoo`03001oogoo015oo`03001oogoo03Uoo`<008Qoo`00SWoo0P004Goo00<007oo
Ool0=Goo1000Rgoo002@Ool00`00Oomoo`0>Ool00`00Oomoo`0aOol4002?Ool0095oo`03001oogoo
00eoo`03001oogoo02eoo`@009=oo`00TWoo00<007ooOol037oo00<007ooOol0:Goo1000Ugoo002C
Ool2000<Ool00`00Oomoo`0UOol4002KOol009Eoo`03001oogoo00Uoo`03001oogoo029oo`<009mo
o`00UWoo00<007ooOol027oo00<007ooOol07Woo1000XWoo002GOol00`00Oomoo`07Ool00`00Oomo
o`0JOol4002VOol009Qoo`03001oogoo00Ioo`03001oogoo01Ioo`@00:Yoo`00VGoo0P001Woo00<0
07ooOol04Woo1000[Woo002KOol00`00Oomoo`03Ool00`00Oomoo`0?Ool3002bOol009aoo`03001o
ogoo009oo`03001oogoo00]oo`@00;Eoo`00WGoo00D007ooOomoo`0000Uoo`@00;Uoo`00WWoo0P00
00=oo`00Ool017oo1000_Goo002POol200000goo000000020031Ool00:5oo`800<Eoo`00ogooJGoo
003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?mo
ofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.642 .74 .92 r
.39638 .69674 .4017 .70159 .41062 .69927 .40531 .69453 Mtetra
.65 .747 .92 r
.40531 .69453 .41062 .69927 .41957 .69683 .41427 .69212 Mtetra
.654 .75 .92 r
.41427 .69212 .41957 .69683 .42855 .69431 .42327 .68961 Mtetra
.656 .752 .92 r
.42327 .68961 .42855 .69431 .43756 .69174 .43231 .68705 Mtetra
.658 .753 .92 r
.43231 .68705 .43756 .69174 .4466 .68913 .44137 .68443 Mtetra
.659 .753 .92 r
.44137 .68443 .4466 .68913 .45568 .6865 .45046 .68179 Mtetra
.659 .754 .92 r
.45046 .68179 .45568 .6865 .46478 .68386 .45958 .67913 Mtetra
.45958 .67913 .46478 .68386 .47391 .68121 .46874 .67647 Mtetra
.46874 .67647 .47391 .68121 .48308 .67855 .47792 .67379 Mtetra
.659 .753 .92 r
.47792 .67379 .48308 .67855 .49227 .6759 .48713 .67112 Mtetra
.658 .753 .92 r
.48713 .67112 .49227 .6759 .5015 .67324 .49638 .66844 Mtetra
.49638 .66844 .5015 .67324 .51075 .67058 .50566 .66576 Mtetra
.50566 .66576 .51075 .67058 .52004 .66791 .51496 .66308 Mtetra
.51496 .66308 .52004 .66791 .52936 .66524 .5243 .66039 Mtetra
.5243 .66039 .52936 .66524 .53871 .66256 .53367 .65769 Mtetra
.53367 .65769 .53871 .66256 .54809 .65987 .54307 .65498 Mtetra
.657 .753 .92 r
.54307 .65498 .54809 .65987 .5575 .65718 .55251 .65227 Mtetra
.55251 .65227 .5575 .65718 .56694 .65448 .56198 .64955 Mtetra
.56198 .64955 .56694 .65448 .57642 .65177 .57147 .64682 Mtetra
.657 .752 .92 r
.57147 .64682 .57642 .65177 .58593 .64905 .581 .64409 Mtetra
.581 .64409 .58593 .64905 .59547 .64632 .59057 .64135 Mtetra
.59057 .64135 .59547 .64632 .60505 .64359 .60016 .63859 Mtetra
.60016 .63859 .60505 .64359 .61465 .64084 .60979 .63583 Mtetra
.60979 .63583 .61465 .64084 .62429 .63809 .61946 .63306 Mtetra
.61946 .63306 .62429 .63809 .63397 .63533 .62915 .63029 Mtetra
.62915 .63029 .63397 .63533 .64367 .63256 .63888 .6275 Mtetra
.63888 .6275 .64367 .63256 .65341 .62979 .64864 .6247 Mtetra
.64864 .6247 .65341 .62979 .66319 .627 .65844 .6219 Mtetra
.65844 .6219 .66319 .627 .67299 .6242 .66827 .61908 Mtetra
.66827 .61908 .67299 .6242 .68284 .6214 .67814 .61626 Mtetra
.67814 .61626 .68284 .6214 .69271 .61858 .68804 .61343 Mtetra
.68804 .61343 .69271 .61858 .70262 .61576 .69797 .61058 Mtetra
.69797 .61058 .70262 .61576 .71257 .61293 .70794 .60773 Mtetra
.70794 .60773 .71257 .61293 .72255 .61008 .71795 .60487 Mtetra
.71795 .60487 .72255 .61008 .73256 .60723 .72798 .602 Mtetra
.72798 .602 .73256 .60723 .74261 .60437 .73806 .59912 Mtetra
.73806 .59912 .74261 .60437 .7527 .6015 .74817 .59623 Mtetra
.74817 .59623 .7527 .6015 .76282 .59862 .75831 .59333 Mtetra
.75831 .59333 .76282 .59862 .77297 .59573 .7685 .59042 Mtetra
.7685 .59042 .77297 .59573 .78317 .59283 .77871 .5875 Mtetra
.77871 .5875 .78317 .59283 .79339 .58992 .78897 .58457 Mtetra
.78897 .58457 .79339 .58992 .80366 .587 .79926 .58163 Mtetra
.79926 .58163 .80366 .587 .81396 .58407 .80959 .57868 Mtetra
.80959 .57868 .81396 .58407 .8243 .58112 .81995 .57572 Mtetra
.81995 .57572 .8243 .58112 .83467 .57817 .83035 .57275 Mtetra
.83035 .57275 .83467 .57817 .84508 .57521 .84079 .56977 Mtetra
.84079 .56977 .84508 .57521 .85553 .57224 .85127 .56678 Mtetra
.85127 .56678 .85553 .57224 .86602 .56926 .86178 .56378 Mtetra
.86178 .56378 .86602 .56926 .87654 .56627 .87233 .56076 Mtetra
.87233 .56076 .87654 .56627 .88711 .56326 .88292 .55774 Mtetra
.88292 .55774 .88711 .56326 .89771 .56025 .89355 .55471 Mtetra
.89355 .55471 .89771 .56025 .90835 .55722 .90422 .55166 Mtetra
.90422 .55166 .90835 .55722 .91902 .55419 .91492 .54861 Mtetra
.91492 .54861 .91902 .55419 .92974 .55114 .92567 .54554 Mtetra
.92567 .54554 .92974 .55114 .94049 .54809 .93645 .54246 Mtetra
.93645 .54246 .94049 .54809 .95129 .54502 .94727 .53937 Mtetra
.94727 .53937 .95129 .54502 .96212 .54194 .95814 .53627 Mtetra
.95814 .53627 .96212 .54194 .97299 .53885 .96904 .53316 Mtetra
.96904 .53316 .97299 .53885 .98391 .53575 .97998 .53004 Mtetra
.633 .732 .919 r
.39103 .69173 .39638 .69674 .40531 .69453 .39997 .68971 Mtetra
.647 .744 .92 r
.39997 .68971 .40531 .69453 .41427 .69212 .40895 .68736 Mtetra
.652 .748 .92 r
.40895 .68736 .41427 .69212 .42327 .68961 .41797 .68487 Mtetra
.655 .751 .92 r
.41797 .68487 .42327 .68961 .43231 .68705 .42702 .68231 Mtetra
.657 .752 .92 r
.42702 .68231 .43231 .68705 .44137 .68443 .4361 .6797 Mtetra
.658 .753 .92 r
.4361 .6797 .44137 .68443 .45046 .68179 .44521 .67705 Mtetra
.659 .754 .92 r
.44521 .67705 .45046 .68179 .45958 .67913 .45435 .67438 Mtetra
.45435 .67438 .45958 .67913 .46874 .67647 .46353 .6717 Mtetra
.46353 .6717 .46874 .67647 .47792 .67379 .47273 .66901 Mtetra
.47273 .66901 .47792 .67379 .48713 .67112 .48197 .66631 Mtetra
.658 .753 .92 r
.48197 .66631 .48713 .67112 .49638 .66844 .49123 .66362 Mtetra
.49123 .66362 .49638 .66844 .50566 .66576 .50053 .66092 Mtetra
.50053 .66092 .50566 .66576 .51496 .66308 .50986 .65821 Mtetra
.50986 .65821 .51496 .66308 .5243 .66039 .51922 .6555 Mtetra
.51922 .6555 .5243 .66039 .53367 .65769 .52861 .65279 Mtetra
.52861 .65279 .53367 .65769 .54307 .65498 .53803 .65006 Mtetra
.53803 .65006 .54307 .65498 .55251 .65227 .54749 .64734 Mtetra
.657 .753 .92 r
.54749 .64734 .55251 .65227 .56198 .64955 .55697 .6446 Mtetra
.55697 .6446 .56198 .64955 .57147 .64682 .56649 .64185 Mtetra
.657 .752 .92 r
.56649 .64185 .57147 .64682 .581 .64409 .57605 .6391 Mtetra
.57605 .6391 .581 .64409 .59057 .64135 .58563 .63634 Mtetra
.58563 .63634 .59057 .64135 .60016 .63859 .59525 .63357 Mtetra
.59525 .63357 .60016 .63859 .60979 .63583 .6049 .63079 Mtetra
.6049 .63079 .60979 .63583 .61946 .63306 .61459 .628 Mtetra
.61459 .628 .61946 .63306 .62915 .63029 .62431 .6252 Mtetra
.62431 .6252 .62915 .63029 .63888 .6275 .63406 .6224 Mtetra
.63406 .6224 .63888 .6275 .64864 .6247 .64385 .61959 Mtetra
.64385 .61959 .64864 .6247 .65844 .6219 .65367 .61676 Mtetra
.65367 .61676 .65844 .6219 .66827 .61908 .66352 .61393 Mtetra
.66352 .61393 .66827 .61908 .67814 .61626 .67341 .61109 Mtetra
.67341 .61109 .67814 .61626 .68804 .61343 .68333 .60824 Mtetra
.68333 .60824 .68804 .61343 .69797 .61058 .69329 .60538 Mtetra
.69329 .60538 .69797 .61058 .70794 .60773 .70328 .60251 Mtetra
.70328 .60251 .70794 .60773 .71795 .60487 .71331 .59963 Mtetra
.71331 .59963 .71795 .60487 .72798 .602 .72338 .59674 Mtetra
.72338 .59674 .72798 .602 .73806 .59912 .73348 .59384 Mtetra
.73348 .59384 .73806 .59912 .74817 .59623 .74361 .59093 Mtetra
.74361 .59093 .74817 .59623 .75831 .59333 .75378 .58801 Mtetra
.75378 .58801 .75831 .59333 .7685 .59042 .76399 .58508 Mtetra
.76399 .58508 .7685 .59042 .77871 .5875 .77423 .58214 Mtetra
.77423 .58214 .77871 .5875 .78897 .58457 .78451 .57919 Mtetra
.78451 .57919 .78897 .58457 .79926 .58163 .79483 .57623 Mtetra
.79483 .57623 .79926 .58163 .80959 .57868 .80518 .57326 Mtetra
.80518 .57326 .80959 .57868 .81995 .57572 .81558 .57028 Mtetra
.81558 .57028 .81995 .57572 .83035 .57275 .826 .56729 Mtetra
.826 .56729 .83035 .57275 .84079 .56977 .83647 .56429 Mtetra
.83647 .56429 .84079 .56977 .85127 .56678 .84697 .56128 Mtetra
.84697 .56128 .85127 .56678 .86178 .56378 .85751 .55826 Mtetra
.85751 .55826 .86178 .56378 .87233 .56076 .86809 .55522 Mtetra
.86809 .55522 .87233 .56076 .88292 .55774 .87871 .55218 Mtetra
.87871 .55218 .88292 .55774 .89355 .55471 .88937 .54913 Mtetra
.88937 .54913 .89355 .55471 .90422 .55166 .90006 .54606 Mtetra
.90006 .54606 .90422 .55166 .91492 .54861 .9108 .54299 Mtetra
.9108 .54299 .91492 .54861 .92567 .54554 .92157 .5399 Mtetra
.92157 .5399 .92567 .54554 .93645 .54246 .93238 .5368 Mtetra
.93238 .5368 .93645 .54246 .94727 .53937 .94323 .53369 Mtetra
.94323 .53369 .94727 .53937 .95814 .53627 .95413 .53057 Mtetra
.95413 .53057 .95814 .53627 .96904 .53316 .96506 .52744 Mtetra
.96506 .52744 .96904 .53316 .97998 .53004 .97603 .52429 Mtetra
.611 .711 .916 r
.38567 .68631 .39103 .69173 .39997 .68971 .3946 .68479 Mtetra
.642 .74 .92 r
.3946 .68479 .39997 .68971 .40895 .68736 .4036 .68254 Mtetra
.65 .747 .92 r
.4036 .68254 .40895 .68736 .41797 .68487 .41263 .68009 Mtetra
.654 .75 .92 r
.41263 .68009 .41797 .68487 .42702 .68231 .4217 .67754 Mtetra
.656 .752 .92 r
.4217 .67754 .42702 .68231 .4361 .6797 .4308 .67493 Mtetra
.658 .753 .92 r
.4308 .67493 .4361 .6797 .44521 .67705 .43993 .67228 Mtetra
.659 .753 .92 r
.43993 .67228 .44521 .67705 .45435 .67438 .44909 .6696 Mtetra
.659 .754 .92 r
.44909 .6696 .45435 .67438 .46353 .6717 .45829 .6669 Mtetra
.45829 .6669 .46353 .6717 .47273 .66901 .46751 .66419 Mtetra
.46751 .66419 .47273 .66901 .48197 .66631 .47677 .66148 Mtetra
.659 .753 .92 r
.47677 .66148 .48197 .66631 .49123 .66362 .48605 .65876 Mtetra
.658 .753 .92 r
.48605 .65876 .49123 .66362 .50053 .66092 .49537 .65604 Mtetra
.49537 .65604 .50053 .66092 .50986 .65821 .50472 .65332 Mtetra
.50472 .65332 .50986 .65821 .51922 .6555 .5141 .65059 Mtetra
.5141 .65059 .51922 .6555 .52861 .65279 .52351 .64786 Mtetra
.52351 .64786 .52861 .65279 .53803 .65006 .53296 .64512 Mtetra
.53296 .64512 .53803 .65006 .54749 .64734 .54243 .64237 Mtetra
.657 .753 .92 r
.54243 .64237 .54749 .64734 .55697 .6446 .55194 .63961 Mtetra
.55194 .63961 .55697 .6446 .56649 .64185 .56148 .63685 Mtetra
.56148 .63685 .56649 .64185 .57605 .6391 .57106 .63408 Mtetra
.657 .752 .92 r
.57106 .63408 .57605 .6391 .58563 .63634 .58067 .6313 Mtetra
.58067 .6313 .58563 .63634 .59525 .63357 .59031 .62851 Mtetra
.59031 .62851 .59525 .63357 .6049 .63079 .59998 .62571 Mtetra
.59998 .62571 .6049 .63079 .61459 .628 .60969 .62291 Mtetra
.60969 .62291 .61459 .628 .62431 .6252 .61943 .62009 Mtetra
.61943 .62009 .62431 .6252 .63406 .6224 .62921 .61727 Mtetra
.62921 .61727 .63406 .6224 .64385 .61959 .63902 .61444 Mtetra
.63902 .61444 .64385 .61959 .65367 .61676 .64886 .61159 Mtetra
.64886 .61159 .65367 .61676 .66352 .61393 .65874 .60874 Mtetra
.65874 .60874 .66352 .61393 .67341 .61109 .66865 .60588 Mtetra
.66865 .60588 .67341 .61109 .68333 .60824 .6786 .60301 Mtetra
.6786 .60301 .68333 .60824 .69329 .60538 .68858 .60013 Mtetra
.68858 .60013 .69329 .60538 .70328 .60251 .6986 .59724 Mtetra
.6986 .59724 .70328 .60251 .71331 .59963 .70865 .59435 Mtetra
.70865 .59435 .71331 .59963 .72338 .59674 .71874 .59144 Mtetra
.71874 .59144 .72338 .59674 .73348 .59384 .72886 .58852 Mtetra
.72886 .58852 .73348 .59384 .74361 .59093 .73902 .58559 Mtetra
.73902 .58559 .74361 .59093 .75378 .58801 .74922 .58265 Mtetra
.74922 .58265 .75378 .58801 .76399 .58508 .75945 .5797 Mtetra
.75945 .5797 .76399 .58508 .77423 .58214 .76972 .57674 Mtetra
.76972 .57674 .77423 .58214 .78451 .57919 .78003 .57378 Mtetra
.78003 .57378 .78451 .57919 .79483 .57623 .79037 .5708 Mtetra
.79037 .5708 .79483 .57623 .80518 .57326 .80075 .56781 Mtetra
.80075 .56781 .80518 .57326 .81558 .57028 .81117 .56481 Mtetra
.81117 .56481 .81558 .57028 .826 .56729 .82162 .5618 Mtetra
.82162 .5618 .826 .56729 .83647 .56429 .83212 .55878 Mtetra
.83212 .55878 .83647 .56429 .84697 .56128 .84265 .55574 Mtetra
.84265 .55574 .84697 .56128 .85751 .55826 .85322 .5527 Mtetra
.85322 .5527 .85751 .55826 .86809 .55522 .86382 .54965 Mtetra
.86382 .54965 .86809 .55522 .87871 .55218 .87447 .54658 Mtetra
.87447 .54658 .87871 .55218 .88937 .54913 .88515 .54351 Mtetra
.88515 .54351 .88937 .54913 .90006 .54606 .89588 .54042 Mtetra
.89588 .54042 .90006 .54606 .9108 .54299 .90664 .53733 Mtetra
.90664 .53733 .9108 .54299 .92157 .5399 .91744 .53422 Mtetra
.91744 .53422 .92157 .5399 .93238 .5368 .92829 .5311 Mtetra
.92829 .5311 .93238 .5368 .94323 .53369 .93917 .52797 Mtetra
.93917 .52797 .94323 .53369 .95413 .53057 .95009 .52483 Mtetra
.95009 .52483 .95413 .53057 .96506 .52744 .96105 .52167 Mtetra
.96105 .52167 .96506 .52744 .97603 .52429 .97205 .51851 Mtetra
.516 .609 .884 r
.38035 .67899 .38567 .68631 .3946 .68479 .38921 .6797 Mtetra
.633 .732 .919 r
.38921 .6797 .3946 .68479 .4036 .68254 .39821 .67764 Mtetra
.647 .744 .92 r
.39821 .67764 .4036 .68254 .41263 .68009 .40726 .67525 Mtetra
.652 .748 .92 r
.40726 .67525 .41263 .68009 .4217 .67754 .41635 .67273 Mtetra
.655 .751 .92 r
.41635 .67273 .4217 .67754 .4308 .67493 .42547 .67013 Mtetra
.657 .752 .92 r
.42547 .67013 .4308 .67493 .43993 .67228 .43462 .66748 Mtetra
.658 .753 .92 r
.43462 .66748 .43993 .67228 .44909 .6696 .4438 .66478 Mtetra
.659 .754 .92 r
.4438 .66478 .44909 .6696 .45829 .6669 .45301 .66207 Mtetra
.45301 .66207 .45829 .6669 .46751 .66419 .46226 .65934 Mtetra
.46226 .65934 .46751 .66419 .47677 .66148 .47153 .65661 Mtetra
.47153 .65661 .47677 .66148 .48605 .65876 .48084 .65387 Mtetra
.658 .753 .92 r
.48084 .65387 .48605 .65876 .49537 .65604 .49018 .65114 Mtetra
.49018 .65114 .49537 .65604 .50472 .65332 .49955 .64839 Mtetra
.49955 .64839 .50472 .65332 .5141 .65059 .50895 .64565 Mtetra
.50895 .64565 .5141 .65059 .52351 .64786 .51838 .64289 Mtetra
.51838 .64289 .52351 .64786 .53296 .64512 .52785 .64013 Mtetra
.52785 .64013 .53296 .64512 .54243 .64237 .53735 .63737 Mtetra
.53735 .63737 .54243 .64237 .55194 .63961 .54688 .63459 Mtetra
.657 .753 .92 r
.54688 .63459 .55194 .63961 .56148 .63685 .55644 .63181 Mtetra
.55644 .63181 .56148 .63685 .57106 .63408 .56604 .62902 Mtetra
.657 .752 .92 r
.56604 .62902 .57106 .63408 .58067 .6313 .57567 .62622 Mtetra
.57567 .62622 .58067 .6313 .59031 .62851 .58533 .62342 Mtetra
.58533 .62342 .59031 .62851 .59998 .62571 .59503 .6206 Mtetra
.59503 .6206 .59998 .62571 .60969 .62291 .60476 .61778 Mtetra
.60476 .61778 .60969 .62291 .61943 .62009 .61452 .61495 Mtetra
.61452 .61495 .61943 .62009 .62921 .61727 .62432 .6121 Mtetra
.62432 .6121 .62921 .61727 .63902 .61444 .63415 .60925 Mtetra
.63415 .60925 .63902 .61444 .64886 .61159 .64402 .60639 Mtetra
.64402 .60639 .64886 .61159 .65874 .60874 .65392 .60352 Mtetra
.65392 .60352 .65874 .60874 .66865 .60588 .66386 .60064 Mtetra
.66386 .60064 .66865 .60588 .6786 .60301 .67383 .59775 Mtetra
.67383 .59775 .6786 .60301 .68858 .60013 .68384 .59486 Mtetra
.68384 .59486 .68858 .60013 .6986 .59724 .69388 .59195 Mtetra
.69388 .59195 .6986 .59724 .70865 .59435 .70396 .58903 Mtetra
.70396 .58903 .70865 .59435 .71874 .59144 .71407 .5861 Mtetra
.71407 .5861 .71874 .59144 .72886 .58852 .72422 .58316 Mtetra
.72422 .58316 .72886 .58852 .73902 .58559 .73441 .58022 Mtetra
.73441 .58022 .73902 .58559 .74922 .58265 .74463 .57726 Mtetra
.74463 .57726 .74922 .58265 .75945 .5797 .75489 .57429 Mtetra
.75489 .57429 .75945 .5797 .76972 .57674 .76518 .57131 Mtetra
.76518 .57131 .76972 .57674 .78003 .57378 .77551 .56832 Mtetra
.77551 .56832 .78003 .57378 .79037 .5708 .78588 .56533 Mtetra
.78588 .56533 .79037 .5708 .80075 .56781 .79629 .56232 Mtetra
.79629 .56232 .80075 .56781 .81117 .56481 .80674 .5593 Mtetra
.80674 .5593 .81117 .56481 .82162 .5618 .81722 .55626 Mtetra
.81722 .55626 .82162 .5618 .83212 .55878 .82774 .55322 Mtetra
.82774 .55322 .83212 .55878 .84265 .55574 .8383 .55017 Mtetra
.8383 .55017 .84265 .55574 .85322 .5527 .84889 .54711 Mtetra
.84889 .54711 .85322 .5527 .86382 .54965 .85953 .54403 Mtetra
.85953 .54403 .86382 .54965 .87447 .54658 .8702 .54095 Mtetra
.8702 .54095 .87447 .54658 .88515 .54351 .88091 .53785 Mtetra
.88091 .53785 .88515 .54351 .89588 .54042 .89167 .53475 Mtetra
.89167 .53475 .89588 .54042 .90664 .53733 .90246 .53163 Mtetra
.90246 .53163 .90664 .53733 .91744 .53422 .91329 .5285 Mtetra
.91329 .5285 .91744 .53422 .92829 .5311 .92416 .52536 Mtetra
.92416 .52536 .92829 .5311 .93917 .52797 .93507 .52221 Mtetra
.93507 .52221 .93917 .52797 .95009 .52483 .94602 .51904 Mtetra
.94602 .51904 .95009 .52483 .96105 .52167 .95702 .51587 Mtetra
.95702 .51587 .96105 .52167 .97205 .51851 .96805 .51268 Mtetra
0 0 0 r
.37413 .69195 .38035 .67899 .38921 .6797 .38379 .6742 Mtetra
.611 .711 .916 r
.38379 .6742 .38921 .6797 .39821 .67764 .3928 .67265 Mtetra
.642 .74 .92 r
.3928 .67265 .39821 .67764 .40726 .67525 .40186 .67036 Mtetra
.65 .747 .92 r
.40186 .67036 .40726 .67525 .41635 .67273 .41096 .66787 Mtetra
.654 .75 .92 r
.41096 .66787 .41635 .67273 .42547 .67013 .4201 .66528 Mtetra
.656 .752 .92 r
.4201 .66528 .42547 .67013 .43462 .66748 .42927 .66263 Mtetra
.658 .753 .92 r
.42927 .66263 .43462 .66748 .4438 .66478 .43847 .65994 Mtetra
.659 .753 .92 r
.43847 .65994 .4438 .66478 .45301 .66207 .44771 .65721 Mtetra
.659 .754 .92 r
.44771 .65721 .45301 .66207 .46226 .65934 .45697 .65447 Mtetra
.45697 .65447 .46226 .65934 .47153 .65661 .46627 .65172 Mtetra
.46627 .65172 .47153 .65661 .48084 .65387 .47559 .64896 Mtetra
.659 .753 .92 r
.47559 .64896 .48084 .65387 .49018 .65114 .48495 .6462 Mtetra
.658 .753 .92 r
.48495 .6462 .49018 .65114 .49955 .64839 .49434 .64344 Mtetra
.49434 .64344 .49955 .64839 .50895 .64565 .50377 .64067 Mtetra
.50377 .64067 .50895 .64565 .51838 .64289 .51322 .6379 Mtetra
.51322 .6379 .51838 .64289 .52785 .64013 .52271 .63512 Mtetra
.52271 .63512 .52785 .64013 .53735 .63737 .53223 .63234 Mtetra
.53223 .63234 .53735 .63737 .54688 .63459 .54178 .62954 Mtetra
.657 .753 .92 r
.54178 .62954 .54688 .63459 .55644 .63181 .55137 .62674 Mtetra
.55137 .62674 .55644 .63181 .56604 .62902 .56099 .62394 Mtetra
.56099 .62394 .56604 .62902 .57567 .62622 .57064 .62112 Mtetra
.657 .752 .92 r
.57064 .62112 .57567 .62622 .58533 .62342 .58032 .61829 Mtetra
.58032 .61829 .58533 .62342 .59503 .6206 .59004 .61546 Mtetra
.59004 .61546 .59503 .6206 .60476 .61778 .5998 .61262 Mtetra
.5998 .61262 .60476 .61778 .61452 .61495 .60958 .60977 Mtetra
.60958 .60977 .61452 .61495 .62432 .6121 .61941 .60691 Mtetra
.61941 .60691 .62432 .6121 .63415 .60925 .62926 .60404 Mtetra
.62926 .60404 .63415 .60925 .64402 .60639 .63915 .60116 Mtetra
.63915 .60116 .64402 .60639 .65392 .60352 .64908 .59827 Mtetra
.64908 .59827 .65392 .60352 .66386 .60064 .65904 .59537 Mtetra
.65904 .59537 .66386 .60064 .67383 .59775 .66903 .59246 Mtetra
.66903 .59246 .67383 .59775 .68384 .59486 .67907 .58954 Mtetra
.67907 .58954 .68384 .59486 .69388 .59195 .68913 .58662 Mtetra
.68913 .58662 .69388 .59195 .70396 .58903 .69923 .58368 Mtetra
.69923 .58368 .70396 .58903 .71407 .5861 .70937 .58073 Mtetra
.70937 .58073 .71407 .5861 .72422 .58316 .71955 .57778 Mtetra
.71955 .57778 .72422 .58316 .73441 .58022 .72976 .57481 Mtetra
.72976 .57481 .73441 .58022 .74463 .57726 .74001 .57183 Mtetra
.74001 .57183 .74463 .57726 .75489 .57429 .75029 .56884 Mtetra
.75029 .56884 .75489 .57429 .76518 .57131 .76061 .56584 Mtetra
.76061 .56584 .76518 .57131 .77551 .56832 .77097 .56284 Mtetra
.77097 .56284 .77551 .56832 .78588 .56533 .78137 .55982 Mtetra
.78137 .55982 .78588 .56533 .79629 .56232 .7918 .55679 Mtetra
.7918 .55679 .79629 .56232 .80674 .5593 .80227 .55375 Mtetra
.80227 .55375 .80674 .5593 .81722 .55626 .81278 .5507 Mtetra
.81278 .5507 .81722 .55626 .82774 .55322 .82333 .54763 Mtetra
.82333 .54763 .82774 .55322 .8383 .55017 .83391 .54456 Mtetra
.83391 .54456 .8383 .55017 .84889 .54711 .84454 .54148 Mtetra
.84454 .54148 .84889 .54711 .85953 .54403 .8552 .53838 Mtetra
.8552 .53838 .85953 .54403 .8702 .54095 .8659 .53528 Mtetra
.8659 .53528 .8702 .54095 .88091 .53785 .87664 .53216 Mtetra
.87664 .53216 .88091 .53785 .89167 .53475 .88743 .52903 Mtetra
.88743 .52903 .89167 .53475 .90246 .53163 .89825 .52589 Mtetra
.89825 .52589 .90246 .53163 .91329 .5285 .90911 .52274 Mtetra
.90911 .52274 .91329 .5285 .92416 .52536 .92001 .51958 Mtetra
.92001 .51958 .92416 .52536 .93507 .52221 .93095 .51641 Mtetra
.93095 .51641 .93507 .52221 .94602 .51904 .94193 .51322 Mtetra
.94193 .51322 .94602 .51904 .95702 .51587 .95295 .51003 Mtetra
.95295 .51003 .95702 .51587 .96805 .51268 .96402 .50682 Mtetra
.721 .587 .705 r
.36909 .67651 .37413 .69195 .38379 .6742 .37843 .6668 Mtetra
.516 .609 .885 r
.37843 .6668 .38379 .6742 .3928 .67265 .38735 .66748 Mtetra
.633 .732 .919 r
.38735 .66748 .3928 .67265 .40186 .67036 .39643 .66539 Mtetra
.647 .744 .92 r
.39643 .66539 .40186 .67036 .41096 .66787 .40555 .66295 Mtetra
.652 .748 .92 r
.40555 .66295 .41096 .66787 .4201 .66528 .4147 .66039 Mtetra
.655 .751 .92 r
.4147 .66039 .4201 .66528 .42927 .66263 .42389 .65775 Mtetra
.657 .752 .92 r
.42389 .65775 .42927 .66263 .43847 .65994 .43311 .65505 Mtetra
.658 .753 .92 r
.43311 .65505 .43847 .65994 .44771 .65721 .44236 .65232 Mtetra
.659 .754 .92 r
.44236 .65232 .44771 .65721 .45697 .65447 .45165 .64956 Mtetra
.45165 .64956 .45697 .65447 .46627 .65172 .46097 .64679 Mtetra
.46097 .64679 .46627 .65172 .47559 .64896 .47031 .64402 Mtetra
.47031 .64402 .47559 .64896 .48495 .6462 .47969 .64124 Mtetra
.658 .753 .92 r
.47969 .64124 .48495 .6462 .49434 .64344 .48911 .63845 Mtetra
.48911 .63845 .49434 .64344 .50377 .64067 .49855 .63567 Mtetra
.49855 .63567 .50377 .64067 .51322 .6379 .50803 .63288 Mtetra
.50803 .63288 .51322 .6379 .52271 .63512 .51753 .63008 Mtetra
.51753 .63008 .52271 .63512 .53223 .63234 .52708 .62727 Mtetra
.52708 .62727 .53223 .63234 .54178 .62954 .53665 .62446 Mtetra
.53665 .62446 .54178 .62954 .55137 .62674 .54626 .62164 Mtetra
.657 .753 .92 r
.54626 .62164 .55137 .62674 .56099 .62394 .5559 .61882 Mtetra
.5559 .61882 .56099 .62394 .57064 .62112 .56557 .61598 Mtetra
.657 .752 .92 r
.56557 .61598 .57064 .62112 .58032 .61829 .57528 .61314 Mtetra
.57528 .61314 .58032 .61829 .59004 .61546 .58502 .61029 Mtetra
.58502 .61029 .59004 .61546 .5998 .61262 .5948 .60742 Mtetra
.5948 .60742 .5998 .61262 .60958 .60977 .60461 .60455 Mtetra
.60461 .60455 .60958 .60977 .61941 .60691 .61446 .60167 Mtetra
.61446 .60167 .61941 .60691 .62926 .60404 .62434 .59879 Mtetra
.62434 .59879 .62926 .60404 .63915 .60116 .63425 .59589 Mtetra
.63425 .59589 .63915 .60116 .64908 .59827 .6442 .59298 Mtetra
.6442 .59298 .64908 .59827 .65904 .59537 .65418 .59006 Mtetra
.65418 .59006 .65904 .59537 .66903 .59246 .6642 .58714 Mtetra
.6642 .58714 .66903 .59246 .67907 .58954 .67426 .5842 Mtetra
.67426 .5842 .67907 .58954 .68913 .58662 .68435 .58125 Mtetra
.68435 .58125 .68913 .58662 .69923 .58368 .69448 .57829 Mtetra
.69448 .57829 .69923 .58368 .70937 .58073 .70464 .57533 Mtetra
.70464 .57533 .70937 .58073 .71955 .57778 .71484 .57235 Mtetra
.71484 .57235 .71955 .57778 .72976 .57481 .72508 .56936 Mtetra
.72508 .56936 .72976 .57481 .74001 .57183 .73535 .56637 Mtetra
.73535 .56637 .74001 .57183 .75029 .56884 .74566 .56336 Mtetra
.74566 .56336 .75029 .56884 .76061 .56584 .75601 .56034 Mtetra
.75601 .56034 .76061 .56584 .77097 .56284 .7664 .55731 Mtetra
.7664 .55731 .77097 .56284 .78137 .55982 .77682 .55427 Mtetra
.77682 .55427 .78137 .55982 .7918 .55679 .78728 .55122 Mtetra
.78728 .55122 .7918 .55679 .80227 .55375 .79778 .54816 Mtetra
.79778 .54816 .80227 .55375 .81278 .5507 .80831 .54509 Mtetra
.80831 .54509 .81278 .5507 .82333 .54763 .81889 .54201 Mtetra
.81889 .54201 .82333 .54763 .83391 .54456 .8295 .53891 Mtetra
.8295 .53891 .83391 .54456 .84454 .54148 .84015 .53581 Mtetra
.84015 .53581 .84454 .54148 .8552 .53838 .85084 .53269 Mtetra
.85084 .53269 .8552 .53838 .8659 .53528 .86158 .52957 Mtetra
.86158 .52957 .8659 .53528 .87664 .53216 .87235 .52643 Mtetra
.87235 .52643 .87664 .53216 .88743 .52903 .88316 .52328 Mtetra
.88316 .52328 .88743 .52903 .89825 .52589 .89401 .52012 Mtetra
.89401 .52012 .89825 .52589 .90911 .52274 .9049 .51695 Mtetra
.9049 .51695 .90911 .52274 .92001 .51958 .91583 .51376 Mtetra
.91583 .51376 .92001 .51958 .93095 .51641 .9268 .51057 Mtetra
.9268 .51057 .93095 .51641 .94193 .51322 .93781 .50736 Mtetra
.93781 .50736 .94193 .51322 .95295 .51003 .94886 .50414 Mtetra
.94886 .50414 .95295 .51003 .96402 .50682 .95996 .50091 Mtetra
0 0 .486 r
.36361 .67045 .36909 .67651 .37843 .6668 .37215 .67976 Mtetra
0 0 0 r
.37215 .67976 .37843 .6668 .38735 .66748 .38189 .6619 Mtetra
.611 .711 .916 r
.38189 .6619 .38735 .66748 .39643 .66539 .39096 .66032 Mtetra
.642 .74 .92 r
.39096 .66032 .39643 .66539 .40555 .66295 .4001 .65798 Mtetra
.65 .747 .92 r
.4001 .65798 .40555 .66295 .4147 .66039 .40927 .65545 Mtetra
.654 .75 .92 r
.40927 .65545 .4147 .66039 .42389 .65775 .41848 .65282 Mtetra
.656 .752 .92 r
.41848 .65282 .42389 .65775 .43311 .65505 .42772 .65013 Mtetra
.658 .753 .92 r
.42772 .65013 .43311 .65505 .44236 .65232 .43699 .64739 Mtetra
.659 .753 .92 r
.43699 .64739 .44236 .65232 .45165 .64956 .4463 .64462 Mtetra
.659 .754 .92 r
.4463 .64462 .45165 .64956 .46097 .64679 .45563 .64184 Mtetra
.45563 .64184 .46097 .64679 .47031 .64402 .465 .63904 Mtetra
.465 .63904 .47031 .64402 .47969 .64124 .4744 .63624 Mtetra
.659 .753 .92 r
.4744 .63624 .47969 .64124 .48911 .63845 .48383 .63344 Mtetra
.658 .753 .92 r
.48383 .63344 .48911 .63845 .49855 .63567 .4933 .63063 Mtetra
.4933 .63063 .49855 .63567 .50803 .63288 .5028 .62782 Mtetra
.5028 .62782 .50803 .63288 .51753 .63008 .51233 .625 Mtetra
.51233 .625 .51753 .63008 .52708 .62727 .52189 .62218 Mtetra
.52189 .62218 .52708 .62727 .53665 .62446 .53149 .61935 Mtetra
.53149 .61935 .53665 .62446 .54626 .62164 .54112 .61651 Mtetra
.657 .753 .92 r
.54112 .61651 .54626 .62164 .5559 .61882 .55078 .61367 Mtetra
.55078 .61367 .5559 .61882 .56557 .61598 .56048 .61081 Mtetra
.56048 .61081 .56557 .61598 .57528 .61314 .57021 .60795 Mtetra
.657 .752 .92 r
.57021 .60795 .57528 .61314 .58502 .61029 .57997 .60508 Mtetra
.57997 .60508 .58502 .61029 .5948 .60742 .58977 .6022 Mtetra
.58977 .6022 .5948 .60742 .60461 .60455 .59961 .59931 Mtetra
.59961 .59931 .60461 .60455 .61446 .60167 .60948 .59641 Mtetra
.60948 .59641 .61446 .60167 .62434 .59879 .61938 .5935 Mtetra
.61938 .5935 .62434 .59879 .63425 .59589 .62932 .59058 Mtetra
.62932 .59058 .63425 .59589 .6442 .59298 .63929 .58766 Mtetra
.63929 .58766 .6442 .59298 .65418 .59006 .6493 .58472 Mtetra
.6493 .58472 .65418 .59006 .6642 .58714 .65934 .58177 Mtetra
.65934 .58177 .6642 .58714 .67426 .5842 .66942 .57882 Mtetra
.66942 .57882 .67426 .5842 .68435 .58125 .67954 .57585 Mtetra
.67954 .57585 .68435 .58125 .69448 .57829 .68969 .57287 Mtetra
.68969 .57287 .69448 .57829 .70464 .57533 .69988 .56989 Mtetra
.69988 .56989 .70464 .57533 .71484 .57235 .71011 .56689 Mtetra
.71011 .56689 .71484 .57235 .72508 .56936 .72037 .56388 Mtetra
.72037 .56388 .72508 .56936 .73535 .56637 .73067 .56087 Mtetra
.73067 .56087 .73535 .56637 .74566 .56336 .741 .55784 Mtetra
.741 .55784 .74566 .56336 .75601 .56034 .75138 .5548 Mtetra
.75138 .5548 .75601 .56034 .7664 .55731 .76179 .55175 Mtetra
.76179 .55175 .7664 .55731 .77682 .55427 .77224 .54869 Mtetra
.77224 .54869 .77682 .55427 .78728 .55122 .78273 .54562 Mtetra
.78273 .54562 .78728 .55122 .79778 .54816 .79325 .54254 Mtetra
.79325 .54254 .79778 .54816 .80831 .54509 .80382 .53945 Mtetra
.80382 .53945 .80831 .54509 .81889 .54201 .81442 .53634 Mtetra
.81442 .53634 .81889 .54201 .8295 .53891 .82506 .53323 Mtetra
.82506 .53323 .8295 .53891 .84015 .53581 .83574 .5301 Mtetra
.83574 .5301 .84015 .53581 .85084 .53269 .84646 .52696 Mtetra
.84646 .52696 .85084 .53269 .86158 .52957 .85722 .52382 Mtetra
.85722 .52382 .86158 .52957 .87235 .52643 .86802 .52066 Mtetra
.86802 .52066 .87235 .52643 .88316 .52328 .87886 .51749 Mtetra
.87886 .51749 .88316 .52328 .89401 .52012 .88974 .5143 Mtetra
.88974 .5143 .89401 .52012 .9049 .51695 .90066 .51111 Mtetra
.90066 .51111 .9049 .51695 .91583 .51376 .91162 .5079 Mtetra
.91162 .5079 .91583 .51376 .9268 .51057 .92262 .50469 Mtetra
.92262 .50469 .9268 .51057 .93781 .50736 .93366 .50146 Mtetra
.93366 .50146 .93781 .50736 .94886 .50414 .94474 .49822 Mtetra
.94474 .49822 .94886 .50414 .95996 .50091 .95587 .49496 Mtetra
.57 .706 .933 r
.35807 .66509 .36361 .67045 .37215 .67976 .36706 .66419 Mtetra
.721 .587 .705 r
.36706 .66419 .37215 .67976 .38189 .6619 .37648 .65441 Mtetra
.515 .609 .885 r
.37648 .65441 .38189 .6619 .39096 .66032 .38547 .65507 Mtetra
.633 .732 .919 r
.38547 .65507 .39096 .66032 .4001 .65798 .39461 .65293 Mtetra
.647 .744 .92 r
.39461 .65293 .4001 .65798 .40927 .65545 .4038 .65046 Mtetra
.652 .748 .92 r
.4038 .65046 .40927 .65545 .41848 .65282 .41303 .64785 Mtetra
.655 .751 .92 r
.41303 .64785 .41848 .65282 .42772 .65013 .42229 .64517 Mtetra
.657 .752 .92 r
.42229 .64517 .42772 .65013 .43699 .64739 .43158 .64243 Mtetra
.658 .753 .92 r
.43158 .64243 .43699 .64739 .4463 .64462 .44091 .63965 Mtetra
.659 .754 .92 r
.44091 .63965 .4463 .64462 .45563 .64184 .45026 .63685 Mtetra
.45026 .63685 .45563 .64184 .465 .63904 .45965 .63404 Mtetra
.45965 .63404 .465 .63904 .4744 .63624 .46908 .63122 Mtetra
.46908 .63122 .4744 .63624 .48383 .63344 .47853 .62839 Mtetra
.658 .753 .92 r
.47853 .62839 .48383 .63344 .4933 .63063 .48802 .62556 Mtetra
.48802 .62556 .4933 .63063 .5028 .62782 .49754 .62273 Mtetra
.49754 .62273 .5028 .62782 .51233 .625 .50709 .6199 Mtetra
.50709 .6199 .51233 .625 .52189 .62218 .51667 .61705 Mtetra
.51667 .61705 .52189 .62218 .53149 .61935 .52629 .6142 Mtetra
.52629 .6142 .53149 .61935 .54112 .61651 .53594 .61135 Mtetra
.53594 .61135 .54112 .61651 .55078 .61367 .54563 .60848 Mtetra
.657 .753 .92 r
.54563 .60848 .55078 .61367 .56048 .61081 .55535 .60561 Mtetra
.55535 .60561 .56048 .61081 .57021 .60795 .5651 .60273 Mtetra
.657 .752 .92 r
.5651 .60273 .57021 .60795 .57997 .60508 .57489 .59984 Mtetra
.57489 .59984 .57997 .60508 .58977 .6022 .58471 .59694 Mtetra
.58471 .59694 .58977 .6022 .59961 .59931 .59457 .59403 Mtetra
.59457 .59403 .59961 .59931 .60948 .59641 .60446 .59111 Mtetra
.60446 .59111 .60948 .59641 .61938 .5935 .61439 .58818 Mtetra
.61439 .58818 .61938 .5935 .62932 .59058 .62435 .58525 Mtetra
.62435 .58525 .62932 .59058 .63929 .58766 .63435 .5823 Mtetra
.63435 .5823 .63929 .58766 .6493 .58472 .64438 .57934 Mtetra
.64438 .57934 .6493 .58472 .65934 .58177 .65445 .57638 Mtetra
.65445 .57638 .65934 .58177 .66942 .57882 .66456 .5734 Mtetra
.66456 .5734 .66942 .57882 .67954 .57585 .6747 .57041 Mtetra
.6747 .57041 .67954 .57585 .68969 .57287 .68487 .56742 Mtetra
.68487 .56742 .68969 .57287 .69988 .56989 .69509 .56441 Mtetra
.69509 .56441 .69988 .56989 .71011 .56689 .70534 .56139 Mtetra
.70534 .56139 .71011 .56689 .72037 .56388 .71563 .55837 Mtetra
.71563 .55837 .72037 .56388 .73067 .56087 .72595 .55533 Mtetra
.72595 .55533 .73067 .56087 .741 .55784 .73632 .55228 Mtetra
.73632 .55228 .741 .55784 .75138 .5548 .74672 .54922 Mtetra
.74672 .54922 .75138 .5548 .76179 .55175 .75715 .54615 Mtetra
.75715 .54615 .76179 .55175 .77224 .54869 .76763 .54307 Mtetra
.76763 .54307 .77224 .54869 .78273 .54562 .77814 .53998 Mtetra
.77814 .53998 .78273 .54562 .79325 .54254 .7887 .53688 Mtetra
.7887 .53688 .79325 .54254 .80382 .53945 .79929 .53376 Mtetra
.79929 .53376 .80382 .53945 .81442 .53634 .80992 .53064 Mtetra
.80992 .53064 .81442 .53634 .82506 .53323 .82059 .5275 Mtetra
.82059 .5275 .82506 .53323 .83574 .5301 .8313 .52436 Mtetra
.8313 .52436 .83574 .5301 .84646 .52696 .84204 .5212 Mtetra
.84204 .5212 .84646 .52696 .85722 .52382 .85283 .51803 Mtetra
.85283 .51803 .85722 .52382 .86802 .52066 .86366 .51485 Mtetra
.86366 .51485 .86802 .52066 .87886 .51749 .87453 .51165 Mtetra
.87453 .51165 .87886 .51749 .88974 .5143 .88544 .50845 Mtetra
.88544 .50845 .88974 .5143 .90066 .51111 .89639 .50523 Mtetra
.89639 .50523 .90066 .51111 .91162 .5079 .90738 .502 Mtetra
.90738 .502 .91162 .5079 .92262 .50469 .91841 .49876 Mtetra
.91841 .49876 .92262 .50469 .93366 .50146 .92948 .49551 Mtetra
.92948 .49551 .93366 .50146 .94474 .49822 .94059 .49225 Mtetra
.94059 .49225 .94474 .49822 .95587 .49496 .95175 .48897 Mtetra
.619 .73 .926 r
.35248 .6599 .35807 .66509 .36706 .66419 .36154 .65805 Mtetra
0 0 .494 r
.36154 .65805 .36706 .66419 .37648 .65441 .37013 .66738 Mtetra
0 0 0 r
.37013 .66738 .37648 .65441 .38547 .65507 .37996 .64941 Mtetra
.611 .711 .916 r
.37996 .64941 .38547 .65507 .39461 .65293 .3891 .64778 Mtetra
.642 .74 .92 r
.3891 .64778 .39461 .65293 .4038 .65046 .3983 .64541 Mtetra
.65 .747 .92 r
.3983 .64541 .4038 .65046 .41303 .64785 .40755 .64283 Mtetra
.654 .75 .92 r
.40755 .64283 .41303 .64785 .42229 .64517 .41682 .64016 Mtetra
.656 .752 .92 r
.41682 .64016 .42229 .64517 .43158 .64243 .42614 .63743 Mtetra
.658 .753 .92 r
.42614 .63743 .43158 .64243 .44091 .63965 .43548 .63464 Mtetra
.659 .753 .92 r
.43548 .63464 .44091 .63965 .45026 .63685 .44486 .63183 Mtetra
.659 .754 .92 r
.44486 .63183 .45026 .63685 .45965 .63404 .45427 .629 Mtetra
.45427 .629 .45965 .63404 .46908 .63122 .46372 .62616 Mtetra
.46372 .62616 .46908 .63122 .47853 .62839 .47319 .62331 Mtetra
.659 .753 .92 r
.47319 .62331 .47853 .62839 .48802 .62556 .4827 .62047 Mtetra
.658 .753 .92 r
.4827 .62047 .48802 .62556 .49754 .62273 .49224 .61761 Mtetra
.49224 .61761 .49754 .62273 .50709 .6199 .50181 .61476 Mtetra
.50181 .61476 .50709 .6199 .51667 .61705 .51142 .61189 Mtetra
.51142 .61189 .51667 .61705 .52629 .6142 .52106 .60902 Mtetra
.52106 .60902 .52629 .6142 .53594 .61135 .53074 .60615 Mtetra
.53074 .60615 .53594 .61135 .54563 .60848 .54044 .60326 Mtetra
.657 .753 .92 r
.54044 .60326 .54563 .60848 .55535 .60561 .55019 .60037 Mtetra
.55019 .60037 .55535 .60561 .5651 .60273 .55996 .59747 Mtetra
.55996 .59747 .5651 .60273 .57489 .59984 .56977 .59456 Mtetra
.657 .752 .92 r
.56977 .59456 .57489 .59984 .58471 .59694 .57962 .59164 Mtetra
.57962 .59164 .58471 .59694 .59457 .59403 .5895 .58871 Mtetra
.5895 .58871 .59457 .59403 .60446 .59111 .59942 .58577 Mtetra
.59942 .58577 .60446 .59111 .61439 .58818 .60937 .58283 Mtetra
.60937 .58283 .61439 .58818 .62435 .58525 .61935 .57987 Mtetra
.61935 .57987 .62435 .58525 .63435 .5823 .62937 .5769 Mtetra
.62937 .5769 .63435 .5823 .64438 .57934 .63943 .57393 Mtetra
.63943 .57393 .64438 .57934 .65445 .57638 .64953 .57094 Mtetra
.64953 .57094 .65445 .57638 .66456 .5734 .65965 .56795 Mtetra
.65965 .56795 .66456 .5734 .6747 .57041 .66982 .56494 Mtetra
.66982 .56494 .6747 .57041 .68487 .56742 .68002 .56192 Mtetra
.68002 .56192 .68487 .56742 .69509 .56441 .69026 .5589 Mtetra
.69026 .5589 .69509 .56441 .70534 .56139 .70054 .55586 Mtetra
.70054 .55586 .70534 .56139 .71563 .55837 .71085 .55281 Mtetra
.71085 .55281 .71563 .55837 .72595 .55533 .7212 .54975 Mtetra
.7212 .54975 .72595 .55533 .73632 .55228 .73159 .54668 Mtetra
.73159 .54668 .73632 .55228 .74672 .54922 .74202 .5436 Mtetra
.74202 .5436 .74672 .54922 .75715 .54615 .75249 .54051 Mtetra
.75249 .54051 .75715 .54615 .76763 .54307 .76299 .53741 Mtetra
.76299 .53741 .76763 .54307 .77814 .53998 .77353 .5343 Mtetra
.77353 .5343 .77814 .53998 .7887 .53688 .78411 .53118 Mtetra
.78411 .53118 .7887 .53688 .79929 .53376 .79473 .52804 Mtetra
.79473 .52804 .79929 .53376 .80992 .53064 .80539 .5249 Mtetra
.80539 .5249 .80992 .53064 .82059 .5275 .81608 .52174 Mtetra
.81608 .52174 .82059 .5275 .8313 .52436 .82682 .51857 Mtetra
.82682 .51857 .8313 .52436 .84204 .5212 .8376 .51539 Mtetra
.8376 .51539 .84204 .5212 .85283 .51803 .84841 .5122 Mtetra
.84841 .5122 .85283 .51803 .86366 .51485 .85927 .50899 Mtetra
.85927 .50899 .86366 .51485 .87453 .51165 .87017 .50578 Mtetra
.87017 .50578 .87453 .51165 .88544 .50845 .88111 .50255 Mtetra
.88111 .50255 .88544 .50845 .89639 .50523 .89209 .49931 Mtetra
.89209 .49931 .89639 .50523 .90738 .502 .90311 .49606 Mtetra
.90311 .49606 .90738 .502 .91841 .49876 .91417 .4928 Mtetra
.91417 .4928 .91841 .49876 .92948 .49551 .92527 .48953 Mtetra
.92527 .48953 .92948 .49551 .94059 .49225 .93642 .48624 Mtetra
.93642 .48624 .94059 .49225 .95175 .48897 .9476 .48294 Mtetra
.633 .737 .923 r
.34686 .65476 .35248 .6599 .36154 .65805 .35594 .65261 Mtetra
.571 .706 .933 r
.35594 .65261 .36154 .65805 .37013 .66738 .36501 .65168 Mtetra
.721 .587 .705 r
.36501 .65168 .37013 .66738 .37996 .64941 .3745 .64182 Mtetra
.515 .609 .885 r
.3745 .64182 .37996 .64941 .3891 .64778 .38356 .64245 Mtetra
.633 .732 .919 r
.38356 .64245 .3891 .64778 .3983 .64541 .39277 .64028 Mtetra
.647 .744 .92 r
.39277 .64028 .3983 .64541 .40755 .64283 .40203 .63776 Mtetra
.652 .748 .92 r
.40203 .63776 .40755 .64283 .41682 .64016 .41133 .63511 Mtetra
.655 .751 .92 r
.41133 .63511 .41682 .64016 .42614 .63743 .42066 .63238 Mtetra
.657 .752 .92 r
.42066 .63238 .42614 .63743 .43548 .63464 .43003 .6296 Mtetra
.658 .753 .92 r
.43003 .6296 .43548 .63464 .44486 .63183 .43942 .62678 Mtetra
.659 .754 .92 r
.43942 .62678 .44486 .63183 .45427 .629 .44886 .62393 Mtetra
.44886 .62393 .45427 .629 .46372 .62616 .45832 .62107 Mtetra
.45832 .62107 .46372 .62616 .47319 .62331 .46782 .61821 Mtetra
.46782 .61821 .47319 .62331 .4827 .62047 .47735 .61534 Mtetra
.658 .753 .92 r
.47735 .61534 .4827 .62047 .49224 .61761 .48691 .61246 Mtetra
.48691 .61246 .49224 .61761 .50181 .61476 .49651 .60958 Mtetra
.49651 .60958 .50181 .61476 .51142 .61189 .50613 .6067 Mtetra
.50613 .6067 .51142 .61189 .52106 .60902 .5158 .60381 Mtetra
.5158 .60381 .52106 .60902 .53074 .60615 .52549 .60092 Mtetra
.52549 .60092 .53074 .60615 .54044 .60326 .53522 .59801 Mtetra
.53522 .59801 .54044 .60326 .55019 .60037 .54499 .5951 Mtetra
.657 .753 .92 r
.54499 .5951 .55019 .60037 .55996 .59747 .55479 .59218 Mtetra
.55479 .59218 .55996 .59747 .56977 .59456 .56462 .58925 Mtetra
.657 .752 .92 r
.56462 .58925 .56977 .59456 .57962 .59164 .57449 .58631 Mtetra
.57449 .58631 .57962 .59164 .5895 .58871 .5844 .58336 Mtetra
.5844 .58336 .5895 .58871 .59942 .58577 .59434 .58041 Mtetra
.59434 .58041 .59942 .58577 .60937 .58283 .60431 .57744 Mtetra
.60431 .57744 .60937 .58283 .61935 .57987 .61432 .57446 Mtetra
.61432 .57446 .61935 .57987 .62937 .5769 .62437 .57148 Mtetra
.62437 .57148 .62937 .5769 .63943 .57393 .63445 .56848 Mtetra
.63445 .56848 .63943 .57393 .64953 .57094 .64457 .56547 Mtetra
.64457 .56547 .64953 .57094 .65965 .56795 .65472 .56246 Mtetra
.65472 .56246 .65965 .56795 .66982 .56494 .66491 .55943 Mtetra
.66491 .55943 .66982 .56494 .68002 .56192 .67514 .55639 Mtetra
.67514 .55639 .68002 .56192 .69026 .5589 .68541 .55335 Mtetra
.68541 .55335 .69026 .5589 .70054 .55586 .69571 .55029 Mtetra
.69571 .55029 .70054 .55586 .71085 .55281 .70605 .54722 Mtetra
.70605 .54722 .71085 .55281 .7212 .54975 .71643 .54414 Mtetra
.71643 .54414 .7212 .54975 .73159 .54668 .72684 .54105 Mtetra
.72684 .54105 .73159 .54668 .74202 .5436 .73729 .53795 Mtetra
.73729 .53795 .74202 .5436 .75249 .54051 .74779 .53484 Mtetra
.74779 .53484 .75249 .54051 .76299 .53741 .75832 .53172 Mtetra
.75832 .53172 .76299 .53741 .77353 .5343 .76888 .52858 Mtetra
.76888 .52858 .77353 .5343 .78411 .53118 .77949 .52544 Mtetra
.77949 .52544 .78411 .53118 .79473 .52804 .79014 .52228 Mtetra
.79014 .52228 .79473 .52804 .80539 .5249 .80082 .51911 Mtetra
.80082 .51911 .80539 .5249 .81608 .52174 .81155 .51593 Mtetra
.81155 .51593 .81608 .52174 .82682 .51857 .82232 .51274 Mtetra
.82232 .51274 .82682 .51857 .8376 .51539 .83312 .50954 Mtetra
.83312 .50954 .8376 .51539 .84841 .5122 .84397 .50633 Mtetra
.84397 .50633 .84841 .5122 .85927 .50899 .85485 .5031 Mtetra
.85485 .5031 .85927 .50899 .87017 .50578 .86578 .49987 Mtetra
.86578 .49987 .87017 .50578 .88111 .50255 .87675 .49662 Mtetra
.87675 .49662 .88111 .50255 .89209 .49931 .88776 .49336 Mtetra
.88776 .49336 .89209 .49931 .90311 .49606 .89881 .49008 Mtetra
.89881 .49008 .90311 .49606 .91417 .4928 .9099 .4868 Mtetra
.9099 .4868 .91417 .4928 .92527 .48953 .92103 .4835 Mtetra
.92103 .4835 .92527 .48953 .93642 .48624 .93221 .48019 Mtetra
.93221 .48019 .93642 .48624 .9476 .48294 .94343 .47687 Mtetra
.638 .74 .922 r
.34119 .64963 .34686 .65476 .35594 .65261 .3503 .64734 Mtetra
.619 .73 .926 r
.3503 .64734 .35594 .65261 .36501 .65168 .35943 .64546 Mtetra
0 0 .501 r
.35943 .64546 .36501 .65168 .3745 .64182 .36808 .65479 Mtetra
0 0 0 r
.36808 .65479 .3745 .64182 .38356 .64245 .378 .63671 Mtetra
.611 .711 .916 r
.378 .63671 .38356 .64245 .39277 .64028 .3872 .63505 Mtetra
.642 .74 .92 r
.3872 .63505 .39277 .64028 .40203 .63776 .39648 .63263 Mtetra
.65 .747 .92 r
.39648 .63263 .40203 .63776 .41133 .63511 .4058 .63001 Mtetra
.654 .75 .92 r
.4058 .63001 .41133 .63511 .42066 .63238 .41515 .62729 Mtetra
.656 .752 .92 r
.41515 .62729 .42066 .63238 .43003 .6296 .42453 .62451 Mtetra
.658 .753 .92 r
.42453 .62451 .43003 .6296 .43942 .62678 .43395 .62169 Mtetra
.659 .753 .92 r
.43395 .62169 .43942 .62678 .44886 .62393 .4434 .61883 Mtetra
.659 .754 .92 r
.4434 .61883 .44886 .62393 .45832 .62107 .45289 .61595 Mtetra
.45289 .61595 .45832 .62107 .46782 .61821 .46241 .61306 Mtetra
.46241 .61306 .46782 .61821 .47735 .61534 .47196 .61017 Mtetra
.659 .753 .92 r
.47196 .61017 .47735 .61534 .48691 .61246 .48154 .60728 Mtetra
.658 .753 .92 r
.48154 .60728 .48691 .61246 .49651 .60958 .49116 .60438 Mtetra
.49116 .60438 .49651 .60958 .50613 .6067 .50081 .60148 Mtetra
.50081 .60148 .50613 .6067 .5158 .60381 .5105 .59857 Mtetra
.5105 .59857 .5158 .60381 .52549 .60092 .52022 .59565 Mtetra
.52022 .59565 .52549 .60092 .53522 .59801 .52997 .59273 Mtetra
.52997 .59273 .53522 .59801 .54499 .5951 .53976 .58979 Mtetra
.657 .753 .92 r
.53976 .58979 .54499 .5951 .55479 .59218 .54958 .58685 Mtetra
.54958 .58685 .55479 .59218 .56462 .58925 .55944 .5839 Mtetra
.55944 .5839 .56462 .58925 .57449 .58631 .56933 .58095 Mtetra
.657 .752 .92 r
.56933 .58095 .57449 .58631 .5844 .58336 .57926 .57798 Mtetra
.57926 .57798 .5844 .58336 .59434 .58041 .58922 .575 Mtetra
.58922 .575 .59434 .58041 .60431 .57744 .59922 .57201 Mtetra
.59922 .57201 .60431 .57744 .61432 .57446 .60925 .56902 Mtetra
.60925 .56902 .61432 .57446 .62437 .57148 .61932 .56601 Mtetra
.61932 .56601 .62437 .57148 .63445 .56848 .62943 .56299 Mtetra
.62943 .56299 .63445 .56848 .64457 .56547 .63957 .55997 Mtetra
.63957 .55997 .64457 .56547 .65472 .56246 .64975 .55693 Mtetra
.64975 .55693 .65472 .56246 .66491 .55943 .65997 .55388 Mtetra
.65997 .55388 .66491 .55943 .67514 .55639 .67022 .55083 Mtetra
.67022 .55083 .67514 .55639 .68541 .55335 .68052 .54776 Mtetra
.68052 .54776 .68541 .55335 .69571 .55029 .69084 .54468 Mtetra
.69084 .54468 .69571 .55029 .70605 .54722 .70121 .54159 Mtetra
.70121 .54159 .70605 .54722 .71643 .54414 .71161 .53849 Mtetra
.71161 .53849 .71643 .54414 .72684 .54105 .72205 .53538 Mtetra
.72205 .53538 .72684 .54105 .73729 .53795 .73254 .53226 Mtetra
.73254 .53226 .73729 .53795 .74779 .53484 .74305 .52912 Mtetra
.74305 .52912 .74779 .53484 .75832 .53172 .75361 .52598 Mtetra
.75361 .52598 .75832 .53172 .76888 .52858 .76421 .52283 Mtetra
.76421 .52283 .76888 .52858 .77949 .52544 .77484 .51966 Mtetra
.77484 .51966 .77949 .52544 .79014 .52228 .78552 .51648 Mtetra
.78552 .51648 .79014 .52228 .80082 .51911 .79623 .51329 Mtetra
.79623 .51329 .80082 .51911 .81155 .51593 .80699 .51009 Mtetra
.80699 .51009 .81155 .51593 .82232 .51274 .81778 .50688 Mtetra
.81778 .50688 .82232 .51274 .83312 .50954 .82861 .50365 Mtetra
.82861 .50365 .83312 .50954 .84397 .50633 .83949 .50042 Mtetra
.83949 .50042 .84397 .50633 .85485 .5031 .8504 .49717 Mtetra
.8504 .49717 .85485 .5031 .86578 .49987 .86136 .49391 Mtetra
.86136 .49391 .86578 .49987 .87675 .49662 .87236 .49064 Mtetra
.87236 .49064 .87675 .49662 .88776 .49336 .8834 .48736 Mtetra
.8834 .48736 .88776 .49336 .89881 .49008 .89448 .48406 Mtetra
.89448 .48406 .89881 .49008 .9099 .4868 .9056 .48075 Mtetra
.9056 .48075 .9099 .4868 .92103 .4835 .91677 .47743 Mtetra
.91677 .47743 .92103 .4835 .93221 .48019 .92797 .4741 Mtetra
.92797 .4741 .93221 .48019 .94343 .47687 .93922 .47075 Mtetra
.64 .74 .922 r
.3355 .64447 .34119 .64963 .3503 .64734 .34463 .64212 Mtetra
.633 .737 .923 r
.34463 .64212 .3503 .64734 .35943 .64546 .35378 .63993 Mtetra
.571 .706 .933 r
.35378 .63993 .35943 .64546 .36808 .65479 .36292 .63897 Mtetra
.721 .587 .705 r
.36292 .63897 .36808 .65479 .378 .63671 .37249 .62903 Mtetra
.515 .609 .885 r
.37249 .62903 .378 .63671 .3872 .63505 .38161 .62963 Mtetra
.633 .732 .919 r
.38161 .62963 .3872 .63505 .39648 .63263 .3909 .62742 Mtetra
.647 .744 .92 r
.3909 .62742 .39648 .63263 .4058 .63001 .40023 .62485 Mtetra
.652 .748 .92 r
.40023 .62485 .4058 .63001 .41515 .62729 .4096 .62216 Mtetra
.655 .751 .92 r
.4096 .62216 .41515 .62729 .42453 .62451 .419 .61939 Mtetra
.657 .752 .92 r
.419 .61939 .42453 .62451 .43395 .62169 .42844 .61656 Mtetra
.658 .753 .92 r
.42844 .61656 .43395 .62169 .4434 .61883 .43792 .61369 Mtetra
.659 .754 .92 r
.43792 .61369 .4434 .61883 .45289 .61595 .44742 .6108 Mtetra
.44742 .6108 .45289 .61595 .46241 .61306 .45696 .60789 Mtetra
.45696 .60789 .46241 .61306 .47196 .61017 .46654 .60498 Mtetra
.46654 .60498 .47196 .61017 .48154 .60728 .47614 .60206 Mtetra
.658 .753 .92 r
.47614 .60206 .48154 .60728 .49116 .60438 .48578 .59914 Mtetra
.48578 .59914 .49116 .60438 .50081 .60148 .49546 .59622 Mtetra
.49546 .59622 .50081 .60148 .5105 .59857 .50516 .59329 Mtetra
.50516 .59329 .5105 .59857 .52022 .59565 .51491 .59035 Mtetra
.51491 .59035 .52022 .59565 .52997 .59273 .52468 .58741 Mtetra
.52468 .58741 .52997 .59273 .53976 .58979 .53449 .58445 Mtetra
.53449 .58445 .53976 .58979 .54958 .58685 .54434 .58149 Mtetra
.657 .753 .92 r
.54434 .58149 .54958 .58685 .55944 .5839 .55422 .57852 Mtetra
.55422 .57852 .55944 .5839 .56933 .58095 .56414 .57554 Mtetra
.657 .752 .92 r
.56414 .57554 .56933 .58095 .57926 .57798 .57409 .57256 Mtetra
.57409 .57256 .57926 .57798 .58922 .575 .58407 .56956 Mtetra
.58407 .56956 .58922 .575 .59922 .57201 .5941 .56655 Mtetra
.5941 .56655 .59922 .57201 .60925 .56902 .60416 .56354 Mtetra
.60416 .56354 .60925 .56902 .61932 .56601 .61425 .56051 Mtetra
.61425 .56051 .61932 .56601 .62943 .56299 .62438 .55747 Mtetra
.62438 .55747 .62943 .56299 .63957 .55997 .63455 .55443 Mtetra
.63455 .55443 .63957 .55997 .64975 .55693 .64475 .55137 Mtetra
.64475 .55137 .64975 .55693 .65997 .55388 .655 .5483 Mtetra
.655 .5483 .65997 .55388 .67022 .55083 .66528 .54522 Mtetra
.66528 .54522 .67022 .55083 .68052 .54776 .67559 .54213 Mtetra
.67559 .54213 .68052 .54776 .69084 .54468 .68595 .53903 Mtetra
.68595 .53903 .69084 .54468 .70121 .54159 .69634 .53592 Mtetra
.69634 .53592 .70121 .54159 .71161 .53849 .70677 .5328 Mtetra
.70677 .5328 .71161 .53849 .72205 .53538 .71724 .52967 Mtetra
.71724 .52967 .72205 .53538 .73254 .53226 .72774 .52653 Mtetra
.72774 .52653 .73254 .53226 .74305 .52912 .73829 .52337 Mtetra
.73829 .52337 .74305 .52912 .75361 .52598 .74887 .52021 Mtetra
.74887 .52021 .75361 .52598 .76421 .52283 .7595 .51703 Mtetra
.7595 .51703 .76421 .52283 .77484 .51966 .77016 .51384 Mtetra
.77016 .51384 .77484 .51966 .78552 .51648 .78086 .51064 Mtetra
.78086 .51064 .78552 .51648 .79623 .51329 .79161 .50743 Mtetra
.79161 .50743 .79623 .51329 .80699 .51009 .80239 .50421 Mtetra
.80239 .50421 .80699 .51009 .81778 .50688 .81321 .50097 Mtetra
.81321 .50097 .81778 .50688 .82861 .50365 .82408 .49773 Mtetra
.82408 .49773 .82861 .50365 .83949 .50042 .83498 .49447 Mtetra
.83498 .49447 .83949 .50042 .8504 .49717 .84592 .4912 Mtetra
.84592 .4912 .8504 .49717 .86136 .49391 .85691 .48791 Mtetra
.85691 .48791 .86136 .49391 .87236 .49064 .86794 .48462 Mtetra
.86794 .48462 .87236 .49064 .8834 .48736 .87901 .48131 Mtetra
.87901 .48131 .8834 .48736 .89448 .48406 .89012 .47799 Mtetra
.89012 .47799 .89448 .48406 .9056 .48075 .90127 .47466 Mtetra
.90127 .47466 .9056 .48075 .91677 .47743 .91247 .47132 Mtetra
.91247 .47132 .91677 .47743 .92797 .4741 .92371 .46796 Mtetra
.92371 .46796 .92797 .4741 .93922 .47075 .93499 .46459 Mtetra
.64 .74 .921 r
.32976 .63926 .3355 .64447 .34463 .64212 .33891 .63691 Mtetra
.638 .74 .922 r
.33891 .63691 .34463 .64212 .35378 .63993 .34809 .63458 Mtetra
.619 .73 .925 r
.34809 .63458 .35378 .63993 .36292 .63897 .35729 .63266 Mtetra
0 0 .508 r
.35729 .63266 .36292 .63897 .37249 .62903 .366 .642 Mtetra
0 0 0 r
.366 .642 .37249 .62903 .38161 .62963 .376 .62381 Mtetra
.611 .711 .916 r
.376 .62381 .38161 .62963 .3909 .62742 .38528 .6221 Mtetra
.642 .74 .92 r
.38528 .6221 .3909 .62742 .40023 .62485 .39463 .61964 Mtetra
.65 .747 .92 r
.39463 .61964 .40023 .62485 .4096 .62216 .40402 .61698 Mtetra
.654 .75 .92 r
.40402 .61698 .4096 .62216 .419 .61939 .41344 .61422 Mtetra
.656 .752 .92 r
.41344 .61422 .419 .61939 .42844 .61656 .4229 .61139 Mtetra
.658 .753 .92 r
.4229 .61139 .42844 .61656 .43792 .61369 .4324 .60852 Mtetra
.659 .753 .92 r
.4324 .60852 .43792 .61369 .44742 .6108 .44192 .60561 Mtetra
.659 .754 .92 r
.44192 .60561 .44742 .6108 .45696 .60789 .45149 .60269 Mtetra
.45149 .60269 .45696 .60789 .46654 .60498 .46108 .59975 Mtetra
.46108 .59975 .46654 .60498 .47614 .60206 .47071 .59681 Mtetra
.659 .753 .92 r
.47071 .59681 .47614 .60206 .48578 .59914 .48037 .59387 Mtetra
.658 .753 .92 r
.48037 .59387 .48578 .59914 .49546 .59622 .49007 .59093 Mtetra
.49007 .59093 .49546 .59622 .50516 .59329 .4998 .58797 Mtetra
.4998 .58797 .50516 .59329 .51491 .59035 .50956 .58502 Mtetra
.50956 .58502 .51491 .59035 .52468 .58741 .51936 .58205 Mtetra
.51936 .58205 .52468 .58741 .53449 .58445 .52919 .57908 Mtetra
.52919 .57908 .53449 .58445 .54434 .58149 .53906 .5761 Mtetra
.657 .753 .92 r
.53906 .5761 .54434 .58149 .55422 .57852 .54897 .57311 Mtetra
.54897 .57311 .55422 .57852 .56414 .57554 .55891 .57011 Mtetra
.55891 .57011 .56414 .57554 .57409 .57256 .56888 .5671 Mtetra
.657 .752 .92 r
.56888 .5671 .57409 .57256 .58407 .56956 .57889 .56408 Mtetra
.57889 .56408 .58407 .56956 .5941 .56655 .58894 .56106 Mtetra
.58894 .56106 .5941 .56655 .60416 .56354 .59902 .55802 Mtetra
.59902 .55802 .60416 .56354 .61425 .56051 .60914 .55497 Mtetra
.60914 .55497 .61425 .56051 .62438 .55747 .6193 .55191 Mtetra
.6193 .55191 .62438 .55747 .63455 .55443 .62949 .54885 Mtetra
.62949 .54885 .63455 .55443 .64475 .55137 .63972 .54577 Mtetra
.63972 .54577 .64475 .55137 .655 .5483 .64999 .54268 Mtetra
.64999 .54268 .655 .5483 .66528 .54522 .66029 .53958 Mtetra
.66029 .53958 .66528 .54522 .67559 .54213 .67064 .53647 Mtetra
.67064 .53647 .67559 .54213 .68595 .53903 .68102 .53335 Mtetra
.68102 .53335 .68595 .53903 .69634 .53592 .69143 .53022 Mtetra
.69143 .53022 .69634 .53592 .70677 .5328 .70189 .52707 Mtetra
.70189 .52707 .70677 .5328 .71724 .52967 .71239 .52392 Mtetra
.71239 .52392 .71724 .52967 .72774 .52653 .72292 .52076 Mtetra
.72292 .52076 .72774 .52653 .73829 .52337 .73349 .51758 Mtetra
.73349 .51758 .73829 .52337 .74887 .52021 .7441 .51439 Mtetra
.7441 .51439 .74887 .52021 .7595 .51703 .75476 .51119 Mtetra
.75476 .51119 .7595 .51703 .77016 .51384 .76545 .50798 Mtetra
.76545 .50798 .77016 .51384 .78086 .51064 .77618 .50476 Mtetra
.77618 .50476 .78086 .51064 .79161 .50743 .78695 .50153 Mtetra
.78695 .50153 .79161 .50743 .80239 .50421 .79776 .49828 Mtetra
.79776 .49828 .80239 .50421 .81321 .50097 .80861 .49503 Mtetra
.80861 .49503 .81321 .50097 .82408 .49773 .81951 .49176 Mtetra
.81951 .49176 .82408 .49773 .83498 .49447 .83044 .48848 Mtetra
.83044 .48848 .83498 .49447 .84592 .4912 .84141 .48518 Mtetra
.84141 .48518 .84592 .4912 .85691 .48791 .85243 .48188 Mtetra
.85243 .48188 .85691 .48791 .86794 .48462 .86349 .47856 Mtetra
.86349 .47856 .86794 .48462 .87901 .48131 .87459 .47523 Mtetra
.87459 .47523 .87901 .48131 .89012 .47799 .88573 .47189 Mtetra
.88573 .47189 .89012 .47799 .90127 .47466 .89691 .46853 Mtetra
.89691 .46853 .90127 .47466 .91247 .47132 .90814 .46516 Mtetra
.90814 .46516 .91247 .47132 .92371 .46796 .91941 .46178 Mtetra
.91941 .46178 .92371 .46796 .93499 .46459 .93072 .45839 Mtetra
.638 .738 .921 r
.324 .63399 .32976 .63926 .33891 .63691 .33316 .63166 Mtetra
.64 .74 .922 r
.33316 .63166 .33891 .63691 .34809 .63458 .34236 .62928 Mtetra
.633 .737 .923 r
.34236 .62928 .34809 .63458 .35729 .63266 .35159 .62705 Mtetra
.571 .706 .933 r
.35159 .62705 .35729 .63266 .366 .642 .36079 .62604 Mtetra
.721 .587 .705 r
.36079 .62604 .366 .642 .376 .62381 .37044 .61603 Mtetra
.514 .609 .885 r
.37044 .61603 .376 .62381 .38528 .6221 .37963 .6166 Mtetra
.633 .732 .919 r
.37963 .6166 .38528 .6221 .39463 .61964 .38899 .61434 Mtetra
.647 .744 .92 r
.38899 .61434 .39463 .61964 .40402 .61698 .3984 .61174 Mtetra
.652 .748 .92 r
.3984 .61174 .40402 .61698 .41344 .61422 .40784 .609 Mtetra
.655 .751 .92 r
.40784 .609 .41344 .61422 .4229 .61139 .41732 .60618 Mtetra
.657 .752 .92 r
.41732 .60618 .4229 .61139 .4324 .60852 .42684 .6033 Mtetra
.658 .753 .92 r
.42684 .6033 .4324 .60852 .44192 .60561 .43639 .60039 Mtetra
.659 .754 .92 r
.43639 .60039 .44192 .60561 .45149 .60269 .44597 .59745 Mtetra
.44597 .59745 .45149 .60269 .46108 .59975 .45559 .59449 Mtetra
.45559 .59449 .46108 .59975 .47071 .59681 .46524 .59153 Mtetra
.46524 .59153 .47071 .59681 .48037 .59387 .47492 .58857 Mtetra
.658 .753 .92 r
.47492 .58857 .48037 .59387 .49007 .59093 .48464 .5856 Mtetra
.48464 .5856 .49007 .59093 .4998 .58797 .49439 .58263 Mtetra
.49439 .58263 .4998 .58797 .50956 .58502 .50418 .57965 Mtetra
.50418 .57965 .50956 .58502 .51936 .58205 .514 .57666 Mtetra
.514 .57666 .51936 .58205 .52919 .57908 .52386 .57367 Mtetra
.52386 .57367 .52919 .57908 .53906 .5761 .53375 .57067 Mtetra
.53375 .57067 .53906 .5761 .54897 .57311 .54368 .56766 Mtetra
.657 .753 .92 r
.54368 .56766 .54897 .57311 .55891 .57011 .55364 .56464 Mtetra
.55364 .56464 .55891 .57011 .56888 .5671 .56364 .56161 Mtetra
.657 .752 .92 r
.56364 .56161 .56888 .5671 .57889 .56408 .57367 .55857 Mtetra
.57367 .55857 .57889 .56408 .58894 .56106 .58375 .55552 Mtetra
.58375 .55552 .58894 .56106 .59902 .55802 .59385 .55246 Mtetra
.59385 .55246 .59902 .55802 .60914 .55497 .604 .5494 Mtetra
.604 .5494 .60914 .55497 .6193 .55191 .61418 .54632 Mtetra
.61418 .54632 .6193 .55191 .62949 .54885 .6244 .54323 Mtetra
.6244 .54323 .62949 .54885 .63972 .54577 .63465 .54013 Mtetra
.63465 .54013 .63972 .54577 .64999 .54268 .64495 .53702 Mtetra
.64495 .53702 .64999 .54268 .66029 .53958 .65528 .5339 Mtetra
.65528 .5339 .66029 .53958 .67064 .53647 .66564 .53077 Mtetra
.66564 .53077 .67064 .53647 .68102 .53335 .67605 .52763 Mtetra
.67605 .52763 .68102 .53335 .69143 .53022 .6865 .52447 Mtetra
.6865 .52447 .69143 .53022 .70189 .52707 .69698 .52131 Mtetra
.69698 .52131 .70189 .52707 .71239 .52392 .7075 .51813 Mtetra
.7075 .51813 .71239 .52392 .72292 .52076 .71806 .51495 Mtetra
.71806 .51495 .72292 .52076 .73349 .51758 .72866 .51175 Mtetra
.72866 .51175 .73349 .51758 .7441 .51439 .7393 .50854 Mtetra
.7393 .50854 .7441 .51439 .75476 .51119 .74998 .50532 Mtetra
.74998 .50532 .75476 .51119 .76545 .50798 .7607 .50209 Mtetra
.7607 .50209 .76545 .50798 .77618 .50476 .77146 .49884 Mtetra
.77146 .49884 .77618 .50476 .78695 .50153 .78226 .49558 Mtetra
.78226 .49558 .78695 .50153 .79776 .49828 .7931 .49232 Mtetra
.7931 .49232 .79776 .49828 .80861 .49503 .80398 .48904 Mtetra
.80398 .48904 .80861 .49503 .81951 .49176 .8149 .48574 Mtetra
.8149 .48574 .81951 .49176 .83044 .48848 .82587 .48244 Mtetra
.82587 .48244 .83044 .48848 .84141 .48518 .83687 .47912 Mtetra
.83687 .47912 .84141 .48518 .85243 .48188 .84792 .4758 Mtetra
.84792 .4758 .85243 .48188 .86349 .47856 .85901 .47246 Mtetra
.85901 .47246 .86349 .47856 .87459 .47523 .87014 .4691 Mtetra
.87014 .4691 .87459 .47523 .88573 .47189 .88131 .46574 Mtetra
.88131 .46574 .88573 .47189 .89691 .46853 .89252 .46236 Mtetra
.89252 .46236 .89691 .46853 .90814 .46516 .90378 .45897 Mtetra
.90378 .45897 .90814 .46516 .91941 .46178 .91509 .45556 Mtetra
.91509 .45556 .91941 .46178 .93072 .45839 .92643 .45215 Mtetra
.633 .734 .921 r
.3182 .6286 .324 .63399 .33316 .63166 .32737 .62638 Mtetra
.64 .74 .921 r
.32737 .62638 .33316 .63166 .34236 .62928 .33659 .62398 Mtetra
.638 .74 .922 r
.33659 .62398 .34236 .62928 .35159 .62705 .34584 .62161 Mtetra
.619 .73 .925 r
.34584 .62161 .35159 .62705 .36079 .62604 .35511 .61965 Mtetra
0 0 .516 r
.35511 .61965 .36079 .62604 .37044 .61603 .36388 .62899 Mtetra
0 0 0 r
.36388 .62899 .37044 .61603 .37963 .6166 .37397 .61069 Mtetra
.611 .711 .916 r
.37397 .61069 .37963 .6166 .38899 .61434 .38332 .60894 Mtetra
.642 .74 .92 r
.38332 .60894 .38899 .61434 .3984 .61174 .39274 .60643 Mtetra
.65 .747 .92 r
.39274 .60643 .3984 .61174 .40784 .609 .40221 .60373 Mtetra
.654 .75 .92 r
.40221 .60373 .40784 .609 .41732 .60618 .41171 .60092 Mtetra
.656 .752 .92 r
.41171 .60092 .41732 .60618 .42684 .6033 .42124 .59805 Mtetra
.658 .753 .92 r
.42124 .59805 .42684 .6033 .43639 .60039 .43081 .59513 Mtetra
.659 .753 .92 r
.43081 .59513 .43639 .60039 .44597 .59745 .44042 .59217 Mtetra
.659 .754 .92 r
.44042 .59217 .44597 .59745 .45559 .59449 .45006 .5892 Mtetra
.45006 .5892 .45559 .59449 .46524 .59153 .45973 .58622 Mtetra
.45973 .58622 .46524 .59153 .47492 .58857 .46944 .58323 Mtetra
.659 .753 .92 r
.46944 .58323 .47492 .58857 .48464 .5856 .47918 .58024 Mtetra
.658 .753 .92 r
.47918 .58024 .48464 .5856 .49439 .58263 .48895 .57725 Mtetra
.48895 .57725 .49439 .58263 .50418 .57965 .49876 .57425 Mtetra
.49876 .57425 .50418 .57965 .514 .57666 .50861 .57124 Mtetra
.50861 .57124 .514 .57666 .52386 .57367 .51849 .56822 Mtetra
.51849 .56822 .52386 .57367 .53375 .57067 .5284 .5652 Mtetra
.5284 .5652 .53375 .57067 .54368 .56766 .53835 .56217 Mtetra
.657 .753 .92 r
.53835 .56217 .54368 .56766 .55364 .56464 .54834 .55913 Mtetra
.54834 .55913 .55364 .56464 .56364 .56161 .55836 .55608 Mtetra
.55836 .55608 .56364 .56161 .57367 .55857 .56842 .55302 Mtetra
.657 .752 .92 r
.56842 .55302 .57367 .55857 .58375 .55552 .57852 .54995 Mtetra
.57852 .54995 .58375 .55552 .59385 .55246 .58865 .54687 Mtetra
.58865 .54687 .59385 .55246 .604 .5494 .59882 .54378 Mtetra
.59882 .54378 .604 .5494 .61418 .54632 .60903 .54068 Mtetra
.60903 .54068 .61418 .54632 .6244 .54323 .61927 .53757 Mtetra
.61927 .53757 .6244 .54323 .63465 .54013 .62955 .53445 Mtetra
.62955 .53445 .63465 .54013 .64495 .53702 .63987 .53132 Mtetra
.63987 .53132 .64495 .53702 .65528 .5339 .65023 .52818 Mtetra
.65023 .52818 .65528 .5339 .66564 .53077 .66062 .52503 Mtetra
.66062 .52503 .66564 .53077 .67605 .52763 .67105 .52186 Mtetra
.67105 .52186 .67605 .52763 .6865 .52447 .68152 .51869 Mtetra
.68152 .51869 .6865 .52447 .69698 .52131 .69203 .5155 Mtetra
.69203 .5155 .69698 .52131 .7075 .51813 .70258 .51231 Mtetra
.70258 .51231 .7075 .51813 .71806 .51495 .71317 .5091 Mtetra
.71317 .5091 .71806 .51495 .72866 .51175 .7238 .50588 Mtetra
.7238 .50588 .72866 .51175 .7393 .50854 .73447 .50264 Mtetra
.73447 .50264 .7393 .50854 .74998 .50532 .74517 .4994 Mtetra
.74517 .4994 .74998 .50532 .7607 .50209 .75592 .49615 Mtetra
.75592 .49615 .7607 .50209 .77146 .49884 .76671 .49288 Mtetra
.76671 .49288 .77146 .49884 .78226 .49558 .77754 .4896 Mtetra
.77754 .4896 .78226 .49558 .7931 .49232 .78841 .48631 Mtetra
.78841 .48631 .7931 .49232 .80398 .48904 .79932 .48301 Mtetra
.79932 .48301 .80398 .48904 .8149 .48574 .81027 .47969 Mtetra
.81027 .47969 .8149 .48574 .82587 .48244 .82126 .47636 Mtetra
.82126 .47636 .82587 .48244 .83687 .47912 .8323 .47302 Mtetra
.8323 .47302 .83687 .47912 .84792 .4758 .84337 .46967 Mtetra
.84337 .46967 .84792 .4758 .85901 .47246 .85449 .46631 Mtetra
.85449 .46631 .85901 .47246 .87014 .4691 .86565 .46293 Mtetra
.86565 .46293 .87014 .4691 .88131 .46574 .87686 .45954 Mtetra
.87686 .45954 .88131 .46574 .89252 .46236 .8881 .45614 Mtetra
.8881 .45614 .89252 .46236 .90378 .45897 .89939 .45272 Mtetra
.89939 .45272 .90378 .45897 .91509 .45556 .91073 .4493 Mtetra
.91073 .4493 .91509 .45556 .92643 .45215 .9221 .44585 Mtetra
.621 .723 .92 r
.31238 .623 .3182 .6286 .32737 .62638 .32155 .62102 Mtetra
.638 .738 .921 r
.32155 .62102 .32737 .62638 .33659 .62398 .33079 .61865 Mtetra
.64 .74 .922 r
.33079 .61865 .33659 .62398 .34584 .62161 .34006 .61623 Mtetra
.633 .737 .923 r
.34006 .61623 .34584 .62161 .35511 .61965 .34936 .61395 Mtetra
.571 .706 .933 r
.34936 .61395 .35511 .61965 .36388 .62899 .35863 .61291 Mtetra
.721 .587 .705 r
.35863 .61291 .36388 .62899 .37397 .61069 .36836 .60282 Mtetra
.514 .609 .885 r
.36836 .60282 .37397 .61069 .38332 .60894 .37762 .60336 Mtetra
.633 .732 .919 r
.37762 .60336 .38332 .60894 .39274 .60643 .38706 .60105 Mtetra
.647 .744 .92 r
.38706 .60105 .39274 .60643 .40221 .60373 .39654 .5984 Mtetra
.652 .748 .92 r
.39654 .5984 .40221 .60373 .41171 .60092 .40606 .59561 Mtetra
.655 .751 .92 r
.40606 .59561 .41171 .60092 .42124 .59805 .41561 .59275 Mtetra
.657 .752 .92 r
.41561 .59275 .42124 .59805 .43081 .59513 .4252 .58982 Mtetra
.658 .753 .92 r
.4252 .58982 .43081 .59513 .44042 .59217 .43483 .58686 Mtetra
.659 .754 .92 r
.43483 .58686 .44042 .59217 .45006 .5892 .44449 .58387 Mtetra
.44449 .58387 .45006 .5892 .45973 .58622 .45419 .58087 Mtetra
.45419 .58087 .45973 .58622 .46944 .58323 .46391 .57786 Mtetra
.46391 .57786 .46944 .58323 .47918 .58024 .47368 .57485 Mtetra
.658 .753 .92 r
.47368 .57485 .47918 .58024 .48895 .57725 .48348 .57183 Mtetra
.48348 .57183 .48895 .57725 .49876 .57425 .49331 .56881 Mtetra
.49331 .56881 .49876 .57425 .50861 .57124 .50318 .56578 Mtetra
.50318 .56578 .50861 .57124 .51849 .56822 .51308 .56274 Mtetra
.51308 .56274 .51849 .56822 .5284 .5652 .52302 .5597 Mtetra
.52302 .5597 .5284 .5652 .53835 .56217 .53299 .55665 Mtetra
.53299 .55665 .53835 .56217 .54834 .55913 .543 .55358 Mtetra
.657 .753 .92 r
.543 .55358 .54834 .55913 .55836 .55608 .55305 .55051 Mtetra
.55305 .55051 .55836 .55608 .56842 .55302 .56314 .54743 Mtetra
.657 .752 .92 r
.56314 .54743 .56842 .55302 .57852 .54995 .57326 .54434 Mtetra
.57326 .54434 .57852 .54995 .58865 .54687 .58341 .54124 Mtetra
.58341 .54124 .58865 .54687 .59882 .54378 .59361 .53813 Mtetra
.59361 .53813 .59882 .54378 .60903 .54068 .60384 .53501 Mtetra
.60384 .53501 .60903 .54068 .61927 .53757 .61411 .53188 Mtetra
.61411 .53188 .61927 .53757 .62955 .53445 .62441 .52874 Mtetra
.62441 .52874 .62955 .53445 .63987 .53132 .63476 .52559 Mtetra
.63476 .52559 .63987 .53132 .65023 .52818 .64514 .52242 Mtetra
.64514 .52242 .65023 .52818 .66062 .52503 .65556 .51925 Mtetra
.65556 .51925 .66062 .52503 .67105 .52186 .66602 .51606 Mtetra
.66602 .51606 .67105 .52186 .68152 .51869 .67652 .51286 Mtetra
.67652 .51286 .68152 .51869 .69203 .5155 .68706 .50966 Mtetra
.68706 .50966 .69203 .5155 .70258 .51231 .69763 .50644 Mtetra
.69763 .50644 .70258 .51231 .71317 .5091 .70825 .50321 Mtetra
.70825 .50321 .71317 .5091 .7238 .50588 .7189 .49996 Mtetra
.7189 .49996 .7238 .50588 .73447 .50264 .7296 .49671 Mtetra
.7296 .49671 .73447 .50264 .74517 .4994 .74033 .49344 Mtetra
.74033 .49344 .74517 .4994 .75592 .49615 .75111 .49017 Mtetra
.75111 .49017 .75592 .49615 .76671 .49288 .76193 .48688 Mtetra
.76193 .48688 .76671 .49288 .77754 .4896 .77278 .48357 Mtetra
.77278 .48357 .77754 .4896 .78841 .48631 .78368 .48026 Mtetra
.78368 .48026 .78841 .48631 .79932 .48301 .79462 .47693 Mtetra
.79462 .47693 .79932 .48301 .81027 .47969 .8056 .4736 Mtetra
.8056 .4736 .81027 .47969 .82126 .47636 .81662 .47024 Mtetra
.81662 .47024 .82126 .47636 .8323 .47302 .82769 .46688 Mtetra
.82769 .46688 .8323 .47302 .84337 .46967 .8388 .46351 Mtetra
.8388 .46351 .84337 .46967 .85449 .46631 .84995 .46012 Mtetra
.84995 .46012 .85449 .46631 .86565 .46293 .86114 .45672 Mtetra
.86114 .45672 .86565 .46293 .87686 .45954 .87237 .4533 Mtetra
.87237 .4533 .87686 .45954 .8881 .45614 .88365 .44988 Mtetra
.88365 .44988 .8881 .45614 .89939 .45272 .89497 .44644 Mtetra
.89497 .44644 .89939 .45272 .91073 .4493 .90634 .44298 Mtetra
.90634 .44298 .91073 .4493 .9221 .44585 .91775 .43952 Mtetra
.586 .691 .914 r
.30656 .61676 .31238 .623 .32155 .62102 .3157 .61555 Mtetra
.633 .734 .921 r
.3157 .61555 .32155 .62102 .33079 .61865 .32494 .61328 Mtetra
.64 .74 .921 r
.32494 .61328 .33079 .61865 .34006 .61623 .33423 .61084 Mtetra
.638 .74 .922 r
.33423 .61084 .34006 .61623 .34936 .61395 .34356 .60843 Mtetra
.619 .73 .925 r
.34356 .60843 .34936 .61395 .35863 .61291 .35289 .60642 Mtetra
0 .001 .523 r
.35289 .60642 .35863 .61291 .36836 .60282 .36173 .61577 Mtetra
0 0 0 r
.36173 .61577 .36836 .60282 .37762 .60336 .37191 .59735 Mtetra
.61 .711 .916 r
.37191 .59735 .37762 .60336 .38706 .60105 .38133 .59556 Mtetra
.642 .74 .92 r
.38133 .59556 .38706 .60105 .39654 .5984 .39083 .59301 Mtetra
.65 .747 .92 r
.39083 .59301 .39654 .5984 .40606 .59561 .40037 .59026 Mtetra
.654 .75 .92 r
.40037 .59026 .40606 .59561 .41561 .59275 .40994 .5874 Mtetra
.656 .752 .92 r
.40994 .5874 .41561 .59275 .4252 .58982 .41956 .58448 Mtetra
.658 .753 .92 r
.41956 .58448 .4252 .58982 .43483 .58686 .4292 .58151 Mtetra
.659 .753 .92 r
.4292 .58151 .43483 .58686 .44449 .58387 .43889 .57851 Mtetra
.659 .754 .92 r
.43889 .57851 .44449 .58387 .45419 .58087 .4486 .57549 Mtetra
.4486 .57549 .45419 .58087 .46391 .57786 .45836 .57246 Mtetra
.45836 .57246 .46391 .57786 .47368 .57485 .46814 .56942 Mtetra
.659 .753 .92 r
.46814 .56942 .47368 .57485 .48348 .57183 .47796 .56638 Mtetra
.658 .753 .92 r
.47796 .56638 .48348 .57183 .49331 .56881 .48782 .56333 Mtetra
.48782 .56333 .49331 .56881 .50318 .56578 .49771 .56028 Mtetra
.49771 .56028 .50318 .56578 .51308 .56274 .50764 .55722 Mtetra
.50764 .55722 .51308 .56274 .52302 .5597 .5176 .55416 Mtetra
.5176 .55416 .52302 .5597 .53299 .55665 .5276 .55109 Mtetra
.5276 .55109 .53299 .55665 .543 .55358 .53763 .548 Mtetra
.657 .753 .92 r
.53763 .548 .543 .55358 .55305 .55051 .5477 .54491 Mtetra
.5477 .54491 .55305 .55051 .56314 .54743 .55781 .54181 Mtetra
.55781 .54181 .56314 .54743 .57326 .54434 .56796 .5387 Mtetra
.657 .752 .92 r
.56796 .5387 .57326 .54434 .58341 .54124 .57814 .53558 Mtetra
.57814 .53558 .58341 .54124 .59361 .53813 .58836 .53244 Mtetra
.58836 .53244 .59361 .53813 .60384 .53501 .59861 .5293 Mtetra
.59861 .5293 .60384 .53501 .61411 .53188 .60891 .52615 Mtetra
.60891 .52615 .61411 .53188 .62441 .52874 .61924 .52298 Mtetra
.61924 .52298 .62441 .52874 .63476 .52559 .62961 .51981 Mtetra
.62961 .51981 .63476 .52559 .64514 .52242 .64002 .51662 Mtetra
.64002 .51662 .64514 .52242 .65556 .51925 .65047 .51343 Mtetra
.65047 .51343 .65556 .51925 .66602 .51606 .66095 .51022 Mtetra
.66095 .51022 .66602 .51606 .67652 .51286 .67148 .507 Mtetra
.67148 .507 .67652 .51286 .68706 .50966 .68204 .50377 Mtetra
.68204 .50377 .68706 .50966 .69763 .50644 .69265 .50053 Mtetra
.69265 .50053 .69763 .50644 .70825 .50321 .70329 .49728 Mtetra
.70329 .49728 .70825 .50321 .7189 .49996 .71397 .49401 Mtetra
.71397 .49401 .7189 .49996 .7296 .49671 .7247 .49073 Mtetra
.7247 .49073 .7296 .49671 .74033 .49344 .73546 .48744 Mtetra
.73546 .48744 .74033 .49344 .75111 .49017 .74626 .48414 Mtetra
.74626 .48414 .75111 .49017 .76193 .48688 .75711 .48083 Mtetra
.75711 .48083 .76193 .48688 .77278 .48357 .76799 .47751 Mtetra
.76799 .47751 .77278 .48357 .78368 .48026 .77892 .47417 Mtetra
.77892 .47417 .78368 .48026 .79462 .47693 .78989 .47082 Mtetra
.78989 .47082 .79462 .47693 .8056 .4736 .8009 .46746 Mtetra
.8009 .46746 .8056 .4736 .81662 .47024 .81195 .46408 Mtetra
.81195 .46408 .81662 .47024 .82769 .46688 .82305 .4607 Mtetra
.82305 .4607 .82769 .46688 .8388 .46351 .83419 .4573 Mtetra
.83419 .4573 .8388 .46351 .84995 .46012 .84537 .45388 Mtetra
.84537 .45388 .84995 .46012 .86114 .45672 .85659 .45046 Mtetra
.85659 .45046 .86114 .45672 .87237 .4533 .86786 .44702 Mtetra
.86786 .44702 .87237 .4533 .88365 .44988 .87917 .44357 Mtetra
.87917 .44357 .88365 .44988 .89497 .44644 .89052 .4401 Mtetra
.89052 .4401 .89497 .44644 .90634 .44298 .90192 .43663 Mtetra
.90192 .43663 .90634 .44298 .91775 .43952 .91336 .43314 Mtetra
.357 .442 .811 r
.30103 .60545 .30656 .61676 .3157 .61555 .30982 .60986 Mtetra
.621 .723 .92 r
.30982 .60986 .3157 .61555 .32494 .61328 .31907 .60784 Mtetra
.638 .738 .921 r
.31907 .60784 .32494 .61328 .33423 .61084 .32837 .60543 Mtetra
.64 .74 .922 r
.32837 .60543 .33423 .61084 .34356 .60843 .33772 .60296 Mtetra
.633 .737 .923 r
.33772 .60296 .34356 .60843 .35289 .60642 .34709 .60063 Mtetra
.571 .706 .933 r
.34709 .60063 .35289 .60642 .36173 .61577 .35643 .59955 Mtetra
.721 .587 .705 r
.35643 .59955 .36173 .61577 .37191 .59735 .36624 .58939 Mtetra
.513 .609 .886 r
.36624 .58939 .37191 .59735 .38133 .59556 .37558 .58989 Mtetra
.633 .732 .919 r
.37558 .58989 .38133 .59556 .39083 .59301 .38509 .58754 Mtetra
.647 .744 .92 r
.38509 .58754 .39083 .59301 .40037 .59026 .39464 .58484 Mtetra
.652 .748 .92 r
.39464 .58484 .40037 .59026 .40994 .5874 .40424 .58201 Mtetra
.655 .751 .92 r
.40424 .58201 .40994 .5874 .41956 .58448 .41387 .57909 Mtetra
.657 .752 .92 r
.41387 .57909 .41956 .58448 .4292 .58151 .42354 .57612 Mtetra
.658 .753 .92 r
.42354 .57612 .4292 .58151 .43889 .57851 .43325 .57311 Mtetra
.659 .754 .92 r
.43325 .57311 .43889 .57851 .4486 .57549 .44299 .57007 Mtetra
.44299 .57007 .4486 .57549 .45836 .57246 .45276 .56702 Mtetra
.45276 .56702 .45836 .57246 .46814 .56942 .46257 .56396 Mtetra
.46257 .56396 .46814 .56942 .47796 .56638 .47241 .56089 Mtetra
.658 .753 .92 r
.47241 .56089 .47796 .56638 .48782 .56333 .48229 .55783 Mtetra
.48229 .55783 .48782 .56333 .49771 .56028 .49221 .55475 Mtetra
.49221 .55475 .49771 .56028 .50764 .55722 .50216 .55167 Mtetra
.50216 .55167 .50764 .55722 .5176 .55416 .51214 .54858 Mtetra
.51214 .54858 .5176 .55416 .5276 .55109 .52217 .54549 Mtetra
.52217 .54549 .5276 .55109 .53763 .548 .53223 .54238 Mtetra
.53223 .54238 .53763 .548 .5477 .54491 .54232 .53927 Mtetra
.657 .753 .92 r
.54232 .53927 .5477 .54491 .55781 .54181 .55245 .53615 Mtetra
.55245 .53615 .55781 .54181 .56796 .5387 .56262 .53301 Mtetra
.657 .752 .92 r
.56262 .53301 .56796 .5387 .57814 .53558 .57283 .52987 Mtetra
.57283 .52987 .57814 .53558 .58836 .53244 .58307 .52672 Mtetra
.58307 .52672 .58836 .53244 .59861 .5293 .59336 .52355 Mtetra
.59336 .52355 .59861 .5293 .60891 .52615 .60367 .52038 Mtetra
.60367 .52038 .60891 .52615 .61924 .52298 .61403 .51719 Mtetra
.61403 .51719 .61924 .52298 .62961 .51981 .62443 .51399 Mtetra
.62443 .51399 .62961 .51981 .64002 .51662 .63486 .51079 Mtetra
.63486 .51079 .64002 .51662 .65047 .51343 .64534 .50757 Mtetra
.64534 .50757 .65047 .51343 .66095 .51022 .65585 .50434 Mtetra
.65585 .50434 .66095 .51022 .67148 .507 .6664 .5011 Mtetra
.6664 .5011 .67148 .507 .68204 .50377 .67699 .49784 Mtetra
.67699 .49784 .68204 .50377 .69265 .50053 .68762 .49458 Mtetra
.68762 .49458 .69265 .50053 .70329 .49728 .6983 .4913 Mtetra
.6983 .4913 .70329 .49728 .71397 .49401 .70901 .48802 Mtetra
.70901 .48802 .71397 .49401 .7247 .49073 .71976 .48472 Mtetra
.71976 .48472 .7247 .49073 .73546 .48744 .73055 .4814 Mtetra
.73055 .4814 .73546 .48744 .74626 .48414 .74138 .47808 Mtetra
.74138 .47808 .74626 .48414 .75711 .48083 .75226 .47474 Mtetra
.75226 .47474 .75711 .48083 .76799 .47751 .76317 .47139 Mtetra
.76317 .47139 .76799 .47751 .77892 .47417 .77413 .46803 Mtetra
.77413 .46803 .77892 .47417 .78989 .47082 .78513 .46466 Mtetra
.78513 .46466 .78989 .47082 .8009 .46746 .79617 .46127 Mtetra
.79617 .46127 .8009 .46746 .81195 .46408 .80725 .45788 Mtetra
.80725 .45788 .81195 .46408 .82305 .4607 .81838 .45446 Mtetra
.81838 .45446 .82305 .4607 .83419 .4573 .82955 .45104 Mtetra
.82955 .45104 .83419 .4573 .84537 .45388 .84076 .4476 Mtetra
.84076 .4476 .84537 .45388 .85659 .45046 .85201 .44415 Mtetra
.85201 .44415 .85659 .45046 .86786 .44702 .86331 .44069 Mtetra
.86331 .44069 .86786 .44702 .87917 .44357 .87465 .43722 Mtetra
.87465 .43722 .87917 .44357 .89052 .4401 .88604 .43373 Mtetra
.88604 .43373 .89052 .4401 .90192 .43663 .89747 .43022 Mtetra
.89747 .43022 .90192 .43663 .91336 .43314 .90894 .42671 Mtetra
0 0 0 r
.29413 .61439 .30103 .60545 .30982 .60986 .30394 .60353 Mtetra
.586 .691 .914 r
.30394 .60353 .30982 .60986 .31907 .60784 .31316 .60228 Mtetra
.633 .734 .921 r
.31316 .60228 .31907 .60784 .32837 .60543 .32247 .59997 Mtetra
.64 .74 .921 r
.32247 .59997 .32837 .60543 .33772 .60296 .33184 .59748 Mtetra
.638 .74 .922 r
.33184 .59748 .33772 .60296 .34709 .60063 .34123 .59502 Mtetra
.619 .73 .925 r
.34123 .59502 .34709 .60063 .35643 .59955 .35064 .59297 Mtetra
0 .007 .53 r
.35064 .59297 .35643 .59955 .36624 .58939 .35954 .60233 Mtetra
0 0 0 r
.35954 .60233 .36624 .58939 .37558 .58989 .36981 .5838 Mtetra
.61 .711 .916 r
.36981 .5838 .37558 .58989 .38509 .58754 .37931 .58196 Mtetra
.642 .74 .92 r
.37931 .58196 .38509 .58754 .39464 .58484 .38888 .57936 Mtetra
.65 .747 .92 r
.38888 .57936 .39464 .58484 .40424 .58201 .3985 .57656 Mtetra
.654 .75 .92 r
.3985 .57656 .40424 .58201 .41387 .57909 .40815 .57366 Mtetra
.656 .752 .92 r
.40815 .57366 .41387 .57909 .42354 .57612 .41784 .57069 Mtetra
.658 .753 .92 r
.41784 .57069 .42354 .57612 .43325 .57311 .42757 .56767 Mtetra
.659 .753 .92 r
.42757 .56767 .43325 .57311 .44299 .57007 .43733 .56462 Mtetra
.659 .754 .92 r
.43733 .56462 .44299 .57007 .45276 .56702 .44713 .56154 Mtetra
.44713 .56154 .45276 .56702 .46257 .56396 .45696 .55846 Mtetra
.45696 .55846 .46257 .56396 .47241 .56089 .46683 .55537 Mtetra
.659 .753 .92 r
.46683 .55537 .47241 .56089 .48229 .55783 .47673 .55228 Mtetra
.658 .753 .92 r
.47673 .55228 .48229 .55783 .49221 .55475 .48667 .54918 Mtetra
.48667 .54918 .49221 .55475 .50216 .55167 .49664 .54608 Mtetra
.49664 .54608 .50216 .55167 .51214 .54858 .50665 .54297 Mtetra
.50665 .54297 .51214 .54858 .52217 .54549 .5167 .53985 Mtetra
.5167 .53985 .52217 .54549 .53223 .54238 .52678 .53673 Mtetra
.52678 .53673 .53223 .54238 .54232 .53927 .5369 .53359 Mtetra
.657 .753 .92 r
.5369 .53359 .54232 .53927 .55245 .53615 .54706 .53045 Mtetra
.54706 .53045 .55245 .53615 .56262 .53301 .55725 .52729 Mtetra
.55725 .52729 .56262 .53301 .57283 .52987 .56748 .52412 Mtetra
.657 .752 .92 r
.56748 .52412 .57283 .52987 .58307 .52672 .57775 .52095 Mtetra
.57775 .52095 .58307 .52672 .59336 .52355 .58806 .51776 Mtetra
.58806 .51776 .59336 .52355 .60367 .52038 .59841 .51457 Mtetra
.59841 .51457 .60367 .52038 .61403 .51719 .60879 .51136 Mtetra
.60879 .51136 .61403 .51719 .62443 .51399 .61921 .50814 Mtetra
.61921 .50814 .62443 .51399 .63486 .51079 .62967 .50491 Mtetra
.62967 .50491 .63486 .51079 .64534 .50757 .64017 .50167 Mtetra
.64017 .50167 .64534 .50757 .65585 .50434 .65071 .49842 Mtetra
.65071 .49842 .65585 .50434 .6664 .5011 .66129 .49515 Mtetra
.66129 .49515 .6664 .5011 .67699 .49784 .67191 .49188 Mtetra
.67191 .49188 .67699 .49784 .68762 .49458 .68257 .48859 Mtetra
.68257 .48859 .68762 .49458 .6983 .4913 .69327 .48529 Mtetra
.69327 .48529 .6983 .4913 .70901 .48802 .70401 .48198 Mtetra
.70401 .48198 .70901 .48802 .71976 .48472 .71479 .47866 Mtetra
.71479 .47866 .71976 .48472 .73055 .4814 .72561 .47532 Mtetra
.72561 .47532 .73055 .4814 .74138 .47808 .73647 .47197 Mtetra
.73647 .47197 .74138 .47808 .75226 .47474 .74737 .46861 Mtetra
.74737 .46861 .75226 .47474 .76317 .47139 .75832 .46524 Mtetra
.75832 .46524 .76317 .47139 .77413 .46803 .7693 .46186 Mtetra
.7693 .46186 .77413 .46803 .78513 .46466 .78033 .45846 Mtetra
.78033 .45846 .78513 .46466 .79617 .46127 .7914 .45505 Mtetra
.7914 .45505 .79617 .46127 .80725 .45788 .80251 .45163 Mtetra
.80251 .45163 .80725 .45788 .81838 .45446 .81367 .44819 Mtetra
.81367 .44819 .81838 .45446 .82955 .45104 .82487 .44474 Mtetra
.82487 .44474 .82955 .45104 .84076 .4476 .83611 .44128 Mtetra
.83611 .44128 .84076 .4476 .85201 .44415 .8474 .43781 Mtetra
.8474 .43781 .85201 .44415 .86331 .44069 .85873 .43432 Mtetra
.85873 .43432 .86331 .44069 .87465 .43722 .8701 .43082 Mtetra
.8701 .43082 .87465 .43722 .88604 .43373 .88152 .4273 Mtetra
.88152 .4273 .88604 .43373 .89747 .43022 .89298 .42377 Mtetra
.89298 .42377 .89747 .43022 .90894 .42671 .90449 .42023 Mtetra
.808 .692 .736 r
.28836 .60545 .29413 .61439 .30394 .60353 .29837 .59211 Mtetra
.356 .441 .811 r
.29837 .59211 .30394 .60353 .31316 .60228 .30722 .5965 Mtetra
.621 .723 .92 r
.30722 .5965 .31316 .60228 .32247 .59997 .31654 .59444 Mtetra
.638 .738 .921 r
.31654 .59444 .32247 .59997 .33184 .59748 .32592 .59198 Mtetra
.64 .74 .922 r
.32592 .59198 .33184 .59748 .34123 .59502 .33534 .58946 Mtetra
.633 .737 .923 r
.33534 .58946 .34123 .59502 .35064 .59297 .34478 .5871 Mtetra
.571 .706 .933 r
.34478 .5871 .35064 .59297 .35954 .60233 .3542 .58598 Mtetra
.722 .587 .705 r
.3542 .58598 .35954 .60233 .36981 .5838 .36409 .57573 Mtetra
.513 .609 .886 r
.36409 .57573 .36981 .5838 .37931 .58196 .3735 .5762 Mtetra
.633 .732 .919 r
.3735 .5762 .37931 .58196 .38888 .57936 .38309 .5738 Mtetra
.647 .744 .92 r
.38309 .5738 .38888 .57936 .3985 .57656 .39272 .57105 Mtetra
.652 .748 .92 r
.39272 .57105 .3985 .57656 .40815 .57366 .40239 .56817 Mtetra
.655 .751 .92 r
.40239 .56817 .40815 .57366 .41784 .57069 .4121 .56521 Mtetra
.657 .752 .92 r
.4121 .56521 .41784 .57069 .42757 .56767 .42185 .56218 Mtetra
.658 .753 .92 r
.42185 .56218 .42757 .56767 .43733 .56462 .43164 .55912 Mtetra
.659 .754 .92 r
.43164 .55912 .43733 .56462 .44713 .56154 .44146 .55603 Mtetra
.44146 .55603 .44713 .56154 .45696 .55846 .45131 .55293 Mtetra
.45131 .55293 .45696 .55846 .46683 .55537 .4612 .54982 Mtetra
.4612 .54982 .46683 .55537 .47673 .55228 .47113 .5467 Mtetra
.658 .753 .92 r
.47113 .5467 .47673 .55228 .48667 .54918 .48109 .54358 Mtetra
.48109 .54358 .48667 .54918 .49664 .54608 .49109 .54045 Mtetra
.49109 .54045 .49664 .54608 .50665 .54297 .50112 .53732 Mtetra
.50112 .53732 .50665 .54297 .5167 .53985 .51119 .53418 Mtetra
.51119 .53418 .5167 .53985 .52678 .53673 .5213 .53103 Mtetra
.5213 .53103 .52678 .53673 .5369 .53359 .53144 .52787 Mtetra
.53144 .52787 .5369 .53359 .54706 .53045 .54162 .52471 Mtetra
.657 .753 .92 r
.54162 .52471 .54706 .53045 .55725 .52729 .55184 .52153 Mtetra
.55184 .52153 .55725 .52729 .56748 .52412 .5621 .51834 Mtetra
.657 .752 .92 r
.5621 .51834 .56748 .52412 .57775 .52095 .5724 .51514 Mtetra
.5724 .51514 .57775 .52095 .58806 .51776 .58273 .51194 Mtetra
.58273 .51194 .58806 .51776 .59841 .51457 .5931 .50872 Mtetra
.5931 .50872 .59841 .51457 .60879 .51136 .60351 .50549 Mtetra
.60351 .50549 .60879 .51136 .61921 .50814 .61396 .50224 Mtetra
.61396 .50224 .61921 .50814 .62967 .50491 .62445 .49899 Mtetra
.62445 .49899 .62967 .50491 .64017 .50167 .63497 .49573 Mtetra
.63497 .49573 .64017 .50167 .65071 .49842 .64554 .49245 Mtetra
.64554 .49245 .65071 .49842 .66129 .49515 .65615 .48917 Mtetra
.65615 .48917 .66129 .49515 .67191 .49188 .66679 .48587 Mtetra
.66679 .48587 .67191 .49188 .68257 .48859 .67748 .48256 Mtetra
.67748 .48256 .68257 .48859 .69327 .48529 .6882 .47923 Mtetra
.6882 .47923 .69327 .48529 .70401 .48198 .69897 .4759 Mtetra
.69897 .4759 .70401 .48198 .71479 .47866 .70978 .47255 Mtetra
.70978 .47255 .71479 .47866 .72561 .47532 .72063 .46919 Mtetra
.72063 .46919 .72561 .47532 .73647 .47197 .73152 .46582 Mtetra
.73152 .46582 .73647 .47197 .74737 .46861 .74245 .46244 Mtetra
.74245 .46244 .74737 .46861 .75832 .46524 .75343 .45904 Mtetra
.75343 .45904 .75832 .46524 .7693 .46186 .76444 .45563 Mtetra
.76444 .45563 .7693 .46186 .78033 .45846 .7755 .45221 Mtetra
.7755 .45221 .78033 .45846 .7914 .45505 .7866 .44878 Mtetra
.7866 .44878 .7914 .45505 .80251 .45163 .79774 .44533 Mtetra
.79774 .44533 .80251 .45163 .81367 .44819 .80893 .44187 Mtetra
.80893 .44187 .81367 .44819 .82487 .44474 .82016 .4384 Mtetra
.82016 .4384 .82487 .44474 .83611 .44128 .83143 .43491 Mtetra
.83143 .43491 .83611 .44128 .8474 .43781 .84275 .43141 Mtetra
.84275 .43141 .8474 .43781 .85873 .43432 .85411 .4279 Mtetra
.85411 .4279 .85873 .43432 .8701 .43082 .86552 .42437 Mtetra
.86552 .42437 .8701 .43082 .88152 .4273 .87697 .42083 Mtetra
.87697 .42083 .88152 .4273 .89298 .42377 .88847 .41728 Mtetra
.88847 .41728 .89298 .42377 .90449 .42023 .90001 .41371 Mtetra
.363 .601 .938 r
.28238 .59924 .28836 .60545 .29837 .59211 .29139 .60102 Mtetra
0 0 0 r
.29139 .60102 .29837 .59211 .30722 .5965 .30129 .59008 Mtetra
.586 .691 .914 r
.30129 .59008 .30722 .5965 .31654 .59444 .31057 .58879 Mtetra
.633 .734 .921 r
.31057 .58879 .31654 .59444 .32592 .59198 .31996 .58643 Mtetra
.64 .74 .921 r
.31996 .58643 .32592 .59198 .33534 .58946 .3294 .5839 Mtetra
.638 .74 .922 r
.3294 .5839 .33534 .58946 .34478 .5871 .33887 .5814 Mtetra
.619 .73 .925 r
.33887 .5814 .34478 .5871 .3542 .58598 .34836 .5793 Mtetra
0 .013 .537 r
.34836 .5793 .3542 .58598 .36409 .57573 .35732 .58866 Mtetra
0 0 0 r
.35732 .58866 .36409 .57573 .3735 .5762 .36768 .57001 Mtetra
.61 .711 .916 r
.36768 .57001 .3735 .5762 .38309 .5738 .37725 .56813 Mtetra
.642 .74 .92 r
.37725 .56813 .38309 .5738 .39272 .57105 .3869 .56548 Mtetra
.65 .747 .92 r
.3869 .56548 .39272 .57105 .40239 .56817 .3966 .56263 Mtetra
.654 .75 .92 r
.3966 .56263 .40239 .56817 .4121 .56521 .40633 .55968 Mtetra
.656 .752 .92 r
.40633 .55968 .4121 .56521 .42185 .56218 .4161 .55666 Mtetra
.658 .753 .92 r
.4161 .55666 .42185 .56218 .43164 .55912 .4259 .55359 Mtetra
.659 .753 .92 r
.4259 .55359 .43164 .55912 .44146 .55603 .43575 .55048 Mtetra
.659 .754 .92 r
.43575 .55048 .44146 .55603 .45131 .55293 .44562 .54736 Mtetra
.44562 .54736 .45131 .55293 .4612 .54982 .45554 .54422 Mtetra
.45554 .54422 .4612 .54982 .47113 .5467 .46549 .54108 Mtetra
.659 .753 .92 r
.46549 .54108 .47113 .5467 .48109 .54358 .47547 .53794 Mtetra
.658 .753 .92 r
.47547 .53794 .48109 .54358 .49109 .54045 .48549 .53479 Mtetra
.48549 .53479 .49109 .54045 .50112 .53732 .49555 .53163 Mtetra
.49555 .53163 .50112 .53732 .51119 .53418 .50565 .52847 Mtetra
.50565 .52847 .51119 .53418 .5213 .53103 .51578 .5253 Mtetra
.51578 .5253 .5213 .53103 .53144 .52787 .52595 .52212 Mtetra
.52595 .52212 .53144 .52787 .54162 .52471 .53615 .51893 Mtetra
.657 .753 .92 r
.53615 .51893 .54162 .52471 .55184 .52153 .5464 .51573 Mtetra
.5464 .51573 .55184 .52153 .5621 .51834 .55668 .51252 Mtetra
.55668 .51252 .5621 .51834 .5724 .51514 .567 .5093 Mtetra
.657 .752 .92 r
.567 .5093 .5724 .51514 .58273 .51194 .57736 .50607 Mtetra
.57736 .50607 .58273 .51194 .5931 .50872 .58776 .50283 Mtetra
.58776 .50283 .5931 .50872 .60351 .50549 .59819 .49957 Mtetra
.59819 .49957 .60351 .50549 .61396 .50224 .60867 .49631 Mtetra
.60867 .49631 .61396 .50224 .62445 .49899 .61918 .49303 Mtetra
.61918 .49303 .62445 .49899 .63497 .49573 .62974 .48975 Mtetra
.62974 .48975 .63497 .49573 .64554 .49245 .64033 .48645 Mtetra
.64033 .48645 .64554 .49245 .65615 .48917 .65096 .48314 Mtetra
.65096 .48314 .65615 .48917 .66679 .48587 .66164 .47982 Mtetra
.66164 .47982 .66679 .48587 .67748 .48256 .67235 .47648 Mtetra
.67235 .47648 .67748 .48256 .6882 .47923 .6831 .47314 Mtetra
.6831 .47314 .6882 .47923 .69897 .4759 .6939 .46978 Mtetra
.6939 .46978 .69897 .4759 .70978 .47255 .70474 .46641 Mtetra
.70474 .46641 .70978 .47255 .72063 .46919 .71562 .46302 Mtetra
.71562 .46302 .72063 .46919 .73152 .46582 .72653 .45963 Mtetra
.72653 .45963 .73152 .46582 .74245 .46244 .7375 .45622 Mtetra
.7375 .45622 .74245 .46244 .75343 .45904 .7485 .4528 Mtetra
.7485 .4528 .75343 .45904 .76444 .45563 .75955 .44937 Mtetra
.75955 .44937 .76444 .45563 .7755 .45221 .77063 .44592 Mtetra
.77063 .44592 .7755 .45221 .7866 .44878 .78177 .44246 Mtetra
.78177 .44246 .7866 .44878 .79774 .44533 .79294 .43899 Mtetra
.79294 .43899 .79774 .44533 .80893 .44187 .80416 .43551 Mtetra
.80416 .43551 .80893 .44187 .82016 .4384 .81542 .43201 Mtetra
.81542 .43201 .82016 .4384 .83143 .43491 .82672 .4285 Mtetra
.82672 .4285 .83143 .43491 .84275 .43141 .83807 .42497 Mtetra
.83807 .42497 .84275 .43141 .85411 .4279 .84947 .42143 Mtetra
.84947 .42143 .85411 .4279 .86552 .42437 .8609 .41788 Mtetra
.8609 .41788 .86552 .42437 .87697 .42083 .87239 .41432 Mtetra
.87239 .41432 .87697 .42083 .88847 .41728 .88392 .41074 Mtetra
.88392 .41074 .88847 .41728 .90001 .41371 .89549 .40714 Mtetra
.589 .714 .93 r
.27632 .59343 .28238 .59924 .29139 .60102 .28557 .59198 Mtetra
.809 .692 .736 r
.28557 .59198 .29139 .60102 .30129 .59008 .29566 .57855 Mtetra
.354 .44 .811 r
.29566 .57855 .30129 .59008 .31057 .58879 .30458 .58292 Mtetra
.621 .723 .92 r
.30458 .58292 .31057 .58879 .31996 .58643 .31397 .58081 Mtetra
.638 .738 .921 r
.31397 .58081 .31996 .58643 .3294 .5839 .32342 .57831 Mtetra
.64 .74 .922 r
.32342 .57831 .3294 .5839 .33887 .5814 .33292 .57574 Mtetra
.633 .737 .923 r
.33292 .57574 .33887 .5814 .34836 .5793 .34244 .57333 Mtetra
.571 .706 .933 r
.34244 .57333 .34836 .5793 .35732 .58866 .35193 .57217 Mtetra
.722 .587 .705 r
.35193 .57217 .35732 .58866 .36768 .57001 .36191 .56184 Mtetra
.513 .609 .886 r
.36191 .56184 .36768 .57001 .37725 .56813 .37139 .56227 Mtetra
.633 .732 .919 r
.37139 .56227 .37725 .56813 .3869 .56548 .38105 .55983 Mtetra
.647 .744 .92 r
.38105 .55983 .3869 .56548 .3966 .56263 .39076 .55703 Mtetra
.652 .748 .92 r
.39076 .55703 .3966 .56263 .40633 .55968 .40051 .5541 Mtetra
.655 .751 .92 r
.40051 .5541 .40633 .55968 .4161 .55666 .41031 .55108 Mtetra
.657 .752 .92 r
.41031 .55108 .4161 .55666 .4259 .55359 .42013 .54801 Mtetra
.658 .753 .92 r
.42013 .54801 .4259 .55359 .43575 .55048 .43 .54489 Mtetra
.659 .754 .92 r
.43 .54489 .43575 .55048 .44562 .54736 .4399 .54175 Mtetra
.4399 .54175 .44562 .54736 .45554 .54422 .44984 .5386 Mtetra
.44984 .5386 .45554 .54422 .46549 .54108 .45981 .53543 Mtetra
.45981 .53543 .46549 .54108 .47547 .53794 .46982 .53226 Mtetra
.658 .753 .92 r
.46982 .53226 .47547 .53794 .48549 .53479 .47986 .52909 Mtetra
.47986 .52909 .48549 .53479 .49555 .53163 .48995 .52591 Mtetra
.48995 .52591 .49555 .53163 .50565 .52847 .50007 .52272 Mtetra
.50007 .52272 .50565 .52847 .51578 .5253 .51022 .51953 Mtetra
.51022 .51953 .51578 .5253 .52595 .52212 .52042 .51632 Mtetra
.52042 .51632 .52595 .52212 .53615 .51893 .53065 .51311 Mtetra
.53065 .51311 .53615 .51893 .5464 .51573 .54092 .50989 Mtetra
.657 .753 .92 r
.54092 .50989 .5464 .51573 .55668 .51252 .55122 .50666 Mtetra
.55122 .50666 .55668 .51252 .567 .5093 .56157 .50341 Mtetra
.657 .752 .92 r
.56157 .50341 .567 .5093 .57736 .50607 .57195 .50016 Mtetra
.57195 .50016 .57736 .50607 .58776 .50283 .58238 .49689 Mtetra
.58238 .49689 .58776 .50283 .59819 .49957 .59284 .49362 Mtetra
.59284 .49362 .59819 .49957 .60867 .49631 .60334 .49033 Mtetra
.60334 .49033 .60867 .49631 .61918 .49303 .61388 .48703 Mtetra
.61388 .48703 .61918 .49303 .62974 .48975 .62446 .48372 Mtetra
.62446 .48372 .62974 .48975 .64033 .48645 .63508 .4804 Mtetra
.63508 .4804 .64033 .48645 .65096 .48314 .64574 .47707 Mtetra
.64574 .47707 .65096 .48314 .66164 .47982 .65645 .47372 Mtetra
.65645 .47372 .66164 .47982 .67235 .47648 .66719 .47036 Mtetra
.66719 .47036 .67235 .47648 .6831 .47314 .67797 .46699 Mtetra
.67797 .46699 .6831 .47314 .6939 .46978 .68879 .46361 Mtetra
.68879 .46361 .6939 .46978 .70474 .46641 .69966 .46022 Mtetra
.69966 .46022 .70474 .46641 .71562 .46302 .71057 .45681 Mtetra
.71057 .45681 .71562 .46302 .72653 .45963 .72151 .45339 Mtetra
.72151 .45339 .72653 .45963 .7375 .45622 .73251 .44996 Mtetra
.73251 .44996 .7375 .45622 .7485 .4528 .74354 .44651 Mtetra
.74354 .44651 .7485 .4528 .75955 .44937 .75461 .44306 Mtetra
.75461 .44306 .75955 .44937 .77063 .44592 .76573 .43959 Mtetra
.76573 .43959 .77063 .44592 .78177 .44246 .7769 .4361 Mtetra
.7769 .4361 .78177 .44246 .79294 .43899 .7881 .43261 Mtetra
.7881 .43261 .79294 .43899 .80416 .43551 .79935 .42909 Mtetra
.79935 .42909 .80416 .43551 .81542 .43201 .81064 .42557 Mtetra
.81064 .42557 .81542 .43201 .82672 .4285 .82198 .42203 Mtetra
.82198 .42203 .82672 .4285 .83807 .42497 .83336 .41848 Mtetra
.83336 .41848 .83807 .42497 .84947 .42143 .84479 .41492 Mtetra
.84479 .41492 .84947 .42143 .8609 .41788 .85626 .41134 Mtetra
.85626 .41134 .8609 .41788 .87239 .41432 .86777 .40775 Mtetra
.86777 .40775 .87239 .41432 .88392 .41074 .87933 .40414 Mtetra
.87933 .40414 .88392 .41074 .89549 .40714 .89094 .40053 Mtetra
.618 .728 .925 r
.27022 .58772 .27632 .59343 .28557 .59198 .27953 .58567 Mtetra
.364 .601 .938 r
.27953 .58567 .28557 .59198 .29566 .57855 .2886 .58743 Mtetra
0 0 0 r
.2886 .58743 .29566 .57855 .30458 .58292 .29859 .57641 Mtetra
.586 .691 .914 r
.29859 .57641 .30458 .58292 .31397 .58081 .30795 .57507 Mtetra
.633 .734 .921 r
.30795 .57507 .31397 .58081 .32342 .57831 .31741 .57267 Mtetra
.64 .74 .921 r
.31741 .57267 .32342 .57831 .33292 .57574 .32692 .57009 Mtetra
.638 .74 .922 r
.32692 .57009 .33292 .57574 .34244 .57333 .33647 .56754 Mtetra
.619 .73 .925 r
.33647 .56754 .34244 .57333 .35193 .57217 .34603 .56539 Mtetra
0 .019 .544 r
.34603 .56539 .35193 .57217 .36191 .56184 .35505 .57476 Mtetra
0 0 0 r
.35505 .57476 .36191 .56184 .37139 .56227 .36551 .55599 Mtetra
.61 .711 .916 r
.36551 .55599 .37139 .56227 .38105 .55983 .37516 .55406 Mtetra
.642 .74 .92 r
.37516 .55406 .38105 .55983 .39076 .55703 .38489 .55137 Mtetra
.65 .747 .92 r
.38489 .55137 .39076 .55703 .40051 .5541 .39466 .54846 Mtetra
.654 .75 .92 r
.39466 .54846 .40051 .5541 .41031 .55108 .40447 .54546 Mtetra
.656 .752 .92 r
.40447 .54546 .41031 .55108 .42013 .54801 .41432 .54238 Mtetra
.658 .753 .92 r
.41432 .54238 .42013 .54801 .43 .54489 .42421 .53926 Mtetra
.659 .753 .92 r
.42421 .53926 .43 .54489 .4399 .54175 .43414 .53611 Mtetra
.659 .754 .92 r
.43414 .53611 .4399 .54175 .44984 .5386 .4441 .53293 Mtetra
.4441 .53293 .44984 .5386 .45981 .53543 .45409 .52974 Mtetra
.45409 .52974 .45981 .53543 .46982 .53226 .46413 .52655 Mtetra
.659 .753 .92 r
.46413 .52655 .46982 .53226 .47986 .52909 .4742 .52335 Mtetra
.658 .753 .92 r
.4742 .52335 .47986 .52909 .48995 .52591 .4843 .52014 Mtetra
.4843 .52014 .48995 .52591 .50007 .52272 .49445 .51693 Mtetra
.49445 .51693 .50007 .52272 .51022 .51953 .50463 .51372 Mtetra
.50463 .51372 .51022 .51953 .52042 .51632 .51484 .51049 Mtetra
.51484 .51049 .52042 .51632 .53065 .51311 .5251 .50725 Mtetra
.5251 .50725 .53065 .51311 .54092 .50989 .5354 .50401 Mtetra
.657 .753 .92 r
.5354 .50401 .54092 .50989 .55122 .50666 .54573 .50075 Mtetra
.54573 .50075 .55122 .50666 .56157 .50341 .5561 .49749 Mtetra
.5561 .49749 .56157 .50341 .57195 .50016 .56651 .49421 Mtetra
.657 .752 .92 r
.56651 .49421 .57195 .50016 .58238 .49689 .57696 .49092 Mtetra
.57696 .49092 .58238 .49689 .59284 .49362 .58745 .48762 Mtetra
.58745 .48762 .59284 .49362 .60334 .49033 .59798 .48431 Mtetra
.59798 .48431 .60334 .49033 .61388 .48703 .60854 .48099 Mtetra
.60854 .48099 .61388 .48703 .62446 .48372 .61915 .47766 Mtetra
.61915 .47766 .62446 .48372 .63508 .4804 .6298 .47431 Mtetra
.6298 .47431 .63508 .4804 .64574 .47707 .64049 .47095 Mtetra
.64049 .47095 .64574 .47707 .65645 .47372 .65122 .46758 Mtetra
.65122 .46758 .65645 .47372 .66719 .47036 .66199 .4642 Mtetra
.66199 .4642 .66719 .47036 .67797 .46699 .6728 .46081 Mtetra
.6728 .46081 .67797 .46699 .68879 .46361 .68365 .4574 Mtetra
.68365 .4574 .68879 .46361 .69966 .46022 .69455 .45398 Mtetra
.69455 .45398 .69966 .46022 .71057 .45681 .70548 .45055 Mtetra
.70548 .45055 .71057 .45681 .72151 .45339 .71646 .44711 Mtetra
.71646 .44711 .72151 .45339 .73251 .44996 .72748 .44365 Mtetra
.72748 .44365 .73251 .44996 .74354 .44651 .73854 .44018 Mtetra
.73854 .44018 .74354 .44651 .75461 .44306 .74965 .4367 Mtetra
.74965 .4367 .75461 .44306 .76573 .43959 .7608 .4332 Mtetra
.7608 .4332 .76573 .43959 .7769 .4361 .77199 .4297 Mtetra
.77199 .4297 .7769 .4361 .7881 .43261 .78323 .42617 Mtetra
.78323 .42617 .7881 .43261 .79935 .42909 .79451 .42264 Mtetra
.79451 .42264 .79935 .42909 .81064 .42557 .80583 .41909 Mtetra
.80583 .41909 .81064 .42557 .82198 .42203 .8172 .41553 Mtetra
.8172 .41553 .82198 .42203 .83336 .41848 .82861 .41195 Mtetra
.82861 .41195 .83336 .41848 .84479 .41492 .84007 .40836 Mtetra
.84007 .40836 .84479 .41492 .85626 .41134 .85157 .40476 Mtetra
.85157 .40476 .85626 .41134 .86777 .40775 .86312 .40114 Mtetra
.86312 .40114 .86777 .40775 .87933 .40414 .87472 .39751 Mtetra
.87472 .39751 .87933 .40414 .89094 .40053 .88636 .39386 Mtetra
.625 .731 .923 r
.26408 .58201 .27022 .58772 .27953 .58567 .27341 .57978 Mtetra
.589 .714 .93 r
.27341 .57978 .27953 .58567 .2886 .58743 .28273 .57828 Mtetra
.809 .693 .737 r
.28273 .57828 .2886 .58743 .29859 .57641 .29291 .56476 Mtetra
.353 .44 .811 r
.29291 .56476 .29859 .57641 .30795 .57507 .30189 .56911 Mtetra
.621 .723 .92 r
.30189 .56911 .30795 .57507 .31741 .57267 .31136 .56696 Mtetra
.638 .738 .921 r
.31136 .56696 .31741 .57267 .32692 .57009 .32089 .5644 Mtetra
.64 .74 .922 r
.32089 .5644 .32692 .57009 .33647 .56754 .33046 .56179 Mtetra
.633 .737 .923 r
.33046 .56179 .33647 .56754 .34603 .56539 .34005 .55933 Mtetra
.571 .706 .933 r
.34005 .55933 .34603 .56539 .35505 .57476 .34962 .55812 Mtetra
.722 .587 .704 r
.34962 .55812 .35505 .57476 .36551 .55599 .35968 .54771 Mtetra
.512 .609 .886 r
.35968 .54771 .36551 .55599 .37516 .55406 .36924 .54811 Mtetra
.633 .732 .919 r
.36924 .54811 .37516 .55406 .38489 .55137 .37898 .54562 Mtetra
.647 .744 .92 r
.37898 .54562 .38489 .55137 .39466 .54846 .38877 .54277 Mtetra
.652 .748 .92 r
.38877 .54277 .39466 .54846 .40447 .54546 .3986 .53978 Mtetra
.655 .751 .92 r
.3986 .53978 .40447 .54546 .41432 .54238 .40848 .53671 Mtetra
.657 .752 .92 r
.40848 .53671 .41432 .54238 .42421 .53926 .41839 .53359 Mtetra
.658 .753 .92 r
.41839 .53359 .42421 .53926 .43414 .53611 .42833 .53042 Mtetra
.659 .754 .92 r
.42833 .53042 .43414 .53611 .4441 .53293 .43832 .52722 Mtetra
.43832 .52722 .4441 .53293 .45409 .52974 .44834 .52401 Mtetra
.44834 .52401 .45409 .52974 .46413 .52655 .45839 .5208 Mtetra
.45839 .5208 .46413 .52655 .4742 .52335 .46849 .51757 Mtetra
.658 .753 .92 r
.46849 .51757 .4742 .52335 .4843 .52014 .47862 .51434 Mtetra
.47862 .51434 .4843 .52014 .49445 .51693 .48879 .51111 Mtetra
.48879 .51111 .49445 .51693 .50463 .51372 .49899 .50787 Mtetra
.49899 .50787 .50463 .51372 .51484 .51049 .50924 .50462 Mtetra
.50924 .50462 .51484 .51049 .5251 .50725 .51952 .50136 Mtetra
.51952 .50136 .5251 .50725 .5354 .50401 .52984 .49809 Mtetra
.52984 .49809 .5354 .50401 .54573 .50075 .5402 .49481 Mtetra
.657 .753 .92 r
.5402 .49481 .54573 .50075 .5561 .49749 .55059 .49152 Mtetra
.55059 .49152 .5561 .49749 .56651 .49421 .56103 .48822 Mtetra
.657 .752 .92 r
.56103 .48822 .56651 .49421 .57696 .49092 .5715 .48491 Mtetra
.5715 .48491 .57696 .49092 .58745 .48762 .58202 .48158 Mtetra
.58202 .48158 .58745 .48762 .59798 .48431 .59257 .47825 Mtetra
.59257 .47825 .59798 .48431 .60854 .48099 .60317 .47491 Mtetra
.60317 .47491 .60854 .48099 .61915 .47766 .6138 .47155 Mtetra
.6138 .47155 .61915 .47766 .6298 .47431 .62448 .46818 Mtetra
.62448 .46818 .6298 .47431 .64049 .47095 .6352 .4648 Mtetra
.6352 .4648 .64049 .47095 .65122 .46758 .64595 .4614 Mtetra
.64595 .4614 .65122 .46758 .66199 .4642 .65675 .458 Mtetra
.65675 .458 .66199 .4642 .6728 .46081 .66759 .45458 Mtetra
.66759 .45458 .6728 .46081 .68365 .4574 .67847 .45115 Mtetra
.67847 .45115 .68365 .4574 .69455 .45398 .68939 .44771 Mtetra
.68939 .44771 .69455 .45398 .70548 .45055 .70036 .44425 Mtetra
.70036 .44425 .70548 .45055 .71646 .44711 .71137 .44078 Mtetra
.71137 .44078 .71646 .44711 .72748 .44365 .72242 .4373 Mtetra
.72242 .4373 .72748 .44365 .73854 .44018 .73351 .43381 Mtetra
.73351 .43381 .73854 .44018 .74965 .4367 .74465 .4303 Mtetra
.74465 .4303 .74965 .4367 .7608 .4332 .75583 .42678 Mtetra
.75583 .42678 .7608 .4332 .77199 .4297 .76705 .42324 Mtetra
.76705 .42324 .77199 .4297 .78323 .42617 .77832 .4197 Mtetra
.77832 .4197 .78323 .42617 .79451 .42264 .78963 .41613 Mtetra
.78963 .41613 .79451 .42264 .80583 .41909 .80098 .41256 Mtetra
.80098 .41256 .80583 .41909 .8172 .41553 .81238 .40897 Mtetra
.81238 .40897 .8172 .41553 .82861 .41195 .82383 .40537 Mtetra
.82383 .40537 .82861 .41195 .84007 .40836 .83532 .40175 Mtetra
.83532 .40175 .84007 .40836 .85157 .40476 .84686 .39812 Mtetra
.84686 .39812 .85157 .40476 .86312 .40114 .85844 .39448 Mtetra
.85844 .39448 .86312 .40114 .87472 .39751 .87007 .39082 Mtetra
.87007 .39082 .87472 .39751 .88636 .39386 .88174 .38714 Mtetra
.625 .73 .922 r
.2579 .57622 .26408 .58201 .27341 .57978 .26725 .57398 Mtetra
.618 .728 .925 r
.26725 .57398 .27341 .57978 .28273 .57828 .27663 .57188 Mtetra
.365 .601 .938 r
.27663 .57188 .28273 .57828 .29291 .56476 .28577 .57361 Mtetra
0 0 0 r
.28577 .57361 .29291 .56476 .30189 .56911 .29584 .5625 Mtetra
.586 .691 .914 r
.29584 .5625 .30189 .56911 .31136 .56696 .30527 .56112 Mtetra
.633 .734 .921 r
.30527 .56112 .31136 .56696 .32089 .5644 .31481 .55867 Mtetra
.64 .74 .921 r
.31481 .55867 .32089 .5644 .33046 .56179 .3244 .55604 Mtetra
.638 .74 .922 r
.3244 .55604 .33046 .56179 .34005 .55933 .33402 .55344 Mtetra
.619 .73 .925 r
.33402 .55344 .34005 .55933 .34962 .55812 .34366 .55125 Mtetra
0 .025 .551 r
.34366 .55125 .34962 .55812 .35968 .54771 .35275 .56062 Mtetra
0 0 0 r
.35275 .56062 .35968 .54771 .36924 .54811 .3633 .54172 Mtetra
.61 .711 .916 r
.3633 .54172 .36924 .54811 .37898 .54562 .37303 .53975 Mtetra
.642 .74 .92 r
.37303 .53975 .37898 .54562 .38877 .54277 .38284 .537 Mtetra
.65 .747 .92 r
.38284 .537 .38877 .54277 .3986 .53978 .39269 .53405 Mtetra
.654 .75 .92 r
.39269 .53405 .3986 .53978 .40848 .53671 .40259 .53099 Mtetra
.656 .752 .92 r
.40259 .53099 .40848 .53671 .41839 .53359 .41252 .52787 Mtetra
.658 .753 .92 r
.41252 .52787 .41839 .53359 .42833 .53042 .42249 .52469 Mtetra
.659 .753 .92 r
.42249 .52469 .42833 .53042 .43832 .52722 .4325 .52148 Mtetra
.659 .754 .92 r
.4325 .52148 .43832 .52722 .44834 .52401 .44254 .51825 Mtetra
.44254 .51825 .44834 .52401 .45839 .5208 .45262 .51501 Mtetra
.45262 .51501 .45839 .5208 .46849 .51757 .46274 .51176 Mtetra
.659 .753 .92 r
.46274 .51176 .46849 .51757 .47862 .51434 .4729 .5085 Mtetra
.658 .753 .92 r
.4729 .5085 .47862 .51434 .48879 .51111 .48309 .50524 Mtetra
.48309 .50524 .48879 .51111 .49899 .50787 .49332 .50198 Mtetra
.49332 .50198 .49899 .50787 .50924 .50462 .50359 .4987 Mtetra
.50359 .4987 .50924 .50462 .51952 .50136 .51389 .49542 Mtetra
.51389 .49542 .51952 .50136 .52984 .49809 .52424 .49213 Mtetra
.52424 .49213 .52984 .49809 .5402 .49481 .53462 .48882 Mtetra
.657 .753 .92 r
.53462 .48882 .5402 .49481 .55059 .49152 .54505 .48551 Mtetra
.54505 .48551 .55059 .49152 .56103 .48822 .55551 .48219 Mtetra
.55551 .48219 .56103 .48822 .5715 .48491 .56601 .47885 Mtetra
.657 .752 .92 r
.56601 .47885 .5715 .48491 .58202 .48158 .57655 .47551 Mtetra
.57655 .47551 .58202 .48158 .59257 .47825 .58713 .47215 Mtetra
.58713 .47215 .59257 .47825 .60317 .47491 .59776 .46878 Mtetra
.59776 .46878 .60317 .47491 .6138 .47155 .60842 .4654 Mtetra
.60842 .4654 .6138 .47155 .62448 .46818 .61912 .462 Mtetra
.61912 .462 .62448 .46818 .6352 .4648 .62987 .4586 Mtetra
.62987 .4586 .6352 .4648 .64595 .4614 .64065 .45518 Mtetra
.64065 .45518 .64595 .4614 .65675 .458 .65148 .45175 Mtetra
.65148 .45175 .65675 .458 .66759 .45458 .66234 .44831 Mtetra
.66234 .44831 .66759 .45458 .67847 .45115 .67325 .44485 Mtetra
.67325 .44485 .67847 .45115 .68939 .44771 .68421 .44138 Mtetra
.68421 .44138 .68939 .44771 .70036 .44425 .6952 .4379 Mtetra
.6952 .4379 .70036 .44425 .71137 .44078 .70624 .43441 Mtetra
.70624 .43441 .71137 .44078 .72242 .4373 .71732 .4309 Mtetra
.71732 .4309 .72242 .4373 .73351 .43381 .72844 .42738 Mtetra
.72844 .42738 .73351 .43381 .74465 .4303 .73961 .42385 Mtetra
.73961 .42385 .74465 .4303 .75583 .42678 .75082 .4203 Mtetra
.75082 .4203 .75583 .42678 .76705 .42324 .76207 .41674 Mtetra
.76207 .41674 .76705 .42324 .77832 .4197 .77337 .41317 Mtetra
.77337 .41317 .77832 .4197 .78963 .41613 .78471 .40958 Mtetra
.78471 .40958 .78963 .41613 .80098 .41256 .7961 .40598 Mtetra
.7961 .40598 .80098 .41256 .81238 .40897 .80753 .40237 Mtetra
.80753 .40237 .81238 .40897 .82383 .40537 .81901 .39874 Mtetra
.81901 .39874 .82383 .40537 .83532 .40175 .83054 .39509 Mtetra
.83054 .39509 .83532 .40175 .84686 .39812 .8421 .39144 Mtetra
.8421 .39144 .84686 .39812 .85844 .39448 .85372 .38777 Mtetra
.85372 .38777 .85844 .39448 .87007 .39082 .86538 .38408 Mtetra
.86538 .38408 .87007 .39082 .88174 .38714 .87709 .38038 Mtetra
.617 .722 .921 r
.2517 .57024 .2579 .57622 .26725 .57398 .26105 .56817 Mtetra
.625 .731 .923 r
.26105 .56817 .26725 .57398 .27663 .57188 .27045 .56589 Mtetra
.589 .714 .93 r
.27045 .56589 .27663 .57188 .28577 .57361 .27984 .56435 Mtetra
.81 .694 .737 r
.27984 .56435 .28577 .57361 .29584 .5625 .29012 .55073 Mtetra
.352 .439 .811 r
.29012 .55073 .29584 .5625 .30527 .56112 .29916 .55506 Mtetra
.621 .723 .92 r
.29916 .55506 .30527 .56112 .31481 .55867 .3087 .55286 Mtetra
.638 .738 .921 r
.3087 .55286 .31481 .55867 .3244 .55604 .31831 .55026 Mtetra
.64 .74 .922 r
.31831 .55026 .3244 .55604 .33402 .55344 .32795 .5476 Mtetra
.633 .737 .923 r
.32795 .5476 .33402 .55344 .34366 .55125 .33763 .54509 Mtetra
.572 .705 .933 r
.33763 .54509 .34366 .55125 .35275 .56062 .34727 .54384 Mtetra
.722 .587 .704 r
.34727 .54384 .35275 .56062 .3633 .54172 .35742 .53334 Mtetra
.512 .609 .886 r
.35742 .53334 .3633 .54172 .37303 .53975 .36706 .5337 Mtetra
.633 .732 .919 r
.36706 .5337 .37303 .53975 .38284 .537 .37687 .53116 Mtetra
.647 .744 .92 r
.37687 .53116 .38284 .537 .39269 .53405 .38675 .52826 Mtetra
.652 .748 .92 r
.38675 .52826 .39269 .53405 .40259 .53099 .39666 .52522 Mtetra
.655 .751 .92 r
.39666 .52522 .40259 .53099 .41252 .52787 .40661 .5221 Mtetra
.657 .752 .92 r
.40661 .5221 .41252 .52787 .42249 .52469 .41661 .51891 Mtetra
.658 .753 .92 r
.41661 .51891 .42249 .52469 .4325 .52148 .42664 .51569 Mtetra
.659 .754 .92 r
.42664 .51569 .4325 .52148 .44254 .51825 .43671 .51244 Mtetra
.43671 .51244 .44254 .51825 .45262 .51501 .44681 .50918 Mtetra
.44681 .50918 .45262 .51501 .46274 .51176 .45695 .5059 Mtetra
.45695 .5059 .46274 .51176 .4729 .5085 .46713 .50262 Mtetra
.658 .753 .92 r
.46713 .50262 .4729 .5085 .48309 .50524 .47735 .49934 Mtetra
.47735 .49934 .48309 .50524 .49332 .50198 .48761 .49605 Mtetra
.48761 .49605 .49332 .50198 .50359 .4987 .4979 .49275 Mtetra
.4979 .49275 .50359 .4987 .51389 .49542 .50823 .48944 Mtetra
.50823 .48944 .51389 .49542 .52424 .49213 .5186 .48612 Mtetra
.5186 .48612 .52424 .49213 .53462 .48882 .52901 .4828 Mtetra
.52901 .4828 .53462 .48882 .54505 .48551 .53946 .47946 Mtetra
.657 .753 .92 r
.53946 .47946 .54505 .48551 .55551 .48219 .54995 .47611 Mtetra
.54995 .47611 .55551 .48219 .56601 .47885 .56048 .47275 Mtetra
.657 .752 .92 r
.56048 .47275 .56601 .47885 .57655 .47551 .57105 .46938 Mtetra
.57105 .46938 .57655 .47551 .58713 .47215 .58166 .466 Mtetra
.58166 .466 .58713 .47215 .59776 .46878 .5923 .46261 Mtetra
.5923 .46261 .59776 .46878 .60842 .4654 .60299 .4592 Mtetra
.60299 .4592 .60842 .4654 .61912 .462 .61372 .45578 Mtetra
.61372 .45578 .61912 .462 .62987 .4586 .6245 .45235 Mtetra
.6245 .45235 .62987 .4586 .64065 .45518 .63531 .44891 Mtetra
.63531 .44891 .64065 .45518 .65148 .45175 .64616 .44546 Mtetra
.64616 .44546 .65148 .45175 .66234 .44831 .65706 .44199 Mtetra
.65706 .44199 .66234 .44831 .67325 .44485 .668 .43851 Mtetra
.668 .43851 .67325 .44485 .68421 .44138 .67898 .43502 Mtetra
.67898 .43502 .68421 .44138 .6952 .4379 .69001 .43151 Mtetra
.69001 .43151 .6952 .4379 .70624 .43441 .70107 .42799 Mtetra
.70107 .42799 .70624 .43441 .71732 .4309 .71218 .42446 Mtetra
.71218 .42446 .71732 .4309 .72844 .42738 .72334 .42091 Mtetra
.72334 .42091 .72844 .42738 .73961 .42385 .73453 .41736 Mtetra
.73453 .41736 .73961 .42385 .75082 .4203 .74577 .41378 Mtetra
.74577 .41378 .75082 .4203 .76207 .41674 .75706 .4102 Mtetra
.75706 .4102 .76207 .41674 .77337 .41317 .76839 .4066 Mtetra
.76839 .4066 .77337 .41317 .78471 .40958 .77976 .40298 Mtetra
.77976 .40298 .78471 .40958 .7961 .40598 .79118 .39936 Mtetra
.79118 .39936 .7961 .40598 .80753 .40237 .80265 .39571 Mtetra
.80265 .39571 .80753 .40237 .81901 .39874 .81416 .39206 Mtetra
.81416 .39206 .81901 .39874 .83054 .39509 .82571 .38839 Mtetra
.82571 .38839 .83054 .39509 .8421 .39144 .83732 .3847 Mtetra
.83732 .3847 .8421 .39144 .85372 .38777 .84897 .38101 Mtetra
.84897 .38101 .85372 .38777 .86538 .38408 .86066 .37729 Mtetra
.86066 .37729 .86538 .38408 .87709 .38038 .8724 .37356 Mtetra
.589 .696 .917 r
.24549 .56374 .2517 .57024 .26105 .56817 .25481 .56228 Mtetra
.625 .73 .922 r
.25481 .56228 .26105 .56817 .27045 .56589 .26423 .55999 Mtetra
.618 .728 .925 r
.26423 .55999 .27045 .56589 .27984 .56435 .27368 .55785 Mtetra
.367 .602 .938 r
.27368 .55785 .27984 .56435 .29012 .55073 .28289 .55955 Mtetra
0 0 0 r
.28289 .55955 .29012 .55073 .29916 .55506 .29305 .54835 Mtetra
.586 .691 .914 r
.29305 .54835 .29916 .55506 .3087 .55286 .30256 .54694 Mtetra
.633 .734 .921 r
.30256 .54694 .3087 .55286 .31831 .55026 .31217 .54443 Mtetra
.64 .74 .921 r
.31217 .54443 .31831 .55026 .32795 .5476 .32184 .54175 Mtetra
.638 .74 .922 r
.32184 .54175 .32795 .5476 .33763 .54509 .33154 .5391 Mtetra
.619 .73 .925 r
.33154 .5391 .33763 .54509 .34727 .54384 .34125 .53686 Mtetra
0 .032 .558 r
.34125 .53686 .34727 .54384 .35742 .53334 .35041 .54623 Mtetra
0 0 0 r
.35041 .54623 .35742 .53334 .36706 .5337 .36106 .52722 Mtetra
.61 .711 .916 r
.36106 .52722 .36706 .5337 .37687 .53116 .37087 .5252 Mtetra
.642 .74 .92 r
.37087 .5252 .37687 .53116 .38675 .52826 .38076 .52239 Mtetra
.65 .747 .92 r
.38076 .52239 .38675 .52826 .39666 .52522 .39069 .51939 Mtetra
.654 .75 .92 r
.39069 .51939 .39666 .52522 .40661 .5221 .40067 .51627 Mtetra
.656 .752 .92 r
.40067 .51627 .40661 .5221 .41661 .51891 .41068 .51309 Mtetra
.658 .753 .92 r
.41068 .51309 .41661 .51891 .42664 .51569 .42074 .50986 Mtetra
.659 .753 .92 r
.42074 .50986 .42664 .51569 .43671 .51244 .43083 .5066 Mtetra
.659 .754 .92 r
.43083 .5066 .43671 .51244 .44681 .50918 .44096 .50331 Mtetra
.44096 .50331 .44681 .50918 .45695 .5059 .45113 .50001 Mtetra
.45113 .50001 .45695 .5059 .46713 .50262 .46133 .4967 Mtetra
.659 .753 .92 r
.46133 .4967 .46713 .50262 .47735 .49934 .47157 .49339 Mtetra
.658 .753 .92 r
.47157 .49339 .47735 .49934 .48761 .49605 .48185 .49008 Mtetra
.48185 .49008 .48761 .49605 .4979 .49275 .49217 .48675 Mtetra
.49217 .48675 .4979 .49275 .50823 .48944 .50253 .48342 Mtetra
.50253 .48342 .50823 .48944 .5186 .48612 .51293 .48008 Mtetra
.51293 .48008 .5186 .48612 .52901 .4828 .52336 .47673 Mtetra
.52336 .47673 .52901 .4828 .53946 .47946 .53384 .47337 Mtetra
.657 .753 .92 r
.53384 .47337 .53946 .47946 .54995 .47611 .54435 .47 Mtetra
.54435 .47 .54995 .47611 .56048 .47275 .55491 .46661 Mtetra
.55491 .46661 .56048 .47275 .57105 .46938 .5655 .46322 Mtetra
.657 .752 .92 r
.5655 .46322 .57105 .46938 .58166 .466 .57614 .45981 Mtetra
.57614 .45981 .58166 .466 .5923 .46261 .58681 .45639 Mtetra
.58681 .45639 .5923 .46261 .60299 .4592 .59753 .45296 Mtetra
.59753 .45296 .60299 .4592 .61372 .45578 .60829 .44952 Mtetra
.60829 .44952 .61372 .45578 .6245 .45235 .61909 .44607 Mtetra
.61909 .44607 .6245 .45235 .63531 .44891 .62993 .4426 Mtetra
.62993 .4426 .63531 .44891 .64616 .44546 .64081 .43912 Mtetra
.64081 .43912 .64616 .44546 .65706 .44199 .65174 .43563 Mtetra
.65174 .43563 .65706 .44199 .668 .43851 .66271 .43212 Mtetra
.66271 .43212 .668 .43851 .67898 .43502 .67372 .4286 Mtetra
.67372 .4286 .67898 .43502 .69001 .43151 .68477 .42507 Mtetra
.68477 .42507 .69001 .43151 .70107 .42799 .69587 .42153 Mtetra
.69587 .42153 .70107 .42799 .71218 .42446 .70701 .41797 Mtetra
.70701 .41797 .71218 .42446 .72334 .42091 .71819 .4144 Mtetra
.71819 .4144 .72334 .42091 .73453 .41736 .72942 .41081 Mtetra
.72942 .41081 .73453 .41736 .74577 .41378 .74069 .40721 Mtetra
.74069 .40721 .74577 .41378 .75706 .4102 .75201 .4036 Mtetra
.75201 .4036 .75706 .4102 .76839 .4066 .76337 .39998 Mtetra
.76337 .39998 .76839 .4066 .77976 .40298 .77478 .39634 Mtetra
.77478 .39634 .77976 .40298 .79118 .39936 .78623 .39268 Mtetra
.78623 .39268 .79118 .39936 .80265 .39571 .79773 .38901 Mtetra
.79773 .38901 .80265 .39571 .81416 .39206 .80927 .38533 Mtetra
.80927 .38533 .81416 .39206 .82571 .38839 .82086 .38163 Mtetra
.82086 .38163 .82571 .38839 .83732 .3847 .83249 .37792 Mtetra
.83249 .37792 .83732 .3847 .84897 .38101 .84418 .3742 Mtetra
.84418 .3742 .84897 .38101 .86066 .37729 .85591 .37045 Mtetra
.85591 .37045 .86066 .37729 .8724 .37356 .86768 .3667 Mtetra
.427 .531 .86 r
.23951 .55408 .24549 .56374 .25481 .56228 .24854 .55621 Mtetra
.617 .722 .921 r
.24854 .55621 .25481 .56228 .26423 .55999 .25796 .55409 Mtetra
.625 .731 .923 r
.25796 .55409 .26423 .55999 .27368 .55785 .26744 .55177 Mtetra
.589 .714 .93 r
.26744 .55177 .27368 .55785 .28289 .55955 .27691 .55018 Mtetra
.811 .694 .737 r
.27691 .55018 .28289 .55955 .29305 .54835 .28727 .53646 Mtetra
.35 .438 .811 r
.28727 .53646 .29305 .54835 .30256 .54694 .29638 .54078 Mtetra
.621 .723 .92 r
.29638 .54078 .30256 .54694 .31217 .54443 .306 .53853 Mtetra
.638 .738 .921 r
.306 .53853 .31217 .54443 .32184 .54175 .31568 .53588 Mtetra
.64 .74 .922 r
.31568 .53588 .32184 .54175 .33154 .5391 .32541 .53316 Mtetra
.633 .737 .923 r
.32541 .53316 .33154 .5391 .34125 .53686 .33516 .5306 Mtetra
.572 .705 .933 r
.33516 .5306 .34125 .53686 .35041 .54623 .34488 .5293 Mtetra
.722 .588 .704 r
.34488 .5293 .35041 .54623 .36106 .52722 .35512 .51872 Mtetra
.512 .609 .886 r
.35512 .51872 .36106 .52722 .37087 .5252 .36483 .51904 Mtetra
.633 .732 .919 r
.36483 .51904 .37087 .5252 .38076 .52239 .37473 .51645 Mtetra
.647 .744 .92 r
.37473 .51645 .38076 .52239 .39069 .51939 .38468 .51349 Mtetra
.652 .748 .92 r
.38468 .51349 .39069 .51939 .40067 .51627 .39468 .5104 Mtetra
.655 .751 .92 r
.39468 .5104 .40067 .51627 .41068 .51309 .40472 .50722 Mtetra
.657 .752 .92 r
.40472 .50722 .41068 .51309 .42074 .50986 .4148 .50398 Mtetra
.658 .753 .92 r
.4148 .50398 .42074 .50986 .43083 .5066 .42491 .50071 Mtetra
.659 .754 .92 r
.42491 .50071 .43083 .5066 .44096 .50331 .43507 .4974 Mtetra
.43507 .4974 .44096 .50331 .45113 .50001 .44526 .49408 Mtetra
.44526 .49408 .45113 .50001 .46133 .4967 .45549 .49075 Mtetra
.45549 .49075 .46133 .4967 .47157 .49339 .46575 .48741 Mtetra
.658 .753 .92 r
.46575 .48741 .47157 .49339 .48185 .49008 .47606 .48407 Mtetra
.47606 .48407 .48185 .49008 .49217 .48675 .4864 .48072 Mtetra
.4864 .48072 .49217 .48675 .50253 .48342 .49679 .47736 Mtetra
.49679 .47736 .50253 .48342 .51293 .48008 .50721 .47399 Mtetra
.50721 .47399 .51293 .48008 .52336 .47673 .51767 .47062 Mtetra
.51767 .47062 .52336 .47673 .53384 .47337 .52817 .46723 Mtetra
.52817 .46723 .53384 .47337 .54435 .47 .53871 .46384 Mtetra
.657 .753 .92 r
.53871 .46384 .54435 .47 .55491 .46661 .5493 .46043 Mtetra
.5493 .46043 .55491 .46661 .5655 .46322 .55992 .45701 Mtetra
.657 .752 .92 r
.55992 .45701 .5655 .46322 .57614 .45981 .57058 .45358 Mtetra
.57058 .45358 .57614 .45981 .58681 .45639 .58128 .45014 Mtetra
.58128 .45014 .58681 .45639 .59753 .45296 .59203 .44668 Mtetra
.59203 .44668 .59753 .45296 .60829 .44952 .60282 .44321 Mtetra
.60282 .44321 .60829 .44952 .61909 .44607 .61364 .43973 Mtetra
.61364 .43973 .61909 .44607 .62993 .4426 .62451 .43624 Mtetra
.62451 .43624 .62993 .4426 .64081 .43912 .63543 .43274 Mtetra
.63543 .43274 .64081 .43912 .65174 .43563 .64638 .42922 Mtetra
.64638 .42922 .65174 .43563 .66271 .43212 .65738 .42569 Mtetra
.65738 .42569 .66271 .43212 .67372 .4286 .66842 .42214 Mtetra
.66842 .42214 .67372 .4286 .68477 .42507 .6795 .41859 Mtetra
.6795 .41859 .68477 .42507 .69587 .42153 .69063 .41502 Mtetra
.69063 .41502 .69587 .42153 .70701 .41797 .7018 .41143 Mtetra
.7018 .41143 .70701 .41797 .71819 .4144 .71301 .40783 Mtetra
.71301 .40783 .71819 .4144 .72942 .41081 .72427 .40422 Mtetra
.72427 .40422 .72942 .41081 .74069 .40721 .73558 .4006 Mtetra
.73558 .4006 .74069 .40721 .75201 .4036 .74692 .39696 Mtetra
.74692 .39696 .75201 .4036 .76337 .39998 .75832 .39331 Mtetra
.75832 .39331 .76337 .39998 .77478 .39634 .76976 .38964 Mtetra
.76976 .38964 .77478 .39634 .78623 .39268 .78124 .38596 Mtetra
.78124 .38596 .78623 .39268 .79773 .38901 .79277 .38226 Mtetra
.79277 .38226 .79773 .38901 .80927 .38533 .80434 .37855 Mtetra
.80434 .37855 .80927 .38533 .82086 .38163 .81597 .37483 Mtetra
.81597 .37483 .82086 .38163 .83249 .37792 .82764 .37109 Mtetra
.82764 .37109 .83249 .37792 .84418 .3742 .83935 .36733 Mtetra
.83935 .36733 .84418 .3742 .85591 .37045 .85112 .36357 Mtetra
.85112 .36357 .85591 .37045 .86768 .3667 .86293 .35978 Mtetra
.648 .884 .533 r
.23193 .56252 .23951 .55408 .24854 .55621 .24227 .54962 Mtetra
.589 .696 .917 r
.24227 .54962 .24854 .55621 .25796 .55409 .25166 .54811 Mtetra
.625 .73 .922 r
.25166 .54811 .25796 .55409 .26744 .55177 .26116 .54577 Mtetra
.618 .728 .925 r
.26116 .54577 .26744 .55177 .27691 .55018 .27068 .54358 Mtetra
.368 .602 .938 r
.27068 .54358 .27691 .55018 .28727 .53646 .27996 .54525 Mtetra
0 0 0 r
.27996 .54525 .28727 .53646 .29638 .54078 .29021 .53396 Mtetra
.586 .691 .914 r
.29021 .53396 .29638 .54078 .306 .53853 .29979 .5325 Mtetra
.633 .734 .921 r
.29979 .5325 .306 .53853 .31568 .53588 .30949 .52995 Mtetra
.64 .74 .921 r
.30949 .52995 .31568 .53588 .32541 .53316 .31923 .52721 Mtetra
.638 .74 .922 r
.31923 .52721 .32541 .53316 .33516 .5306 .32901 .52451 Mtetra
.619 .73 .925 r
.32901 .52451 .33516 .5306 .34488 .5293 .3388 .52222 Mtetra
0 .038 .565 r
.3388 .52222 .34488 .5293 .35512 .51872 .34802 .53159 Mtetra
0 0 0 r
.34802 .53159 .35512 .51872 .36483 .51904 .35877 .51245 Mtetra
.61 .711 .916 r
.35877 .51245 .36483 .51904 .37473 .51645 .36867 .51038 Mtetra
.642 .74 .92 r
.36867 .51038 .37473 .51645 .38468 .51349 .37864 .50753 Mtetra
.65 .747 .92 r
.37864 .50753 .38468 .51349 .39468 .5104 .38866 .50446 Mtetra
.654 .75 .92 r
.38866 .50446 .39468 .5104 .40472 .50722 .39872 .5013 Mtetra
.656 .752 .92 r
.39872 .5013 .40472 .50722 .4148 .50398 .40882 .49806 Mtetra
.658 .753 .92 r
.40882 .49806 .4148 .50398 .42491 .50071 .41895 .49477 Mtetra
.659 .753 .92 r
.41895 .49477 .42491 .50071 .43507 .4974 .42913 .49145 Mtetra
.659 .754 .92 r
.42913 .49145 .43507 .4974 .44526 .49408 .43935 .48811 Mtetra
.43935 .48811 .44526 .49408 .45549 .49075 .4496 .48475 Mtetra
.4496 .48475 .45549 .49075 .46575 .48741 .45989 .48139 Mtetra
.659 .753 .92 r
.45989 .48139 .46575 .48741 .47606 .48407 .47023 .47802 Mtetra
.658 .753 .92 r
.47023 .47802 .47606 .48407 .4864 .48072 .4806 .47464 Mtetra
.4806 .47464 .4864 .48072 .49679 .47736 .491 .47126 Mtetra
.491 .47126 .49679 .47736 .50721 .47399 .50145 .46787 Mtetra
.50145 .46787 .50721 .47399 .51767 .47062 .51194 .46447 Mtetra
.51194 .46447 .51767 .47062 .52817 .46723 .52247 .46105 Mtetra
.52247 .46105 .52817 .46723 .53871 .46384 .53304 .45763 Mtetra
.657 .753 .92 r
.53304 .45763 .53871 .46384 .5493 .46043 .54365 .4542 Mtetra
.54365 .4542 .5493 .46043 .55992 .45701 .55429 .45076 Mtetra
.55429 .45076 .55992 .45701 .57058 .45358 .56498 .4473 Mtetra
.657 .752 .92 r
.56498 .4473 .57058 .45358 .58128 .45014 .57572 .44383 Mtetra
.57572 .44383 .58128 .45014 .59203 .44668 .58649 .44035 Mtetra
.58649 .44035 .59203 .44668 .60282 .44321 .5973 .43686 Mtetra
.5973 .43686 .60282 .44321 .61364 .43973 .60816 .43336 Mtetra
.60816 .43336 .61364 .43973 .62451 .43624 .61906 .42984 Mtetra
.61906 .42984 .62451 .43624 .63543 .43274 .63 .42631 Mtetra
.63 .42631 .63543 .43274 .64638 .42922 .64098 .42276 Mtetra
.64098 .42276 .64638 .42922 .65738 .42569 .65201 .41921 Mtetra
.65201 .41921 .65738 .42569 .66842 .42214 .66308 .41564 Mtetra
.66308 .41564 .66842 .42214 .6795 .41859 .67419 .41205 Mtetra
.67419 .41205 .6795 .41859 .69063 .41502 .68535 .40846 Mtetra
.68535 .40846 .69063 .41502 .7018 .41143 .69655 .40485 Mtetra
.69655 .40485 .7018 .41143 .71301 .40783 .7078 .40122 Mtetra
.7078 .40122 .71301 .40783 .72427 .40422 .71909 .39758 Mtetra
.71909 .39758 .72427 .40422 .73558 .4006 .73042 .39393 Mtetra
.73042 .39393 .73558 .4006 .74692 .39696 .7418 .39027 Mtetra
.7418 .39027 .74692 .39696 .75832 .39331 .75322 .38659 Mtetra
.75322 .38659 .75832 .39331 .76976 .38964 .7647 .38289 Mtetra
.7647 .38289 .76976 .38964 .78124 .38596 .77621 .37918 Mtetra
.77621 .37918 .78124 .38596 .79277 .38226 .78777 .37546 Mtetra
.78777 .37546 .79277 .38226 .80434 .37855 .79938 .37172 Mtetra
.79938 .37172 .80434 .37855 .81597 .37483 .81104 .36797 Mtetra
.81104 .36797 .81597 .37483 .82764 .37109 .82274 .3642 Mtetra
.82274 .3642 .82764 .37109 .83935 .36733 .83449 .36042 Mtetra
.83449 .36042 .83935 .36733 .85112 .36357 .84629 .35662 Mtetra
.84629 .35662 .85112 .36357 .86293 .35978 .85813 .35281 Mtetra
.773 .659 .738 r
.226 .55131 .23193 .56252 .24227 .54962 .23623 .53984 Mtetra
.427 .531 .86 r
.23623 .53984 .24227 .54962 .25166 .54811 .24532 .54194 Mtetra
.617 .722 .921 r
.24532 .54194 .25166 .54811 .26116 .54577 .25482 .53977 Mtetra
.625 .731 .923 r
.25482 .53977 .26116 .54577 .27068 .54358 .26438 .5374 Mtetra
.589 .714 .93 r
.26438 .5374 .27068 .54358 .27996 .54525 .27392 .53577 Mtetra
.811 .695 .737 r
.27392 .53577 .27996 .54525 .29021 .53396 .28438 .52195 Mtetra
.349 .438 .811 r
.28438 .52195 .29021 .53396 .29979 .5325 .29356 .52624 Mtetra
.621 .723 .92 r
.29356 .52624 .29979 .5325 .30949 .52995 .30325 .52394 Mtetra
.638 .738 .921 r
.30325 .52394 .30949 .52995 .31923 .52721 .31301 .52124 Mtetra
.64 .74 .922 r
.31301 .52124 .31923 .52721 .32901 .52451 .32281 .51847 Mtetra
.633 .737 .923 r
.32281 .51847 .32901 .52451 .3388 .52222 .33265 .51586 Mtetra
.572 .705 .932 r
.33265 .51586 .3388 .52222 .34802 .53159 .34245 .51451 Mtetra
.722 .588 .704 r
.34245 .51451 .34802 .53159 .35877 .51245 .35278 .50385 Mtetra
.511 .609 .887 r
.35278 .50385 .35877 .51245 .36867 .51038 .36257 .50413 Mtetra
.633 .732 .919 r
.36257 .50413 .36867 .51038 .37864 .50753 .37255 .50148 Mtetra
.647 .744 .92 r
.37255 .50148 .37864 .50753 .38866 .50446 .38259 .49847 Mtetra
.652 .748 .92 r
.38259 .49847 .38866 .50446 .39872 .5013 .39267 .49532 Mtetra
.655 .751 .92 r
.39267 .49532 .39872 .5013 .40882 .49806 .40279 .49208 Mtetra
.657 .752 .92 r
.40279 .49208 .40882 .49806 .41895 .49477 .41295 .48879 Mtetra
.658 .753 .92 r
.41295 .48879 .41895 .49477 .42913 .49145 .42316 .48545 Mtetra
.659 .754 .92 r
.42316 .48545 .42913 .49145 .43935 .48811 .4334 .48209 Mtetra
.4334 .48209 .43935 .48811 .4496 .48475 .44368 .47871 Mtetra
.44368 .47871 .4496 .48475 .45989 .48139 .45399 .47532 Mtetra
.45399 .47532 .45989 .48139 .47023 .47802 .46435 .47192 Mtetra
.658 .753 .92 r
.46435 .47192 .47023 .47802 .4806 .47464 .47475 .46852 Mtetra
.47475 .46852 .4806 .47464 .491 .47126 .48518 .46511 Mtetra
.48518 .46511 .491 .47126 .50145 .46787 .49565 .4617 Mtetra
.49565 .4617 .50145 .46787 .51194 .46447 .50617 .45827 Mtetra
.50617 .45827 .51194 .46447 .52247 .46105 .51672 .45483 Mtetra
.51672 .45483 .52247 .46105 .53304 .45763 .52732 .45139 Mtetra
.52732 .45139 .53304 .45763 .54365 .4542 .53795 .44793 Mtetra
.657 .753 .92 r
.53795 .44793 .54365 .4542 .55429 .45076 .54863 .44446 Mtetra
.54863 .44446 .55429 .45076 .56498 .4473 .55935 .44098 Mtetra
.657 .752 .92 r
.55935 .44098 .56498 .4473 .57572 .44383 .57011 .43748 Mtetra
.57011 .43748 .57572 .44383 .58649 .44035 .58091 .43398 Mtetra
.58091 .43398 .58649 .44035 .5973 .43686 .59175 .43046 Mtetra
.59175 .43046 .5973 .43686 .60816 .43336 .60264 .42693 Mtetra
.60264 .42693 .60816 .43336 .61906 .42984 .61356 .42339 Mtetra
.61356 .42339 .61906 .42984 .63 .42631 .62453 .41983 Mtetra
.62453 .41983 .63 .42631 .64098 .42276 .63555 .41626 Mtetra
.63555 .41626 .64098 .42276 .65201 .41921 .6466 .41268 Mtetra
.6466 .41268 .65201 .41921 .66308 .41564 .6577 .40908 Mtetra
.6577 .40908 .66308 .41564 .67419 .41205 .66884 .40547 Mtetra
.66884 .40547 .67419 .41205 .68535 .40846 .68003 .40185 Mtetra
.68003 .40185 .68535 .40846 .69655 .40485 .69126 .39821 Mtetra
.69126 .39821 .69655 .40485 .7078 .40122 .70254 .39456 Mtetra
.70254 .39456 .7078 .40122 .71909 .39758 .71386 .3909 Mtetra
.71386 .3909 .71909 .39758 .73042 .39393 .72523 .38722 Mtetra
.72523 .38722 .73042 .39393 .7418 .39027 .73664 .38353 Mtetra
.73664 .38353 .7418 .39027 .75322 .38659 .74809 .37982 Mtetra
.74809 .37982 .75322 .38659 .7647 .38289 .7596 .3761 Mtetra
.7596 .3761 .7647 .38289 .77621 .37918 .77115 .37236 Mtetra
.77115 .37236 .77621 .37918 .78777 .37546 .78274 .36861 Mtetra
.78274 .36861 .78777 .37546 .79938 .37172 .79438 .36484 Mtetra
.79438 .36484 .79938 .37172 .81104 .36797 .80607 .36106 Mtetra
.80607 .36106 .81104 .36797 .82274 .3642 .81781 .35727 Mtetra
.81781 .35727 .82274 .3642 .83449 .36042 .82959 .35346 Mtetra
.82959 .35346 .83449 .36042 .84629 .35662 .84143 .34963 Mtetra
.84143 .34963 .84629 .35662 .85813 .35281 .85331 .34579 Mtetra
.144 .473 .894 r
.21963 .54452 .226 .55131 .23623 .53984 .22856 .54825 Mtetra
.658 .891 .543 r
.22856 .54825 .23623 .53984 .24532 .54194 .23899 .53525 Mtetra
.589 .696 .917 r
.23899 .53525 .24532 .54194 .25482 .53977 .24846 .53369 Mtetra
.625 .73 .922 r
.24846 .53369 .25482 .53977 .26438 .5374 .25803 .53131 Mtetra
.618 .728 .925 r
.25803 .53131 .26438 .5374 .27392 .53577 .26763 .52907 Mtetra
.369 .602 .938 r
.26763 .52907 .27392 .53577 .28438 .52195 .27698 .5307 Mtetra
0 0 0 r
.27698 .5307 .28438 .52195 .29356 .52624 .28732 .51933 Mtetra
.586 .691 .914 r
.28732 .51933 .29356 .52624 .30325 .52394 .29698 .51781 Mtetra
.633 .734 .921 r
.29698 .51781 .30325 .52394 .31301 .52124 .30675 .51521 Mtetra
.64 .74 .921 r
.30675 .51521 .31301 .52124 .32281 .51847 .31658 .51242 Mtetra
.638 .74 .922 r
.31658 .51242 .32281 .51847 .33265 .51586 .32644 .50967 Mtetra
.619 .73 .925 r
.32644 .50967 .33265 .51586 .34245 .51451 .33631 .50732 Mtetra
0 .044 .571 r
.33631 .50732 .34245 .51451 .35278 .50385 .3456 .5167 Mtetra
0 0 0 r
.3456 .5167 .35278 .50385 .36257 .50413 .35645 .49743 Mtetra
.61 .711 .916 r
.35645 .49743 .36257 .50413 .37255 .50148 .36643 .49531 Mtetra
.642 .74 .92 r
.36643 .49531 .37255 .50148 .38259 .49847 .37648 .4924 Mtetra
.65 .747 .92 r
.37648 .4924 .38259 .49847 .39267 .49532 .38658 .48928 Mtetra
.654 .75 .92 r
.38658 .48928 .39267 .49532 .40279 .49208 .39673 .48605 Mtetra
.656 .752 .92 r
.39673 .48605 .40279 .49208 .41295 .48879 .40691 .48276 Mtetra
.658 .753 .92 r
.40691 .48276 .41295 .48879 .42316 .48545 .41714 .47941 Mtetra
.659 .753 .92 r
.41714 .47941 .42316 .48545 .4334 .48209 .4274 .47603 Mtetra
.659 .754 .92 r
.4274 .47603 .4334 .48209 .44368 .47871 .43771 .47263 Mtetra
.43771 .47263 .44368 .47871 .45399 .47532 .44805 .46921 Mtetra
.44805 .46921 .45399 .47532 .46435 .47192 .45843 .46579 Mtetra
.659 .753 .92 r
.45843 .46579 .46435 .47192 .47475 .46852 .46885 .46236 Mtetra
.658 .753 .92 r
.46885 .46236 .47475 .46852 .48518 .46511 .47932 .45893 Mtetra
.47932 .45893 .48518 .46511 .49565 .4617 .48982 .45548 Mtetra
.48982 .45548 .49565 .4617 .50617 .45827 .50036 .45203 Mtetra
.50036 .45203 .50617 .45827 .51672 .45483 .51094 .44857 Mtetra
.51094 .44857 .51672 .45483 .52732 .45139 .52156 .4451 Mtetra
.52156 .4451 .52732 .45139 .53795 .44793 .53222 .44161 Mtetra
.657 .753 .92 r
.53222 .44161 .53795 .44793 .54863 .44446 .54293 .43812 Mtetra
.54293 .43812 .54863 .44446 .55935 .44098 .55367 .43461 Mtetra
.55367 .43461 .55935 .44098 .57011 .43748 .56446 .43109 Mtetra
.657 .752 .92 r
.56446 .43109 .57011 .43748 .58091 .43398 .57529 .42756 Mtetra
.57529 .42756 .58091 .43398 .59175 .43046 .58616 .42402 Mtetra
.58616 .42402 .59175 .43046 .60264 .42693 .59707 .42046 Mtetra
.59707 .42046 .60264 .42693 .61356 .42339 .60803 .41689 Mtetra
.60803 .41689 .61356 .42339 .62453 .41983 .61903 .41331 Mtetra
.61903 .41331 .62453 .41983 .63555 .41626 .63007 .40971 Mtetra
.63007 .40971 .63555 .41626 .6466 .41268 .64115 .4061 Mtetra
.64115 .4061 .6466 .41268 .6577 .40908 .65228 .40248 Mtetra
.65228 .40248 .6577 .40908 .66884 .40547 .66346 .39884 Mtetra
.66346 .39884 .66884 .40547 .68003 .40185 .67467 .39519 Mtetra
.67467 .39519 .68003 .40185 .69126 .39821 .68594 .39153 Mtetra
.68594 .39153 .69126 .39821 .70254 .39456 .69724 .38785 Mtetra
.69724 .38785 .70254 .39456 .71386 .3909 .7086 .38416 Mtetra
.7086 .38416 .71386 .3909 .72523 .38722 .71999 .38046 Mtetra
.71999 .38046 .72523 .38722 .73664 .38353 .73144 .37673 Mtetra
.73144 .37673 .73664 .38353 .74809 .37982 .74293 .373 Mtetra
.74293 .373 .74809 .37982 .7596 .3761 .75446 .36925 Mtetra
.75446 .36925 .7596 .3761 .77115 .37236 .76604 .36549 Mtetra
.76604 .36549 .77115 .37236 .78274 .36861 .77767 .36171 Mtetra
.77767 .36171 .78274 .36861 .79438 .36484 .78935 .35791 Mtetra
.78935 .35791 .79438 .36484 .80607 .36106 .80107 .3541 Mtetra
.80107 .3541 .80607 .36106 .81781 .35727 .81284 .35028 Mtetra
.81284 .35028 .81781 .35727 .82959 .35346 .82466 .34644 Mtetra
.82466 .34644 .82959 .35346 .84143 .34963 .83653 .34259 Mtetra
.83653 .34259 .84143 .34963 .85331 .34579 .84844 .33872 Mtetra
.572 .705 .932 r
.21318 .53824 .21963 .54452 .22856 .54825 .22257 .53691 Mtetra
.773 .66 .738 r
.22257 .53691 .22856 .54825 .23899 .53525 .23289 .52535 Mtetra
.426 .53 .861 r
.23289 .52535 .23899 .53525 .24846 .53369 .24206 .52742 Mtetra
.617 .722 .921 r
.24206 .52742 .24846 .53369 .25803 .53131 .25163 .52521 Mtetra
.625 .731 .923 r
.25163 .52521 .25803 .53131 .26763 .52907 .26126 .52278 Mtetra
.589 .714 .93 r
.26126 .52278 .26763 .52907 .27698 .5307 .27088 .5211 Mtetra
.812 .696 .737 r
.27088 .5211 .27698 .5307 .28732 .51933 .28143 .50718 Mtetra
.347 .437 .811 r
.28143 .50718 .28732 .51933 .29698 .51781 .29068 .51145 Mtetra
.621 .723 .92 r
.29068 .51145 .29698 .51781 .30675 .51521 .30045 .5091 Mtetra
.638 .738 .921 r
.30045 .5091 .30675 .51521 .31658 .51242 .31029 .50634 Mtetra
.64 .74 .922 r
.31029 .50634 .31658 .51242 .32644 .50967 .32018 .50352 Mtetra
.633 .737 .923 r
.32018 .50352 .32644 .50967 .33631 .50732 .33009 .50085 Mtetra
.572 .705 .932 r
.33009 .50085 .33631 .50732 .3456 .5167 .33997 .49946 Mtetra
.722 .588 .704 r
.33997 .49946 .3456 .5167 .35645 .49743 .3504 .48871 Mtetra
.511 .609 .887 r
.3504 .48871 .35645 .49743 .36643 .49531 .36027 .48895 Mtetra
.633 .732 .919 r
.36027 .48895 .36643 .49531 .37648 .4924 .37033 .48624 Mtetra
.647 .744 .92 r
.37033 .48624 .37648 .4924 .38658 .48928 .38045 .48318 Mtetra
.652 .749 .92 r
.38045 .48318 .38658 .48928 .39673 .48605 .39062 .47997 Mtetra
.655 .751 .92 r
.39062 .47997 .39673 .48605 .40691 .48276 .40083 .47668 Mtetra
.657 .752 .92 r
.40083 .47668 .40691 .48276 .41714 .47941 .41108 .47332 Mtetra
.658 .753 .92 r
.41108 .47332 .41714 .47941 .4274 .47603 .42137 .46993 Mtetra
.659 .754 .92 r
.42137 .46993 .4274 .47603 .43771 .47263 .4317 .46651 Mtetra
.4317 .46651 .43771 .47263 .44805 .46921 .44207 .46306 Mtetra
.44207 .46306 .44805 .46921 .45843 .46579 .45247 .45961 Mtetra
.45247 .45961 .45843 .46579 .46885 .46236 .46292 .45616 Mtetra
.658 .753 .92 r
.46292 .45616 .46885 .46236 .47932 .45893 .47341 .45269 Mtetra
.47341 .45269 .47932 .45893 .48982 .45548 .48394 .44922 Mtetra
.48394 .44922 .48982 .45548 .50036 .45203 .4945 .44575 Mtetra
.4945 .44575 .50036 .45203 .51094 .44857 .50511 .44226 Mtetra
.50511 .44226 .51094 .44857 .52156 .4451 .51576 .43876 Mtetra
.51576 .43876 .52156 .4451 .53222 .44161 .52645 .43525 Mtetra
.52645 .43525 .53222 .44161 .54293 .43812 .53718 .43173 Mtetra
.657 .753 .92 r
.53718 .43173 .54293 .43812 .55367 .43461 .54795 .4282 Mtetra
.54795 .4282 .55367 .43461 .56446 .43109 .55877 .42465 Mtetra
.657 .752 .92 r
.55877 .42465 .56446 .43109 .57529 .42756 .56962 .42109 Mtetra
.56962 .42109 .57529 .42756 .58616 .42402 .58052 .41753 Mtetra
.58052 .41753 .58616 .42402 .59707 .42046 .59147 .41394 Mtetra
.59147 .41394 .59707 .42046 .60803 .41689 .60245 .41035 Mtetra
.60245 .41035 .60803 .41689 .61903 .41331 .61348 .40674 Mtetra
.61348 .40674 .61903 .41331 .63007 .40971 .62455 .40312 Mtetra
.62455 .40312 .63007 .40971 .64115 .4061 .63567 .39948 Mtetra
.63567 .39948 .64115 .4061 .65228 .40248 .64683 .39583 Mtetra
.64683 .39583 .65228 .40248 .66346 .39884 .65803 .39217 Mtetra
.65803 .39217 .66346 .39884 .67467 .39519 .66928 .38849 Mtetra
.66928 .38849 .67467 .39519 .68594 .39153 .68057 .3848 Mtetra
.68057 .3848 .68594 .39153 .69724 .38785 .69191 .38109 Mtetra
.69191 .38109 .69724 .38785 .7086 .38416 .70329 .37737 Mtetra
.70329 .37737 .7086 .38416 .71999 .38046 .71472 .37364 Mtetra
.71472 .37364 .71999 .38046 .73144 .37673 .7262 .36989 Mtetra
.7262 .36989 .73144 .37673 .74293 .373 .73772 .36613 Mtetra
.73772 .36613 .74293 .373 .75446 .36925 .74929 .36235 Mtetra
.74929 .36235 .75446 .36925 .76604 .36549 .7609 .35856 Mtetra
.7609 .35856 .76604 .36549 .77767 .36171 .77256 .35475 Mtetra
.77256 .35475 .77767 .36171 .78935 .35791 .78427 .35093 Mtetra
.78427 .35093 .78935 .35791 .80107 .3541 .79603 .34709 Mtetra
.79603 .34709 .80107 .3541 .81284 .35028 .80784 .34324 Mtetra
.80784 .34324 .81284 .35028 .82466 .34644 .81969 .33937 Mtetra
.81969 .33937 .82466 .34644 .83653 .34259 .83159 .33549 Mtetra
.83159 .33549 .83653 .34259 .84844 .33872 .84354 .33159 Mtetra
.608 .722 .926 r
.20667 .53205 .21318 .53824 .22257 .53691 .21614 .53002 Mtetra
.147 .474 .895 r
.21614 .53002 .22257 .53691 .23289 .52535 .22514 .53372 Mtetra
.667 .897 .552 r
.22514 .53372 .23289 .52535 .24206 .52742 .23566 .52062 Mtetra
.589 .696 .917 r
.23566 .52062 .24206 .52742 .25163 .52521 .2452 .51902 Mtetra
.625 .73 .922 r
.2452 .51902 .25163 .52521 .26126 .52278 .25485 .51659 Mtetra
.618 .728 .925 r
.25485 .51659 .26126 .52278 .27088 .5211 .26452 .5143 Mtetra
.37 .602 .938 r
.26452 .5143 .27088 .5211 .28143 .50718 .27395 .5159 Mtetra
0 0 0 r
.27395 .5159 .28143 .50718 .29068 .51145 .28438 .50443 Mtetra
.586 .691 .914 r
.28438 .50443 .29068 .51145 .30045 .5091 .29412 .50287 Mtetra
.633 .734 .921 r
.29412 .50287 .30045 .5091 .31029 .50634 .30397 .50021 Mtetra
.64 .74 .921 r
.30397 .50021 .31029 .50634 .32018 .50352 .31387 .49737 Mtetra
.638 .74 .922 r
.31387 .49737 .32018 .50352 .33009 .50085 .32382 .49456 Mtetra
.619 .73 .925 r
.32382 .49456 .33009 .50085 .33997 .49946 .33377 .49216 Mtetra
0 .05 .578 r
.33377 .49216 .33997 .49946 .3504 .48871 .34313 .50153 Mtetra
.618 .789 .35 r
.34313 .50153 .3504 .48871 .36027 .48895 .35409 .48214 Mtetra
.61 .711 .916 r
.35409 .48214 .36027 .48895 .37033 .48624 .36414 .47997 Mtetra
.642 .74 .92 r
.36414 .47997 .37033 .48624 .38045 .48318 .37428 .477 Mtetra
.65 .747 .92 r
.37428 .477 .38045 .48318 .39062 .47997 .38447 .47382 Mtetra
.654 .75 .92 r
.38447 .47382 .39062 .47997 .40083 .47668 .3947 .47054 Mtetra
.656 .752 .92 r
.3947 .47054 .40083 .47668 .41108 .47332 .40498 .46718 Mtetra
.658 .753 .92 r
.40498 .46718 .41108 .47332 .42137 .46993 .41529 .46378 Mtetra
.659 .753 .92 r
.41529 .46378 .42137 .46993 .4317 .46651 .42565 .46034 Mtetra
.659 .754 .92 r
.42565 .46034 .4317 .46651 .44207 .46306 .43604 .45687 Mtetra
.43604 .45687 .44207 .46306 .45247 .45961 .44647 .4534 Mtetra
.44647 .4534 .45247 .45961 .46292 .45616 .45695 .44991 Mtetra
.659 .753 .92 r
.45695 .44991 .46292 .45616 .47341 .45269 .46746 .44642 Mtetra
.658 .753 .92 r
.46746 .44642 .47341 .45269 .48394 .44922 .47801 .44292 Mtetra
.47801 .44292 .48394 .44922 .4945 .44575 .48861 .43942 Mtetra
.48861 .43942 .4945 .44575 .50511 .44226 .49924 .4359 Mtetra
.49924 .4359 .50511 .44226 .51576 .43876 .50992 .43238 Mtetra
.50992 .43238 .51576 .43876 .52645 .43525 .52063 .42884 Mtetra
.52063 .42884 .52645 .43525 .53718 .43173 .53139 .4253 Mtetra
.657 .753 .92 r
.53139 .4253 .53718 .43173 .54795 .4282 .54219 .42174 Mtetra
.54219 .42174 .54795 .4282 .55877 .42465 .55304 .41817 Mtetra
.55304 .41817 .55877 .42465 .56962 .42109 .56392 .41458 Mtetra
.657 .752 .92 r
.56392 .41458 .56962 .42109 .58052 .41753 .57485 .41099 Mtetra
.57485 .41099 .58052 .41753 .59147 .41394 .58582 .40738 Mtetra
.58582 .40738 .59147 .41394 .60245 .41035 .59683 .40376 Mtetra
.59683 .40376 .60245 .41035 .61348 .40674 .60789 .40012 Mtetra
.60789 .40012 .61348 .40674 .62455 .40312 .61899 .39647 Mtetra
.61899 .39647 .62455 .40312 .63567 .39948 .63014 .39281 Mtetra
.63014 .39281 .63567 .39948 .64683 .39583 .64133 .38913 Mtetra
.64133 .38913 .64683 .39583 .65803 .39217 .65256 .38544 Mtetra
.65256 .38544 .65803 .39217 .66928 .38849 .66384 .38174 Mtetra
.66384 .38174 .66928 .38849 .68057 .3848 .67517 .37802 Mtetra
.67517 .37802 .68057 .3848 .69191 .38109 .68654 .37429 Mtetra
.68654 .37429 .69191 .38109 .70329 .37737 .69795 .37054 Mtetra
.69795 .37054 .70329 .37737 .71472 .37364 .70941 .36678 Mtetra
.70941 .36678 .71472 .37364 .7262 .36989 .72092 .363 Mtetra
.72092 .363 .7262 .36989 .73772 .36613 .73247 .35921 Mtetra
.73247 .35921 .73772 .36613 .74929 .36235 .74407 .3554 Mtetra
.74407 .3554 .74929 .36235 .7609 .35856 .75572 .35158 Mtetra
.75572 .35158 .7609 .35856 .77256 .35475 .76742 .34775 Mtetra
.76742 .34775 .77256 .35475 .78427 .35093 .77916 .34389 Mtetra
.77916 .34389 .78427 .35093 .79603 .34709 .79095 .34003 Mtetra
.79095 .34003 .79603 .34709 .80784 .34324 .80279 .33615 Mtetra
.80279 .33615 .80784 .34324 .81969 .33937 .81468 .33225 Mtetra
.81468 .33225 .81969 .33937 .83159 .33549 .82662 .32833 Mtetra
.82662 .32833 .83159 .33549 .84354 .33159 .8386 .3244 Mtetra
.614 .723 .924 r
.20013 .52581 .20667 .53205 .21614 .53002 .20962 .52363 Mtetra
.572 .705 .932 r
.20962 .52363 .21614 .53002 .22514 .53372 .21908 .52226 Mtetra
.774 .66 .738 r
.21908 .52226 .22514 .53372 .23566 .52062 .2295 .51061 Mtetra
.425 .53 .861 r
.2295 .51061 .23566 .52062 .2452 .51902 .23873 .51265 Mtetra
.617 .722 .921 r
.23873 .51265 .2452 .51902 .25485 .51659 .24838 .51038 Mtetra
.625 .731 .923 r
.24838 .51038 .25485 .51659 .26452 .5143 .25809 .50791 Mtetra
.589 .714 .93 r
.25809 .50791 .26452 .5143 .27395 .5159 .26778 .50618 Mtetra
.812 .697 .737 r
.26778 .50618 .27395 .5159 .28438 .50443 .27843 .49216 Mtetra
.346 .436 .811 r
.27843 .49216 .28438 .50443 .29412 .50287 .28775 .4964 Mtetra
.621 .723 .92 r
.28775 .4964 .29412 .50287 .30397 .50021 .29761 .494 Mtetra
.638 .738 .921 r
.29761 .494 .30397 .50021 .31387 .49737 .30753 .49119 Mtetra
.64 .74 .922 r
.30753 .49119 .31387 .49737 .32382 .49456 .31749 .48831 Mtetra
.633 .737 .923 r
.31749 .48831 .32382 .49456 .33377 .49216 .32749 .48559 Mtetra
.572 .705 .932 r
.32749 .48559 .33377 .49216 .34313 .50153 .33745 .48415 Mtetra
.722 .588 .704 r
.33745 .48415 .34313 .50153 .35409 .48214 .34797 .4733 Mtetra
.511 .609 .887 r
.34797 .4733 .35409 .48214 .36414 .47997 .35792 .4735 Mtetra
.633 .732 .919 r
.35792 .4735 .36414 .47997 .37428 .477 .36807 .47073 Mtetra
.647 .744 .92 r
.36807 .47073 .37428 .477 .38447 .47382 .37828 .46761 Mtetra
.652 .749 .92 r
.37828 .46761 .38447 .47382 .3947 .47054 .38853 .46434 Mtetra
.655 .751 .92 r
.38853 .46434 .3947 .47054 .40498 .46718 .39883 .46099 Mtetra
.657 .752 .92 r
.39883 .46099 .40498 .46718 .41529 .46378 .40917 .45758 Mtetra
.658 .753 .92 r
.40917 .45758 .41529 .46378 .42565 .46034 .41955 .45412 Mtetra
.659 .754 .92 r
.41955 .45412 .42565 .46034 .43604 .45687 .42997 .45064 Mtetra
.42997 .45064 .43604 .45687 .44647 .4534 .44043 .44714 Mtetra
.44043 .44714 .44647 .4534 .45695 .44991 .45093 .44362 Mtetra
.45093 .44362 .45695 .44991 .46746 .44642 .46147 .4401 Mtetra
.658 .753 .92 r
.46147 .4401 .46746 .44642 .47801 .44292 .47205 .43658 Mtetra
.47205 .43658 .47801 .44292 .48861 .43942 .48267 .43305 Mtetra
.48267 .43305 .48861 .43942 .49924 .4359 .49333 .4295 Mtetra
.49333 .4295 .49924 .4359 .50992 .43238 .50403 .42595 Mtetra
.50403 .42595 .50992 .43238 .52063 .42884 .51478 .42239 Mtetra
.51478 .42239 .52063 .42884 .53139 .4253 .52556 .41882 Mtetra
.52556 .41882 .53139 .4253 .54219 .42174 .53639 .41523 Mtetra
.657 .753 .92 r
.53639 .41523 .54219 .42174 .55304 .41817 .54726 .41163 Mtetra
.54726 .41163 .55304 .41817 .56392 .41458 .55818 .40802 Mtetra
.657 .752 .92 r
.55818 .40802 .56392 .41458 .57485 .41099 .56913 .4044 Mtetra
.56913 .4044 .57485 .41099 .58582 .40738 .58013 .40076 Mtetra
.58013 .40076 .58582 .40738 .59683 .40376 .59118 .39712 Mtetra
.59118 .39712 .59683 .40376 .60789 .40012 .60226 .39345 Mtetra
.60226 .39345 .60789 .40012 .61899 .39647 .61339 .38978 Mtetra
.61339 .38978 .61899 .39647 .63014 .39281 .62457 .38609 Mtetra
.62457 .38609 .63014 .39281 .64133 .38913 .63579 .38238 Mtetra
.63579 .38238 .64133 .38913 .65256 .38544 .64705 .37866 Mtetra
.64705 .37866 .65256 .38544 .66384 .38174 .65836 .37493 Mtetra
.65836 .37493 .66384 .38174 .67517 .37802 .66972 .37119 Mtetra
.66972 .37119 .67517 .37802 .68654 .37429 .68112 .36743 Mtetra
.68112 .36743 .68654 .37429 .69795 .37054 .69257 .36365 Mtetra
.69257 .36365 .69795 .37054 .70941 .36678 .70406 .35986 Mtetra
.70406 .35986 .70941 .36678 .72092 .363 .7156 .35606 Mtetra
.7156 .35606 .72092 .363 .73247 .35921 .72719 .35224 Mtetra
.72719 .35224 .73247 .35921 .74407 .3554 .73882 .3484 Mtetra
.73882 .3484 .74407 .3554 .75572 .35158 .7505 .34455 Mtetra
.7505 .34455 .75572 .35158 .76742 .34775 .76223 .34069 Mtetra
.76223 .34069 .76742 .34775 .77916 .34389 .77401 .33681 Mtetra
.77401 .33681 .77916 .34389 .79095 .34003 .78583 .33291 Mtetra
.78583 .33291 .79095 .34003 .80279 .33615 .79771 .329 Mtetra
.79771 .329 .80279 .33615 .81468 .33225 .80963 .32507 Mtetra
.80963 .32507 .81468 .33225 .82662 .32833 .8216 .32113 Mtetra
.8216 .32113 .82662 .32833 .8386 .3244 .83362 .31717 Mtetra
.605 .714 .922 r
.19355 .51935 .20013 .52581 .20962 .52363 .20305 .51735 Mtetra
.608 .722 .926 r
.20305 .51735 .20962 .52363 .21908 .52226 .21259 .51526 Mtetra
.15 .475 .896 r
.21259 .51526 .21908 .52226 .2295 .51061 .22165 .51894 Mtetra
.676 .904 .562 r
.22165 .51894 .2295 .51061 .23873 .51265 .23227 .50575 Mtetra
.588 .696 .917 r
.23227 .50575 .23873 .51265 .24838 .51038 .24188 .5041 Mtetra
.625 .73 .922 r
.24188 .5041 .24838 .51038 .25809 .50791 .25161 .50161 Mtetra
.618 .728 .925 r
.25161 .50161 .25809 .50791 .26778 .50618 .26136 .49927 Mtetra
.371 .603 .938 r
.26136 .49927 .26778 .50618 .27843 .49216 .27086 .50083 Mtetra
0 0 0 r
.27086 .50083 .27843 .49216 .28775 .4964 .28139 .48927 Mtetra
.586 .691 .914 r
.28139 .48927 .28775 .4964 .29761 .494 .2912 .48766 Mtetra
.633 .734 .921 r
.2912 .48766 .29761 .494 .30753 .49119 .30114 .48495 Mtetra
.64 .74 .921 r
.30114 .48495 .30753 .49119 .31749 .48831 .31113 .48205 Mtetra
.638 .74 .922 r
.31113 .48205 .31749 .48831 .32749 .48559 .32115 .47918 Mtetra
.619 .73 .925 r
.32115 .47918 .32749 .48559 .33745 .48415 .33119 .47673 Mtetra
0 .056 .584 r
.33119 .47673 .33745 .48415 .34797 .4733 .34062 .4861 Mtetra
.628 .797 .36 r
.34062 .4861 .34797 .4733 .35792 .4735 .35168 .46658 Mtetra
.61 .711 .916 r
.35168 .46658 .35792 .4735 .36807 .47073 .36182 .46435 Mtetra
.642 .74 .92 r
.36182 .46435 .36807 .47073 .37828 .46761 .37205 .46132 Mtetra
.65 .747 .92 r
.37205 .46132 .37828 .46761 .38853 .46434 .38232 .45809 Mtetra
.654 .75 .92 r
.38232 .45809 .38853 .46434 .39883 .46099 .39264 .45474 Mtetra
.656 .752 .92 r
.39264 .45474 .39883 .46099 .40917 .45758 .40301 .45133 Mtetra
.658 .753 .92 r
.40301 .45133 .40917 .45758 .41955 .45412 .41341 .44786 Mtetra
.659 .753 .92 r
.41341 .44786 .41955 .45412 .42997 .45064 .42386 .44436 Mtetra
.659 .754 .92 r
.42386 .44436 .42997 .45064 .44043 .44714 .43434 .44083 Mtetra
.43434 .44083 .44043 .44714 .45093 .44362 .44487 .43729 Mtetra
.44487 .43729 .45093 .44362 .46147 .4401 .45543 .43374 Mtetra
.659 .753 .92 r
.45543 .43374 .46147 .4401 .47205 .43658 .46604 .43019 Mtetra
.658 .753 .92 r
.46604 .43019 .47205 .43658 .48267 .43305 .47669 .42663 Mtetra
.47669 .42663 .48267 .43305 .49333 .4295 .48737 .42306 Mtetra
.48737 .42306 .49333 .4295 .50403 .42595 .4981 .41948 Mtetra
.4981 .41948 .50403 .42595 .51478 .42239 .50888 .41589 Mtetra
.50888 .41589 .51478 .42239 .52556 .41882 .51969 .41229 Mtetra
.51969 .41229 .52556 .41882 .53639 .41523 .53055 .40868 Mtetra
.657 .753 .92 r
.53055 .40868 .53639 .41523 .54726 .41163 .54145 .40505 Mtetra
.54145 .40505 .54726 .41163 .55818 .40802 .55239 .40142 Mtetra
.55239 .40142 .55818 .40802 .56913 .4044 .56337 .39777 Mtetra
.657 .752 .92 r
.56337 .39777 .56913 .4044 .58013 .40076 .5744 .3941 Mtetra
.5744 .3941 .58013 .40076 .59118 .39712 .58548 .39043 Mtetra
.58548 .39043 .59118 .39712 .60226 .39345 .59659 .38674 Mtetra
.59659 .38674 .60226 .39345 .61339 .38978 .60775 .38303 Mtetra
.60775 .38303 .61339 .38978 .62457 .38609 .61896 .37932 Mtetra
.61896 .37932 .62457 .38609 .63579 .38238 .63021 .37558 Mtetra
.63021 .37558 .63579 .38238 .64705 .37866 .64151 .37184 Mtetra
.64151 .37184 .64705 .37866 .65836 .37493 .65285 .36808 Mtetra
.65285 .36808 .65836 .37493 .66972 .37119 .66423 .3643 Mtetra
.66423 .3643 .66972 .37119 .68112 .36743 .67567 .36051 Mtetra
.67567 .36051 .68112 .36743 .69257 .36365 .68715 .35671 Mtetra
.68715 .35671 .69257 .36365 .70406 .35986 .69867 .35289 Mtetra
.69867 .35289 .70406 .35986 .7156 .35606 .71024 .34906 Mtetra
.71024 .34906 .7156 .35606 .72719 .35224 .72186 .34521 Mtetra
.72186 .34521 .72719 .35224 .73882 .3484 .73353 .34135 Mtetra
.73353 .34135 .73882 .3484 .7505 .34455 .74524 .33747 Mtetra
.74524 .33747 .7505 .34455 .76223 .34069 .75701 .33357 Mtetra
.75701 .33357 .76223 .34069 .77401 .33681 .76882 .32966 Mtetra
.76882 .32966 .77401 .33681 .78583 .33291 .78068 .32574 Mtetra
.78068 .32574 .78583 .33291 .79771 .329 .79259 .32179 Mtetra
.79259 .32179 .79771 .329 .80963 .32507 .80454 .31784 Mtetra
.80454 .31784 .80963 .32507 .8216 .32113 .81655 .31386 Mtetra
.81655 .31386 .8216 .32113 .83362 .31717 .82861 .30987 Mtetra
.564 .676 .914 r
.18701 .51212 .19355 .51935 .20305 .51735 .19643 .511 Mtetra
.614 .723 .924 r
.19643 .511 .20305 .51735 .21259 .51526 .206 .50878 Mtetra
.573 .705 .932 r
.206 .50878 .21259 .51526 .22165 .51894 .21554 .50735 Mtetra
.774 .661 .738 r
.21554 .50735 .22165 .51894 .23227 .50575 .22605 .49562 Mtetra
.424 .53 .861 r
.22605 .49562 .23227 .50575 .24188 .5041 .23535 .49762 Mtetra
.617 .722 .921 r
.23535 .49762 .24188 .5041 .25161 .50161 .24508 .4953 Mtetra
.625 .731 .923 r
.24508 .4953 .25161 .50161 .26136 .49927 .25487 .49277 Mtetra
.589 .714 .93 r
.25487 .49277 .26136 .49927 .27086 .50083 .26464 .49099 Mtetra
.813 .697 .737 r
.26464 .49099 .27086 .50083 .28139 .48927 .27538 .47687 Mtetra
.344 .436 .811 r
.27538 .47687 .28139 .48927 .2912 .48766 .28477 .48108 Mtetra
.621 .723 .92 r
.28477 .48108 .2912 .48766 .30114 .48495 .29471 .47863 Mtetra
.638 .738 .921 r
.29471 .47863 .30114 .48495 .31113 .48205 .30471 .47576 Mtetra
.64 .74 .922 r
.30471 .47576 .31113 .48205 .32115 .47918 .31476 .47282 Mtetra
.633 .737 .923 r
.31476 .47282 .32115 .47918 .33119 .47673 .32484 .47004 Mtetra
.572 .705 .932 r
.32484 .47004 .33119 .47673 .34062 .4861 .33489 .46855 Mtetra
.723 .588 .704 r
.33489 .46855 .34062 .4861 .35168 .46658 .3455 .45761 Mtetra
.51 .609 .887 r
.3455 .45761 .35168 .46658 .36182 .46435 .35553 .45777 Mtetra
.633 .732 .919 r
.35553 .45777 .36182 .46435 .37205 .46132 .36577 .45495 Mtetra
.647 .744 .92 r
.36577 .45495 .37205 .46132 .38232 .45809 .37607 .45176 Mtetra
.652 .749 .92 r
.37607 .45176 .38232 .45809 .39264 .45474 .38641 .44843 Mtetra
.655 .751 .92 r
.38641 .44843 .39264 .45474 .40301 .45133 .3968 .44502 Mtetra
.657 .752 .92 r
.3968 .44502 .40301 .45133 .41341 .44786 .40723 .44155 Mtetra
.658 .753 .92 r
.40723 .44155 .41341 .44786 .42386 .44436 .4177 .43803 Mtetra
.659 .754 .92 r
.4177 .43803 .42386 .44436 .43434 .44083 .42821 .43448 Mtetra
.42821 .43448 .43434 .44083 .44487 .43729 .43876 .43091 Mtetra
.43876 .43091 .44487 .43729 .45543 .43374 .44935 .42734 Mtetra
.44935 .42734 .45543 .43374 .46604 .43019 .45999 .42376 Mtetra
.658 .753 .92 r
.45999 .42376 .46604 .43019 .47669 .42663 .47066 .42017 Mtetra
.47066 .42017 .47669 .42663 .48737 .42306 .48138 .41657 Mtetra
.48138 .41657 .48737 .42306 .4981 .41948 .49213 .41296 Mtetra
.49213 .41296 .4981 .41948 .50888 .41589 .50293 .40935 Mtetra
.50293 .40935 .50888 .41589 .51969 .41229 .51377 .40572 Mtetra
.51377 .40572 .51969 .41229 .53055 .40868 .52466 .40208 Mtetra
.52466 .40208 .53055 .40868 .54145 .40505 .53559 .39843 Mtetra
.657 .753 .92 r
.53559 .39843 .54145 .40505 .55239 .40142 .54656 .39476 Mtetra
.54656 .39476 .55239 .40142 .56337 .39777 .55757 .39108 Mtetra
.657 .752 .92 r
.55757 .39108 .56337 .39777 .5744 .3941 .56863 .38739 Mtetra
.56863 .38739 .5744 .3941 .58548 .39043 .57973 .38369 Mtetra
.57973 .38369 .58548 .39043 .59659 .38674 .59088 .37997 Mtetra
.59088 .37997 .59659 .38674 .60775 .38303 .60207 .37624 Mtetra
.60207 .37624 .60775 .38303 .61896 .37932 .61331 .37249 Mtetra
.61331 .37249 .61896 .37932 .63021 .37558 .62459 .36873 Mtetra
.62459 .36873 .63021 .37558 .64151 .37184 .63591 .36496 Mtetra
.63591 .36496 .64151 .37184 .65285 .36808 .64729 .36117 Mtetra
.64729 .36117 .65285 .36808 .66423 .3643 .65871 .35737 Mtetra
.65871 .35737 .66423 .3643 .67567 .36051 .67017 .35355 Mtetra
.67017 .35355 .67567 .36051 .68715 .35671 .68168 .34972 Mtetra
.68168 .34972 .68715 .35671 .69867 .35289 .69324 .34587 Mtetra
.69324 .34587 .69867 .35289 .71024 .34906 .70484 .34201 Mtetra
.70484 .34201 .71024 .34906 .72186 .34521 .7165 .33813 Mtetra
.7165 .33813 .72186 .34521 .73353 .34135 .7282 .33424 Mtetra
.7282 .33424 .73353 .34135 .74524 .33747 .73995 .33033 Mtetra
.73995 .33033 .74524 .33747 .75701 .33357 .75174 .3264 Mtetra
.75174 .3264 .75701 .33357 .76882 .32966 .76359 .32246 Mtetra
.76359 .32246 .76882 .32966 .78068 .32574 .77548 .31851 Mtetra
.77548 .31851 .78068 .32574 .79259 .32179 .78743 .31454 Mtetra
.78743 .31454 .79259 .32179 .80454 .31784 .79942 .31055 Mtetra
.79942 .31055 .80454 .31784 .81655 .31386 .81146 .30654 Mtetra
.81146 .30654 .81655 .31386 .82861 .30987 .82356 .30252 Mtetra
.173 .263 .716 r
.18134 .49607 .18701 .51212 .19643 .511 .18979 .50444 Mtetra
.605 .714 .922 r
.18979 .50444 .19643 .511 .206 .50878 .19935 .50238 Mtetra
.608 .722 .926 r
.19935 .50238 .206 .50878 .21554 .50735 .20897 .50025 Mtetra
.154 .477 .896 r
.20897 .50025 .21554 .50735 .22605 .49562 .2181 .5039 Mtetra
.685 .91 .571 r
.2181 .5039 .22605 .49562 .23535 .49762 .22881 .49061 Mtetra
.588 .696 .917 r
.22881 .49061 .23535 .49762 .24508 .4953 .23851 .48891 Mtetra
.625 .73 .922 r
.23851 .48891 .24508 .4953 .25487 .49277 .24831 .48636 Mtetra
.618 .728 .925 r
.24831 .48636 .25487 .49277 .26464 .49099 .25815 .48397 Mtetra
.373 .603 .937 r
.25815 .48397 .26464 .49099 .27538 .47687 .26772 .48549 Mtetra
0 0 0 r
.26772 .48549 .27538 .47687 .28477 .48108 .27835 .47384 Mtetra
.586 .691 .914 r
.27835 .47384 .28477 .48108 .29471 .47863 .28824 .47218 Mtetra
.633 .734 .921 r
.28824 .47218 .29471 .47863 .30471 .47576 .29826 .46941 Mtetra
.64 .74 .921 r
.29826 .46941 .30471 .47576 .31476 .47282 .30833 .46645 Mtetra
.638 .74 .922 r
.30833 .46645 .31476 .47282 .32484 .47004 .31844 .46353 Mtetra
.619 .73 .925 r
.31844 .46353 .32484 .47004 .33489 .46855 .32856 .46102 Mtetra
0 .062 .591 r
.32856 .46102 .33489 .46855 .3455 .45761 .33806 .47038 Mtetra
.637 .804 .369 r
.33806 .47038 .3455 .45761 .35553 .45777 .34923 .45073 Mtetra
.61 .711 .916 r
.34923 .45073 .35553 .45777 .36577 .45495 .35946 .44845 Mtetra
.642 .74 .92 r
.35946 .44845 .36577 .45495 .37607 .45176 .36977 .44536 Mtetra
.65 .747 .92 r
.36977 .44536 .37607 .45176 .38641 .44843 .38014 .44206 Mtetra
.654 .75 .92 r
.38014 .44206 .38641 .44843 .3968 .44502 .39055 .43866 Mtetra
.656 .752 .92 r
.39055 .43866 .3968 .44502 .40723 .44155 .401 .43518 Mtetra
.658 .753 .92 r
.401 .43518 .40723 .44155 .4177 .43803 .41149 .43165 Mtetra
.659 .753 .92 r
.41149 .43165 .4177 .43803 .42821 .43448 .42203 .42808 Mtetra
.659 .754 .92 r
.42203 .42808 .42821 .43448 .43876 .43091 .43261 .42449 Mtetra
.43261 .42449 .43876 .43091 .44935 .42734 .44323 .42089 Mtetra
.44323 .42089 .44935 .42734 .45999 .42376 .45389 .41728 Mtetra
.659 .753 .92 r
.45389 .41728 .45999 .42376 .47066 .42017 .46459 .41366 Mtetra
.658 .753 .92 r
.46459 .41366 .47066 .42017 .48138 .41657 .47533 .41003 Mtetra
.47533 .41003 .48138 .41657 .49213 .41296 .48612 .4064 Mtetra
.48612 .4064 .49213 .41296 .50293 .40935 .49695 .40275 Mtetra
.49695 .40275 .50293 .40935 .51377 .40572 .50782 .3991 Mtetra
.50782 .3991 .51377 .40572 .52466 .40208 .51873 .39543 Mtetra
.51873 .39543 .52466 .40208 .53559 .39843 .52969 .39175 Mtetra
.657 .753 .92 r
.52969 .39175 .53559 .39843 .54656 .39476 .54069 .38806 Mtetra
.54069 .38806 .54656 .39476 .55757 .39108 .55173 .38435 Mtetra
.55173 .38435 .55757 .39108 .56863 .38739 .56282 .38063 Mtetra
.657 .752 .92 r
.56282 .38063 .56863 .38739 .57973 .38369 .57395 .3769 Mtetra
.57395 .3769 .57973 .38369 .59088 .37997 .58512 .37316 Mtetra
.58512 .37316 .59088 .37997 .60207 .37624 .59635 .3694 Mtetra
.59635 .3694 .60207 .37624 .61331 .37249 .60761 .36562 Mtetra
.60761 .36562 .61331 .37249 .62459 .36873 .61892 .36183 Mtetra
.61892 .36183 .62459 .36873 .63591 .36496 .63028 .35803 Mtetra
.63028 .35803 .63591 .36496 .64729 .36117 .64169 .35422 Mtetra
.64169 .35422 .64729 .36117 .65871 .35737 .65314 .35038 Mtetra
.65314 .35038 .65871 .35737 .67017 .35355 .66463 .34654 Mtetra
.66463 .34654 .67017 .35355 .68168 .34972 .67618 .34268 Mtetra
.67618 .34268 .68168 .34972 .69324 .34587 .68777 .3388 Mtetra
.68777 .3388 .69324 .34587 .70484 .34201 .6994 .33491 Mtetra
.6994 .33491 .70484 .34201 .7165 .33813 .71109 .331 Mtetra
.71109 .331 .7165 .33813 .7282 .33424 .72282 .32708 Mtetra
.72282 .32708 .7282 .33424 .73995 .33033 .73461 .32314 Mtetra
.73461 .32314 .73995 .33033 .75174 .3264 .74644 .31918 Mtetra
.74644 .31918 .75174 .3264 .76359 .32246 .75832 .31521 Mtetra
.75832 .31521 .76359 .32246 .77548 .31851 .77025 .31123 Mtetra
.77025 .31123 .77548 .31851 .78743 .31454 .78223 .30722 Mtetra
.78223 .30722 .78743 .31454 .79942 .31055 .79425 .3032 Mtetra
.79425 .3032 .79942 .31055 .81146 .30654 .80633 .29917 Mtetra
.80633 .29917 .81146 .30654 .82356 .30252 .81846 .29512 Mtetra
0 0 0 r
.17274 .50765 .18134 .49607 .18979 .50444 .18317 .4971 Mtetra
.564 .676 .914 r
.18317 .4971 .18979 .50444 .19935 .50238 .19267 .49593 Mtetra
.614 .723 .924 r
.19267 .49593 .19935 .50238 .20897 .50025 .20231 .49366 Mtetra
.573 .705 .932 r
.20231 .49366 .20897 .50025 .2181 .5039 .21193 .49218 Mtetra
.775 .662 .738 r
.21193 .49218 .2181 .5039 .22881 .49061 .22253 .48035 Mtetra
.423 .53 .861 r
.22253 .48035 .22881 .49061 .23851 .48891 .2319 .48232 Mtetra
.617 .722 .921 r
.2319 .48232 .23851 .48891 .24831 .48636 .24171 .47995 Mtetra
.625 .731 .923 r
.24171 .47995 .24831 .48636 .25815 .48397 .25158 .47736 Mtetra
.589 .714 .93 r
.25158 .47736 .25815 .48397 .26772 .48549 .26143 .47553 Mtetra
.814 .698 .737 r
.26143 .47553 .26772 .48549 .27835 .47384 .27228 .4613 Mtetra
.343 .435 .811 r
.27228 .4613 .27835 .47384 .28824 .47218 .28174 .46549 Mtetra
.621 .723 .92 r
.28174 .46549 .28824 .47218 .29826 .46941 .29176 .46298 Mtetra
.638 .738 .921 r
.29176 .46298 .29826 .46941 .30833 .46645 .30185 .46005 Mtetra
.64 .74 .922 r
.30185 .46005 .30833 .46645 .31844 .46353 .31198 .45706 Mtetra
.633 .737 .923 r
.31198 .45706 .31844 .46353 .32856 .46102 .32215 .45422 Mtetra
.572 .705 .932 r
.32215 .45422 .32856 .46102 .33806 .47038 .33228 .45268 Mtetra
.723 .588 .704 r
.33228 .45268 .33806 .47038 .34923 .45073 .34299 .44164 Mtetra
.51 .609 .887 r
.34299 .44164 .34923 .45073 .35946 .44845 .3531 .44175 Mtetra
.633 .732 .919 r
.3531 .44175 .35946 .44845 .36977 .44536 .36343 .43887 Mtetra
.647 .744 .92 r
.36343 .43887 .36977 .44536 .38014 .44206 .37382 .43562 Mtetra
.652 .749 .92 r
.37382 .43562 .38014 .44206 .39055 .43866 .38425 .43223 Mtetra
.655 .751 .92 r
.38425 .43223 .39055 .43866 .401 .43518 .39473 .42876 Mtetra
.657 .752 .92 r
.39473 .42876 .401 .43518 .41149 .43165 .40525 .42522 Mtetra
.658 .753 .92 r
.40525 .42522 .41149 .43165 .42203 .42808 .41581 .42164 Mtetra
.659 .754 .92 r
.41581 .42164 .42203 .42808 .43261 .42449 .42641 .41802 Mtetra
.42641 .41802 .43261 .42449 .44323 .42089 .43706 .41439 Mtetra
.43706 .41439 .44323 .42089 .45389 .41728 .44775 .41075 Mtetra
.44775 .41075 .45389 .41728 .46459 .41366 .45848 .4071 Mtetra
.658 .753 .92 r
.45848 .4071 .46459 .41366 .47533 .41003 .46925 .40345 Mtetra
.46925 .40345 .47533 .41003 .48612 .4064 .48006 .39978 Mtetra
.48006 .39978 .48612 .4064 .49695 .40275 .49092 .39611 Mtetra
.49092 .39611 .49695 .40275 .50782 .3991 .50181 .39243 Mtetra
.50181 .39243 .50782 .3991 .51873 .39543 .51276 .38873 Mtetra
.51276 .38873 .51873 .39543 .52969 .39175 .52374 .38502 Mtetra
.52374 .38502 .52969 .39175 .54069 .38806 .53477 .3813 Mtetra
.657 .753 .92 r
.53477 .3813 .54069 .38806 .55173 .38435 .54584 .37757 Mtetra
.54584 .37757 .55173 .38435 .56282 .38063 .55696 .37382 Mtetra
.657 .752 .92 r
.55696 .37382 .56282 .38063 .57395 .3769 .56812 .37006 Mtetra
.56812 .37006 .57395 .3769 .58512 .37316 .57933 .36629 Mtetra
.57933 .36629 .58512 .37316 .59635 .3694 .59058 .3625 Mtetra
.59058 .3625 .59635 .3694 .60761 .36562 .60188 .3587 Mtetra
.60188 .3587 .60761 .36562 .61892 .36183 .61322 .35488 Mtetra
.61322 .35488 .61892 .36183 .63028 .35803 .62461 .35105 Mtetra
.62461 .35105 .63028 .35803 .64169 .35422 .63604 .34721 Mtetra
.63604 .34721 .64169 .35422 .65314 .35038 .64752 .34334 Mtetra
.64752 .34334 .65314 .35038 .66463 .34654 .65905 .33947 Mtetra
.65905 .33947 .66463 .34654 .67618 .34268 .67063 .33558 Mtetra
.67063 .33558 .67618 .34268 .68777 .3388 .68225 .33167 Mtetra
.68225 .33167 .68777 .3388 .6994 .33491 .69392 .32775 Mtetra
.69392 .32775 .6994 .33491 .71109 .331 .70564 .32381 Mtetra
.70564 .32381 .71109 .331 .72282 .32708 .71741 .31986 Mtetra
.71741 .31986 .72282 .32708 .73461 .32314 .72923 .31589 Mtetra
.72923 .31589 .73461 .32314 .74644 .31918 .74109 .3119 Mtetra
.74109 .3119 .74644 .31918 .75832 .31521 .75301 .3079 Mtetra
.75301 .3079 .75832 .31521 .77025 .31123 .76497 .30389 Mtetra
.76497 .30389 .77025 .31123 .78223 .30722 .77698 .29985 Mtetra
.77698 .29985 .78223 .30722 .79425 .3032 .78905 .2958 Mtetra
.78905 .2958 .79425 .3032 .80633 .29917 .80116 .29174 Mtetra
.80116 .29174 .80633 .29917 .81846 .29512 .81333 .28765 Mtetra
.841 .709 .718 r
.16623 .49867 .17274 .50765 .18317 .4971 .17745 .4809 Mtetra
.17 .261 .716 r
.17745 .4809 .18317 .4971 .19267 .49593 .18595 .48926 Mtetra
.605 .714 .922 r
.18595 .48926 .19267 .49593 .20231 .49366 .1956 .48716 Mtetra
.608 .722 .926 r
.1956 .48716 .20231 .49366 .21193 .49218 .20529 .48497 Mtetra
.157 .478 .897 r
.20529 .48497 .21193 .49218 .22253 .48035 .21449 .48859 Mtetra
.694 .916 .58 r
.21449 .48859 .22253 .48035 .2319 .48232 .2253 .4752 Mtetra
.588 .696 .917 r
.2253 .4752 .2319 .48232 .24171 .47995 .23507 .47345 Mtetra
.625 .73 .922 r
.23507 .47345 .24171 .47995 .25158 .47736 .24496 .47085 Mtetra
.618 .728 .925 r
.24496 .47085 .25158 .47736 .26143 .47553 .25488 .46839 Mtetra
.374 .603 .937 r
.25488 .46839 .26143 .47553 .27228 .4613 .26452 .46988 Mtetra
0 0 0 r
.26452 .46988 .27228 .4613 .28174 .46549 .27524 .45813 Mtetra
.586 .691 .914 r
.27524 .45813 .28174 .46549 .29176 .46298 .28522 .45642 Mtetra
.633 .734 .921 r
.28522 .45642 .29176 .46298 .30185 .46005 .29532 .45359 Mtetra
.64 .74 .921 r
.29532 .45359 .30185 .46005 .31198 .45706 .30548 .45058 Mtetra
.638 .74 .922 r
.30548 .45058 .31198 .45706 .32215 .45422 .31567 .44759 Mtetra
.619 .729 .925 r
.31567 .44759 .32215 .45422 .33228 .45268 .32588 .44503 Mtetra
0 .068 .597 r
.32588 .44503 .33228 .45268 .34299 .44164 .33545 .45438 Mtetra
.647 .812 .379 r
.33545 .45438 .34299 .44164 .3531 .44175 .34673 .4346 Mtetra
.61 .711 .917 r
.34673 .4346 .3531 .44175 .36343 .43887 .35705 .43225 Mtetra
.642 .74 .92 r
.35705 .43225 .36343 .43887 .37382 .43562 .36745 .42911 Mtetra
.65 .747 .92 r
.36745 .42911 .37382 .43562 .38425 .43223 .37791 .42574 Mtetra
.654 .75 .92 r
.37791 .42574 .38425 .43223 .39473 .42876 .38841 .42228 Mtetra
.656 .752 .92 r
.38841 .42228 .39473 .42876 .40525 .42522 .39896 .41873 Mtetra
.658 .753 .92 r
.39896 .41873 .40525 .42522 .41581 .42164 .40954 .41514 Mtetra
.659 .753 .92 r
.40954 .41514 .41581 .42164 .42641 .41802 .42017 .41151 Mtetra
.659 .754 .92 r
.42017 .41151 .42641 .41802 .43706 .41439 .43085 .40785 Mtetra
.43085 .40785 .43706 .41439 .44775 .41075 .44156 .40418 Mtetra
.44156 .40418 .44775 .41075 .45848 .4071 .45232 .4005 Mtetra
.659 .753 .92 r
.45232 .4005 .45848 .4071 .46925 .40345 .46312 .39682 Mtetra
.658 .753 .92 r
.46312 .39682 .46925 .40345 .48006 .39978 .47396 .39312 Mtetra
.47396 .39312 .48006 .39978 .49092 .39611 .48484 .38942 Mtetra
.48484 .38942 .49092 .39611 .50181 .39243 .49577 .38571 Mtetra
.49577 .38571 .50181 .39243 .51276 .38873 .50674 .38199 Mtetra
.50674 .38199 .51276 .38873 .52374 .38502 .51775 .37825 Mtetra
.51775 .37825 .52374 .38502 .53477 .3813 .52881 .3745 Mtetra
.657 .753 .92 r
.52881 .3745 .53477 .3813 .54584 .37757 .53991 .37074 Mtetra
.53991 .37074 .54584 .37757 .55696 .37382 .55106 .36696 Mtetra
.55106 .36696 .55696 .37382 .56812 .37006 .56225 .36317 Mtetra
.657 .752 .92 r
.56225 .36317 .56812 .37006 .57933 .36629 .57349 .35937 Mtetra
.57349 .35937 .57933 .36629 .59058 .3625 .58477 .35556 Mtetra
.58477 .35556 .59058 .3625 .60188 .3587 .5961 .35172 Mtetra
.5961 .35172 .60188 .3587 .61322 .35488 .60747 .34788 Mtetra
.60747 .34788 .61322 .35488 .62461 .35105 .61889 .34402 Mtetra
.61889 .34402 .62461 .35105 .63604 .34721 .63036 .34014 Mtetra
.63036 .34014 .63604 .34721 .64752 .34334 .64187 .33625 Mtetra
.64187 .33625 .64752 .34334 .65905 .33947 .65343 .33235 Mtetra
.65343 .33235 .65905 .33947 .67063 .33558 .66504 .32843 Mtetra
.66504 .32843 .67063 .33558 .68225 .33167 .6767 .32449 Mtetra
.6767 .32449 .68225 .33167 .69392 .32775 .6884 .32054 Mtetra
.6884 .32054 .69392 .32775 .70564 .32381 .70015 .31657 Mtetra
.70015 .31657 .70564 .32381 .71741 .31986 .71195 .31259 Mtetra
.71195 .31259 .71741 .31986 .72923 .31589 .72381 .30859 Mtetra
.72381 .30859 .72923 .31589 .74109 .3119 .7357 .30457 Mtetra
.7357 .30457 .74109 .3119 .75301 .3079 .74765 .30054 Mtetra
.74765 .30054 .75301 .3079 .76497 .30389 .75965 .29649 Mtetra
.75965 .29649 .76497 .30389 .77698 .29985 .7717 .29243 Mtetra
.7717 .29243 .77698 .29985 .78905 .2958 .7838 .28834 Mtetra
.7838 .28834 .78905 .2958 .80116 .29174 .79595 .28425 Mtetra
.79595 .28425 .80116 .29174 .81333 .28765 .80816 .28013 Mtetra
.425 .633 .941 r
.15946 .4917 .16623 .49867 .17745 .4809 .16874 .49245 Mtetra
0 0 0 r
.16874 .49245 .17745 .4809 .18595 .48926 .17927 .48181 Mtetra
.564 .676 .914 r
.17927 .48181 .18595 .48926 .1956 .48716 .18884 .4806 Mtetra
.614 .723 .924 r
.18884 .4806 .1956 .48716 .20529 .48497 .19856 .47826 Mtetra
.573 .705 .932 r
.19856 .47826 .20529 .48497 .21449 .48859 .20825 .47674 Mtetra
.775 .662 .738 r
.20825 .47674 .21449 .48859 .2253 .4752 .21896 .46482 Mtetra
.423 .53 .861 r
.21896 .46482 .2253 .4752 .23507 .47345 .2284 .46675 Mtetra
.617 .722 .921 r
.2284 .46675 .23507 .47345 .24496 .47085 .23829 .46432 Mtetra
.625 .731 .923 r
.23829 .46432 .24496 .47085 .25488 .46839 .24824 .46167 Mtetra
.589 .714 .93 r
.24824 .46167 .25488 .46839 .26452 .46988 .25817 .45979 Mtetra
.814 .699 .738 r
.25817 .45979 .26452 .46988 .27524 .45813 .26912 .44545 Mtetra
.341 .434 .811 r
.26912 .44545 .27524 .45813 .28522 .45642 .27865 .44962 Mtetra
.621 .723 .92 r
.27865 .44962 .28522 .45642 .29532 .45359 .28875 .44704 Mtetra
.638 .738 .921 r
.28875 .44704 .29532 .45359 .30548 .45058 .29893 .44406 Mtetra
.64 .74 .922 r
.29893 .44406 .30548 .45058 .31567 .44759 .30915 .441 Mtetra
.633 .737 .923 r
.30915 .441 .31567 .44759 .32588 .44503 .3194 .43811 Mtetra
.572 .705 .932 r
.3194 .43811 .32588 .44503 .33545 .45438 .32962 .43651 Mtetra
.723 .588 .704 r
.32962 .43651 .33545 .45438 .34673 .4346 .34043 .42538 Mtetra
.51 .609 .887 r
.34043 .42538 .34673 .4346 .35705 .43225 .35063 .42544 Mtetra
.633 .732 .919 r
.35063 .42544 .35705 .43225 .36745 .42911 .36104 .4225 Mtetra
.647 .744 .92 r
.36104 .4225 .36745 .42911 .37791 .42574 .37152 .41919 Mtetra
.652 .749 .92 r
.37152 .41919 .37791 .42574 .38841 .42228 .38205 .41573 Mtetra
.655 .751 .92 r
.38205 .41573 .38841 .42228 .39896 .41873 .39262 .41219 Mtetra
.657 .752 .92 r
.39262 .41219 .39896 .41873 .40954 .41514 .40323 .40859 Mtetra
.658 .753 .92 r
.40323 .40859 .40954 .41514 .42017 .41151 .41389 .40494 Mtetra
.659 .754 .92 r
.41389 .40494 .42017 .41151 .43085 .40785 .42459 .40126 Mtetra
.42459 .40126 .43085 .40785 .44156 .40418 .43533 .39756 Mtetra
.43533 .39756 .44156 .40418 .45232 .4005 .44611 .39386 Mtetra
.44611 .39386 .45232 .4005 .46312 .39682 .45694 .39014 Mtetra
.658 .753 .92 r
.45694 .39014 .46312 .39682 .47396 .39312 .46781 .38642 Mtetra
.46781 .38642 .47396 .39312 .48484 .38942 .47872 .38268 Mtetra
.47872 .38268 .48484 .38942 .49577 .38571 .48967 .37894 Mtetra
.48967 .37894 .49577 .38571 .50674 .38199 .50067 .37519 Mtetra
.50067 .37519 .50674 .38199 .51775 .37825 .51172 .37142 Mtetra
.51172 .37142 .51775 .37825 .52881 .3745 .5228 .36765 Mtetra
.5228 .36765 .52881 .3745 .53991 .37074 .53393 .36386 Mtetra
.657 .753 .92 r
.53393 .36386 .53991 .37074 .55106 .36696 .54511 .36005 Mtetra
.54511 .36005 .55106 .36696 .56225 .36317 .55633 .35623 Mtetra
.657 .752 .92 r
.55633 .35623 .56225 .36317 .57349 .35937 .5676 .3524 Mtetra
.5676 .3524 .57349 .35937 .58477 .35556 .57891 .34856 Mtetra
.57891 .34856 .58477 .35556 .5961 .35172 .59027 .3447 Mtetra
.59027 .3447 .5961 .35172 .60747 .34788 .60168 .34082 Mtetra
.60168 .34082 .60747 .34788 .61889 .34402 .61313 .33693 Mtetra
.61313 .33693 .61889 .34402 .63036 .34014 .62463 .33303 Mtetra
.62463 .33303 .63036 .34014 .64187 .33625 .63617 .32911 Mtetra
.63617 .32911 .64187 .33625 .65343 .33235 .64777 .32517 Mtetra
.64777 .32517 .65343 .33235 .66504 .32843 .65941 .32122 Mtetra
.65941 .32122 .66504 .32843 .6767 .32449 .6711 .31725 Mtetra
.6711 .31725 .6767 .32449 .6884 .32054 .68284 .31327 Mtetra
.68284 .31327 .6884 .32054 .70015 .31657 .69462 .30927 Mtetra
.69462 .30927 .70015 .31657 .71195 .31259 .70646 .30526 Mtetra
.70646 .30526 .71195 .31259 .72381 .30859 .71834 .30123 Mtetra
.71834 .30123 .72381 .30859 .7357 .30457 .73028 .29718 Mtetra
.73028 .29718 .7357 .30457 .74765 .30054 .74226 .29312 Mtetra
.74226 .29312 .74765 .30054 .75965 .29649 .7543 .28904 Mtetra
.7543 .28904 .75965 .29649 .7717 .29243 .76638 .28494 Mtetra
.76638 .28494 .7717 .29243 .7838 .28834 .77852 .28083 Mtetra
.77852 .28083 .7838 .28834 .79595 .28425 .7907 .2767 Mtetra
.7907 .2767 .79595 .28425 .80816 .28013 .80294 .27255 Mtetra
.582 .709 .93 r
.1526 .48503 .15946 .4917 .16874 .49245 .16216 .48335 Mtetra
.841 .71 .718 r
.16216 .48335 .16874 .49245 .17927 .48181 .17349 .46546 Mtetra
.166 .258 .715 r
.17349 .46546 .17927 .48181 .18884 .4806 .18205 .47381 Mtetra
.605 .714 .922 r
.18205 .47381 .18884 .4806 .19856 .47826 .19177 .47165 Mtetra
.608 .722 .926 r
.19177 .47165 .19856 .47826 .20825 .47674 .20155 .46941 Mtetra
.16 .479 .897 r
.20155 .46941 .20825 .47674 .21896 .46482 .21081 .47301 Mtetra
.702 .922 .589 r
.21081 .47301 .21896 .46482 .2284 .46675 .22173 .45951 Mtetra
.588 .696 .917 r
.22173 .45951 .2284 .46675 .23829 .46432 .23157 .4577 Mtetra
.625 .73 .922 r
.23157 .4577 .23829 .46432 .24824 .46167 .24154 .45505 Mtetra
.618 .728 .925 r
.24154 .45505 .24824 .46167 .25817 .45979 .25154 .45254 Mtetra
.375 .603 .937 r
.25154 .45254 .25817 .45979 .26912 .44545 .26127 .45398 Mtetra
.528 .82 .483 r
.26127 .45398 .26912 .44545 .27865 .44962 .27209 .44214 Mtetra
.585 .691 .914 r
.27209 .44214 .27865 .44962 .28875 .44704 .28215 .44037 Mtetra
.633 .734 .921 r
.28215 .44037 .28875 .44704 .29893 .44406 .29233 .43748 Mtetra
.64 .74 .921 r
.29233 .43748 .29893 .44406 .30915 .441 .30258 .43441 Mtetra
.638 .74 .922 r
.30258 .43441 .30915 .441 .3194 .43811 .31286 .43136 Mtetra
.619 .729 .925 r
.31286 .43136 .3194 .43811 .32962 .43651 .32316 .42874 Mtetra
0 .074 .603 r
.32316 .42874 .32962 .43651 .34043 .42538 .3328 .43808 Mtetra
.656 .819 .388 r
.3328 .43808 .34043 .42538 .35063 .42544 .34419 .41816 Mtetra
.61 .711 .917 r
.34419 .41816 .35063 .42544 .36104 .4225 .3546 .41576 Mtetra
.642 .74 .92 r
.3546 .41576 .36104 .4225 .37152 .41919 .36509 .41255 Mtetra
.65 .747 .92 r
.36509 .41255 .37152 .41919 .38205 .41573 .37564 .40912 Mtetra
.654 .75 .92 r
.37564 .40912 .38205 .41573 .39262 .41219 .38623 .40559 Mtetra
.656 .752 .92 r
.38623 .40559 .39262 .41219 .40323 .40859 .39687 .40198 Mtetra
.658 .753 .92 r
.39687 .40198 .40323 .40859 .41389 .40494 .40756 .39832 Mtetra
.659 .753 .92 r
.40756 .39832 .41389 .40494 .42459 .40126 .41828 .39462 Mtetra
.659 .754 .92 r
.41828 .39462 .42459 .40126 .43533 .39756 .42905 .3909 Mtetra
.42905 .3909 .43533 .39756 .44611 .39386 .43986 .38716 Mtetra
.43986 .38716 .44611 .39386 .45694 .39014 .45072 .38342 Mtetra
.659 .753 .92 r
.45072 .38342 .45694 .39014 .46781 .38642 .46161 .37966 Mtetra
.658 .753 .92 r
.46161 .37966 .46781 .38642 .47872 .38268 .47255 .3759 Mtetra
.47255 .3759 .47872 .38268 .48967 .37894 .48354 .37213 Mtetra
.48354 .37213 .48967 .37894 .50067 .37519 .49456 .36834 Mtetra
.49456 .36834 .50067 .37519 .51172 .37142 .50564 .36455 Mtetra
.50564 .36455 .51172 .37142 .5228 .36765 .51675 .36074 Mtetra
.51675 .36074 .5228 .36765 .53393 .36386 .52791 .35692 Mtetra
.657 .753 .92 r
.52791 .35692 .53393 .36386 .54511 .36005 .53912 .35309 Mtetra
.53912 .35309 .54511 .36005 .55633 .35623 .55037 .34924 Mtetra
.55037 .34924 .55633 .35623 .5676 .3524 .56167 .34538 Mtetra
.657 .752 .92 r
.56167 .34538 .5676 .3524 .57891 .34856 .57301 .34151 Mtetra
.57301 .34151 .57891 .34856 .59027 .3447 .5844 .33762 Mtetra
.5844 .33762 .59027 .3447 .60168 .34082 .59584 .33371 Mtetra
.59584 .33371 .60168 .34082 .61313 .33693 .60732 .32979 Mtetra
.60732 .32979 .61313 .33693 .62463 .33303 .61885 .32586 Mtetra
.61885 .32586 .62463 .33303 .63617 .32911 .63043 .32191 Mtetra
.63043 .32191 .63617 .32911 .64777 .32517 .64206 .31794 Mtetra
.64206 .31794 .64777 .32517 .65941 .32122 .65373 .31396 Mtetra
.65373 .31396 .65941 .32122 .6711 .31725 .66546 .30996 Mtetra
.66546 .30996 .6711 .31725 .68284 .31327 .67723 .30595 Mtetra
.67723 .30595 .68284 .31327 .69462 .30927 .68905 .30192 Mtetra
.68905 .30192 .69462 .30927 .70646 .30526 .70092 .29787 Mtetra
.70092 .29787 .70646 .30526 .71834 .30123 .71284 .29381 Mtetra
.71284 .29381 .71834 .30123 .73028 .29718 .72481 .28973 Mtetra
.72481 .28973 .73028 .29718 .74226 .29312 .73682 .28564 Mtetra
.73682 .28564 .74226 .29312 .7543 .28904 .74889 .28152 Mtetra
.74889 .28152 .7543 .28904 .76638 .28494 .76102 .2774 Mtetra
.76102 .2774 .76638 .28494 .77852 .28083 .77319 .27325 Mtetra
.77319 .27325 .77852 .28083 .7907 .2767 .78541 .26909 Mtetra
.78541 .26909 .7907 .2767 .80294 .27255 .79769 .26491 Mtetra
.602 .717 .925 r
.1457 .47837 .1526 .48503 .16216 .48335 .15532 .47627 Mtetra
.426 .633 .941 r
.15532 .47627 .16216 .48335 .17349 .46546 .16467 .47698 Mtetra
0 0 0 r
.16467 .47698 .17349 .46546 .18205 .47381 .1753 .46625 Mtetra
.564 .676 .915 r
.1753 .46625 .18205 .47381 .19177 .47165 .18494 .46499 Mtetra
.614 .723 .924 r
.18494 .46499 .19177 .47165 .20155 .46941 .19474 .4626 Mtetra
.573 .705 .932 r
.19474 .4626 .20155 .46941 .21081 .47301 .20451 .46102 Mtetra
.775 .663 .739 r
.20451 .46102 .21081 .47301 .22173 .45951 .21531 .449 Mtetra
.422 .529 .861 r
.21531 .449 .22173 .45951 .23157 .4577 .22483 .45089 Mtetra
.617 .722 .921 r
.22483 .45089 .23157 .4577 .24154 .45505 .2348 .4484 Mtetra
.625 .731 .923 r
.2348 .4484 .24154 .45505 .25154 .45254 .24483 .4457 Mtetra
.589 .714 .929 r
.24483 .4457 .25154 .45254 .26127 .45398 .25485 .44376 Mtetra
.815 .7 .738 r
.25485 .44376 .26127 .45398 .27209 .44214 .2659 .42932 Mtetra
.34 .433 .811 r
.2659 .42932 .27209 .44214 .28215 .44037 .27551 .43345 Mtetra
.621 .723 .92 r
.27551 .43345 .28215 .44037 .29233 .43748 .2857 .43082 Mtetra
.638 .738 .921 r
.2857 .43082 .29233 .43748 .30258 .43441 .29596 .42777 Mtetra
.64 .74 .922 r
.29596 .42777 .30258 .43441 .31286 .43136 .30627 .42466 Mtetra
.633 .737 .923 r
.30627 .42466 .31286 .43136 .32316 .42874 .31661 .4217 Mtetra
.573 .705 .932 r
.31661 .4217 .32316 .42874 .3328 .43808 .32691 .42004 Mtetra
.723 .588 .704 r
.32691 .42004 .3328 .43808 .34419 .41816 .33782 .40882 Mtetra
.509 .609 .888 r
.33782 .40882 .34419 .41816 .3546 .41576 .34811 .40882 Mtetra
.633 .732 .92 r
.34811 .40882 .3546 .41576 .36509 .41255 .35862 .40582 Mtetra
.647 .744 .92 r
.35862 .40582 .36509 .41255 .37564 .40912 .36918 .40245 Mtetra
.652 .749 .92 r
.36918 .40245 .37564 .40912 .38623 .40559 .3798 .39893 Mtetra
.655 .751 .92 r
.3798 .39893 .38623 .40559 .39687 .40198 .39047 .39532 Mtetra
.657 .752 .92 r
.39047 .39532 .39687 .40198 .40756 .39832 .40118 .39165 Mtetra
.658 .753 .92 r
.40118 .39165 .40756 .39832 .41828 .39462 .41193 .38793 Mtetra
.659 .754 .92 r
.41193 .38793 .41828 .39462 .42905 .3909 .42273 .38418 Mtetra
.42273 .38418 .42905 .3909 .43986 .38716 .43357 .38042 Mtetra
.43357 .38042 .43986 .38716 .45072 .38342 .44445 .37664 Mtetra
.44445 .37664 .45072 .38342 .46161 .37966 .45537 .37286 Mtetra
.658 .753 .92 r
.45537 .37286 .46161 .37966 .47255 .3759 .46634 .36906 Mtetra
.46634 .36906 .47255 .3759 .48354 .37213 .47735 .36526 Mtetra
.47735 .36526 .48354 .37213 .49456 .36834 .48841 .36145 Mtetra
.48841 .36145 .49456 .36834 .50564 .36455 .49951 .35762 Mtetra
.49951 .35762 .50564 .36455 .51675 .36074 .51066 .35379 Mtetra
.51066 .35379 .51675 .36074 .52791 .35692 .52185 .34994 Mtetra
.52185 .34994 .52791 .35692 .53912 .35309 .53308 .34607 Mtetra
.657 .753 .92 r
.53308 .34607 .53912 .35309 .55037 .34924 .54437 .3422 Mtetra
.54437 .3422 .55037 .34924 .56167 .34538 .5557 .33831 Mtetra
.657 .752 .92 r
.5557 .33831 .56167 .34538 .57301 .34151 .56707 .3344 Mtetra
.56707 .3344 .57301 .34151 .5844 .33762 .57849 .33048 Mtetra
.57849 .33048 .5844 .33762 .59584 .33371 .58996 .32655 Mtetra
.58996 .32655 .59584 .33371 .60732 .32979 .60147 .3226 Mtetra
.60147 .3226 .60732 .32979 .61885 .32586 .61304 .31863 Mtetra
.61304 .31863 .61885 .32586 .63043 .32191 .62465 .31465 Mtetra
.62465 .31465 .63043 .32191 .64206 .31794 .63631 .31065 Mtetra
.63631 .31065 .64206 .31794 .65373 .31396 .64801 .30664 Mtetra
.64801 .30664 .65373 .31396 .66546 .30996 .65977 .30261 Mtetra
.65977 .30261 .66546 .30996 .67723 .30595 .67157 .29857 Mtetra
.67157 .29857 .67723 .30595 .68905 .30192 .68343 .29451 Mtetra
.68343 .29451 .68905 .30192 .70092 .29787 .69533 .29043 Mtetra
.69533 .29043 .70092 .29787 .71284 .29381 .70729 .28634 Mtetra
.70729 .28634 .71284 .29381 .72481 .28973 .71929 .28223 Mtetra
.71929 .28223 .72481 .28973 .73682 .28564 .73135 .2781 Mtetra
.73135 .2781 .73682 .28564 .74889 .28152 .74345 .27395 Mtetra
.74345 .27395 .74889 .28152 .76102 .2774 .75561 .26979 Mtetra
.75561 .26979 .76102 .2774 .77319 .27325 .76782 .26561 Mtetra
.76782 .26561 .77319 .27325 .78541 .26909 .78008 .26142 Mtetra
.78008 .26142 .78541 .26909 .79769 .26491 .79239 .25721 Mtetra
.595 .708 .922 r
.13878 .47146 .1457 .47837 .15532 .47627 .14839 .46949 Mtetra
.582 .709 .93 r
.14839 .46949 .15532 .47627 .16467 .47698 .15802 .46776 Mtetra
.842 .71 .718 r
.15802 .46776 .16467 .47698 .1753 .46625 .16947 .44975 Mtetra
.163 .256 .714 r
.16947 .44975 .1753 .46625 .18494 .46499 .17808 .45809 Mtetra
.605 .714 .922 r
.17808 .45809 .18494 .46499 .19474 .4626 .18788 .45587 Mtetra
.608 .722 .926 r
.18788 .45587 .19474 .4626 .20451 .46102 .19773 .45358 Mtetra
.163 .481 .898 r
.19773 .45358 .20451 .46102 .21531 .449 .20706 .45714 Mtetra
.71 .927 .598 r
.20706 .45714 .21531 .449 .22483 .45089 .21808 .44354 Mtetra
.588 .696 .917 r
.21808 .44354 .22483 .45089 .2348 .4484 .22801 .44168 Mtetra
.625 .73 .922 r
.22801 .44168 .2348 .4484 .24483 .4457 .23807 .43896 Mtetra
.618 .728 .925 r
.23807 .43896 .24483 .4457 .25485 .44376 .24815 .43639 Mtetra
.376 .604 .937 r
.24815 .43639 .25485 .44376 .2659 .42932 .25795 .43779 Mtetra
.541 .831 .496 r
.25795 .43779 .2659 .42932 .27551 .43345 .26887 .42585 Mtetra
.585 .691 .915 r
.26887 .42585 .27551 .43345 .2857 .43082 .27902 .42403 Mtetra
.633 .734 .921 r
.27902 .42403 .2857 .43082 .29596 .42777 .28929 .42108 Mtetra
.64 .74 .921 r
.28929 .42108 .29596 .42777 .30627 .42466 .29962 .41794 Mtetra
.638 .74 .922 r
.29962 .41794 .30627 .42466 .31661 .4217 .30999 .41483 Mtetra
.619 .729 .925 r
.30999 .41483 .31661 .4217 .32691 .42004 .32038 .41214 Mtetra
0 .08 .609 r
.32038 .41214 .32691 .42004 .33782 .40882 .33009 .42147 Mtetra
.665 .826 .398 r
.33009 .42147 .33782 .40882 .34811 .40882 .3416 .40143 Mtetra
.61 .711 .917 r
.3416 .40143 .34811 .40882 .35862 .40582 .3521 .39896 Mtetra
.642 .74 .92 r
.3521 .39896 .35862 .40582 .36918 .40245 .36269 .39569 Mtetra
.65 .747 .92 r
.36269 .39569 .36918 .40245 .3798 .39893 .37333 .39219 Mtetra
.654 .75 .92 r
.37333 .39219 .3798 .39893 .39047 .39532 .38402 .38859 Mtetra
.656 .752 .92 r
.38402 .38859 .39047 .39532 .40118 .39165 .39475 .38492 Mtetra
.658 .753 .92 r
.39475 .38492 .40118 .39165 .41193 .38793 .40553 .38119 Mtetra
.659 .753 .92 r
.40553 .38119 .41193 .38793 .42273 .38418 .41635 .37742 Mtetra
.659 .754 .92 r
.41635 .37742 .42273 .38418 .43357 .38042 .42722 .37363 Mtetra
.42722 .37363 .43357 .38042 .44445 .37664 .43813 .36982 Mtetra
.43813 .36982 .44445 .37664 .45537 .37286 .44908 .366 Mtetra
.659 .753 .92 r
.44908 .366 .45537 .37286 .46634 .36906 .46008 .36218 Mtetra
.658 .753 .92 r
.46008 .36218 .46634 .36906 .47735 .36526 .47112 .35834 Mtetra
.47112 .35834 .47735 .36526 .48841 .36145 .48221 .3545 Mtetra
.48221 .3545 .48841 .36145 .49951 .35762 .49334 .35065 Mtetra
.49334 .35065 .49951 .35762 .51066 .35379 .50452 .34678 Mtetra
.50452 .34678 .51066 .35379 .52185 .34994 .51574 .3429 Mtetra
.51574 .3429 .52185 .34994 .53308 .34607 .527 .33901 Mtetra
.657 .753 .92 r
.527 .33901 .53308 .34607 .54437 .3422 .53832 .3351 Mtetra
.53832 .3351 .54437 .3422 .5557 .33831 .54967 .33118 Mtetra
.54967 .33118 .5557 .33831 .56707 .3344 .56108 .32724 Mtetra
.657 .752 .92 r
.56108 .32724 .56707 .3344 .57849 .33048 .57253 .32329 Mtetra
.57253 .32329 .57849 .33048 .58996 .32655 .58403 .31933 Mtetra
.58403 .31933 .58996 .32655 .60147 .3226 .59558 .31535 Mtetra
.59558 .31535 .60147 .3226 .61304 .31863 .60717 .31135 Mtetra
.60717 .31135 .61304 .31863 .62465 .31465 .61882 .30734 Mtetra
.61882 .30734 .62465 .31465 .63631 .31065 .63051 .30331 Mtetra
.63051 .30331 .63631 .31065 .64801 .30664 .64225 .29927 Mtetra
.64225 .29927 .64801 .30664 .65977 .30261 .65404 .29521 Mtetra
.65404 .29521 .65977 .30261 .67157 .29857 .66588 .29113 Mtetra
.66588 .29113 .67157 .29857 .68343 .29451 .67777 .28704 Mtetra
.67777 .28704 .68343 .29451 .69533 .29043 .68971 .28293 Mtetra
.68971 .28293 .69533 .29043 .70729 .28634 .70169 .2788 Mtetra
.70169 .2788 .70729 .28634 .71929 .28223 .71373 .27466 Mtetra
.71373 .27466 .71929 .28223 .73135 .2781 .72582 .2705 Mtetra
.72582 .2705 .73135 .2781 .74345 .27395 .73797 .26632 Mtetra
.73797 .26632 .74345 .27395 .75561 .26979 .75016 .26213 Mtetra
.75016 .26213 .75561 .26979 .76782 .26561 .76241 .25792 Mtetra
.76241 .25792 .76782 .26561 .78008 .26142 .7747 .25369 Mtetra
.7747 .25369 .78008 .26142 .79239 .25721 .78705 .24944 Mtetra
.543 .66 .912 r
.13191 .46359 .13878 .47146 .14839 .46949 .14141 .46271 Mtetra
.602 .717 .925 r
.14141 .46271 .14839 .46949 .15802 .46776 .1511 .46056 Mtetra
.426 .633 .941 r
.1511 .46056 .15802 .46776 .16947 .44975 .16053 .46123 Mtetra
0 0 0 r
.16053 .46123 .16947 .44975 .17808 .45809 .17125 .45041 Mtetra
.563 .676 .915 r
.17125 .45041 .17808 .45809 .18788 .45587 .18097 .44909 Mtetra
.614 .723 .924 r
.18097 .44909 .18788 .45587 .19773 .45358 .19086 .44664 Mtetra
.573 .705 .932 r
.19086 .44664 .19773 .45358 .20706 .45714 .2007 .44502 Mtetra
.776 .663 .739 r
.2007 .44502 .20706 .45714 .21808 .44354 .21161 .43289 Mtetra
.421 .529 .862 r
.21161 .43289 .21808 .44354 .22801 .44168 .22119 .43475 Mtetra
.617 .722 .921 r
.22119 .43475 .22801 .44168 .23807 .43896 .23125 .4322 Mtetra
.625 .731 .923 r
.23125 .4322 .23807 .43896 .24815 .43639 .24137 .42944 Mtetra
.589 .714 .929 r
.24137 .42944 .24815 .43639 .25795 .43779 .25146 .42744 Mtetra
.816 .7 .738 r
.25146 .42744 .25795 .43779 .26887 .42585 .26263 .41289 Mtetra
.338 .433 .811 r
.26263 .41289 .26887 .42585 .27902 .42403 .27231 .41699 Mtetra
.621 .723 .92 r
.27231 .41699 .27902 .42403 .28929 .42108 .28258 .41429 Mtetra
.638 .738 .921 r
.28258 .41429 .28929 .42108 .29962 .41794 .29293 .41118 Mtetra
.64 .74 .922 r
.29293 .41118 .29962 .41794 .30999 .41483 .30333 .408 Mtetra
.633 .737 .923 r
.30333 .408 .30999 .41483 .32038 .41214 .31376 .40498 Mtetra
.573 .705 .932 r
.31376 .40498 .32038 .41214 .33009 .42147 .32415 .40327 Mtetra
.723 .588 .704 r
.32415 .40327 .33009 .42147 .3416 .40143 .33517 .39195 Mtetra
.509 .609 .888 r
.33517 .39195 .3416 .40143 .3521 .39896 .34554 .3919 Mtetra
.633 .732 .92 r
.34554 .3919 .3521 .39896 .36269 .39569 .35614 .38883 Mtetra
.647 .744 .92 r
.35614 .38883 .36269 .39569 .37333 .39219 .3668 .38539 Mtetra
.652 .749 .92 r
.3668 .38539 .37333 .39219 .38402 .38859 .37752 .3818 Mtetra
.655 .751 .92 r
.37752 .3818 .38402 .38859 .39475 .38492 .38828 .37812 Mtetra
.657 .752 .92 r
.38828 .37812 .39475 .38492 .40553 .38119 .39908 .37439 Mtetra
.658 .753 .92 r
.39908 .37439 .40553 .38119 .41635 .37742 .40994 .3706 Mtetra
.659 .754 .92 r
.40994 .3706 .41635 .37742 .42722 .37363 .42083 .36678 Mtetra
.42083 .36678 .42722 .37363 .43813 .36982 .43177 .36295 Mtetra
.43177 .36295 .43813 .36982 .44908 .366 .44275 .3591 Mtetra
.44275 .3591 .44908 .366 .46008 .36218 .45378 .35524 Mtetra
.658 .753 .92 r
.45378 .35524 .46008 .36218 .47112 .35834 .46485 .35138 Mtetra
.46485 .35138 .47112 .35834 .48221 .3545 .47596 .3475 Mtetra
.47596 .3475 .48221 .3545 .49334 .35065 .48712 .34362 Mtetra
.48712 .34362 .49334 .35065 .50452 .34678 .49833 .33972 Mtetra
.49833 .33972 .50452 .34678 .51574 .3429 .50958 .33581 Mtetra
.50958 .33581 .51574 .3429 .527 .33901 .52087 .33188 Mtetra
.52087 .33188 .527 .33901 .53832 .3351 .53222 .32795 Mtetra
.657 .753 .92 r
.53222 .32795 .53832 .3351 .54967 .33118 .54361 .324 Mtetra
.54361 .324 .54967 .33118 .56108 .32724 .55504 .32003 Mtetra
.657 .752 .92 r
.55504 .32003 .56108 .32724 .57253 .32329 .56653 .31605 Mtetra
.56653 .31605 .57253 .32329 .58403 .31933 .57806 .31205 Mtetra
.57806 .31205 .58403 .31933 .59558 .31535 .58964 .30804 Mtetra
.58964 .30804 .59558 .31535 .60717 .31135 .60127 .30401 Mtetra
.60127 .30401 .60717 .31135 .61882 .30734 .61294 .29997 Mtetra
.61294 .29997 .61882 .30734 .63051 .30331 .62467 .29591 Mtetra
.62467 .29591 .63051 .30331 .64225 .29927 .63644 .29184 Mtetra
.63644 .29184 .64225 .29927 .65404 .29521 .64827 .28774 Mtetra
.64827 .28774 .65404 .29521 .66588 .29113 .66014 .28364 Mtetra
.66014 .28364 .66588 .29113 .67777 .28704 .67206 .27951 Mtetra
.67206 .27951 .67777 .28704 .68971 .28293 .68403 .27537 Mtetra
.68403 .27537 .68971 .28293 .70169 .2788 .69606 .27121 Mtetra
.69606 .27121 .70169 .2788 .71373 .27466 .70813 .26704 Mtetra
.70813 .26704 .71373 .27466 .72582 .2705 .72026 .26284 Mtetra
.72026 .26284 .72582 .2705 .73797 .26632 .73244 .25863 Mtetra
.73244 .25863 .73797 .26632 .75016 .26213 .74467 .25441 Mtetra
.74467 .25441 .75016 .26213 .76241 .25792 .75695 .25016 Mtetra
.75695 .25016 .76241 .25792 .7747 .25369 .76929 .2459 Mtetra
.76929 .2459 .7747 .25369 .78705 .24944 .78167 .24162 Mtetra
0 0 .462 r
.12768 .43375 .13191 .46359 .14141 .46271 .13441 .45569 Mtetra
.595 .708 .923 r
.13441 .45569 .14141 .46271 .1511 .46056 .1441 .45367 Mtetra
.582 .709 .93 r
.1441 .45367 .1511 .46056 .16053 .46123 .15381 .45188 Mtetra
.843 .711 .718 r
.15381 .45188 .16053 .46123 .17125 .45041 .16537 .43375 Mtetra
.16 .254 .713 r
.16537 .43375 .17125 .45041 .18097 .44909 .17403 .44207 Mtetra
.605 .714 .922 r
.17403 .44207 .18097 .44909 .19086 .44664 .18392 .4398 Mtetra
.608 .722 .926 r
.18392 .4398 .19086 .44664 .2007 .44502 .19385 .43745 Mtetra
.166 .482 .899 r
.19385 .43745 .2007 .44502 .21161 .43289 .20325 .44098 Mtetra
.718 .932 .606 r
.20325 .44098 .21161 .43289 .22119 .43475 .21438 .42727 Mtetra
.588 .696 .917 r
.21438 .42727 .22119 .43475 .23125 .4322 .22439 .42535 Mtetra
.625 .73 .922 r
.22439 .42535 .23125 .4322 .24137 .42944 .23452 .42258 Mtetra
.618 .728 .925 r
.23452 .42258 .24137 .42944 .25146 .42744 .24469 .41995 Mtetra
.377 .604 .937 r
.24469 .41995 .25146 .42744 .26263 .41289 .25457 .42131 Mtetra
.554 .841 .508 r
.25457 .42131 .26263 .41289 .27231 .41699 .2656 .40926 Mtetra
.585 .691 .915 r
.2656 .40926 .27231 .41699 .28258 .41429 .27583 .40738 Mtetra
.633 .734 .921 r
.27583 .40738 .28258 .41429 .29293 .41118 .28619 .40437 Mtetra
.64 .74 .921 r
.28619 .40437 .29293 .41118 .30333 .408 .29661 .40116 Mtetra
.638 .74 .922 r
.29661 .40116 .30333 .408 .31376 .40498 .30707 .39799 Mtetra
.619 .729 .925 r
.30707 .39799 .31376 .40498 .32415 .40327 .31755 .39524 Mtetra
0 .085 .616 r
.31755 .39524 .32415 .40327 .33517 .39195 .32734 .40455 Mtetra
.674 .833 .407 r
.32734 .40455 .33517 .39195 .34554 .3919 .33896 .38437 Mtetra
.61 .711 .917 r
.33896 .38437 .34554 .3919 .35614 .38883 .34955 .38185 Mtetra
.642 .74 .92 r
.34955 .38185 .35614 .38883 .3668 .38539 .36023 .3785 Mtetra
.65 .747 .92 r
.36023 .3785 .3668 .38539 .37752 .3818 .37097 .37494 Mtetra
.654 .75 .92 r
.37097 .37494 .37752 .3818 .38828 .37812 .38176 .37127 Mtetra
.656 .752 .92 r
.38176 .37127 .38828 .37812 .39908 .37439 .39259 .36753 Mtetra
.658 .753 .92 r
.39259 .36753 .39908 .37439 .40994 .3706 .40347 .36373 Mtetra
.659 .753 .92 r
.40347 .36373 .40994 .3706 .42083 .36678 .41439 .35989 Mtetra
.659 .754 .92 r
.41439 .35989 .42083 .36678 .43177 .36295 .42536 .35602 Mtetra
.42536 .35602 .43177 .36295 .44275 .3591 .43637 .35214 Mtetra
.43637 .35214 .44275 .3591 .45378 .35524 .44742 .34825 Mtetra
.659 .753 .92 r
.44742 .34825 .45378 .35524 .46485 .35138 .45852 .34436 Mtetra
.658 .753 .92 r
.45852 .34436 .46485 .35138 .47596 .3475 .46967 .34045 Mtetra
.46967 .34045 .47596 .3475 .48712 .34362 .48086 .33653 Mtetra
.48086 .33653 .48712 .34362 .49833 .33972 .49209 .3326 Mtetra
.49209 .3326 .49833 .33972 .50958 .33581 .50337 .32866 Mtetra
.50337 .32866 .50958 .33581 .52087 .33188 .5147 .32471 Mtetra
.5147 .32471 .52087 .33188 .53222 .32795 .52607 .32074 Mtetra
.657 .753 .92 r
.52607 .32074 .53222 .32795 .54361 .324 .53749 .31676 Mtetra
.53749 .31676 .54361 .324 .55504 .32003 .54896 .31276 Mtetra
.54896 .31276 .55504 .32003 .56653 .31605 .56048 .30875 Mtetra
.657 .752 .92 r
.56048 .30875 .56653 .31605 .57806 .31205 .57204 .30472 Mtetra
.57204 .30472 .57806 .31205 .58964 .30804 .58365 .30068 Mtetra
.58365 .30068 .58964 .30804 .60127 .30401 .59531 .29662 Mtetra
.59531 .29662 .60127 .30401 .61294 .29997 .60702 .29255 Mtetra
.60702 .29255 .61294 .29997 .62467 .29591 .61878 .28845 Mtetra
.61878 .28845 .62467 .29591 .63644 .29184 .63059 .28435 Mtetra
.63059 .28435 .63644 .29184 .64827 .28774 .64245 .28022 Mtetra
.64245 .28022 .64827 .28774 .66014 .28364 .65435 .27608 Mtetra
.65435 .27608 .66014 .28364 .67206 .27951 .66631 .27193 Mtetra
.66631 .27193 .67206 .27951 .68403 .27537 .67832 .26775 Mtetra
.67832 .26775 .68403 .27537 .69606 .27121 .69038 .26356 Mtetra
.69038 .26356 .69606 .27121 .70813 .26704 .70249 .25935 Mtetra
.70249 .25935 .70813 .26704 .72026 .26284 .71465 .25513 Mtetra
.71465 .25513 .72026 .26284 .73244 .25863 .72687 .25088 Mtetra
.72687 .25088 .73244 .25863 .74467 .25441 .73913 .24662 Mtetra
.73913 .24662 .74467 .25441 .75695 .25016 .75145 .24234 Mtetra
.75145 .24234 .75695 .25016 .76929 .2459 .76382 .23805 Mtetra
.76382 .23805 .76929 .2459 .78167 .24162 .77625 .23373 Mtetra
.2 0 .182 r
.11678 .45801 .12768 .43375 .13441 .45569 .12747 .44771 Mtetra
.543 .66 .913 r
.12747 .44771 .13441 .45569 .1441 .45367 .13704 .44677 Mtetra
.602 .717 .925 r
.13704 .44677 .1441 .45367 .15381 .45188 .14681 .44456 Mtetra
.427 .633 .941 r
.14681 .44456 .15381 .45188 .16537 .43375 .15631 .44519 Mtetra
0 0 0 r
.15631 .44519 .16537 .43375 .17403 .44207 .16713 .43427 Mtetra
.563 .676 .915 r
.16713 .43427 .17403 .44207 .18392 .4398 .17693 .4329 Mtetra
.614 .723 .924 r
.17693 .4329 .18392 .4398 .19385 .43745 .1869 .4304 Mtetra
.573 .705 .932 r
.1869 .4304 .19385 .43745 .20325 .44098 .19682 .42871 Mtetra
.776 .664 .739 r
.19682 .42871 .20325 .44098 .21438 .42727 .20783 .41649 Mtetra
.42 .529 .862 r
.20783 .41649 .21438 .42727 .22439 .42535 .21749 .4183 Mtetra
.617 .722 .921 r
.21749 .4183 .22439 .42535 .23452 .42258 .22763 .4157 Mtetra
.625 .731 .923 r
.22763 .4157 .23452 .42258 .24469 .41995 .23784 .41287 Mtetra
.589 .713 .929 r
.23784 .41287 .24469 .41995 .25457 .42131 .24802 .41082 Mtetra
.816 .701 .738 r
.24802 .41082 .25457 .42131 .2656 .40926 .25929 .39615 Mtetra
.337 .432 .811 r
.25929 .39615 .2656 .40926 .27583 .40738 .26904 .40022 Mtetra
.621 .724 .92 r
.26904 .40022 .27583 .40738 .28619 .40437 .27941 .39746 Mtetra
.638 .738 .921 r
.27941 .39746 .28619 .40437 .29661 .40116 .28985 .39428 Mtetra
.64 .74 .922 r
.28985 .39428 .29661 .40116 .30707 .39799 .30034 .39104 Mtetra
.633 .737 .923 r
.30034 .39104 .30707 .39799 .31755 .39524 .31086 .38795 Mtetra
.573 .705 .932 r
.31086 .38795 .31755 .39524 .32734 .40455 .32134 .38618 Mtetra
.723 .588 .704 r
.32134 .38618 .32734 .40455 .33896 .38437 .33246 .37476 Mtetra
.508 .609 .888 r
.33246 .37476 .33896 .38437 .34955 .38185 .34292 .37465 Mtetra
.633 .732 .92 r
.34292 .37465 .34955 .38185 .36023 .3785 .35362 .37152 Mtetra
.647 .744 .92 r
.35362 .37152 .36023 .3785 .37097 .37494 .36438 .36801 Mtetra
.652 .749 .92 r
.36438 .36801 .37097 .37494 .38176 .37127 .37519 .36435 Mtetra
.655 .751 .92 r
.37519 .36435 .38176 .37127 .39259 .36753 .38605 .3606 Mtetra
.657 .752 .92 r
.38605 .3606 .39259 .36753 .40347 .36373 .39695 .35679 Mtetra
.658 .753 .92 r
.39695 .35679 .40347 .36373 .41439 .35989 .4079 .35294 Mtetra
.659 .754 .92 r
.4079 .35294 .41439 .35989 .42536 .35602 .4189 .34905 Mtetra
.4189 .34905 .42536 .35602 .43637 .35214 .42994 .34514 Mtetra
.42994 .34514 .43637 .35214 .44742 .34825 .44102 .34122 Mtetra
.44102 .34122 .44742 .34825 .45852 .34436 .45215 .33729 Mtetra
.658 .753 .92 r
.45215 .33729 .45852 .34436 .46967 .34045 .46332 .33335 Mtetra
.46332 .33335 .46967 .34045 .48086 .33653 .47454 .3294 Mtetra
.47454 .3294 .48086 .33653 .49209 .3326 .48581 .32544 Mtetra
.48581 .32544 .49209 .3326 .50337 .32866 .49712 .32147 Mtetra
.49712 .32147 .50337 .32866 .5147 .32471 .50848 .31748 Mtetra
.50848 .31748 .5147 .32471 .52607 .32074 .51988 .31348 Mtetra
.51988 .31348 .52607 .32074 .53749 .31676 .53133 .30947 Mtetra
.657 .753 .92 r
.53133 .30947 .53749 .31676 .54896 .31276 .54283 .30544 Mtetra
.54283 .30544 .54896 .31276 .56048 .30875 .55438 .30139 Mtetra
.657 .752 .92 r
.55438 .30139 .56048 .30875 .57204 .30472 .56598 .29733 Mtetra
.56598 .29733 .57204 .30472 .58365 .30068 .57762 .29326 Mtetra
.57762 .29326 .58365 .30068 .59531 .29662 .58931 .28917 Mtetra
.58931 .28917 .59531 .29662 .60702 .29255 .60106 .28506 Mtetra
.60106 .28506 .60702 .29255 .61878 .28845 .61285 .28094 Mtetra
.61285 .28094 .61878 .28845 .63059 .28435 .62469 .2768 Mtetra
.62469 .2768 .63059 .28435 .64245 .28022 .63658 .27264 Mtetra
.63658 .27264 .64245 .28022 .65435 .27608 .64852 .26847 Mtetra
.64852 .26847 .65435 .27608 .66631 .27193 .66051 .26428 Mtetra
.66051 .26428 .66631 .27193 .67832 .26775 .67256 .26007 Mtetra
.67256 .26007 .67832 .26775 .69038 .26356 .68465 .25585 Mtetra
.68465 .25585 .69038 .26356 .70249 .25935 .6968 .25161 Mtetra
.6968 .25161 .70249 .25935 .71465 .25513 .709 .24735 Mtetra
.709 .24735 .71465 .25513 .72687 .25088 .72125 .24307 Mtetra
.72125 .24307 .72687 .25088 .73913 .24662 .73355 .23878 Mtetra
.73355 .23878 .73913 .24662 .75145 .24234 .74591 .23446 Mtetra
.74591 .23446 .75145 .24234 .76382 .23805 .75832 .23013 Mtetra
.75832 .23013 .76382 .23805 .77625 .23373 .77078 .22578 Mtetra
.886 .713 .662 r
.10986 .44926 .11678 .45801 .12747 .44771 .12322 .41765 Mtetra
0 0 .458 r
.12322 .41765 .12747 .44771 .13704 .44677 .12996 .43964 Mtetra
.595 .708 .923 r
.12996 .43964 .13704 .44677 .14681 .44456 .13973 .43756 Mtetra
.582 .709 .93 r
.13973 .43756 .14681 .44456 .15631 .44519 .14952 .43571 Mtetra
.844 .712 .718 r
.14952 .43571 .15631 .44519 .16713 .43427 .16119 .41746 Mtetra
.157 .252 .712 r
.16119 .41746 .16713 .43427 .17693 .4329 .16992 .42577 Mtetra
.605 .714 .922 r
.16992 .42577 .17693 .4329 .1869 .4304 .17988 .42344 Mtetra
.608 .722 .926 r
.17988 .42344 .1869 .4304 .19682 .42871 .18989 .42102 Mtetra
.169 .483 .899 r
.18989 .42102 .19682 .42871 .20783 .41649 .19936 .42452 Mtetra
.726 .937 .614 r
.19936 .42452 .20783 .41649 .21749 .4183 .2106 .4107 Mtetra
.588 .696 .917 r
.2106 .4107 .21749 .4183 .22763 .4157 .22069 .40873 Mtetra
.625 .73 .922 r
.22069 .40873 .22763 .4157 .23784 .41287 .23092 .40589 Mtetra
.618 .728 .925 r
.23092 .40589 .23784 .41287 .24802 .41082 .24117 .4032 Mtetra
.378 .604 .937 r
.24117 .4032 .24802 .41082 .25929 .39615 .25113 .40451 Mtetra
.566 .851 .521 r
.25113 .40451 .25929 .39615 .26904 .40022 .26226 .39237 Mtetra
.585 .691 .915 r
.26226 .39237 .26904 .40022 .27941 .39746 .27258 .39042 Mtetra
.633 .734 .921 r
.27258 .39042 .27941 .39746 .28985 .39428 .28303 .38734 Mtetra
.64 .74 .921 r
.28303 .38734 .28985 .39428 .30034 .39104 .29355 .38407 Mtetra
.638 .74 .922 r
.29355 .38407 .30034 .39104 .31086 .38795 .3041 .38083 Mtetra
.619 .729 .925 r
.3041 .38083 .31086 .38795 .32134 .38618 .31467 .37802 Mtetra
0 .091 .621 r
.31467 .37802 .32134 .38618 .33246 .37476 .32453 .38732 Mtetra
.683 .84 .416 r
.32453 .38732 .33246 .37476 .34292 .37465 .33627 .367 Mtetra
.61 .711 .917 r
.33627 .367 .34292 .37465 .35362 .37152 .34696 .3644 Mtetra
.642 .74 .92 r
.34696 .3644 .35362 .37152 .36438 .36801 .35774 .36099 Mtetra
.65 .747 .92 r
.35774 .36099 .36438 .36801 .37519 .36435 .36857 .35736 Mtetra
.654 .75 .92 r
.36857 .35736 .37519 .36435 .38605 .3606 .37946 .35362 Mtetra
.656 .752 .92 r
.37946 .35362 .38605 .3606 .39695 .35679 .39039 .3498 Mtetra
.658 .753 .92 r
.39039 .3498 .39695 .35679 .4079 .35294 .40136 .34593 Mtetra
.659 .753 .92 r
.40136 .34593 .4079 .35294 .4189 .34905 .41239 .34202 Mtetra
.659 .754 .92 r
.41239 .34202 .4189 .34905 .42994 .34514 .42346 .33808 Mtetra
.42346 .33808 .42994 .34514 .44102 .34122 .43457 .33413 Mtetra
.43457 .33413 .44102 .34122 .45215 .33729 .44573 .33016 Mtetra
.659 .753 .92 r
.44573 .33016 .45215 .33729 .46332 .33335 .45693 .32619 Mtetra
.658 .753 .92 r
.45693 .32619 .46332 .33335 .47454 .3294 .46818 .32221 Mtetra
.46818 .32221 .47454 .3294 .48581 .32544 .47948 .31822 Mtetra
.47948 .31822 .48581 .32544 .49712 .32147 .49082 .31421 Mtetra
.49082 .31421 .49712 .32147 .50848 .31748 .50221 .31019 Mtetra
.50221 .31019 .50848 .31748 .51988 .31348 .51364 .30616 Mtetra
.51364 .30616 .51988 .31348 .53133 .30947 .52513 .30212 Mtetra
.657 .753 .92 r
.52513 .30212 .53133 .30947 .54283 .30544 .53666 .29806 Mtetra
.53666 .29806 .54283 .30544 .55438 .30139 .54824 .29398 Mtetra
.54824 .29398 .55438 .30139 .56598 .29733 .55987 .28989 Mtetra
.657 .752 .92 r
.55987 .28989 .56598 .29733 .57762 .29326 .57154 .28578 Mtetra
.57154 .28578 .57762 .29326 .58931 .28917 .58327 .28166 Mtetra
.58327 .28166 .58931 .28917 .60106 .28506 .59504 .27752 Mtetra
.59504 .27752 .60106 .28506 .61285 .28094 .60687 .27337 Mtetra
.60687 .27337 .61285 .28094 .62469 .2768 .61874 .26919 Mtetra
.61874 .26919 .62469 .2768 .63658 .27264 .63067 .265 Mtetra
.63067 .265 .63658 .27264 .64852 .26847 .64264 .2608 Mtetra
.64264 .2608 .64852 .26847 .66051 .26428 .65467 .25658 Mtetra
.65467 .25658 .66051 .26428 .67256 .26007 .66675 .25233 Mtetra
.66675 .25233 .67256 .26007 .68465 .25585 .67888 .24808 Mtetra
.67888 .24808 .68465 .25585 .6968 .25161 .69106 .2438 Mtetra
.69106 .2438 .6968 .25161 .709 .24735 .7033 .23951 Mtetra
.7033 .23951 .709 .24735 .72125 .24307 .71559 .2352 Mtetra
.71559 .2352 .72125 .24307 .73355 .23878 .72793 .23087 Mtetra
.72793 .23087 .73355 .23878 .74591 .23446 .74032 .22652 Mtetra
.74032 .22652 .74591 .23446 .75832 .23013 .75277 .22215 Mtetra
.75277 .22215 .75832 .23013 .77078 .22578 .76527 .21777 Mtetra
.472 .656 .941 r
.10271 .44196 .10986 .44926 .12322 .41765 .11216 .44192 Mtetra
.189 0 .17 r
.11216 .44192 .12322 .41765 .12996 .43964 .12294 .43153 Mtetra
.543 .66 .913 r
.12294 .43153 .12996 .43964 .13973 .43756 .13259 .43054 Mtetra
.602 .717 .925 r
.13259 .43054 .13973 .43756 .14952 .43571 .14244 .42828 Mtetra
.428 .633 .941 r
.14244 .42828 .14952 .43571 .16119 .41746 .15201 .42886 Mtetra
0 0 0 r
.15201 .42886 .16119 .41746 .16992 .42577 .16294 .41784 Mtetra
.563 .676 .915 r
.16294 .41784 .16992 .42577 .17988 .42344 .17281 .41642 Mtetra
.614 .723 .924 r
.17281 .41642 .17988 .42344 .18989 .42102 .18286 .41385 Mtetra
.573 .705 .932 r
.18286 .41385 .18989 .42102 .19936 .42452 .19287 .41211 Mtetra
.777 .665 .739 r
.19287 .41211 .19936 .42452 .2106 .4107 .20398 .39979 Mtetra
.419 .528 .862 r
.20398 .39979 .2106 .4107 .22069 .40873 .21372 .40155 Mtetra
.617 .722 .921 r
.21372 .40155 .22069 .40873 .23092 .40589 .22395 .39888 Mtetra
.625 .731 .923 r
.22395 .39888 .23092 .40589 .24117 .4032 .23424 .396 Mtetra
.59 .713 .929 r
.23424 .396 .24117 .4032 .25113 .40451 .24451 .39388 Mtetra
.817 .702 .738 r
.24451 .39388 .25113 .40451 .26226 .39237 .25589 .3791 Mtetra
.335 .431 .811 r
.25589 .3791 .26226 .39237 .27258 .39042 .26572 .38313 Mtetra
.621 .724 .92 r
.26572 .38313 .27258 .39042 .28303 .38734 .27617 .38031 Mtetra
.638 .738 .921 r
.27617 .38031 .28303 .38734 .29355 .38407 .28671 .37707 Mtetra
.64 .74 .922 r
.28671 .37707 .29355 .38407 .3041 .38083 .29729 .37375 Mtetra
.633 .737 .923 r
.29729 .37375 .3041 .38083 .31467 .37802 .3079 .3706 Mtetra
.573 .705 .932 r
.3079 .3706 .31467 .37802 .32453 .38732 .31848 .36876 Mtetra
.723 .588 .704 r
.31848 .36876 .32453 .38732 .33627 .367 .3297 .35724 Mtetra
.508 .609 .888 r
.3297 .35724 .33627 .367 .34696 .3644 .34026 .35708 Mtetra
.633 .732 .92 r
.34026 .35708 .34696 .3644 .35774 .36099 .35105 .35388 Mtetra
.647 .744 .92 r
.35105 .35388 .35774 .36099 .36857 .35736 .36191 .3503 Mtetra
.652 .749 .92 r
.36191 .3503 .36857 .35736 .37946 .35362 .37282 .34657 Mtetra
.655 .751 .92 r
.37282 .34657 .37946 .35362 .39039 .3498 .38377 .34275 Mtetra
.657 .752 .92 r
.38377 .34275 .39039 .3498 .40136 .34593 .39478 .33886 Mtetra
.658 .753 .92 r
.39478 .33886 .40136 .34593 .41239 .34202 .40583 .33493 Mtetra
.659 .754 .92 r
.40583 .33493 .41239 .34202 .42346 .33808 .41693 .33097 Mtetra
.41693 .33097 .42346 .33808 .43457 .33413 .42807 .32699 Mtetra
.42807 .32699 .43457 .33413 .44573 .33016 .43926 .32299 Mtetra
.43926 .32299 .44573 .33016 .45693 .32619 .45049 .31898 Mtetra
.658 .753 .92 r
.45049 .31898 .45693 .32619 .46818 .32221 .46177 .31497 Mtetra
.46177 .31497 .46818 .32221 .47948 .31822 .4731 .31094 Mtetra
.4731 .31094 .47948 .31822 .49082 .31421 .48447 .3069 Mtetra
.48447 .3069 .49082 .31421 .50221 .31019 .49589 .30285 Mtetra
.49589 .30285 .50221 .31019 .51364 .30616 .50736 .29879 Mtetra
.50736 .29879 .51364 .30616 .52513 .30212 .51887 .29471 Mtetra
.51887 .29471 .52513 .30212 .53666 .29806 .53043 .29062 Mtetra
.657 .753 .92 r
.53043 .29062 .53666 .29806 .54824 .29398 .54205 .28651 Mtetra
.54205 .28651 .54824 .29398 .55987 .28989 .55371 .28239 Mtetra
.657 .752 .92 r
.55371 .28239 .55987 .28989 .57154 .28578 .56542 .27825 Mtetra
.56542 .27825 .57154 .28578 .58327 .28166 .57717 .27409 Mtetra
.57717 .27409 .58327 .28166 .59504 .27752 .58898 .26992 Mtetra
.58898 .26992 .59504 .27752 .60687 .27337 .60084 .26573 Mtetra
.60084 .26573 .60687 .27337 .61874 .26919 .61275 .26153 Mtetra
.61275 .26153 .61874 .26919 .63067 .265 .62471 .2573 Mtetra
.62471 .2573 .63067 .265 .64264 .2608 .63672 .25307 Mtetra
.63672 .25307 .64264 .2608 .65467 .25658 .64878 .24881 Mtetra
.64878 .24881 .65467 .25658 .66675 .25233 .6609 .24453 Mtetra
.6609 .24453 .66675 .25233 .67888 .24808 .67306 .24024 Mtetra
.67306 .24024 .67888 .24808 .69106 .2438 .68528 .23593 Mtetra
.68528 .23593 .69106 .2438 .7033 .23951 .69755 .2316 Mtetra
.69755 .2316 .7033 .23951 .71559 .2352 .70988 .22726 Mtetra
.70988 .22726 .71559 .2352 .72793 .23087 .72226 .22289 Mtetra
.72226 .22289 .72793 .23087 .74032 .22652 .73469 .21851 Mtetra
.73469 .21851 .74032 .22652 .75277 .22215 .74717 .21411 Mtetra
.74717 .21411 .75277 .22215 .76527 .21777 .75971 .20969 Mtetra
.58 .707 .929 r
.09547 .43487 .10271 .44196 .11216 .44192 .10516 .43304 Mtetra
.887 .714 .661 r
.10516 .43304 .11216 .44192 .12294 .43153 .11867 .40126 Mtetra
0 0 .454 r
.11867 .40126 .12294 .43153 .13259 .43054 .12543 .42329 Mtetra
.595 .708 .923 r
.12543 .42329 .13259 .43054 .14244 .42828 .13528 .42115 Mtetra
.582 .709 .93 r
.13528 .42115 .14244 .42828 .15201 .42886 .14514 .41925 Mtetra
.845 .713 .718 r
.14514 .41925 .15201 .42886 .16294 .41784 .15694 .40087 Mtetra
.153 .25 .712 r
.15694 .40087 .16294 .41784 .17281 .41642 .16572 .40916 Mtetra
.605 .714 .922 r
.16572 .40916 .17281 .41642 .18286 .41385 .17577 .40677 Mtetra
.608 .722 .926 r
.17577 .40677 .18286 .41385 .19287 .41211 .18587 .40429 Mtetra
.172 .484 .9 r
.18587 .40429 .19287 .41211 .20398 .39979 .19541 .40775 Mtetra
.734 .942 .622 r
.19541 .40775 .20398 .39979 .21372 .40155 .20675 .39383 Mtetra
.588 .696 .917 r
.20675 .39383 .21372 .40155 .22395 .39888 .21693 .39179 Mtetra
.625 .73 .922 r
.21693 .39179 .22395 .39888 .23424 .396 .22724 .38889 Mtetra
.618 .728 .925 r
.22724 .38889 .23424 .396 .24451 .39388 .23759 .38613 Mtetra
.38 .604 .936 r
.23759 .38613 .24451 .39388 .25589 .3791 .24763 .3874 Mtetra
.578 .86 .533 r
.24763 .3874 .25589 .3791 .26572 .38313 .25886 .37515 Mtetra
.585 .691 .915 r
.25886 .37515 .26572 .38313 .27617 .38031 .26927 .37314 Mtetra
.633 .734 .921 r
.26927 .37314 .27617 .38031 .28671 .37707 .27982 .37 Mtetra
.64 .74 .921 r
.27982 .37 .28671 .37707 .29729 .37375 .29042 .36666 Mtetra
.638 .74 .922 r
.29042 .36666 .29729 .37375 .3079 .3706 .30107 .36335 Mtetra
.62 .729 .925 r
.30107 .36335 .3079 .3706 .31848 .36876 .31173 .36047 Mtetra
0 .097 .627 r
.31173 .36047 .31848 .36876 .3297 .35724 .32167 .36975 Mtetra
.692 .847 .425 r
.32167 .36975 .3297 .35724 .34026 .35708 .33353 .34929 Mtetra
.61 .711 .917 r
.33353 .34929 .34026 .35708 .35105 .35388 .34432 .34663 Mtetra
.642 .74 .92 r
.34432 .34663 .35105 .35388 .36191 .3503 .35519 .34315 Mtetra
.65 .747 .92 r
.35519 .34315 .36191 .3503 .37282 .34657 .36613 .33944 Mtetra
.654 .75 .92 r
.36613 .33944 .37282 .34657 .38377 .34275 .37711 .33563 Mtetra
.656 .752 .92 r
.37711 .33563 .38377 .34275 .39478 .33886 .38814 .33174 Mtetra
.658 .753 .92 r
.38814 .33174 .39478 .33886 .40583 .33493 .39922 .32779 Mtetra
.659 .753 .92 r
.39922 .32779 .40583 .33493 .41693 .33097 .41035 .3238 Mtetra
.659 .754 .92 r
.41035 .3238 .41693 .33097 .42807 .32699 .42152 .31979 Mtetra
.42152 .31979 .42807 .32699 .43926 .32299 .43274 .31576 Mtetra
.43274 .31576 .43926 .32299 .45049 .31898 .444 .31172 Mtetra
.659 .753 .92 r
.444 .31172 .45049 .31898 .46177 .31497 .45531 .30767 Mtetra
.658 .753 .92 r
.45531 .30767 .46177 .31497 .4731 .31094 .46667 .30361 Mtetra
.46667 .30361 .4731 .31094 .48447 .3069 .47807 .29954 Mtetra
.47807 .29954 .48447 .3069 .49589 .30285 .48952 .29546 Mtetra
.48952 .29546 .49589 .30285 .50736 .29879 .50102 .29136 Mtetra
.50102 .29136 .50736 .29879 .51887 .29471 .51257 .28725 Mtetra
.51257 .28725 .51887 .29471 .53043 .29062 .52416 .28313 Mtetra
.657 .753 .92 r
.52416 .28313 .53043 .29062 .54205 .28651 .5358 .27898 Mtetra
.5358 .27898 .54205 .28651 .55371 .28239 .5475 .27483 Mtetra
.5475 .27483 .55371 .28239 .56542 .27825 .55924 .27066 Mtetra
.657 .752 .92 r
.55924 .27066 .56542 .27825 .57717 .27409 .57103 .26647 Mtetra
.57103 .26647 .57717 .27409 .58898 .26992 .58287 .26226 Mtetra
.58287 .26226 .58898 .26992 .60084 .26573 .59477 .25804 Mtetra
.59477 .25804 .60084 .26573 .61275 .26153 .60671 .2538 Mtetra
.60671 .2538 .61275 .26153 .62471 .2573 .6187 .24954 Mtetra
.6187 .24954 .62471 .2573 .63672 .25307 .63075 .24527 Mtetra
.63075 .24527 .63672 .25307 .64878 .24881 .64285 .24098 Mtetra
.64285 .24098 .64878 .24881 .6609 .24453 .655 .23667 Mtetra
.655 .23667 .6609 .24453 .67306 .24024 .6672 .23234 Mtetra
.6672 .23234 .67306 .24024 .68528 .23593 .67946 .228 Mtetra
.67946 .228 .68528 .23593 .69755 .2316 .69176 .22364 Mtetra
.69176 .22364 .69755 .2316 .70988 .22726 .70413 .21926 Mtetra
.70413 .21926 .70988 .22726 .72226 .22289 .71654 .21486 Mtetra
.71654 .21486 .72226 .22289 .73469 .21851 .72901 .21044 Mtetra
.72901 .21044 .73469 .21851 .74717 .21411 .74153 .206 Mtetra
.74153 .206 .74717 .21411 .75971 .20969 .75411 .20154 Mtetra
.59 .708 .925 r
.0882 .42767 .09547 .43487 .10516 .43304 .09793 .42563 Mtetra
.473 .656 .941 r
.09793 .42563 .10516 .43304 .11867 .40126 .10745 .42554 Mtetra
.177 0 .158 r
.10745 .42554 .11867 .40126 .12543 .42329 .11834 .41505 Mtetra
.543 .66 .913 r
.11834 .41505 .12543 .42329 .13528 .42115 .12806 .41401 Mtetra
.602 .717 .925 r
.12806 .41401 .13528 .42115 .14514 .41925 .13799 .41169 Mtetra
.429 .633 .941 r
.13799 .41169 .14514 .41925 .15694 .40087 .14763 .41222 Mtetra
0 0 0 r
.14763 .41222 .15694 .40087 .16572 .40916 .15866 .40111 Mtetra
.563 .676 .915 r
.15866 .40111 .16572 .40916 .17577 .40677 .16862 .39962 Mtetra
.614 .723 .924 r
.16862 .39962 .17577 .40677 .18587 .40429 .17875 .397 Mtetra
.573 .705 .931 r
.17875 .397 .18587 .40429 .19541 .40775 .18885 .39519 Mtetra
.777 .665 .739 r
.18885 .39519 .19541 .40775 .20675 .39383 .20007 .38277 Mtetra
.419 .528 .862 r
.20007 .38277 .20675 .39383 .21693 .39179 .20988 .38449 Mtetra
.617 .722 .921 r
.20988 .38449 .21693 .39179 .22724 .38889 .22019 .38176 Mtetra
.625 .731 .923 r
.22019 .38176 .22724 .38889 .23759 .38613 .23057 .3788 Mtetra
.59 .713 .929 r
.23057 .3788 .23759 .38613 .24763 .3874 .24093 .37662 Mtetra
.818 .703 .738 r
.24093 .37662 .24763 .3874 .25886 .37515 .25242 .36173 Mtetra
.334 .43 .811 r
.25242 .36173 .25886 .37515 .26927 .37314 .26233 .36572 Mtetra
.621 .724 .92 r
.26233 .36572 .26927 .37314 .27982 .37 .27288 .36283 Mtetra
.638 .738 .921 r
.27288 .36283 .27982 .37 .29042 .36666 .2835 .35952 Mtetra
.64 .74 .922 r
.2835 .35952 .29042 .36666 .30107 .36335 .29418 .35614 Mtetra
.633 .737 .923 r
.29418 .35614 .30107 .36335 .31173 .36047 .30489 .35291 Mtetra
.573 .705 .931 r
.30489 .35291 .31173 .36047 .32167 .36975 .31556 .35101 Mtetra
.724 .589 .704 r
.31556 .35101 .32167 .36975 .33353 .34929 .32689 .33939 Mtetra
.508 .609 .888 r
.32689 .33939 .33353 .34929 .34432 .34663 .33754 .33917 Mtetra
.633 .732 .92 r
.33754 .33917 .34432 .34663 .35519 .34315 .34843 .33589 Mtetra
.647 .744 .92 r
.34843 .33589 .35519 .34315 .36613 .33944 .35939 .33224 Mtetra
.652 .749 .92 r
.35939 .33224 .36613 .33944 .37711 .33563 .3704 .32844 Mtetra
.655 .751 .92 r
.3704 .32844 .37711 .33563 .38814 .33174 .38145 .32454 Mtetra
.657 .752 .92 r
.38145 .32454 .38814 .33174 .39922 .32779 .39256 .32058 Mtetra
.658 .753 .92 r
.39256 .32058 .39922 .32779 .41035 .3238 .40372 .31658 Mtetra
.659 .754 .92 r
.40372 .31658 .41035 .3238 .42152 .31979 .41492 .31254 Mtetra
.41492 .31254 .42152 .31979 .43274 .31576 .42617 .30848 Mtetra
.42617 .30848 .43274 .31576 .444 .31172 .43746 .3044 Mtetra
.43746 .3044 .444 .31172 .45531 .30767 .4488 .30032 Mtetra
.658 .753 .92 r
.4488 .30032 .45531 .30767 .46667 .30361 .46019 .29623 Mtetra
.46019 .29623 .46667 .30361 .47807 .29954 .47162 .29212 Mtetra
.47162 .29212 .47807 .29954 .48952 .29546 .4831 .288 Mtetra
.4831 .288 .48952 .29546 .50102 .29136 .49463 .28387 Mtetra
.49463 .28387 .50102 .29136 .51257 .28725 .50621 .27973 Mtetra
.50621 .27973 .51257 .28725 .52416 .28313 .51784 .27557 Mtetra
.51784 .27557 .52416 .28313 .5358 .27898 .52951 .2714 Mtetra
.657 .753 .92 r
.52951 .2714 .5358 .27898 .5475 .27483 .54124 .26721 Mtetra
.54124 .26721 .5475 .27483 .55924 .27066 .55302 .263 Mtetra
.657 .752 .92 r
.55302 .263 .55924 .27066 .57103 .26647 .56484 .25878 Mtetra
.56484 .25878 .57103 .26647 .58287 .26226 .57672 .25454 Mtetra
.57672 .25454 .58287 .26226 .59477 .25804 .58864 .25029 Mtetra
.58864 .25029 .59477 .25804 .60671 .2538 .60062 .24601 Mtetra
.60062 .24601 .60671 .2538 .6187 .24954 .61265 .24172 Mtetra
.61265 .24172 .6187 .24954 .63075 .24527 .62473 .23741 Mtetra
.62473 .23741 .63075 .24527 .64285 .24098 .63687 .23309 Mtetra
.63687 .23309 .64285 .24098 .655 .23667 .64905 .22875 Mtetra
.64905 .22875 .655 .23667 .6672 .23234 .66129 .22438 Mtetra
.66129 .22438 .6672 .23234 .67946 .228 .67358 .22 Mtetra
.67358 .22 .67946 .228 .69176 .22364 .68593 .21561 Mtetra
.68593 .21561 .69176 .22364 .70413 .21926 .69832 .21119 Mtetra
.69832 .21119 .70413 .21926 .71654 .21486 .71078 .20675 Mtetra
.71078 .20675 .71654 .21486 .72901 .21044 .72329 .2023 Mtetra
.72329 .2023 .72901 .21044 .74153 .206 .73585 .19783 Mtetra
.73585 .19783 .74153 .206 .75411 .20154 .74847 .19333 Mtetra
.559 .679 .919 r
.08096 .41983 .0882 .42767 .09793 .42563 .09061 .41842 Mtetra
.58 .707 .929 r
.09061 .41842 .09793 .42563 .10745 .42554 .10038 .41653 Mtetra
.888 .715 .661 r
.10038 .41653 .10745 .42554 .11834 .41505 .11404 .38457 Mtetra
0 0 .45 r
.11404 .38457 .11834 .41505 .12806 .41401 .12082 .40663 Mtetra
.595 .708 .923 r
.12082 .40663 .12806 .41401 .13799 .41169 .13074 .40444 Mtetra
.582 .709 .93 r
.13074 .40444 .13799 .41169 .14763 .41222 .14069 .40247 Mtetra
.845 .714 .718 r
.14069 .40247 .14763 .41222 .15866 .40111 .15261 .38397 Mtetra
.15 .248 .711 r
.15261 .38397 .15866 .40111 .16862 .39962 .16145 .39224 Mtetra
.605 .714 .922 r
.16145 .39224 .16862 .39962 .17875 .397 .17158 .38979 Mtetra
.608 .722 .926 r
.17158 .38979 .17875 .397 .18885 .39519 .18176 .38725 Mtetra
.175 .486 .9 r
.18176 .38725 .18885 .39519 .20007 .38277 .19138 .39067 Mtetra
.741 .947 .63 r
.19138 .39067 .20007 .38277 .20988 .38449 .20283 .37663 Mtetra
.588 .697 .917 r
.20283 .37663 .20988 .38449 .22019 .38176 .2131 .37453 Mtetra
.625 .73 .922 r
.2131 .37453 .22019 .38176 .23057 .3788 .2235 .37156 Mtetra
.618 .728 .925 r
.2235 .37156 .23057 .3788 .24093 .37662 .23393 .36874 Mtetra
.381 .605 .936 r
.23393 .36874 .24093 .37662 .25242 .36173 .24405 .36996 Mtetra
.59 .869 .545 r
.24405 .36996 .25242 .36173 .26233 .36572 .2554 .3576 Mtetra
.585 .691 .915 r
.2554 .3576 .26233 .36572 .27288 .36283 .2659 .35553 Mtetra
.632 .734 .921 r
.2659 .35553 .27288 .36283 .2835 .35952 .27654 .35232 Mtetra
.64 .74 .921 r
.27654 .35232 .2835 .35952 .29418 .35614 .28724 .34891 Mtetra
.638 .74 .922 r
.28724 .34891 .29418 .35614 .30489 .35291 .29798 .34553 Mtetra
.62 .729 .925 r
.29798 .34553 .30489 .35291 .31556 .35101 .30874 .34258 Mtetra
0 .103 .633 r
.30874 .34258 .31556 .35101 .32689 .33939 .31876 .35184 Mtetra
.7 .853 .434 r
.31876 .35184 .32689 .33939 .33754 .33917 .33074 .33124 Mtetra
.61 .711 .917 r
.33074 .33124 .33754 .33917 .34843 .33589 .34162 .32851 Mtetra
.642 .74 .92 r
.34162 .32851 .34843 .33589 .35939 .33224 .3526 .32495 Mtetra
.65 .747 .92 r
.3526 .32495 .35939 .33224 .3704 .32844 .36363 .32117 Mtetra
.654 .75 .92 r
.36363 .32117 .3704 .32844 .38145 .32454 .37472 .31728 Mtetra
.656 .752 .92 r
.37472 .31728 .38145 .32454 .39256 .32058 .38585 .31332 Mtetra
.658 .753 .92 r
.38585 .31332 .39256 .32058 .40372 .31658 .39704 .30929 Mtetra
.659 .753 .92 r
.39704 .30929 .40372 .31658 .41492 .31254 .40827 .30523 Mtetra
.659 .754 .92 r
.40827 .30523 .41492 .31254 .42617 .30848 .41954 .30114 Mtetra
.41954 .30114 .42617 .30848 .43746 .3044 .43087 .29703 Mtetra
.43087 .29703 .43746 .3044 .4488 .30032 .44224 .29291 Mtetra
.659 .753 .92 r
.44224 .29291 .4488 .30032 .46019 .29623 .45366 .28878 Mtetra
.658 .753 .92 r
.45366 .28878 .46019 .29623 .47162 .29212 .46512 .28464 Mtetra
.46512 .28464 .47162 .29212 .4831 .288 .47663 .28049 Mtetra
.47663 .28049 .4831 .288 .49463 .28387 .4882 .27633 Mtetra
.4882 .27633 .49463 .28387 .50621 .27973 .49981 .27215 Mtetra
.49981 .27215 .50621 .27973 .51784 .27557 .51147 .26796 Mtetra
.51147 .26796 .51784 .27557 .52951 .2714 .52318 .26375 Mtetra
.657 .753 .92 r
.52318 .26375 .52951 .2714 .54124 .26721 .53493 .25953 Mtetra
.53493 .25953 .54124 .26721 .55302 .263 .54674 .25529 Mtetra
.54674 .25529 .55302 .263 .56484 .25878 .5586 .25103 Mtetra
.657 .752 .92 r
.5586 .25103 .56484 .25878 .57672 .25454 .57051 .24676 Mtetra
.57051 .24676 .57672 .25454 .58864 .25029 .58247 .24247 Mtetra
.58247 .24247 .58864 .25029 .60062 .24601 .59449 .23816 Mtetra
.59449 .23816 .60062 .24601 .61265 .24172 .60655 .23384 Mtetra
.60655 .23384 .61265 .24172 .62473 .23741 .61867 .22949 Mtetra
.61867 .22949 .62473 .23741 .63687 .23309 .63083 .22513 Mtetra
.63083 .22513 .63687 .23309 .64905 .22875 .64306 .22076 Mtetra
.64306 .22076 .64905 .22875 .66129 .22438 .65533 .21636 Mtetra
.65533 .21636 .66129 .22438 .67358 .22 .66766 .21194 Mtetra
.66766 .21194 .67358 .22 .68593 .21561 .68004 .20751 Mtetra
.68004 .20751 .68593 .21561 .69832 .21119 .69248 .20306 Mtetra
.69248 .20306 .69832 .21119 .71078 .20675 .70497 .19858 Mtetra
.70497 .19858 .71078 .20675 .72329 .2023 .71751 .19409 Mtetra
.71751 .19409 .72329 .2023 .73585 .19783 .73012 .18958 Mtetra
.73012 .18958 .73585 .19783 .74847 .19333 .74277 .18505 Mtetra
.263 .385 .8 r
.07443 .40649 .08096 .41983 .09061 .41842 .08325 .41109 Mtetra
.59 .708 .925 r
.08325 .41109 .09061 .41842 .10038 .41653 .09306 .40899 Mtetra
.473 .656 .94 r
.09306 .40899 .10038 .41653 .11404 .38457 .10265 .40885 Mtetra
.164 0 .145 r
.10265 .40885 .11404 .38457 .12082 .40663 .11364 .39827 Mtetra
.543 .66 .913 r
.11364 .39827 .12082 .40663 .13074 .40444 .12344 .39718 Mtetra
.602 .717 .925 r
.12344 .39718 .13074 .40444 .14069 .40247 .13346 .39479 Mtetra
.429 .633 .94 r
.13346 .39479 .14069 .40247 .15261 .38397 .14317 .39527 Mtetra
0 0 0 r
.14317 .39527 .15261 .38397 .16145 .39224 .15431 .38406 Mtetra
.563 .676 .915 r
.15431 .38406 .16145 .39224 .17158 .38979 .16435 .38252 Mtetra
.614 .723 .924 r
.16435 .38252 .17158 .38979 .18176 .38725 .17457 .37982 Mtetra
.573 .705 .931 r
.17457 .37982 .18176 .38725 .19138 .39067 .18474 .37796 Mtetra
.778 .666 .74 r
.18474 .37796 .19138 .39067 .20283 .37663 .19607 .36543 Mtetra
.418 .528 .862 r
.19607 .36543 .20283 .37663 .2131 .37453 .20597 .3671 Mtetra
.617 .722 .921 r
.20597 .3671 .2131 .37453 .2235 .37156 .21637 .3643 Mtetra
.625 .731 .923 r
.21637 .3643 .2235 .37156 .23393 .36874 .22684 .36128 Mtetra
.59 .713 .929 r
.22684 .36128 .23393 .36874 .24405 .36996 .23728 .35904 Mtetra
.818 .704 .738 r
.23728 .35904 .24405 .36996 .2554 .3576 .24889 .34403 Mtetra
.332 .43 .811 r
.24889 .34403 .2554 .3576 .2659 .35553 .25888 .34798 Mtetra
.621 .724 .92 r
.25888 .34798 .2659 .35553 .27654 .35232 .26952 .34502 Mtetra
.638 .738 .921 r
.26952 .34502 .27654 .35232 .28724 .34891 .28024 .34164 Mtetra
.64 .74 .922 r
.28024 .34164 .28724 .34891 .29798 .34553 .29101 .33818 Mtetra
.633 .737 .923 r
.29101 .33818 .29798 .34553 .30874 .34258 .30182 .33489 Mtetra
.573 .705 .931 r
.30182 .33489 .30874 .34258 .31876 .35184 .31258 .33292 Mtetra
.724 .589 .704 r
.31258 .33292 .31876 .35184 .33074 .33124 .32403 .32119 Mtetra
.507 .609 .888 r
.32403 .32119 .33074 .33124 .34162 .32851 .33477 .32091 Mtetra
.633 .732 .92 r
.33477 .32091 .34162 .32851 .3526 .32495 .34576 .31756 Mtetra
.647 .744 .92 r
.34576 .31756 .3526 .32495 .36363 .32117 .35682 .31383 Mtetra
.652 .749 .92 r
.35682 .31383 .36363 .32117 .37472 .31728 .36793 .30995 Mtetra
.655 .751 .92 r
.36793 .30995 .37472 .31728 .38585 .31332 .37909 .30598 Mtetra
.657 .752 .92 r
.37909 .30598 .38585 .31332 .39704 .30929 .3903 .30195 Mtetra
.658 .753 .92 r
.3903 .30195 .39704 .30929 .40827 .30523 .40156 .29786 Mtetra
.659 .754 .92 r
.40156 .29786 .40827 .30523 .41954 .30114 .41287 .29374 Mtetra
.41287 .29374 .41954 .30114 .43087 .29703 .42422 .2896 Mtetra
.42422 .2896 .43087 .29703 .44224 .29291 .43562 .28545 Mtetra
.43562 .28545 .44224 .29291 .45366 .28878 .44707 .28128 Mtetra
.658 .753 .92 r
.44707 .28128 .45366 .28878 .46512 .28464 .45857 .27711 Mtetra
.45857 .27711 .46512 .28464 .47663 .28049 .47012 .27292 Mtetra
.47012 .27292 .47663 .28049 .4882 .27633 .48171 .26873 Mtetra
.48171 .26873 .4882 .27633 .49981 .27215 .49335 .26451 Mtetra
.49335 .26451 .49981 .27215 .51147 .26796 .50504 .26029 Mtetra
.50504 .26029 .51147 .26796 .52318 .26375 .51679 .25605 Mtetra
.51679 .25605 .52318 .26375 .53493 .25953 .52858 .25179 Mtetra
.657 .753 .92 r
.52858 .25179 .53493 .25953 .54674 .25529 .54042 .24751 Mtetra
.54042 .24751 .54674 .25529 .5586 .25103 .55231 .24322 Mtetra
.657 .752 .92 r
.55231 .24322 .5586 .25103 .57051 .24676 .56426 .23892 Mtetra
.56426 .23892 .57051 .24676 .58247 .24247 .57625 .23459 Mtetra
.57625 .23459 .58247 .24247 .59449 .23816 .5883 .23025 Mtetra
.5883 .23025 .59449 .23816 .60655 .23384 .6004 .22589 Mtetra
.6004 .22589 .60655 .23384 .61867 .22949 .61255 .22151 Mtetra
.61255 .22151 .61867 .22949 .63083 .22513 .62475 .21712 Mtetra
.62475 .21712 .63083 .22513 .64306 .22076 .63701 .2127 Mtetra
.63701 .2127 .64306 .22076 .65533 .21636 .64932 .20827 Mtetra
.64932 .20827 .65533 .21636 .66766 .21194 .66169 .20382 Mtetra
.66169 .20382 .66766 .21194 .68004 .20751 .67411 .19935 Mtetra
.67411 .19935 .68004 .20751 .69248 .20306 .68658 .19486 Mtetra
.68658 .19486 .69248 .20306 .70497 .19858 .69911 .19035 Mtetra
.69911 .19035 .70497 .19858 .71751 .19409 .7117 .18582 Mtetra
.7117 .18582 .71751 .19409 .73012 .18958 .72434 .18127 Mtetra
.72434 .18127 .73012 .18958 .74277 .18505 .73703 .17671 Mtetra
.652 .919 .623 r
.06479 .41483 .07443 .40649 .08325 .41109 .07592 .40313 Mtetra
.559 .679 .919 r
.07592 .40313 .08325 .41109 .09306 .40899 .08565 .40166 Mtetra
.58 .707 .929 r
.08565 .40166 .09306 .40899 .10265 .40885 .0955 .39971 Mtetra
.889 .716 .66 r
.0955 .39971 .10265 .40885 .11364 .39827 .10933 .36757 Mtetra
0 0 .446 r
.10933 .36757 .11364 .39827 .12344 .39718 .11612 .38967 Mtetra
.595 .708 .923 r
.11612 .38967 .12344 .39718 .13346 .39479 .12613 .38741 Mtetra
.582 .709 .93 r
.12613 .38741 .13346 .39479 .14317 .39527 .13616 .38538 Mtetra
.846 .714 .718 r
.13616 .38538 .14317 .39527 .15431 .38406 .1482 .36675 Mtetra
.147 .246 .71 r
.1482 .36675 .15431 .38406 .16435 .38252 .15709 .375 Mtetra
.605 .714 .922 r
.15709 .375 .16435 .38252 .17457 .37982 .16731 .37249 Mtetra
.608 .722 .926 r
.16731 .37249 .17457 .37982 .18474 .37796 .17758 .36988 Mtetra
.178 .487 .901 r
.17758 .36988 .18474 .37796 .19607 .36543 .18727 .37326 Mtetra
.748 .951 .638 r
.18727 .37326 .19607 .36543 .20597 .3671 .19884 .35911 Mtetra
.588 .697 .918 r
.19884 .35911 .20597 .3671 .21637 .3643 .20919 .35695 Mtetra
.625 .73 .922 r
.20919 .35695 .21637 .3643 .22684 .36128 .21968 .35391 Mtetra
.618 .728 .925 r
.21968 .35391 .22684 .36128 .23728 .35904 .2302 .35102 Mtetra
.382 .605 .936 r
.2302 .35102 .23728 .35904 .24889 .34403 .24041 .35218 Mtetra
.602 .878 .557 r
.24041 .35218 .24889 .34403 .25888 .34798 .25187 .33972 Mtetra
.585 .691 .915 r
.25187 .33972 .25888 .34798 .26952 .34502 .26246 .33758 Mtetra
.632 .734 .921 r
.26246 .33758 .26952 .34502 .28024 .34164 .27319 .3343 Mtetra
.64 .74 .921 r
.27319 .3343 .28024 .34164 .29101 .33818 .28399 .33082 Mtetra
.638 .74 .922 r
.28399 .33082 .29101 .33818 .30182 .33489 .29483 .32737 Mtetra
.62 .729 .925 r
.29483 .32737 .30182 .33489 .31258 .33292 .30569 .32434 Mtetra
0 .108 .639 r
.30569 .32434 .31258 .33292 .32403 .32119 .31578 .33358 Mtetra
.709 .86 .443 r
.31578 .33358 .32403 .32119 .33477 .32091 .3279 .31284 Mtetra
.61 .711 .917 r
.3279 .31284 .33477 .32091 .34576 .31756 .33887 .31004 Mtetra
.642 .74 .92 r
.33887 .31004 .34576 .31756 .35682 .31383 .34995 .3064 Mtetra
.65 .747 .92 r
.34995 .3064 .35682 .31383 .36793 .30995 .36109 .30255 Mtetra
.654 .75 .92 r
.36109 .30255 .36793 .30995 .37909 .30598 .37228 .29858 Mtetra
.656 .752 .92 r
.37228 .29858 .37909 .30598 .3903 .30195 .38352 .29453 Mtetra
.658 .753 .92 r
.38352 .29453 .3903 .30195 .40156 .29786 .39481 .29043 Mtetra
.659 .753 .92 r
.39481 .29043 .40156 .29786 .41287 .29374 .40614 .28629 Mtetra
.659 .754 .92 r
.40614 .28629 .41287 .29374 .42422 .2896 .41753 .28212 Mtetra
.41753 .28212 .42422 .2896 .43562 .28545 .42896 .27793 Mtetra
.42896 .27793 .43562 .28545 .44707 .28128 .44044 .27373 Mtetra
.659 .753 .92 r
.44044 .27373 .44707 .28128 .45857 .27711 .45197 .26952 Mtetra
.658 .753 .92 r
.45197 .26952 .45857 .27711 .47012 .27292 .46355 .2653 Mtetra
.46355 .2653 .47012 .27292 .48171 .26873 .47517 .26106 Mtetra
.47517 .26106 .48171 .26873 .49335 .26451 .48685 .25682 Mtetra
.48685 .25682 .49335 .26451 .50504 .26029 .49857 .25256 Mtetra
.49857 .25256 .50504 .26029 .51679 .25605 .51034 .24828 Mtetra
.51034 .24828 .51679 .25605 .52858 .25179 .52217 .24399 Mtetra
.657 .753 .92 r
.52217 .24399 .52858 .25179 .54042 .24751 .53405 .23968 Mtetra
.53405 .23968 .54042 .24751 .55231 .24322 .54597 .23535 Mtetra
.54597 .23535 .55231 .24322 .56426 .23892 .55795 .23101 Mtetra
.657 .752 .92 r
.55795 .23101 .56426 .23892 .57625 .23459 .56998 .22665 Mtetra
.56998 .22665 .57625 .23459 .5883 .23025 .58206 .22227 Mtetra
.58206 .22227 .5883 .23025 .6004 .22589 .5942 .21788 Mtetra
.5942 .21788 .6004 .22589 .61255 .22151 .60638 .21346 Mtetra
.60638 .21346 .61255 .22151 .62475 .21712 .61863 .20903 Mtetra
.61863 .20903 .62475 .21712 .63701 .2127 .63092 .20458 Mtetra
.63092 .20458 .63701 .2127 .64932 .20827 .64327 .20011 Mtetra
.64327 .20011 .64932 .20827 .66169 .20382 .65567 .19563 Mtetra
.65567 .19563 .66169 .20382 .67411 .19935 .66813 .19112 Mtetra
.66813 .19112 .67411 .19935 .68658 .19486 .68064 .18659 Mtetra
.68064 .18659 .68658 .19486 .69911 .19035 .69321 .18205 Mtetra
.69321 .18205 .69911 .19035 .7117 .18582 .70583 .17748 Mtetra
.70583 .17748 .7117 .18582 .72434 .18127 .71851 .1729 Mtetra
.71851 .1729 .72434 .18127 .73703 .17671 .73125 .16829 Mtetra
.811 .695 .737 r
.05776 .4042 .06479 .41483 .07592 .40313 .06933 .38963 Mtetra
.261 .384 .8 r
.06933 .38963 .07592 .40313 .08565 .40166 .07821 .3942 Mtetra
.59 .708 .925 r
.07821 .3942 .08565 .40166 .0955 .39971 .0881 .39204 Mtetra
.473 .656 .94 r
.0881 .39204 .0955 .39971 .10933 .36757 .09777 .39185 Mtetra
.151 0 .132 r
.09777 .39185 .10933 .36757 .11612 .38967 .10886 .38117 Mtetra
.542 .66 .913 r
.10886 .38117 .11612 .38967 .12613 .38741 .11874 .38002 Mtetra
.602 .717 .925 r
.11874 .38002 .12613 .38741 .13616 .38538 .12884 .37757 Mtetra
.43 .633 .94 r
.12884 .37757 .13616 .38538 .1482 .36675 .13863 .37799 Mtetra
0 0 0 r
.13863 .37799 .1482 .36675 .15709 .375 .14987 .36669 Mtetra
.563 .676 .915 r
.14987 .36669 .15709 .375 .16731 .37249 .16 .36508 Mtetra
.614 .723 .924 r
.16 .36508 .16731 .37249 .17758 .36988 .1703 .36232 Mtetra
.573 .705 .931 r
.1703 .36232 .17758 .36988 .18727 .37326 .18056 .3604 Mtetra
.778 .666 .74 r
.18056 .3604 .18727 .37326 .19884 .35911 .192 .34776 Mtetra
.417 .528 .862 r
.192 .34776 .19884 .35911 .20919 .35695 .20198 .34938 Mtetra
.617 .722 .921 r
.20198 .34938 .20919 .35695 .21968 .35391 .21247 .34651 Mtetra
.625 .731 .923 r
.21247 .34651 .21968 .35391 .2302 .35102 .22303 .34342 Mtetra
.59 .713 .929 r
.22303 .34342 .2302 .35102 .24041 .35218 .23357 .34111 Mtetra
.819 .704 .738 r
.23357 .34111 .24041 .35218 .25187 .33972 .2453 .32599 Mtetra
.331 .429 .811 r
.2453 .32599 .25187 .33972 .26246 .33758 .25536 .32989 Mtetra
.621 .724 .92 r
.25536 .32989 .26246 .33758 .27319 .3343 .2661 .32686 Mtetra
.638 .738 .921 r
.2661 .32686 .27319 .3343 .28399 .33082 .27691 .32341 Mtetra
.64 .74 .922 r
.27691 .32341 .28399 .33082 .29483 .32737 .28778 .31988 Mtetra
.633 .737 .923 r
.28778 .31988 .29483 .32737 .30569 .32434 .29869 .31651 Mtetra
.573 .705 .931 r
.29869 .31651 .30569 .32434 .31578 .33358 .30955 .31447 Mtetra
.724 .589 .704 r
.30955 .31447 .31578 .33358 .3279 .31284 .32111 .30263 Mtetra
.507 .609 .889 r
.32111 .30263 .3279 .31284 .33887 .31004 .33195 .30229 Mtetra
.633 .732 .92 r
.33195 .30229 .33887 .31004 .34995 .3064 .34304 .29887 Mtetra
.647 .744 .92 r
.34304 .29887 .34995 .3064 .36109 .30255 .3542 .29506 Mtetra
.652 .749 .92 r
.3542 .29506 .36109 .30255 .37228 .29858 .36541 .2911 Mtetra
.655 .751 .92 r
.36541 .2911 .37228 .29858 .38352 .29453 .37668 .28705 Mtetra
.657 .752 .92 r
.37668 .28705 .38352 .29453 .39481 .29043 .388 .28294 Mtetra
.658 .753 .92 r
.388 .28294 .39481 .29043 .40614 .28629 .39936 .27877 Mtetra
.659 .754 .92 r
.39936 .27877 .40614 .28629 .41753 .28212 .41078 .27457 Mtetra
.41078 .27457 .41753 .28212 .42896 .27793 .42224 .27035 Mtetra
.42224 .27035 .42896 .27793 .44044 .27373 .43375 .26612 Mtetra
.43375 .26612 .44044 .27373 .45197 .26952 .44531 .26187 Mtetra
.658 .753 .92 r
.44531 .26187 .45197 .26952 .46355 .2653 .45692 .25761 Mtetra
.45692 .25761 .46355 .2653 .47517 .26106 .46858 .25334 Mtetra
.46858 .25334 .47517 .26106 .48685 .25682 .48029 .24906 Mtetra
.48029 .24906 .48685 .25682 .49857 .25256 .49205 .24476 Mtetra
.49205 .24476 .49857 .25256 .51034 .24828 .50385 .24045 Mtetra
.50385 .24045 .51034 .24828 .52217 .24399 .51571 .23612 Mtetra
.51571 .23612 .52217 .24399 .53405 .23968 .52762 .23178 Mtetra
.657 .753 .92 r
.52762 .23178 .53405 .23968 .54597 .23535 .53958 .22742 Mtetra
.53958 .22742 .54597 .23535 .55795 .23101 .55159 .22304 Mtetra
.657 .752 .92 r
.55159 .22304 .55795 .23101 .56998 .22665 .56366 .21865 Mtetra
.56366 .21865 .56998 .22665 .58206 .22227 .57578 .21423 Mtetra
.57578 .21423 .58206 .22227 .5942 .21788 .58795 .2098 Mtetra
.58795 .2098 .5942 .21788 .60638 .21346 .60017 .20535 Mtetra
.60017 .20535 .60638 .21346 .61863 .20903 .61245 .20088 Mtetra
.61245 .20088 .61863 .20903 .63092 .20458 .62478 .1964 Mtetra
.62478 .1964 .63092 .20458 .64327 .20011 .63716 .19189 Mtetra
.63716 .19189 .64327 .20011 .65567 .19563 .6496 .18737 Mtetra
.6496 .18737 .65567 .19563 .66813 .19112 .6621 .18282 Mtetra
.6621 .18282 .66813 .19112 .68064 .18659 .67465 .17826 Mtetra
.67465 .17826 .68064 .18659 .69321 .18205 .68725 .17368 Mtetra
.68725 .17368 .69321 .18205 .70583 .17748 .69992 .16907 Mtetra
.69992 .16907 .70583 .17748 .71851 .1729 .71263 .16445 Mtetra
.71263 .16445 .71851 .1729 .73125 .16829 .72541 .15981 Mtetra
.328 .58 .934 r
.05028 .39634 .05776 .4042 .06933 .38963 .05956 .39792 Mtetra
.663 .926 .633 r
.05956 .39792 .06933 .38963 .07821 .3942 .0708 .38611 Mtetra
.559 .679 .919 r
.0708 .38611 .07821 .3942 .0881 .39204 .08061 .38458 Mtetra
.58 .707 .929 r
.08061 .38458 .0881 .39204 .09777 .39185 .09053 .38257 Mtetra
.89 .716 .66 r
.09053 .38257 .09777 .39185 .10886 .38117 .10452 .35025 Mtetra
0 0 .442 r
.10452 .35025 .10886 .38117 .11874 .38002 .11133 .37238 Mtetra
.595 .708 .923 r
.11133 .37238 .11874 .38002 .12884 .37757 .12142 .37006 Mtetra
.582 .709 .93 r
.12142 .37006 .12884 .37757 .13863 .37799 .13153 .36797 Mtetra
.847 .715 .717 r
.13153 .36797 .13863 .37799 .14987 .36669 .1437 .34921 Mtetra
.143 .243 .709 r
.1437 .34921 .14987 .36669 .16 .36508 .15265 .35744 Mtetra
.605 .714 .922 r
.15265 .35744 .16 .36508 .1703 .36232 .16296 .35485 Mtetra
.608 .722 .926 r
.16296 .35485 .1703 .36232 .18056 .3604 .17332 .35218 Mtetra
.181 .488 .901 r
.17332 .35218 .18056 .3604 .192 .34776 .18308 .35551 Mtetra
.755 .955 .645 r
.18308 .35551 .192 .34776 .20198 .34938 .19477 .34125 Mtetra
.588 .697 .918 r
.19477 .34125 .20198 .34938 .21247 .34651 .20521 .33902 Mtetra
.625 .73 .922 r
.20521 .33902 .21247 .34651 .22303 .34342 .21579 .33591 Mtetra
.618 .728 .925 r
.21579 .33591 .22303 .34342 .23357 .34111 .22641 .33295 Mtetra
.383 .605 .936 r
.22641 .33295 .23357 .34111 .2453 .32599 .2367 .33406 Mtetra
.614 .887 .569 r
.2367 .33406 .2453 .32599 .25536 .32989 .24827 .32149 Mtetra
.585 .691 .915 r
.24827 .32149 .25536 .32989 .2661 .32686 .25896 .31929 Mtetra
.632 .734 .921 r
.25896 .31929 .2661 .32686 .27691 .32341 .26979 .31593 Mtetra
.64 .74 .921 r
.26979 .31593 .27691 .32341 .28778 .31988 .28068 .31237 Mtetra
.638 .74 .922 r
.28068 .31237 .28778 .31988 .29869 .31651 .29162 .30884 Mtetra
.62 .729 .925 r
.29162 .30884 .29869 .31651 .30955 .31447 .30257 .30575 Mtetra
0 .114 .644 r
.30257 .30575 .30955 .31447 .32111 .30263 .31275 .31495 Mtetra
.717 .866 .452 r
.31275 .31495 .32111 .30263 .33195 .30229 .32499 .29407 Mtetra
.61 .711 .917 r
.32499 .29407 .33195 .30229 .34304 .29887 .33607 .2912 Mtetra
.642 .74 .92 r
.33607 .2912 .34304 .29887 .3542 .29506 .34725 .28749 Mtetra
.65 .747 .92 r
.34725 .28749 .3542 .29506 .36541 .2911 .35849 .28355 Mtetra
.654 .75 .92 r
.35849 .28355 .36541 .2911 .37668 .28705 .36979 .2795 Mtetra
.656 .752 .92 r
.36979 .2795 .37668 .28705 .388 .28294 .38114 .27538 Mtetra
.658 .753 .92 r
.38114 .27538 .388 .28294 .39936 .27877 .39253 .27119 Mtetra
.659 .753 .92 r
.39253 .27119 .39936 .27877 .41078 .27457 .40398 .26697 Mtetra
.659 .754 .92 r
.40398 .26697 .41078 .27457 .42224 .27035 .41547 .26271 Mtetra
.41547 .26271 .42224 .27035 .43375 .26612 .42702 .25844 Mtetra
.42702 .25844 .43375 .26612 .44531 .26187 .43861 .25416 Mtetra
.659 .753 .92 r
.43861 .25416 .44531 .26187 .45692 .25761 .45025 .24987 Mtetra
.658 .753 .92 r
.45025 .24987 .45692 .25761 .46858 .25334 .46194 .24556 Mtetra
.46194 .24556 .46858 .25334 .48029 .24906 .47368 .24124 Mtetra
.47368 .24124 .48029 .24906 .49205 .24476 .48547 .23691 Mtetra
.48547 .23691 .49205 .24476 .50385 .24045 .49731 .23256 Mtetra
.49731 .23256 .50385 .24045 .51571 .23612 .5092 .2282 Mtetra
.5092 .2282 .51571 .23612 .52762 .23178 .52114 .22382 Mtetra
.657 .753 .92 r
.52114 .22382 .52762 .23178 .53958 .22742 .53314 .21942 Mtetra
.53314 .21942 .53958 .22742 .55159 .22304 .54519 .21501 Mtetra
.54519 .21501 .55159 .22304 .56366 .21865 .55729 .21058 Mtetra
.657 .752 .92 r
.55729 .21058 .56366 .21865 .57578 .21423 .56944 .20613 Mtetra
.56944 .20613 .57578 .21423 .58795 .2098 .58164 .20166 Mtetra
.58164 .20166 .58795 .2098 .60017 .20535 .5939 .19717 Mtetra
.5939 .19717 .60017 .20535 .61245 .20088 .60622 .19267 Mtetra
.60622 .19267 .61245 .20088 .62478 .1964 .61858 .18814 Mtetra
.61858 .18814 .62478 .1964 .63716 .19189 .63101 .1836 Mtetra
.63101 .1836 .63716 .19189 .6496 .18737 .64348 .17904 Mtetra
.64348 .17904 .6496 .18737 .6621 .18282 .65602 .17446 Mtetra
.65602 .17446 .6621 .18282 .67465 .17826 .66861 .16986 Mtetra
.66861 .16986 .67465 .17826 .68725 .17368 .68125 .16524 Mtetra
.68125 .16524 .68725 .17368 .69992 .16907 .69395 .16059 Mtetra
.69395 .16059 .69992 .16907 .71263 .16445 .70671 .15593 Mtetra
.70671 .15593 .71263 .16445 .72541 .15981 .71952 .15125 Mtetra
.562 .698 .932 r
.04269 .38882 .05028 .39634 .05956 .39792 .05245 .38714 Mtetra
.811 .696 .738 r
.05245 .38714 .05956 .39792 .0708 .38611 .06413 .37246 Mtetra
.259 .383 .799 r
.06413 .37246 .0708 .38611 .08061 .38458 .07307 .377 Mtetra
.59 .708 .925 r
.07307 .377 .08061 .38458 .09053 .38257 .08304 .37477 Mtetra
.474 .656 .94 r
.08304 .37477 .09053 .38257 .10452 .35025 .09279 .37453 Mtetra
.138 0 .118 r
.09279 .37453 .10452 .35025 .11133 .37238 .10399 .36375 Mtetra
.542 .66 .913 r
.10399 .36375 .11133 .37238 .12142 .37006 .11395 .36254 Mtetra
.602 .717 .925 r
.11395 .36254 .12142 .37006 .13153 .36797 .12413 .36002 Mtetra
.431 .633 .94 r
.12413 .36002 .13153 .36797 .1437 .34921 .134 .36039 Mtetra
0 0 0 r
.134 .36039 .1437 .34921 .15265 .35744 .14535 .34898 Mtetra
.563 .676 .915 r
.14535 .34898 .15265 .35744 .16296 .35485 .15556 .34731 Mtetra
.614 .723 .924 r
.15556 .34731 .16296 .35485 .17332 .35218 .16595 .34449 Mtetra
.573 .705 .931 r
.16595 .34449 .17332 .35218 .18308 .35551 .1763 .34249 Mtetra
.779 .667 .74 r
.1763 .34249 .18308 .35551 .19477 .34125 .18786 .32975 Mtetra
.416 .527 .863 r
.18786 .32975 .19477 .34125 .20521 .33902 .19791 .33132 Mtetra
.617 .722 .921 r
.19791 .33132 .20521 .33902 .21579 .33591 .2085 .32838 Mtetra
.625 .731 .923 r
.2085 .32838 .21579 .33591 .22641 .33295 .21915 .32522 Mtetra
.59 .713 .929 r
.21915 .32522 .22641 .33295 .2367 .33406 .22978 .32283 Mtetra
.82 .705 .739 r
.22978 .32283 .2367 .33406 .24827 .32149 .24163 .30759 Mtetra
.329 .428 .811 r
.24163 .30759 .24827 .32149 .25896 .31929 .25178 .31145 Mtetra
.621 .724 .92 r
.25178 .31145 .25896 .31929 .26979 .31593 .26261 .30835 Mtetra
.638 .738 .921 r
.26261 .30835 .26979 .31593 .28068 .31237 .27352 .30482 Mtetra
.64 .74 .922 r
.27352 .30482 .28068 .31237 .29162 .30884 .28449 .30121 Mtetra
.633 .737 .923 r
.28449 .30121 .29162 .30884 .30257 .30575 .29549 .29777 Mtetra
.573 .705 .931 r
.29549 .29777 .30257 .30575 .31275 .31495 .30645 .29566 Mtetra
.724 .589 .704 r
.30645 .29566 .31275 .31495 .32499 .29407 .31813 .28371 Mtetra
.507 .609 .889 r
.31813 .28371 .32499 .29407 .33607 .2912 .32907 .28331 Mtetra
.633 .732 .92 r
.32907 .28331 .33607 .2912 .34725 .28749 .34026 .2798 Mtetra
.647 .744 .92 r
.34026 .2798 .34725 .28749 .35849 .28355 .35152 .27592 Mtetra
.652 .749 .92 r
.35152 .27592 .35849 .28355 .36979 .2795 .36285 .27188 Mtetra
.655 .751 .92 r
.36285 .27188 .36979 .2795 .38114 .27538 .37422 .26775 Mtetra
.657 .752 .92 r
.37422 .26775 .38114 .27538 .39253 .27119 .38565 .26355 Mtetra
.658 .753 .92 r
.38565 .26355 .39253 .27119 .40398 .26697 .39712 .2593 Mtetra
.659 .754 .92 r
.39712 .2593 .40398 .26697 .41547 .26271 .40865 .25502 Mtetra
.40865 .25502 .41547 .26271 .42702 .25844 .42022 .25071 Mtetra
.42022 .25071 .42702 .25844 .43861 .25416 .43185 .24639 Mtetra
.43185 .24639 .43861 .25416 .45025 .24987 .44352 .24206 Mtetra
.658 .753 .92 r
.44352 .24206 .45025 .24987 .46194 .24556 .45524 .23772 Mtetra
.45524 .23772 .46194 .24556 .47368 .24124 .46701 .23336 Mtetra
.46701 .23336 .47368 .24124 .48547 .23691 .47884 .22899 Mtetra
.47884 .22899 .48547 .23691 .49731 .23256 .49071 .22461 Mtetra
.49071 .22461 .49731 .23256 .5092 .2282 .50264 .22021 Mtetra
.50264 .22021 .5092 .2282 .52114 .22382 .51461 .21579 Mtetra
.51461 .21579 .52114 .22382 .53314 .21942 .52664 .21136 Mtetra
.657 .753 .92 r
.52664 .21136 .53314 .21942 .54519 .21501 .53873 .20691 Mtetra
.53873 .20691 .54519 .21501 .55729 .21058 .55086 .20244 Mtetra
.657 .752 .92 r
.55086 .20244 .55729 .21058 .56944 .20613 .56305 .19796 Mtetra
.56305 .19796 .56944 .20613 .58164 .20166 .57529 .19345 Mtetra
.57529 .19345 .58164 .20166 .5939 .19717 .58759 .18893 Mtetra
.58759 .18893 .5939 .19717 .60622 .19267 .59994 .18439 Mtetra
.59994 .18439 .60622 .19267 .61858 .18814 .61234 .17982 Mtetra
.61234 .17982 .61858 .18814 .63101 .1836 .6248 .17524 Mtetra
.6248 .17524 .63101 .1836 .64348 .17904 .63732 .17064 Mtetra
.63732 .17064 .64348 .17904 .65602 .17446 .64989 .16602 Mtetra
.64989 .16602 .65602 .17446 .66861 .16986 .66251 .16139 Mtetra
.66251 .16139 .66861 .16986 .68125 .16524 .6752 .15673 Mtetra
.6752 .15673 .68125 .16524 .69395 .16059 .68794 .15205 Mtetra
.68794 .15205 .69395 .16059 .70671 .15593 .70074 .14735 Mtetra
.70074 .14735 .70671 .15593 .71952 .15125 .71359 .14262 Mtetra
.579 .701 .926 r
.03506 .38115 .04269 .38882 .05245 .38714 .04488 .37916 Mtetra
.33 .581 .934 r
.04488 .37916 .05245 .38714 .06413 .37246 .05422 .38068 Mtetra
.673 .933 .643 r
.05422 .38068 .06413 .37246 .07307 .377 .06557 .36877 Mtetra
.559 .679 .919 r
.06557 .36877 .07307 .377 .08304 .37477 .07546 .36718 Mtetra
.58 .707 .929 r
.07546 .36718 .08304 .37477 .09279 .37453 .08547 .36511 Mtetra
.891 .717 .659 r
.08547 .36511 .09279 .37453 .10399 .36375 .09963 .3326 Mtetra
0 0 .437 r
.09963 .3326 .10399 .36375 .11395 .36254 .10645 .35476 Mtetra
.595 .708 .923 r
.10645 .35476 .11395 .36254 .12413 .36002 .11662 .35238 Mtetra
.582 .709 .93 r
.11662 .35238 .12413 .36002 .134 .36039 .12682 .35022 Mtetra
.848 .716 .717 r
.12682 .35022 .134 .36039 .14535 .34898 .13912 .33133 Mtetra
.14 .241 .708 r
.13912 .33133 .14535 .34898 .15556 .34731 .14813 .33953 Mtetra
.605 .714 .922 r
.14813 .33953 .15556 .34731 .16595 .34449 .15852 .33688 Mtetra
.608 .722 .926 r
.15852 .33688 .16595 .34449 .1763 .34249 .16897 .33414 Mtetra
.184 .489 .901 r
.16897 .33414 .1763 .34249 .18786 .32975 .17881 .33742 Mtetra
.762 .959 .653 r
.17881 .33742 .18786 .32975 .19791 .33132 .19061 .32305 Mtetra
.588 .697 .918 r
.19061 .32305 .19791 .33132 .2085 .32838 .20115 .32075 Mtetra
.625 .73 .922 r
.20115 .32075 .2085 .32838 .21915 .32522 .21183 .31756 Mtetra
.618 .728 .925 r
.21183 .31756 .21915 .32522 .22978 .32283 .22254 .31453 Mtetra
.384 .605 .936 r
.22254 .31453 .22978 .32283 .24163 .30759 .23292 .31558 Mtetra
.625 .895 .58 r
.23292 .31558 .24163 .30759 .25178 .31145 .24461 .3029 Mtetra
.585 .691 .915 r
.24461 .3029 .25178 .31145 .26261 .30835 .25538 .30063 Mtetra
.632 .734 .921 r
.25538 .30063 .26261 .30835 .27352 .30482 .26631 .29719 Mtetra
.64 .74 .921 r
.26631 .29719 .27352 .30482 .28449 .30121 .2773 .29356 Mtetra
.638 .74 .922 r
.2773 .29356 .28449 .30121 .29549 .29777 .28834 .28996 Mtetra
.62 .729 .925 r
.28834 .28996 .29549 .29777 .30645 .29566 .2994 .28678 Mtetra
0 .12 .65 r
.2994 .28678 .30645 .29566 .31813 .28371 .30966 .29596 Mtetra
.725 .872 .461 r
.30966 .29596 .31813 .28371 .32907 .28331 .32203 .27493 Mtetra
.61 .711 .917 r
.32203 .27493 .32907 .28331 .34026 .2798 .33321 .27198 Mtetra
.642 .74 .92 r
.33321 .27198 .34026 .2798 .35152 .27592 .3445 .26819 Mtetra
.65 .747 .92 r
.3445 .26819 .35152 .27592 .36285 .27188 .35585 .26418 Mtetra
.654 .75 .92 r
.35585 .26418 .36285 .27188 .37422 .26775 .36725 .26004 Mtetra
.656 .752 .92 r
.36725 .26004 .37422 .26775 .38565 .26355 .37871 .25584 Mtetra
.658 .753 .92 r
.37871 .25584 .38565 .26355 .39712 .2593 .39021 .25157 Mtetra
.659 .753 .92 r
.39021 .25157 .39712 .2593 .40865 .25502 .40177 .24726 Mtetra
.659 .754 .92 r
.40177 .24726 .40865 .25502 .42022 .25071 .41338 .24292 Mtetra
.41338 .24292 .42022 .25071 .43185 .24639 .42503 .23856 Mtetra
.42503 .23856 .43185 .24639 .44352 .24206 .43674 .23419 Mtetra
.659 .753 .92 r
.43674 .23419 .44352 .24206 .45524 .23772 .44849 .22981 Mtetra
.658 .753 .92 r
.44849 .22981 .45524 .23772 .46701 .23336 .4603 .22542 Mtetra
.4603 .22542 .46701 .23336 .47884 .22899 .47215 .22101 Mtetra
.47215 .22101 .47884 .22899 .49071 .22461 .48406 .21659 Mtetra
.48406 .21659 .49071 .22461 .50264 .22021 .49602 .21216 Mtetra
.49602 .21216 .50264 .22021 .51461 .21579 .50803 .2077 Mtetra
.50803 .2077 .51461 .21579 .52664 .21136 .5201 .20323 Mtetra
.657 .753 .92 r
.5201 .20323 .52664 .21136 .53873 .20691 .53221 .19875 Mtetra
.53221 .19875 .53873 .20691 .55086 .20244 .54438 .19424 Mtetra
.54438 .19424 .55086 .20244 .56305 .19796 .55661 .18972 Mtetra
.657 .752 .92 r
.55661 .18972 .56305 .19796 .57529 .19345 .56889 .18518 Mtetra
.56889 .18518 .57529 .19345 .58759 .18893 .58122 .18062 Mtetra
.58122 .18062 .58759 .18893 .59994 .18439 .5936 .17604 Mtetra
.5936 .17604 .59994 .18439 .61234 .17982 .60605 .17144 Mtetra
.60605 .17144 .61234 .17982 .6248 .17524 .61854 .16682 Mtetra
.61854 .16682 .6248 .17524 .63732 .17064 .6311 .16218 Mtetra
.6311 .16218 .63732 .17064 .64989 .16602 .6437 .15752 Mtetra
.6437 .15752 .64989 .16602 .66251 .16139 .65637 .15284 Mtetra
.65637 .15284 .66251 .16139 .6752 .15673 .66909 .14814 Mtetra
.66909 .14814 .6752 .15673 .68794 .15205 .68187 .14343 Mtetra
.68187 .14343 .68794 .15205 .70074 .14735 .69471 .13869 Mtetra
.69471 .13869 .70074 .14735 .71359 .14262 .70761 .13392 Mtetra
.537 .662 .917 r
.0275 .37265 .03506 .38115 .04488 .37916 .0372 .3715 Mtetra
.562 .698 .931 r
.0372 .3715 .04488 .37916 .05422 .38068 .04703 .36976 Mtetra
.812 .697 .738 r
.04703 .36976 .05422 .38068 .06557 .36877 .05884 .35497 Mtetra
.257 .382 .799 r
.05884 .35497 .06557 .36877 .07546 .36718 .06784 .35947 Mtetra
.59 .708 .925 r
.06784 .35947 .07546 .36718 .08547 .36511 .07789 .35717 Mtetra
.474 .656 .94 r
.07789 .35717 .08547 .36511 .09963 .3326 .08771 .35687 Mtetra
.124 0 .104 r
.08771 .35687 .09963 .3326 .10645 .35476 .09902 .346 Mtetra
.542 .66 .913 r
.09902 .346 .10645 .35476 .11662 .35238 .10906 .34472 Mtetra
.602 .717 .925 r
.10906 .34472 .11662 .35238 .12682 .35022 .11933 .34213 Mtetra
.431 .633 .94 r
.11933 .34213 .12682 .35022 .13912 .33133 .12928 .34245 Mtetra
0 0 0 r
.12928 .34245 .13912 .33133 .14813 .33953 .14074 .33094 Mtetra
.563 .676 .915 r
.14074 .33094 .14813 .33953 .15852 .33688 .15104 .3292 Mtetra
.614 .723 .924 r
.15104 .3292 .15852 .33688 .16897 .33414 .16152 .3263 Mtetra
.574 .705 .931 r
.16152 .3263 .16897 .33414 .17881 .33742 .17196 .32424 Mtetra
.779 .668 .74 r
.17196 .32424 .17881 .33742 .19061 .32305 .18363 .31139 Mtetra
.415 .527 .863 r
.18363 .31139 .19061 .32305 .20115 .32075 .19377 .3129 Mtetra
.617 .722 .921 r
.19377 .3129 .20115 .32075 .21183 .31756 .20444 .30989 Mtetra
.625 .731 .923 r
.20444 .30989 .21183 .31756 .22254 .31453 .21519 .30665 Mtetra
.59 .713 .929 r
.21519 .30665 .22254 .31453 .23292 .31558 .22592 .3042 Mtetra
.82 .706 .739 r
.22592 .3042 .23292 .31558 .24461 .3029 .23789 .28884 Mtetra
.328 .427 .811 r
.23789 .28884 .24461 .3029 .25538 .30063 .24812 .29264 Mtetra
.621 .724 .92 r
.24812 .29264 .25538 .30063 .26631 .29719 .25905 .28947 Mtetra
.638 .738 .921 r
.25905 .28947 .26631 .29719 .2773 .29356 .27006 .28586 Mtetra
.64 .74 .922 r
.27006 .28586 .2773 .29356 .28834 .28996 .28113 .28218 Mtetra
.633 .737 .923 r
.28113 .28218 .28834 .28996 .2994 .28678 .29224 .27865 Mtetra
.574 .705 .931 r
.29224 .27865 .2994 .28678 .30966 .29596 .3033 .27647 Mtetra
.724 .589 .704 r
.3033 .27647 .30966 .29596 .32203 .27493 .31509 .26441 Mtetra
.506 .609 .889 r
.31509 .26441 .32203 .27493 .33321 .27198 .32613 .26394 Mtetra
.633 .732 .92 r
.32613 .26394 .33321 .27198 .3445 .26819 .33743 .26036 Mtetra
.647 .744 .92 r
.33743 .26036 .3445 .26819 .35585 .26418 .3488 .25639 Mtetra
.652 .749 .92 r
.3488 .25639 .35585 .26418 .36725 .26004 .36023 .25227 Mtetra
.655 .751 .92 r
.36023 .25227 .36725 .26004 .37871 .25584 .37171 .24805 Mtetra
.657 .752 .92 r
.37171 .24805 .37871 .25584 .39021 .25157 .38325 .24377 Mtetra
.658 .753 .92 r
.38325 .24377 .39021 .25157 .40177 .24726 .39484 .23943 Mtetra
.659 .754 .92 r
.39484 .23943 .40177 .24726 .41338 .24292 .40647 .23506 Mtetra
.40647 .23506 .41338 .24292 .42503 .23856 .41816 .23067 Mtetra
.41816 .23067 .42503 .23856 .43674 .23419 .4299 .22626 Mtetra
.4299 .22626 .43674 .23419 .44849 .22981 .44169 .22184 Mtetra
.658 .753 .92 r
.44169 .22184 .44849 .22981 .4603 .22542 .45353 .21741 Mtetra
.45353 .21741 .4603 .22542 .47215 .22101 .46542 .21297 Mtetra
.46542 .21297 .47215 .22101 .48406 .21659 .47736 .20851 Mtetra
.47736 .20851 .48406 .21659 .49602 .21216 .48935 .20404 Mtetra
.48935 .20404 .49602 .21216 .50803 .2077 .5014 .19955 Mtetra
.5014 .19955 .50803 .2077 .5201 .20323 .5135 .19504 Mtetra
.5135 .19504 .5201 .20323 .53221 .19875 .52565 .19052 Mtetra
.657 .753 .92 r
.52565 .19052 .53221 .19875 .54438 .19424 .53785 .18597 Mtetra
.53785 .18597 .54438 .19424 .55661 .18972 .55011 .18141 Mtetra
.657 .752 .92 r
.55011 .18141 .55661 .18972 .56889 .18518 .56243 .17683 Mtetra
.56243 .17683 .56889 .18518 .58122 .18062 .5748 .17223 Mtetra
.5748 .17223 .58122 .18062 .5936 .17604 .58722 .16762 Mtetra
.58722 .16762 .5936 .17604 .60605 .17144 .5997 .16298 Mtetra
.5997 .16298 .60605 .17144 .61854 .16682 .61223 .15832 Mtetra
.61223 .15832 .61854 .16682 .6311 .16218 .62482 .15364 Mtetra
.62482 .15364 .6311 .16218 .6437 .15752 .63747 .14895 Mtetra
.63747 .14895 .6437 .15752 .65637 .15284 .65018 .14423 Mtetra
.65018 .14423 .65637 .15284 .66909 .14814 .66294 .13949 Mtetra
.66294 .13949 .66909 .14814 .68187 .14343 .67576 .13473 Mtetra
.67576 .13473 .68187 .14343 .69471 .13869 .68864 .12995 Mtetra
.68864 .12995 .69471 .13869 .70761 .13392 .70157 .12515 Mtetra
0 .034 .572 r
.02199 .35086 .0275 .37265 .0372 .3715 .02948 .3637 Mtetra
.579 .701 .926 r
.02948 .3637 .0372 .3715 .04703 .36976 .03937 .36164 Mtetra
.331 .581 .934 r
.03937 .36164 .04703 .36976 .05884 .35497 .04879 .36312 Mtetra
.682 .939 .653 r
.04879 .36312 .05884 .35497 .06784 .35947 .06025 .3511 Mtetra
.559 .679 .919 r
.06025 .3511 .06784 .35947 .07789 .35717 .07022 .34945 Mtetra
.58 .707 .929 r
.07022 .34945 .07789 .35717 .08771 .35687 .08031 .34731 Mtetra
.892 .718 .658 r
.08031 .34731 .08771 .35687 .09902 .346 .09464 .31462 Mtetra
0 0 .433 r
.09464 .31462 .09902 .346 .10906 .34472 .10147 .33681 Mtetra
.595 .708 .923 r
.10147 .33681 .10906 .34472 .11933 .34213 .11173 .33435 Mtetra
.582 .709 .929 r
.11173 .33435 .11933 .34213 .12928 .34245 .12202 .33213 Mtetra
.849 .717 .717 r
.12202 .33213 .12928 .34245 .14074 .33094 .13445 .3131 Mtetra
.136 .239 .707 r
.13445 .3131 .14074 .33094 .15104 .3292 .14352 .32128 Mtetra
.605 .714 .922 r
.14352 .32128 .15104 .3292 .16152 .3263 .154 .31855 Mtetra
.608 .722 .926 r
.154 .31855 .16152 .3263 .17196 .32424 .16454 .31574 Mtetra
.187 .491 .902 r
.16454 .31574 .17196 .32424 .18363 .31139 .17446 .31898 Mtetra
.769 .963 .66 r
.17446 .31898 .18363 .31139 .19377 .3129 .18638 .30448 Mtetra
.588 .697 .918 r
.18638 .30448 .19377 .3129 .20444 .30989 .19701 .30211 Mtetra
.625 .73 .922 r
.19701 .30211 .20444 .30989 .21519 .30665 .20778 .29886 Mtetra
.618 .728 .925 r
.20778 .29886 .21519 .30665 .22592 .3042 .21859 .29575 Mtetra
.385 .606 .936 r
.21859 .29575 .22592 .3042 .23789 .28884 .22906 .29674 Mtetra
.636 .903 .591 r
.22906 .29674 .23789 .28884 .24812 .29264 .24086 .28395 Mtetra
.585 .691 .915 r
.24086 .28395 .24812 .29264 .25905 .28947 .25174 .2816 Mtetra
.632 .734 .921 r
.25174 .2816 .25905 .28947 .27006 .28586 .26277 .27809 Mtetra
.64 .74 .921 r
.26277 .27809 .27006 .28586 .28113 .28218 .27386 .27438 Mtetra
.638 .74 .922 r
.27386 .27438 .28113 .28218 .29224 .27865 .285 .27069 Mtetra
.62 .729 .925 r
.285 .27069 .29224 .27865 .3033 .27647 .29616 .26744 Mtetra
0 .125 .655 r
.29616 .26744 .3033 .27647 .31509 .26441 .3065 .27658 Mtetra
.733 .878 .469 r
.3065 .27658 .31509 .26441 .32613 .26394 .31901 .25541 Mtetra
.61 .711 .917 r
.31901 .25541 .32613 .26394 .33743 .26036 .3303 .25238 Mtetra
.642 .74 .92 r
.3303 .25238 .33743 .26036 .3488 .25639 .34169 .24851 Mtetra
.65 .747 .92 r
.34169 .24851 .3488 .25639 .36023 .25227 .35315 .24441 Mtetra
.654 .75 .92 r
.35315 .24441 .36023 .25227 .37171 .24805 .36466 .24019 Mtetra
.656 .752 .92 r
.36466 .24019 .37171 .24805 .38325 .24377 .37623 .2359 Mtetra
.658 .753 .92 r
.37623 .2359 .38325 .24377 .39484 .23943 .38785 .23154 Mtetra
.659 .753 .92 r
.38785 .23154 .39484 .23943 .40647 .23506 .39952 .22714 Mtetra
.659 .754 .92 r
.39952 .22714 .40647 .23506 .41816 .23067 .41124 .22272 Mtetra
.41124 .22272 .41816 .23067 .4299 .22626 .42301 .21827 Mtetra
.42301 .21827 .4299 .22626 .44169 .22184 .43483 .21381 Mtetra
.659 .753 .92 r
.43483 .21381 .44169 .22184 .45353 .21741 .4467 .20934 Mtetra
.658 .753 .92 r
.4467 .20934 .45353 .21741 .46542 .21297 .45862 .20486 Mtetra
.45862 .20486 .46542 .21297 .47736 .20851 .4706 .20036 Mtetra
.4706 .20036 .47736 .20851 .48935 .20404 .48263 .19585 Mtetra
.48263 .19585 .48935 .20404 .5014 .19955 .49471 .19133 Mtetra
.49471 .19133 .5014 .19955 .5135 .19504 .50684 .18678 Mtetra
.50684 .18678 .5135 .19504 .52565 .19052 .51903 .18222 Mtetra
.657 .753 .92 r
.51903 .18222 .52565 .19052 .53785 .18597 .53127 .17764 Mtetra
.53127 .17764 .53785 .18597 .55011 .18141 .54356 .17304 Mtetra
.54356 .17304 .55011 .18141 .56243 .17683 .55592 .16842 Mtetra
.657 .752 .92 r
.55592 .16842 .56243 .17683 .5748 .17223 .56832 .16378 Mtetra
.56832 .16378 .5748 .17223 .58722 .16762 .58078 .15913 Mtetra
.58078 .15913 .58722 .16762 .5997 .16298 .5933 .15445 Mtetra
.5933 .15445 .5997 .16298 .61223 .15832 .60587 .14975 Mtetra
.60587 .14975 .61223 .15832 .62482 .15364 .6185 .14504 Mtetra
.6185 .14504 .62482 .15364 .63747 .14895 .63119 .1403 Mtetra
.63119 .1403 .63747 .14895 .65018 .14423 .64393 .13554 Mtetra
.64393 .13554 .65018 .14423 .66294 .13949 .65673 .13077 Mtetra
.65673 .13077 .66294 .13949 .67576 .13473 .66959 .12597 Mtetra
.66959 .12597 .67576 .13473 .68864 .12995 .68251 .12115 Mtetra
.68251 .12115 .68864 .12995 .70157 .12515 .69549 .1163 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05Yoo`0JD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoAMo
o`03001oogoo04Moo`00Qgoo0`00HGoo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
2E;mD_aBo5;lD_eBo000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069oo`0PD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoAIoo`03
001oogoo04Ioo`00PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eoo`00P7oo0P00Hgoo
02EBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d0
0e;l00=BoE;lOol05Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1MOol0;5;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;l00000e;l00EBoE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00HGoo03ABo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo049oo`00Lgoo0`00HGoo
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00ABoE;lD_aBo1Moo`03001oogoo
045oo`00LGoo0P00HWoo03UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aB
oE;lD_eBo5;mD_`05Goo00<007oo0000@Woo001^Ool3001POol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001oogoo041oo`00
Jgoo0`00HGoo045Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001B
o5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo03moo`00JGoo0P000goo00<007ooOol0Fgoo
00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m
00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`0oOol006Ioo`<005moo`19D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d05Woo00<007ooOol0?Woo001TOol2001POol00e;lD_eBo002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=B
o005D_eBo5;lD_aBo@02D_`FOol00`00Oomoo`0mOol0065oo`<0061oo`1?D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d05Goo00<007ooOol09Goo0`005Goo000eOol4000VOol2001O
Ool00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0E
Ool00`00Oomoo`0VOol00`00Oomoo`0COol003Aoo`03001oogoo009oo`03001oogoo021oo`<0061o
o`1ED_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<0
07ooOol09Goo00<007ooOol04goo000iOol00`00Oomoo`0NOol20002Ool00`00Oomoo`1LOol2D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l5Goo00<0
07ooOol097oo00<007oo000057oo000/Ool60007Ool00`00Oomoo`0KOol3001OOol0G5;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dFOol0
0`00Oomoo`0SOol00`00Ool0000DOol003Eoo`@001aoo`80061oo`9Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Ioo`03001o
ogoo025oo`05001oogooOol0000COol003Eoo`03001oogoo01Yoo`<0061oo`1RD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoAAoo`8002=oo`05001oogooOol0000COol003Eoo`03001oogoo01Moo`<005moo`9Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0OOol3000017oo000000004Woo000eOol5000C
Ool2001POol0JE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0gOol004Yo
o`<00003Ool007oo05eoo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol0
0`00Oomoo`08Ool4000[Ool004Qoo`8005moo`1`D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004Eoo`<0
05moo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`FOol0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004=oo`80061oo`1eD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo00Eoo`03
001oogoo009oo`03001oogoo02Qoo`00@7oo0`00GWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol0:7oo000nOol2001MOol0Oe;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo02Qoo`00>goo1000GGoo0e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;l
D_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0D
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003Uoo`8000Aoo`03001oogoo05Qo
o`24D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol00goo1000:goo000fOol3001MOol3
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01=oo`800003Ool007oo039oo`00<goo0`00GWoo
08]BoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0aOol0035o
o`8005moo`03D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0P0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
5Goo00<007ooOol0<7oo000^Ool3001MOol0Le;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m00<0000MD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0_Ool002aoo`@005Yoo`05C]aBo4klD_e>
g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00<00006D_eBo5;lD_aB
o@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<0
07ooOol0;goo000ZOol2001KOol0M4ZlC]e:_4kMC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d3000095;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02ioo`00:Woo0P00FWoo00EK
KUm^B]a>g4[L009>g004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0800005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m009Bo1Eoo`03001oogoo02ioo`0047oo1@000goo100017oo10001Woo00<007oo
0000FGoo071OKU]^C]e:_4kMB[a>gDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0<0000ZD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<007ooOol0;Goo000BOol00`00Oomoo`02Ool00`00Oomo
o`02Ool01000Oomoo`0017oo00<007ooOol00goo0P0000=oo`00Ool0EWoo00EOKU]^FfiKKTkm00=>
g006C_e>o5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l
D_`05Goo00<007ooOol0;7oo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo
00<007ooOol00Woo0P000goo00<007ooOol0Dgoo06`0M5Xe?W`nFd9l?U]BoDkLD_e>g5;mC]aBoDkl
D_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`30000<U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
05;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00
Oomoo`0/Ool000Moo`H000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1:Ool014kLC]e>g4kM17oo00AJEEYFFUDnO08nF`03
C]a>oDkL009>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00IBoE;lD_aBo5;mD_`30003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_aoo`0DOol00`00Oomoo`0[Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`17Ool0L5;mC]aBoD[LC_e:g4km
05=oo`1dFUIJ=EiF?U/nO3iK@Wa>g5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0`0003UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007oo0000;7oo000BOol00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo0P001Woo0P00AGoo01Y>o5;mC]a>
oDklC]e>g4kMC]a>gEYEFUIJEEYFFUEJET[LC]a:g4kLC_aBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo000008000=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol0:Woo
000@Ool30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0?Woo071BoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gDJlFUIJ=EiFFSEJEU]=Gfi:_4kM
B[a>gDZlD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0<0
0010D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_dEOol00`00Oomoo`0YOol0019oo`03001oogoo00=oo`@000Aoo`@000Eoo`03001o
ogoo00Qoo`03001oogoo03Yoo`9>g00DC_e>g4klC_aBoDkLC_a>g4kmC]a>oDkLA]e6_DKMA[eJEUYE
FUIJE@=KKP03C]a>oDkL009>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
0e;mD_`000020003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Eoo`03001oogoo02Qoo`00:7oo00<007ooOol0
2Woo00<007ooOol0=Goo0796_4ZmA[a:_DJlD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[a:
gEXeFUIJ=D9l?U/nO3iK@Wa>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d20000Ae;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol0:7oo000XOol3000;Ool0
0`00Oomoo`0cOol2Ci8014JlB[a:_4Zl0dkL019BoDkLC_a>o5;mC]a>oDkLC_e>g4kmA[e6gDJmFUIJ
EEYFFUD2?U/01Cil?U]>g4kLC_d00TkL00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l
0`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`EOol00`00Oomoo`0WOol002Qoo`03001oogoo
00aoo`03001oogoo035oo`1^I[HY^DnBB[e6_4ZmA[a:_DkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[L
C_e6_4[MFSENEUXeFUIJ=D9l?U/nO3iKD_e>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@<0
001>D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol09Woo000XOol0
0`00Oomoo`0=Ool00`00Oomoo`0_Ool00fJgI]MV]P029KT08TkMC]a>g4kLC]e>g4klC]aBoDkLC_e>
o5;mC]a>oDkLC]e>g4kM07A6gEYEFUIJEEYFFUE>g4[LC]a:g5;lC_aBoDkL0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
D_aBo0030002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eB
o000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00
Oomoo`0VOol002Qoo`8000moo`03001oogoo02eoo`1Z;UaZefJfI]LUV2Vi9IU>gD[LC_e:g4kMC]aB
oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>oEXeFUIJ=EiFFSEKKUM=C]e:_4kMB[aBoDkLD_e>g5;mC_aB
oDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d30000EU;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`DOol00`00Oomoo`0UOol002Qoo`03001oogoo00moo`03001oogoo02Eoo`05C]a>gDkLC]e>g002
;Ud01VKGI[IVefJgI]LUV@8U^@06:KU>g4kLC]a>oDkL0Tkl01IBoDkLC_e>g4kmC]a>oDJmA]e6_EYF
FUEJEUYEFUIKKE]^B]a>g4[LC]a:g09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l0`000U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Goo00<007ooOol097oo000XOol00`00
Oomoo`0@Ool00`00Oomoo`0QOol0KT[LC_e>g4kmB]a>oD[LC_e:g6[GI[IVefJfJ]MV]TZmA[a:_DJl
B[e>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gDJlGUIJ=EYFEdeKKU]=Ffi>g5;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d30000GE;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@0COol2000VOol002Moo`03001oogoo019oo`03001oogoo01]oo`03GmASe4Zl
009:_006B[e>g4kMC]a>gDkL0d[M00U:g6KGI[MVefJfCi9?TDZlA[`00TZl01E>oDkLC]a>g4kmC]a>
oDklD_e>g4kmC]a>oDkLA]e6_DKMFUEJEUYEFUH00ciK00HnO4kLC]a>g4kmC]`2D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l0`000U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;m
D_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009B
o1Aoo`03001oogoo02=oo`009goo0`004goo00<007ooOol06Goo06iO]6?DGkASe4JlB]e6_4[MB]a>
oDkLC_e:g4[MB[a:gFJfJ]MV]VKGI[HY^DmaB[e6_4ZmA[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>
oD[LB]e6_5YFFSENEUXeFUHnFd9l?U/nO4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m0`0006ABoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo029o
o`009goo00<007ooOol057oo00<007ooOol067oo00ISe5oDHmAOe6?DB]`2C]`01TkMC]a>gDkLC_e:
g0=:g@08I[IVefJgI]LUVBVi9KU>g@=>g00HD_e>g4klC]aBoDkLC_e>o5;mC]a>gDkLC]e>g01dA[eJ
EUYEFUIJEEYFB]a>g4[L0TkL00=Bo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l0P000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`DOol00`00Oomoo`0ROol001Eoo`@0
00Aoo`@000Ioo`03001oogoo01Eoo`03001oogoo00Moo`03J]H@mWoo00aoo`1ZHmARUV:g<OXf6c7j
=Q]:g4kMB]a>gD[LC_e>g4kmA[a:gDZl<WeV]V[GI[IVebFH:KTUVDkMB]a>oD[LC]e>g5;mC]aBoDkL
D_e>g5;mC]a>oD[LC_e:g5iFFSEJEUXeGUIGCE]]B[a>gDZlC]e>g5;mC]aBoDkLD_e>o5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`30000JU;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo
00<007ooOol08Goo000DOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00<007oo
Ool05Woo0P001goo0V[F00<<mWooOol00goo0T[M00=>gD[L5O`00QGl00URUV:GHYMR]c8J<Q/b6TkM
B]`00TkL00E>gDkLC]e>g4kM008^G@0:I[MVefJfI]MV]bVi9ITY^BFiC_d3C]`06TkmC]a>o4klD_e>
g4kmC]a>oDkLA]e6_DKMFUEJEUYEFUIJEE]]Fde>g4[LC]a:g4kLC_`2D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oGooOol04goo00<007ooOol087oo000IOol01000Oomoo`0017oo00<007ooOol00goo0P004goo00=b
e00<Ool00goo00<007ooOol00goo07AZeVZeK]H<eA3fB[a>gDZlC]e:_4kMB]a>gA7K5OaRUV:gGYIR
]f:F=Q/anSHK<OY>oD[LC_e>g4kmB]a>oD[LC_eV]V[GI[IVefJfJ]MV]TZmA[a:_DJlC_e>g5;mC]aB
oDkLD_e>g5;mC]aBoDkLD_e6_4[MA[a:gEXeGUIJ=E]]EdeKKUM=D_e>g5;mC]aBoDkLD_e>g5;mC]aB
oE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;l0`00079Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_dDOol00`00Oomoo`0POol000aoo`H000Moo`04001oogoo0004Ool00`00Oomoo`02Ool0
0`00Oomoo`0COol00fkD00eoo`04Ool00`00Oomoo`02Ool3J]H020cf3?D<mT[LB]e:g4[MB]`2B]d0
1TkMHYIRUf:GH[MRUP9RU`0:B[e:_4ZlB[a>gDkLC]e>g4kMB]`3B]d01FJfI]MV]fKGI[H00Tma00E:
_4JlB[a>g4km00=>g00AD_e>g4kmC_aBoDkLC_e>g4kmA[e6gDJmFUIJEEYFFUDnO003?U/01DkmC]a>
g4kLC_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo004D_eBo5;lD_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo01moo`005Goo10000goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol04Woo00=^]7;D00`01Woo00D007ooOomZ]FkF009ZeP1[
J[D@mPcE4?I:_4kMB[a>gDJlB]e6_4[MGYIR]f:FH[MNUV?DGkA:gDJlB]e6_4kmB]a>oDkLC_e6_4[M
B[a:gFJfJ]MV]TnABg5?TTJlB[e6_4ZmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>oDJlB]eJ=EYF
FSENEUXe?W`nFd9l?U]BoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo0030000NE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01moo`00
5Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo0P004goo00=be6kDL]@01goo00<0
07ooJ]H016[F00d<e@cf3?D<mT[LC]e>g4kMA[e6gDJmA]eRUP02HYL01V?DGkAOe5oDC]e:g09>g006
C_e>g4kMC]a:gD[L0T[M00UVefJfCg5V]VKG9ITY^DkLC]d00dkL01eBoDkLC_a>g5;mC]a>oDklD_e>
g4kMC]a>g@1CA]eJEEYFFUEJEUYEC]a:g4kLB]aBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`300000e;lD_eBo002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;l
D_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Ao
o`03001oogoo01ioo`005Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool04Goo00Ebe6kDL]A^]00=00Moo`1ZK]IZeV[FJ[E^eV[F4?I6W4JmAYa6_D[LC_e:g4kMA[a:gDJl
H[MNUV?DHYIR]c7j=Q/anTkMB]a>gD[LC_e:g4kmC]a:gDJlB]e:_39mI[IZefJf:KTUV2ViB]a>gD[L
C_e:g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4kmFSENEUXeFUIJ=E]]Ede>gDZlC]e>g5;mC]aBoDkL
D_e>g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_`30000
PE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0MOol001Eoo`D000=oo`@000Eoo`03001oogoo
015oo`0=K]Abe6kDL]@03D[MB]a:gDZlB]e6gD[MA[`00f[F00DfOF[FJ]H@mTJL00=6_005B]a:gD[M
C]dEg0035O`02F:FHYMRUc8K<QXb6dkLC]e:g002C]`014kMC]a>gDkL0biM00YV]VKGI[IVefJf:KTU
VBViC]a>o@=>g00AD_e>g4klC_aBoDkLC_e>g4kmA[e6gDJmFUIJEEYFFUEJEP02Edd01d[LC]a:g4kL
D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0<0
0003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`04goo0P007goo000VOol00`00Oomoo`0@Ool0LVkD
L]A^]7;DK]@03@0<B]e:_4[MB[a:gDJlB]eZ]FkF<WeZeVZeK]H<eA3fB[a>gDZlC]e:g4kMB]a>gA7K
5OaRUV:gGYIR]f:F=Q/anSHKC]a>oD[LC_e>g4kmB]a>oD[LC_eV]V[GI[IVefJfJ]M6_4ZmA[a:_DkL
C_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MA[aJEUXeGUIGCE]]EdaKKDkLD_e>g5;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBo@800028D_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`0LOol002Eoo`03001oo`00015oo`05L]A^
e7;DK]Abe00300d024[MB]a:gDZlB]e6gD[M=Wd4J]H23?H01Q3fB]a:gD[LC]e:g09:g@03C]eRUV:G
009RU`04HYIRUdZlB[d2B[`01dkLC]e>g4kMC]a:gD[L00=:g@04I[IVefJfI]L2Bg42B[`014JlC]a>
g4km0TkL019>o5;mC]a>oDklC_e>g4kmC]a6gDJmA]eJEEYFFUEJESiK?W`2?U/00dkLC_e>g002C]`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0300001E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Aoo`03001oogoo00Moo`D000moo`009Goo0P004Goo
01=be6jdL]A^e7;DK[@03@0<00d034kMB]a>gDZl=YdbOCJMJ[E^eP02J]H0F6Ze4?H<eDkMB[a>gDZl
B]e6_4[MA[a:gEjFH[MRUV:gGk=Se4JlB]e6_4[MA[a>oD[LC_e>g4[MA[a:gDZlI]MV]V[GI[HY^D]`
B[e6_4ZmA[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oD[LB]e6_5iFFSEJEUXeGUHnFd9l?U]2O4kL
D_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0`0008iBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00Moo`05001oogooOol0000?
Ool002Eoo`03001oogoo011oo`07K]Abe6kDL]A^e7;DK]@014:L00E:gD[LB]e:g4[M00IZeP0E3=D<
mPcfC]e:g4kMC]a6gDJmA]e6_F:GHYIRUendGmAO/eoDC]a>gD[L009>g006C_e>g4kMC]a:gD[L0T[M
00IVefJfI]MV]RVi9KT2C]`01TkMC]a>o4kLD_e>g09>o00ID_e>g4kmC_a>gDkLC]e>g01CA[eJEUYE
FUIJEEYFB]a>g4[LC]a>o5;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d00000001Bo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@00
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Aoo`03001oogoo
00Moo`03001oogoo011oo`009Goo00<007ooOol02Woo01M6_D:LA[e6W4[MA[a:gFkDL]A^]7;DK]Ab
e6jdAYe2W4JL@Ya:gDJlB]e6_4[M009ZeP1DJ[E^ePcE0016W4JmAYa>gD[LC_e:g4kMA[a:gDJlH[MO
/f:gHYHf6c7j=Q]:g4kMB]a>gDkLC_e:g4kmC]a:gDJlB]d^GFKGI[IZebFI:KTUV4kmB]a>gD[LC_e>
g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e:g5YFFSENEUXeFUIGC5]=B[a>gDZlD_e>g5;mC]aBoDkLD_e>
g5;mC_aBoDklD_eBo5;m0`0009IBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`07Ool00`00Oomoo`0?Ool002Eoo`8000Yoo`9G
]00FA[e6W4JlA[a:gDJlB]e^e7;DK]Abe6kDL]@03D[MB]a:gDZlB]e6gD[MA[d5J]H00`cfA[a6W002
A[`04TkMB]a:gD[MC]dEg1Gl5MaRUf:FHYLb6S8K<QXb6dkLC]e:g09>g004C]e>g4kMC]`2;Ud026KG
I[IVefJfI]LU^BVi9KT2C]`01TkmC]a>g4klD_e>g09>o00BC_e>g4kmC]a6gDJmA]eJEEYFFUEJEUYE
EdeGC4kLB]a>g4[L0U;l00EBoDklD_aBo5;m00=Bo005D_d00000001Bo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l0000
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d057oo00<007ooOol0
27oo00<007ooOol03Woo000UOol00`00039oo`08Ool06fKG7GQG]4JLA[e2W4JmAYa:gDJlB]e^e7;D
K[Abe6kD00d034[MB[a:gDZlB]e6_4[MA[a^eP02J]H0C6Ze4?H<eDkMB[a>gDZlC]e:g4kMB]`Eo17K
H[MRUV:gGYIR]c8J=Q/anSHKC]a>oD[LC_e:g4kmB]a>oD[LI]MV]V[GI[IVefJfB[e6_4ZmA[aBoDkL
C_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]e6_4[MFSEJEUXeFdeGC5M=EdaBoDkLD_e>g5;mC]aBoDkL
D_eBo5;m0`0009eBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0DOol00`00Oomoo`08Ool00`00Oomoo`0=Ool002Eoo`03
0000<Goo00Moo`0:I[MV]VJg7GPMND[LB]e:_4[MB]`2>Yd01G;DK]Abe6kDL]@00P0=00Q:_4[MB]a:
gDZlB]e6gD[M16[F00T<mA3f3?I:gD[LB]e:g4[MB]`00T[M00=RUf:FHYL00V:G0Unc00Q:_4ZmB[a:
_4kLC]e>g4kM0T[M00U:g4[MB]eVefJfI]MV]T]aBg000dZl01E6_4kLC]a>oDkLC_e>o5;mC]a>oDkL
C_e>g4kmA[e6gDJmFUIJEEYFFUD00SiK00HnO3iKC]a>g4kmC]`2D_`01E;m00000000D_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o004D_eBo5;lD_`EOol00`00Oomoo`03Ool01@00Oomoogoo00003goo000TOol07000Ool0<P0aB]e6
_4[MA[`ZGBHm:UeR]VKGI[HMNAeh8IU:_4[MA[a:gDZlL]A^]7;DK]Abe6jd0`0=00U:_4kMB]a>gDZl
=YdbOF[FJ[D00f[F04@<eA3f3=D@mT[LC_e:g4kMA[a:gDJlH[MNUV:gGk=Oe5^cGmA6_4[MA[a:gDkL
C_e:g4kmB[a:gDJlB]eV]VKGI[IZebFIBg56_4ZmA[a:_DJlD_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[L
C_e6_4[MFSENEUXeFUHnFd9l?U]2O3iKD_e>g5;m0`000:ABoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l57oo00<007ooOol017oo0`0047oo000TOol20003034064ZmA[e:gBHm:UeV]VJgI[IV]fJf7GTM
N1ei7GQ:gDJlB]e6_G;DK]Abe6kDL]A^e0=2W005B]a:gD[LB]e:g006J]H00dJlAYa6_002A[`01T[L
C]e>g4KMA[e6g@9RU`09HYIRUf:G=Q/b6S8KC]a>gD[L009>g003C_e>g4kM009:g@06B]a:gFJfI]MV
]VJg0RVi0dkL01Y>gDkLC_a>g5;mC]a>oDklD_e>g4kmC]a>gDkLC]d0DdKMFUEJEUYEFUI:g4kLB]a>
g4[L0P0000EBoDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00
Ool05goo000TOol09P00Oomoo`0a0380<D[MA[a:gF:fI]MV]VKGH[IVedJLA[e2W4JmAYa:gDJlB]e^
e7;DK[Abe6kDL]@03DJM@Ya6W4:LB]e6_4[MA[`3J]H0@FZeJ]H<eDJmAYa6_DJLC]e:g4kmB]a:gDJl
B]eRUQGlGYIR]f:F=Q/anSHKB]a>gD[LC]e>g4kmB]a>oDZlB]e6_39mI[IVefJf:KTUVBViB]a>oD[L
C]e:g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4kmFSEJEUXeGUIJ=EM=B[`00`000:]:_5;mC]aBoDkL
D_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol05Goo000JOol40006Ool0
0`00Oomoo`04@Y`3A[d046JfI[MV]VJgDk=G]4JlA[e6W4JlA[e:gDJlB]djWG;D0fkD0P0=00M:gD[L
B]e:_4[MA]e:g@03J]H01SImJ]IZeQ3fA[a6W096_007C]e:g4[MB]dEo17L5O`00V:G00iRUV:G<QXf
6c8J<Q]>g4kMC]a>gDkLC]e>g4kM0RiM00EV]VJgI[IVefJf00<Y^@=>g00BC_e>g4klC_aBoDkLC_a>
g4kmC]a>oDJmA]e6_EYFFUEJEUYE0`0000EGC4kLC]a>oDkL009Bo005D_e>o5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo01Eoo`006Goo00<007ooOol00Woo00<007oo
Ool00goo01D007ooOomoodJm@Ya2WD:LA]e6_4KMH[IVee>CI]MR]R6I7GQ6_D:LA[d00SZM00LjOCjM
K]Abe6jdL]A^e00200d0A4[MB[a:gDZlB]e6_4[MJ[DfWFZfJ]IZ]A3f3=E>gDZlC]e:_4kMB]a>gD[L
5O`Aff:gHYIR]ejFH[M6_4[MA[a:gDkLC_e:g4kmB]a>oD[LC_eV]VKGI[IZefJfI]M6_4ZmA[a:_DkL
D_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MA[`30000/ciK@W`nFd9l?U]BoDkLD_e>g5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007ooOol057oo000IOol00`00
Oomoo`02Ool00`00Oomoo`03Ool20002Ool5@Y`3A[d02RHmI[MV]VJg7GPMNAehB]e:_4[M0SZM0fkD
00=be6kDK]@00`0=00A:gD[LB]e:g0<fO@AZeP093?D@mQ3fB]e:g4[MB]a>gD[L009:g@03HYMRUV:G
009RU`03Fk=O/dZl009:_005C]e>g4kMC]a>g@02B]d02D[LB]eV]VKGI[IV]dM@Bg16_003B[`03DJl
C_a>g5;mC]a>oDklD_e>g4kmC]a>oDkL00<00004FUEJEUM<FUH3?U/01CilC]a>g4kLC_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Aoo`03001oogoo01=oo`006Goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00goo05U6_4[MA[a:gDJl:UdV?BYMH[IVefJfI]LMN26I
B[a:gDJlB]e:_7;DK[Abe6kDL]A^]4JM@Ya6W4:LC]e:g4kMB[`fWC9mJ]IZ]F[FJ[IZePcE4?H<eDkM
B]a>oD[LB]e6_4[MA[aR]ejFH[MK/eoCFk=:gDJlB]e6_4kmC]a>oD[LC_e:_4[MA[aZefJfI]MV]V[G
9ITY^D[LC_e:g4kMB]aBoDkLD_e>g5;mC]aBoDkL00<0002jB]a:gDJlFUIJ=EiFFSE2O3iK@W`nFd9l
C]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m4goo00<007ooOol0
4goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool054JlB[e6_D[M9SdZGFJf
I[MV]VJgI[HMNAeh7GU6_D[MA[a:gDJmL]@3K]@00g;DK]A2W002@Y`01D[LB]e:g4[MB]`01V[F00]6
_4JLA[a6_4kMB]a>gDkLA]e6_DKM009RU`05HYIRUf:G=Q/b6P02C]`01dkMB]a>gDkLC_e>g4kM009:
g@05B]aV]fJfI]MV]P03:KT3C]`01TkMC]a>o4kLD_e>g0<0000?C]a>gDkLC]e>g4kMA[eGC5YEFUIJ
EDkLB]a>g4[L009>g003D_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UB
oE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_ao
o`0COol00`00Oomoo`0BOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Ioo`1@
B]e6_4[MH[IVefJfI]MR]UNdDi=6_D:LA[e6_4[MA[a:gFkDL]A^]7;DK]Abe00=AYe2W4JLA[a:gDJl
B]e6_6[FJ[IZeVZe4?H004JmAYa6_DJLC]e:g4kmB]a:gDJlB]eRUV:gGYIR]c8J=Q/anTkMB]a>gD[L
C]e:g4kmB]a>oBiM;Wd^G6[GI[IVefJf:KTUVDkMB]a>oD[LC]e>g0<00031C]aBoDkLD_e>g4[MA[a:
gDJlGUIJ=EYFFSEGC5</C]e:_4kMB[a>gDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`057oo00<007ooOol04Goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool20008
Ool3A[d02FJfI[MV]VJgI[HMNE>cA[e6W002A[`01D[MA[a:gFkDL]@00fkD0P0=00M:gD[LB]e6_D[M
A]e:g@02J]H00cImJ]IZeP024?H01T[MB]a:gD[LC]e:g09:g@035O`Ag6:G009RU`0=HYIRUc8J=Q/b
6TkMC]a>gDkLC]e>g4kMC]`00RiM00IVefJfI[MV]VKG9KT2:KT00dkmC]`00002000054kLC_a>o5;m
C]a>oDkLC_e>g4KMA[e6gEYEFUIJEEYFDbaGC5=<C_d3C]`01TkmC_aBo5;lD_e>o09Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l4goo00<007ooOol04Goo000JOol40005Ool00`00Oomo
o`07Ool0BT:lA]e6_4KMH[IVefJfI[MR]R6I7GQ:gDJlB]e:_3ZM>Webe6kDL]A^]7;D00d03TZlB]e:
_4[MB[a:gDJlB]dbOF[FJ[IZePcE4?H<mDkMB[a>gDZlC]e:g4kMB]aR]ejFH[MNUV:gGYI:gDJlB]e6
_4kmC]a>oD[LC_e:g4kmB]aZefJfI]MV]V[GAdm7D4JlB[d20000b4kLD_e>g5;mC]aBoDkLD_e>g5;m
C]aBoDkLB]e6_4[MFSENEUXeFUHnFd9l?U]BoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_dBOol3000BOol000Eoo`800003Ool0000001Uoo`03001oogoo00Qo
o`A6_@0<9SeV]fJfI[LMN1ei7GQ:gDZlB]djWG;D0fkD00=be6kD00d00P0=00E:g4[MB]a:gD[L008f
O@EZeP8@mP0;B]a:gD[LB]e:g4KMA[e6gDJmHYMRUP02HYL00encFk=:_004B[`00dkLC]e>g003B]d0
1T[LI[MV]VKGAdm7D0<000=:_00DC]a>o4kLD_e>g4kmC_aBoDkLC]e>g4kMC]a6gDJmFUIC;5YFFUDn
O0<nF`05?Wa>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
Oomoo`0AOol00`00Oomoo`0@Ool000Aoo`03001oogoo008001Yoo`03001oogoo00Uoo`129S`ZGBHm
I[MR]VKGI[IV]aeh8ITMN4[MA[a:gFkDL]A^]7;DK]Abe6jdAYe2W4JLB[a>gD[LC]dbOCJMJ[IZeVZe
J]IZ]Q3f3=D@mT[LC]e:g4kmB]a:gDJlB]eNUV:gGYIOde^cGk=K/TkMB]a>gD[LC]e>g4kmB]a:gDZl
B]eV]V[G0`000<lY^BFIC]e:g4kmB]a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>o@0bB]eJ=EYFFSEN
EUXeC]e:_4kMB[a>gDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d04goo00<007ooOol03goo0004Ool01@00Oomoogoo00006Goo0`0037oo00QV]fJfI[MV]VJg
I[I6_DJL0TJl00E:gDJlB]e^e7;D00=^e009L]@03D:L@Ya6W4:LB]e:g4[M00EZeP0D4?H004JlAYa6
_4kLC]e:g4kMC]a6gDJmA]eRUencHYIRUc8J=Q/b6P9>g007C]e:g4kMC]a>oDkLB]d00`0000=V]fJf
I]L00bVi00I>gDkLC]a>g4kMC]`2C_`03U;mC]a>oDklD_e>g4kMC]a>gEYEFUIJEEYFFUD2Db`02DkL
B]a>g4[LD_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
Oomoo`0AOol00`00Oomoo`0>Ool000Aoo`05001oogooOol0000IOol00`00Oomoo`0=Ool0>FKGI[IV
]f:fDk=?TdJm@Ya6_DJLB]e6_4[MK]Abe6jdL]E^e00>00e:gDZlB]e:_4[MA[a:gFZeJ]IZ]V[FJ[D@
mTJLA[e6W4JmAYa>gD[LC]e:g1Gl4M/Eo5jFH[MNUSHK<QXf6d[LC]e:g4kMB]a>o@030000eRim;UeV
efJfI]MV]VKG9IPY^BFI:KU>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[aJEUXeGUIJ=EYFDb]G
C4ZlC]e:_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l4goo00<007ooOol03Woo0004Ool01@00Oomoogoo00006Goo00<007ooOol03Goo00=V]VJgI[H0
0Woo00@MNAehA[e6W096_005B]e6_4[MK]Abe003K]@0200>00e:gD[LB]e6_D[MA]d2J]H00cImJ]IZ
eP024?H02d[LB]e:g4[MB]a>gD[LB]dAg1GlHYH00f:G00IRUS8K<QXf6dkLC]d3000034kMC]a>gDkL
I[MV]VKGI[IV]fJfB[a6_0=:_0=>g00EC_e>g4kmC_aBoDkLC_e>g4kmA[e6gDJmFUIJEEYFDbaCC5<[
Dba>g4km00=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004
D_eBo5;lD_`COol00`00Oomoo`0=Ool000=oo`80009oo`8001Uoo`03001oogoo00ioo`03H[Ioogoo
009oo`0]8ITMN4[MA[a:gDZl>Ye^]7;EK]Abe6jdL]D03@0>00e:gDZlB]e6_4[MA[`fWFZeJ]IZ]Q3f
3=D@mTZlC]e:_4kMB[a>gD[LC]eNUV:gGYIR]ejFFk=KTT[M00<0003NC_e>g4kmB]a:gDJlB]e6_6KG
I[IVefJfAe13CdZmA[a:_DJlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MFSEJEUXeGUIJ=D9l
?U]2O4kLD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l4goo00<007ooOol037oo000ROol2000DOol021eh7GTMN4[MB[a:gD[LL]@3K]@02W;DK]A2
W4:LAYa2W4[MB]a:gC9m0SIm16[F113f00M>gD[LC]e>g4KMA[e6g@02HYL00f:FFk<000020004B[`0
14kMC]a>oDkL0d[M00E:g6JgI[IVefJf008Y^@0IB[a6_4ZlB[aBoDkLC_a>g5;mC]a>oDklD_e>g4kM
C]a>gDJmFUIJEE=<FUEJESiK?W`00SiK00I>o5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Woo00<007ooOol037oo000ROol00`00Oomoo`0DOol0
9Qeh8ITMN4[MA[a:gDJlL]A^]7;EK]Abe6jdAYe2W4JLB[a>gD[LC]e:_6[FJ[IZeVZeJ]I6W4JmAYa6
_DJLC]e:g4kmA[a:gDJlH[L30000iF:g<QXf6d[LC]e:g4kMB]a>oDkLC_e:g4[MA[a:gFJfI]MV]VKG
9IPY^BFIC]e:g4kmB]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>oDJlGUIJ=EYFFSENETZlC]e:_4kM
C]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
01=oo`03001oogoo00]oo`008Goo00<007ooOol05Woo00Q6W4JlA[a:gDJlB]e^e7;D0fkD00Ybe00=
@Ya2W4JLA[e:gDKMB]e6_@AZeP0:4?I6_4JlAYa6_4kLC]e:g4kMA[d2000026:G4MaRUf:F<Q/b6SHK
B]`2C]`01TkMB]a>gDkLC]e>g0<^G@04I[IV]fJfI]L3:KT01TkMC]a>g4kLD_e>g09>o00=D_e>g4km
C_aBoDJmA]e6_EYFFUEJEUYEFUH00U<[00M:g4kLB]a>g4[LD_e>o002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l019oo`8000aoo`008Goo00<007oo0000
5Woo0216_D:LA[e6W4[MA[a:gFjdL]A^]7;EK[@03P0=B]e:_4[MA[a:gDJlB]eZ]F[F<WeZeVZe4?H@
mDJmAYa6_D[L0`000>/AfaGl4M]R]ejFHYMNUSHK<QXf6c7jC_e>g4kmB]a>oD[LC_e:g2im;UeVefJf
I]MV]RVi9IPY^BFID_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[aJEUXeGUIJ=E</Cb]CC4kL
D_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo00COol00`00Oomoo`0:Ool0025oo`8001Qoo`04B]e:_4[MB]`2>Yd2K]@03W;DK]A^e00=00i:
_4[MB]a:gDZlB]e6gD[M<Wd3J]H34?H300000d[MC]e:g002B]d00f:GHYIRU`02HYL5B[`044kMC]a>
gDkLC]e>g4kMC]aV]fJfI]MV]T=?@bm:_4Jl0TZl01E>oDkLC]a>g5;mC]a>oDklD_e>g4kmC]a>oDJm
A]eJEEYFFUEJEUYE?W`00SiK00=>g4kmC]`00TkL00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo015oo`8000]oo`003goo100017oo10001Woo00<0
07ooOol067oo01Q:gDJlB]djWG;DK[AbeFjdL]A^]00>00d03TZlC]e:g4kMB[`fWC9mJ]IZ]F[FJ[H3
0000ldZlC]e:_4kMA[a:gDJlB]e6_6:GGYIR]e^BFk=6_4[MA[a:gDJlC_e>g4kmB]a:gDJlB]e6_6KG
I[IVebFHAdm6_4ZmA[a:_DJlD_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LC_e6_5iFFSEC;5XeGUHnFd9l
?U]2O4kLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo00>Ool300000goo001oo`0:Ool000ioo`03001oogoo009oo`04001oogoo0004Ool0
0`00Oomoo`03Ool00`00Oomoo`0IOol01D[MB[a:gFkDL]@01FkD0T:L00Q6W4[LB]e:g4[M<WdfOF[F
0`0000aZeQ3f4?H@mTkLC]e:g4kMA[e6gDJmA]d2HYL01F:FFk9K/U^cFk800TkL00I>gD[LC]e>g4km
B]`3B]d016JfI[MV]VKG0RVi00=>g4kMC]`00TkL01YBoDkLC_a>g5;mC]a>oDklD_e>g4kMC]`0<TJm
FUIJEEYFFUEJET[LC]a:g4kLC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo00Qoo`@000Aoo`03001oogoo00Uoo`004goo00@007oo
Ool000Aoo`03001oogoo00=oo`8001]oo`0@B]e6_4[MK[Abe6jdL]E^]7;D00e6WD:LAYa2W4kMB]`3
0000nVZfJ]IZ]A4F0016_DJLA[e:g4kMB]a>oD[LB]e6_4[MGYIRUejF=Q/b6SHK<OY>gD[LC]e:g4km
C]a>oDJlB]e6_4[MI[IVefJf:KTUV2ViB]a>gD[LC_e:g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g5YF
FSENEUXeFUI?2e</B[a>gDZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m1Woo0`0027oo00<007ooOol02Goo000COol01000Oomoo`00
17oo00<007ooOol00Woo0P007Goo00E:gDJlB]e^e7;D00A^e00300e:gD[L00<00003A]e:gF[F00AZ
eP084?I6_4JlAYa6_4[MC]e:g09:g@034O`Ag17L009RU`05HYHb6c8J=Q]:g002C]`01DkMC]a>gDkL
C]d00biM00AVefJfI[MV]P@Y^@06C_e>g4kLC]aBoDkL0Tkl019BoDkLC_e>g4kmA[e6gEYEFUIJEEYF
FUEC:dl[C]a:g4kLB]`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo004D_eBo5;lD_`3Ool3000<Ool00`00Oomoo`08Ool000moo`@000=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo01eoo`08B]e6_4[MK[Abe6jdL]E^]0<0003oB[a:gDZlB]e6
_6[FJ[EZeVZfJ]H@mA4FB[a>gDZlC]e:g4kMB]a>gA7K5OaNUV:gGYIRUejF=Q/b6SHKB]a>oDkLC_e:
g4kmB]a>oD[LI]MV]VKGI[IVedJlB[a6_4ZmA[aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eJ
=EYFFSEC;4l[Db]?2e;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l005Bo@5Bo08000moo`03001oogoo00Qoo`003goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo00@jWFkDK]A^e0<000803P0500e:
gD[LB]e:g002=Wd5J]H24?H024[LB]e:g4[MB]a>gD[LB]d2HYL01F:FHYMRUe^bEi800dZl00E>g4kM
C]a>gD[L00=:g@04B]aV]fJfI]L2@bh2B[`06DJlB[a:_5;mC]a>o4kLD_e>g4kmC_aBoDkLC_e>g4KM
A[eJEUYEFUIJEEYF?U/nO3iK009>g005C_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l47oo00<007ooOol027oo000?Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0OOol01G;D000006jdL]@00Woo0?m2W4JL
@Ya>gD[LC]dbOCJMJ[IZeVJeJ]IZ]Q3f4?DA5T[LC]e:g4kmB]a:gDJlB]eNUV:GGYIK/eNBFk96_4[M
A[a:gD[LC_e>g4kmA[a:gDJlB]eV]VKGI[IVebFH:KU:g4kMB]a>oD[LD_e>g5;mC]aBoDkLD_e>g5;m
B]a>oD[LB]eJ=EiFCb]JEUXeGUHnFd9l?U]BoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`000IBoE;lD_eBo5;mD_`?Ool00`00Oomoo`08Ool000mo
o`D000=oo`@000Eoo`8001ioo`<000=^e0=oo`92W005AYa2W4[MB]a:g@06J]H02a3fA[a6W4JlC]a>
gD[LC]e>g4KMA[d00f:G00ERUV:G<QXf6d[L009>g006C]e>g4kMC]a>oDkL0d[M00=V]VJgI[H00bVi
00=>g4kMC]`00TkL01YBoDkLC_a>o5;mC]a>oDklC]e>g4kMC]a6gEYEFUIJEEYFC`]?:d[LC]a:g5;l
C_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo5;l00moo`03001oogoo00Qoo`0087oo00<007ooOol06Woo0`000goo00=^]7;DOol00goo
03403D[MB[a:gDZlB]e6_4[MI[EZeVZfJ]IV]F[FAYa6_DJLA[e6W4kMB]a>gD[LB]e6_6:gGYIRUejF
=Q/b6SHKB]a>gD[LC]e:g4kmB]a>oD[L;Wd^GFKGI[IVefJf:KTUV002:KT0de;mC]aBoDkLD_e>g5;m
C]aBoDkLD_e>g4[MA[a:gEXeFUIJ=EiFFSEC:dl:C]e:_4kMB[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00ioo`03001oogoo
00Qoo`0087oo00<007ooOol05goo0`0037oo0P0>00M:gD[LB]e:_4[MA]e:g@04J]H03FZf4?I:g4[M
B]a:gD[LC]e:g4[M4M`Ao6:F00=RU`0BHYHf6c8J=Q]>g4kMC]a>gDkLC]e>g4kMC]aV]fJfI[MV]VJg
1DZl019>oDkLC]a>o5;mC]a>o4kLC_e>g4kmC]a6gDJmA]eJEEYFFUD2Cb/01U<[C`]>g4kLC_e>g09B
o005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_aBo00=Ool00`00Oomoo`08Ool001moo`03001oogoo01Eoo`<000moo`0^00d03P0=
B]e:_4[MB[a:gDJlB]eV]F[FJ[IZeQ3e5AI:_4kMB[a>gDZlC]e:g4kMGYIRUejFH[MNUU^bEi5:gDJl
B]e:g4kmC]a>oDJlB]e6_4[MA[aVefJfI]L20000f4JlB[a6_4ZmC]aBoDkLD_e>g5;mC]aBoDkLD_e>
g5;mC]a:gDJlGUIJ=EYFFSE2O3iK@W`nFe;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@eoo`03001oogoo00Moo`00
7goo0P004goo0`004Woo0T:L00I6W4:LB]e:g4[MB]`2=Wd00f[FJ[IZeP02J]H34?H01dkMB]a>gDkL
A]e6_DKM009RU`04HYIG/UNBFk84B[`014kLC]e>g4km14[M00AV]VJgI[IV]`<Y^@=:_003C]aBoDkL
009>o00=D_e>g4kmC_a>gDkLC]e>g4KMFUEJEUYEFUH00ciK00HnO3iKD_a>o5;mC]`2D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oE;lOol037oo00<007ooOol01goo000OOol00`00Oomoo`0?Ool3000FOol0<4JM@Ya6W4:LC]e:g4kM
B[aZeVZfJ]IV]F[FJ[I6_DJLA[e6W4kMB]a>oDJlB]e6_6:gGYIRUejFH[Lb6SHKB]a>gD[LC]e:g4km
C]a>oD[LB]e6_4[MI[IVefJf:KTUV08Y^@3FC]e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmB]a:
gEXeGUIJ=EYFB[a>gDZlC]e:_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`<Ool00`00Oomoo`07Ool001moo`03001o
ogoo00aoo`<001]oo`07@Ya6W4:LB]e6gD[MA[d00f[F00EZ]V[F4?I6_4JL0096_00>C]e:g4kMA[e6
gDJmHYMRUV:GHYHf6c8J=Q]:g09>g006C]e>g4kMC]a>gDkL0RiM00AV]fJfI[MV]P<Y^@07C]a>gDkL
C]a>o5;mC]`00Tkl019BoDkLC_e>o4KMA[e6gEYEFUIJEEYFFUE?:d[LC]a:g4kLB]`2D_`01E;mC_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo7oo00Yoo`03001oogoo00Moo`007goo00<007ooOol02Goo0`007goo02a:_4[MB[a:gDJl
B]eV]F[FJ[IZeVJe5AH@mTkMB[a>gDZlC]e:g4kM4M/Ao5jFH[MNUV:GGYHf6c8J=Q]:g4kmC]a>oD[L
C_e:g4km:U`^OFJfI]MV]VKG0RVi0=TUV2ViC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eJ
=EYFFSE?:dl:Cb]?2U;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00:Ool00`00Oomoo`07Ool001moo`80
00Qoo`80029oo`08B]e:g4[MB[a:gDKMB]eZ]P=ZeP<@mP0=B]e:g4[MB]e>gD[LB]eRUV:GHYIRUf:F
HYL014Zl00a>g4kMC]a>gDkLC]e>g4kMI[IV]fJfI[L20004B[`04dkLC_e>g4kLC_aBoDkLC_e>g4km
C]a>oDkLA]e6_EYFFUEJEUYE008nF`06?W`nFdkLC]a>oDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`08Ool0
0`00Oomoo`07Ool001ioo`03001oogoo00Eoo`<002Eoo`3oC]e:g4kMB[`fWC9mJ]IV]F[FJ[IZeQ3e
5AH@mTkMB[a>gDJlB]e6_4[MGYIRUejFH[MGTENbA[a:gDJlB]e:g4kmC]a>oD[LB]e6_4[MI[IVefJf
I]LYV2ViA[a:_4JlB[e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LC_e:g4[MFSENEUXeFUHnFd9l?U]2O3iK
D_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m0008D_aBoE;lD_eBo5;mD_aBo@Yoo`03001oogoo00Ioo`007Woo00<007ooOol00Woo0`00
:Goo00A:gD[LB]e:g0=ZeP05J[IZeV[FA[a6W002A[`03TkMB]a>gDJmA]e6_F:GHYIRUf:FHYLb6SHK
B]`2C]`01TkMC]a>gDkLC_e>g09:g@04I[MV]VJgI[H3:KT00dkLC]e>g002C]`06U;mC]a>o4klD_e>
g4kmC]a>gDkLC]e>g4KMFUEJEUYEFUI:g4kLB]a>g4[LD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0Yoo`03001o
ogoo00Ioo`007Woo00<007oo00000P00;Goo0?m:gDJlB]e6_6[FJ[IZeVJeJ]H@mTJlAYa6_DJLC]e:
g4kmA[a:gDJlH[LAff:GGYHf6c8J=Q]:g4kMB]a>gD[LC_e:g4kmB]`^OBiMI]MV]VKGI[HY^BVH:KU:
g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gEXeFUIJ=EYFFSE?2TZlC]e:_4kMB[aBoDkLD_e>
g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
00MBo5;mD_aBoE;lD_eBo009Ool00`00Oomoo`06Ool001ioo`<0031oo`08B]e6gD[MJ[IZeS9mJ]IZ
]P8@mP07B]e:g4[MB]a>gD[LB]d00Q7L010Aff:GHYIRUf:F=Q/b6SHKC]a>gDkLC]e>g4kMC]a>g@8^
G@04I[IV]fJfI[L4:KT04dkLC_e>g4kLC_aBoDkLC_a>g4kmC]a>oDkLA]e6_DKMFUEJEUYE00=?2P=>
g006C_e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`8Ool00`00Oomoo`06Ool000Aoo`D000=oo`@000Aoo`@0
00Moo`03001oogoo031oo`0WB]e6_4[M<WeZeVZfJ]H@mADF4?I>gDZlC]e:g4kMB]a>gD[LHYMNUV:g
GYIRUdJlB]e6_4[MB]a>oDkLC_e:g4kmB]a>oFJfI]MV]VKG0080003MA[a:_4JlB[e>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLD_e>g4[MA[aJEUXeFUIJ=D9l?U]2O4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkL
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo007Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`05Ool2000aOol013Im<WdfOFZf0f[F0a3f00]:gD[LB]e6_DKMA[e6gDJmHYMRUV:G
009GT@A:_005C]a>gDkLC_e>g003B]d016JfI[MV]VJg0RVi14Zl00=>g5;mC]`00Tkl00eBoDkLC_e>
g4kMC]a>gDkLA]eJEEYFFUEJEP03?U/01SilC]aBo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`01goo
00<007ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo
Ool01goo00<007ooOol0<7oo0?mZ]V[FI[EZeVZfA[a6W4JmAYa>gD[LC_e6_4[MA[a:gEjFHYMNUV:g
<QXf6d[LC]e:g4kMB]a>oDkLC_e:g4[MA[aVefJfI]MV]RVi:IPY^D[LC]e:g4kmC]aBoDkLD_e>g5;m
C]aBoD[LC_e:g4kmB]a:gEXeFUIJ=EYFB[a>gDZlC]e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`000EBoE;lD_eB
o5;m00Ioo`03001oogoo00Ioo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00Qoo`03001oogoo031oo`9ZeP05J[Iooa3fA[a6W002A[`03TkMB]a>gDkLA]e6_DKM
HYIRUf:F=Q/b6SHKB]`2C]`01TkMB]a>gDkLC]e>g08^G@04I[MV]VJgI[H3:KT01dkLC]e>g4kLC_aB
oDkL009>o00;D_e>g4kmA[e6gDJmA]eJEEYFFUEJEP0200001D[LC]a:g4kLC_`00U;l00EBoDklD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mD_aoo`06Ool00`00Oomoo`05Ool000Ioo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`09Ool00`00Oomoo`0_Ool00f[FJ[Ioo`02Ool0813fC]e:
_4kMB[a>gD[LC]e:g17l3M]R]ejFHYMNUSHK<QXf6d[LC_e>g4kmB]a>oD[LC_dZGBimI[IVef:fI]L2
:KT05BVH:KU>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[aJEUXeFUIJ=@030000aDkLD_e>g5;m
C]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`01Woo00<007ooOol01Goo0006Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol02Woo0P00=7oo00PDmQ3fB]e:g4[MB]a>gD[L
0T[M00ERUf:FHYMRUV:G00A:_00<C]a>gDkLC]e>g4kMC]a>gFJfI[MV]VJg0P0014Zl01=>g4kmC]a>
g4klD_e>g4kmC]a>oDkLC_e6_DKMA[eJEUYEFUIJE@02?U/01CilC]a>g4kLC_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mD_aoo`04Ool00`00Oomoo`05Ool000Aoo`<000Aoo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`0<Ool00`00Oomoo`0aOol0oa3e5AH@mTkMB[a>gDZlB]e6_4[MA[aR
UejFH[MCTENAA[a:gDJlB]e6_4kmC]a>oD[LB]e6_4[MH[IVefJfI]LYV2ViA[a:_4JlB[e>g5;mC]aB
oDkLD_e>g5;mB]a>oD[LC_e6_4[MFSD005XeFUHnFd9l?U]2O4kLD_e>g5;mC]aBoDklD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo001D_d1D_`4Ool00`00Oomoo`05Ool000Ioo`03001oogoo00=oo`@000Aoo`@0011oo`03
001oogoo031oo`0BA[a6W4JlA[a>gD[LC]e>g4KMA[e6gF:FHYMRUV:G<QXf6d[L0TkL00I>gD[LC]e>
g4kmC]`2B]d016JgI[IV]fJf0bVi00=>g4kMC]`00TkL01ABoDkLC_a>o5;mC]a>oDkLC]e>g4kMA[eJ
EUYEFUIJEEYFB]a>g4[L0TkL00=Bo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;l
D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo009oo`03
001oogoo00Eoo`00:Goo00<007ooOol0<7oo03M6_4JLA[e6W4JlB]a>oD[LB]e6_4[MGYIRUejF=Q/b
6SHKB]a>gD[LC]e:g4kmB]a>oD[L;WdZGFKGH[IVefJf:KTYV2ViB]a>gD[LC_e>g5;mC]aBoDkLD_e>
g5;mA[a:gDJlFUIJ=EYFFSEJEP020000b4ZlC]e:_4kMC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d3Ool00`00Oomoo`05Ool002Yoo`03001oogoo035oo`05B]a:gD[LB]e:g002B]d04A7L4M]R
Uf:FHYMRUSHK<QXf6dkLC]e>g4kMC]a>gDkLC]d00RiM00AV]VJgI[IV]`@Y^@0CC]a>oDkLC]a>o5;m
C]a>o4kLC_e>g4kmA[e6gDJmFUIJEEYFFUD00`000dkL00E>oDklD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`3Ool00`00Oomoo`05Ool002]oo`80039oo`0LB[a>gDZlC]e:g4kMB]aRUejFHYMNUUNADg1:
gDJlB]e:g4kmC]a>oD[LC_e:g4kmH[IVefJfI]L20000hDJlB[a6_4ZmC]aBoDkLD_e>g5;mC]aBoDkL
D_e>g5;mA[a:gEXeFUIJ=EYFFSE2O3iK@Wa>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo003Ool00`00Oomoo`04Ool002eoo`03001oogoo031oo`0:B]a>gDkLC]e6_DKMA[eRUf:FHYL2
Di45B[`014kMC]a>oDkL0d[M00AV]VJgI[IV]`8Y^@A:_003C]aBoDkL009>o00=D_e>g4kmC]a>gDkL
C]e6_EYFFUD005YEFUH00ciK00E2NdkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo09o
o`03001oogoo00Aoo`00;Woo00<007ooOol0<7oo0?m:g4kmB]a:gDJlB]eNUV:GGYIRUc8J=Q]:g4kM
B]a>gD[LC_e>g4kmB]a:gDJlI]MR]VKGI[HY^BVh;KU:g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e:g4km
B]a>oDJlFUIJ=EYFFSEJETZlC]e:_4kMC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`00Goo0@001Woo000_Ool00`00Oomoo`0`Ool03D[LC]e>g4KMA[e6gF:FHYMNUSHK=QXf6d[L009>
g006C]e:g4kMC]a>gDkL0RiM00AV]fJfI[MV]P<Y^@07C]a>gDkLC]a>o5;mC]`00Tkl00]BoDkLC_e6
_DKMA[eJEUYEFUIJEEYF00800005B]a>g4[LC]a>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aoo`0000Ioo`00<7oo0P00<Goo035:g4kMB]`Ag0gKHYMNUV:GGYHf6c8J=Q/anTkmC]a>
oD[LC_e:g4kmB]aVefJfI[MR]VKGA[a:_4JlB[e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[aJ
EUXeFUIJ=@030000bdkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0000
1Woo000bOol00`00Oomoo`0_Ool02D[LB]e:gF:GGYIRUf:FDi5CL004B[`014kMC]a>gDkL14[M00=V
]fJfI[L00P0014Zl019>g5;mC]a>o4kLD_e>g4kmC]a>oDkLC_e6_DKMFUEJEUYEFUH3?U/01D9kC]a>
g4kLC_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l0goo00<007ooOol017oo000cOol00`00Oomo
o`0_Ool0mDJlB]e6_6:GGYIRUe=`Di5CL5>AA[a:gDJlC_e>g4kmB]a:gDJlB]eR]VKGI[IV]bVh;KU:
g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>oDJlFUIJ=EYFFSEJESiK@W`nFe;mC]aBoDkLD_e>
g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`027oo00<007ooOol00goo000dOol00`00Oomoo`0_Ool04DJmA]eRUV:G
Dg1RUf:F=Q/b6SHKC]a>gD[LC]e>g4kmC]`00d[M00=V]VJgI[H00bVi00=>g4kMC]`00TkL01UBoDkL
C_a>o5;mC]a>oDklC]e>g4kMA[eJEUYEFUIJE@00B]a>g4[LD_e>g5;lC_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00aoo`03
001oogoo00=oo`00=Goo0P00<7oo02e6_4[MGYIRUejFHYLb6SHK<OXf6d[LC]e:g4kmB]a>oD[L;WdZ
GFJgH[IVefJf:KTY^2fiC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlFUIJ=EYFFSD00`000;a:
_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m001BoE;lD_eBo5;m3goo00<007ooOol00goo000gOol00`00Oomoo`0]Ool01a7L3M]RUf:FHYMN
UV:G00A:_00<C]a>gDkLC]e>g4kMC]aV]fJfI[MV]VJg14Zl00=>g4kmC]`00TkL00iBoDkLC_e>o4km
C]a>oDJmA]e6_EYFFUEJEUYE0SiK00I2NdkLC]a>g5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<007ooOol04Goo00<007ooOol00goo000hOol0
0`00Oomoo`0]Ool0i6:GGYIRUejFHYM?L5>@A[a:gDJlB]e>g4kmB]a:gDJlB]e6_6KGI[IV]f:f0016
_4ZlA[a:_DkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]eJ=EYFFSEJESiK@W`nFd9lC]aBoDkLD_e>
g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0=oo`03001oogoo
011oo`03001oogoo00=oo`00>Goo00<007ooOol0;Goo00=RUejFHYL00Woo00Db6SHKC]a>gD[L009>
g003C_e>g4[M009:g@04I[IV]fJfI[L2:KT00dkLC]e>g002C]`055;mC]a>o4kLD_e>g4kmC_a>gDkL
C]e6_EYFFUEJEUYEFUI:g4kLB]`2C]`00e;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`8Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003Yoo`8002eoo`03GYIRUgoo009o
o`3G=Q/anSHKB]a>gD[LC]e>g4kmB]a:gDJlB]eR]VKGI[IV]bVh;KU:g4kMB]a>oDkLD_e>g5;mC]aB
oDkLD_e>g4kmB]a>oDJlFUIJ=EYFFSD004ZlC]e:_4kMC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mC_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@0;Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003aoo`03001oogoo031oo`0:
=Q/b6SHKC]a>gDkLC]e>g4kMC]`2;Ud016JgI[IV]fJf0bVi00M>g4kmC]a>g4klD_e>g002C_`02Tkm
C]a>oDkLA]e6_EYFFUEJEUYE0`000dkL00E>oDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo11o
o`03001oogoo00moo`03001oogoo009oo`00?Goo00<007ooOol0;goo00m6_4[MA[a:gDkLC_e:g4km
B]a>oD[LI]MV]VJgH[H00P000;i:_4JlB[e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[aJEUXe
FUIJ=D9l?U]2O4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00ioo`03001o
ogoo009oo`00?Woo00<007ooOol0;goo14Zl00A>g4kmC]a>g@=:g@04I[MV]VJgI[H2:KT3B[`00dkL
D_e>g002C_`03E;mC]a>oDkLC]e>g4kMC]a6gEYEFUIJEEYF00<nF`05@W]>g5;lC_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoGooOol05goo00<007ooOol03Goo00<007ooOol00Woo000oOol00`00Oomoo`0_Ool0aT[LC]e:
g4kMC]a>oD[LC_e6_4[MH[IVefJfI[LY^2fi:KU>gD[LC_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LC_e:
g4[MFSEJEUXeFUI:_4kMB[a>gDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAaoo`03001oogoo00eoo`03001oogoo009oo`00
@7oo0P00<7oo00=>g4kMB]`00TkL00=>gDkLC]d00RiM00AV]VJgI[IV]`<Y^@06C]e>g4kLC_aBoDkL
0Tkl00]BoDkLC_e6_DKMA[e6gEYEFUIJEEYF00800005B]a>g4[LC]a>o002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d087oo00<007ooOol0
37oo00<007ooOol00Woo0012Ool00`00Oomoo`0^Ool08dkLC_e:g4kmB]a>oD[LC_eV]VJgH[IVefJf
B[a6_4ZmA[aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlFUIJ=EYFFSD00`0009M>g5;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00UOol00`00
Oomoo`0;Ool00`00Oomoo`02Ool004=oo`03001oogoo02ioo`04C]a>gDkLC]d4B]d01FJfI[MV]VJg
000014Zl019BoDkLC_a>g5;mC]a>oDklC_e>g4kmA[e6gDJmFUIJEEYFFUD2?U/01D9kC]a>g4kLC_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l:7oo00<007ooOol02goo
00<007ooOol00Woo0014Ool00`00Oomoo`0^Ool0]4kLC_e:g4kmA[a:gDJlI]MV]VJgH[H]^BViC]e:
g4kmB]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmA[a:gEXe001J=EYF?U]2O3iK@Wa>g5;mC]aBoDkLD_e>
o5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoBeoo`03001oogoo00]oo`03001oogoo005oo`00
AGoo0P00<7oo00=>oDkLC]d00d[M00AV]fJfI[MV]P8Y^@06C]e>g4kLC]aBoDkL0Tkl011BoDkLC_e>
o4kMC]a>gDJmFUIJEEYFFUD004[LC]a:g09>g003D_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
D_aBo00aOol00`00Oomoo`0:Ool00`00Oomoo`01Ool004Moo`03001oogoo02ioo`0NC_e:g4km:Ud^
GF:fI]MV]VJg:KP]^BViD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_5YFFSEJEUXe0`0008Y>g5;m
C]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_deOol00`00Oomoo`09Ool00`00Oomoo`01Ool0
04Qoo`03001oogoo02ioo`07C]e>g4kMI[IV]fJfI[L00P000dZl019>oDkLC]a>g5;mC]a>oDklC_e>
g4kmC]a6gDJmFUIJEEYFFUD2?U/01D9kC]a>g4kLC_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`iOol00`00Oomo
o`09Ool00`00Oomoo`01Ool004Uoo`03001oogoo02ioo`2RB]e6_4[MI[IV]f:fI]LY^BfiA[a:_DJl
D_e>g5;mC]aBoDkLD_e>g4kmB]a>oD[LB]eJ=EYFFSEJESiK@W`nFd9lC]aBoDkLD_e>g5;mC_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
?Goo00<007ooOol027oo00<007ooOol00Goo001:Ool2000_Ool2B]d016JgI[IV]fJf0RVi01P]^DkL
C]a>g5;mC]a>o4kLD_e>g4kmC_a>gDkLC]e>g4KMFUEJEUYEFUI:g4kLB]`2C]`00e;lC_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l@Goo
00<007ooOol01goo00<007ooOol00Goo001<Ool00`00Oomoo`0]Ool0VBiM:UeVef:fI[MR]Rfi:KT]
^D[LC_e:g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eJ=EYFFSEJEUXe001:_4kMB[a>gDkLD_e>g5;mC]aB
oDklD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@16Ool00`00Oomo
o`06Ool00`00Oomoo`01Ool004eoo`03001oogoo02eoo`05I[MV]VJgI[IV]`04B[`3C]`04DkmC]a>
o4klC_e>g4kmC]a6gDJmA]eJEEYFFUEJESiK@W/00dkL00E>oDklD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0BGoo00<007ooOol01goo0@000Goo0Goo001>Ool0
0`00Oomoo`0]Ool0TFJgH[IVegoo0016_4ZmA[a:_4kLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlFUIJ
=EYFFSE2O3iK@W`nFe;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m04eoo`03001oogoo00Ioo`40005oo`5oo`00Cgoo0P00;Goo00IV]VJgOomoobVi;KT3C]`06TkM
C]a>o4kLD_e>g4kmC_aBoDkLC]e>g4KMFUEJEUYEFUIJEDkLB]a>g4[LD_a>o5;mC]`2D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;lDWoo00<007ooOol01Goo0@000Goo0Goo001AOol00`00Oomoo`0_
Ool05BVi;KU:g4kmB]a>gDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a:gEXeFUIJ=@020000KTkMB[a>gDZl
D_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aEOol00`00Oomoo`05Ool10001Ool1Ool0059o
o`03001oogoo02ioo`8Y^@06;KU>g4kLC]a>oDkL0Tkl00]BoDkLC_e>g4kmA[e6gEYEFUIJEEYF00<0
009>g006C_e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;lFGoo00<007ooOol017oo0@000Goo0Goo001C
Ool00`00Oomoo`0^Ool0OTZmA[a:_4JlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlFUIJ=EYFFSEJESiK
@W`nFe;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5eoo`03001oogoo00=oo`40005oo`5oo`00E7oo00<0
07ooOol0;Woo0TkL019>gDkLC_a>g5;mC]a>oDklD_e>g4kMC]a>gDJmFUH005YFFUD2?U/01T9k?U]B
o4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lD_`0HWoo00<007ooOol00goo0@000Goo001EOol2000_Ool0LTkmB]a>gDkLD_e>
g5;mC]aBoDkLD_e:g4kmB]a:gEXeFUIJ=EYF001>gDZlC]e:_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo6Qoo`03001oogoo00=oo`40005oo`00
Egoo00<007ooOol0;7oo0dkL00m>oDkLC_a>o5;mC]a>oDkLC_e6_DKMFUEJEUYEFUH00`0000A>g4[L
C]a>o09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;lK7oo
00<007ooOol00Woo0@000Goo001HOol00`00Oomoo`0/Ool0JTkLD_e>g5;mC]aBoDkLD_e>g5;mC]aB
oDJlB]eJ=EYFFSEJESiK@W`nFe;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mLGoo00D007ooOomoo`00005oo`00FGoo00<007ooOol0;7oo015>g4klC]aBoDkLC_e>
o5;mC]a>gDkLC]e6_EYFFUEJEUYE008nF`06@W/nFe;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lD_`0MGoo00@007ooOol0005oo`00FWoo0P00;Woo065BoDkLD_e>g5;mC]aBoD[L
C_e:g4kmA[aJEUXeFUIJ=DkMB[a>gDZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@1h
Ool01000Oomoo`000Goo001LOol00`00Oomoo`0/Ool2C_`03E;mC]a>oDklD_e6_DKMA[eJEUYEFUIJ
EEYF00800003B]a>g4[L009Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo7aoo`03001oo`00005oo`00
GGoo00<007ooOol0;7oo05UBoDkLD_e>g5;mC]aBoDkLB]e6_5YFFSEJEUXe@W`nFd9lC]aBoDkLD_e>
g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m081oo`40005oo`400000GWoo00<007ooOol0;7oo00A>oDklD_e>g0=>g@08
C]a6gEYEFUIJEEYF?U]2N`8nF`03C_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lQ7oo0P00001OOol2000]Ool0D5;m
C]aBoDkLC_e:g4km00mJEUXeFUIJ=EYFB[a>gDZlC]e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_b8Ool20000065oo`03001oogoo02]o
o`04C_e>o5;mC]`3C]d03DJmFUIJEEYFFUD004[LC]a:g4kLD_aBoDkl009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;lRgoo0P00001ROol00`00Oomoo`0[Ool0
AE;mC]aBoDkLB]e6_5YFFSEJEUXe@W`nFd9lC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@2=Ool40002Ool006=oo`03001oogoo02aoo`0:C]a>oDkLA]e6_EYF
FUEJEUYE@W/2?U/00dkLC_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b<
Ool40006Ool006Aoo`8002eoo`0lB]a>oD[LB]eJ=EYFFSEJETZlC]e:_4kMC]aBoDkLD_e>o5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mRgoo10002Woo001VOol00`00Oomoo`0[Ool2C]d03DkLA]eJEEYF
FUD004[LC]a:g4kLD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lRWoo10003Woo001WOol00`00
Oomoo`0[Ool0=4JlA]eJ=EYFFSEJESiK@Wa>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mRWoo0`00
4Woo001XOol00`00Oomoo`0ZOol02dKMA[eJEUYEFUIJED9k?U]2FciKC_d00TkL00=Bo5;mD_`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
009Bo8Uoo`@001Eoo`00JGoo0P00:goo02e:gDJlFUIJ=EYFFSE>gDZlC]e:_5;mC]aBoDkLD_e>g5;m
C_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_d0R7oo
10006Goo001[Ool00`00Oomoo`0YOol034KMFUEJEUYEFUH004kLB]a>g4[LD_e>o09Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo8Yoo`@001eoo`00K7oo00<007oo
Ool0:7oo02=J=EYFFSEJEWoo@W`nFe;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;l08Uoo`@0025oo`00KGoo00<007ooOol0:7oo00QJEEYFFUEoociK@U/n
Fd9k0dkL00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;lRGoo0`009Goo001^
Ool00`00Oomoo`0WOol00eYFFSEoo`02Ool05dZlC]e:_4kMC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;m
D_aBoE;lD_eBo5;mD_`0R7oo1000:7oo001_Ool2000XOol00eYFOomoo`02Ool01D[LC]a:g5;mC_`0
0U;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_b7Ool4000/Ool0075oo`03001oogoo02Yoo`0@D_e>
g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_b6Ool4000`Ool0079oo`03001oogoo02]oo`=>g005
D_eBo5;lD_aBo@03D_b5Ool4000dOol007=oo`03001oogoo02]oo`04C]aBoDkLD_f7Ool4000hOol0
07Aoo`8002aoo`03001oogoo08Aoo`<003aoo`00MWoo00<007ooOol0:Goo00<007ooOol0P7oo1000
?goo001gOol00`00Oomoo`0XOol00`00Oomoo`1lOol40013Ool007Qoo`03001oogoo02Moo`03001o
ogoo07Qoo`@004Moo`00NGoo0P009goo00<007ooOol0M7oo1000Bgoo001kOol00`00Oomoo`0TOol0
0`00Oomoo`1aOol3001?Ool007aoo`03001oogoo02=oo`03001oogoo06eoo`@0059oo`00OGoo00<0
07ooOol08Woo00<007ooOol0JGoo1000EWoo001nOol2000ROol00`00Oomoo`1UOol4001JOol0081o
o`03001oogoo01moo`03001oogoo065oo`@005ioo`00PGoo00<007ooOol07Woo00<007ooOol0GWoo
0`00HWoo0022Ool00`00Oomoo`0MOol00`00Oomoo`1JOol4001UOol008=oo`03001oogoo01aoo`03
001oogoo05Ioo`@006Uoo`00Q7oo0P0077oo00<007ooOol0DWoo1000KGoo0026Ool00`00Oomoo`0I
Ool00`00Oomoo`1>Ool4001aOol008Moo`03001oogoo01Qoo`03001oogoo04]oo`<007Eoo`00R7oo
00<007ooOol05goo00<007ooOol0Agoo1000N7oo0029Ool2000GOol00`00Oomoo`13Ool4001lOol0
08]oo`03001oogoo01Aoo`03001oogoo03moo`@0081oo`00S7oo00<007ooOol04Woo00<007ooOol0
?7oo1000Q7oo002=Ool00`00Oomoo`0AOol00`00Oomoo`0iOol30028Ool008ioo`80015oo`03001o
ogoo03Eoo`@008]oo`00T7oo00<007ooOol03Woo00<007ooOol0<Goo1000Sgoo002AOol00`00Oomo
o`0=Ool00`00Oomoo`0]Ool4002COol0099oo`03001oogoo00aoo`03001oogoo02Uoo`@009Moo`00
Tgoo0P0037oo00<007ooOol09Goo1000Vgoo002EOol00`00Oomoo`09Ool00`00Oomoo`0ROol3002O
Ool009Ioo`03001oogoo00Qoo`03001oogoo01ioo`@00:9oo`00Ugoo00<007ooOol01goo00<007oo
Ool06Woo1000YWoo002HOol00`00Oomoo`06Ool00`00Oomoo`0FOol4002ZOol009Uoo`8000Ioo`03
001oogoo019oo`@00:ioo`00Vgoo00<007ooOol00goo00<007ooOol03goo0`00/Woo002LOol00`00
Oomoo`02Ool00`00Oomoo`0;Ool4002eOol009eoo`05001oogooOol00009Ool4002iOol009ioo`80
0003Ool007oo00Aoo`@00;eoo`00X7oo0P0000=oo`0000000P00`Goo002QOol20035Ool00?moofUo
o`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003o
OomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.594 .694 .912 r
.39644 .69522 .40173 .70088 .41062 .69901 .40532 .69412 Mtetra
.64 .738 .92 r
.40532 .69412 .41062 .69901 .41957 .69672 .41428 .69195 Mtetra
.649 .746 .92 r
.41428 .69195 .41957 .69672 .42855 .69429 .42328 .68955 Mtetra
.653 .749 .92 r
.42328 .68955 .42855 .69429 .43756 .69177 .4323 .68705 Mtetra
.656 .751 .92 r
.4323 .68705 .43756 .69177 .4466 .6892 .44137 .68449 Mtetra
.658 .753 .92 r
.44137 .68449 .4466 .6892 .45567 .68658 .45046 .68187 Mtetra
.659 .753 .92 r
.45046 .68187 .45567 .68658 .46478 .68395 .45958 .67922 Mtetra
.659 .754 .92 r
.45958 .67922 .46478 .68395 .47391 .68129 .46873 .67656 Mtetra
.46873 .67656 .47391 .68129 .48308 .67863 .47792 .67388 Mtetra
.47792 .67388 .48308 .67863 .49227 .67597 .48713 .6712 Mtetra
.659 .753 .92 r
.48713 .6712 .49227 .67597 .50149 .67331 .49638 .66851 Mtetra
.658 .753 .92 r
.49638 .66851 .50149 .67331 .51075 .67064 .50566 .66583 Mtetra
.50566 .66583 .51075 .67064 .52004 .66797 .51496 .66314 Mtetra
.51496 .66314 .52004 .66797 .52936 .66529 .5243 .66044 Mtetra
.5243 .66044 .52936 .66529 .53871 .66261 .53367 .65774 Mtetra
.53367 .65774 .53871 .66261 .54809 .65992 .54307 .65503 Mtetra
.54307 .65503 .54809 .65992 .5575 .65722 .55251 .65232 Mtetra
.657 .753 .92 r
.55251 .65232 .5575 .65722 .56694 .65452 .56198 .6496 Mtetra
.56198 .6496 .56694 .65452 .57642 .65181 .57147 .64687 Mtetra
.57147 .64687 .57642 .65181 .58593 .64909 .58101 .64413 Mtetra
.657 .752 .92 r
.58101 .64413 .58593 .64909 .59547 .64636 .59057 .64139 Mtetra
.59057 .64139 .59547 .64636 .60505 .64363 .60017 .63863 Mtetra
.60017 .63863 .60505 .64363 .61465 .64088 .60979 .63587 Mtetra
.60979 .63587 .61465 .64088 .62429 .63813 .61946 .6331 Mtetra
.61946 .6331 .62429 .63813 .63397 .63537 .62915 .63032 Mtetra
.62915 .63032 .63397 .63537 .64367 .6326 .63888 .62753 Mtetra
.63888 .62753 .64367 .6326 .65341 .62982 .64865 .62474 Mtetra
.64865 .62474 .65341 .62982 .66319 .62703 .65844 .62193 Mtetra
.65844 .62193 .66319 .62703 .673 .62424 .66827 .61912 Mtetra
.66827 .61912 .673 .62424 .68284 .62143 .67814 .61629 Mtetra
.67814 .61629 .68284 .62143 .69271 .61862 .68804 .61346 Mtetra
.68804 .61346 .69271 .61862 .70262 .61579 .69797 .61062 Mtetra
.69797 .61062 .70262 .61579 .71257 .61296 .70794 .60777 Mtetra
.70794 .60777 .71257 .61296 .72255 .61012 .71795 .6049 Mtetra
.71795 .6049 .72255 .61012 .73256 .60726 .72799 .60203 Mtetra
.72799 .60203 .73256 .60726 .74261 .6044 .73806 .59915 Mtetra
.73806 .59915 .74261 .6044 .7527 .60153 .74817 .59626 Mtetra
.74817 .59626 .7527 .60153 .76282 .59865 .75832 .59336 Mtetra
.75832 .59336 .76282 .59865 .77298 .59576 .7685 .59045 Mtetra
.7685 .59045 .77298 .59576 .78317 .59286 .77872 .58753 Mtetra
.77872 .58753 .78317 .59286 .7934 .58994 .78897 .5846 Mtetra
.78897 .5846 .7934 .58994 .80366 .58702 .79926 .58166 Mtetra
.79926 .58166 .80366 .58702 .81396 .58409 .80959 .57871 Mtetra
.80959 .57871 .81396 .58409 .8243 .58115 .81995 .57575 Mtetra
.81995 .57575 .8243 .58115 .83468 .5782 .83035 .57278 Mtetra
.83035 .57278 .83468 .5782 .84509 .57524 .84079 .5698 Mtetra
.84079 .5698 .84509 .57524 .85554 .57227 .85127 .5668 Mtetra
.85127 .5668 .85554 .57227 .86602 .56928 .86178 .5638 Mtetra
.86178 .5638 .86602 .56928 .87655 .56629 .87234 .56079 Mtetra
.87234 .56079 .87655 .56629 .88711 .56329 .88293 .55777 Mtetra
.88293 .55777 .88711 .56329 .89771 .56027 .89355 .55473 Mtetra
.89355 .55473 .89771 .56027 .90835 .55725 .90422 .55169 Mtetra
.90422 .55169 .90835 .55725 .91903 .55421 .91493 .54863 Mtetra
.91493 .54863 .91903 .55421 .92974 .55117 .92567 .54556 Mtetra
.92567 .54556 .92974 .55117 .9405 .54811 .93645 .54249 Mtetra
.93645 .54249 .9405 .54811 .95129 .54504 .94728 .5394 Mtetra
.94728 .5394 .95129 .54504 .96212 .54196 .95814 .5363 Mtetra
.95814 .5363 .96212 .54196 .973 .53887 .96904 .53319 Mtetra
.96904 .53319 .973 .53887 .98391 .53577 .97999 .53007 Mtetra
.385 .455 .81 r
.3913 .68458 .39644 .69522 .40532 .69412 .4 .689 Mtetra
.628 .727 .918 r
.4 .689 .40532 .69412 .41428 .69195 .40896 .6871 Mtetra
.646 .743 .92 r
.40896 .6871 .41428 .69195 .42328 .68955 .41797 .68477 Mtetra
.652 .748 .92 r
.41797 .68477 .42328 .68955 .4323 .68705 .42702 .68229 Mtetra
.655 .75 .92 r
.42702 .68229 .4323 .68705 .44137 .68449 .4361 .67973 Mtetra
.657 .752 .92 r
.4361 .67973 .44137 .68449 .45046 .68187 .44521 .67712 Mtetra
.658 .753 .92 r
.44521 .67712 .45046 .68187 .45958 .67922 .45435 .67447 Mtetra
.659 .754 .92 r
.45435 .67447 .45958 .67922 .46873 .67656 .46353 .67179 Mtetra
.46353 .67179 .46873 .67656 .47792 .67388 .47273 .66909 Mtetra
.47273 .66909 .47792 .67388 .48713 .6712 .48197 .66639 Mtetra
.48197 .66639 .48713 .6712 .49638 .66851 .49123 .66369 Mtetra
.658 .753 .92 r
.49123 .66369 .49638 .66851 .50566 .66583 .50053 .66098 Mtetra
.50053 .66098 .50566 .66583 .51496 .66314 .50986 .65827 Mtetra
.50986 .65827 .51496 .66314 .5243 .66044 .51922 .65556 Mtetra
.51922 .65556 .5243 .66044 .53367 .65774 .52861 .65284 Mtetra
.52861 .65284 .53367 .65774 .54307 .65503 .53803 .65012 Mtetra
.53803 .65012 .54307 .65503 .55251 .65232 .54749 .64738 Mtetra
.54749 .64738 .55251 .65232 .56198 .6496 .55697 .64464 Mtetra
.657 .753 .92 r
.55697 .64464 .56198 .6496 .57147 .64687 .5665 .6419 Mtetra
.5665 .6419 .57147 .64687 .58101 .64413 .57605 .63914 Mtetra
.57605 .63914 .58101 .64413 .59057 .64139 .58563 .63638 Mtetra
.657 .752 .92 r
.58563 .63638 .59057 .64139 .60017 .63863 .59525 .63361 Mtetra
.59525 .63361 .60017 .63863 .60979 .63587 .6049 .63083 Mtetra
.6049 .63083 .60979 .63587 .61946 .6331 .61459 .62804 Mtetra
.61459 .62804 .61946 .6331 .62915 .63032 .62431 .62524 Mtetra
.62431 .62524 .62915 .63032 .63888 .62753 .63406 .62244 Mtetra
.63406 .62244 .63888 .62753 .64865 .62474 .64385 .61962 Mtetra
.64385 .61962 .64865 .62474 .65844 .62193 .65367 .6168 Mtetra
.65367 .6168 .65844 .62193 .66827 .61912 .66352 .61396 Mtetra
.66352 .61396 .66827 .61912 .67814 .61629 .67341 .61112 Mtetra
.67341 .61112 .67814 .61629 .68804 .61346 .68333 .60827 Mtetra
.68333 .60827 .68804 .61346 .69797 .61062 .69329 .60541 Mtetra
.69329 .60541 .69797 .61062 .70794 .60777 .70329 .60254 Mtetra
.70329 .60254 .70794 .60777 .71795 .6049 .71332 .59966 Mtetra
.71332 .59966 .71795 .6049 .72799 .60203 .72338 .59677 Mtetra
.72338 .59677 .72799 .60203 .73806 .59915 .73348 .59387 Mtetra
.73348 .59387 .73806 .59915 .74817 .59626 .74361 .59096 Mtetra
.74361 .59096 .74817 .59626 .75832 .59336 .75378 .58804 Mtetra
.75378 .58804 .75832 .59336 .7685 .59045 .76399 .58511 Mtetra
.76399 .58511 .7685 .59045 .77872 .58753 .77424 .58217 Mtetra
.77424 .58217 .77872 .58753 .78897 .5846 .78452 .57922 Mtetra
.78452 .57922 .78897 .5846 .79926 .58166 .79483 .57626 Mtetra
.79483 .57626 .79926 .58166 .80959 .57871 .80519 .57329 Mtetra
.80519 .57329 .80959 .57871 .81995 .57575 .81558 .57031 Mtetra
.81558 .57031 .81995 .57575 .83035 .57278 .82601 .56732 Mtetra
.82601 .56732 .83035 .57278 .84079 .5698 .83647 .56432 Mtetra
.83647 .56432 .84079 .5698 .85127 .5668 .84697 .56131 Mtetra
.84697 .56131 .85127 .5668 .86178 .5638 .85752 .55828 Mtetra
.85752 .55828 .86178 .5638 .87234 .56079 .8681 .55525 Mtetra
.8681 .55525 .87234 .56079 .88293 .55777 .87871 .55221 Mtetra
.87871 .55221 .88293 .55777 .89355 .55473 .88937 .54915 Mtetra
.88937 .54915 .89355 .55473 .90422 .55169 .90006 .54609 Mtetra
.90006 .54609 .90422 .55169 .91493 .54863 .9108 .54301 Mtetra
.9108 .54301 .91493 .54863 .92567 .54556 .92157 .53992 Mtetra
.92157 .53992 .92567 .54556 .93645 .54249 .93239 .53682 Mtetra
.93239 .53682 .93645 .54249 .94728 .5394 .94324 .53371 Mtetra
.94324 .53371 .94728 .5394 .95814 .5363 .95413 .53059 Mtetra
.95413 .53059 .95814 .5363 .96904 .53319 .96506 .52746 Mtetra
.96506 .52746 .96904 .53319 .97999 .53007 .97603 .52432 Mtetra
0 0 0 r
.38537 .69371 .3913 .68458 .4 .689 .39466 .68326 Mtetra
.594 .694 .912 r
.39466 .68326 .4 .689 .40896 .6871 .40361 .68212 Mtetra
.64 .738 .92 r
.40361 .68212 .40896 .6871 .41797 .68477 .41264 .67992 Mtetra
.649 .746 .92 r
.41264 .67992 .41797 .68477 .42702 .68229 .4217 .67748 Mtetra
.653 .749 .92 r
.4217 .67748 .42702 .68229 .4361 .67973 .4308 .67494 Mtetra
.656 .751 .92 r
.4308 .67494 .4361 .67973 .44521 .67712 .43993 .67233 Mtetra
.658 .753 .92 r
.43993 .67233 .44521 .67712 .45435 .67447 .44909 .66968 Mtetra
.659 .753 .92 r
.44909 .66968 .45435 .67447 .46353 .67179 .45829 .66699 Mtetra
.659 .754 .92 r
.45829 .66699 .46353 .67179 .47273 .66909 .46751 .66428 Mtetra
.46751 .66428 .47273 .66909 .48197 .66639 .47676 .66156 Mtetra
.47676 .66156 .48197 .66639 .49123 .66369 .48605 .65884 Mtetra
.659 .753 .92 r
.48605 .65884 .49123 .66369 .50053 .66098 .49537 .65611 Mtetra
.658 .753 .92 r
.49537 .65611 .50053 .66098 .50986 .65827 .50472 .65338 Mtetra
.50472 .65338 .50986 .65827 .51922 .65556 .5141 .65065 Mtetra
.5141 .65065 .51922 .65556 .52861 .65284 .52351 .64791 Mtetra
.52351 .64791 .52861 .65284 .53803 .65012 .53296 .64517 Mtetra
.53296 .64517 .53803 .65012 .54749 .64738 .54243 .64242 Mtetra
.54243 .64242 .54749 .64738 .55697 .64464 .55194 .63966 Mtetra
.657 .753 .92 r
.55194 .63966 .55697 .64464 .5665 .6419 .56148 .63689 Mtetra
.56148 .63689 .5665 .6419 .57605 .63914 .57106 .63412 Mtetra
.57106 .63412 .57605 .63914 .58563 .63638 .58067 .63134 Mtetra
.657 .752 .92 r
.58067 .63134 .58563 .63638 .59525 .63361 .59031 .62855 Mtetra
.59031 .62855 .59525 .63361 .6049 .63083 .59998 .62575 Mtetra
.59998 .62575 .6049 .63083 .61459 .62804 .60969 .62295 Mtetra
.60969 .62295 .61459 .62804 .62431 .62524 .61943 .62013 Mtetra
.61943 .62013 .62431 .62524 .63406 .62244 .62921 .61731 Mtetra
.62921 .61731 .63406 .62244 .64385 .61962 .63902 .61447 Mtetra
.63902 .61447 .64385 .61962 .65367 .6168 .64886 .61163 Mtetra
.64886 .61163 .65367 .6168 .66352 .61396 .65874 .60878 Mtetra
.65874 .60878 .66352 .61396 .67341 .61112 .66865 .60592 Mtetra
.66865 .60592 .67341 .61112 .68333 .60827 .6786 .60305 Mtetra
.6786 .60305 .68333 .60827 .69329 .60541 .68858 .60017 Mtetra
.68858 .60017 .69329 .60541 .70329 .60254 .6986 .59728 Mtetra
.6986 .59728 .70329 .60254 .71332 .59966 .70865 .59438 Mtetra
.70865 .59438 .71332 .59966 .72338 .59677 .71874 .59147 Mtetra
.71874 .59147 .72338 .59677 .73348 .59387 .72887 .58855 Mtetra
.72887 .58855 .73348 .59387 .74361 .59096 .73903 .58562 Mtetra
.73903 .58562 .74361 .59096 .75378 .58804 .74922 .58268 Mtetra
.74922 .58268 .75378 .58804 .76399 .58511 .75946 .57973 Mtetra
.75946 .57973 .76399 .58511 .77424 .58217 .76973 .57677 Mtetra
.76973 .57677 .77424 .58217 .78452 .57922 .78003 .5738 Mtetra
.78003 .5738 .78452 .57922 .79483 .57626 .79037 .57082 Mtetra
.79037 .57082 .79483 .57626 .80519 .57329 .80075 .56784 Mtetra
.80075 .56784 .80519 .57329 .81558 .57031 .81117 .56483 Mtetra
.81117 .56483 .81558 .57031 .82601 .56732 .82163 .56182 Mtetra
.82163 .56182 .82601 .56732 .83647 .56432 .83212 .5588 Mtetra
.83212 .5588 .83647 .56432 .84697 .56131 .84265 .55577 Mtetra
.84265 .55577 .84697 .56131 .85752 .55828 .85322 .55273 Mtetra
.85322 .55273 .85752 .55828 .8681 .55525 .86383 .54967 Mtetra
.86383 .54967 .8681 .55525 .87871 .55221 .87447 .54661 Mtetra
.87447 .54661 .87871 .55221 .88937 .54915 .88516 .54354 Mtetra
.88516 .54354 .88937 .54915 .90006 .54609 .89588 .54045 Mtetra
.89588 .54045 .90006 .54609 .9108 .54301 .90664 .53735 Mtetra
.90664 .53735 .9108 .54301 .92157 .53992 .91745 .53424 Mtetra
.91745 .53424 .92157 .53992 .93239 .53682 .92829 .53112 Mtetra
.92829 .53112 .93239 .53682 .94324 .53371 .93917 .52799 Mtetra
.93917 .52799 .94324 .53371 .95413 .53059 .95009 .52485 Mtetra
.95009 .52485 .95413 .53059 .96506 .52746 .96105 .5217 Mtetra
.96105 .5217 .96506 .52746 .97603 .52432 .97206 .51853 Mtetra
.809 .691 .735 r
.38008 .68546 .38537 .69371 .39466 .68326 .38949 .67252 Mtetra
.384 .455 .81 r
.38949 .67252 .39466 .68326 .40361 .68212 .39824 .67693 Mtetra
.628 .727 .918 r
.39824 .67693 .40361 .68212 .41264 .67992 .40727 .67499 Mtetra
.646 .743 .92 r
.40727 .67499 .41264 .67992 .4217 .67748 .41635 .67262 Mtetra
.652 .748 .92 r
.41635 .67262 .4217 .67748 .4308 .67494 .42547 .67011 Mtetra
.655 .75 .92 r
.42547 .67011 .4308 .67494 .43993 .67233 .43462 .66751 Mtetra
.657 .752 .92 r
.43462 .66751 .43993 .67233 .44909 .66968 .4438 .66485 Mtetra
.658 .753 .92 r
.4438 .66485 .44909 .66968 .45829 .66699 .45301 .66216 Mtetra
.659 .754 .92 r
.45301 .66216 .45829 .66699 .46751 .66428 .46226 .65943 Mtetra
.46226 .65943 .46751 .66428 .47676 .66156 .47153 .6567 Mtetra
.47153 .6567 .47676 .66156 .48605 .65884 .48084 .65396 Mtetra
.48084 .65396 .48605 .65884 .49537 .65611 .49018 .65121 Mtetra
.658 .753 .92 r
.49018 .65121 .49537 .65611 .50472 .65338 .49955 .64846 Mtetra
.49955 .64846 .50472 .65338 .5141 .65065 .50895 .64571 Mtetra
.50895 .64571 .5141 .65065 .52351 .64791 .51838 .64295 Mtetra
.51838 .64295 .52351 .64791 .53296 .64517 .52785 .64019 Mtetra
.52785 .64019 .53296 .64517 .54243 .64242 .53735 .63742 Mtetra
.53735 .63742 .54243 .64242 .55194 .63966 .54688 .63464 Mtetra
.54688 .63464 .55194 .63966 .56148 .63689 .55644 .63186 Mtetra
.657 .753 .92 r
.55644 .63186 .56148 .63689 .57106 .63412 .56604 .62907 Mtetra
.56604 .62907 .57106 .63412 .58067 .63134 .57567 .62627 Mtetra
.57567 .62627 .58067 .63134 .59031 .62855 .58533 .62346 Mtetra
.657 .752 .92 r
.58533 .62346 .59031 .62855 .59998 .62575 .59503 .62064 Mtetra
.59503 .62064 .59998 .62575 .60969 .62295 .60476 .61782 Mtetra
.60476 .61782 .60969 .62295 .61943 .62013 .61452 .61498 Mtetra
.61452 .61498 .61943 .62013 .62921 .61731 .62432 .61214 Mtetra
.62432 .61214 .62921 .61731 .63902 .61447 .63416 .60929 Mtetra
.63416 .60929 .63902 .61447 .64886 .61163 .64402 .60643 Mtetra
.64402 .60643 .64886 .61163 .65874 .60878 .65392 .60356 Mtetra
.65392 .60356 .65874 .60878 .66865 .60592 .66386 .60068 Mtetra
.66386 .60068 .66865 .60592 .6786 .60305 .67383 .59779 Mtetra
.67383 .59779 .6786 .60305 .68858 .60017 .68384 .59489 Mtetra
.68384 .59489 .68858 .60017 .6986 .59728 .69388 .59198 Mtetra
.69388 .59198 .6986 .59728 .70865 .59438 .70396 .58906 Mtetra
.70396 .58906 .70865 .59438 .71874 .59147 .71407 .58613 Mtetra
.71407 .58613 .71874 .59147 .72887 .58855 .72422 .5832 Mtetra
.72422 .5832 .72887 .58855 .73903 .58562 .73441 .58025 Mtetra
.73441 .58025 .73903 .58562 .74922 .58268 .74463 .57729 Mtetra
.74463 .57729 .74922 .58268 .75946 .57973 .75489 .57432 Mtetra
.75489 .57432 .75946 .57973 .76973 .57677 .76518 .57134 Mtetra
.76518 .57134 .76973 .57677 .78003 .5738 .77552 .56835 Mtetra
.77552 .56835 .78003 .5738 .79037 .57082 .78589 .56535 Mtetra
.78589 .56535 .79037 .57082 .80075 .56784 .79629 .56234 Mtetra
.79629 .56234 .80075 .56784 .81117 .56483 .80674 .55932 Mtetra
.80674 .55932 .81117 .56483 .82163 .56182 .81722 .55629 Mtetra
.81722 .55629 .82163 .56182 .83212 .5588 .82774 .55325 Mtetra
.82774 .55325 .83212 .5588 .84265 .55577 .8383 .5502 Mtetra
.8383 .5502 .84265 .55577 .85322 .55273 .84889 .54714 Mtetra
.84889 .54714 .85322 .55273 .86383 .54967 .85953 .54406 Mtetra
.85953 .54406 .86383 .54967 .87447 .54661 .8702 .54098 Mtetra
.8702 .54098 .87447 .54661 .88516 .54354 .88092 .53788 Mtetra
.88092 .53788 .88516 .54354 .89588 .54045 .89167 .53477 Mtetra
.89167 .53477 .89588 .54045 .90664 .53735 .90246 .53165 Mtetra
.90246 .53165 .90664 .53735 .91745 .53424 .91329 .52853 Mtetra
.91329 .52853 .91745 .53424 .92829 .53112 .92416 .52538 Mtetra
.92416 .52538 .92829 .53112 .93917 .52799 .93507 .52223 Mtetra
.93507 .52223 .93917 .52799 .95009 .52485 .94603 .51907 Mtetra
.94603 .51907 .95009 .52485 .96105 .5217 .95702 .51589 Mtetra
.95702 .51589 .96105 .5217 .97206 .51853 .96805 .51271 Mtetra
.38 .61 .94 r
.37465 .67985 .38008 .68546 .38949 .67252 .38349 .68164 Mtetra
0 0 0 r
.38349 .68164 .38949 .67252 .39824 .67693 .39286 .67111 Mtetra
.594 .694 .912 r
.39286 .67111 .39824 .67693 .40727 .67499 .40188 .66994 Mtetra
.64 .738 .92 r
.40188 .66994 .40727 .67499 .41635 .67262 .41097 .6677 Mtetra
.649 .746 .92 r
.41097 .6677 .41635 .67262 .42547 .67011 .4201 .66522 Mtetra
.653 .749 .92 r
.4201 .66522 .42547 .67011 .43462 .66751 .42927 .66264 Mtetra
.656 .751 .92 r
.42927 .66264 .43462 .66751 .4438 .66485 .43847 .65999 Mtetra
.658 .753 .92 r
.43847 .65999 .4438 .66485 .45301 .66216 .4477 .65729 Mtetra
.659 .753 .92 r
.4477 .65729 .45301 .66216 .46226 .65943 .45697 .65456 Mtetra
.659 .754 .92 r
.45697 .65456 .46226 .65943 .47153 .6567 .46626 .65181 Mtetra
.46626 .65181 .47153 .6567 .48084 .65396 .47559 .64905 Mtetra
.47559 .64905 .48084 .65396 .49018 .65121 .48495 .64628 Mtetra
.659 .753 .92 r
.48495 .64628 .49018 .65121 .49955 .64846 .49434 .64351 Mtetra
.658 .753 .92 r
.49434 .64351 .49955 .64846 .50895 .64571 .50377 .64074 Mtetra
.50377 .64074 .50895 .64571 .51838 .64295 .51322 .63796 Mtetra
.51322 .63796 .51838 .64295 .52785 .64019 .52271 .63518 Mtetra
.52271 .63518 .52785 .64019 .53735 .63742 .53223 .63239 Mtetra
.53223 .63239 .53735 .63742 .54688 .63464 .54178 .62959 Mtetra
.54178 .62959 .54688 .63464 .55644 .63186 .55137 .62679 Mtetra
.657 .753 .92 r
.55137 .62679 .55644 .63186 .56604 .62907 .56099 .62398 Mtetra
.56099 .62398 .56604 .62907 .57567 .62627 .57064 .62116 Mtetra
.57064 .62116 .57567 .62627 .58533 .62346 .58032 .61834 Mtetra
.657 .752 .92 r
.58032 .61834 .58533 .62346 .59503 .62064 .59004 .6155 Mtetra
.59004 .6155 .59503 .62064 .60476 .61782 .5998 .61266 Mtetra
.5998 .61266 .60476 .61782 .61452 .61498 .60958 .60981 Mtetra
.60958 .60981 .61452 .61498 .62432 .61214 .61941 .60694 Mtetra
.61941 .60694 .62432 .61214 .63416 .60929 .62926 .60407 Mtetra
.62926 .60407 .63416 .60929 .64402 .60643 .63915 .60119 Mtetra
.63915 .60119 .64402 .60643 .65392 .60356 .64908 .5983 Mtetra
.64908 .5983 .65392 .60356 .66386 .60068 .65904 .59541 Mtetra
.65904 .59541 .66386 .60068 .67383 .59779 .66904 .5925 Mtetra
.66904 .5925 .67383 .59779 .68384 .59489 .67907 .58958 Mtetra
.67907 .58958 .68384 .59489 .69388 .59198 .68913 .58665 Mtetra
.68913 .58665 .69388 .59198 .70396 .58906 .69924 .58371 Mtetra
.69924 .58371 .70396 .58906 .71407 .58613 .70937 .58076 Mtetra
.70937 .58076 .71407 .58613 .72422 .5832 .71955 .57781 Mtetra
.71955 .57781 .72422 .5832 .73441 .58025 .72976 .57484 Mtetra
.72976 .57484 .73441 .58025 .74463 .57729 .74001 .57186 Mtetra
.74001 .57186 .74463 .57729 .75489 .57432 .75029 .56887 Mtetra
.75029 .56887 .75489 .57432 .76518 .57134 .76061 .56587 Mtetra
.76061 .56587 .76518 .57134 .77552 .56835 .77097 .56287 Mtetra
.77097 .56287 .77552 .56835 .78589 .56535 .78137 .55985 Mtetra
.78137 .55985 .78589 .56535 .79629 .56234 .7918 .55682 Mtetra
.7918 .55682 .79629 .56234 .80674 .55932 .80227 .55378 Mtetra
.80227 .55378 .80674 .55932 .81722 .55629 .81278 .55072 Mtetra
.81278 .55072 .81722 .55629 .82774 .55325 .82333 .54766 Mtetra
.82333 .54766 .82774 .55325 .8383 .5502 .83392 .54459 Mtetra
.83392 .54459 .8383 .5502 .84889 .54714 .84454 .5415 Mtetra
.84454 .5415 .84889 .54714 .85953 .54406 .8552 .53841 Mtetra
.8552 .53841 .85953 .54406 .8702 .54098 .86591 .5353 Mtetra
.86591 .5353 .8702 .54098 .88092 .53788 .87665 .53219 Mtetra
.87665 .53219 .88092 .53788 .89167 .53477 .88743 .52906 Mtetra
.88743 .52906 .89167 .53477 .90246 .53165 .89825 .52592 Mtetra
.89825 .52592 .90246 .53165 .91329 .52853 .90911 .52277 Mtetra
.90911 .52277 .91329 .52853 .92416 .52538 .92001 .51961 Mtetra
.92001 .51961 .92416 .52538 .93507 .52223 .93095 .51643 Mtetra
.93095 .51643 .93507 .52223 .94603 .51907 .94193 .51325 Mtetra
.94193 .51325 .94603 .51907 .95702 .51589 .95296 .51005 Mtetra
.95296 .51005 .95702 .51589 .96805 .51271 .96402 .50684 Mtetra
.596 .718 .929 r
.36917 .67465 .37465 .67985 .38349 .68164 .37816 .6733 Mtetra
.809 .692 .735 r
.37816 .6733 .38349 .68164 .39286 .67111 .38764 .66027 Mtetra
.383 .454 .81 r
.38764 .66027 .39286 .67111 .40188 .66994 .39645 .66467 Mtetra
.628 .727 .918 r
.39645 .66467 .40188 .66994 .41097 .6677 .40556 .66269 Mtetra
.646 .743 .92 r
.40556 .66269 .41097 .6677 .4201 .66522 .4147 .66028 Mtetra
.652 .748 .92 r
.4147 .66028 .4201 .66522 .42927 .66264 .42389 .65773 Mtetra
.655 .75 .92 r
.42389 .65773 .42927 .66264 .43847 .65999 .43311 .65508 Mtetra
.657 .752 .92 r
.43311 .65508 .43847 .65999 .4477 .65729 .44236 .65239 Mtetra
.658 .753 .92 r
.44236 .65239 .4477 .65729 .45697 .65456 .45165 .64965 Mtetra
.659 .754 .92 r
.45165 .64965 .45697 .65456 .46626 .65181 .46096 .64688 Mtetra
.46096 .64688 .46626 .65181 .47559 .64905 .47031 .6441 Mtetra
.47031 .6441 .47559 .64905 .48495 .64628 .47969 .64132 Mtetra
.47969 .64132 .48495 .64628 .49434 .64351 .48911 .63853 Mtetra
.658 .753 .92 r
.48911 .63853 .49434 .64351 .50377 .64074 .49855 .63573 Mtetra
.49855 .63573 .50377 .64074 .51322 .63796 .50803 .63294 Mtetra
.50803 .63294 .51322 .63796 .52271 .63518 .51753 .63014 Mtetra
.51753 .63014 .52271 .63518 .53223 .63239 .52708 .62733 Mtetra
.52708 .62733 .53223 .63239 .54178 .62959 .53665 .62451 Mtetra
.53665 .62451 .54178 .62959 .55137 .62679 .54626 .62169 Mtetra
.54626 .62169 .55137 .62679 .56099 .62398 .5559 .61886 Mtetra
.657 .753 .92 r
.5559 .61886 .56099 .62398 .57064 .62116 .56557 .61603 Mtetra
.56557 .61603 .57064 .62116 .58032 .61834 .57528 .61318 Mtetra
.57528 .61318 .58032 .61834 .59004 .6155 .58503 .61033 Mtetra
.657 .752 .92 r
.58503 .61033 .59004 .6155 .5998 .61266 .5948 .60747 Mtetra
.5948 .60747 .5998 .61266 .60958 .60981 .60461 .60459 Mtetra
.60461 .60459 .60958 .60981 .61941 .60694 .61446 .60171 Mtetra
.61446 .60171 .61941 .60694 .62926 .60407 .62434 .59882 Mtetra
.62434 .59882 .62926 .60407 .63915 .60119 .63425 .59592 Mtetra
.63425 .59592 .63915 .60119 .64908 .5983 .6442 .59302 Mtetra
.6442 .59302 .64908 .5983 .65904 .59541 .65419 .5901 Mtetra
.65419 .5901 .65904 .59541 .66904 .5925 .66421 .58717 Mtetra
.66421 .58717 .66904 .5925 .67907 .58958 .67426 .58423 Mtetra
.67426 .58423 .67907 .58958 .68913 .58665 .68435 .58128 Mtetra
.68435 .58128 .68913 .58665 .69924 .58371 .69448 .57833 Mtetra
.69448 .57833 .69924 .58371 .70937 .58076 .70464 .57536 Mtetra
.70464 .57536 .70937 .58076 .71955 .57781 .71484 .57238 Mtetra
.71484 .57238 .71955 .57781 .72976 .57484 .72508 .5694 Mtetra
.72508 .5694 .72976 .57484 .74001 .57186 .73535 .5664 Mtetra
.73535 .5664 .74001 .57186 .75029 .56887 .74567 .56339 Mtetra
.74567 .56339 .75029 .56887 .76061 .56587 .75601 .56037 Mtetra
.75601 .56037 .76061 .56587 .77097 .56287 .7664 .55734 Mtetra
.7664 .55734 .77097 .56287 .78137 .55985 .77682 .5543 Mtetra
.77682 .5543 .78137 .55985 .7918 .55682 .78728 .55125 Mtetra
.78728 .55125 .7918 .55682 .80227 .55378 .79778 .54819 Mtetra
.79778 .54819 .80227 .55378 .81278 .55072 .80832 .54512 Mtetra
.80832 .54512 .81278 .55072 .82333 .54766 .81889 .54203 Mtetra
.81889 .54203 .82333 .54766 .83392 .54459 .8295 .53894 Mtetra
.8295 .53894 .83392 .54459 .84454 .5415 .84016 .53584 Mtetra
.84016 .53584 .84454 .5415 .8552 .53841 .85085 .53272 Mtetra
.85085 .53272 .8552 .53841 .86591 .5353 .86158 .52959 Mtetra
.86158 .52959 .86591 .5353 .87665 .53219 .87235 .52645 Mtetra
.87235 .52645 .87665 .53219 .88743 .52906 .88316 .5233 Mtetra
.88316 .5233 .88743 .52906 .89825 .52592 .89401 .52014 Mtetra
.89401 .52014 .89825 .52592 .90911 .52277 .9049 .51697 Mtetra
.9049 .51697 .90911 .52277 .92001 .51961 .91583 .51379 Mtetra
.91583 .51379 .92001 .51961 .93095 .51643 .9268 .51059 Mtetra
.9268 .51059 .93095 .51643 .94193 .51325 .93781 .50738 Mtetra
.93781 .50738 .94193 .51325 .95296 .51005 .94886 .50417 Mtetra
.94886 .50417 .95296 .51005 .96402 .50684 .95996 .50093 Mtetra
.625 .733 .924 r
.36365 .66956 .36917 .67465 .37816 .6733 .37268 .66761 Mtetra
.381 .61 .94 r
.37268 .66761 .37816 .6733 .38764 .66027 .38159 .66938 Mtetra
0 0 0 r
.38159 .66938 .38764 .66027 .39645 .66467 .39102 .65877 Mtetra
.594 .694 .912 r
.39102 .65877 .39645 .66467 .40556 .66269 .40011 .65757 Mtetra
.64 .738 .92 r
.40011 .65757 .40556 .66269 .4147 .66028 .40927 .65528 Mtetra
.649 .746 .92 r
.40927 .65528 .4147 .66028 .42389 .65773 .41848 .65276 Mtetra
.653 .749 .92 r
.41848 .65276 .42389 .65773 .43311 .65508 .42772 .65014 Mtetra
.656 .751 .92 r
.42772 .65014 .43311 .65508 .44236 .65239 .43699 .64744 Mtetra
.658 .753 .92 r
.43699 .64744 .44236 .65239 .45165 .64965 .44629 .6447 Mtetra
.659 .753 .92 r
.44629 .6447 .45165 .64965 .46096 .64688 .45563 .64193 Mtetra
.659 .754 .92 r
.45563 .64193 .46096 .64688 .47031 .6441 .465 .63913 Mtetra
.465 .63913 .47031 .6441 .47969 .64132 .4744 .63633 Mtetra
.4744 .63633 .47969 .64132 .48911 .63853 .48383 .63352 Mtetra
.659 .753 .92 r
.48383 .63352 .48911 .63853 .49855 .63573 .4933 .6307 Mtetra
.658 .753 .92 r
.4933 .6307 .49855 .63573 .50803 .63294 .5028 .62788 Mtetra
.5028 .62788 .50803 .63294 .51753 .63014 .51233 .62506 Mtetra
.51233 .62506 .51753 .63014 .52708 .62733 .52189 .62224 Mtetra
.52189 .62224 .52708 .62733 .53665 .62451 .53149 .6194 Mtetra
.53149 .6194 .53665 .62451 .54626 .62169 .54112 .61656 Mtetra
.54112 .61656 .54626 .62169 .5559 .61886 .55078 .61371 Mtetra
.657 .753 .92 r
.55078 .61371 .5559 .61886 .56557 .61603 .56048 .61086 Mtetra
.56048 .61086 .56557 .61603 .57528 .61318 .57021 .60799 Mtetra
.57021 .60799 .57528 .61318 .58503 .61033 .57997 .60512 Mtetra
.657 .752 .92 r
.57997 .60512 .58503 .61033 .5948 .60747 .58977 .60224 Mtetra
.58977 .60224 .5948 .60747 .60461 .60459 .59961 .59935 Mtetra
.59961 .59935 .60461 .60459 .61446 .60171 .60948 .59645 Mtetra
.60948 .59645 .61446 .60171 .62434 .59882 .61938 .59354 Mtetra
.61938 .59354 .62434 .59882 .63425 .59592 .62932 .59062 Mtetra
.62932 .59062 .63425 .59592 .6442 .59302 .63929 .58769 Mtetra
.63929 .58769 .6442 .59302 .65419 .5901 .6493 .58476 Mtetra
.6493 .58476 .65419 .5901 .66421 .58717 .65935 .58181 Mtetra
.65935 .58181 .66421 .58717 .67426 .58423 .66943 .57885 Mtetra
.66943 .57885 .67426 .58423 .68435 .58128 .67954 .57588 Mtetra
.67954 .57588 .68435 .58128 .69448 .57833 .68969 .57291 Mtetra
.68969 .57291 .69448 .57833 .70464 .57536 .69988 .56992 Mtetra
.69988 .56992 .70464 .57536 .71484 .57238 .71011 .56692 Mtetra
.71011 .56692 .71484 .57238 .72508 .5694 .72037 .56391 Mtetra
.72037 .56391 .72508 .5694 .73535 .5664 .73067 .5609 Mtetra
.73067 .5609 .73535 .5664 .74567 .56339 .74101 .55787 Mtetra
.74101 .55787 .74567 .56339 .75601 .56037 .75138 .55483 Mtetra
.75138 .55483 .75601 .56037 .7664 .55734 .76179 .55178 Mtetra
.76179 .55178 .7664 .55734 .77682 .5543 .77224 .54872 Mtetra
.77224 .54872 .77682 .5543 .78728 .55125 .78273 .54565 Mtetra
.78273 .54565 .78728 .55125 .79778 .54819 .79325 .54257 Mtetra
.79325 .54257 .79778 .54819 .80832 .54512 .80382 .53947 Mtetra
.80382 .53947 .80832 .54512 .81889 .54203 .81442 .53637 Mtetra
.81442 .53637 .81889 .54203 .8295 .53894 .82506 .53325 Mtetra
.82506 .53325 .8295 .53894 .84016 .53584 .83574 .53013 Mtetra
.83574 .53013 .84016 .53584 .85085 .53272 .84646 .52699 Mtetra
.84646 .52699 .85085 .53272 .86158 .52959 .85722 .52384 Mtetra
.85722 .52384 .86158 .52959 .87235 .52645 .86802 .52068 Mtetra
.86802 .52068 .87235 .52645 .88316 .5233 .87886 .51751 Mtetra
.87886 .51751 .88316 .5233 .89401 .52014 .88974 .51433 Mtetra
.88974 .51433 .89401 .52014 .9049 .51697 .90066 .51113 Mtetra
.90066 .51113 .9049 .51697 .91583 .51379 .91162 .50793 Mtetra
.91162 .50793 .91583 .51379 .9268 .51059 .92262 .50471 Mtetra
.92262 .50471 .9268 .51059 .93781 .50738 .93366 .50148 Mtetra
.93366 .50148 .93781 .50738 .94886 .50417 .94474 .49824 Mtetra
.94474 .49824 .94886 .50417 .95996 .50093 .95587 .49499 Mtetra
.635 .738 .923 r
.3581 .6645 .36365 .66956 .37268 .66761 .36715 .66233 Mtetra
.596 .718 .929 r
.36715 .66233 .37268 .66761 .38159 .66938 .3762 .66094 Mtetra
.81 .693 .736 r
.3762 .66094 .38159 .66938 .39102 .65877 .38576 .64782 Mtetra
.382 .453 .81 r
.38576 .64782 .39102 .65877 .40011 .65757 .39464 .65221 Mtetra
.628 .727 .918 r
.39464 .65221 .40011 .65757 .40927 .65528 .40381 .6502 Mtetra
.646 .743 .92 r
.40381 .6502 .40927 .65528 .41848 .65276 .41303 .64774 Mtetra
.652 .748 .92 r
.41303 .64774 .41848 .65276 .42772 .65014 .42229 .64514 Mtetra
.655 .75 .92 r
.42229 .64514 .42772 .65014 .43699 .64744 .43158 .64246 Mtetra
.657 .752 .92 r
.43158 .64246 .43699 .64744 .44629 .6447 .4409 .63972 Mtetra
.658 .753 .92 r
.4409 .63972 .44629 .6447 .45563 .64193 .45026 .63694 Mtetra
.659 .754 .92 r
.45026 .63694 .45563 .64193 .465 .63913 .45965 .63413 Mtetra
.45965 .63413 .465 .63913 .4744 .63633 .46907 .6313 Mtetra
.46907 .6313 .4744 .63633 .48383 .63352 .47853 .62847 Mtetra
.47853 .62847 .48383 .63352 .4933 .6307 .48802 .62564 Mtetra
.658 .753 .92 r
.48802 .62564 .4933 .6307 .5028 .62788 .49754 .6228 Mtetra
.49754 .6228 .5028 .62788 .51233 .62506 .50709 .61996 Mtetra
.50709 .61996 .51233 .62506 .52189 .62224 .51667 .61711 Mtetra
.51667 .61711 .52189 .62224 .53149 .6194 .52629 .61426 Mtetra
.52629 .61426 .53149 .6194 .54112 .61656 .53594 .6114 Mtetra
.53594 .6114 .54112 .61656 .55078 .61371 .54563 .60853 Mtetra
.54563 .60853 .55078 .61371 .56048 .61086 .55535 .60566 Mtetra
.657 .753 .92 r
.55535 .60566 .56048 .61086 .57021 .60799 .5651 .60277 Mtetra
.5651 .60277 .57021 .60799 .57997 .60512 .57489 .59988 Mtetra
.57489 .59988 .57997 .60512 .58977 .60224 .58471 .59698 Mtetra
.657 .752 .92 r
.58471 .59698 .58977 .60224 .59961 .59935 .59457 .59407 Mtetra
.59457 .59407 .59961 .59935 .60948 .59645 .60446 .59115 Mtetra
.60446 .59115 .60948 .59645 .61938 .59354 .61439 .58822 Mtetra
.61439 .58822 .61938 .59354 .62932 .59062 .62435 .58528 Mtetra
.62435 .58528 .62932 .59062 .63929 .58769 .63435 .58234 Mtetra
.63435 .58234 .63929 .58769 .6493 .58476 .64438 .57938 Mtetra
.64438 .57938 .6493 .58476 .65935 .58181 .65445 .57641 Mtetra
.65445 .57641 .65935 .58181 .66943 .57885 .66456 .57343 Mtetra
.66456 .57343 .66943 .57885 .67954 .57588 .6747 .57045 Mtetra
.6747 .57045 .67954 .57588 .68969 .57291 .68488 .56745 Mtetra
.68488 .56745 .68969 .57291 .69988 .56992 .69509 .56444 Mtetra
.69509 .56444 .69988 .56992 .71011 .56692 .70534 .56143 Mtetra
.70534 .56143 .71011 .56692 .72037 .56391 .71563 .5584 Mtetra
.71563 .5584 .72037 .56391 .73067 .5609 .72595 .55536 Mtetra
.72595 .55536 .73067 .5609 .74101 .55787 .73632 .55231 Mtetra
.73632 .55231 .74101 .55787 .75138 .55483 .74672 .54925 Mtetra
.74672 .54925 .75138 .55483 .76179 .55178 .75716 .54618 Mtetra
.75716 .54618 .76179 .55178 .77224 .54872 .76763 .5431 Mtetra
.76763 .5431 .77224 .54872 .78273 .54565 .77815 .54001 Mtetra
.77815 .54001 .78273 .54565 .79325 .54257 .7887 .5369 Mtetra
.7887 .5369 .79325 .54257 .80382 .53947 .79929 .53379 Mtetra
.79929 .53379 .80382 .53947 .81442 .53637 .80992 .53067 Mtetra
.80992 .53067 .81442 .53637 .82506 .53325 .82059 .52753 Mtetra
.82059 .52753 .82506 .53325 .83574 .53013 .8313 .52438 Mtetra
.8313 .52438 .83574 .53013 .84646 .52699 .84205 .52122 Mtetra
.84205 .52122 .84646 .52699 .85722 .52384 .85283 .51805 Mtetra
.85283 .51805 .85722 .52384 .86802 .52068 .86366 .51487 Mtetra
.86366 .51487 .86802 .52068 .87886 .51751 .87453 .51168 Mtetra
.87453 .51168 .87886 .51751 .88974 .51433 .88544 .50847 Mtetra
.88544 .50847 .88974 .51433 .90066 .51113 .89639 .50526 Mtetra
.89639 .50526 .90066 .51113 .91162 .50793 .90738 .50203 Mtetra
.90738 .50203 .91162 .50793 .92262 .50471 .91841 .49879 Mtetra
.91841 .49879 .92262 .50471 .93366 .50148 .92948 .49554 Mtetra
.92948 .49554 .93366 .50148 .94474 .49824 .9406 .49227 Mtetra
.9406 .49227 .94474 .49824 .95587 .49499 .95175 .489 Mtetra
.639 .74 .922 r
.3525 .65943 .3581 .6645 .36715 .66233 .36158 .65716 Mtetra
.625 .733 .924 r
.36158 .65716 .36715 .66233 .3762 .66094 .37067 .65517 Mtetra
.382 .611 .94 r
.37067 .65517 .3762 .66094 .38576 .64782 .37965 .65692 Mtetra
0 0 0 r
.37965 .65692 .38576 .64782 .39464 .65221 .38916 .64623 Mtetra
.594 .694 .912 r
.38916 .64623 .39464 .65221 .40381 .6502 .39832 .64499 Mtetra
.64 .738 .92 r
.39832 .64499 .40381 .6502 .41303 .64774 .40755 .64266 Mtetra
.649 .746 .92 r
.40755 .64266 .41303 .64774 .42229 .64514 .41683 .6401 Mtetra
.653 .749 .92 r
.41683 .6401 .42229 .64514 .43158 .64246 .42614 .63743 Mtetra
.656 .751 .92 r
.42614 .63743 .43158 .64246 .4409 .63972 .43548 .6347 Mtetra
.658 .753 .92 r
.43548 .6347 .4409 .63972 .45026 .63694 .44486 .63191 Mtetra
.659 .753 .92 r
.44486 .63191 .45026 .63694 .45965 .63413 .45427 .62909 Mtetra
.659 .754 .92 r
.45427 .62909 .45965 .63413 .46907 .6313 .46371 .62625 Mtetra
.46371 .62625 .46907 .6313 .47853 .62847 .47319 .6234 Mtetra
.47319 .6234 .47853 .62847 .48802 .62564 .4827 .62054 Mtetra
.659 .753 .92 r
.4827 .62054 .48802 .62564 .49754 .6228 .49224 .61768 Mtetra
.658 .753 .92 r
.49224 .61768 .49754 .6228 .50709 .61996 .50181 .61482 Mtetra
.50181 .61482 .50709 .61996 .51667 .61711 .51142 .61195 Mtetra
.51142 .61195 .51667 .61711 .52629 .61426 .52106 .60908 Mtetra
.52106 .60908 .52629 .61426 .53594 .6114 .53074 .6062 Mtetra
.53074 .6062 .53594 .6114 .54563 .60853 .54044 .60331 Mtetra
.54044 .60331 .54563 .60853 .55535 .60566 .55019 .60042 Mtetra
.657 .753 .92 r
.55019 .60042 .55535 .60566 .5651 .60277 .55996 .59752 Mtetra
.55996 .59752 .5651 .60277 .57489 .59988 .56977 .5946 Mtetra
.56977 .5946 .57489 .59988 .58471 .59698 .57962 .59168 Mtetra
.657 .752 .92 r
.57962 .59168 .58471 .59698 .59457 .59407 .5895 .58875 Mtetra
.5895 .58875 .59457 .59407 .60446 .59115 .59942 .58582 Mtetra
.59942 .58582 .60446 .59115 .61439 .58822 .60937 .58287 Mtetra
.60937 .58287 .61439 .58822 .62435 .58528 .61935 .57991 Mtetra
.61935 .57991 .62435 .58528 .63435 .58234 .62938 .57694 Mtetra
.62938 .57694 .63435 .58234 .64438 .57938 .63943 .57397 Mtetra
.63943 .57397 .64438 .57938 .65445 .57641 .64953 .57098 Mtetra
.64953 .57098 .65445 .57641 .66456 .57343 .65966 .56798 Mtetra
.65966 .56798 .66456 .57343 .6747 .57045 .66982 .56497 Mtetra
.66982 .56497 .6747 .57045 .68488 .56745 .68003 .56196 Mtetra
.68003 .56196 .68488 .56745 .69509 .56444 .69026 .55893 Mtetra
.69026 .55893 .69509 .56444 .70534 .56143 .70054 .55589 Mtetra
.70054 .55589 .70534 .56143 .71563 .5584 .71086 .55284 Mtetra
.71086 .55284 .71563 .5584 .72595 .55536 .72121 .54978 Mtetra
.72121 .54978 .72595 .55536 .73632 .55231 .7316 .54672 Mtetra
.7316 .54672 .73632 .55231 .74672 .54925 .74202 .54363 Mtetra
.74202 .54363 .74672 .54925 .75716 .54618 .75249 .54054 Mtetra
.75249 .54054 .75716 .54618 .76763 .5431 .76299 .53744 Mtetra
.76299 .53744 .76763 .5431 .77815 .54001 .77353 .53433 Mtetra
.77353 .53433 .77815 .54001 .7887 .5369 .78411 .5312 Mtetra
.78411 .5312 .7887 .5369 .79929 .53379 .79473 .52807 Mtetra
.79473 .52807 .79929 .53379 .80992 .53067 .80539 .52492 Mtetra
.80539 .52492 .80992 .53067 .82059 .52753 .81609 .52177 Mtetra
.81609 .52177 .82059 .52753 .8313 .52438 .82682 .5186 Mtetra
.82682 .5186 .8313 .52438 .84205 .52122 .8376 .51542 Mtetra
.8376 .51542 .84205 .52122 .85283 .51805 .84842 .51222 Mtetra
.84842 .51222 .85283 .51805 .86366 .51487 .85927 .50902 Mtetra
.85927 .50902 .86366 .51487 .87453 .51168 .87017 .50581 Mtetra
.87017 .50581 .87453 .51168 .88544 .50847 .88111 .50258 Mtetra
.88111 .50258 .88544 .50847 .89639 .50526 .89209 .49934 Mtetra
.89209 .49934 .89639 .50526 .90738 .50203 .90311 .49609 Mtetra
.90311 .49609 .90738 .50203 .91841 .49879 .91417 .49283 Mtetra
.91417 .49283 .91841 .49879 .92948 .49554 .92527 .48955 Mtetra
.92527 .48955 .92948 .49554 .9406 .49227 .93642 .48627 Mtetra
.93642 .48627 .9406 .49227 .95175 .489 .94761 .48297 Mtetra
.64 .74 .921 r
.34688 .65433 .3525 .65943 .36158 .65716 .35597 .65202 Mtetra
.635 .738 .923 r
.35597 .65202 .36158 .65716 .37067 .65517 .36509 .64981 Mtetra
.597 .718 .929 r
.36509 .64981 .37067 .65517 .37965 .65692 .37421 .64839 Mtetra
.81 .693 .736 r
.37421 .64839 .37965 .65692 .38916 .64623 .38385 .63518 Mtetra
.38 .453 .81 r
.38385 .63518 .38916 .64623 .39832 .64499 .3928 .63956 Mtetra
.628 .727 .919 r
.3928 .63956 .39832 .64499 .40755 .64266 .40204 .6375 Mtetra
.646 .743 .92 r
.40204 .6375 .40755 .64266 .41683 .6401 .41133 .635 Mtetra
.652 .748 .92 r
.41133 .635 .41683 .6401 .42614 .63743 .42066 .63236 Mtetra
.655 .75 .92 r
.42066 .63236 .42614 .63743 .43548 .6347 .43002 .62963 Mtetra
.657 .752 .92 r
.43002 .62963 .43548 .6347 .44486 .63191 .43942 .62685 Mtetra
.658 .753 .92 r
.43942 .62685 .44486 .63191 .45427 .62909 .44885 .62402 Mtetra
.659 .754 .92 r
.44885 .62402 .45427 .62909 .46371 .62625 .45832 .62116 Mtetra
.45832 .62116 .46371 .62625 .47319 .6234 .46782 .61829 Mtetra
.46782 .61829 .47319 .6234 .4827 .62054 .47735 .61542 Mtetra
.47735 .61542 .4827 .62054 .49224 .61768 .48691 .61254 Mtetra
.658 .753 .92 r
.48691 .61254 .49224 .61768 .50181 .61482 .4965 .60965 Mtetra
.4965 .60965 .50181 .61482 .51142 .61195 .50613 .60676 Mtetra
.50613 .60676 .51142 .61195 .52106 .60908 .5158 .60387 Mtetra
.5158 .60387 .52106 .60908 .53074 .6062 .52549 .60097 Mtetra
.52549 .60097 .53074 .6062 .54044 .60331 .53522 .59806 Mtetra
.53522 .59806 .54044 .60331 .55019 .60042 .54499 .59515 Mtetra
.54499 .59515 .55019 .60042 .55996 .59752 .55479 .59223 Mtetra
.657 .753 .92 r
.55479 .59223 .55996 .59752 .56977 .5946 .56462 .58929 Mtetra
.56462 .58929 .56977 .5946 .57962 .59168 .57449 .58635 Mtetra
.57449 .58635 .57962 .59168 .5895 .58875 .5844 .58341 Mtetra
.657 .752 .92 r
.5844 .58341 .5895 .58875 .59942 .58582 .59434 .58045 Mtetra
.59434 .58045 .59942 .58582 .60937 .58287 .60431 .57748 Mtetra
.60431 .57748 .60937 .58287 .61935 .57991 .61432 .5745 Mtetra
.61432 .5745 .61935 .57991 .62938 .57694 .62437 .57151 Mtetra
.62437 .57151 .62938 .57694 .63943 .57397 .63445 .56852 Mtetra
.63445 .56852 .63943 .57397 .64953 .57098 .64457 .56551 Mtetra
.64457 .56551 .64953 .57098 .65966 .56798 .65472 .56249 Mtetra
.65472 .56249 .65966 .56798 .66982 .56497 .66491 .55947 Mtetra
.66491 .55947 .66982 .56497 .68003 .56196 .67514 .55643 Mtetra
.67514 .55643 .68003 .56196 .69026 .55893 .68541 .55338 Mtetra
.68541 .55338 .69026 .55893 .70054 .55589 .69571 .55032 Mtetra
.69571 .55032 .70054 .55589 .71086 .55284 .70605 .54725 Mtetra
.70605 .54725 .71086 .55284 .72121 .54978 .71643 .54417 Mtetra
.71643 .54417 .72121 .54978 .7316 .54672 .72684 .54108 Mtetra
.72684 .54108 .7316 .54672 .74202 .54363 .7373 .53798 Mtetra
.7373 .53798 .74202 .54363 .75249 .54054 .74779 .53487 Mtetra
.74779 .53487 .75249 .54054 .76299 .53744 .75832 .53175 Mtetra
.75832 .53175 .76299 .53744 .77353 .53433 .76889 .52861 Mtetra
.76889 .52861 .77353 .53433 .78411 .5312 .77949 .52547 Mtetra
.77949 .52547 .78411 .5312 .79473 .52807 .79014 .52231 Mtetra
.79014 .52231 .79473 .52807 .80539 .52492 .80083 .51914 Mtetra
.80083 .51914 .80539 .52492 .81609 .52177 .81155 .51596 Mtetra
.81155 .51596 .81609 .52177 .82682 .5186 .82232 .51277 Mtetra
.82232 .51277 .82682 .5186 .8376 .51542 .83312 .50957 Mtetra
.83312 .50957 .8376 .51542 .84842 .51222 .84397 .50636 Mtetra
.84397 .50636 .84842 .51222 .85927 .50902 .85486 .50313 Mtetra
.85486 .50313 .85927 .50902 .87017 .50581 .86578 .49989 Mtetra
.86578 .49989 .87017 .50581 .88111 .50258 .87675 .49664 Mtetra
.87675 .49664 .88111 .50258 .89209 .49934 .88776 .49338 Mtetra
.88776 .49338 .89209 .49934 .90311 .49609 .89881 .49011 Mtetra
.89881 .49011 .90311 .49609 .91417 .49283 .9099 .48682 Mtetra
.9099 .48682 .91417 .49283 .92527 .48955 .92104 .48353 Mtetra
.92104 .48353 .92527 .48955 .93642 .48627 .93221 .48022 Mtetra
.93221 .48022 .93642 .48627 .94761 .48297 .94343 .47689 Mtetra
.639 .739 .921 r
.34122 .64918 .34688 .65433 .35597 .65202 .35033 .64687 Mtetra
.639 .74 .922 r
.35033 .64687 .35597 .65202 .36509 .64981 .35947 .64456 Mtetra
.625 .733 .924 r
.35947 .64456 .36509 .64981 .37421 .64839 .36864 .64253 Mtetra
.383 .611 .94 r
.36864 .64253 .37421 .64839 .38385 .63518 .37768 .64425 Mtetra
0 0 0 r
.37768 .64425 .38385 .63518 .3928 .63956 .38727 .63349 Mtetra
.594 .694 .912 r
.38727 .63349 .3928 .63956 .40204 .6375 .3965 .63221 Mtetra
.64 .738 .92 r
.3965 .63221 .40204 .6375 .41133 .635 .4058 .62984 Mtetra
.649 .746 .92 r
.4058 .62984 .41133 .635 .42066 .63236 .41515 .62723 Mtetra
.653 .749 .92 r
.41515 .62723 .42066 .63236 .43002 .62963 .42453 .62452 Mtetra
.656 .751 .92 r
.42453 .62452 .43002 .62963 .43942 .62685 .43395 .62174 Mtetra
.658 .753 .92 r
.43395 .62174 .43942 .62685 .44885 .62402 .4434 .61891 Mtetra
.659 .753 .92 r
.4434 .61891 .44885 .62402 .45832 .62116 .45289 .61604 Mtetra
.659 .754 .92 r
.45289 .61604 .45832 .62116 .46782 .61829 .46241 .61316 Mtetra
.46241 .61316 .46782 .61829 .47735 .61542 .47196 .61026 Mtetra
.47196 .61026 .47735 .61542 .48691 .61254 .48154 .60736 Mtetra
.659 .753 .92 r
.48154 .60736 .48691 .61254 .4965 .60965 .49116 .60445 Mtetra
.658 .753 .92 r
.49116 .60445 .4965 .60965 .50613 .60676 .50081 .60154 Mtetra
.50081 .60154 .50613 .60676 .5158 .60387 .5105 .59863 Mtetra
.5105 .59863 .5158 .60387 .52549 .60097 .52022 .59571 Mtetra
.52022 .59571 .52549 .60097 .53522 .59806 .52997 .59278 Mtetra
.52997 .59278 .53522 .59806 .54499 .59515 .53976 .58984 Mtetra
.53976 .58984 .54499 .59515 .55479 .59223 .54958 .5869 Mtetra
.657 .753 .92 r
.54958 .5869 .55479 .59223 .56462 .58929 .55944 .58395 Mtetra
.55944 .58395 .56462 .58929 .57449 .58635 .56933 .58099 Mtetra
.56933 .58099 .57449 .58635 .5844 .58341 .57926 .57802 Mtetra
.657 .752 .92 r
.57926 .57802 .5844 .58341 .59434 .58045 .58922 .57504 Mtetra
.58922 .57504 .59434 .58045 .60431 .57748 .59922 .57205 Mtetra
.59922 .57205 .60431 .57748 .61432 .5745 .60926 .56906 Mtetra
.60926 .56906 .61432 .5745 .62437 .57151 .61933 .56605 Mtetra
.61933 .56605 .62437 .57151 .63445 .56852 .62943 .56303 Mtetra
.62943 .56303 .63445 .56852 .64457 .56551 .63958 .56 Mtetra
.63958 .56 .64457 .56551 .65472 .56249 .64976 .55697 Mtetra
.64976 .55697 .65472 .56249 .66491 .55947 .65997 .55392 Mtetra
.65997 .55392 .66491 .55947 .67514 .55643 .67023 .55086 Mtetra
.67023 .55086 .67514 .55643 .68541 .55338 .68052 .54779 Mtetra
.68052 .54779 .68541 .55338 .69571 .55032 .69085 .54471 Mtetra
.69085 .54471 .69571 .55032 .70605 .54725 .70121 .54162 Mtetra
.70121 .54162 .70605 .54725 .71643 .54417 .71161 .53852 Mtetra
.71161 .53852 .71643 .54417 .72684 .54108 .72206 .53541 Mtetra
.72206 .53541 .72684 .54108 .7373 .53798 .73254 .53229 Mtetra
.73254 .53229 .7373 .53798 .74779 .53487 .74306 .52916 Mtetra
.74306 .52916 .74779 .53487 .75832 .53175 .75361 .52601 Mtetra
.75361 .52601 .75832 .53175 .76889 .52861 .76421 .52286 Mtetra
.76421 .52286 .76889 .52861 .77949 .52547 .77484 .51969 Mtetra
.77484 .51969 .77949 .52547 .79014 .52231 .78552 .51651 Mtetra
.78552 .51651 .79014 .52231 .80083 .51914 .79623 .51332 Mtetra
.79623 .51332 .80083 .51914 .81155 .51596 .80699 .51012 Mtetra
.80699 .51012 .81155 .51596 .82232 .51277 .81778 .50691 Mtetra
.81778 .50691 .82232 .51277 .83312 .50957 .82862 .50368 Mtetra
.82862 .50368 .83312 .50957 .84397 .50636 .83949 .50045 Mtetra
.83949 .50045 .84397 .50636 .85486 .50313 .85041 .4972 Mtetra
.85041 .4972 .85486 .50313 .86578 .49989 .86136 .49394 Mtetra
.86136 .49394 .86578 .49989 .87675 .49664 .87236 .49067 Mtetra
.87236 .49067 .87675 .49664 .88776 .49338 .8834 .48738 Mtetra
.8834 .48738 .88776 .49338 .89881 .49011 .89448 .48409 Mtetra
.89448 .48409 .89881 .49011 .9099 .48682 .9056 .48078 Mtetra
.9056 .48078 .9099 .48682 .92104 .48353 .91677 .47746 Mtetra
.91677 .47746 .92104 .48353 .93221 .48022 .92798 .47412 Mtetra
.92798 .47412 .93221 .48022 .94343 .47689 .93923 .47078 Mtetra
.636 .737 .921 r
.33552 .64395 .34122 .64918 .35033 .64687 .34465 .64169 Mtetra
.64 .74 .921 r
.34465 .64169 .35033 .64687 .35947 .64456 .35381 .63934 Mtetra
.635 .738 .923 r
.35381 .63934 .35947 .64456 .36864 .64253 .363 .63708 Mtetra
.597 .718 .929 r
.363 .63708 .36864 .64253 .37768 .64425 .37219 .63563 Mtetra
.811 .694 .736 r
.37219 .63563 .37768 .64425 .38727 .63349 .38191 .62232 Mtetra
.379 .452 .81 r
.38191 .62232 .38727 .63349 .3965 .63221 .39092 .62669 Mtetra
.628 .727 .919 r
.39092 .62669 .3965 .63221 .4058 .62984 .40024 .62459 Mtetra
.646 .743 .92 r
.40024 .62459 .4058 .62984 .41515 .62723 .4096 .62205 Mtetra
.652 .748 .92 r
.4096 .62205 .41515 .62723 .42453 .62452 .41901 .61936 Mtetra
.655 .75 .92 r
.41901 .61936 .42453 .62452 .43395 .62174 .42844 .61659 Mtetra
.657 .752 .92 r
.42844 .61659 .43395 .62174 .4434 .61891 .43792 .61376 Mtetra
.658 .753 .92 r
.43792 .61376 .4434 .61891 .45289 .61604 .44742 .61089 Mtetra
.659 .754 .92 r
.44742 .61089 .45289 .61604 .46241 .61316 .45696 .60799 Mtetra
.45696 .60799 .46241 .61316 .47196 .61026 .46654 .60507 Mtetra
.46654 .60507 .47196 .61026 .48154 .60736 .47614 .60215 Mtetra
.47614 .60215 .48154 .60736 .49116 .60445 .48578 .59922 Mtetra
.658 .753 .92 r
.48578 .59922 .49116 .60445 .50081 .60154 .49546 .59629 Mtetra
.49546 .59629 .50081 .60154 .5105 .59863 .50516 .59335 Mtetra
.50516 .59335 .5105 .59863 .52022 .59571 .51491 .59041 Mtetra
.51491 .59041 .52022 .59571 .52997 .59278 .52468 .58746 Mtetra
.52468 .58746 .52997 .59278 .53976 .58984 .53449 .58451 Mtetra
.53449 .58451 .53976 .58984 .54958 .5869 .54434 .58154 Mtetra
.54434 .58154 .54958 .5869 .55944 .58395 .55422 .57857 Mtetra
.657 .753 .92 r
.55422 .57857 .55944 .58395 .56933 .58099 .56414 .57559 Mtetra
.56414 .57559 .56933 .58099 .57926 .57802 .57409 .5726 Mtetra
.57409 .5726 .57926 .57802 .58922 .57504 .58407 .5696 Mtetra
.657 .752 .92 r
.58407 .5696 .58922 .57504 .59922 .57205 .5941 .56659 Mtetra
.5941 .56659 .59922 .57205 .60926 .56906 .60416 .56358 Mtetra
.60416 .56358 .60926 .56906 .61933 .56605 .61425 .56055 Mtetra
.61425 .56055 .61933 .56605 .62943 .56303 .62438 .55751 Mtetra
.62438 .55751 .62943 .56303 .63958 .56 .63455 .55446 Mtetra
.63455 .55446 .63958 .56 .64976 .55697 .64476 .5514 Mtetra
.64476 .5514 .64976 .55697 .65997 .55392 .655 .54834 Mtetra
.655 .54834 .65997 .55392 .67023 .55086 .66528 .54526 Mtetra
.66528 .54526 .67023 .55086 .68052 .54779 .67559 .54217 Mtetra
.67559 .54217 .68052 .54779 .69085 .54471 .68595 .53907 Mtetra
.68595 .53907 .69085 .54471 .70121 .54162 .69634 .53596 Mtetra
.69634 .53596 .70121 .54162 .71161 .53852 .70677 .53283 Mtetra
.70677 .53283 .71161 .53852 .72206 .53541 .71724 .5297 Mtetra
.71724 .5297 .72206 .53541 .73254 .53229 .72775 .52656 Mtetra
.72775 .52656 .73254 .53229 .74306 .52916 .73829 .5234 Mtetra
.73829 .5234 .74306 .52916 .75361 .52601 .74888 .52024 Mtetra
.74888 .52024 .75361 .52601 .76421 .52286 .7595 .51706 Mtetra
.7595 .51706 .76421 .52286 .77484 .51969 .77016 .51387 Mtetra
.77016 .51387 .77484 .51969 .78552 .51651 .78087 .51067 Mtetra
.78087 .51067 .78552 .51651 .79623 .51332 .79161 .50746 Mtetra
.79161 .50746 .79623 .51332 .80699 .51012 .80239 .50424 Mtetra
.80239 .50424 .80699 .51012 .81778 .50691 .81321 .501 Mtetra
.81321 .501 .81778 .50691 .82862 .50368 .82408 .49775 Mtetra
.82408 .49775 .82862 .50368 .83949 .50045 .83498 .4945 Mtetra
.83498 .4945 .83949 .50045 .85041 .4972 .84593 .49122 Mtetra
.84593 .49122 .85041 .4972 .86136 .49394 .85691 .48794 Mtetra
.85691 .48794 .86136 .49394 .87236 .49067 .86794 .48465 Mtetra
.86794 .48465 .87236 .49067 .8834 .48738 .87901 .48134 Mtetra
.87901 .48134 .8834 .48738 .89448 .48409 .89012 .47802 Mtetra
.89012 .47802 .89448 .48409 .9056 .48078 .90128 .47469 Mtetra
.90128 .47469 .9056 .48078 .91677 .47746 .91247 .47135 Mtetra
.91247 .47135 .91677 .47746 .92798 .47412 .92371 .46799 Mtetra
.92371 .46799 .92798 .47412 .93923 .47078 .93499 .46462 Mtetra
.63 .731 .92 r
.3298 .63858 .33552 .64395 .34465 .64169 .33894 .63646 Mtetra
.639 .739 .921 r
.33894 .63646 .34465 .64169 .35381 .63934 .34812 .63411 Mtetra
.639 .74 .922 r
.34812 .63411 .35381 .63934 .363 .63708 .35733 .63175 Mtetra
.625 .733 .924 r
.35733 .63175 .363 .63708 .37219 .63563 .36656 .62968 Mtetra
.385 .611 .939 r
.36656 .62968 .37219 .63563 .38191 .62232 .37567 .63138 Mtetra
0 0 0 r
.37567 .63138 .38191 .62232 .39092 .62669 .38534 .62054 Mtetra
.594 .694 .912 r
.38534 .62054 .39092 .62669 .40024 .62459 .39464 .61922 Mtetra
.64 .738 .92 r
.39464 .61922 .40024 .62459 .4096 .62205 .40402 .6168 Mtetra
.649 .746 .92 r
.40402 .6168 .4096 .62205 .41901 .61936 .41344 .61416 Mtetra
.653 .749 .92 r
.41344 .61416 .41901 .61936 .42844 .61659 .4229 .6114 Mtetra
.656 .751 .92 r
.4229 .6114 .42844 .61659 .43792 .61376 .43239 .60857 Mtetra
.658 .753 .92 r
.43239 .60857 .43792 .61376 .44742 .61089 .44192 .60569 Mtetra
.659 .753 .92 r
.44192 .60569 .44742 .61089 .45696 .60799 .45148 .60278 Mtetra
.659 .754 .92 r
.45148 .60278 .45696 .60799 .46654 .60507 .46108 .59985 Mtetra
.46108 .59985 .46654 .60507 .47614 .60215 .47071 .5969 Mtetra
.47071 .5969 .47614 .60215 .48578 .59922 .48037 .59395 Mtetra
.659 .753 .92 r
.48037 .59395 .48578 .59922 .49546 .59629 .49007 .591 Mtetra
.658 .753 .92 r
.49007 .591 .49546 .59629 .50516 .59335 .4998 .58804 Mtetra
.4998 .58804 .50516 .59335 .51491 .59041 .50956 .58508 Mtetra
.50956 .58508 .51491 .59041 .52468 .58746 .51936 .58211 Mtetra
.51936 .58211 .52468 .58746 .53449 .58451 .52919 .57913 Mtetra
.52919 .57913 .53449 .58451 .54434 .58154 .53906 .57615 Mtetra
.53906 .57615 .54434 .58154 .55422 .57857 .54897 .57316 Mtetra
.657 .753 .92 r
.54897 .57316 .55422 .57857 .56414 .57559 .55891 .57016 Mtetra
.55891 .57016 .56414 .57559 .57409 .5726 .56888 .56715 Mtetra
.56888 .56715 .57409 .5726 .58407 .5696 .57889 .56413 Mtetra
.657 .752 .92 r
.57889 .56413 .58407 .5696 .5941 .56659 .58894 .5611 Mtetra
.58894 .5611 .5941 .56659 .60416 .56358 .59902 .55806 Mtetra
.59902 .55806 .60416 .56358 .61425 .56055 .60914 .55501 Mtetra
.60914 .55501 .61425 .56055 .62438 .55751 .6193 .55195 Mtetra
.6193 .55195 .62438 .55751 .63455 .55446 .62949 .54888 Mtetra
.62949 .54888 .63455 .55446 .64476 .5514 .63972 .5458 Mtetra
.63972 .5458 .64476 .5514 .655 .54834 .64999 .54272 Mtetra
.64999 .54272 .655 .54834 .66528 .54526 .66029 .53962 Mtetra
.66029 .53962 .66528 .54526 .67559 .54217 .67064 .5365 Mtetra
.67064 .5365 .67559 .54217 .68595 .53907 .68102 .53338 Mtetra
.68102 .53338 .68595 .53907 .69634 .53596 .69144 .53025 Mtetra
.69144 .53025 .69634 .53596 .70677 .53283 .70189 .52711 Mtetra
.70189 .52711 .70677 .53283 .71724 .5297 .71239 .52395 Mtetra
.71239 .52395 .71724 .5297 .72775 .52656 .72292 .52079 Mtetra
.72292 .52079 .72775 .52656 .73829 .5234 .73349 .51761 Mtetra
.73349 .51761 .73829 .5234 .74888 .52024 .74411 .51442 Mtetra
.74411 .51442 .74888 .52024 .7595 .51706 .75476 .51122 Mtetra
.75476 .51122 .7595 .51706 .77016 .51387 .76545 .50801 Mtetra
.76545 .50801 .77016 .51387 .78087 .51067 .77618 .50479 Mtetra
.77618 .50479 .78087 .51067 .79161 .50746 .78695 .50156 Mtetra
.78695 .50156 .79161 .50746 .80239 .50424 .79776 .49831 Mtetra
.79776 .49831 .80239 .50424 .81321 .501 .80862 .49505 Mtetra
.80862 .49505 .81321 .501 .82408 .49775 .81951 .49178 Mtetra
.81951 .49178 .82408 .49775 .83498 .4945 .83044 .4885 Mtetra
.83044 .4885 .83498 .4945 .84593 .49122 .84142 .48521 Mtetra
.84142 .48521 .84593 .49122 .85691 .48794 .85243 .4819 Mtetra
.85243 .4819 .85691 .48794 .86794 .48465 .86349 .47859 Mtetra
.86349 .47859 .86794 .48465 .87901 .48134 .87459 .47526 Mtetra
.87459 .47526 .87901 .48134 .89012 .47802 .88573 .47191 Mtetra
.88573 .47191 .89012 .47802 .90128 .47469 .89692 .46856 Mtetra
.89692 .46856 .90128 .47469 .91247 .47135 .90814 .46519 Mtetra
.90814 .46519 .91247 .47135 .92371 .46799 .91941 .46181 Mtetra
.91941 .46181 .92371 .46799 .93499 .46462 .93073 .45842 Mtetra
.614 .716 .918 r
.32406 .63292 .3298 .63858 .33894 .63646 .33319 .63115 Mtetra
.636 .737 .921 r
.33319 .63115 .33894 .63646 .34812 .63411 .34238 .62884 Mtetra
.64 .74 .921 r
.34238 .62884 .34812 .63411 .35733 .63175 .35162 .62645 Mtetra
.635 .738 .923 r
.35162 .62645 .35733 .63175 .36656 .62968 .36088 .62415 Mtetra
.597 .718 .929 r
.36088 .62415 .36656 .62968 .37567 .63138 .37014 .62266 Mtetra
.811 .695 .736 r
.37014 .62266 .37567 .63138 .38534 .62054 .37994 .60926 Mtetra
.378 .452 .81 r
.37994 .60926 .38534 .62054 .39464 .61922 .38902 .61361 Mtetra
.628 .727 .919 r
.38902 .61361 .39464 .61922 .40402 .6168 .39841 .61147 Mtetra
.646 .743 .92 r
.39841 .61147 .40402 .6168 .41344 .61416 .40785 .60889 Mtetra
.652 .748 .92 r
.40785 .60889 .41344 .61416 .4229 .6114 .41732 .60615 Mtetra
.655 .75 .92 r
.41732 .60615 .4229 .6114 .43239 .60857 .42684 .60334 Mtetra
.657 .752 .92 r
.42684 .60334 .43239 .60857 .44192 .60569 .43638 .60046 Mtetra
.658 .753 .92 r
.43638 .60046 .44192 .60569 .45148 .60278 .44597 .59754 Mtetra
.659 .754 .92 r
.44597 .59754 .45148 .60278 .46108 .59985 .45558 .59459 Mtetra
.45558 .59459 .46108 .59985 .47071 .5969 .46524 .59162 Mtetra
.46524 .59162 .47071 .5969 .48037 .59395 .47492 .58865 Mtetra
.47492 .58865 .48037 .59395 .49007 .591 .48464 .58568 Mtetra
.658 .753 .92 r
.48464 .58568 .49007 .591 .4998 .58804 .49439 .5827 Mtetra
.49439 .5827 .4998 .58804 .50956 .58508 .50418 .57971 Mtetra
.50418 .57971 .50956 .58508 .51936 .58211 .514 .57672 Mtetra
.514 .57672 .51936 .58211 .52919 .57913 .52386 .57372 Mtetra
.52386 .57372 .52919 .57913 .53906 .57615 .53375 .57072 Mtetra
.53375 .57072 .53906 .57615 .54897 .57316 .54368 .56771 Mtetra
.54368 .56771 .54897 .57316 .55891 .57016 .55364 .56468 Mtetra
.657 .753 .92 r
.55364 .56468 .55891 .57016 .56888 .56715 .56364 .56165 Mtetra
.56364 .56165 .56888 .56715 .57889 .56413 .57368 .55861 Mtetra
.57368 .55861 .57889 .56413 .58894 .5611 .58375 .55556 Mtetra
.657 .752 .92 r
.58375 .55556 .58894 .5611 .59902 .55806 .59385 .55251 Mtetra
.59385 .55251 .59902 .55806 .60914 .55501 .604 .54944 Mtetra
.604 .54944 .60914 .55501 .6193 .55195 .61418 .54636 Mtetra
.61418 .54636 .6193 .55195 .62949 .54888 .6244 .54327 Mtetra
.6244 .54327 .62949 .54888 .63972 .5458 .63465 .54017 Mtetra
.63465 .54017 .63972 .5458 .64999 .54272 .64495 .53706 Mtetra
.64495 .53706 .64999 .54272 .66029 .53962 .65528 .53394 Mtetra
.65528 .53394 .66029 .53962 .67064 .5365 .66565 .5308 Mtetra
.66565 .5308 .67064 .5365 .68102 .53338 .67605 .52766 Mtetra
.67605 .52766 .68102 .53338 .69144 .53025 .6865 .52451 Mtetra
.6865 .52451 .69144 .53025 .70189 .52711 .69698 .52134 Mtetra
.69698 .52134 .70189 .52711 .71239 .52395 .7075 .51817 Mtetra
.7075 .51817 .71239 .52395 .72292 .52079 .71806 .51498 Mtetra
.71806 .51498 .72292 .52079 .73349 .51761 .72866 .51178 Mtetra
.72866 .51178 .73349 .51761 .74411 .51442 .7393 .50857 Mtetra
.7393 .50857 .74411 .51442 .75476 .51122 .74998 .50535 Mtetra
.74998 .50535 .75476 .51122 .76545 .50801 .7607 .50212 Mtetra
.7607 .50212 .76545 .50801 .77618 .50479 .77146 .49887 Mtetra
.77146 .49887 .77618 .50479 .78695 .50156 .78226 .49561 Mtetra
.78226 .49561 .78695 .50156 .79776 .49831 .7931 .49235 Mtetra
.7931 .49235 .79776 .49831 .80862 .49505 .80398 .48907 Mtetra
.80398 .48907 .80862 .49505 .81951 .49178 .81491 .48577 Mtetra
.81491 .48577 .81951 .49178 .83044 .4885 .82587 .48247 Mtetra
.82587 .48247 .83044 .4885 .84142 .48521 .83687 .47915 Mtetra
.83687 .47915 .84142 .48521 .85243 .4819 .84792 .47582 Mtetra
.84792 .47582 .85243 .4819 .86349 .47859 .85901 .47248 Mtetra
.85901 .47248 .86349 .47859 .87459 .47526 .87014 .46913 Mtetra
.87014 .46913 .87459 .47526 .88573 .47191 .88131 .46576 Mtetra
.88131 .46576 .88573 .47191 .89692 .46856 .89253 .46238 Mtetra
.89253 .46238 .89692 .46856 .90814 .46519 .90379 .45899 Mtetra
.90379 .45899 .90814 .46519 .91941 .46181 .91509 .45559 Mtetra
.91509 .45559 .91941 .46181 .93073 .45842 .92643 .45217 Mtetra
.557 .66 .905 r
.31834 .62619 .32406 .63292 .33319 .63115 .32741 .6257 Mtetra
.63 .731 .92 r
.32741 .6257 .33319 .63115 .34238 .62884 .33662 .62353 Mtetra
.639 .739 .921 r
.33662 .62353 .34238 .62884 .35162 .62645 .34587 .62113 Mtetra
.639 .74 .922 r
.34587 .62113 .35162 .62645 .36088 .62415 .35515 .61874 Mtetra
.625 .733 .924 r
.35515 .61874 .36088 .62415 .37014 .62266 .36446 .61663 Mtetra
.386 .611 .939 r
.36446 .61663 .37014 .62266 .37994 .60926 .37364 .6183 Mtetra
0 0 0 r
.37364 .6183 .37994 .60926 .38902 .61361 .38339 .60737 Mtetra
.594 .694 .912 r
.38339 .60737 .38902 .61361 .39841 .61147 .39276 .60601 Mtetra
.64 .738 .92 r
.39276 .60601 .39841 .61147 .40785 .60889 .40221 .60355 Mtetra
.649 .746 .92 r
.40221 .60355 .40785 .60889 .41732 .60615 .41171 .60086 Mtetra
.653 .749 .92 r
.41171 .60086 .41732 .60615 .42684 .60334 .42124 .59805 Mtetra
.656 .751 .92 r
.42124 .59805 .42684 .60334 .43638 .60046 .43081 .59518 Mtetra
.658 .753 .92 r
.43081 .59518 .43638 .60046 .44597 .59754 .44042 .59225 Mtetra
.659 .753 .92 r
.44042 .59225 .44597 .59754 .45558 .59459 .45005 .58929 Mtetra
.659 .754 .92 r
.45005 .58929 .45558 .59459 .46524 .59162 .45973 .58631 Mtetra
.45973 .58631 .46524 .59162 .47492 .58865 .46943 .58332 Mtetra
.46943 .58332 .47492 .58865 .48464 .58568 .47918 .58032 Mtetra
.659 .753 .92 r
.47918 .58032 .48464 .58568 .49439 .5827 .48895 .57732 Mtetra
.658 .753 .92 r
.48895 .57732 .49439 .5827 .50418 .57971 .49876 .57431 Mtetra
.49876 .57431 .50418 .57971 .514 .57672 .50861 .5713 Mtetra
.50861 .5713 .514 .57672 .52386 .57372 .51849 .56828 Mtetra
.51849 .56828 .52386 .57372 .53375 .57072 .5284 .56525 Mtetra
.5284 .56525 .53375 .57072 .54368 .56771 .53835 .56222 Mtetra
.53835 .56222 .54368 .56771 .55364 .56468 .54834 .55918 Mtetra
.657 .753 .92 r
.54834 .55918 .55364 .56468 .56364 .56165 .55836 .55613 Mtetra
.55836 .55613 .56364 .56165 .57368 .55861 .56842 .55306 Mtetra
.56842 .55306 .57368 .55861 .58375 .55556 .57852 .54999 Mtetra
.657 .752 .92 r
.57852 .54999 .58375 .55556 .59385 .55251 .58865 .54691 Mtetra
.58865 .54691 .59385 .55251 .604 .54944 .59882 .54382 Mtetra
.59882 .54382 .604 .54944 .61418 .54636 .60903 .54072 Mtetra
.60903 .54072 .61418 .54636 .6244 .54327 .61927 .53761 Mtetra
.61927 .53761 .6244 .54327 .63465 .54017 .62955 .53449 Mtetra
.62955 .53449 .63465 .54017 .64495 .53706 .63987 .53136 Mtetra
.63987 .53136 .64495 .53706 .65528 .53394 .65023 .52822 Mtetra
.65023 .52822 .65528 .53394 .66565 .5308 .66062 .52506 Mtetra
.66062 .52506 .66565 .5308 .67605 .52766 .67105 .5219 Mtetra
.67105 .5219 .67605 .52766 .6865 .52451 .68153 .51872 Mtetra
.68153 .51872 .6865 .52451 .69698 .52134 .69204 .51554 Mtetra
.69204 .51554 .69698 .52134 .7075 .51817 .70259 .51234 Mtetra
.70259 .51234 .7075 .51817 .71806 .51498 .71317 .50913 Mtetra
.71317 .50913 .71806 .51498 .72866 .51178 .7238 .50591 Mtetra
.7238 .50591 .72866 .51178 .7393 .50857 .73447 .50268 Mtetra
.73447 .50268 .7393 .50857 .74998 .50535 .74518 .49943 Mtetra
.74518 .49943 .74998 .50535 .7607 .50212 .75592 .49618 Mtetra
.75592 .49618 .7607 .50212 .77146 .49887 .76671 .49291 Mtetra
.76671 .49291 .77146 .49887 .78226 .49561 .77754 .48963 Mtetra
.77754 .48963 .78226 .49561 .7931 .49235 .78841 .48634 Mtetra
.78841 .48634 .7931 .49235 .80398 .48907 .79932 .48304 Mtetra
.79932 .48304 .80398 .48907 .81491 .48577 .81027 .47972 Mtetra
.81027 .47972 .81491 .48577 .82587 .48247 .82126 .47639 Mtetra
.82126 .47639 .82587 .48247 .83687 .47915 .8323 .47305 Mtetra
.8323 .47305 .83687 .47915 .84792 .47582 .84338 .4697 Mtetra
.84338 .4697 .84792 .47582 .85901 .47248 .85449 .46634 Mtetra
.85449 .46634 .85901 .47248 .87014 .46913 .86566 .46296 Mtetra
.86566 .46296 .87014 .46913 .88131 .46576 .87686 .45957 Mtetra
.87686 .45957 .88131 .46576 .89253 .46238 .88811 .45617 Mtetra
.88811 .45617 .89253 .46238 .90379 .45899 .8994 .45275 Mtetra
.8994 .45275 .90379 .45899 .91509 .45559 .91073 .44932 Mtetra
.91073 .44932 .91509 .45559 .92643 .45217 .92211 .44588 Mtetra
0 0 .401 r
.31605 .56347 .31834 .62619 .32741 .6257 .32162 .61995 Mtetra
.614 .716 .918 r
.32162 .61995 .32741 .6257 .33662 .62353 .33082 .61813 Mtetra
.636 .737 .921 r
.33082 .61813 .33662 .62353 .34587 .62113 .34008 .61579 Mtetra
.64 .74 .921 r
.34008 .61579 .34587 .62113 .35515 .61874 .34939 .61335 Mtetra
.635 .738 .923 r
.34939 .61335 .35515 .61874 .36446 .61663 .35872 .61101 Mtetra
.597 .718 .929 r
.35872 .61101 .36446 .61663 .37364 .6183 .36806 .60947 Mtetra
.812 .695 .736 r
.36806 .60947 .37364 .6183 .38339 .60737 .37794 .59598 Mtetra
.377 .451 .81 r
.37794 .59598 .38339 .60737 .39276 .60601 .38709 .60032 Mtetra
.628 .727 .919 r
.38709 .60032 .39276 .60601 .40221 .60355 .39655 .59813 Mtetra
.646 .743 .92 r
.39655 .59813 .40221 .60355 .41171 .60086 .40606 .59551 Mtetra
.652 .748 .92 r
.40606 .59551 .41171 .60086 .42124 .59805 .41561 .59272 Mtetra
.655 .75 .92 r
.41561 .59272 .42124 .59805 .43081 .59518 .4252 .58986 Mtetra
.657 .752 .92 r
.4252 .58986 .43081 .59518 .44042 .59225 .43483 .58693 Mtetra
.658 .753 .92 r
.43483 .58693 .44042 .59225 .45005 .58929 .44449 .58396 Mtetra
.659 .754 .92 r
.44449 .58396 .45005 .58929 .45973 .58631 .45418 .58097 Mtetra
.45418 .58097 .45973 .58631 .46943 .58332 .46391 .57795 Mtetra
.46391 .57795 .46943 .58332 .47918 .58032 .47368 .57493 Mtetra
.47368 .57493 .47918 .58032 .48895 .57732 .48347 .57191 Mtetra
.658 .753 .92 r
.48347 .57191 .48895 .57732 .49876 .57431 .49331 .56888 Mtetra
.49331 .56888 .49876 .57431 .50861 .5713 .50318 .56584 Mtetra
.50318 .56584 .50861 .5713 .51849 .56828 .51308 .5628 Mtetra
.51308 .5628 .51849 .56828 .5284 .56525 .52302 .55975 Mtetra
.52302 .55975 .5284 .56525 .53835 .56222 .53299 .5567 Mtetra
.53299 .5567 .53835 .56222 .54834 .55918 .54301 .55363 Mtetra
.54301 .55363 .54834 .55918 .55836 .55613 .55305 .55056 Mtetra
.657 .753 .92 r
.55305 .55056 .55836 .55613 .56842 .55306 .56314 .54748 Mtetra
.56314 .54748 .56842 .55306 .57852 .54999 .57326 .54439 Mtetra
.57326 .54439 .57852 .54999 .58865 .54691 .58341 .54129 Mtetra
.657 .752 .92 r
.58341 .54129 .58865 .54691 .59882 .54382 .59361 .53817 Mtetra
.59361 .53817 .59882 .54382 .60903 .54072 .60384 .53505 Mtetra
.60384 .53505 .60903 .54072 .61927 .53761 .61411 .53192 Mtetra
.61411 .53192 .61927 .53761 .62955 .53449 .62441 .52878 Mtetra
.62441 .52878 .62955 .53449 .63987 .53136 .63476 .52562 Mtetra
.63476 .52562 .63987 .53136 .65023 .52822 .64514 .52246 Mtetra
.64514 .52246 .65023 .52822 .66062 .52506 .65556 .51928 Mtetra
.65556 .51928 .66062 .52506 .67105 .5219 .66602 .5161 Mtetra
.66602 .5161 .67105 .5219 .68153 .51872 .67652 .5129 Mtetra
.67652 .5129 .68153 .51872 .69204 .51554 .68706 .50969 Mtetra
.68706 .50969 .69204 .51554 .70259 .51234 .69763 .50647 Mtetra
.69763 .50647 .70259 .51234 .71317 .50913 .70825 .50324 Mtetra
.70825 .50324 .71317 .50913 .7238 .50591 .7189 .5 Mtetra
.7189 .5 .7238 .50591 .73447 .50268 .7296 .49674 Mtetra
.7296 .49674 .73447 .50268 .74518 .49943 .74034 .49347 Mtetra
.74034 .49347 .74518 .49943 .75592 .49618 .75111 .4902 Mtetra
.75111 .4902 .75592 .49618 .76671 .49291 .76193 .48691 Mtetra
.76193 .48691 .76671 .49291 .77754 .48963 .77279 .4836 Mtetra
.77279 .4836 .77754 .48963 .78841 .48634 .78368 .48029 Mtetra
.78368 .48029 .78841 .48634 .79932 .48304 .79462 .47696 Mtetra
.79462 .47696 .79932 .48304 .81027 .47972 .8056 .47362 Mtetra
.8056 .47362 .81027 .47972 .82126 .47639 .81663 .47027 Mtetra
.81663 .47027 .82126 .47639 .8323 .47305 .82769 .46691 Mtetra
.82769 .46691 .8323 .47305 .84338 .4697 .8388 .46353 Mtetra
.8388 .46353 .84338 .4697 .85449 .46634 .84995 .46015 Mtetra
.84995 .46015 .85449 .46634 .86566 .46296 .86114 .45674 Mtetra
.86114 .45674 .86566 .46296 .87686 .45957 .87238 .45333 Mtetra
.87238 .45333 .87686 .45957 .88811 .45617 .88365 .4499 Mtetra
.88365 .4499 .88811 .45617 .8994 .45275 .89498 .44646 Mtetra
.89498 .44646 .8994 .45275 .91073 .44932 .90634 .44301 Mtetra
.90634 .44301 .91073 .44932 .92211 .44588 .91775 .43954 Mtetra
.486 .245 .474 r
.30618 .62261 .31605 .56347 .32162 .61995 .31585 .61313 Mtetra
.557 .66 .905 r
.31585 .61313 .32162 .61995 .33082 .61813 .32498 .6126 Mtetra
.63 .731 .92 r
.32498 .6126 .33082 .61813 .34008 .61579 .33426 .61039 Mtetra
.639 .739 .921 r
.33426 .61039 .34008 .61579 .34939 .61335 .34358 .60795 Mtetra
.639 .74 .922 r
.34358 .60795 .34939 .61335 .35872 .61101 .35294 .60551 Mtetra
.626 .733 .924 r
.35294 .60551 .35872 .61101 .36806 .60947 .36232 .60335 Mtetra
.387 .612 .939 r
.36232 .60335 .36806 .60947 .37794 .59598 .37157 .605 Mtetra
0 0 0 r
.37157 .605 .37794 .59598 .38709 .60032 .3814 .59399 Mtetra
.594 .694 .912 r
.3814 .59399 .38709 .60032 .39655 .59813 .39085 .59259 Mtetra
.64 .738 .92 r
.39085 .59259 .39655 .59813 .40606 .59551 .40037 .59008 Mtetra
.649 .746 .92 r
.40037 .59008 .40606 .59551 .41561 .59272 .40995 .58734 Mtetra
.653 .749 .92 r
.40995 .58734 .41561 .59272 .4252 .58986 .41956 .58449 Mtetra
.656 .751 .92 r
.41956 .58449 .4252 .58986 .43483 .58693 .4292 .58157 Mtetra
.658 .753 .92 r
.4292 .58157 .43483 .58693 .44449 .58396 .43889 .57859 Mtetra
.659 .753 .92 r
.43889 .57859 .44449 .58396 .45418 .58097 .4486 .57558 Mtetra
.659 .754 .92 r
.4486 .57558 .45418 .58097 .46391 .57795 .45835 .57255 Mtetra
.45835 .57255 .46391 .57795 .47368 .57493 .46814 .56951 Mtetra
.46814 .56951 .47368 .57493 .48347 .57191 .47796 .56646 Mtetra
.659 .753 .92 r
.47796 .56646 .48347 .57191 .49331 .56888 .48782 .56341 Mtetra
.658 .753 .92 r
.48782 .56341 .49331 .56888 .50318 .56584 .49771 .56035 Mtetra
.49771 .56035 .50318 .56584 .51308 .5628 .50764 .55729 Mtetra
.50764 .55729 .51308 .5628 .52302 .55975 .5176 .55422 Mtetra
.5176 .55422 .52302 .55975 .53299 .5567 .5276 .55114 Mtetra
.5276 .55114 .53299 .5567 .54301 .55363 .53763 .54805 Mtetra
.53763 .54805 .54301 .55363 .55305 .55056 .5477 .54496 Mtetra
.657 .753 .92 r
.5477 .54496 .55305 .55056 .56314 .54748 .55781 .54186 Mtetra
.55781 .54186 .56314 .54748 .57326 .54439 .56796 .53874 Mtetra
.56796 .53874 .57326 .54439 .58341 .54129 .57814 .53562 Mtetra
.657 .752 .92 r
.57814 .53562 .58341 .54129 .59361 .53817 .58836 .53249 Mtetra
.58836 .53249 .59361 .53817 .60384 .53505 .59862 .52934 Mtetra
.59862 .52934 .60384 .53505 .61411 .53192 .60891 .52619 Mtetra
.60891 .52619 .61411 .53192 .62441 .52878 .61924 .52302 Mtetra
.61924 .52302 .62441 .52878 .63476 .52562 .62961 .51985 Mtetra
.62961 .51985 .63476 .52562 .64514 .52246 .64002 .51666 Mtetra
.64002 .51666 .64514 .52246 .65556 .51928 .65047 .51346 Mtetra
.65047 .51346 .65556 .51928 .66602 .5161 .66095 .51026 Mtetra
.66095 .51026 .66602 .5161 .67652 .5129 .67148 .50704 Mtetra
.67148 .50704 .67652 .5129 .68706 .50969 .68204 .50381 Mtetra
.68204 .50381 .68706 .50969 .69763 .50647 .69265 .50056 Mtetra
.69265 .50056 .69763 .50647 .70825 .50324 .70329 .49731 Mtetra
.70329 .49731 .70825 .50324 .7189 .5 .71397 .49404 Mtetra
.71397 .49404 .7189 .5 .7296 .49674 .7247 .49077 Mtetra
.7247 .49077 .7296 .49674 .74034 .49347 .73546 .48748 Mtetra
.73546 .48748 .74034 .49347 .75111 .4902 .74627 .48417 Mtetra
.74627 .48417 .75111 .4902 .76193 .48691 .75711 .48086 Mtetra
.75711 .48086 .76193 .48691 .77279 .4836 .768 .47754 Mtetra
.768 .47754 .77279 .4836 .78368 .48029 .77892 .4742 Mtetra
.77892 .4742 .78368 .48029 .79462 .47696 .78989 .47085 Mtetra
.78989 .47085 .79462 .47696 .8056 .47362 .8009 .46749 Mtetra
.8009 .46749 .8056 .47362 .81663 .47027 .81196 .46411 Mtetra
.81196 .46411 .81663 .47027 .82769 .46691 .82305 .46072 Mtetra
.82305 .46072 .82769 .46691 .8388 .46353 .83419 .45732 Mtetra
.83419 .45732 .8388 .46353 .84995 .46015 .84537 .45391 Mtetra
.84537 .45391 .84995 .46015 .86114 .45674 .85659 .45049 Mtetra
.85659 .45049 .86114 .45674 .87238 .45333 .86786 .44705 Mtetra
.86786 .44705 .87238 .45333 .88365 .4499 .87917 .4436 Mtetra
.87917 .4436 .88365 .4499 .89498 .44646 .89052 .44013 Mtetra
.89052 .44013 .89498 .44646 .90634 .44301 .90192 .43665 Mtetra
.90192 .43665 .90634 .44301 .91775 .43954 .91336 .43316 Mtetra
.916 .703 .601 r
.30037 .61548 .30618 .62261 .31585 .61313 .31357 .55008 Mtetra
0 0 .397 r
.31357 .55008 .31585 .61313 .32498 .6126 .31913 .60676 Mtetra
.614 .716 .919 r
.31913 .60676 .32498 .6126 .33426 .61039 .3284 .60491 Mtetra
.636 .737 .921 r
.3284 .60491 .33426 .61039 .34358 .60795 .33774 .60252 Mtetra
.64 .74 .921 r
.33774 .60252 .34358 .60795 .35294 .60551 .34712 .60003 Mtetra
.635 .738 .923 r
.34712 .60003 .35294 .60551 .36232 .60335 .35653 .59765 Mtetra
.597 .718 .929 r
.35653 .59765 .36232 .60335 .37157 .605 .36593 .59607 Mtetra
.813 .696 .736 r
.36593 .59607 .37157 .605 .3814 .59399 .37591 .58249 Mtetra
.375 .451 .81 r
.37591 .58249 .3814 .59399 .39085 .59259 .38512 .58681 Mtetra
.628 .727 .919 r
.38512 .58681 .39085 .59259 .40037 .59008 .39465 .58457 Mtetra
.646 .743 .92 r
.39465 .58457 .40037 .59008 .40995 .58734 .40424 .5819 Mtetra
.652 .748 .92 r
.40424 .5819 .40995 .58734 .41956 .58449 .41387 .57907 Mtetra
.655 .75 .92 r
.41387 .57907 .41956 .58449 .4292 .58157 .42354 .57615 Mtetra
.657 .752 .92 r
.42354 .57615 .4292 .58157 .43889 .57859 .43324 .57318 Mtetra
.658 .753 .92 r
.43324 .57318 .43889 .57859 .4486 .57558 .44298 .57016 Mtetra
.659 .754 .92 r
.44298 .57016 .4486 .57558 .45835 .57255 .45276 .56711 Mtetra
.45276 .56711 .45835 .57255 .46814 .56951 .46257 .56405 Mtetra
.46257 .56405 .46814 .56951 .47796 .56646 .47241 .56098 Mtetra
.47241 .56098 .47796 .56646 .48782 .56341 .48229 .5579 Mtetra
.658 .753 .92 r
.48229 .5579 .48782 .56341 .49771 .56035 .49221 .55482 Mtetra
.49221 .55482 .49771 .56035 .50764 .55729 .50216 .55173 Mtetra
.50216 .55173 .50764 .55729 .5176 .55422 .51214 .54864 Mtetra
.51214 .54864 .5176 .55422 .5276 .55114 .52217 .54554 Mtetra
.52217 .54554 .5276 .55114 .53763 .54805 .53223 .54244 Mtetra
.53223 .54244 .53763 .54805 .5477 .54496 .54232 .53932 Mtetra
.54232 .53932 .5477 .54496 .55781 .54186 .55245 .53619 Mtetra
.657 .753 .92 r
.55245 .53619 .55781 .54186 .56796 .53874 .56262 .53306 Mtetra
.56262 .53306 .56796 .53874 .57814 .53562 .57283 .52991 Mtetra
.57283 .52991 .57814 .53562 .58836 .53249 .58307 .52676 Mtetra
.657 .752 .92 r
.58307 .52676 .58836 .53249 .59862 .52934 .59336 .52359 Mtetra
.59336 .52359 .59862 .52934 .60891 .52619 .60368 .52042 Mtetra
.60368 .52042 .60891 .52619 .61924 .52302 .61403 .51723 Mtetra
.61403 .51723 .61924 .52302 .62961 .51985 .62443 .51403 Mtetra
.62443 .51403 .62961 .51985 .64002 .51666 .63487 .51083 Mtetra
.63487 .51083 .64002 .51666 .65047 .51346 .64534 .50761 Mtetra
.64534 .50761 .65047 .51346 .66095 .51026 .65585 .50437 Mtetra
.65585 .50437 .66095 .51026 .67148 .50704 .6664 .50113 Mtetra
.6664 .50113 .67148 .50704 .68204 .50381 .677 .49788 Mtetra
.677 .49788 .68204 .50381 .69265 .50056 .68763 .49461 Mtetra
.68763 .49461 .69265 .50056 .70329 .49731 .6983 .49134 Mtetra
.6983 .49134 .70329 .49731 .71397 .49404 .70901 .48805 Mtetra
.70901 .48805 .71397 .49404 .7247 .49077 .71976 .48475 Mtetra
.71976 .48475 .7247 .49077 .73546 .48748 .73055 .48144 Mtetra
.73055 .48144 .73546 .48748 .74627 .48417 .74139 .47811 Mtetra
.74139 .47811 .74627 .48417 .75711 .48086 .75226 .47477 Mtetra
.75226 .47477 .75711 .48086 .768 .47754 .76317 .47143 Mtetra
.76317 .47143 .768 .47754 .77892 .4742 .77413 .46806 Mtetra
.77413 .46806 .77892 .4742 .78989 .47085 .78513 .46469 Mtetra
.78513 .46469 .78989 .47085 .8009 .46749 .79617 .4613 Mtetra
.79617 .4613 .8009 .46749 .81196 .46411 .80725 .45791 Mtetra
.80725 .45791 .81196 .46411 .82305 .46072 .81838 .45449 Mtetra
.81838 .45449 .82305 .46072 .83419 .45732 .82955 .45107 Mtetra
.82955 .45107 .83419 .45732 .84537 .45391 .84076 .44763 Mtetra
.84076 .44763 .84537 .45391 .85659 .45049 .85201 .44418 Mtetra
.85201 .44418 .85659 .45049 .86786 .44705 .86331 .44072 Mtetra
.86331 .44072 .86786 .44705 .87917 .4436 .87465 .43724 Mtetra
.87465 .43724 .87917 .4436 .89052 .44013 .88604 .43375 Mtetra
.88604 .43375 .89052 .44013 .90192 .43665 .89747 .43025 Mtetra
.89747 .43025 .90192 .43665 .91336 .43316 .90894 .42673 Mtetra
.516 .678 .939 r
.29445 .60956 .30037 .61548 .31357 .55008 .30356 .60941 Mtetra
.482 .24 .47 r
.30356 .60941 .31357 .55008 .31913 .60676 .31331 .59985 Mtetra
.556 .66 .905 r
.31331 .59985 .31913 .60676 .3284 .60491 .32252 .59928 Mtetra
.63 .731 .92 r
.32252 .59928 .3284 .60491 .33774 .60252 .33186 .59703 Mtetra
.639 .739 .921 r
.33186 .59703 .33774 .60252 .34712 .60003 .34126 .59454 Mtetra
.639 .74 .922 r
.34126 .59454 .34712 .60003 .35653 .59765 .35069 .59205 Mtetra
.626 .733 .924 r
.35069 .59205 .35653 .59765 .36593 .59607 .36014 .58985 Mtetra
.388 .612 .939 r
.36014 .58985 .36593 .59607 .37591 .58249 .36946 .59147 Mtetra
0 0 0 r
.36946 .59147 .37591 .58249 .38512 .58681 .37938 .58038 Mtetra
.594 .694 .912 r
.37938 .58038 .38512 .58681 .39465 .58457 .3889 .57894 Mtetra
.64 .738 .92 r
.3889 .57894 .39465 .58457 .40424 .5819 .3985 .57639 Mtetra
.649 .746 .92 r
.3985 .57639 .40424 .5819 .41387 .57907 .40815 .5736 Mtetra
.653 .749 .92 r
.40815 .5736 .41387 .57907 .42354 .57615 .41784 .57069 Mtetra
.656 .751 .92 r
.41784 .57069 .42354 .57615 .43324 .57318 .42757 .56772 Mtetra
.658 .753 .92 r
.42757 .56772 .43324 .57318 .44298 .57016 .43733 .5647 Mtetra
.659 .753 .92 r
.43733 .5647 .44298 .57016 .45276 .56711 .44712 .56164 Mtetra
.659 .754 .92 r
.44712 .56164 .45276 .56711 .46257 .56405 .45696 .55855 Mtetra
.45696 .55855 .46257 .56405 .47241 .56098 .46682 .55546 Mtetra
.46682 .55546 .47241 .56098 .48229 .5579 .47673 .55236 Mtetra
.659 .753 .92 r
.47673 .55236 .48229 .5579 .49221 .55482 .48667 .54926 Mtetra
.658 .753 .92 r
.48667 .54926 .49221 .55482 .50216 .55173 .49664 .54615 Mtetra
.49664 .54615 .50216 .55173 .51214 .54864 .50665 .54303 Mtetra
.50665 .54303 .51214 .54864 .52217 .54554 .5167 .53991 Mtetra
.5167 .53991 .52217 .54554 .53223 .54244 .52678 .53678 Mtetra
.52678 .53678 .53223 .54244 .54232 .53932 .5369 .53364 Mtetra
.5369 .53364 .54232 .53932 .55245 .53619 .54706 .53049 Mtetra
.657 .753 .92 r
.54706 .53049 .55245 .53619 .56262 .53306 .55725 .52734 Mtetra
.55725 .52734 .56262 .53306 .57283 .52991 .56748 .52417 Mtetra
.56748 .52417 .57283 .52991 .58307 .52676 .57775 .52099 Mtetra
.657 .752 .92 r
.57775 .52099 .58307 .52676 .59336 .52359 .58806 .51781 Mtetra
.58806 .51781 .59336 .52359 .60368 .52042 .59841 .51461 Mtetra
.59841 .51461 .60368 .52042 .61403 .51723 .60879 .5114 Mtetra
.60879 .5114 .61403 .51723 .62443 .51403 .61921 .50818 Mtetra
.61921 .50818 .62443 .51403 .63487 .51083 .62967 .50495 Mtetra
.62967 .50495 .63487 .51083 .64534 .50761 .64017 .50171 Mtetra
.64017 .50171 .64534 .50761 .65585 .50437 .65071 .49845 Mtetra
.65071 .49845 .65585 .50437 .6664 .50113 .66129 .49519 Mtetra
.66129 .49519 .6664 .50113 .677 .49788 .67191 .49191 Mtetra
.67191 .49191 .677 .49788 .68763 .49461 .68257 .48862 Mtetra
.68257 .48862 .68763 .49461 .6983 .49134 .69327 .48532 Mtetra
.69327 .48532 .6983 .49134 .70901 .48805 .70401 .48201 Mtetra
.70401 .48201 .70901 .48805 .71976 .48475 .71479 .47869 Mtetra
.71479 .47869 .71976 .48475 .73055 .48144 .72561 .47535 Mtetra
.72561 .47535 .73055 .48144 .74139 .47811 .73647 .472 Mtetra
.73647 .472 .74139 .47811 .75226 .47477 .74737 .46864 Mtetra
.74737 .46864 .75226 .47477 .76317 .47143 .75832 .46527 Mtetra
.75832 .46527 .76317 .47143 .77413 .46806 .7693 .46189 Mtetra
.7693 .46189 .77413 .46806 .78513 .46469 .78033 .45849 Mtetra
.78033 .45849 .78513 .46469 .79617 .4613 .7914 .45508 Mtetra
.7914 .45508 .79617 .4613 .80725 .45791 .80252 .45165 Mtetra
.80252 .45165 .80725 .45791 .81838 .45449 .81367 .44822 Mtetra
.81367 .44822 .81838 .45449 .82955 .45107 .82487 .44477 Mtetra
.82487 .44477 .82955 .45107 .84076 .44763 .83612 .44131 Mtetra
.83612 .44131 .84076 .44763 .85201 .44418 .8474 .43783 Mtetra
.8474 .43783 .85201 .44418 .86331 .44072 .85873 .43435 Mtetra
.85873 .43435 .86331 .44072 .87465 .43724 .8701 .43084 Mtetra
.8701 .43084 .87465 .43724 .88604 .43375 .88152 .42733 Mtetra
.88152 .42733 .88604 .43375 .89747 .43025 .89299 .4238 Mtetra
.89299 .4238 .89747 .43025 .90894 .42673 .90449 .42026 Mtetra
.604 .721 .927 r
.28847 .60388 .29445 .60956 .30356 .60941 .2977 .60218 Mtetra
.917 .704 .6 r
.2977 .60218 .30356 .60941 .31331 .59985 .31104 .53647 Mtetra
0 0 .393 r
.31104 .53647 .31331 .59985 .32252 .59928 .31661 .59335 Mtetra
.614 .716 .919 r
.31661 .59335 .32252 .59928 .33186 .59703 .32595 .59146 Mtetra
.636 .737 .921 r
.32595 .59146 .33186 .59703 .34126 .59454 .33536 .58902 Mtetra
.64 .74 .921 r
.33536 .58902 .34126 .59454 .35069 .59205 .34481 .58649 Mtetra
.635 .738 .923 r
.34481 .58649 .35069 .59205 .36014 .58985 .3543 .58406 Mtetra
.597 .718 .929 r
.3543 .58406 .36014 .58985 .36946 .59147 .36378 .58244 Mtetra
.813 .697 .736 r
.36378 .58244 .36946 .59147 .37938 .58038 .37384 .56876 Mtetra
.374 .45 .81 r
.37384 .56876 .37938 .58038 .3889 .57894 .38312 .57306 Mtetra
.628 .727 .919 r
.38312 .57306 .3889 .57894 .3985 .57639 .39273 .57078 Mtetra
.646 .743 .92 r
.39273 .57078 .3985 .57639 .40815 .5736 .4024 .56806 Mtetra
.652 .748 .92 r
.4024 .56806 .40815 .5736 .41784 .57069 .41211 .56518 Mtetra
.655 .75 .92 r
.41211 .56518 .41784 .57069 .42757 .56772 .42185 .56222 Mtetra
.657 .752 .92 r
.42185 .56222 .42757 .56772 .43733 .5647 .43163 .55919 Mtetra
.658 .753 .92 r
.43163 .55919 .43733 .5647 .44712 .56164 .44145 .55612 Mtetra
.659 .754 .92 r
.44145 .55612 .44712 .56164 .45696 .55855 .45131 .55302 Mtetra
.45131 .55302 .45696 .55855 .46682 .55546 .4612 .54991 Mtetra
.4612 .54991 .46682 .55546 .47673 .55236 .47113 .54678 Mtetra
.47113 .54678 .47673 .55236 .48667 .54926 .48109 .54366 Mtetra
.658 .753 .92 r
.48109 .54366 .48667 .54926 .49664 .54615 .49109 .54052 Mtetra
.49109 .54052 .49664 .54615 .50665 .54303 .50112 .53738 Mtetra
.50112 .53738 .50665 .54303 .5167 .53991 .51119 .53424 Mtetra
.51119 .53424 .5167 .53991 .52678 .53678 .5213 .53109 Mtetra
.5213 .53109 .52678 .53678 .5369 .53364 .53144 .52793 Mtetra
.53144 .52793 .5369 .53364 .54706 .53049 .54162 .52476 Mtetra
.54162 .52476 .54706 .53049 .55725 .52734 .55184 .52158 Mtetra
.657 .753 .92 r
.55184 .52158 .55725 .52734 .56748 .52417 .5621 .51839 Mtetra
.5621 .51839 .56748 .52417 .57775 .52099 .5724 .51519 Mtetra
.5724 .51519 .57775 .52099 .58806 .51781 .58273 .51198 Mtetra
.657 .752 .92 r
.58273 .51198 .58806 .51781 .59841 .51461 .5931 .50876 Mtetra
.5931 .50876 .59841 .51461 .60879 .5114 .60351 .50553 Mtetra
.60351 .50553 .60879 .5114 .61921 .50818 .61396 .50228 Mtetra
.61396 .50228 .61921 .50818 .62967 .50495 .62445 .49903 Mtetra
.62445 .49903 .62967 .50495 .64017 .50171 .63497 .49577 Mtetra
.63497 .49577 .64017 .50171 .65071 .49845 .64554 .49249 Mtetra
.64554 .49249 .65071 .49845 .66129 .49519 .65615 .4892 Mtetra
.65615 .4892 .66129 .49519 .67191 .49191 .66679 .4859 Mtetra
.66679 .4859 .67191 .49191 .68257 .48862 .67748 .48259 Mtetra
.67748 .48259 .68257 .48862 .69327 .48532 .68821 .47927 Mtetra
.68821 .47927 .69327 .48532 .70401 .48201 .69897 .47593 Mtetra
.69897 .47593 .70401 .48201 .71479 .47869 .70978 .47259 Mtetra
.70978 .47259 .71479 .47869 .72561 .47535 .72063 .46923 Mtetra
.72063 .46923 .72561 .47535 .73647 .472 .73152 .46585 Mtetra
.73152 .46585 .73647 .472 .74737 .46864 .74245 .46247 Mtetra
.74245 .46247 .74737 .46864 .75832 .46527 .75343 .45907 Mtetra
.75343 .45907 .75832 .46527 .7693 .46189 .76444 .45566 Mtetra
.76444 .45566 .7693 .46189 .78033 .45849 .7755 .45224 Mtetra
.7755 .45224 .78033 .45849 .7914 .45508 .7866 .44881 Mtetra
.7866 .44881 .7914 .45508 .80252 .45165 .79775 .44536 Mtetra
.79775 .44536 .80252 .45165 .81367 .44822 .80893 .4419 Mtetra
.80893 .4419 .81367 .44822 .82487 .44477 .82016 .43843 Mtetra
.82016 .43843 .82487 .44477 .83612 .44131 .83144 .43494 Mtetra
.83144 .43494 .83612 .44131 .8474 .43783 .84276 .43144 Mtetra
.84276 .43144 .8474 .43783 .85873 .43435 .85412 .42793 Mtetra
.85412 .42793 .85873 .43435 .8701 .43084 .86552 .4244 Mtetra
.86552 .4244 .8701 .43084 .88152 .42733 .87697 .42086 Mtetra
.87697 .42086 .88152 .42733 .89299 .4238 .88847 .41731 Mtetra
.88847 .41731 .89299 .4238 .90449 .42026 .90001 .41374 Mtetra
.622 .73 .924 r
.28245 .59826 .28847 .60388 .2977 .60218 .29172 .59617 Mtetra
.516 .678 .939 r
.29172 .59617 .2977 .60218 .31104 .53647 .3009 .59598 Mtetra
.478 .235 .466 r
.3009 .59598 .31104 .53647 .31661 .59335 .31073 .58635 Mtetra
.556 .66 .906 r
.31073 .58635 .31661 .59335 .32595 .59146 .32001 .58574 Mtetra
.63 .731 .92 r
.32001 .58574 .32595 .59146 .33536 .58902 .32943 .58344 Mtetra
.639 .739 .921 r
.32943 .58344 .33536 .58902 .34481 .58649 .3389 .58091 Mtetra
.639 .74 .922 r
.3389 .58091 .34481 .58649 .3543 .58406 .3484 .57838 Mtetra
.626 .733 .924 r
.3484 .57838 .3543 .58406 .36378 .58244 .35793 .57613 Mtetra
.389 .612 .939 r
.35793 .57613 .36378 .58244 .37384 .56876 .36732 .57772 Mtetra
0 0 0 r
.36732 .57772 .37384 .56876 .38312 .57306 .37732 .56654 Mtetra
.594 .694 .912 r
.37732 .56654 .38312 .57306 .39273 .57078 .38692 .56505 Mtetra
.64 .738 .92 r
.38692 .56505 .39273 .57078 .4024 .56806 .3966 .56246 Mtetra
.649 .746 .92 r
.3966 .56246 .4024 .56806 .41211 .56518 .40633 .55962 Mtetra
.653 .749 .92 r
.40633 .55962 .41211 .56518 .42185 .56222 .4161 .55666 Mtetra
.656 .751 .92 r
.4161 .55666 .42185 .56222 .43163 .55919 .4259 .55364 Mtetra
.658 .753 .92 r
.4259 .55364 .43163 .55919 .44145 .55612 .43574 .55056 Mtetra
.659 .753 .92 r
.43574 .55056 .44145 .55612 .45131 .55302 .44562 .54745 Mtetra
.659 .754 .92 r
.44562 .54745 .45131 .55302 .4612 .54991 .45554 .54432 Mtetra
.45554 .54432 .4612 .54991 .47113 .54678 .46549 .54117 Mtetra
.46549 .54117 .47113 .54678 .48109 .54366 .47547 .53802 Mtetra
.659 .753 .92 r
.47547 .53802 .48109 .54366 .49109 .54052 .48549 .53486 Mtetra
.658 .753 .92 r
.48549 .53486 .49109 .54052 .50112 .53738 .49555 .5317 Mtetra
.49555 .5317 .50112 .53738 .51119 .53424 .50565 .52853 Mtetra
.50565 .52853 .51119 .53424 .5213 .53109 .51578 .52536 Mtetra
.51578 .52536 .5213 .53109 .53144 .52793 .52595 .52217 Mtetra
.52595 .52217 .53144 .52793 .54162 .52476 .53615 .51898 Mtetra
.53615 .51898 .54162 .52476 .55184 .52158 .5464 .51578 Mtetra
.657 .753 .92 r
.5464 .51578 .55184 .52158 .5621 .51839 .55668 .51257 Mtetra
.55668 .51257 .5621 .51839 .5724 .51519 .567 .50934 Mtetra
.567 .50934 .5724 .51519 .58273 .51198 .57736 .50611 Mtetra
.657 .752 .92 r
.57736 .50611 .58273 .51198 .5931 .50876 .58776 .50287 Mtetra
.58776 .50287 .5931 .50876 .60351 .50553 .59819 .49961 Mtetra
.59819 .49961 .60351 .50553 .61396 .50228 .60867 .49635 Mtetra
.60867 .49635 .61396 .50228 .62445 .49903 .61918 .49307 Mtetra
.61918 .49307 .62445 .49903 .63497 .49577 .62974 .48978 Mtetra
.62974 .48978 .63497 .49577 .64554 .49249 .64033 .48649 Mtetra
.64033 .48649 .64554 .49249 .65615 .4892 .65096 .48317 Mtetra
.65096 .48317 .65615 .4892 .66679 .4859 .66164 .47985 Mtetra
.66164 .47985 .66679 .4859 .67748 .48259 .67235 .47652 Mtetra
.67235 .47652 .67748 .48259 .68821 .47927 .68311 .47317 Mtetra
.68311 .47317 .68821 .47927 .69897 .47593 .6939 .46981 Mtetra
.6939 .46981 .69897 .47593 .70978 .47259 .70474 .46644 Mtetra
.70474 .46644 .70978 .47259 .72063 .46923 .71562 .46306 Mtetra
.71562 .46306 .72063 .46923 .73152 .46585 .72654 .45966 Mtetra
.72654 .45966 .73152 .46585 .74245 .46247 .7375 .45625 Mtetra
.7375 .45625 .74245 .46247 .75343 .45907 .7485 .45283 Mtetra
.7485 .45283 .75343 .45907 .76444 .45566 .75955 .4494 Mtetra
.75955 .4494 .76444 .45566 .7755 .45224 .77064 .44595 Mtetra
.77064 .44595 .7755 .45224 .7866 .44881 .78177 .44249 Mtetra
.78177 .44249 .7866 .44881 .79775 .44536 .79294 .43902 Mtetra
.79294 .43902 .79775 .44536 .80893 .4419 .80416 .43553 Mtetra
.80416 .43553 .80893 .4419 .82016 .43843 .81542 .43204 Mtetra
.81542 .43204 .82016 .43843 .83144 .43494 .82673 .42852 Mtetra
.82673 .42852 .83144 .43494 .84276 .43144 .83808 .425 Mtetra
.83808 .425 .84276 .43144 .85412 .42793 .84947 .42146 Mtetra
.84947 .42146 .85412 .42793 .86552 .4244 .86091 .41791 Mtetra
.86091 .41791 .86552 .4244 .87697 .42086 .87239 .41434 Mtetra
.87239 .41434 .87697 .42086 .88847 .41731 .88392 .41076 Mtetra
.88392 .41076 .88847 .41731 .90001 .41374 .89549 .40717 Mtetra
.626 .731 .923 r
.27638 .59261 .28245 .59826 .29172 .59617 .28568 .59041 Mtetra
.604 .721 .927 r
.28568 .59041 .29172 .59617 .3009 .59598 .29498 .58866 Mtetra
.918 .705 .598 r
.29498 .58866 .3009 .59598 .31073 .58635 .30848 .52263 Mtetra
0 0 .388 r
.30848 .52263 .31073 .58635 .32001 .58574 .31404 .57972 Mtetra
.613 .716 .919 r
.31404 .57972 .32001 .58574 .32943 .58344 .32346 .57778 Mtetra
.636 .737 .921 r
.32346 .57778 .32943 .58344 .3389 .58091 .33294 .5753 Mtetra
.64 .74 .921 r
.33294 .5753 .3389 .58091 .3484 .57838 .34247 .57272 Mtetra
.635 .738 .923 r
.34247 .57272 .3484 .57838 .35793 .57613 .35203 .57024 Mtetra
.597 .718 .929 r
.35203 .57024 .35793 .57613 .36732 .57772 .36158 .56858 Mtetra
.814 .697 .736 r
.36158 .56858 .36732 .57772 .37732 .56654 .37173 .5548 Mtetra
.373 .449 .811 r
.37173 .5548 .37732 .56654 .38692 .56505 .38108 .55909 Mtetra
.628 .727 .919 r
.38108 .55909 .38692 .56505 .3966 .56246 .39077 .55676 Mtetra
.646 .743 .92 r
.39077 .55676 .3966 .56246 .40633 .55962 .40052 .55399 Mtetra
.652 .748 .92 r
.40052 .55399 .40633 .55962 .4161 .55666 .41031 .55106 Mtetra
.655 .75 .92 r
.41031 .55106 .4161 .55666 .4259 .55364 .42013 .54804 Mtetra
.657 .752 .92 r
.42013 .54804 .4259 .55364 .43574 .55056 .43 .54496 Mtetra
.658 .753 .92 r
.43 .54496 .43574 .55056 .44562 .54745 .4399 .54184 Mtetra
.659 .754 .92 r
.4399 .54184 .44562 .54745 .45554 .54432 .44983 .53869 Mtetra
.44983 .53869 .45554 .54432 .46549 .54117 .45981 .53552 Mtetra
.45981 .53552 .46549 .54117 .47547 .53802 .46982 .53235 Mtetra
.46982 .53235 .47547 .53802 .48549 .53486 .47986 .52916 Mtetra
.658 .753 .92 r
.47986 .52916 .48549 .53486 .49555 .5317 .48995 .52598 Mtetra
.48995 .52598 .49555 .5317 .50565 .52853 .50006 .52279 Mtetra
.50006 .52279 .50565 .52853 .51578 .52536 .51022 .51959 Mtetra
.51022 .51959 .51578 .52536 .52595 .52217 .52042 .51638 Mtetra
.52042 .51638 .52595 .52217 .53615 .51898 .53065 .51316 Mtetra
.53065 .51316 .53615 .51898 .5464 .51578 .54092 .50994 Mtetra
.54092 .50994 .5464 .51578 .55668 .51257 .55122 .5067 Mtetra
.657 .753 .92 r
.55122 .5067 .55668 .51257 .567 .50934 .56157 .50346 Mtetra
.56157 .50346 .567 .50934 .57736 .50611 .57195 .5002 Mtetra
.57195 .5002 .57736 .50611 .58776 .50287 .58238 .49694 Mtetra
.657 .752 .92 r
.58238 .49694 .58776 .50287 .59819 .49961 .59284 .49366 Mtetra
.59284 .49366 .59819 .49961 .60867 .49635 .60334 .49037 Mtetra
.60334 .49037 .60867 .49635 .61918 .49307 .61388 .48707 Mtetra
.61388 .48707 .61918 .49307 .62974 .48978 .62446 .48376 Mtetra
.62446 .48376 .62974 .48978 .64033 .48649 .63508 .48044 Mtetra
.63508 .48044 .64033 .48649 .65096 .48317 .64575 .4771 Mtetra
.64575 .4771 .65096 .48317 .66164 .47985 .65645 .47376 Mtetra
.65645 .47376 .66164 .47985 .67235 .47652 .66719 .4704 Mtetra
.66719 .4704 .67235 .47652 .68311 .47317 .67797 .46703 Mtetra
.67797 .46703 .68311 .47317 .6939 .46981 .6888 .46365 Mtetra
.6888 .46365 .6939 .46981 .70474 .46644 .69966 .46025 Mtetra
.69966 .46025 .70474 .46644 .71562 .46306 .71057 .45684 Mtetra
.71057 .45684 .71562 .46306 .72654 .45966 .72152 .45342 Mtetra
.72152 .45342 .72654 .45966 .7375 .45625 .73251 .44999 Mtetra
.73251 .44999 .7375 .45625 .7485 .45283 .74354 .44655 Mtetra
.74354 .44655 .7485 .45283 .75955 .4494 .75462 .44309 Mtetra
.75462 .44309 .75955 .4494 .77064 .44595 .76574 .43962 Mtetra
.76574 .43962 .77064 .44595 .78177 .44249 .7769 .43613 Mtetra
.7769 .43613 .78177 .44249 .79294 .43902 .7881 .43264 Mtetra
.7881 .43264 .79294 .43902 .80416 .43553 .79935 .42912 Mtetra
.79935 .42912 .80416 .43553 .81542 .43204 .81064 .4256 Mtetra
.81064 .4256 .81542 .43204 .82673 .42852 .82198 .42206 Mtetra
.82198 .42206 .82673 .42852 .83808 .425 .83336 .41851 Mtetra
.83336 .41851 .83808 .425 .84947 .42146 .84479 .41495 Mtetra
.84479 .41495 .84947 .42146 .86091 .41791 .85626 .41137 Mtetra
.85626 .41137 .86091 .41791 .87239 .41434 .86777 .40778 Mtetra
.86777 .40778 .87239 .41434 .88392 .41076 .87934 .40417 Mtetra
.87934 .40417 .88392 .41076 .89549 .40717 .89094 .40055 Mtetra
.623 .728 .922 r
.27029 .58686 .27638 .59261 .28568 .59041 .2796 .5847 Mtetra
.622 .73 .924 r
.2796 .5847 .28568 .59041 .29498 .58866 .28894 .58255 Mtetra
.516 .678 .939 r
.28894 .58255 .29498 .58866 .30848 .52263 .2982 .58233 Mtetra
.475 .23 .462 r
.2982 .58233 .30848 .52263 .31404 .57972 .3081 .57262 Mtetra
.556 .66 .906 r
.3081 .57262 .31404 .57972 .32346 .57778 .31745 .57198 Mtetra
.63 .731 .92 r
.31745 .57198 .32346 .57778 .33294 .5753 .32695 .56963 Mtetra
.639 .739 .921 r
.32695 .56963 .33294 .5753 .34247 .57272 .3365 .56705 Mtetra
.639 .74 .922 r
.3365 .56705 .34247 .57272 .35203 .57024 .34608 .56447 Mtetra
.626 .733 .924 r
.34608 .56447 .35203 .57024 .36158 .56858 .35568 .56217 Mtetra
.39 .612 .939 r
.35568 .56217 .36158 .56858 .37173 .5548 .36514 .56373 Mtetra
0 0 0 r
.36514 .56373 .37173 .5548 .38108 .55909 .37523 .55246 Mtetra
.594 .694 .912 r
.37523 .55246 .38108 .55909 .39077 .55676 .38491 .55094 Mtetra
.64 .738 .92 r
.38491 .55094 .39077 .55676 .40052 .55399 .39467 .54829 Mtetra
.649 .746 .92 r
.39467 .54829 .40052 .55399 .41031 .55106 .40448 .5454 Mtetra
.653 .749 .92 r
.40448 .5454 .41031 .55106 .42013 .54804 .41432 .54239 Mtetra
.656 .751 .92 r
.41432 .54239 .42013 .54804 .43 .54496 .42421 .53932 Mtetra
.658 .753 .92 r
.42421 .53932 .43 .54496 .4399 .54184 .43413 .53619 Mtetra
.659 .753 .92 r
.43413 .53619 .4399 .54184 .44983 .53869 .44409 .53302 Mtetra
.659 .754 .92 r
.44409 .53302 .44983 .53869 .45981 .53552 .45409 .52984 Mtetra
.45409 .52984 .45981 .53552 .46982 .53235 .46412 .52664 Mtetra
.46412 .52664 .46982 .53235 .47986 .52916 .47419 .52343 Mtetra
.659 .753 .92 r
.47419 .52343 .47986 .52916 .48995 .52598 .4843 .52022 Mtetra
.658 .753 .92 r
.4843 .52022 .48995 .52598 .50006 .52279 .49444 .517 Mtetra
.49444 .517 .50006 .52279 .51022 .51959 .50463 .51378 Mtetra
.50463 .51378 .51022 .51959 .52042 .51638 .51484 .51055 Mtetra
.51484 .51055 .52042 .51638 .53065 .51316 .5251 .50731 Mtetra
.5251 .50731 .53065 .51316 .54092 .50994 .5354 .50406 Mtetra
.5354 .50406 .54092 .50994 .55122 .5067 .54573 .5008 Mtetra
.657 .753 .92 r
.54573 .5008 .55122 .5067 .56157 .50346 .5561 .49753 Mtetra
.5561 .49753 .56157 .50346 .57195 .5002 .56651 .49426 Mtetra
.56651 .49426 .57195 .5002 .58238 .49694 .57696 .49097 Mtetra
.657 .752 .92 r
.57696 .49097 .58238 .49694 .59284 .49366 .58745 .48767 Mtetra
.58745 .48767 .59284 .49366 .60334 .49037 .59798 .48435 Mtetra
.59798 .48435 .60334 .49037 .61388 .48707 .60855 .48103 Mtetra
.60855 .48103 .61388 .48707 .62446 .48376 .61915 .4777 Mtetra
.61915 .4777 .62446 .48376 .63508 .48044 .6298 .47435 Mtetra
.6298 .47435 .63508 .48044 .64575 .4771 .64049 .47099 Mtetra
.64049 .47099 .64575 .4771 .65645 .47376 .65122 .46762 Mtetra
.65122 .46762 .65645 .47376 .66719 .4704 .66199 .46424 Mtetra
.66199 .46424 .66719 .4704 .67797 .46703 .6728 .46084 Mtetra
.6728 .46084 .67797 .46703 .6888 .46365 .68365 .45744 Mtetra
.68365 .45744 .6888 .46365 .69966 .46025 .69455 .45402 Mtetra
.69455 .45402 .69966 .46025 .71057 .45684 .70548 .45059 Mtetra
.70548 .45059 .71057 .45684 .72152 .45342 .71646 .44714 Mtetra
.71646 .44714 .72152 .45342 .73251 .44999 .72748 .44369 Mtetra
.72748 .44369 .73251 .44999 .74354 .44655 .73854 .44021 Mtetra
.73854 .44021 .74354 .44655 .75462 .44309 .74965 .43673 Mtetra
.74965 .43673 .75462 .44309 .76574 .43962 .7608 .43324 Mtetra
.7608 .43324 .76574 .43962 .7769 .43613 .77199 .42973 Mtetra
.77199 .42973 .7769 .43613 .7881 .43264 .78323 .4262 Mtetra
.78323 .4262 .7881 .43264 .79935 .42912 .79451 .42267 Mtetra
.79451 .42267 .79935 .42912 .81064 .4256 .80583 .41912 Mtetra
.80583 .41912 .81064 .4256 .82198 .42206 .8172 .41556 Mtetra
.8172 .41556 .82198 .42206 .83336 .41851 .82861 .41198 Mtetra
.82861 .41198 .83336 .41851 .84479 .41495 .84007 .40839 Mtetra
.84007 .40839 .84479 .41495 .85626 .41137 .85158 .40478 Mtetra
.85158 .40478 .85626 .41137 .86777 .40778 .86312 .40117 Mtetra
.86312 .40117 .86777 .40778 .87934 .40417 .87472 .39753 Mtetra
.87472 .39753 .87934 .40417 .89094 .40055 .88636 .39389 Mtetra
.611 .716 .92 r
.26417 .58085 .27029 .58686 .2796 .5847 .27347 .57896 Mtetra
.626 .731 .923 r
.27347 .57896 .2796 .5847 .28894 .58255 .28284 .5767 Mtetra
.604 .721 .927 r
.28284 .5767 .28894 .58255 .2982 .58233 .29222 .57491 Mtetra
.919 .705 .597 r
.29222 .57491 .2982 .58233 .3081 .57262 .30587 .50857 Mtetra
0 0 .384 r
.30587 .50857 .3081 .57262 .31745 .57198 .31143 .56586 Mtetra
.613 .716 .919 r
.31143 .56586 .31745 .57198 .32695 .56963 .32092 .56388 Mtetra
.636 .737 .921 r
.32092 .56388 .32695 .56963 .3365 .56705 .33048 .56134 Mtetra
.64 .74 .921 r
.33048 .56134 .3365 .56705 .34608 .56447 .34009 .55872 Mtetra
.635 .738 .923 r
.34009 .55872 .34608 .56447 .35568 .56217 .34972 .55619 Mtetra
.597 .718 .929 r
.34972 .55619 .35568 .56217 .36514 .56373 .35935 .55448 Mtetra
.814 .698 .736 r
.35935 .55448 .36514 .56373 .37523 .55246 .36959 .54061 Mtetra
.372 .449 .811 r
.36959 .54061 .37523 .55246 .38491 .55094 .37901 .54487 Mtetra
.628 .727 .919 r
.37901 .54487 .38491 .55094 .39467 .54829 .38878 .5425 Mtetra
.646 .743 .92 r
.38878 .5425 .39467 .54829 .40448 .5454 .39861 .53967 Mtetra
.652 .748 .92 r
.39861 .53967 .40448 .5454 .41432 .54239 .40848 .53669 Mtetra
.655 .75 .92 r
.40848 .53669 .41432 .54239 .42421 .53932 .41838 .53362 Mtetra
.657 .752 .92 r
.41838 .53362 .42421 .53932 .43413 .53619 .42833 .53049 Mtetra
.658 .753 .92 r
.42833 .53049 .43413 .53619 .44409 .53302 .43831 .52731 Mtetra
.659 .754 .92 r
.43831 .52731 .44409 .53302 .45409 .52984 .44833 .52411 Mtetra
.44833 .52411 .45409 .52984 .46412 .52664 .45839 .52089 Mtetra
.45839 .52089 .46412 .52664 .47419 .52343 .46849 .51766 Mtetra
.46849 .51766 .47419 .52343 .4843 .52022 .47862 .51442 Mtetra
.658 .753 .92 r
.47862 .51442 .4843 .52022 .49444 .517 .48879 .51118 Mtetra
.48879 .51118 .49444 .517 .50463 .51378 .49899 .50793 Mtetra
.49899 .50793 .50463 .51378 .51484 .51055 .50923 .50468 Mtetra
.50923 .50468 .51484 .51055 .5251 .50731 .51952 .50141 Mtetra
.51952 .50141 .5251 .50731 .5354 .50406 .52984 .49814 Mtetra
.52984 .49814 .5354 .50406 .54573 .5008 .5402 .49486 Mtetra
.5402 .49486 .54573 .5008 .5561 .49753 .55059 .49157 Mtetra
.657 .753 .92 r
.55059 .49157 .5561 .49753 .56651 .49426 .56103 .48827 Mtetra
.56103 .48827 .56651 .49426 .57696 .49097 .5715 .48495 Mtetra
.5715 .48495 .57696 .49097 .58745 .48767 .58202 .48163 Mtetra
.657 .752 .92 r
.58202 .48163 .58745 .48767 .59798 .48435 .59258 .47829 Mtetra
.59258 .47829 .59798 .48435 .60855 .48103 .60317 .47495 Mtetra
.60317 .47495 .60855 .48103 .61915 .4777 .61381 .47159 Mtetra
.61381 .47159 .61915 .4777 .6298 .47435 .62448 .46822 Mtetra
.62448 .46822 .6298 .47435 .64049 .47099 .6352 .46484 Mtetra
.6352 .46484 .64049 .47099 .65122 .46762 .64595 .46144 Mtetra
.64595 .46144 .65122 .46762 .66199 .46424 .65675 .45804 Mtetra
.65675 .45804 .66199 .46424 .6728 .46084 .66759 .45462 Mtetra
.66759 .45462 .6728 .46084 .68365 .45744 .67847 .45119 Mtetra
.67847 .45119 .68365 .45744 .69455 .45402 .6894 .44774 Mtetra
.6894 .44774 .69455 .45402 .70548 .45059 .70036 .44429 Mtetra
.70036 .44429 .70548 .45059 .71646 .44714 .71137 .44082 Mtetra
.71137 .44082 .71646 .44714 .72748 .44369 .72242 .43733 Mtetra
.72242 .43733 .72748 .44369 .73854 .44021 .73351 .43384 Mtetra
.73351 .43384 .73854 .44021 .74965 .43673 .74465 .43033 Mtetra
.74465 .43033 .74965 .43673 .7608 .43324 .75583 .42681 Mtetra
.75583 .42681 .7608 .43324 .77199 .42973 .76705 .42327 Mtetra
.76705 .42327 .77199 .42973 .78323 .4262 .77832 .41973 Mtetra
.77832 .41973 .78323 .4262 .79451 .42267 .78963 .41616 Mtetra
.78963 .41616 .79451 .42267 .80583 .41912 .80099 .41259 Mtetra
.80099 .41259 .80583 .41912 .8172 .41556 .81239 .409 Mtetra
.81239 .409 .8172 .41556 .82861 .41198 .82383 .4054 Mtetra
.82383 .4054 .82861 .41198 .84007 .40839 .83532 .40178 Mtetra
.83532 .40178 .84007 .40839 .85158 .40478 .84686 .39815 Mtetra
.84686 .39815 .85158 .40478 .86312 .40117 .85844 .3945 Mtetra
.85844 .3945 .86312 .40117 .87472 .39753 .87007 .39085 Mtetra
.87007 .39085 .87472 .39753 .88636 .39389 .88174 .38717 Mtetra
.565 .673 .911 r
.25807 .57401 .26417 .58085 .27347 .57896 .26732 .57311 Mtetra
.623 .728 .922 r
.26732 .57311 .27347 .57896 .28284 .5767 .2767 .5709 Mtetra
.622 .73 .924 r
.2767 .5709 .28284 .5767 .29222 .57491 .28612 .56871 Mtetra
.516 .678 .939 r
.28612 .56871 .29222 .57491 .30587 .50857 .29544 .56845 Mtetra
.471 .224 .458 r
.29544 .56845 .30587 .50857 .31143 .56586 .30543 .55866 Mtetra
.556 .66 .906 r
.30543 .55866 .31143 .56586 .32092 .56388 .31486 .55798 Mtetra
.63 .731 .92 r
.31486 .55798 .32092 .56388 .33048 .56134 .32443 .55558 Mtetra
.639 .739 .921 r
.32443 .55558 .33048 .56134 .34009 .55872 .33405 .55295 Mtetra
.639 .74 .922 r
.33405 .55295 .34009 .55872 .34972 .55619 .34371 .55032 Mtetra
.626 .733 .924 r
.34371 .55032 .34972 .55619 .35935 .55448 .35339 .54798 Mtetra
.391 .612 .938 r
.35339 .54798 .35935 .55448 .36959 .54061 .36293 .5495 Mtetra
0 0 0 r
.36293 .5495 .36959 .54061 .37901 .54487 .37311 .53815 Mtetra
.593 .694 .913 r
.37311 .53815 .37901 .54487 .38878 .5425 .38286 .53657 Mtetra
.64 .738 .92 r
.38286 .53657 .38878 .5425 .39861 .53967 .3927 .53387 Mtetra
.649 .746 .92 r
.3927 .53387 .39861 .53967 .40848 .53669 .40259 .53093 Mtetra
.653 .749 .92 r
.40259 .53093 .40848 .53669 .41838 .53362 .41252 .52787 Mtetra
.656 .751 .92 r
.41252 .52787 .41838 .53362 .42833 .53049 .42249 .52474 Mtetra
.658 .753 .92 r
.42249 .52474 .42833 .53049 .43831 .52731 .43249 .52156 Mtetra
.659 .753 .92 r
.43249 .52156 .43831 .52731 .44833 .52411 .44254 .51834 Mtetra
.659 .754 .92 r
.44254 .51834 .44833 .52411 .45839 .52089 .45262 .5151 Mtetra
.45262 .5151 .45839 .52089 .46849 .51766 .46274 .51185 Mtetra
.46274 .51185 .46849 .51766 .47862 .51442 .47289 .50858 Mtetra
.659 .753 .92 r
.47289 .50858 .47862 .51442 .48879 .51118 .48309 .50532 Mtetra
.658 .753 .92 r
.48309 .50532 .48879 .51118 .49899 .50793 .49332 .50204 Mtetra
.49332 .50204 .49899 .50793 .50923 .50468 .50359 .49876 Mtetra
.50359 .49876 .50923 .50468 .51952 .50141 .51389 .49548 Mtetra
.51389 .49548 .51952 .50141 .52984 .49814 .52424 .49218 Mtetra
.52424 .49218 .52984 .49814 .5402 .49486 .53462 .48888 Mtetra
.53462 .48888 .5402 .49486 .55059 .49157 .54505 .48556 Mtetra
.657 .753 .92 r
.54505 .48556 .55059 .49157 .56103 .48827 .55551 .48223 Mtetra
.55551 .48223 .56103 .48827 .5715 .48495 .56601 .4789 Mtetra
.56601 .4789 .5715 .48495 .58202 .48163 .57655 .47555 Mtetra
.657 .752 .92 r
.57655 .47555 .58202 .48163 .59258 .47829 .58713 .47219 Mtetra
.58713 .47219 .59258 .47829 .60317 .47495 .59776 .46882 Mtetra
.59776 .46882 .60317 .47495 .61381 .47159 .60842 .46544 Mtetra
.60842 .46544 .61381 .47159 .62448 .46822 .61912 .46204 Mtetra
.61912 .46204 .62448 .46822 .6352 .46484 .62987 .45864 Mtetra
.62987 .45864 .6352 .46484 .64595 .46144 .64065 .45522 Mtetra
.64065 .45522 .64595 .46144 .65675 .45804 .65148 .45179 Mtetra
.65148 .45179 .65675 .45804 .66759 .45462 .66235 .44834 Mtetra
.66235 .44834 .66759 .45462 .67847 .45119 .67326 .44489 Mtetra
.67326 .44489 .67847 .45119 .6894 .44774 .68421 .44142 Mtetra
.68421 .44142 .6894 .44774 .70036 .44429 .6952 .43794 Mtetra
.6952 .43794 .70036 .44429 .71137 .44082 .70624 .43444 Mtetra
.70624 .43444 .71137 .44082 .72242 .43733 .71732 .43094 Mtetra
.71732 .43094 .72242 .43733 .73351 .43384 .72844 .42742 Mtetra
.72844 .42742 .73351 .43384 .74465 .43033 .73961 .42388 Mtetra
.73961 .42388 .74465 .43033 .75583 .42681 .75082 .42034 Mtetra
.75082 .42034 .75583 .42681 .76705 .42327 .76208 .41677 Mtetra
.76208 .41677 .76705 .42327 .77832 .41973 .77337 .4132 Mtetra
.77337 .4132 .77832 .41973 .78963 .41616 .78472 .40961 Mtetra
.78472 .40961 .78963 .41616 .80099 .41259 .7961 .40601 Mtetra
.7961 .40601 .80099 .41259 .81239 .409 .80754 .4024 Mtetra
.80754 .4024 .81239 .409 .82383 .4054 .81901 .39877 Mtetra
.81901 .39877 .82383 .4054 .83532 .40178 .83054 .39512 Mtetra
.83054 .39512 .83532 .40178 .84686 .39815 .84211 .39147 Mtetra
.84211 .39147 .84686 .39815 .85844 .3945 .85372 .38779 Mtetra
.85372 .38779 .85844 .3945 .87007 .39085 .86538 .38411 Mtetra
.86538 .38411 .87007 .39085 .88174 .38717 .87709 .38041 Mtetra
.121 .181 .653 r
.25294 .55481 .25807 .57401 .26732 .57311 .26114 .56701 Mtetra
.611 .716 .92 r
.26114 .56701 .26732 .57311 .2767 .5709 .27051 .56507 Mtetra
.626 .731 .923 r
.27051 .56507 .2767 .5709 .28612 .56871 .27996 .56276 Mtetra
.604 .721 .927 r
.27996 .56276 .28612 .56871 .29544 .56845 .28941 .56093 Mtetra
.92 .706 .596 r
.28941 .56093 .29544 .56845 .30543 .55866 .30323 .49427 Mtetra
0 0 .379 r
.30323 .49427 .30543 .55866 .31486 .55798 .30877 .55176 Mtetra
.613 .716 .919 r
.30877 .55176 .31486 .55798 .32443 .55558 .31834 .54973 Mtetra
.636 .737 .921 r
.31834 .54973 .32443 .55558 .33405 .55295 .32798 .54715 Mtetra
.64 .74 .921 r
.32798 .54715 .33405 .55295 .34371 .55032 .33766 .54447 Mtetra
.635 .738 .923 r
.33766 .54447 .34371 .55032 .35339 .54798 .34737 .54189 Mtetra
.597 .718 .929 r
.34737 .54189 .35339 .54798 .36293 .5495 .35708 .54014 Mtetra
.815 .699 .737 r
.35708 .54014 .36293 .5495 .37311 .53815 .36741 .52617 Mtetra
.37 .448 .811 r
.36741 .52617 .37311 .53815 .38286 .53657 .37691 .53041 Mtetra
.628 .727 .919 r
.37691 .53041 .38286 .53657 .3927 .53387 .38676 .52798 Mtetra
.646 .743 .92 r
.38676 .52798 .3927 .53387 .40259 .53093 .39666 .52511 Mtetra
.652 .748 .92 r
.39666 .52511 .40259 .53093 .41252 .52787 .40661 .52207 Mtetra
.655 .75 .92 r
.40661 .52207 .41252 .52787 .42249 .52474 .41661 .51895 Mtetra
.657 .752 .92 r
.41661 .51895 .42249 .52474 .43249 .52156 .42664 .51576 Mtetra
.658 .753 .92 r
.42664 .51576 .43249 .52156 .44254 .51834 .4367 .51253 Mtetra
.659 .754 .92 r
.4367 .51253 .44254 .51834 .45262 .5151 .44681 .50927 Mtetra
.44681 .50927 .45262 .5151 .46274 .51185 .45695 .506 Mtetra
.45695 .506 .46274 .51185 .47289 .50858 .46713 .50271 Mtetra
.46713 .50271 .47289 .50858 .48309 .50532 .47735 .49942 Mtetra
.658 .753 .92 r
.47735 .49942 .48309 .50532 .49332 .50204 .4876 .49612 Mtetra
.4876 .49612 .49332 .50204 .50359 .49876 .4979 .49281 Mtetra
.4979 .49281 .50359 .49876 .51389 .49548 .50823 .4895 Mtetra
.50823 .4895 .51389 .49548 .52424 .49218 .5186 .48618 Mtetra
.5186 .48618 .52424 .49218 .53462 .48888 .52901 .48285 Mtetra
.52901 .48285 .53462 .48888 .54505 .48556 .53946 .47951 Mtetra
.53946 .47951 .54505 .48556 .55551 .48223 .54995 .47616 Mtetra
.657 .753 .92 r
.54995 .47616 .55551 .48223 .56601 .4789 .56048 .4728 Mtetra
.56048 .4728 .56601 .4789 .57655 .47555 .57105 .46943 Mtetra
.57105 .46943 .57655 .47555 .58713 .47219 .58166 .46605 Mtetra
.657 .752 .92 r
.58166 .46605 .58713 .47219 .59776 .46882 .59231 .46265 Mtetra
.59231 .46265 .59776 .46882 .60842 .46544 .603 .45924 Mtetra
.603 .45924 .60842 .46544 .61912 .46204 .61373 .45582 Mtetra
.61373 .45582 .61912 .46204 .62987 .45864 .6245 .45239 Mtetra
.6245 .45239 .62987 .45864 .64065 .45522 .63531 .44895 Mtetra
.63531 .44895 .64065 .45522 .65148 .45179 .64617 .4455 Mtetra
.64617 .4455 .65148 .45179 .66235 .44834 .65706 .44203 Mtetra
.65706 .44203 .66235 .44834 .67326 .44489 .668 .43855 Mtetra
.668 .43855 .67326 .44489 .68421 .44142 .67898 .43505 Mtetra
.67898 .43505 .68421 .44142 .6952 .43794 .69001 .43155 Mtetra
.69001 .43155 .6952 .43794 .70624 .43444 .70107 .42803 Mtetra
.70107 .42803 .70624 .43444 .71732 .43094 .71218 .42449 Mtetra
.71218 .42449 .71732 .43094 .72844 .42742 .72334 .42095 Mtetra
.72334 .42095 .72844 .42742 .73961 .42388 .73454 .41739 Mtetra
.73454 .41739 .73961 .42388 .75082 .42034 .74578 .41381 Mtetra
.74578 .41381 .75082 .42034 .76208 .41677 .75706 .41023 Mtetra
.75706 .41023 .76208 .41677 .77337 .4132 .76839 .40663 Mtetra
.76839 .40663 .77337 .4132 .78472 .40961 .77977 .40301 Mtetra
.77977 .40301 .78472 .40961 .7961 .40601 .79119 .39939 Mtetra
.79119 .39939 .7961 .40601 .80754 .4024 .80265 .39574 Mtetra
.80265 .39574 .80754 .4024 .81901 .39877 .81416 .39209 Mtetra
.81416 .39209 .81901 .39877 .83054 .39512 .82572 .38842 Mtetra
.82572 .38842 .83054 .39512 .84211 .39147 .83732 .38473 Mtetra
.83732 .38473 .84211 .39147 .85372 .38779 .84897 .38103 Mtetra
.84897 .38103 .85372 .38779 .86538 .38411 .86066 .37732 Mtetra
.86066 .37732 .86538 .38411 .87709 .38041 .87241 .37359 Mtetra
.081 0 .073 r
.24497 .57007 .25294 .55481 .26114 .56701 .25498 .56007 Mtetra
.565 .673 .911 r
.25498 .56007 .26114 .56701 .27051 .56507 .2643 .55913 Mtetra
.623 .728 .922 r
.2643 .55913 .27051 .56507 .27996 .56276 .27375 .55687 Mtetra
.622 .73 .924 r
.27375 .55687 .27996 .56276 .28941 .56093 .28324 .55463 Mtetra
.517 .678 .938 r
.28324 .55463 .28941 .56093 .30323 .49427 .29264 .55433 Mtetra
.467 .219 .454 r
.29264 .55433 .30323 .49427 .30877 .55176 .30272 .54446 Mtetra
.556 .66 .906 r
.30272 .54446 .30877 .55176 .31834 .54973 .31222 .54373 Mtetra
.63 .731 .92 r
.31222 .54373 .31834 .54973 .32798 .54715 .32187 .54129 Mtetra
.639 .739 .921 r
.32187 .54129 .32798 .54715 .33766 .54447 .33157 .53861 Mtetra
.639 .74 .922 r
.33157 .53861 .33766 .54447 .34737 .54189 .3413 .53593 Mtetra
.626 .733 .924 r
.3413 .53593 .34737 .54189 .35708 .54014 .35107 .53353 Mtetra
.392 .613 .938 r
.35107 .53353 .35708 .54014 .36741 .52617 .36068 .53503 Mtetra
0 0 0 r
.36068 .53503 .36741 .52617 .37691 .53041 .37094 .52358 Mtetra
.593 .694 .913 r
.37094 .52358 .37691 .53041 .38676 .52798 .38078 .52196 Mtetra
.64 .738 .92 r
.38078 .52196 .38676 .52798 .39666 .52511 .3907 .51921 Mtetra
.649 .746 .92 r
.3907 .51921 .39666 .52511 .40661 .52207 .40067 .51621 Mtetra
.653 .749 .92 r
.40067 .51621 .40661 .52207 .41661 .51895 .41068 .5131 Mtetra
.656 .751 .92 r
.41068 .5131 .41661 .51895 .42664 .51576 .42074 .50992 Mtetra
.658 .753 .92 r
.42074 .50992 .42664 .51576 .4367 .51253 .43083 .50668 Mtetra
.659 .753 .92 r
.43083 .50668 .4367 .51253 .44681 .50927 .44096 .5034 Mtetra
.659 .754 .92 r
.44096 .5034 .44681 .50927 .45695 .506 .45112 .50011 Mtetra
.45112 .50011 .45695 .506 .46713 .50271 .46133 .49679 Mtetra
.46133 .49679 .46713 .50271 .47735 .49942 .47157 .49348 Mtetra
.659 .753 .92 r
.47157 .49348 .47735 .49942 .4876 .49612 .48185 .49015 Mtetra
.658 .753 .92 r
.48185 .49015 .4876 .49612 .4979 .49281 .49217 .48682 Mtetra
.49217 .48682 .4979 .49281 .50823 .4895 .50253 .48348 Mtetra
.50253 .48348 .50823 .4895 .5186 .48618 .51293 .48014 Mtetra
.51293 .48014 .5186 .48618 .52901 .48285 .52336 .47678 Mtetra
.52336 .47678 .52901 .48285 .53946 .47951 .53384 .47342 Mtetra
.53384 .47342 .53946 .47951 .54995 .47616 .54435 .47005 Mtetra
.657 .753 .92 r
.54435 .47005 .54995 .47616 .56048 .4728 .55491 .46666 Mtetra
.55491 .46666 .56048 .4728 .57105 .46943 .5655 .46326 Mtetra
.5655 .46326 .57105 .46943 .58166 .46605 .57614 .45986 Mtetra
.657 .752 .92 r
.57614 .45986 .58166 .46605 .59231 .46265 .58682 .45644 Mtetra
.58682 .45644 .59231 .46265 .603 .45924 .59753 .45301 Mtetra
.59753 .45301 .603 .45924 .61373 .45582 .60829 .44956 Mtetra
.60829 .44956 .61373 .45582 .6245 .45239 .61909 .44611 Mtetra
.61909 .44611 .6245 .45239 .63531 .44895 .62993 .44264 Mtetra
.62993 .44264 .63531 .44895 .64617 .4455 .64082 .43916 Mtetra
.64082 .43916 .64617 .4455 .65706 .44203 .65174 .43566 Mtetra
.65174 .43566 .65706 .44203 .668 .43855 .66271 .43216 Mtetra
.66271 .43216 .668 .43855 .67898 .43505 .67372 .42864 Mtetra
.67372 .42864 .67898 .43505 .69001 .43155 .68477 .42511 Mtetra
.68477 .42511 .69001 .43155 .70107 .42803 .69587 .42156 Mtetra
.69587 .42156 .70107 .42803 .71218 .42449 .70701 .418 Mtetra
.70701 .418 .71218 .42449 .72334 .42095 .7182 .41443 Mtetra
.7182 .41443 .72334 .42095 .73454 .41739 .72942 .41085 Mtetra
.72942 .41085 .73454 .41739 .74578 .41381 .7407 .40725 Mtetra
.7407 .40725 .74578 .41381 .75706 .41023 .75201 .40363 Mtetra
.75201 .40363 .75706 .41023 .76839 .40663 .76337 .40001 Mtetra
.76337 .40001 .76839 .40663 .77977 .40301 .77478 .39637 Mtetra
.77478 .39637 .77977 .40301 .79119 .39939 .78623 .39271 Mtetra
.78623 .39271 .79119 .39939 .80265 .39574 .79773 .38904 Mtetra
.79773 .38904 .80265 .39574 .81416 .39209 .80927 .38536 Mtetra
.80927 .38536 .81416 .39209 .82572 .38842 .82086 .38166 Mtetra
.82086 .38166 .82572 .38842 .83732 .38473 .8325 .37795 Mtetra
.8325 .37795 .83732 .38473 .84897 .38103 .84418 .37422 Mtetra
.84418 .37422 .84897 .38103 .86066 .37732 .85591 .37048 Mtetra
.85591 .37048 .86066 .37732 .87241 .37359 .86769 .36673 Mtetra
.86 .713 .698 r
.23884 .56194 .24497 .57007 .25498 .56007 .2498 .54072 Mtetra
.117 .179 .652 r
.2498 .54072 .25498 .56007 .2643 .55913 .25805 .55293 Mtetra
.611 .716 .92 r
.25805 .55293 .2643 .55913 .27375 .55687 .26751 .55094 Mtetra
.626 .731 .923 r
.26751 .55094 .27375 .55687 .28324 .55463 .27702 .54859 Mtetra
.604 .721 .927 r
.27702 .54859 .28324 .55463 .29264 .55433 .28655 .5467 Mtetra
.921 .706 .595 r
.28655 .5467 .29264 .55433 .30272 .54446 .30053 .47973 Mtetra
0 0 .375 r
.30053 .47973 .30272 .54446 .31222 .54373 .30607 .53742 Mtetra
.613 .716 .919 r
.30607 .53742 .31222 .54373 .32187 .54129 .31572 .53534 Mtetra
.636 .737 .921 r
.31572 .53534 .32187 .54129 .33157 .53861 .32543 .53271 Mtetra
.64 .74 .921 r
.32543 .53271 .33157 .53861 .3413 .53593 .33519 .52998 Mtetra
.635 .738 .923 r
.33519 .52998 .3413 .53593 .35107 .53353 .34498 .52735 Mtetra
.597 .718 .929 r
.34498 .52735 .35107 .53353 .36068 .53503 .35477 .52555 Mtetra
.816 .7 .737 r
.35477 .52555 .36068 .53503 .37094 .52358 .36519 .51148 Mtetra
.369 .447 .811 r
.36519 .51148 .37094 .52358 .38078 .52196 .37476 .5157 Mtetra
.628 .727 .919 r
.37476 .5157 .38078 .52196 .3907 .51921 .3847 .51322 Mtetra
.646 .743 .92 r
.3847 .51322 .3907 .51921 .40067 .51621 .39469 .51029 Mtetra
.652 .748 .92 r
.39469 .51029 .40067 .51621 .41068 .5131 .40472 .5072 Mtetra
.655 .75 .92 r
.40472 .5072 .41068 .5131 .42074 .50992 .4148 .50402 Mtetra
.657 .752 .92 r
.4148 .50402 .42074 .50992 .43083 .50668 .42491 .50078 Mtetra
.658 .753 .92 r
.42491 .50078 .43083 .50668 .44096 .5034 .43506 .49749 Mtetra
.659 .754 .92 r
.43506 .49749 .44096 .5034 .45112 .50011 .44525 .49417 Mtetra
.44525 .49417 .45112 .50011 .46133 .49679 .45548 .49084 Mtetra
.45548 .49084 .46133 .49679 .47157 .49348 .46575 .4875 Mtetra
.46575 .4875 .47157 .49348 .48185 .49015 .47606 .48414 Mtetra
.658 .753 .92 r
.47606 .48414 .48185 .49015 .49217 .48682 .4864 .48079 Mtetra
.4864 .48079 .49217 .48682 .50253 .48348 .49679 .47743 Mtetra
.49679 .47743 .50253 .48348 .51293 .48014 .50721 .47405 Mtetra
.50721 .47405 .51293 .48014 .52336 .47678 .51767 .47068 Mtetra
.51767 .47068 .52336 .47678 .53384 .47342 .52817 .46729 Mtetra
.52817 .46729 .53384 .47342 .54435 .47005 .53871 .46389 Mtetra
.53871 .46389 .54435 .47005 .55491 .46666 .5493 .46048 Mtetra
.657 .753 .92 r
.5493 .46048 .55491 .46666 .5655 .46326 .55992 .45706 Mtetra
.55992 .45706 .5655 .46326 .57614 .45986 .57058 .45362 Mtetra
.57058 .45362 .57614 .45986 .58682 .45644 .58129 .45018 Mtetra
.657 .752 .92 r
.58129 .45018 .58682 .45644 .59753 .45301 .59203 .44672 Mtetra
.59203 .44672 .59753 .45301 .60829 .44956 .60282 .44325 Mtetra
.60282 .44325 .60829 .44956 .61909 .44611 .61365 .43977 Mtetra
.61365 .43977 .61909 .44611 .62993 .44264 .62452 .43628 Mtetra
.62452 .43628 .62993 .44264 .64082 .43916 .63543 .43277 Mtetra
.63543 .43277 .64082 .43916 .65174 .43566 .64638 .42926 Mtetra
.64638 .42926 .65174 .43566 .66271 .43216 .65738 .42572 Mtetra
.65738 .42572 .66271 .43216 .67372 .42864 .66842 .42218 Mtetra
.66842 .42218 .67372 .42864 .68477 .42511 .6795 .41862 Mtetra
.6795 .41862 .68477 .42511 .69587 .42156 .69063 .41505 Mtetra
.69063 .41505 .69587 .42156 .70701 .418 .7018 .41147 Mtetra
.7018 .41147 .70701 .418 .7182 .41443 .71302 .40787 Mtetra
.71302 .40787 .7182 .41443 .72942 .41085 .72427 .40426 Mtetra
.72427 .40426 .72942 .41085 .7407 .40725 .73558 .40063 Mtetra
.73558 .40063 .7407 .40725 .75201 .40363 .74693 .39699 Mtetra
.74693 .39699 .75201 .40363 .76337 .40001 .75832 .39334 Mtetra
.75832 .39334 .76337 .40001 .77478 .39637 .76976 .38967 Mtetra
.76976 .38967 .77478 .39637 .78623 .39271 .78124 .38599 Mtetra
.78124 .38599 .78623 .39271 .79773 .38904 .79277 .38229 Mtetra
.79277 .38229 .79773 .38904 .80927 .38536 .80435 .37858 Mtetra
.80435 .37858 .80927 .38536 .82086 .38166 .81597 .37486 Mtetra
.81597 .37486 .82086 .38166 .8325 .37795 .82764 .37112 Mtetra
.82764 .37112 .8325 .37795 .84418 .37422 .83936 .36736 Mtetra
.83936 .36736 .84418 .37422 .85591 .37048 .85112 .36359 Mtetra
.85112 .36359 .85591 .37048 .86769 .36673 .86293 .35981 Mtetra
.463 .652 .941 r
.23254 .55551 .23884 .56194 .2498 .54072 .24174 .55597 Mtetra
.068 0 .06 r
.24174 .55597 .2498 .54072 .25805 .55293 .25184 .54589 Mtetra
.565 .673 .911 r
.25184 .54589 .25805 .55293 .26751 .55094 .26122 .5449 Mtetra
.623 .728 .922 r
.26122 .5449 .26751 .55094 .27702 .54859 .27075 .54259 Mtetra
.622 .73 .924 r
.27075 .54259 .27702 .54859 .28655 .5467 .28032 .54031 Mtetra
.517 .678 .938 r
.28032 .54031 .28655 .5467 .30053 .47973 .28979 .53997 Mtetra
.462 .213 .449 r
.28979 .53997 .30053 .47973 .30607 .53742 .29996 .53001 Mtetra
.555 .66 .906 r
.29996 .53001 .30607 .53742 .31572 .53534 .30953 .52925 Mtetra
.63 .731 .92 r
.30953 .52925 .31572 .53534 .32543 .53271 .31926 .52675 Mtetra
.639 .739 .921 r
.31926 .52675 .32543 .53271 .33519 .52998 .32904 .52402 Mtetra
.639 .74 .922 r
.32904 .52402 .33519 .52998 .34498 .52735 .33886 .52128 Mtetra
.626 .733 .924 r
.33886 .52128 .34498 .52735 .35477 .52555 .3487 .51884 Mtetra
.393 .613 .938 r
.3487 .51884 .35477 .52555 .36519 .51148 .35838 .5203 Mtetra
0 0 0 r
.35838 .5203 .36519 .51148 .37476 .5157 .36874 .50876 Mtetra
.593 .694 .913 r
.36874 .50876 .37476 .5157 .3847 .51322 .37866 .50709 Mtetra
.64 .738 .92 r
.37866 .50709 .3847 .51322 .39469 .51029 .38866 .50429 Mtetra
.649 .746 .92 r
.38866 .50429 .39469 .51029 .40472 .5072 .39872 .50123 Mtetra
.653 .749 .92 r
.39872 .50123 .40472 .5072 .4148 .50402 .40881 .49807 Mtetra
.656 .751 .92 r
.40881 .49807 .4148 .50402 .42491 .50078 .41895 .49483 Mtetra
.658 .753 .92 r
.41895 .49483 .42491 .50078 .43506 .49749 .42913 .49153 Mtetra
.659 .753 .92 r
.42913 .49153 .43506 .49749 .44525 .49417 .43935 .4882 Mtetra
.659 .754 .92 r
.43935 .4882 .44525 .49417 .45548 .49084 .4496 .48484 Mtetra
.4496 .48484 .45548 .49084 .46575 .4875 .45989 .48147 Mtetra
.45989 .48147 .46575 .4875 .47606 .48414 .47022 .4781 Mtetra
.659 .753 .92 r
.47022 .4781 .47606 .48414 .4864 .48079 .48059 .47471 Mtetra
.658 .753 .92 r
.48059 .47471 .4864 .48079 .49679 .47743 .491 .47133 Mtetra
.491 .47133 .49679 .47743 .50721 .47405 .50145 .46793 Mtetra
.50145 .46793 .50721 .47405 .51767 .47068 .51194 .46452 Mtetra
.51194 .46452 .51767 .47068 .52817 .46729 .52247 .46111 Mtetra
.52247 .46111 .52817 .46729 .53871 .46389 .53304 .45769 Mtetra
.53304 .45769 .53871 .46389 .5493 .46048 .54365 .45425 Mtetra
.657 .753 .92 r
.54365 .45425 .5493 .46048 .55992 .45706 .55429 .4508 Mtetra
.55429 .4508 .55992 .45706 .57058 .45362 .56499 .44735 Mtetra
.56499 .44735 .57058 .45362 .58129 .45018 .57572 .44388 Mtetra
.657 .752 .92 r
.57572 .44388 .58129 .45018 .59203 .44672 .58649 .4404 Mtetra
.58649 .4404 .59203 .44672 .60282 .44325 .5973 .4369 Mtetra
.5973 .4369 .60282 .44325 .61365 .43977 .60816 .4334 Mtetra
.60816 .4334 .61365 .43977 .62452 .43628 .61906 .42988 Mtetra
.61906 .42988 .62452 .43628 .63543 .43277 .63 .42635 Mtetra
.63 .42635 .63543 .43277 .64638 .42926 .64098 .4228 Mtetra
.64098 .4228 .64638 .42926 .65738 .42572 .65201 .41924 Mtetra
.65201 .41924 .65738 .42572 .66842 .42218 .66308 .41567 Mtetra
.66308 .41567 .66842 .42218 .6795 .41862 .67419 .41209 Mtetra
.67419 .41209 .6795 .41862 .69063 .41505 .68535 .40849 Mtetra
.68535 .40849 .69063 .41505 .7018 .41147 .69655 .40488 Mtetra
.69655 .40488 .7018 .41147 .71302 .40787 .7078 .40126 Mtetra
.7078 .40126 .71302 .40787 .72427 .40426 .71909 .39762 Mtetra
.71909 .39762 .72427 .40426 .73558 .40063 .73042 .39397 Mtetra
.73042 .39397 .73558 .40063 .74693 .39699 .7418 .3903 Mtetra
.7418 .3903 .74693 .39699 .75832 .39334 .75323 .38662 Mtetra
.75323 .38662 .75832 .39334 .76976 .38967 .7647 .38292 Mtetra
.7647 .38292 .76976 .38967 .78124 .38599 .77621 .37922 Mtetra
.77621 .37922 .78124 .38599 .79277 .38229 .78778 .37549 Mtetra
.78778 .37549 .79277 .38229 .80435 .37858 .79939 .37175 Mtetra
.79939 .37175 .80435 .37858 .81597 .37486 .81104 .368 Mtetra
.81104 .368 .81597 .37486 .82764 .37112 .82274 .36423 Mtetra
.82274 .36423 .82764 .37112 .83936 .36736 .83449 .36045 Mtetra
.83449 .36045 .83936 .36736 .85112 .36359 .84629 .35665 Mtetra
.84629 .35665 .85112 .36359 .86293 .35981 .85814 .35284 Mtetra
.591 .714 .929 r
.22617 .54938 .23254 .55551 .24174 .55597 .23555 .54773 Mtetra
.861 .714 .698 r
.23555 .54773 .24174 .55597 .25184 .54589 .24662 .52638 Mtetra
.113 .176 .65 r
.24662 .52638 .25184 .54589 .26122 .5449 .25492 .5386 Mtetra
.611 .716 .92 r
.25492 .5386 .26122 .5449 .27075 .54259 .26444 .53657 Mtetra
.626 .731 .923 r
.26444 .53657 .27075 .54259 .28032 .54031 .27404 .53417 Mtetra
.604 .721 .927 r
.27404 .53417 .28032 .54031 .28979 .53997 .28364 .53223 Mtetra
.922 .707 .593 r
.28364 .53223 .28979 .53997 .29996 .53001 .29779 .46494 Mtetra
0 0 .37 r
.29779 .46494 .29996 .53001 .30953 .52925 .30332 .52283 Mtetra
.613 .716 .919 r
.30332 .52283 .30953 .52925 .31926 .52675 .31305 .5207 Mtetra
.636 .737 .921 r
.31305 .5207 .31926 .52675 .32904 .52402 .32284 .51802 Mtetra
.64 .74 .921 r
.32284 .51802 .32904 .52402 .33886 .52128 .33268 .51524 Mtetra
.635 .738 .923 r
.33268 .51524 .33886 .52128 .3487 .51884 .34255 .51256 Mtetra
.597 .718 .929 r
.34255 .51256 .3487 .51884 .35838 .5203 .35242 .5107 Mtetra
.816 .7 .737 r
.35242 .5107 .35838 .5203 .36874 .50876 .36294 .49653 Mtetra
.368 .447 .811 r
.36294 .49653 .36874 .50876 .37866 .50709 .37258 .50072 Mtetra
.628 .727 .919 r
.37258 .50072 .37866 .50709 .38866 .50429 .3826 .49819 Mtetra
.646 .743 .92 r
.3826 .49819 .38866 .50429 .39872 .50123 .39267 .49521 Mtetra
.652 .748 .92 r
.39267 .49521 .39872 .50123 .40881 .49807 .40279 .49206 Mtetra
.655 .75 .92 r
.40279 .49206 .40881 .49807 .41895 .49483 .41295 .48882 Mtetra
.657 .752 .92 r
.41295 .48882 .41895 .49483 .42913 .49153 .42315 .48553 Mtetra
.658 .753 .92 r
.42315 .48553 .42913 .49153 .43935 .4882 .43339 .48218 Mtetra
.659 .754 .92 r
.43339 .48218 .43935 .4882 .4496 .48484 .44367 .47881 Mtetra
.44367 .47881 .4496 .48484 .45989 .48147 .45399 .47541 Mtetra
.45399 .47541 .45989 .48147 .47022 .4781 .46435 .47201 Mtetra
.46435 .47201 .47022 .4781 .48059 .47471 .47474 .4686 Mtetra
.658 .753 .92 r
.47474 .4686 .48059 .47471 .491 .47133 .48518 .46518 Mtetra
.48518 .46518 .491 .47133 .50145 .46793 .49565 .46176 Mtetra
.49565 .46176 .50145 .46793 .51194 .46452 .50617 .45833 Mtetra
.50617 .45833 .51194 .46452 .52247 .46111 .51672 .45489 Mtetra
.51672 .45489 .52247 .46111 .53304 .45769 .52732 .45144 Mtetra
.52732 .45144 .53304 .45769 .54365 .45425 .53795 .44798 Mtetra
.53795 .44798 .54365 .45425 .55429 .4508 .54863 .44451 Mtetra
.657 .753 .92 r
.54863 .44451 .55429 .4508 .56499 .44735 .55935 .44103 Mtetra
.55935 .44103 .56499 .44735 .57572 .44388 .57011 .43753 Mtetra
.57011 .43753 .57572 .44388 .58649 .4404 .58091 .43402 Mtetra
.657 .752 .92 r
.58091 .43402 .58649 .4404 .5973 .4369 .59175 .4305 Mtetra
.59175 .4305 .5973 .4369 .60816 .4334 .60264 .42697 Mtetra
.60264 .42697 .60816 .4334 .61906 .42988 .61356 .42343 Mtetra
.61356 .42343 .61906 .42988 .63 .42635 .62453 .41987 Mtetra
.62453 .41987 .63 .42635 .64098 .4228 .63555 .4163 Mtetra
.63555 .4163 .64098 .4228 .65201 .41924 .6466 .41272 Mtetra
.6466 .41272 .65201 .41924 .66308 .41567 .6577 .40912 Mtetra
.6577 .40912 .66308 .41567 .67419 .41209 .66885 .40551 Mtetra
.66885 .40551 .67419 .41209 .68535 .40849 .68003 .40189 Mtetra
.68003 .40189 .68535 .40849 .69655 .40488 .69127 .39825 Mtetra
.69127 .39825 .69655 .40488 .7078 .40126 .70254 .3946 Mtetra
.70254 .3946 .7078 .40126 .71909 .39762 .71386 .39093 Mtetra
.71386 .39093 .71909 .39762 .73042 .39397 .72523 .38725 Mtetra
.72523 .38725 .73042 .39397 .7418 .3903 .73664 .38356 Mtetra
.73664 .38356 .7418 .3903 .75323 .38662 .7481 .37985 Mtetra
.7481 .37985 .75323 .38662 .7647 .38292 .7596 .37613 Mtetra
.7596 .37613 .7647 .38292 .77621 .37922 .77115 .37239 Mtetra
.77115 .37239 .77621 .37922 .78778 .37549 .78274 .36864 Mtetra
.78274 .36864 .78778 .37549 .79939 .37175 .79439 .36487 Mtetra
.79439 .36487 .79939 .37175 .81104 .368 .80608 .36109 Mtetra
.80608 .36109 .81104 .368 .82274 .36423 .81781 .3573 Mtetra
.81781 .3573 .82274 .36423 .83449 .36045 .8296 .35349 Mtetra
.8296 .35349 .83449 .36045 .84629 .35665 .84143 .34966 Mtetra
.84143 .34966 .84629 .35665 .85814 .35284 .85331 .34582 Mtetra
.612 .723 .925 r
.21975 .54328 .22617 .54938 .23555 .54773 .22918 .54121 Mtetra
.463 .652 .941 r
.22918 .54121 .23555 .54773 .24662 .52638 .23845 .54163 Mtetra
.055 0 .046 r
.23845 .54163 .24662 .52638 .25492 .5386 .24864 .53146 Mtetra
.565 .673 .911 r
.24864 .53146 .25492 .5386 .26444 .53657 .2581 .53043 Mtetra
.623 .728 .922 r
.2581 .53043 .26444 .53657 .27404 .53417 .2677 .52807 Mtetra
.622 .73 .924 r
.2677 .52807 .27404 .53417 .28364 .53223 .27735 .52574 Mtetra
.517 .678 .938 r
.27735 .52574 .28364 .53223 .29779 .46494 .28689 .52536 Mtetra
.458 .207 .445 r
.28689 .52536 .29779 .46494 .30332 .52283 .29715 .51532 Mtetra
.555 .66 .906 r
.29715 .51532 .30332 .52283 .31305 .5207 .3068 .51451 Mtetra
.63 .731 .92 r
.3068 .51451 .31305 .5207 .32284 .51802 .3166 .51196 Mtetra
.639 .739 .921 r
.3166 .51196 .32284 .51802 .33268 .51524 .32646 .50917 Mtetra
.639 .74 .922 r
.32646 .50917 .33268 .51524 .34255 .51256 .33636 .50638 Mtetra
.626 .733 .924 r
.33636 .50638 .34255 .51256 .35242 .5107 .34629 .50389 Mtetra
.394 .613 .938 r
.34629 .50389 .35242 .5107 .36294 .49653 .35605 .50531 Mtetra
0 0 0 r
.35605 .50531 .36294 .49653 .37258 .50072 .3665 .49368 Mtetra
.593 .694 .913 r
.3665 .49368 .37258 .50072 .3826 .49819 .3765 .49196 Mtetra
.64 .738 .92 r
.3765 .49196 .3826 .49819 .39267 .49521 .38659 .4891 Mtetra
.649 .746 .92 r
.38659 .4891 .39267 .49521 .40279 .49206 .39673 .48599 Mtetra
.653 .749 .92 r
.39673 .48599 .40279 .49206 .41295 .48882 .40691 .48277 Mtetra
.656 .751 .92 r
.40691 .48277 .41295 .48882 .42315 .48553 .41714 .47947 Mtetra
.658 .753 .92 r
.41714 .47947 .42315 .48553 .43339 .48218 .4274 .47612 Mtetra
.659 .753 .92 r
.4274 .47612 .43339 .48218 .44367 .47881 .43771 .47272 Mtetra
.659 .754 .92 r
.43771 .47272 .44367 .47881 .45399 .47541 .44805 .46931 Mtetra
.44805 .46931 .45399 .47541 .46435 .47201 .45843 .46588 Mtetra
.45843 .46588 .46435 .47201 .47474 .4686 .46885 .46244 Mtetra
.659 .753 .92 r
.46885 .46244 .47474 .4686 .48518 .46518 .47931 .459 Mtetra
.658 .753 .92 r
.47931 .459 .48518 .46518 .49565 .46176 .48982 .45555 Mtetra
.48982 .45555 .49565 .46176 .50617 .45833 .50036 .45209 Mtetra
.50036 .45209 .50617 .45833 .51672 .45489 .51094 .44863 Mtetra
.51094 .44863 .51672 .45489 .52732 .45144 .52156 .44515 Mtetra
.52156 .44515 .52732 .45144 .53795 .44798 .53222 .44166 Mtetra
.53222 .44166 .53795 .44798 .54863 .44451 .54293 .43817 Mtetra
.657 .753 .92 r
.54293 .43817 .54863 .44451 .55935 .44103 .55367 .43466 Mtetra
.55367 .43466 .55935 .44103 .57011 .43753 .56446 .43114 Mtetra
.56446 .43114 .57011 .43753 .58091 .43402 .57529 .42761 Mtetra
.657 .752 .92 r
.57529 .42761 .58091 .43402 .59175 .4305 .58616 .42406 Mtetra
.58616 .42406 .59175 .4305 .60264 .42697 .59707 .4205 Mtetra
.59707 .4205 .60264 .42697 .61356 .42343 .60803 .41693 Mtetra
.60803 .41693 .61356 .42343 .62453 .41987 .61903 .41335 Mtetra
.61903 .41335 .62453 .41987 .63555 .4163 .63007 .40975 Mtetra
.63007 .40975 .63555 .4163 .6466 .41272 .64116 .40614 Mtetra
.64116 .40614 .6466 .41272 .6577 .40912 .65228 .40252 Mtetra
.65228 .40252 .6577 .40912 .66885 .40551 .66346 .39888 Mtetra
.66346 .39888 .66885 .40551 .68003 .40189 .67468 .39523 Mtetra
.67468 .39523 .68003 .40189 .69127 .39825 .68594 .39157 Mtetra
.68594 .39157 .69127 .39825 .70254 .3946 .69725 .38789 Mtetra
.69725 .38789 .70254 .3946 .71386 .39093 .7086 .3842 Mtetra
.7086 .3842 .71386 .39093 .72523 .38725 .72 .38049 Mtetra
.72 .38049 .72523 .38725 .73664 .38356 .73144 .37677 Mtetra
.73144 .37677 .73664 .38356 .7481 .37985 .74293 .37303 Mtetra
.74293 .37303 .7481 .37985 .7596 .37613 .75446 .36928 Mtetra
.75446 .36928 .7596 .37613 .77115 .37239 .76605 .36552 Mtetra
.76605 .36552 .77115 .37239 .78274 .36864 .77767 .36174 Mtetra
.77767 .36174 .78274 .36864 .79439 .36487 .78935 .35794 Mtetra
.78935 .35794 .79439 .36487 .80608 .36109 .80107 .35413 Mtetra
.80107 .35413 .80608 .36109 .81781 .3573 .81284 .35031 Mtetra
.81284 .35031 .81781 .3573 .8296 .35349 .82466 .34647 Mtetra
.82466 .34647 .8296 .35349 .84143 .34966 .83653 .34262 Mtetra
.83653 .34262 .84143 .34966 .85331 .34582 .84844 .33875 Mtetra
.613 .721 .923 r
.21329 .53708 .21975 .54328 .22918 .54121 .22274 .53497 Mtetra
.591 .714 .929 r
.22274 .53497 .22918 .54121 .23845 .54163 .2322 .53328 Mtetra
.862 .714 .698 r
.2322 .53328 .23845 .54163 .24864 .53146 .24338 .5118 Mtetra
.109 .173 .649 r
.24338 .5118 .24864 .53146 .2581 .53043 .25173 .52403 Mtetra
.611 .716 .92 r
.25173 .52403 .2581 .53043 .2677 .52807 .26133 .52195 Mtetra
.626 .731 .923 r
.26133 .52195 .2677 .52807 .27735 .52574 .271 .51949 Mtetra
.604 .721 .927 r
.271 .51949 .27735 .52574 .28689 .52536 .28068 .51751 Mtetra
.924 .707 .592 r
.28068 .51751 .28689 .52536 .29715 .51532 .295 .4499 Mtetra
0 0 .365 r
.295 .4499 .29715 .51532 .3068 .51451 .30053 .50799 Mtetra
.613 .716 .919 r
.30053 .50799 .3068 .51451 .3166 .51196 .31033 .50581 Mtetra
.636 .737 .921 r
.31033 .50581 .3166 .51196 .32646 .50917 .32021 .50307 Mtetra
.64 .74 .921 r
.32021 .50307 .32646 .50917 .33636 .50638 .33013 .50023 Mtetra
.635 .738 .923 r
.33013 .50023 .33636 .50638 .34629 .50389 .34008 .4975 Mtetra
.597 .718 .929 r
.34008 .4975 .34629 .50389 .35605 .50531 .35003 .49559 Mtetra
.817 .701 .737 r
.35003 .49559 .35605 .50531 .3665 .49368 .36065 .48131 Mtetra
.366 .446 .811 r
.36065 .48131 .3665 .49368 .3765 .49196 .37037 .48548 Mtetra
.628 .727 .919 r
.37037 .48548 .3765 .49196 .38659 .4891 .38047 .4829 Mtetra
.646 .743 .92 r
.38047 .4829 .38659 .4891 .39673 .48599 .39063 .47986 Mtetra
.652 .748 .92 r
.39063 .47986 .39673 .48599 .40691 .48277 .40083 .47665 Mtetra
.655 .75 .92 r
.40083 .47665 .40691 .48277 .41714 .47947 .41108 .47336 Mtetra
.657 .752 .92 r
.41108 .47336 .41714 .47947 .4274 .47612 .42137 .47 Mtetra
.658 .753 .92 r
.42137 .47 .4274 .47612 .43771 .47272 .4317 .4666 Mtetra
.659 .754 .92 r
.4317 .4666 .43771 .47272 .44805 .46931 .44206 .46316 Mtetra
.44206 .46316 .44805 .46931 .45843 .46588 .45247 .45971 Mtetra
.45247 .45971 .45843 .46588 .46885 .46244 .46292 .45624 Mtetra
.46292 .45624 .46885 .46244 .47931 .459 .47341 .45277 Mtetra
.658 .753 .92 r
.47341 .45277 .47931 .459 .48982 .45555 .48393 .4493 Mtetra
.48393 .4493 .48982 .45555 .50036 .45209 .4945 .44581 Mtetra
.4945 .44581 .50036 .45209 .51094 .44863 .50511 .44232 Mtetra
.50511 .44232 .51094 .44863 .52156 .44515 .51576 .43882 Mtetra
.51576 .43882 .52156 .44515 .53222 .44166 .52645 .4353 Mtetra
.52645 .4353 .53222 .44166 .54293 .43817 .53718 .43178 Mtetra
.53718 .43178 .54293 .43817 .55367 .43466 .54795 .42825 Mtetra
.657 .753 .92 r
.54795 .42825 .55367 .43466 .56446 .43114 .55877 .4247 Mtetra
.55877 .4247 .56446 .43114 .57529 .42761 .56962 .42114 Mtetra
.56962 .42114 .57529 .42761 .58616 .42406 .58052 .41757 Mtetra
.657 .752 .92 r
.58052 .41757 .58616 .42406 .59707 .4205 .59147 .41399 Mtetra
.59147 .41399 .59707 .4205 .60803 .41693 .60245 .41039 Mtetra
.60245 .41039 .60803 .41693 .61903 .41335 .61348 .40678 Mtetra
.61348 .40678 .61903 .41335 .63007 .40975 .62455 .40316 Mtetra
.62455 .40316 .63007 .40975 .64116 .40614 .63567 .39952 Mtetra
.63567 .39952 .64116 .40614 .65228 .40252 .64683 .39587 Mtetra
.64683 .39587 .65228 .40252 .66346 .39888 .65803 .3922 Mtetra
.65803 .3922 .66346 .39888 .67468 .39523 .66928 .38853 Mtetra
.66928 .38853 .67468 .39523 .68594 .39157 .68057 .38484 Mtetra
.68057 .38484 .68594 .39157 .69725 .38789 .69191 .38113 Mtetra
.69191 .38113 .69725 .38789 .7086 .3842 .7033 .37741 Mtetra
.7033 .37741 .7086 .3842 .72 .38049 .71472 .37368 Mtetra
.71472 .37368 .72 .38049 .73144 .37677 .7262 .36993 Mtetra
.7262 .36993 .73144 .37677 .74293 .37303 .73772 .36616 Mtetra
.73772 .36616 .74293 .37303 .75446 .36928 .74929 .36238 Mtetra
.74929 .36238 .75446 .36928 .76605 .36552 .7609 .35859 Mtetra
.7609 .35859 .76605 .36552 .77767 .36174 .77257 .35478 Mtetra
.77257 .35478 .77767 .36174 .78935 .35794 .78428 .35096 Mtetra
.78428 .35096 .78935 .35794 .80107 .35413 .79603 .34712 Mtetra
.79603 .34712 .80107 .35413 .81284 .35031 .80784 .34327 Mtetra
.80784 .34327 .81284 .35031 .82466 .34647 .81969 .3394 Mtetra
.81969 .3394 .82466 .34647 .83653 .34262 .83159 .33552 Mtetra
.83159 .33552 .83653 .34262 .84844 .33875 .84354 .33162 Mtetra
.597 .707 .92 r
.20682 .53056 .21329 .53708 .22274 .53497 .21626 .52878 Mtetra
.612 .723 .925 r
.21626 .52878 .22274 .53497 .2322 .53328 .22577 .52665 Mtetra
.464 .652 .941 r
.22577 .52665 .2322 .53328 .24338 .5118 .2351 .52704 Mtetra
.041 0 .032 r
.2351 .52704 .24338 .5118 .25173 .52403 .24538 .51678 Mtetra
.565 .673 .912 r
.24538 .51678 .25173 .52403 .26133 .52195 .25492 .51571 Mtetra
.623 .728 .922 r
.25492 .51571 .26133 .52195 .271 .51949 .2646 .5133 Mtetra
.622 .73 .924 r
.2646 .5133 .271 .51949 .28068 .51751 .27432 .51091 Mtetra
.518 .678 .938 r
.27432 .51091 .28068 .51751 .295 .4499 .28395 .51049 Mtetra
.454 .201 .44 r
.28395 .51049 .295 .4499 .30053 .50799 .29429 .50036 Mtetra
.555 .66 .906 r
.29429 .50036 .30053 .50799 .31033 .50581 .30402 .4995 Mtetra
.63 .731 .921 r
.30402 .4995 .31033 .50581 .32021 .50307 .3139 .4969 Mtetra
.639 .739 .921 r
.3139 .4969 .32021 .50307 .33013 .50023 .32385 .49406 Mtetra
.639 .74 .922 r
.32385 .49406 .33013 .50023 .34008 .4975 .33383 .49122 Mtetra
.626 .733 .924 r
.33383 .49122 .34008 .4975 .35003 .49559 .34383 .48867 Mtetra
.396 .613 .938 r
.34383 .48867 .35003 .49559 .36065 .48131 .35368 .49005 Mtetra
0 0 0 r
.35368 .49005 .36065 .48131 .37037 .48548 .36422 .47833 Mtetra
.593 .694 .913 r
.36422 .47833 .37037 .48548 .38047 .4829 .3743 .47656 Mtetra
.64 .738 .92 r
.3743 .47656 .38047 .4829 .39063 .47986 .38448 .47364 Mtetra
.649 .746 .92 r
.38448 .47364 .39063 .47986 .40083 .47665 .39471 .47048 Mtetra
.653 .749 .92 r
.39471 .47048 .40083 .47665 .41108 .47336 .40498 .46719 Mtetra
.656 .751 .92 r
.40498 .46719 .41108 .47336 .42137 .47 .41529 .46383 Mtetra
.658 .753 .92 r
.41529 .46383 .42137 .47 .4317 .4666 .42564 .46042 Mtetra
.659 .753 .92 r
.42564 .46042 .4317 .4666 .44206 .46316 .43604 .45697 Mtetra
.659 .754 .92 r
.43604 .45697 .44206 .46316 .45247 .45971 .44647 .45349 Mtetra
.44647 .45349 .45247 .45971 .46292 .45624 .45694 .45 Mtetra
.45694 .45 .46292 .45624 .47341 .45277 .46746 .4465 Mtetra
.659 .753 .92 r
.46746 .4465 .47341 .45277 .48393 .4493 .47801 .443 Mtetra
.658 .753 .92 r
.47801 .443 .48393 .4493 .4945 .44581 .48861 .43949 Mtetra
.48861 .43949 .4945 .44581 .50511 .44232 .49924 .43597 Mtetra
.49924 .43597 .50511 .44232 .51576 .43882 .50992 .43244 Mtetra
.50992 .43244 .51576 .43882 .52645 .4353 .52063 .4289 Mtetra
.52063 .4289 .52645 .4353 .53718 .43178 .53139 .42535 Mtetra
.53139 .42535 .53718 .43178 .54795 .42825 .54219 .42179 Mtetra
.657 .753 .92 r
.54219 .42179 .54795 .42825 .55877 .4247 .55304 .41822 Mtetra
.55304 .41822 .55877 .4247 .56962 .42114 .56392 .41463 Mtetra
.56392 .41463 .56962 .42114 .58052 .41757 .57485 .41103 Mtetra
.657 .752 .92 r
.57485 .41103 .58052 .41757 .59147 .41399 .58582 .40742 Mtetra
.58582 .40742 .59147 .41399 .60245 .41039 .59683 .4038 Mtetra
.59683 .4038 .60245 .41039 .61348 .40678 .60789 .40016 Mtetra
.60789 .40016 .61348 .40678 .62455 .40316 .61899 .39651 Mtetra
.61899 .39651 .62455 .40316 .63567 .39952 .63014 .39285 Mtetra
.63014 .39285 .63567 .39952 .64683 .39587 .64133 .38917 Mtetra
.64133 .38917 .64683 .39587 .65803 .3922 .65256 .38548 Mtetra
.65256 .38548 .65803 .3922 .66928 .38853 .66384 .38177 Mtetra
.66384 .38177 .66928 .38853 .68057 .38484 .67517 .37805 Mtetra
.67517 .37805 .68057 .38484 .69191 .38113 .68654 .37432 Mtetra
.68654 .37432 .69191 .38113 .7033 .37741 .69795 .37057 Mtetra
.69795 .37057 .7033 .37741 .71472 .37368 .70941 .36681 Mtetra
.70941 .36681 .71472 .37368 .7262 .36993 .72092 .36303 Mtetra
.72092 .36303 .7262 .36993 .73772 .36616 .73248 .35924 Mtetra
.73248 .35924 .73772 .36616 .74929 .36238 .74408 .35544 Mtetra
.74408 .35544 .74929 .36238 .7609 .35859 .75572 .35161 Mtetra
.75572 .35161 .7609 .35859 .77257 .35478 .76742 .34778 Mtetra
.76742 .34778 .77257 .35478 .78428 .35096 .77916 .34393 Mtetra
.77916 .34393 .78428 .35096 .79603 .34712 .79095 .34006 Mtetra
.79095 .34006 .79603 .34712 .80784 .34327 .80279 .33618 Mtetra
.80279 .33618 .80784 .34327 .81969 .3394 .81468 .33228 Mtetra
.81468 .33228 .81969 .3394 .83159 .33552 .82662 .32836 Mtetra
.82662 .32836 .83159 .33552 .84354 .33162 .8386 .32443 Mtetra
.523 .636 .903 r
.20043 .52267 .20682 .53056 .21626 .52878 .20973 .52248 Mtetra
.613 .721 .923 r
.20973 .52248 .21626 .52878 .22577 .52665 .21926 .52032 Mtetra
.591 .714 .929 r
.21926 .52032 .22577 .52665 .2351 .52704 .2288 .51858 Mtetra
.863 .715 .697 r
.2288 .51858 .2351 .52704 .24538 .51678 .24008 .49696 Mtetra
.105 .17 .648 r
.24008 .49696 .24538 .51678 .25492 .51571 .24848 .50921 Mtetra
.611 .716 .92 r
.24848 .50921 .25492 .51571 .2646 .5133 .25816 .50707 Mtetra
.626 .731 .923 r
.25816 .50707 .2646 .5133 .27432 .51091 .26791 .50456 Mtetra
.604 .721 .927 r
.26791 .50456 .27432 .51091 .28395 .51049 .27766 .50253 Mtetra
.925 .708 .591 r
.27766 .50253 .28395 .51049 .29429 .50036 .29217 .43459 Mtetra
0 0 .36 r
.29217 .43459 .29429 .50036 .30402 .4995 .29768 .49288 Mtetra
.613 .716 .919 r
.29768 .49288 .30402 .4995 .3139 .4969 .30756 .49065 Mtetra
.636 .737 .921 r
.30756 .49065 .3139 .4969 .32385 .49406 .31752 .48785 Mtetra
.64 .74 .921 r
.31752 .48785 .32385 .49406 .33383 .49122 .32753 .48496 Mtetra
.635 .738 .923 r
.32753 .48496 .33383 .49122 .34383 .48867 .33757 .48217 Mtetra
.597 .718 .929 r
.33757 .48217 .34383 .48867 .35368 .49005 .3476 .48021 Mtetra
.818 .702 .737 r
.3476 .48021 .35368 .49005 .36422 .47833 .35831 .46583 Mtetra
.365 .446 .811 r
.35831 .46583 .36422 .47833 .3743 .47656 .36811 .46997 Mtetra
.628 .727 .919 r
.36811 .46997 .3743 .47656 .38448 .47364 .37829 .46733 Mtetra
.646 .743 .92 r
.37829 .46733 .38448 .47364 .39471 .47048 .38854 .46423 Mtetra
.652 .748 .92 r
.38854 .46423 .39471 .47048 .40498 .46719 .39883 .46097 Mtetra
.655 .75 .92 r
.39883 .46097 .40498 .46719 .41529 .46383 .40917 .45761 Mtetra
.657 .752 .92 r
.40917 .45761 .41529 .46383 .42564 .46042 .41955 .45419 Mtetra
.658 .753 .92 r
.41955 .45419 .42564 .46042 .43604 .45697 .42997 .45073 Mtetra
.659 .754 .92 r
.42997 .45073 .43604 .45697 .44647 .45349 .44043 .44723 Mtetra
.44043 .44723 .44647 .45349 .45694 .45 .45093 .44372 Mtetra
.45093 .44372 .45694 .45 .46746 .4465 .46147 .44019 Mtetra
.46147 .44019 .46746 .4465 .47801 .443 .47205 .43666 Mtetra
.658 .753 .92 r
.47205 .43666 .47801 .443 .48861 .43949 .48267 .43312 Mtetra
.48267 .43312 .48861 .43949 .49924 .43597 .49333 .42957 Mtetra
.49333 .42957 .49924 .43597 .50992 .43244 .50403 .42601 Mtetra
.50403 .42601 .50992 .43244 .52063 .4289 .51478 .42245 Mtetra
.51478 .42245 .52063 .4289 .53139 .42535 .52556 .41887 Mtetra
.52556 .41887 .53139 .42535 .54219 .42179 .53639 .41528 Mtetra
.53639 .41528 .54219 .42179 .55304 .41822 .54726 .41168 Mtetra
.657 .753 .92 r
.54726 .41168 .55304 .41822 .56392 .41463 .55818 .40807 Mtetra
.55818 .40807 .56392 .41463 .57485 .41103 .56913 .40445 Mtetra
.56913 .40445 .57485 .41103 .58582 .40742 .58013 .40081 Mtetra
.657 .752 .92 r
.58013 .40081 .58582 .40742 .59683 .4038 .59118 .39716 Mtetra
.59118 .39716 .59683 .4038 .60789 .40016 .60226 .3935 Mtetra
.60226 .3935 .60789 .40016 .61899 .39651 .61339 .38982 Mtetra
.61339 .38982 .61899 .39651 .63014 .39285 .62457 .38613 Mtetra
.62457 .38613 .63014 .39285 .64133 .38917 .63579 .38242 Mtetra
.63579 .38242 .64133 .38917 .65256 .38548 .64706 .3787 Mtetra
.64706 .3787 .65256 .38548 .66384 .38177 .65837 .37497 Mtetra
.65837 .37497 .66384 .38177 .67517 .37805 .66972 .37122 Mtetra
.66972 .37122 .67517 .37805 .68654 .37432 .68112 .36746 Mtetra
.68112 .36746 .68654 .37432 .69795 .37057 .69257 .36369 Mtetra
.69257 .36369 .69795 .37057 .70941 .36681 .70406 .3599 Mtetra
.70406 .3599 .70941 .36681 .72092 .36303 .7156 .35609 Mtetra
.7156 .35609 .72092 .36303 .73248 .35924 .72719 .35227 Mtetra
.72719 .35227 .73248 .35924 .74408 .35544 .73882 .34843 Mtetra
.73882 .34843 .74408 .35544 .75572 .35161 .75051 .34458 Mtetra
.75051 .34458 .75572 .35161 .76742 .34778 .76223 .34072 Mtetra
.76223 .34072 .76742 .34778 .77916 .34393 .77401 .33684 Mtetra
.77401 .33684 .77916 .34393 .79095 .34006 .78584 .33294 Mtetra
.78584 .33294 .79095 .34006 .80279 .33618 .79771 .32903 Mtetra
.79771 .32903 .80279 .33618 .81468 .33228 .80963 .3251 Mtetra
.80963 .3251 .81468 .33228 .82662 .32836 .82161 .32116 Mtetra
.82161 .32116 .82662 .32836 .8386 .32443 .83363 .3172 Mtetra
0 0 0 r
.18849 .57038 .20043 .52267 .20973 .52248 .20319 .51585 Mtetra
.597 .707 .92 r
.20319 .51585 .20973 .52248 .21926 .52032 .21271 .51402 Mtetra
.612 .723 .925 r
.21271 .51402 .21926 .52032 .2288 .51858 .22229 .51184 Mtetra
.464 .652 .941 r
.22229 .51184 .2288 .51858 .24008 .49696 .2317 .51219 Mtetra
.027 0 .018 r
.2317 .51219 .24008 .49696 .24848 .50921 .24207 .50184 Mtetra
.565 .673 .912 r
.24207 .50184 .24848 .50921 .25816 .50707 .25168 .50072 Mtetra
.623 .728 .922 r
.25168 .50072 .25816 .50707 .26791 .50456 .26144 .49826 Mtetra
.622 .73 .924 r
.26144 .49826 .26791 .50456 .27766 .50253 .27125 .49582 Mtetra
.518 .678 .938 r
.27125 .49582 .27766 .50253 .29217 .43459 .28094 .49535 Mtetra
.449 .195 .435 r
.28094 .49535 .29217 .43459 .29768 .49288 .29138 .48514 Mtetra
.555 .66 .906 r
.29138 .48514 .29768 .49288 .30756 .49065 .30119 .48424 Mtetra
.63 .731 .921 r
.30119 .48424 .30756 .49065 .31752 .48785 .31116 .48158 Mtetra
.639 .739 .921 r
.31116 .48158 .31752 .48785 .32753 .48496 .32118 .47868 Mtetra
.639 .74 .922 r
.32118 .47868 .32753 .48496 .33757 .48217 .33125 .47578 Mtetra
.626 .733 .924 r
.33125 .47578 .33757 .48217 .3476 .48021 .34134 .47318 Mtetra
.397 .614 .937 r
.34134 .47318 .3476 .48021 .35831 .46583 .35126 .47452 Mtetra
0 0 0 r
.35126 .47452 .35831 .46583 .36811 .46997 .3619 .46271 Mtetra
.593 .694 .913 r
.3619 .46271 .36811 .46997 .37829 .46733 .37207 .46088 Mtetra
.64 .738 .92 r
.37207 .46088 .37829 .46733 .38854 .46423 .38233 .45791 Mtetra
.649 .746 .92 r
.38233 .45791 .38854 .46423 .39883 .46097 .39265 .45468 Mtetra
.653 .749 .92 r
.39265 .45468 .39883 .46097 .40917 .45761 .40301 .45133 Mtetra
.656 .751 .92 r
.40301 .45133 .40917 .45761 .41955 .45419 .41341 .44792 Mtetra
.658 .753 .92 r
.41341 .44792 .41955 .45419 .42997 .45073 .42385 .44444 Mtetra
.659 .753 .92 r
.42385 .44444 .42997 .45073 .44043 .44723 .43434 .44093 Mtetra
.659 .754 .92 r
.43434 .44093 .44043 .44723 .45093 .44372 .44486 .43739 Mtetra
.44486 .43739 .45093 .44372 .46147 .44019 .45543 .43384 Mtetra
.45543 .43384 .46147 .44019 .47205 .43666 .46604 .43027 Mtetra
.659 .753 .92 r
.46604 .43027 .47205 .43666 .48267 .43312 .47668 .4267 Mtetra
.658 .753 .92 r
.47668 .4267 .48267 .43312 .49333 .42957 .48737 .42313 Mtetra
.48737 .42313 .49333 .42957 .50403 .42601 .4981 .41954 Mtetra
.4981 .41954 .50403 .42601 .51478 .42245 .50888 .41595 Mtetra
.50888 .41595 .51478 .42245 .52556 .41887 .51969 .41235 Mtetra
.51969 .41235 .52556 .41887 .53639 .41528 .53055 .40873 Mtetra
.53055 .40873 .53639 .41528 .54726 .41168 .54145 .4051 Mtetra
.657 .753 .92 r
.54145 .4051 .54726 .41168 .55818 .40807 .55239 .40147 Mtetra
.55239 .40147 .55818 .40807 .56913 .40445 .56337 .39781 Mtetra
.56337 .39781 .56913 .40445 .58013 .40081 .5744 .39415 Mtetra
.657 .752 .92 r
.5744 .39415 .58013 .40081 .59118 .39716 .58548 .39047 Mtetra
.58548 .39047 .59118 .39716 .60226 .3935 .59659 .38678 Mtetra
.59659 .38678 .60226 .3935 .61339 .38982 .60775 .38307 Mtetra
.60775 .38307 .61339 .38982 .62457 .38613 .61896 .37936 Mtetra
.61896 .37936 .62457 .38613 .63579 .38242 .63021 .37562 Mtetra
.63021 .37562 .63579 .38242 .64706 .3787 .64151 .37188 Mtetra
.64151 .37188 .64706 .3787 .65837 .37497 .65285 .36812 Mtetra
.65285 .36812 .65837 .37497 .66972 .37122 .66424 .36434 Mtetra
.66424 .36434 .66972 .37122 .68112 .36746 .67567 .36055 Mtetra
.67567 .36055 .68112 .36746 .69257 .36369 .68715 .35675 Mtetra
.68715 .35675 .69257 .36369 .70406 .3599 .69867 .35293 Mtetra
.69867 .35293 .70406 .3599 .7156 .35609 .71025 .34909 Mtetra
.71025 .34909 .7156 .35609 .72719 .35227 .72187 .34524 Mtetra
.72187 .34524 .72719 .35227 .73882 .34843 .73353 .34138 Mtetra
.73353 .34138 .73882 .34843 .75051 .34458 .74525 .3375 Mtetra
.74525 .3375 .75051 .34458 .76223 .34072 .75701 .3336 Mtetra
.75701 .3336 .76223 .34072 .77401 .33684 .76882 .32969 Mtetra
.76882 .32969 .77401 .33684 .78584 .33294 .78068 .32577 Mtetra
.78068 .32577 .78584 .33294 .79771 .32903 .79259 .32183 Mtetra
.79259 .32183 .79771 .32903 .80963 .3251 .80455 .31787 Mtetra
.80455 .31787 .80963 .3251 .82161 .32116 .81655 .31389 Mtetra
.81655 .31389 .82161 .32116 .83363 .3172 .82861 .3099 Mtetra
.615 .426 .604 r
.18644 .51778 .18849 .57038 .20319 .51585 .19674 .50785 Mtetra
.523 .636 .903 r
.19674 .50785 .20319 .51585 .21271 .51402 .20611 .50761 Mtetra
.613 .721 .923 r
.20611 .50761 .21271 .51402 .22229 .51184 .21572 .5054 Mtetra
.591 .714 .929 r
.21572 .5054 .22229 .51184 .2317 .51219 .22533 .50361 Mtetra
.863 .716 .697 r
.22533 .50361 .2317 .51219 .24207 .50184 .23672 .48186 Mtetra
.101 .167 .646 r
.23672 .48186 .24207 .50184 .25168 .50072 .24518 .49412 Mtetra
.611 .716 .92 r
.24518 .49412 .25168 .50072 .26144 .49826 .25493 .49193 Mtetra
.626 .731 .923 r
.25493 .49193 .26144 .49826 .27125 .49582 .26476 .48937 Mtetra
.604 .721 .927 r
.26476 .48937 .27125 .49582 .28094 .49535 .2746 .48728 Mtetra
.926 .709 .589 r
.2746 .48728 .28094 .49535 .29138 .48514 .28928 .41902 Mtetra
0 0 .355 r
.28928 .41902 .29138 .48514 .30119 .48424 .29479 .4775 Mtetra
.613 .716 .919 r
.29479 .4775 .30119 .48424 .31116 .48158 .30475 .47522 Mtetra
.636 .737 .921 r
.30475 .47522 .31116 .48158 .32118 .47868 .31479 .47237 Mtetra
.64 .74 .921 r
.31479 .47237 .32118 .47868 .33125 .47578 .32488 .46942 Mtetra
.635 .738 .923 r
.32488 .46942 .33125 .47578 .34134 .47318 .335 .46657 Mtetra
.597 .718 .928 r
.335 .46657 .34134 .47318 .35126 .47452 .34512 .46456 Mtetra
.818 .703 .737 r
.34512 .46456 .35126 .47452 .3619 .46271 .35593 .45007 Mtetra
.364 .445 .811 r
.35593 .45007 .3619 .46271 .37207 .46088 .36581 .45418 Mtetra
.628 .727 .919 r
.36581 .45418 .37207 .46088 .38233 .45791 .37608 .45148 Mtetra
.646 .743 .92 r
.37608 .45148 .38233 .45791 .39265 .45468 .38642 .44832 Mtetra
.652 .748 .92 r
.38642 .44832 .39265 .45468 .40301 .45133 .3968 .445 Mtetra
.655 .75 .92 r
.3968 .445 .40301 .45133 .41341 .44792 .40723 .44158 Mtetra
.657 .752 .92 r
.40723 .44158 .41341 .44792 .42385 .44444 .41769 .4381 Mtetra
.658 .753 .92 r
.41769 .4381 .42385 .44444 .43434 .44093 .42821 .43457 Mtetra
.659 .754 .92 r
.42821 .43457 .43434 .44093 .44486 .43739 .43876 .43101 Mtetra
.43876 .43101 .44486 .43739 .45543 .43384 .44935 .42743 Mtetra
.44935 .42743 .45543 .43384 .46604 .43027 .45998 .42384 Mtetra
.45998 .42384 .46604 .43027 .47668 .4267 .47066 .42025 Mtetra
.658 .753 .92 r
.47066 .42025 .47668 .4267 .48737 .42313 .48137 .41664 Mtetra
.48137 .41664 .48737 .42313 .4981 .41954 .49213 .41303 Mtetra
.49213 .41303 .4981 .41954 .50888 .41595 .50293 .40941 Mtetra
.50293 .40941 .50888 .41595 .51969 .41235 .51377 .40578 Mtetra
.51377 .40578 .51969 .41235 .53055 .40873 .52466 .40213 Mtetra
.52466 .40213 .53055 .40873 .54145 .4051 .53559 .39848 Mtetra
.53559 .39848 .54145 .4051 .55239 .40147 .54656 .39481 Mtetra
.657 .753 .92 r
.54656 .39481 .55239 .40147 .56337 .39781 .55757 .39113 Mtetra
.55757 .39113 .56337 .39781 .5744 .39415 .56863 .38744 Mtetra
.56863 .38744 .5744 .39415 .58548 .39047 .57973 .38373 Mtetra
.657 .752 .92 r
.57973 .38373 .58548 .39047 .59659 .38678 .59088 .38002 Mtetra
.59088 .38002 .59659 .38678 .60775 .38307 .60207 .37628 Mtetra
.60207 .37628 .60775 .38307 .61896 .37936 .61331 .37254 Mtetra
.61331 .37254 .61896 .37936 .63021 .37562 .62459 .36878 Mtetra
.62459 .36878 .63021 .37562 .64151 .37188 .63592 .365 Mtetra
.63592 .365 .64151 .37188 .65285 .36812 .64729 .36121 Mtetra
.64729 .36121 .65285 .36812 .66424 .36434 .65871 .35741 Mtetra
.65871 .35741 .66424 .36434 .67567 .36055 .67017 .35359 Mtetra
.67017 .35359 .67567 .36055 .68715 .35675 .68168 .34976 Mtetra
.68168 .34976 .68715 .35675 .69867 .35293 .69324 .34591 Mtetra
.69324 .34591 .69867 .35293 .71025 .34909 .70485 .34204 Mtetra
.70485 .34204 .71025 .34909 .72187 .34524 .7165 .33817 Mtetra
.7165 .33817 .72187 .34524 .73353 .34138 .7282 .33427 Mtetra
.7282 .33427 .73353 .34138 .74525 .3375 .73995 .33036 Mtetra
.73995 .33036 .74525 .3375 .75701 .3336 .75175 .32644 Mtetra
.75175 .32644 .75701 .3336 .76882 .32969 .76359 .3225 Mtetra
.76359 .3225 .76882 .32969 .78068 .32577 .77548 .31854 Mtetra
.77548 .31854 .78068 .32577 .79259 .32183 .78743 .31457 Mtetra
.78743 .31457 .79259 .32183 .80455 .31787 .79942 .31058 Mtetra
.79942 .31058 .80455 .31787 .81655 .31389 .81146 .30657 Mtetra
.81146 .30657 .81655 .31389 .82861 .3099 .82356 .30255 Mtetra
.95 .627 .383 r
.17988 .51012 .18644 .51778 .19674 .50785 .18462 .55569 Mtetra
0 0 0 r
.18462 .55569 .19674 .50785 .20611 .50761 .1995 .50088 Mtetra
.597 .707 .92 r
.1995 .50088 .20611 .50761 .21572 .5054 .20909 .499 Mtetra
.612 .723 .925 r
.20909 .499 .21572 .5054 .22533 .50361 .21876 .49677 Mtetra
.465 .652 .941 r
.21876 .49677 .22533 .50361 .23672 .48186 .22824 .49707 Mtetra
.013 0 .004 r
.22824 .49707 .23672 .48186 .24518 .49412 .2387 .48664 Mtetra
.565 .673 .912 r
.2387 .48664 .24518 .49412 .25493 .49193 .24839 .48547 Mtetra
.623 .728 .922 r
.24839 .48547 .25493 .49193 .26476 .48937 .25823 .48296 Mtetra
.622 .73 .924 r
.25823 .48296 .26476 .48937 .2746 .48728 .26811 .48047 Mtetra
.518 .678 .938 r
.26811 .48047 .2746 .48728 .28928 .41902 .27789 .47995 Mtetra
.444 .188 .43 r
.27789 .47995 .28928 .41902 .29479 .4775 .28842 .46965 Mtetra
.555 .66 .906 r
.28842 .46965 .29479 .4775 .30475 .47522 .29831 .4687 Mtetra
.63 .731 .921 r
.29831 .4687 .30475 .47522 .31479 .47237 .30836 .46598 Mtetra
.639 .739 .921 r
.30836 .46598 .31479 .47237 .32488 .46942 .31847 .46303 Mtetra
.639 .74 .922 r
.31847 .46303 .32488 .46942 .335 .46657 .32862 .46007 Mtetra
.626 .733 .924 r
.32862 .46007 .335 .46657 .34512 .46456 .33879 .45741 Mtetra
.398 .614 .937 r
.33879 .45741 .34512 .46456 .35593 .45007 .3488 .45871 Mtetra
0 0 0 r
.3488 .45871 .35593 .45007 .36581 .45418 .35954 .4468 Mtetra
.593 .694 .913 r
.35954 .4468 .36581 .45418 .37608 .45148 .36979 .44492 Mtetra
.64 .738 .92 r
.36979 .44492 .37608 .45148 .38642 .44832 .38014 .44188 Mtetra
.649 .746 .92 r
.38014 .44188 .38642 .44832 .3968 .445 .39055 .43859 Mtetra
.653 .749 .92 r
.39055 .43859 .3968 .445 .40723 .44158 .401 .43519 Mtetra
.656 .751 .92 r
.401 .43519 .40723 .44158 .41769 .4381 .41149 .4317 Mtetra
.658 .753 .92 r
.41149 .4317 .41769 .4381 .42821 .43457 .42203 .42817 Mtetra
.659 .753 .92 r
.42203 .42817 .42821 .43457 .43876 .43101 .43261 .42459 Mtetra
.659 .754 .92 r
.43261 .42459 .43876 .43101 .44935 .42743 .44323 .42099 Mtetra
.44323 .42099 .44935 .42743 .45998 .42384 .45389 .41737 Mtetra
.45389 .41737 .45998 .42384 .47066 .42025 .46459 .41374 Mtetra
.659 .753 .92 r
.46459 .41374 .47066 .42025 .48137 .41664 .47533 .41011 Mtetra
.658 .753 .92 r
.47533 .41011 .48137 .41664 .49213 .41303 .48612 .40647 Mtetra
.48612 .40647 .49213 .41303 .50293 .40941 .49695 .40282 Mtetra
.49695 .40282 .50293 .40941 .51377 .40578 .50782 .39916 Mtetra
.50782 .39916 .51377 .40578 .52466 .40213 .51873 .39549 Mtetra
.51873 .39549 .52466 .40213 .53559 .39848 .52969 .3918 Mtetra
.52969 .3918 .53559 .39848 .54656 .39481 .54069 .38811 Mtetra
.657 .753 .92 r
.54069 .38811 .54656 .39481 .55757 .39113 .55173 .3844 Mtetra
.55173 .3844 .55757 .39113 .56863 .38744 .56282 .38068 Mtetra
.56282 .38068 .56863 .38744 .57973 .38373 .57395 .37695 Mtetra
.657 .752 .92 r
.57395 .37695 .57973 .38373 .59088 .38002 .58513 .3732 Mtetra
.58513 .3732 .59088 .38002 .60207 .37628 .59635 .36944 Mtetra
.59635 .36944 .60207 .37628 .61331 .37254 .60761 .36566 Mtetra
.60761 .36566 .61331 .37254 .62459 .36878 .61893 .36188 Mtetra
.61893 .36188 .62459 .36878 .63592 .365 .63028 .35807 Mtetra
.63028 .35807 .63592 .365 .64729 .36121 .64169 .35425 Mtetra
.64169 .35425 .64729 .36121 .65871 .35741 .65314 .35042 Mtetra
.65314 .35042 .65871 .35741 .67017 .35359 .66463 .34657 Mtetra
.66463 .34657 .67017 .35359 .68168 .34976 .67618 .34271 Mtetra
.67618 .34271 .68168 .34976 .69324 .34591 .68777 .33883 Mtetra
.68777 .33883 .69324 .34591 .70485 .34204 .69941 .33494 Mtetra
.69941 .33494 .70485 .34204 .7165 .33817 .71109 .33103 Mtetra
.71109 .33103 .7165 .33817 .7282 .33427 .72283 .32711 Mtetra
.72283 .32711 .7282 .33427 .73995 .33036 .73461 .32317 Mtetra
.73461 .32317 .73995 .33036 .75175 .32644 .74644 .31922 Mtetra
.74644 .31922 .75175 .32644 .76359 .3225 .75832 .31524 Mtetra
.75832 .31524 .76359 .3225 .77548 .31854 .77025 .31126 Mtetra
.77025 .31126 .77548 .31854 .78743 .31457 .78223 .30725 Mtetra
.78223 .30725 .78743 .31457 .79942 .31058 .79426 .30323 Mtetra
.79426 .30323 .79942 .31058 .81146 .30657 .80634 .2992 Mtetra
.80634 .2992 .81146 .30657 .82356 .30255 .81846 .29515 Mtetra
.526 .682 .937 r
.17319 .50341 .17988 .51012 .18462 .55569 .18259 .50278 Mtetra
.613 .425 .602 r
.18259 .50278 .18462 .55569 .1995 .50088 .19298 .49277 Mtetra
.523 .636 .903 r
.19298 .49277 .1995 .50088 .20909 .499 .20243 .49249 Mtetra
.613 .721 .923 r
.20243 .49249 .20909 .499 .21876 .49677 .21211 .49023 Mtetra
.592 .714 .929 r
.21211 .49023 .21876 .49677 .22824 .49707 .2218 .48838 Mtetra
.864 .717 .697 r
.2218 .48838 .22824 .49707 .2387 .48664 .23331 .4665 Mtetra
.097 .164 .645 r
.23331 .4665 .2387 .48664 .24839 .48547 .24181 .47876 Mtetra
.611 .716 .92 r
.24181 .47876 .24839 .48547 .25823 .48296 .25165 .47651 Mtetra
.626 .731 .923 r
.25165 .47651 .25823 .48296 .26811 .48047 .26156 .4739 Mtetra
.604 .721 .927 r
.26156 .4739 .26811 .48047 .27789 .47995 .27148 .47176 Mtetra
.927 .709 .588 r
.27148 .47176 .27789 .47995 .28842 .46965 .28635 .40318 Mtetra
0 0 .35 r
.28635 .40318 .28842 .46965 .29831 .4687 .29184 .46185 Mtetra
.613 .716 .919 r
.29184 .46185 .29831 .4687 .30836 .46598 .30188 .45951 Mtetra
.636 .737 .921 r
.30188 .45951 .30836 .46598 .31847 .46303 .31201 .4566 Mtetra
.64 .74 .921 r
.31201 .4566 .31847 .46303 .32862 .46007 .32219 .45359 Mtetra
.635 .738 .922 r
.32219 .45359 .32862 .46007 .33879 .45741 .33239 .45068 Mtetra
.597 .718 .928 r
.33239 .45068 .33879 .45741 .3488 .45871 .3426 .44861 Mtetra
.819 .703 .737 r
.3426 .44861 .3488 .45871 .35954 .4468 .35351 .43402 Mtetra
.362 .444 .811 r
.35351 .43402 .35954 .4468 .36979 .44492 .36347 .4381 Mtetra
.628 .727 .919 r
.36347 .4381 .36979 .44492 .38014 .44188 .37383 .43534 Mtetra
.646 .743 .92 r
.37383 .43534 .38014 .44188 .39055 .43859 .38425 .43212 Mtetra
.652 .748 .92 r
.38425 .43212 .39055 .43859 .401 .43519 .39473 .42873 Mtetra
.655 .75 .92 r
.39473 .42873 .401 .43519 .41149 .4317 .40525 .42525 Mtetra
.657 .752 .92 r
.40525 .42525 .41149 .4317 .42203 .42817 .41581 .42171 Mtetra
.658 .753 .92 r
.41581 .42171 .42203 .42817 .43261 .42459 .42641 .41812 Mtetra
.659 .754 .92 r
.42641 .41812 .43261 .42459 .44323 .42099 .43706 .41449 Mtetra
.43706 .41449 .44323 .42099 .45389 .41737 .44775 .41085 Mtetra
.44775 .41085 .45389 .41737 .46459 .41374 .45847 .40719 Mtetra
.45847 .40719 .46459 .41374 .47533 .41011 .46925 .40353 Mtetra
.658 .753 .92 r
.46925 .40353 .47533 .41011 .48612 .40647 .48006 .39986 Mtetra
.48006 .39986 .48612 .40647 .49695 .40282 .49091 .39618 Mtetra
.49091 .39618 .49695 .40282 .50782 .39916 .50181 .39249 Mtetra
.50181 .39249 .50782 .39916 .51873 .39549 .51275 .38879 Mtetra
.51275 .38879 .51873 .39549 .52969 .3918 .52374 .38508 Mtetra
.52374 .38508 .52969 .3918 .54069 .38811 .53477 .38136 Mtetra
.53477 .38136 .54069 .38811 .55173 .3844 .54584 .37762 Mtetra
.657 .753 .92 r
.54584 .37762 .55173 .3844 .56282 .38068 .55696 .37387 Mtetra
.55696 .37387 .56282 .38068 .57395 .37695 .56812 .37011 Mtetra
.56812 .37011 .57395 .37695 .58513 .3732 .57933 .36633 Mtetra
.657 .752 .92 r
.57933 .36633 .58513 .3732 .59635 .36944 .59058 .36255 Mtetra
.59058 .36255 .59635 .36944 .60761 .36566 .60188 .35874 Mtetra
.60188 .35874 .60761 .36566 .61893 .36188 .61322 .35492 Mtetra
.61322 .35492 .61893 .36188 .63028 .35807 .62461 .35109 Mtetra
.62461 .35109 .63028 .35807 .64169 .35425 .63604 .34724 Mtetra
.63604 .34724 .64169 .35425 .65314 .35042 .64753 .34338 Mtetra
.64753 .34338 .65314 .35042 .66463 .34657 .65906 .33951 Mtetra
.65906 .33951 .66463 .34657 .67618 .34271 .67063 .33561 Mtetra
.67063 .33561 .67618 .34271 .68777 .33883 .68225 .33171 Mtetra
.68225 .33171 .68777 .33883 .69941 .33494 .69393 .32778 Mtetra
.69393 .32778 .69941 .33494 .71109 .33103 .70564 .32385 Mtetra
.70564 .32385 .71109 .33103 .72283 .32711 .71741 .31989 Mtetra
.71741 .31989 .72283 .32711 .73461 .32317 .72923 .31592 Mtetra
.72923 .31592 .73461 .32317 .74644 .31922 .74109 .31194 Mtetra
.74109 .31194 .74644 .31922 .75832 .31524 .75301 .30794 Mtetra
.75301 .30794 .75832 .31524 .77025 .31126 .76497 .30392 Mtetra
.76497 .30392 .77025 .31126 .78223 .30725 .77699 .29988 Mtetra
.77699 .29988 .78223 .30725 .79426 .30323 .78905 .29583 Mtetra
.78905 .29583 .79426 .30323 .80634 .2992 .80117 .29177 Mtetra
.80117 .29177 .80634 .2992 .81846 .29515 .81333 .28768 Mtetra
.593 .714 .928 r
.16642 .49687 .17319 .50341 .18259 .50278 .17597 .49501 Mtetra
.95 .626 .379 r
.17597 .49501 .18259 .50278 .19298 .49277 .18068 .54074 Mtetra
0 0 0 r
.18068 .54074 .19298 .49277 .20243 .49249 .19575 .48565 Mtetra
.597 .707 .92 r
.19575 .48565 .20243 .49249 .21211 .49023 .20541 .48371 Mtetra
.612 .723 .925 r
.20541 .48371 .21211 .49023 .2218 .48838 .21516 .48143 Mtetra
.465 .652 .941 r
.21516 .48143 .2218 .48838 .23331 .4665 .22471 .48169 Mtetra
0 0 0 r
.22471 .48169 .23331 .4665 .24181 .47876 .23527 .47117 Mtetra
.564 .673 .912 r
.23527 .47117 .24181 .47876 .25165 .47651 .24503 .46995 Mtetra
.623 .728 .922 r
.24503 .46995 .25165 .47651 .26156 .4739 .25496 .46738 Mtetra
.622 .73 .924 r
.25496 .46738 .26156 .4739 .27148 .47176 .26492 .46483 Mtetra
.519 .678 .938 r
.26492 .46483 .27148 .47176 .28635 .40318 .27478 .46427 Mtetra
.439 .182 .425 r
.27478 .46427 .28635 .40318 .29184 .46185 .28541 .45388 Mtetra
.555 .66 .907 r
.28541 .45388 .29184 .46185 .30188 .45951 .29537 .45287 Mtetra
.63 .731 .921 r
.29537 .45287 .30188 .45951 .31201 .4566 .30551 .4501 Mtetra
.639 .739 .921 r
.30551 .4501 .31201 .4566 .32219 .45359 .31571 .44709 Mtetra
.639 .74 .922 r
.31571 .44709 .32219 .45359 .33239 .45068 .32594 .44407 Mtetra
.626 .733 .924 r
.32594 .44407 .33239 .45068 .3426 .44861 .3362 .44135 Mtetra
.399 .614 .937 r
.3362 .44135 .3426 .44861 .35351 .43402 .34629 .44261 Mtetra
0 0 0 r
.34629 .44261 .35351 .43402 .36347 .4381 .35713 .4306 Mtetra
.593 .694 .913 r
.35713 .4306 .36347 .4381 .37383 .43534 .36747 .42866 Mtetra
.64 .738 .92 r
.36747 .42866 .37383 .43534 .38425 .43212 .37792 .42556 Mtetra
.649 .746 .92 r
.37792 .42556 .38425 .43212 .39473 .42873 .38841 .42221 Mtetra
.653 .749 .92 r
.38841 .42221 .39473 .42873 .40525 .42525 .39895 .41874 Mtetra
.656 .751 .92 r
.39895 .41874 .40525 .42525 .41581 .42171 .40954 .4152 Mtetra
.658 .753 .92 r
.40954 .4152 .41581 .42171 .42641 .41812 .42017 .41159 Mtetra
.659 .753 .92 r
.42017 .41159 .42641 .41812 .43706 .41449 .43084 .40795 Mtetra
.659 .754 .92 r
.43084 .40795 .43706 .41449 .44775 .41085 .44156 .40428 Mtetra
.44156 .40428 .44775 .41085 .45847 .40719 .45232 .4006 Mtetra
.45232 .4006 .45847 .40719 .46925 .40353 .46311 .3969 Mtetra
.659 .753 .92 r
.46311 .3969 .46925 .40353 .48006 .39986 .47396 .3932 Mtetra
.658 .753 .92 r
.47396 .3932 .48006 .39986 .49091 .39618 .48484 .38949 Mtetra
.48484 .38949 .49091 .39618 .50181 .39249 .49577 .38577 Mtetra
.49577 .38577 .50181 .39249 .51275 .38879 .50674 .38204 Mtetra
.50674 .38204 .51275 .38879 .52374 .38508 .51775 .37831 Mtetra
.51775 .37831 .52374 .38508 .53477 .38136 .52881 .37455 Mtetra
.52881 .37455 .53477 .38136 .54584 .37762 .53991 .37079 Mtetra
.657 .753 .92 r
.53991 .37079 .54584 .37762 .55696 .37387 .55106 .36701 Mtetra
.55106 .36701 .55696 .37387 .56812 .37011 .56225 .36322 Mtetra
.56225 .36322 .56812 .37011 .57933 .36633 .57349 .35942 Mtetra
.657 .752 .92 r
.57349 .35942 .57933 .36633 .59058 .36255 .58477 .3556 Mtetra
.58477 .3556 .59058 .36255 .60188 .35874 .5961 .35177 Mtetra
.5961 .35177 .60188 .35874 .61322 .35492 .60747 .34792 Mtetra
.60747 .34792 .61322 .35492 .62461 .35109 .61889 .34406 Mtetra
.61889 .34406 .62461 .35109 .63604 .34724 .63036 .34018 Mtetra
.63036 .34018 .63604 .34724 .64753 .34338 .64187 .33629 Mtetra
.64187 .33629 .64753 .34338 .65906 .33951 .65343 .33238 Mtetra
.65343 .33238 .65906 .33951 .67063 .33561 .66504 .32846 Mtetra
.66504 .32846 .67063 .33561 .68225 .33171 .6767 .32453 Mtetra
.6767 .32453 .68225 .33171 .69393 .32778 .6884 .32057 Mtetra
.6884 .32057 .69393 .32778 .70564 .32385 .70016 .3166 Mtetra
.70016 .3166 .70564 .32385 .71741 .31989 .71196 .31262 Mtetra
.71196 .31262 .71741 .31989 .72923 .31592 .72381 .30862 Mtetra
.72381 .30862 .72923 .31592 .74109 .31194 .73571 .3046 Mtetra
.73571 .3046 .74109 .31194 .75301 .30794 .74766 .30057 Mtetra
.74766 .30057 .75301 .30794 .76497 .30392 .75966 .29652 Mtetra
.75966 .29652 .76497 .30392 .77699 .29988 .77171 .29246 Mtetra
.77171 .29246 .77699 .29988 .78905 .29583 .78381 .28838 Mtetra
.78381 .28838 .78905 .29583 .80117 .29177 .79596 .28428 Mtetra
.79596 .28428 .80117 .29177 .81333 .28768 .80816 .28016 Mtetra
.602 .716 .924 r
.15962 .49026 .16642 .49687 .17597 .49501 .1692 .4882 Mtetra
.526 .682 .937 r
.1692 .4882 .17597 .49501 .18068 .54074 .17867 .48752 Mtetra
.612 .423 .601 r
.17867 .48752 .18068 .54074 .19575 .48565 .18916 .47742 Mtetra
.522 .636 .903 r
.18916 .47742 .19575 .48565 .20541 .48371 .19868 .47709 Mtetra
.613 .721 .923 r
.19868 .47709 .20541 .48371 .21516 .48143 .20844 .47478 Mtetra
.592 .714 .929 r
.20844 .47478 .21516 .48143 .22471 .48169 .21821 .47288 Mtetra
.865 .717 .697 r
.21821 .47288 .22471 .48169 .23527 .47117 .22983 .45086 Mtetra
.093 .161 .643 r
.22983 .45086 .23527 .47117 .24503 .46995 .23839 .46312 Mtetra
.611 .716 .92 r
.23839 .46312 .24503 .46995 .25496 .46738 .24831 .46082 Mtetra
.626 .731 .923 r
.24831 .46082 .25496 .46738 .26492 .46483 .2583 .45815 Mtetra
.604 .721 .927 r
.2583 .45815 .26492 .46483 .27478 .46427 .2683 .45596 Mtetra
.928 .71 .587 r
.2683 .45596 .27478 .46427 .28541 .45388 .28336 .38705 Mtetra
0 0 .345 r
.28336 .38705 .28541 .45388 .29537 .45287 .28884 .44591 Mtetra
.613 .716 .919 r
.28884 .44591 .29537 .45287 .30551 .4501 .29897 .44351 Mtetra
.636 .737 .921 r
.29897 .44351 .30551 .4501 .31571 .44709 .30918 .44054 Mtetra
.64 .74 .921 r
.30918 .44054 .31571 .44709 .32594 .44407 .31944 .43747 Mtetra
.635 .738 .922 r
.31944 .43747 .32594 .44407 .3362 .44135 .32974 .43451 Mtetra
.598 .718 .928 r
.32974 .43451 .3362 .44135 .34629 .44261 .34003 .43238 Mtetra
.82 .704 .737 r
.34003 .43238 .34629 .44261 .35713 .4306 .35105 .41768 Mtetra
.361 .444 .811 r
.35105 .41768 .35713 .4306 .36747 .42866 .36108 .42173 Mtetra
.628 .727 .919 r
.36108 .42173 .36747 .42866 .37792 .42556 .37153 .41891 Mtetra
.646 .743 .92 r
.37153 .41891 .37792 .42556 .38841 .42221 .38205 .41562 Mtetra
.652 .748 .92 r
.38205 .41562 .38841 .42221 .39895 .41874 .39262 .41217 Mtetra
.655 .75 .92 r
.39262 .41217 .39895 .41874 .40954 .4152 .40323 .40862 Mtetra
.657 .752 .92 r
.40323 .40862 .40954 .4152 .42017 .41159 .41389 .40501 Mtetra
.658 .753 .92 r
.41389 .40501 .42017 .41159 .43084 .40795 .42458 .40135 Mtetra
.659 .754 .92 r
.42458 .40135 .43084 .40795 .44156 .40428 .43533 .39766 Mtetra
.43533 .39766 .44156 .40428 .45232 .4006 .44611 .39395 Mtetra
.44611 .39395 .45232 .4006 .46311 .3969 .45694 .39023 Mtetra
.45694 .39023 .46311 .3969 .47396 .3932 .46781 .3865 Mtetra
.658 .753 .92 r
.46781 .3865 .47396 .3932 .48484 .38949 .47872 .38276 Mtetra
.47872 .38276 .48484 .38949 .49577 .38577 .48967 .37901 Mtetra
.48967 .37901 .49577 .38577 .50674 .38204 .50067 .37525 Mtetra
.50067 .37525 .50674 .38204 .51775 .37831 .51172 .37148 Mtetra
.51172 .37148 .51775 .37831 .52881 .37455 .5228 .3677 Mtetra
.5228 .3677 .52881 .37455 .53991 .37079 .53393 .36391 Mtetra
.53393 .36391 .53991 .37079 .55106 .36701 .54511 .3601 Mtetra
.657 .753 .92 r
.54511 .3601 .55106 .36701 .56225 .36322 .55633 .35628 Mtetra
.55633 .35628 .56225 .36322 .57349 .35942 .5676 .35245 Mtetra
.5676 .35245 .57349 .35942 .58477 .3556 .57891 .3486 Mtetra
.657 .752 .92 r
.57891 .3486 .58477 .3556 .5961 .35177 .59027 .34474 Mtetra
.59027 .34474 .5961 .35177 .60747 .34792 .60168 .34086 Mtetra
.60168 .34086 .60747 .34792 .61889 .34406 .61313 .33697 Mtetra
.61313 .33697 .61889 .34406 .63036 .34018 .62463 .33307 Mtetra
.62463 .33307 .63036 .34018 .64187 .33629 .63617 .32915 Mtetra
.63617 .32915 .64187 .33629 .65343 .33238 .64777 .32521 Mtetra
.64777 .32521 .65343 .33238 .66504 .32846 .65941 .32126 Mtetra
.65941 .32126 .66504 .32846 .6767 .32453 .6711 .31729 Mtetra
.6711 .31729 .6767 .32453 .6884 .32057 .68284 .31331 Mtetra
.68284 .31331 .6884 .32057 .70016 .3166 .69462 .30931 Mtetra
.69462 .30931 .70016 .3166 .71196 .31262 .70646 .30529 Mtetra
.70646 .30529 .71196 .31262 .72381 .30862 .71834 .30126 Mtetra
.71834 .30126 .72381 .30862 .73571 .3046 .73028 .29721 Mtetra
.73028 .29721 .73571 .3046 .74766 .30057 .74226 .29315 Mtetra
.74226 .29315 .74766 .30057 .75966 .29652 .7543 .28907 Mtetra
.7543 .28907 .75966 .29652 .77171 .29246 .76638 .28497 Mtetra
.76638 .28497 .77171 .29246 .78381 .28838 .77852 .28086 Mtetra
.77852 .28086 .78381 .28838 .79596 .28428 .79071 .27673 Mtetra
.79071 .27673 .79596 .28428 .80816 .28016 .80295 .27258 Mtetra
.586 .699 .921 r
.1528 .48327 .15962 .49026 .1692 .4882 .16236 .48155 Mtetra
.593 .714 .928 r
.16236 .48155 .1692 .4882 .17867 .48752 .17198 .47963 Mtetra
.951 .626 .376 r
.17198 .47963 .17867 .48752 .18916 .47742 .17667 .52552 Mtetra
0 0 0 r
.17667 .52552 .18916 .47742 .19868 .47709 .19193 .47014 Mtetra
.597 .707 .92 r
.19193 .47014 .19868 .47709 .20844 .47478 .20167 .46815 Mtetra
.612 .723 .925 r
.20167 .46815 .20844 .47478 .21821 .47288 .21149 .46582 Mtetra
.466 .652 .94 r
.21149 .46582 .21821 .47288 .22983 .45086 .22112 .46603 Mtetra
0 0 0 r
.22112 .46603 .22983 .45086 .23839 .46312 .23178 .45542 Mtetra
.564 .673 .912 r
.23178 .45542 .23839 .46312 .24831 .46082 .24162 .45415 Mtetra
.623 .728 .922 r
.24162 .45415 .24831 .46082 .2583 .45815 .25163 .45152 Mtetra
.622 .73 .924 r
.25163 .45152 .2583 .45815 .2683 .45596 .26167 .44891 Mtetra
.519 .678 .937 r
.26167 .44891 .2683 .45596 .28336 .38705 .27161 .4483 Mtetra
.434 .175 .42 r
.27161 .4483 .28336 .38705 .28884 .44591 .28234 .43782 Mtetra
.554 .66 .907 r
.28234 .43782 .28884 .44591 .29897 .44351 .29239 .43676 Mtetra
.63 .731 .921 r
.29239 .43676 .29897 .44351 .30918 .44054 .30261 .43393 Mtetra
.639 .739 .921 r
.30261 .43393 .30918 .44054 .31944 .43747 .31289 .43086 Mtetra
.639 .74 .922 r
.31289 .43086 .31944 .43747 .32974 .43451 .32322 .42777 Mtetra
.626 .733 .924 r
.32322 .42777 .32974 .43451 .34003 .43238 .33357 .42499 Mtetra
.4 .614 .937 r
.33357 .42499 .34003 .43238 .35105 .41768 .34374 .42621 Mtetra
0 0 0 r
.34374 .42621 .35105 .41768 .36108 .42173 .35468 .4141 Mtetra
.593 .694 .913 r
.35468 .4141 .36108 .42173 .37153 .41891 .36511 .4121 Mtetra
.64 .738 .92 r
.36511 .4121 .37153 .41891 .38205 .41562 .37565 .40894 Mtetra
.649 .746 .92 r
.37565 .40894 .38205 .41562 .39262 .41217 .38624 .40553 Mtetra
.653 .749 .92 r
.38624 .40553 .39262 .41217 .40323 .40862 .39687 .40199 Mtetra
.656 .751 .92 r
.39687 .40199 .40323 .40862 .41389 .40501 .40755 .39838 Mtetra
.658 .753 .92 r
.40755 .39838 .41389 .40501 .42458 .40135 .41828 .39471 Mtetra
.659 .753 .92 r
.41828 .39471 .42458 .40135 .43533 .39766 .42905 .391 Mtetra
.659 .754 .92 r
.42905 .391 .43533 .39766 .44611 .39395 .43986 .38726 Mtetra
.43986 .38726 .44611 .39395 .45694 .39023 .45071 .38351 Mtetra
.45071 .38351 .45694 .39023 .46781 .3865 .46161 .37974 Mtetra
.659 .753 .92 r
.46161 .37974 .46781 .3865 .47872 .38276 .47255 .37597 Mtetra
.658 .753 .92 r
.47255 .37597 .47872 .38276 .48967 .37901 .48354 .3722 Mtetra
.48354 .3722 .48967 .37901 .50067 .37525 .49456 .36841 Mtetra
.49456 .36841 .50067 .37525 .51172 .37148 .50564 .36461 Mtetra
.50564 .36461 .51172 .37148 .5228 .3677 .51675 .3608 Mtetra
.51675 .3608 .5228 .3677 .53393 .36391 .52791 .35698 Mtetra
.52791 .35698 .53393 .36391 .54511 .3601 .53912 .35314 Mtetra
.657 .753 .92 r
.53912 .35314 .54511 .3601 .55633 .35628 .55037 .34929 Mtetra
.55037 .34929 .55633 .35628 .5676 .35245 .56167 .34543 Mtetra
.56167 .34543 .5676 .35245 .57891 .3486 .57301 .34155 Mtetra
.657 .752 .92 r
.57301 .34155 .57891 .3486 .59027 .34474 .5844 .33766 Mtetra
.5844 .33766 .59027 .34474 .60168 .34086 .59584 .33375 Mtetra
.59584 .33375 .60168 .34086 .61313 .33697 .60732 .32983 Mtetra
.60732 .32983 .61313 .33697 .62463 .33307 .61886 .3259 Mtetra
.61886 .3259 .62463 .33307 .63617 .32915 .63043 .32195 Mtetra
.63043 .32195 .63617 .32915 .64777 .32521 .64206 .31798 Mtetra
.64206 .31798 .64777 .32521 .65941 .32126 .65373 .314 Mtetra
.65373 .314 .65941 .32126 .6711 .31729 .66546 .31 Mtetra
.66546 .31 .6711 .31729 .68284 .31331 .67723 .30598 Mtetra
.67723 .30598 .68284 .31331 .69462 .30931 .68905 .30195 Mtetra
.68905 .30195 .69462 .30931 .70646 .30529 .70092 .29791 Mtetra
.70092 .29791 .70646 .30529 .71834 .30126 .71284 .29385 Mtetra
.71284 .29385 .71834 .30126 .73028 .29721 .72481 .28977 Mtetra
.72481 .28977 .73028 .29721 .74226 .29315 .73683 .28567 Mtetra
.73683 .28567 .74226 .29315 .7543 .28907 .7489 .28156 Mtetra
.7489 .28156 .7543 .28907 .76638 .28497 .76102 .27743 Mtetra
.76102 .27743 .76638 .28497 .77852 .28086 .77319 .27328 Mtetra
.77319 .27328 .77852 .28086 .79071 .27673 .78542 .26912 Mtetra
.78542 .26912 .79071 .27673 .80295 .27258 .79769 .26494 Mtetra
.485 .603 .895 r
.14615 .47444 .1528 .48327 .16236 .48155 .15548 .47482 Mtetra
.602 .716 .924 r
.15548 .47482 .16236 .48155 .17198 .47963 .16514 .47271 Mtetra
.526 .682 .937 r
.16514 .47271 .17198 .47963 .17667 .52552 .17469 .47198 Mtetra
.611 .421 .6 r
.17469 .47198 .17667 .52552 .19193 .47014 .18527 .46179 Mtetra
.522 .636 .903 r
.18527 .46179 .19193 .47014 .20167 .46815 .19486 .46142 Mtetra
.613 .721 .923 r
.19486 .46142 .20167 .46815 .21149 .46582 .2047 .45905 Mtetra
.592 .714 .929 r
.2047 .45905 .21149 .46582 .22112 .46603 .21455 .4571 Mtetra
.866 .718 .696 r
.21455 .4571 .22112 .46603 .23178 .45542 .22629 .43494 Mtetra
.088 .158 .642 r
.22629 .43494 .23178 .45542 .24162 .45415 .23491 .44721 Mtetra
.611 .717 .92 r
.23491 .44721 .24162 .45415 .25163 .45152 .24491 .44485 Mtetra
.626 .731 .923 r
.24491 .44485 .25163 .45152 .26167 .44891 .25498 .44212 Mtetra
.604 .721 .927 r
.25498 .44212 .26167 .44891 .27161 .4483 .26506 .43987 Mtetra
.929 .71 .585 r
.26506 .43987 .27161 .4483 .28234 .43782 .28032 .37064 Mtetra
0 0 .34 r
.28032 .37064 .28234 .43782 .29239 .43676 .28578 .42968 Mtetra
.613 .717 .919 r
.28578 .42968 .29239 .43676 .30261 .43393 .296 .42722 Mtetra
.636 .737 .921 r
.296 .42722 .30261 .43393 .31289 .43086 .3063 .42419 Mtetra
.64 .74 .921 r
.3063 .42419 .31289 .43086 .32322 .42777 .31665 .42106 Mtetra
.635 .738 .922 r
.31665 .42106 .32322 .42777 .33357 .42499 .32703 .41803 Mtetra
.598 .718 .928 r
.32703 .41803 .33357 .42499 .34374 .42621 .33741 .41585 Mtetra
.82 .705 .738 r
.33741 .41585 .34374 .42621 .35468 .4141 .34854 .40103 Mtetra
.36 .443 .811 r
.34854 .40103 .35468 .4141 .36511 .4121 .35866 .40505 Mtetra
.628 .727 .919 r
.35866 .40505 .36511 .4121 .37565 .40894 .3692 .40216 Mtetra
.646 .743 .92 r
.3692 .40216 .37565 .40894 .38624 .40553 .37981 .39881 Mtetra
.652 .748 .92 r
.37981 .39881 .38624 .40553 .39687 .40199 .39047 .39529 Mtetra
.655 .75 .92 r
.39047 .39529 .39687 .40199 .40755 .39838 .40118 .39168 Mtetra
.657 .752 .92 r
.40118 .39168 .40755 .39838 .41828 .39471 .41193 .388 Mtetra
.658 .753 .92 r
.41193 .388 .41828 .39471 .42905 .391 .42272 .38428 Mtetra
.659 .754 .92 r
.42272 .38428 .42905 .391 .43986 .38726 .43356 .38052 Mtetra
.43356 .38052 .43986 .38726 .45071 .38351 .44444 .37674 Mtetra
.44444 .37674 .45071 .38351 .46161 .37974 .45537 .37294 Mtetra
.45537 .37294 .46161 .37974 .47255 .37597 .46634 .36914 Mtetra
.658 .753 .92 r
.46634 .36914 .47255 .37597 .48354 .3722 .47735 .36533 Mtetra
.47735 .36533 .48354 .3722 .49456 .36841 .48841 .36151 Mtetra
.48841 .36151 .49456 .36841 .50564 .36461 .49951 .35768 Mtetra
.49951 .35768 .50564 .36461 .51675 .3608 .51066 .35384 Mtetra
.51066 .35384 .51675 .3608 .52791 .35698 .52185 .34999 Mtetra
.52185 .34999 .52791 .35698 .53912 .35314 .53308 .34613 Mtetra
.53308 .34613 .53912 .35314 .55037 .34929 .54437 .34225 Mtetra
.657 .753 .92 r
.54437 .34225 .55037 .34929 .56167 .34543 .5557 .33836 Mtetra
.5557 .33836 .56167 .34543 .57301 .34155 .56707 .33445 Mtetra
.56707 .33445 .57301 .34155 .5844 .33766 .57849 .33053 Mtetra
.657 .752 .92 r
.57849 .33053 .5844 .33766 .59584 .33375 .58996 .32659 Mtetra
.58996 .32659 .59584 .33375 .60732 .32983 .60148 .32264 Mtetra
.60148 .32264 .60732 .32983 .61886 .3259 .61304 .31867 Mtetra
.61304 .31867 .61886 .3259 .63043 .32195 .62465 .31469 Mtetra
.62465 .31469 .63043 .32195 .64206 .31798 .63631 .31069 Mtetra
.63631 .31069 .64206 .31798 .65373 .314 .64802 .30668 Mtetra
.64802 .30668 .65373 .314 .66546 .31 .65977 .30265 Mtetra
.65977 .30265 .66546 .31 .67723 .30598 .67158 .29861 Mtetra
.67158 .29861 .67723 .30598 .68905 .30195 .68343 .29454 Mtetra
.68343 .29454 .68905 .30195 .70092 .29791 .69533 .29047 Mtetra
.69533 .29047 .70092 .29791 .71284 .29385 .70729 .28637 Mtetra
.70729 .28637 .71284 .29385 .72481 .28977 .71929 .28226 Mtetra
.71929 .28226 .72481 .28977 .73683 .28567 .73135 .27813 Mtetra
.73135 .27813 .73683 .28567 .7489 .28156 .74345 .27399 Mtetra
.74345 .27399 .7489 .28156 .76102 .27743 .75561 .26983 Mtetra
.75561 .26983 .76102 .27743 .77319 .27328 .76782 .26565 Mtetra
.76782 .26565 .77319 .27328 .78542 .26912 .78008 .26145 Mtetra
.78008 .26145 .78542 .26912 .79769 .26494 .7924 .25724 Mtetra
.761 .882 .467 r
.13667 .48943 .14615 .47444 .15548 .47482 .14859 .46772 Mtetra
.586 .699 .921 r
.14859 .46772 .15548 .47482 .16514 .47271 .15822 .46595 Mtetra
.593 .714 .927 r
.15822 .46595 .16514 .47271 .17469 .47198 .16792 .46398 Mtetra
.951 .625 .372 r
.16792 .46398 .17469 .47198 .18527 .46179 .17259 .51002 Mtetra
0 0 0 r
.17259 .51002 .18527 .46179 .19486 .46142 .18804 .45435 Mtetra
.597 .707 .92 r
.18804 .45435 .19486 .46142 .2047 .45905 .19786 .45231 Mtetra
.612 .723 .925 r
.19786 .45231 .2047 .45905 .21455 .4571 .20776 .44992 Mtetra
.466 .652 .94 r
.20776 .44992 .21455 .4571 .22629 .43494 .21747 .45008 Mtetra
0 0 0 r
.21747 .45008 .22629 .43494 .23491 .44721 .22822 .43938 Mtetra
.564 .673 .912 r
.22822 .43938 .23491 .44721 .24491 .44485 .23815 .43806 Mtetra
.623 .728 .922 r
.23815 .43806 .24491 .44485 .25498 .44212 .24824 .43537 Mtetra
.622 .73 .924 r
.24824 .43537 .25498 .44212 .26506 .43987 .25837 .4327 Mtetra
.519 .678 .937 r
.25837 .4327 .26506 .43987 .28032 .37064 .26839 .43204 Mtetra
.429 .168 .414 r
.26839 .43204 .28032 .37064 .28578 .42968 .27921 .42147 Mtetra
.554 .66 .907 r
.27921 .42147 .28578 .42968 .296 .42722 .28934 .42035 Mtetra
.63 .731 .921 r
.28934 .42035 .296 .42722 .3063 .42419 .29966 .41746 Mtetra
.639 .739 .921 r
.29966 .41746 .3063 .42419 .31665 .42106 .31003 .41432 Mtetra
.639 .74 .922 r
.31003 .41432 .31665 .42106 .32703 .41803 .32044 .41118 Mtetra
.626 .733 .924 r
.32044 .41118 .32703 .41803 .33741 .41585 .33088 .40833 Mtetra
.401 .614 .937 r
.33088 .40833 .33741 .41585 .34854 .40103 .34114 .4095 Mtetra
0 0 0 r
.34114 .4095 .34854 .40103 .35866 .40505 .35219 .39729 Mtetra
.593 .694 .913 r
.35219 .39729 .35866 .40505 .3692 .40216 .36271 .39524 Mtetra
.64 .738 .92 r
.36271 .39524 .3692 .40216 .37981 .39881 .37334 .39201 Mtetra
.649 .746 .92 r
.37334 .39201 .37981 .39881 .39047 .39529 .38402 .38853 Mtetra
.653 .749 .92 r
.38402 .38853 .39047 .39529 .40118 .39168 .39475 .38492 Mtetra
.656 .751 .92 r
.39475 .38492 .40118 .39168 .41193 .388 .40553 .38124 Mtetra
.658 .753 .92 r
.40553 .38124 .41193 .388 .42272 .38428 .41635 .3775 Mtetra
.659 .753 .92 r
.41635 .3775 .42272 .38428 .43356 .38052 .42722 .37372 Mtetra
.659 .754 .92 r
.42722 .37372 .43356 .38052 .44444 .37674 .43813 .36992 Mtetra
.43813 .36992 .44444 .37674 .45537 .37294 .44908 .36609 Mtetra
.44908 .36609 .45537 .37294 .46634 .36914 .46008 .36226 Mtetra
.659 .753 .92 r
.46008 .36226 .46634 .36914 .47735 .36533 .47112 .35842 Mtetra
.658 .753 .92 r
.47112 .35842 .47735 .36533 .48841 .36151 .48221 .35457 Mtetra
.48221 .35457 .48841 .36151 .49951 .35768 .49334 .35071 Mtetra
.49334 .35071 .49951 .35768 .51066 .35384 .50451 .34684 Mtetra
.50451 .34684 .51066 .35384 .52185 .34999 .51574 .34296 Mtetra
.51574 .34296 .52185 .34999 .53308 .34613 .527 .33906 Mtetra
.527 .33906 .53308 .34613 .54437 .34225 .53832 .33515 Mtetra
.657 .753 .92 r
.53832 .33515 .54437 .34225 .5557 .33836 .54967 .33123 Mtetra
.54967 .33123 .5557 .33836 .56707 .33445 .56108 .32729 Mtetra
.56108 .32729 .56707 .33445 .57849 .33053 .57253 .32334 Mtetra
.657 .752 .92 r
.57253 .32334 .57849 .33053 .58996 .32659 .58403 .31937 Mtetra
.58403 .31937 .58996 .32659 .60148 .32264 .59558 .31539 Mtetra
.59558 .31539 .60148 .32264 .61304 .31867 .60718 .31139 Mtetra
.60718 .31139 .61304 .31867 .62465 .31469 .61882 .30738 Mtetra
.61882 .30738 .62465 .31469 .63631 .31069 .63051 .30335 Mtetra
.63051 .30335 .63631 .31069 .64802 .30668 .64225 .29931 Mtetra
.64225 .29931 .64802 .30668 .65977 .30265 .65404 .29525 Mtetra
.65404 .29525 .65977 .30265 .67158 .29861 .66588 .29117 Mtetra
.66588 .29117 .67158 .29861 .68343 .29454 .67777 .28708 Mtetra
.67777 .28708 .68343 .29454 .69533 .29047 .68971 .28297 Mtetra
.68971 .28297 .69533 .29047 .70729 .28637 .7017 .27884 Mtetra
.7017 .27884 .70729 .28637 .71929 .28226 .71374 .2747 Mtetra
.71374 .2747 .71929 .28226 .73135 .27813 .72583 .27054 Mtetra
.72583 .27054 .73135 .27813 .74345 .27399 .73797 .26636 Mtetra
.73797 .26636 .74345 .27399 .75561 .26983 .75016 .26216 Mtetra
.75016 .26216 .75561 .26983 .76782 .26565 .76241 .25795 Mtetra
.76241 .25795 .76782 .26565 .78008 .26145 .77471 .25372 Mtetra
.77471 .25372 .78008 .26145 .7924 .25724 .78706 .24947 Mtetra
.702 .56 .69 r
.13124 .4692 .13667 .48943 .14859 .46772 .14187 .45877 Mtetra
.485 .603 .895 r
.14187 .45877 .14859 .46772 .15822 .46595 .15127 .45911 Mtetra
.602 .716 .924 r
.15127 .45911 .15822 .46595 .16792 .46398 .161 .45694 Mtetra
.526 .682 .937 r
.161 .45694 .16792 .46398 .17259 .51002 .17063 .45616 Mtetra
.61 .418 .598 r
.17063 .45616 .17259 .51002 .18804 .45435 .18131 .44588 Mtetra
.522 .636 .904 r
.18131 .44588 .18804 .45435 .19786 .45231 .19098 .44546 Mtetra
.613 .721 .923 r
.19098 .44546 .19786 .45231 .20776 .44992 .2009 .44303 Mtetra
.592 .714 .929 r
.2009 .44303 .20776 .44992 .21747 .45008 .21082 .44103 Mtetra
.867 .719 .696 r
.21082 .44103 .21747 .45008 .22822 .43938 .22269 .41872 Mtetra
.084 .155 .64 r
.22269 .41872 .22822 .43938 .23815 .43806 .23136 .431 Mtetra
.611 .717 .92 r
.23136 .431 .23815 .43806 .24824 .43537 .24144 .42858 Mtetra
.626 .731 .923 r
.24144 .42858 .24824 .43537 .25837 .4327 .2516 .42579 Mtetra
.604 .721 .927 r
.2516 .42579 .25837 .4327 .26839 .43204 .26177 .42348 Mtetra
.931 .711 .584 r
.26177 .42348 .26839 .43204 .27921 .42147 .27722 .35393 Mtetra
0 0 .335 r
.27722 .35393 .27921 .42147 .28934 .42035 .28267 .41315 Mtetra
.613 .717 .919 r
.28267 .41315 .28934 .42035 .29966 .41746 .29297 .41063 Mtetra
.636 .737 .921 r
.29297 .41063 .29966 .41746 .31003 .41432 .30336 .40754 Mtetra
.64 .74 .921 r
.30336 .40754 .31003 .41432 .32044 .41118 .3138 .40434 Mtetra
.635 .738 .922 r
.3138 .40434 .32044 .41118 .33088 .40833 .32428 .40125 Mtetra
.598 .718 .928 r
.32428 .40125 .33088 .40833 .34114 .4095 .33475 .399 Mtetra
.821 .706 .738 r
.33475 .399 .34114 .4095 .35219 .39729 .34598 .38408 Mtetra
.358 .442 .811 r
.34598 .38408 .35219 .39729 .36271 .39524 .35618 .38805 Mtetra
.627 .727 .919 r
.35618 .38805 .36271 .39524 .37334 .39201 .36682 .38511 Mtetra
.646 .743 .92 r
.36682 .38511 .37334 .39201 .38402 .38853 .37752 .38169 Mtetra
.652 .748 .92 r
.37752 .38169 .38402 .38853 .39475 .38492 .38828 .3781 Mtetra
.655 .75 .92 r
.38828 .3781 .39475 .38492 .40553 .38124 .39908 .37442 Mtetra
.657 .752 .92 r
.39908 .37442 .40553 .38124 .41635 .3775 .40993 .37067 Mtetra
.658 .753 .92 r
.40993 .37067 .41635 .3775 .42722 .37372 .42083 .36688 Mtetra
.659 .754 .92 r
.42083 .36688 .42722 .37372 .43813 .36992 .43177 .36305 Mtetra
.43177 .36305 .43813 .36992 .44908 .36609 .44275 .35919 Mtetra
.44275 .35919 .44908 .36609 .46008 .36226 .45377 .35533 Mtetra
.45377 .35533 .46008 .36226 .47112 .35842 .46484 .35146 Mtetra
.658 .753 .92 r
.46484 .35146 .47112 .35842 .48221 .35457 .47596 .34757 Mtetra
.47596 .34757 .48221 .35457 .49334 .35071 .48712 .34368 Mtetra
.48712 .34368 .49334 .35071 .50451 .34684 .49833 .33978 Mtetra
.49833 .33978 .50451 .34684 .51574 .34296 .50958 .33587 Mtetra
.50958 .33587 .51574 .34296 .527 .33906 .52087 .33194 Mtetra
.52087 .33194 .527 .33906 .53832 .33515 .53222 .328 Mtetra
.53222 .328 .53832 .33515 .54967 .33123 .54361 .32405 Mtetra
.657 .753 .92 r
.54361 .32405 .54967 .33123 .56108 .32729 .55505 .32008 Mtetra
.55505 .32008 .56108 .32729 .57253 .32334 .56653 .3161 Mtetra
.56653 .3161 .57253 .32334 .58403 .31937 .57806 .3121 Mtetra
.657 .752 .92 r
.57806 .3121 .58403 .31937 .59558 .31539 .58964 .30808 Mtetra
.58964 .30808 .59558 .31539 .60718 .31139 .60127 .30406 Mtetra
.60127 .30406 .60718 .31139 .61882 .30738 .61294 .30001 Mtetra
.61294 .30001 .61882 .30738 .63051 .30335 .62467 .29595 Mtetra
.62467 .29595 .63051 .30335 .64225 .29931 .63644 .29188 Mtetra
.63644 .29188 .64225 .29931 .65404 .29525 .64827 .28778 Mtetra
.64827 .28778 .65404 .29525 .66588 .29117 .66014 .28367 Mtetra
.66014 .28367 .66588 .29117 .67777 .28708 .67206 .27955 Mtetra
.67206 .27955 .67777 .28708 .68971 .28297 .68404 .27541 Mtetra
.68404 .27541 .68971 .28297 .7017 .27884 .69606 .27125 Mtetra
.69606 .27125 .7017 .27884 .71374 .2747 .70814 .26707 Mtetra
.70814 .26707 .71374 .2747 .72583 .27054 .72026 .26288 Mtetra
.72026 .26288 .72583 .27054 .73797 .26636 .73244 .25867 Mtetra
.73244 .25867 .73797 .26636 .75016 .26216 .74467 .25444 Mtetra
.74467 .25444 .75016 .26216 .76241 .25795 .75695 .2502 Mtetra
.75695 .2502 .76241 .25795 .77471 .25372 .76929 .24593 Mtetra
.76929 .24593 .77471 .25372 .78706 .24947 .78168 .24165 Mtetra
.73 .253 0 r
.12431 .46142 .13124 .4692 .14187 .45877 .13226 .47374 Mtetra
.768 .887 .475 r
.13226 .47374 .14187 .45877 .15127 .45911 .1443 .45189 Mtetra
.586 .699 .921 r
.1443 .45189 .15127 .45911 .161 .45694 .15401 .45006 Mtetra
.593 .714 .927 r
.15401 .45006 .161 .45694 .17063 .45616 .16379 .44804 Mtetra
.951 .624 .368 r
.16379 .44804 .17063 .45616 .18131 .44588 .16843 .49423 Mtetra
0 0 0 r
.16843 .49423 .18131 .44588 .19098 .44546 .18408 .43828 Mtetra
.597 .707 .92 r
.18408 .43828 .19098 .44546 .2009 .44303 .19398 .43618 Mtetra
.612 .723 .925 r
.19398 .43618 .2009 .44303 .21082 .44103 .20396 .43373 Mtetra
.467 .652 .94 r
.20396 .43373 .21082 .44103 .22269 .41872 .21375 .43384 Mtetra
0 0 0 r
.21375 .43384 .22269 .41872 .23136 .431 .2246 .42305 Mtetra
.564 .673 .912 r
.2246 .42305 .23136 .431 .24144 .42858 .23461 .42167 Mtetra
.623 .728 .922 r
.23461 .42167 .24144 .42858 .2516 .42579 .24478 .41892 Mtetra
.622 .73 .924 r
.24478 .41892 .2516 .42579 .26177 .42348 .255 .4162 Mtetra
.519 .678 .937 r
.255 .4162 .26177 .42348 .27722 .35393 .2651 .41548 Mtetra
.423 .161 .409 r
.2651 .41548 .27722 .35393 .28267 .41315 .27603 .40481 Mtetra
.554 .66 .907 r
.27603 .40481 .28267 .41315 .29297 .41063 .28625 .40364 Mtetra
.63 .731 .921 r
.28625 .40364 .29297 .41063 .30336 .40754 .29665 .40069 Mtetra
.639 .739 .921 r
.29665 .40069 .30336 .40754 .3138 .40434 .30711 .39748 Mtetra
.639 .74 .922 r
.30711 .39748 .3138 .40434 .32428 .40125 .31762 .39427 Mtetra
.626 .733 .924 r
.31762 .39427 .32428 .40125 .33475 .399 .32815 .39136 Mtetra
.402 .614 .937 r
.32815 .39136 .33475 .399 .34598 .38408 .33849 .39248 Mtetra
0 0 0 r
.33849 .39248 .34598 .38408 .35618 .38805 .34964 .38017 Mtetra
.593 .694 .913 r
.34964 .38017 .35618 .38805 .36682 .38511 .36026 .37805 Mtetra
.64 .738 .92 r
.36026 .37805 .36682 .38511 .37752 .38169 .37098 .37476 Mtetra
.649 .746 .92 r
.37098 .37476 .37752 .38169 .38828 .3781 .38176 .37121 Mtetra
.653 .749 .92 r
.38176 .37121 .38828 .3781 .39908 .37442 .39259 .36753 Mtetra
.656 .751 .92 r
.39259 .36753 .39908 .37442 .40993 .37067 .40347 .36378 Mtetra
.658 .753 .92 r
.40347 .36378 .40993 .37067 .42083 .36688 .41439 .35997 Mtetra
.659 .753 .92 r
.41439 .35997 .42083 .36688 .43177 .36305 .42535 .35612 Mtetra
.659 .754 .92 r
.42535 .35612 .43177 .36305 .44275 .35919 .43636 .35224 Mtetra
.43636 .35224 .44275 .35919 .45377 .35533 .44742 .34835 Mtetra
.44742 .34835 .45377 .35533 .46484 .35146 .45852 .34444 Mtetra
.659 .753 .92 r
.45852 .34444 .46484 .35146 .47596 .34757 .46966 .34053 Mtetra
.658 .753 .92 r
.46966 .34053 .47596 .34757 .48712 .34368 .48085 .3366 Mtetra
.48085 .3366 .48712 .34368 .49833 .33978 .49209 .33267 Mtetra
.49209 .33267 .49833 .33978 .50958 .33587 .50337 .32872 Mtetra
.50337 .32872 .50958 .33587 .52087 .33194 .5147 .32477 Mtetra
.5147 .32477 .52087 .33194 .53222 .328 .52607 .3208 Mtetra
.52607 .3208 .53222 .328 .54361 .32405 .5375 .31681 Mtetra
.657 .753 .92 r
.5375 .31681 .54361 .32405 .55505 .32008 .54896 .31281 Mtetra
.54896 .31281 .55505 .32008 .56653 .3161 .56048 .3088 Mtetra
.56048 .3088 .56653 .3161 .57806 .3121 .57204 .30477 Mtetra
.657 .752 .92 r
.57204 .30477 .57806 .3121 .58964 .30808 .58365 .30072 Mtetra
.58365 .30072 .58964 .30808 .60127 .30406 .59532 .29666 Mtetra
.59532 .29666 .60127 .30406 .61294 .30001 .60702 .29259 Mtetra
.60702 .29259 .61294 .30001 .62467 .29595 .61878 .2885 Mtetra
.61878 .2885 .62467 .29595 .63644 .29188 .63059 .28439 Mtetra
.63059 .28439 .63644 .29188 .64827 .28778 .64245 .28026 Mtetra
.64245 .28026 .64827 .28778 .66014 .28367 .65435 .27612 Mtetra
.65435 .27612 .66014 .28367 .67206 .27955 .66631 .27196 Mtetra
.66631 .27196 .67206 .27955 .68404 .27541 .67832 .26779 Mtetra
.67832 .26779 .68404 .27541 .69606 .27125 .69038 .2636 Mtetra
.69038 .2636 .69606 .27125 .70814 .26707 .70249 .25939 Mtetra
.70249 .25939 .70814 .26707 .72026 .26288 .71465 .25516 Mtetra
.71465 .25516 .72026 .26288 .73244 .25867 .72687 .25092 Mtetra
.72687 .25092 .73244 .25867 .74467 .25444 .73913 .24666 Mtetra
.73913 .24666 .74467 .25444 .75695 .2502 .75145 .24238 Mtetra
.75145 .24238 .75695 .2502 .76929 .24593 .76383 .23808 Mtetra
.76383 .23808 .76929 .24593 .78168 .24165 .77625 .23376 Mtetra
.539 .688 .935 r
.11724 .45435 .12431 .46142 .13226 .47374 .12678 .45334 Mtetra
.702 .559 .69 r
.12678 .45334 .13226 .47374 .1443 .45189 .13751 .44281 Mtetra
.484 .603 .895 r
.13751 .44281 .1443 .45189 .15401 .45006 .14698 .44311 Mtetra
.602 .716 .924 r
.14698 .44311 .15401 .45006 .16379 .44804 .15679 .44088 Mtetra
.526 .682 .937 r
.15679 .44088 .16379 .44804 .16843 .49423 .1665 .44005 Mtetra
.608 .416 .597 r
.1665 .44005 .16843 .49423 .18408 .43828 .17727 .42968 Mtetra
.521 .636 .904 r
.17727 .42968 .18408 .43828 .19398 .43618 .18702 .42921 Mtetra
.613 .721 .923 r
.18702 .42921 .19398 .43618 .20396 .43373 .19702 .42672 Mtetra
.592 .714 .929 r
.19702 .42672 .20396 .43373 .21375 .43384 .20703 .42466 Mtetra
.868 .72 .696 r
.20703 .42466 .21375 .43384 .2246 .42305 .21902 .40222 Mtetra
.08 .152 .639 r
.21902 .40222 .2246 .42305 .23461 .42167 .22774 .41449 Mtetra
.611 .717 .92 r
.22774 .41449 .23461 .42167 .24478 .41892 .23791 .41201 Mtetra
.626 .731 .923 r
.23791 .41201 .24478 .41892 .255 .4162 .24816 .40916 Mtetra
.604 .721 .927 r
.24816 .40916 .255 .4162 .2651 .41548 .25841 .40679 Mtetra
.932 .712 .582 r
.25841 .40679 .2651 .41548 .27603 .40481 .27407 .33691 Mtetra
0 0 .329 r
.27407 .33691 .27603 .40481 .28625 .40364 .27949 .39632 Mtetra
.613 .717 .919 r
.27949 .39632 .28625 .40364 .29665 .40069 .28989 .39373 Mtetra
.636 .737 .921 r
.28989 .39373 .29665 .40069 .30711 .39748 .30037 .39057 Mtetra
.64 .74 .921 r
.30037 .39057 .30711 .39748 .31762 .39427 .3109 .38731 Mtetra
.635 .738 .922 r
.3109 .38731 .31762 .39427 .32815 .39136 .32147 .38415 Mtetra
.598 .718 .928 r
.32147 .38415 .32815 .39136 .33849 .39248 .33203 .38184 Mtetra
.822 .707 .738 r
.33203 .38184 .33849 .39248 .34964 .38017 .34337 .3668 Mtetra
.357 .442 .811 r
.34337 .3668 .34964 .38017 .36026 .37805 .35366 .37074 Mtetra
.627 .727 .919 r
.35366 .37074 .36026 .37805 .37098 .37476 .36439 .36772 Mtetra
.646 .743 .92 r
.36439 .36772 .37098 .37476 .38176 .37121 .37519 .36424 Mtetra
.652 .748 .92 r
.37519 .36424 .38176 .37121 .39259 .36753 .38605 .36058 Mtetra
.655 .75 .92 r
.38605 .36058 .39259 .36753 .40347 .36378 .39695 .35683 Mtetra
.657 .752 .92 r
.39695 .35683 .40347 .36378 .41439 .35997 .4079 .35301 Mtetra
.658 .753 .92 r
.4079 .35301 .41439 .35997 .42535 .35612 .41889 .34914 Mtetra
.659 .754 .92 r
.41889 .34914 .42535 .35612 .43636 .35224 .42993 .34524 Mtetra
.42993 .34524 .43636 .35224 .44742 .34835 .44102 .34131 Mtetra
.44102 .34131 .44742 .34835 .45852 .34444 .45215 .33738 Mtetra
.45215 .33738 .45852 .34444 .46966 .34053 .46332 .33343 Mtetra
.658 .753 .92 r
.46332 .33343 .46966 .34053 .48085 .3366 .47454 .32947 Mtetra
.47454 .32947 .48085 .3366 .49209 .33267 .48581 .32551 Mtetra
.48581 .32551 .49209 .33267 .50337 .32872 .49712 .32153 Mtetra
.49712 .32153 .50337 .32872 .5147 .32477 .50848 .31754 Mtetra
.50848 .31754 .5147 .32477 .52607 .3208 .51988 .31354 Mtetra
.51988 .31354 .52607 .3208 .5375 .31681 .53133 .30952 Mtetra
.53133 .30952 .5375 .31681 .54896 .31281 .54283 .30549 Mtetra
.657 .753 .92 r
.54283 .30549 .54896 .31281 .56048 .3088 .55438 .30144 Mtetra
.55438 .30144 .56048 .3088 .57204 .30477 .56598 .29738 Mtetra
.56598 .29738 .57204 .30477 .58365 .30072 .57762 .29331 Mtetra
.657 .752 .92 r
.57762 .29331 .58365 .30072 .59532 .29666 .58932 .28921 Mtetra
.58932 .28921 .59532 .29666 .60702 .29259 .60106 .28511 Mtetra
.60106 .28511 .60702 .29259 .61878 .2885 .61285 .28098 Mtetra
.61285 .28098 .61878 .2885 .63059 .28439 .62469 .27684 Mtetra
.62469 .27684 .63059 .28439 .64245 .28026 .63658 .27268 Mtetra
.63658 .27268 .64245 .28026 .65435 .27612 .64852 .26851 Mtetra
.64852 .26851 .65435 .27612 .66631 .27196 .66052 .26432 Mtetra
.66052 .26432 .66631 .27196 .67832 .26779 .67256 .26011 Mtetra
.67256 .26011 .67832 .26779 .69038 .2636 .68465 .25589 Mtetra
.68465 .25589 .69038 .2636 .70249 .25939 .6968 .25164 Mtetra
.6968 .25164 .70249 .25939 .71465 .25516 .709 .24738 Mtetra
.709 .24738 .71465 .25516 .72687 .25092 .72125 .24311 Mtetra
.72125 .24311 .72687 .25092 .73913 .24666 .73355 .23881 Mtetra
.73355 .23881 .73913 .24666 .75145 .24238 .74591 .2345 Mtetra
.74591 .2345 .75145 .24238 .76383 .23808 .75832 .23016 Mtetra
.75832 .23016 .76383 .23808 .77625 .23376 .77078 .22581 Mtetra
.588 .71 .927 r
.1101 .44737 .11724 .45435 .12678 .45334 .11977 .44543 Mtetra
.725 .247 0 r
.11977 .44543 .12678 .45334 .13751 .44281 .12776 .45776 Mtetra
.775 .892 .483 r
.12776 .45776 .13751 .44281 .14698 .44311 .13994 .43577 Mtetra
.586 .699 .921 r
.13994 .43577 .14698 .44311 .15679 .44088 .14973 .43389 Mtetra
.593 .714 .927 r
.14973 .43389 .15679 .44088 .1665 .44005 .15958 .4318 Mtetra
.952 .623 .363 r
.15958 .4318 .1665 .44005 .17727 .42968 .16419 .47815 Mtetra
0 0 0 r
.16419 .47815 .17727 .42968 .18702 .42921 .18004 .4219 Mtetra
.597 .707 .92 r
.18004 .4219 .18702 .42921 .19702 .42672 .19003 .41975 Mtetra
.612 .723 .925 r
.19003 .41975 .19702 .42672 .20703 .42466 .20009 .41724 Mtetra
.467 .652 .94 r
.20009 .41724 .20703 .42466 .21902 .40222 .20996 .4173 Mtetra
0 0 0 r
.20996 .4173 .21902 .40222 .22774 .41449 .22091 .40642 Mtetra
.564 .673 .912 r
.22091 .40642 .22774 .41449 .23791 .41201 .231 .40498 Mtetra
.623 .728 .922 r
.231 .40498 .23791 .41201 .24816 .40916 .24126 .40217 Mtetra
.622 .73 .924 r
.24126 .40217 .24816 .40916 .25841 .40679 .25157 .39938 Mtetra
.52 .678 .937 r
.25157 .39938 .25841 .40679 .27407 .33691 .26175 .3986 Mtetra
.418 .153 .403 r
.26175 .3986 .27407 .33691 .27949 .39632 .27278 .38784 Mtetra
.554 .66 .907 r
.27278 .38784 .27949 .39632 .28989 .39373 .28309 .38661 Mtetra
.63 .731 .921 r
.28309 .38661 .28989 .39373 .30037 .39057 .29358 .38359 Mtetra
.639 .739 .921 r
.29358 .38359 .30037 .39057 .3109 .38731 .30413 .38032 Mtetra
.639 .74 .922 r
.30413 .38032 .3109 .38731 .32147 .38415 .31473 .37705 Mtetra
.626 .733 .924 r
.31473 .37705 .32147 .38415 .33203 .38184 .32536 .37407 Mtetra
.403 .615 .936 r
.32536 .37407 .33203 .38184 .34337 .3668 .33579 .37514 Mtetra
.525 .817 .476 r
.33579 .37514 .34337 .3668 .35366 .37074 .34705 .36272 Mtetra
.593 .694 .913 r
.34705 .36272 .35366 .37074 .36439 .36772 .35776 .36054 Mtetra
.64 .738 .92 r
.35776 .36054 .36439 .36772 .37519 .36424 .36858 .35718 Mtetra
.649 .746 .92 r
.36858 .35718 .37519 .36424 .38605 .36058 .37946 .35355 Mtetra
.653 .749 .92 r
.37946 .35355 .38605 .36058 .39695 .35683 .39039 .34981 Mtetra
.656 .751 .92 r
.39039 .34981 .39695 .35683 .4079 .35301 .40136 .34599 Mtetra
.658 .753 .92 r
.40136 .34599 .4079 .35301 .41889 .34914 .41238 .3421 Mtetra
.659 .753 .92 r
.41238 .3421 .41889 .34914 .42993 .34524 .42345 .33818 Mtetra
.659 .754 .92 r
.42345 .33818 .42993 .34524 .44102 .34131 .43457 .33423 Mtetra
.43457 .33423 .44102 .34131 .45215 .33738 .44573 .33026 Mtetra
.44573 .33026 .45215 .33738 .46332 .33343 .45693 .32628 Mtetra
.659 .753 .92 r
.45693 .32628 .46332 .33343 .47454 .32947 .46818 .32229 Mtetra
.658 .753 .92 r
.46818 .32229 .47454 .32947 .48581 .32551 .47948 .31829 Mtetra
.47948 .31829 .48581 .32551 .49712 .32153 .49082 .31428 Mtetra
.49082 .31428 .49712 .32153 .50848 .31754 .50221 .31026 Mtetra
.50221 .31026 .50848 .31754 .51988 .31354 .51364 .30622 Mtetra
.51364 .30622 .51988 .31354 .53133 .30952 .52513 .30217 Mtetra
.52513 .30217 .53133 .30952 .54283 .30549 .53666 .29811 Mtetra
.657 .753 .92 r
.53666 .29811 .54283 .30549 .55438 .30144 .54824 .29403 Mtetra
.54824 .29403 .55438 .30144 .56598 .29738 .55987 .28994 Mtetra
.55987 .28994 .56598 .29738 .57762 .29331 .57154 .28583 Mtetra
.657 .752 .92 r
.57154 .28583 .57762 .29331 .58932 .28921 .58327 .28171 Mtetra
.58327 .28171 .58932 .28921 .60106 .28511 .59504 .27757 Mtetra
.59504 .27757 .60106 .28511 .61285 .28098 .60687 .27341 Mtetra
.60687 .27341 .61285 .28098 .62469 .27684 .61874 .26924 Mtetra
.61874 .26924 .62469 .27684 .63658 .27268 .63067 .26505 Mtetra
.63067 .26505 .63658 .27268 .64852 .26851 .64265 .26084 Mtetra
.64265 .26084 .64852 .26851 .66052 .26432 .65467 .25661 Mtetra
.65467 .25661 .66052 .26432 .67256 .26011 .66675 .25237 Mtetra
.66675 .25237 .67256 .26011 .68465 .25589 .67888 .24811 Mtetra
.67888 .24811 .68465 .25589 .6968 .25164 .69107 .24384 Mtetra
.69107 .24384 .6968 .25164 .709 .24738 .7033 .23954 Mtetra
.7033 .23954 .709 .24738 .72125 .24311 .71559 .23523 Mtetra
.71559 .23523 .72125 .24311 .73355 .23881 .72793 .2309 Mtetra
.72793 .2309 .73355 .23881 .74591 .2345 .74032 .22655 Mtetra
.74032 .22655 .74591 .2345 .75832 .23016 .75277 .22219 Mtetra
.75277 .22219 .75832 .23016 .77078 .22581 .76527 .2178 Mtetra
.586 .703 .923 r
.10294 .44015 .1101 .44737 .11977 .44543 .11262 .43825 Mtetra
.539 .688 .935 r
.11262 .43825 .11977 .44543 .12776 .45776 .12225 .43719 Mtetra
.702 .559 .69 r
.12225 .43719 .12776 .45776 .13994 .43577 .13307 .42657 Mtetra
.484 .603 .895 r
.13307 .42657 .13994 .43577 .14973 .43389 .14261 .42681 Mtetra
.602 .716 .924 r
.14261 .42681 .14973 .43389 .15958 .4318 .15251 .42453 Mtetra
.527 .682 .937 r
.15251 .42453 .15958 .4318 .16419 .47815 .16229 .42365 Mtetra
.607 .414 .595 r
.16229 .42365 .16419 .47815 .18004 .4219 .17316 .41318 Mtetra
.521 .636 .904 r
.17316 .41318 .18004 .4219 .19003 .41975 .18299 .41266 Mtetra
.613 .721 .923 r
.18299 .41266 .19003 .41975 .20009 .41724 .19308 .41011 Mtetra
.592 .714 .928 r
.19308 .41011 .20009 .41724 .20996 .4173 .20317 .40799 Mtetra
.869 .721 .696 r
.20317 .40799 .20996 .4173 .22091 .40642 .21528 .3854 Mtetra
.075 .149 .637 r
.21528 .3854 .22091 .40642 .231 .40498 .22406 .39767 Mtetra
.611 .717 .92 r
.22406 .39767 .231 .40498 .24126 .40217 .23432 .39513 Mtetra
.626 .731 .923 r
.23432 .39513 .24126 .40217 .25157 .39938 .24465 .39222 Mtetra
.604 .721 .927 r
.24465 .39222 .25157 .39938 .26175 .3986 .25499 .38978 Mtetra
.933 .712 .581 r
.25499 .38978 .26175 .3986 .27278 .38784 .27086 .31958 Mtetra
0 0 .324 r
.27086 .31958 .27278 .38784 .28309 .38661 .27626 .37916 Mtetra
.613 .717 .919 r
.27626 .37916 .28309 .38661 .29358 .38359 .28675 .37651 Mtetra
.636 .737 .921 r
.28675 .37651 .29358 .38359 .30413 .38032 .29732 .37329 Mtetra
.64 .74 .921 r
.29732 .37329 .30413 .38032 .31473 .37705 .30795 .36995 Mtetra
.635 .738 .922 r
.30795 .36995 .31473 .37705 .32536 .37407 .31861 .36673 Mtetra
.598 .718 .928 r
.31861 .36673 .32536 .37407 .33579 .37514 .32927 .36435 Mtetra
.823 .708 .738 r
.32927 .36435 .33579 .37514 .34705 .36272 .34072 .3492 Mtetra
.355 .441 .811 r
.34072 .3492 .34705 .36272 .35776 .36054 .35109 .35309 Mtetra
.627 .727 .919 r
.35109 .35309 .35776 .36054 .36858 .35718 .36192 .35001 Mtetra
.646 .743 .92 r
.36192 .35001 .36858 .35718 .37946 .35355 .37282 .34645 Mtetra
.652 .748 .92 r
.37282 .34645 .37946 .35355 .39039 .34981 .38377 .34272 Mtetra
.655 .75 .92 r
.38377 .34272 .39039 .34981 .40136 .34599 .39478 .3389 Mtetra
.657 .752 .92 r
.39478 .3389 .40136 .34599 .41238 .3421 .40583 .33501 Mtetra
.658 .753 .92 r
.40583 .33501 .41238 .3421 .42345 .33818 .41692 .33106 Mtetra
.659 .754 .92 r
.41692 .33106 .42345 .33818 .43457 .33423 .42807 .32709 Mtetra
.42807 .32709 .43457 .33423 .44573 .33026 .43925 .32309 Mtetra
.43925 .32309 .44573 .33026 .45693 .32628 .45049 .31907 Mtetra
.45049 .31907 .45693 .32628 .46818 .32229 .46177 .31505 Mtetra
.658 .753 .92 r
.46177 .31505 .46818 .32229 .47948 .31829 .47309 .31102 Mtetra
.47309 .31102 .47948 .31829 .49082 .31428 .48447 .30697 Mtetra
.48447 .30697 .49082 .31428 .50221 .31026 .49589 .30292 Mtetra
.49589 .30292 .50221 .31026 .51364 .30622 .50736 .29885 Mtetra
.50736 .29885 .51364 .30622 .52513 .30217 .51887 .29477 Mtetra
.51887 .29477 .52513 .30217 .53666 .29811 .53043 .29067 Mtetra
.53043 .29067 .53666 .29811 .54824 .29403 .54205 .28656 Mtetra
.657 .753 .92 r
.54205 .28656 .54824 .29403 .55987 .28994 .55371 .28244 Mtetra
.55371 .28244 .55987 .28994 .57154 .28583 .56542 .2783 Mtetra
.56542 .2783 .57154 .28583 .58327 .28171 .57717 .27414 Mtetra
.657 .752 .92 r
.57717 .27414 .58327 .28171 .59504 .27757 .58898 .26997 Mtetra
.58898 .26997 .59504 .27757 .60687 .27341 .60084 .26578 Mtetra
.60084 .26578 .60687 .27341 .61874 .26924 .61275 .26157 Mtetra
.61275 .26157 .61874 .26924 .63067 .26505 .62471 .25735 Mtetra
.62471 .25735 .63067 .26505 .64265 .26084 .63672 .25311 Mtetra
.63672 .25311 .64265 .26084 .65467 .25661 .64879 .24885 Mtetra
.64879 .24885 .65467 .25661 .66675 .25237 .6609 .24457 Mtetra
.6609 .24457 .66675 .25237 .67888 .24811 .67307 .24028 Mtetra
.67307 .24028 .67888 .24811 .69107 .24384 .68528 .23597 Mtetra
.68528 .23597 .69107 .24384 .7033 .23954 .69756 .23164 Mtetra
.69756 .23164 .7033 .23954 .71559 .23523 .70988 .22729 Mtetra
.70988 .22729 .71559 .23523 .72793 .2309 .72226 .22293 Mtetra
.72226 .22293 .72793 .2309 .74032 .22655 .73469 .21854 Mtetra
.73469 .21854 .74032 .22655 .75277 .22219 .74718 .21414 Mtetra
.74718 .21414 .75277 .22219 .76527 .2178 .75972 .20972 Mtetra
.526 .647 .911 r
.09588 .43182 .10294 .44015 .11262 .43825 .10541 .43115 Mtetra
.588 .71 .927 r
.10541 .43115 .11262 .43825 .12225 .43719 .11516 .42915 Mtetra
.719 .242 0 r
.11516 .42915 .12225 .43719 .13307 .42657 .12319 .44149 Mtetra
.782 .897 .491 r
.12319 .44149 .13307 .42657 .14261 .42681 .13549 .41935 Mtetra
.586 .699 .921 r
.13549 .41935 .14261 .42681 .15251 .42453 .14536 .41741 Mtetra
.594 .714 .927 r
.14536 .41741 .15251 .42453 .16229 .42365 .1553 .41527 Mtetra
.952 .622 .359 r
.1553 .41527 .16229 .42365 .17316 .41318 .15987 .46177 Mtetra
0 0 0 r
.15987 .46177 .17316 .41318 .18299 .41266 .17593 .40523 Mtetra
.597 .707 .92 r
.17593 .40523 .18299 .41266 .19308 .41011 .186 .40301 Mtetra
.612 .723 .925 r
.186 .40301 .19308 .41011 .20317 .40799 .19615 .40044 Mtetra
.468 .652 .94 r
.19615 .40044 .20317 .40799 .21528 .3854 .2061 .40046 Mtetra
0 0 0 r
.2061 .40046 .21528 .3854 .22406 .39767 .21715 .38947 Mtetra
.564 .673 .912 r
.21715 .38947 .22406 .39767 .23432 .39513 .22733 .38797 Mtetra
.623 .728 .922 r
.22733 .38797 .23432 .39513 .24465 .39222 .23768 .3851 Mtetra
.622 .73 .924 r
.23768 .3851 .24465 .39222 .25499 .38978 .24807 .38224 Mtetra
.52 .678 .937 r
.24807 .38224 .25499 .38978 .27086 .31958 .25834 .38141 Mtetra
.412 .145 .397 r
.25834 .38141 .27086 .31958 .27626 .37916 .26948 .37055 Mtetra
.554 .66 .907 r
.26948 .37055 .27626 .37916 .28675 .37651 .27987 .36926 Mtetra
.63 .731 .921 r
.27987 .36926 .28675 .37651 .29732 .37329 .29046 .36618 Mtetra
.639 .739 .921 r
.29046 .36618 .29732 .37329 .30795 .36995 .3011 .36284 Mtetra
.639 .74 .922 r
.3011 .36284 .30795 .36995 .31861 .36673 .3118 .35949 Mtetra
.626 .733 .924 r
.3118 .35949 .31861 .36673 .32927 .36435 .32252 .35645 Mtetra
.404 .615 .936 r
.32252 .35645 .32927 .36435 .34072 .3492 .33304 .35747 Mtetra
.538 .827 .489 r
.33304 .35747 .34072 .3492 .35109 .35309 .34441 .34494 Mtetra
.592 .694 .913 r
.34441 .34494 .35109 .35309 .36192 .35001 .35522 .34269 Mtetra
.64 .738 .92 r
.35522 .34269 .36192 .35001 .37282 .34645 .36613 .33926 Mtetra
.649 .746 .92 r
.36613 .33926 .37282 .34645 .38377 .34272 .37711 .33556 Mtetra
.653 .749 .92 r
.37711 .33556 .38377 .34272 .39478 .3389 .38814 .33174 Mtetra
.656 .751 .92 r
.38814 .33174 .39478 .3389 .40583 .33501 .39922 .32785 Mtetra
.658 .753 .92 r
.39922 .32785 .40583 .33501 .41692 .33106 .41034 .32389 Mtetra
.659 .753 .92 r
.41034 .32389 .41692 .33106 .42807 .32709 .42152 .31989 Mtetra
.659 .754 .92 r
.42152 .31989 .42807 .32709 .43925 .32309 .43273 .31586 Mtetra
.43273 .31586 .43925 .32309 .45049 .31907 .444 .31181 Mtetra
.444 .31181 .45049 .31907 .46177 .31505 .45531 .30776 Mtetra
.659 .753 .92 r
.45531 .30776 .46177 .31505 .47309 .31102 .46666 .30369 Mtetra
.658 .753 .92 r
.46666 .30369 .47309 .31102 .48447 .30697 .47807 .29961 Mtetra
.47807 .29961 .48447 .30697 .49589 .30292 .48952 .29552 Mtetra
.48952 .29552 .49589 .30292 .50736 .29885 .50102 .29142 Mtetra
.50102 .29142 .50736 .29885 .51887 .29477 .51257 .28731 Mtetra
.51257 .28731 .51887 .29477 .53043 .29067 .52416 .28318 Mtetra
.52416 .28318 .53043 .29067 .54205 .28656 .5358 .27904 Mtetra
.657 .753 .92 r
.5358 .27904 .54205 .28656 .55371 .28244 .5475 .27488 Mtetra
.5475 .27488 .55371 .28244 .56542 .2783 .55924 .2707 Mtetra
.55924 .2707 .56542 .2783 .57717 .27414 .57103 .26651 Mtetra
.657 .752 .92 r
.57103 .26651 .57717 .27414 .58898 .26997 .58288 .26231 Mtetra
.58288 .26231 .58898 .26997 .60084 .26578 .59477 .25808 Mtetra
.59477 .25808 .60084 .26578 .61275 .26157 .60671 .25384 Mtetra
.60671 .25384 .61275 .26157 .62471 .25735 .61871 .24959 Mtetra
.61871 .24959 .62471 .25735 .63672 .25311 .63075 .24531 Mtetra
.63075 .24531 .63672 .25311 .64879 .24885 .64285 .24102 Mtetra
.64285 .24102 .64879 .24885 .6609 .24457 .655 .23671 Mtetra
.655 .23671 .6609 .24457 .67307 .24028 .6672 .23238 Mtetra
.6672 .23238 .67307 .24028 .68528 .23597 .67946 .22804 Mtetra
.67946 .22804 .68528 .23597 .69756 .23164 .69177 .22367 Mtetra
.69177 .22367 .69756 .23164 .70988 .22729 .70413 .21929 Mtetra
.70413 .21929 .70988 .22729 .72226 .22293 .71654 .21489 Mtetra
.71654 .21489 .72226 .22293 .73469 .21854 .72901 .21047 Mtetra
.72901 .21047 .73469 .21854 .74718 .21414 .74154 .20603 Mtetra
.74154 .20603 .74718 .21414 .75972 .20972 .75412 .20158 Mtetra
0 0 .175 r
.09819 .35334 .09588 .43182 .10541 .43115 .09817 .42381 Mtetra
.586 .703 .923 r
.09817 .42381 .10541 .43115 .11516 .42915 .10792 .42186 Mtetra
.539 .688 .935 r
.10792 .42186 .11516 .42915 .12319 .44149 .11762 .42073 Mtetra
.702 .559 .69 r
.11762 .42073 .12319 .44149 .13549 .41935 .12855 .41002 Mtetra
.484 .603 .895 r
.12855 .41002 .13549 .41935 .14536 .41741 .13817 .41021 Mtetra
.602 .716 .924 r
.13817 .41021 .14536 .41741 .1553 .41527 .14814 .40787 Mtetra
.527 .682 .937 r
.14814 .40787 .1553 .41527 .15987 .46177 .158 .40693 Mtetra
.605 .412 .593 r
.158 .40693 .15987 .46177 .17593 .40523 .16898 .39638 Mtetra
.521 .636 .904 r
.16898 .39638 .17593 .40523 .186 .40301 .17888 .3958 Mtetra
.613 .721 .923 r
.17888 .3958 .186 .40301 .19615 .40044 .18906 .39319 Mtetra
.592 .714 .928 r
.18906 .39319 .19615 .40044 .2061 .40046 .19923 .391 Mtetra
.87 .722 .695 r
.19923 .391 .2061 .40046 .21715 .38947 .21147 .36827 Mtetra
.071 .146 .636 r
.21147 .36827 .21715 .38947 .22733 .38797 .22031 .38054 Mtetra
.611 .717 .92 r
.22031 .38054 .22733 .38797 .23768 .3851 .23065 .37794 Mtetra
.626 .731 .923 r
.23065 .37794 .23768 .3851 .24807 .38224 .24108 .37495 Mtetra
.604 .721 .927 r
.24108 .37495 .24807 .38224 .25834 .38141 .25151 .37245 Mtetra
.934 .713 .579 r
.25151 .37245 .25834 .38141 .26948 .37055 .26759 .30193 Mtetra
0 0 .319 r
.26759 .30193 .26948 .37055 .27987 .36926 .27297 .36168 Mtetra
.613 .717 .919 r
.27297 .36168 .27987 .36926 .29046 .36618 .28355 .35896 Mtetra
.636 .737 .921 r
.28355 .35896 .29046 .36618 .3011 .36284 .29421 .35567 Mtetra
.64 .74 .921 r
.29421 .35567 .3011 .36284 .3118 .35949 .30493 .35227 Mtetra
.635 .738 .922 r
.30493 .35227 .3118 .35949 .32252 .35645 .31569 .34897 Mtetra
.598 .718 .928 r
.31569 .34897 .32252 .35645 .33304 .35747 .32644 .34653 Mtetra
.823 .708 .738 r
.32644 .34653 .33304 .35747 .34441 .34494 .33801 .33125 Mtetra
.354 .44 .811 r
.33801 .33125 .34441 .34494 .35522 .34269 .34847 .33511 Mtetra
.627 .727 .919 r
.34847 .33511 .35522 .34269 .36613 .33926 .3594 .33195 Mtetra
.646 .743 .92 r
.3594 .33195 .36613 .33926 .37711 .33556 .3704 .32832 Mtetra
.652 .748 .92 r
.3704 .32832 .37711 .33556 .38814 .33174 .38146 .32452 Mtetra
.655 .75 .92 r
.38146 .32452 .38814 .33174 .39922 .32785 .39256 .32062 Mtetra
.657 .752 .92 r
.39256 .32062 .39922 .32785 .41034 .32389 .40371 .31665 Mtetra
.658 .753 .92 r
.40371 .31665 .41034 .32389 .42152 .31989 .41491 .31263 Mtetra
.659 .754 .92 r
.41491 .31263 .42152 .31989 .43273 .31586 .42616 .30858 Mtetra
.42616 .30858 .43273 .31586 .444 .31181 .43746 .3045 Mtetra
.43746 .3045 .444 .31181 .45531 .30776 .4488 .30041 Mtetra
.4488 .30041 .45531 .30776 .46666 .30369 .46018 .29631 Mtetra
.658 .753 .92 r
.46018 .29631 .46666 .30369 .47807 .29961 .47162 .29219 Mtetra
.47162 .29219 .47807 .29961 .48952 .29552 .4831 .28807 Mtetra
.4831 .28807 .48952 .29552 .50102 .29142 .49463 .28394 Mtetra
.49463 .28394 .50102 .29142 .51257 .28731 .50621 .27979 Mtetra
.50621 .27979 .51257 .28731 .52416 .28318 .51784 .27563 Mtetra
.51784 .27563 .52416 .28318 .5358 .27904 .52951 .27145 Mtetra
.52951 .27145 .5358 .27904 .5475 .27488 .54124 .26726 Mtetra
.657 .753 .92 r
.54124 .26726 .5475 .27488 .55924 .2707 .55302 .26305 Mtetra
.55302 .26305 .55924 .2707 .57103 .26651 .56484 .25883 Mtetra
.56484 .25883 .57103 .26651 .58288 .26231 .57672 .25459 Mtetra
.657 .752 .92 r
.57672 .25459 .58288 .26231 .59477 .25808 .58865 .25033 Mtetra
.58865 .25033 .59477 .25808 .60671 .25384 .60062 .24606 Mtetra
.60062 .24606 .60671 .25384 .61871 .24959 .61265 .24176 Mtetra
.61265 .24176 .61871 .24959 .63075 .24531 .62473 .23746 Mtetra
.62473 .23746 .63075 .24531 .64285 .24102 .63687 .23313 Mtetra
.63687 .23313 .64285 .24102 .655 .23671 .64905 .22878 Mtetra
.64905 .22878 .655 .23671 .6672 .23238 .66129 .22442 Mtetra
.66129 .22442 .6672 .23238 .67946 .22804 .67358 .22004 Mtetra
.67358 .22004 .67946 .22804 .69177 .22367 .68593 .21564 Mtetra
.68593 .21564 .69177 .22367 .70413 .21929 .69833 .21123 Mtetra
.69833 .21123 .70413 .21929 .71654 .21489 .71078 .20679 Mtetra
.71078 .20679 .71654 .21489 .72901 .21047 .72329 .20233 Mtetra
.72329 .20233 .72901 .21047 .74154 .20603 .73585 .19786 Mtetra
.73585 .19786 .74154 .20603 .75412 .20158 .74847 .19337 Mtetra
.422 .157 .405 r
.08016 .42565 .09819 .35334 .09817 .42381 .09102 .41535 Mtetra
.526 .647 .911 r
.09102 .41535 .09817 .42381 .10792 .42186 .10062 .41463 Mtetra
.588 .71 .927 r
.10062 .41463 .10792 .42186 .11762 .42073 .11045 .41258 Mtetra
.713 .236 0 r
.11045 .41258 .11762 .42073 .12855 .41002 .11853 .42491 Mtetra
.789 .902 .499 r
.11853 .42491 .12855 .41002 .13817 .41021 .13096 .40263 Mtetra
.586 .699 .921 r
.13096 .40263 .13817 .41021 .14814 .40787 .14091 .40063 Mtetra
.594 .714 .927 r
.14091 .40063 .14814 .40787 .158 .40693 .15093 .39843 Mtetra
.952 .621 .355 r
.15093 .39843 .158 .40693 .16898 .39638 .15547 .44507 Mtetra
0 0 0 r
.15547 .44507 .16898 .39638 .17888 .3958 .17175 .38824 Mtetra
.597 .707 .921 r
.17175 .38824 .17888 .3958 .18906 .39319 .1819 .38596 Mtetra
.612 .723 .925 r
.1819 .38596 .18906 .39319 .19923 .391 .19214 .38332 Mtetra
.468 .652 .94 r
.19214 .38332 .19923 .391 .21147 .36827 .20216 .38329 Mtetra
0 0 0 r
.20216 .38329 .21147 .36827 .22031 .38054 .21333 .3722 Mtetra
.564 .673 .912 r
.21333 .3722 .22031 .38054 .23065 .37794 .22358 .37065 Mtetra
.623 .728 .922 r
.22358 .37065 .23065 .37794 .24108 .37495 .23402 .3677 Mtetra
.622 .73 .924 r
.23402 .3677 .24108 .37495 .25151 .37245 .24451 .36478 Mtetra
.52 .678 .937 r
.24451 .36478 .25151 .37245 .26759 .30193 .25487 .36389 Mtetra
.406 .137 .39 r
.25487 .36389 .26759 .30193 .27297 .36168 .26611 .35293 Mtetra
.554 .66 .907 r
.26611 .35293 .27297 .36168 .28355 .35896 .27659 .35158 Mtetra
.63 .731 .921 r
.27659 .35158 .28355 .35896 .29421 .35567 .28727 .34843 Mtetra
.639 .739 .921 r
.28727 .34843 .29421 .35567 .30493 .35227 .29802 .34502 Mtetra
.639 .74 .922 r
.29802 .34502 .30493 .35227 .31569 .34897 .30881 .3416 Mtetra
.626 .733 .924 r
.30881 .3416 .31569 .34897 .32644 .34653 .31962 .33849 Mtetra
.405 .615 .936 r
.31962 .33849 .32644 .34653 .33801 .33125 .33024 .33945 Mtetra
.551 .837 .502 r
.33024 .33945 .33801 .33125 .34847 .33511 .34172 .32682 Mtetra
.592 .694 .913 r
.34172 .32682 .34847 .33511 .3594 .33195 .35262 .3245 Mtetra
.64 .738 .92 r
.35262 .3245 .3594 .33195 .3704 .32832 .36364 .32099 Mtetra
.649 .746 .92 r
.36364 .32099 .3704 .32832 .38146 .32452 .37472 .31722 Mtetra
.653 .749 .92 r
.37472 .31722 .38146 .32452 .39256 .32062 .38585 .31333 Mtetra
.656 .751 .92 r
.38585 .31333 .39256 .32062 .40371 .31665 .39703 .30935 Mtetra
.658 .753 .92 r
.39703 .30935 .40371 .31665 .41491 .31263 .40826 .30532 Mtetra
.659 .753 .92 r
.40826 .30532 .41491 .31263 .42616 .30858 .41954 .30124 Mtetra
.659 .754 .92 r
.41954 .30124 .42616 .30858 .43746 .3045 .43086 .29713 Mtetra
.43086 .29713 .43746 .3045 .4488 .30041 .44224 .29301 Mtetra
.44224 .29301 .4488 .30041 .46018 .29631 .45365 .28887 Mtetra
.659 .753 .92 r
.45365 .28887 .46018 .29631 .47162 .29219 .46512 .28472 Mtetra
.658 .753 .92 r
.46512 .28472 .47162 .29219 .4831 .28807 .47663 .28056 Mtetra
.47663 .28056 .4831 .28807 .49463 .28394 .4882 .2764 Mtetra
.4882 .2764 .49463 .28394 .50621 .27979 .49981 .27221 Mtetra
.49981 .27221 .50621 .27979 .51784 .27563 .51147 .26802 Mtetra
.51147 .26802 .51784 .27563 .52951 .27145 .52318 .26381 Mtetra
.52318 .26381 .52951 .27145 .54124 .26726 .53493 .25958 Mtetra
.657 .753 .92 r
.53493 .25958 .54124 .26726 .55302 .26305 .54674 .25534 Mtetra
.54674 .25534 .55302 .26305 .56484 .25883 .5586 .25108 Mtetra
.5586 .25108 .56484 .25883 .57672 .25459 .57051 .24681 Mtetra
.657 .752 .92 r
.57051 .24681 .57672 .25459 .58865 .25033 .58247 .24252 Mtetra
.58247 .24252 .58865 .25033 .60062 .24606 .59449 .23821 Mtetra
.59449 .23821 .60062 .24606 .61265 .24176 .60655 .23388 Mtetra
.60655 .23388 .61265 .24176 .62473 .23746 .61867 .22954 Mtetra
.61867 .22954 .62473 .23746 .63687 .23313 .63084 .22518 Mtetra
.63084 .22518 .63687 .23313 .64905 .22878 .64306 .2208 Mtetra
.64306 .2208 .64905 .22878 .66129 .22442 .65533 .2164 Mtetra
.65533 .2164 .66129 .22442 .67358 .22004 .66766 .21198 Mtetra
.66766 .21198 .67358 .22004 .68593 .21564 .68004 .20755 Mtetra
.68004 .20755 .68593 .21564 .69833 .21123 .69248 .20309 Mtetra
.69248 .20309 .69833 .21123 .71078 .20679 .70497 .19862 Mtetra
.70497 .19862 .71078 .20679 .72329 .20233 .71752 .19413 Mtetra
.71752 .19413 .72329 .20233 .73585 .19786 .73012 .18962 Mtetra
.73012 .18962 .73585 .19786 .74847 .19337 .74278 .18509 Mtetra
.919 .701 .591 r
.07297 .4169 .08016 .42565 .09102 .41535 .09344 .33647 Mtetra
0 0 .168 r
.09344 .33647 .09102 .41535 .10062 .41463 .0933 .40716 Mtetra
.586 .703 .923 r
.0933 .40716 .10062 .41463 .11045 .41258 .10314 .40515 Mtetra
.539 .688 .935 r
.10314 .40515 .11045 .41258 .11853 .42491 .11291 .40397 Mtetra
.702 .559 .69 r
.11291 .40397 .11853 .42491 .13096 .40263 .12394 .39317 Mtetra
.483 .603 .896 r
.12394 .39317 .13096 .40263 .14091 .40063 .13364 .39331 Mtetra
.602 .716 .924 r
.13364 .39331 .14091 .40063 .15093 .39843 .14369 .3909 Mtetra
.527 .682 .936 r
.14369 .3909 .15093 .39843 .15547 .44507 .15363 .38991 Mtetra
.604 .41 .592 r
.15363 .38991 .15547 .44507 .17175 .38824 .16472 .37925 Mtetra
.521 .636 .904 r
.16472 .37925 .17175 .38824 .1819 .38596 .1747 .37862 Mtetra
.613 .721 .923 r
.1747 .37862 .1819 .38596 .19214 .38332 .18496 .37594 Mtetra
.592 .714 .928 r
.18496 .37594 .19214 .38332 .20216 .38329 .19522 .3737 Mtetra
.871 .722 .695 r
.19522 .3737 .20216 .38329 .21333 .3722 .20759 .35082 Mtetra
.067 .142 .634 r
.20759 .35082 .21333 .3722 .22358 .37065 .21649 .36308 Mtetra
.611 .717 .92 r
.21649 .36308 .22358 .37065 .23402 .3677 .22692 .36041 Mtetra
.626 .731 .923 r
.22692 .36041 .23402 .3677 .24451 .36478 .23744 .35736 Mtetra
.604 .721 .927 r
.23744 .35736 .24451 .36478 .25487 .36389 .24796 .35479 Mtetra
.935 .713 .577 r
.24796 .35479 .25487 .36389 .26611 .35293 .26425 .28394 Mtetra
0 0 .313 r
.26425 .28394 .26611 .35293 .27659 .35158 .26961 .34386 Mtetra
.613 .717 .919 r
.26961 .34386 .27659 .35158 .28727 .34843 .28028 .34108 Mtetra
.636 .737 .921 r
.28028 .34108 .28727 .34843 .29802 .34502 .29105 .33771 Mtetra
.64 .74 .921 r
.29105 .33771 .29802 .34502 .30881 .3416 .30186 .33424 Mtetra
.635 .738 .922 r
.30186 .33424 .30881 .3416 .31962 .33849 .31272 .33087 Mtetra
.598 .718 .928 r
.31272 .33087 .31962 .33849 .33024 .33945 .32357 .32836 Mtetra
.824 .709 .738 r
.32357 .32836 .33024 .33945 .34172 .32682 .33525 .31296 Mtetra
.352 .44 .811 r
.33525 .31296 .34172 .32682 .35262 .3245 .3458 .31677 Mtetra
.627 .727 .919 r
.3458 .31677 .35262 .3245 .36364 .32099 .35683 .31355 Mtetra
.646 .743 .92 r
.35683 .31355 .36364 .32099 .37472 .31722 .36793 .30984 Mtetra
.652 .748 .92 r
.36793 .30984 .37472 .31722 .38585 .31333 .37909 .30596 Mtetra
.655 .75 .92 r
.37909 .30596 .38585 .31333 .39703 .30935 .3903 .30198 Mtetra
.657 .752 .92 r
.3903 .30198 .39703 .30935 .40826 .30532 .40156 .29793 Mtetra
.658 .753 .92 r
.40156 .29793 .40826 .30532 .41954 .30124 .41287 .29384 Mtetra
.659 .754 .92 r
.41287 .29384 .41954 .30124 .43086 .29713 .42422 .2897 Mtetra
.42422 .2897 .43086 .29713 .44224 .29301 .43562 .28555 Mtetra
.43562 .28555 .44224 .29301 .45365 .28887 .44707 .28137 Mtetra
.44707 .28137 .45365 .28887 .46512 .28472 .45857 .27719 Mtetra
.658 .753 .92 r
.45857 .27719 .46512 .28472 .47663 .28056 .47011 .273 Mtetra
.47011 .273 .47663 .28056 .4882 .2764 .48171 .26879 Mtetra
.48171 .26879 .4882 .2764 .49981 .27221 .49335 .26458 Mtetra
.49335 .26458 .49981 .27221 .51147 .26802 .50504 .26035 Mtetra
.50504 .26035 .51147 .26802 .52318 .26381 .51679 .2561 Mtetra
.51679 .2561 .52318 .26381 .53493 .25958 .52858 .25184 Mtetra
.52858 .25184 .53493 .25958 .54674 .25534 .54042 .24757 Mtetra
.657 .753 .92 r
.54042 .24757 .54674 .25534 .5586 .25108 .55231 .24327 Mtetra
.55231 .24327 .5586 .25108 .57051 .24681 .56426 .23896 Mtetra
.56426 .23896 .57051 .24681 .58247 .24252 .57625 .23464 Mtetra
.657 .752 .92 r
.57625 .23464 .58247 .24252 .59449 .23821 .5883 .23029 Mtetra
.5883 .23029 .59449 .23821 .60655 .23388 .6004 .22593 Mtetra
.6004 .22593 .60655 .23388 .61867 .22954 .61255 .22155 Mtetra
.61255 .22155 .61867 .22954 .63084 .22518 .62476 .21716 Mtetra
.62476 .21716 .63084 .22518 .64306 .2208 .63701 .21274 Mtetra
.63701 .21274 .64306 .2208 .65533 .2164 .64933 .20831 Mtetra
.64933 .20831 .65533 .2164 .66766 .21198 .66169 .20386 Mtetra
.66169 .20386 .66766 .21198 .68004 .20755 .67411 .19939 Mtetra
.67411 .19939 .68004 .20755 .69248 .20309 .68658 .1949 Mtetra
.68658 .1949 .69248 .20309 .70497 .19862 .69911 .19039 Mtetra
.69911 .19039 .70497 .19862 .71752 .19413 .7117 .18586 Mtetra
.7117 .18586 .71752 .19413 .73012 .18962 .72434 .18131 Mtetra
.72434 .18131 .73012 .18962 .74278 .18509 .73704 .17674 Mtetra
.488 .663 .939 r
.06557 .40935 .07297 .4169 .09344 .33647 .07511 .40897 Mtetra
.416 .149 .399 r
.07511 .40897 .09344 .33647 .0933 .40716 .08607 .39858 Mtetra
.526 .647 .911 r
.08607 .39858 .0933 .40716 .10314 .40515 .09575 .3978 Mtetra
.588 .71 .927 r
.09575 .3978 .10314 .40515 .11291 .40397 .10566 .39569 Mtetra
.707 .23 0 r
.10566 .39569 .11291 .40397 .12394 .39317 .11378 .40802 Mtetra
.796 .906 .506 r
.11378 .40802 .12394 .39317 .13364 .39331 .12635 .3856 Mtetra
.586 .699 .921 r
.12635 .3856 .13364 .39331 .14369 .3909 .13638 .38354 Mtetra
.594 .714 .927 r
.13638 .38354 .14369 .3909 .15363 .38991 .14648 .38127 Mtetra
.953 .62 .35 r
.14648 .38127 .15363 .38991 .16472 .37925 .15099 .42805 Mtetra
0 0 0 r
.15099 .42805 .16472 .37925 .1747 .37862 .16748 .37093 Mtetra
.597 .707 .921 r
.16748 .37093 .1747 .37862 .18496 .37594 .17772 .36859 Mtetra
.612 .723 .925 r
.17772 .36859 .18496 .37594 .19522 .3737 .18805 .36589 Mtetra
.469 .652 .939 r
.18805 .36589 .19522 .3737 .20759 .35082 .19815 .36579 Mtetra
0 0 0 r
.19815 .36579 .20759 .35082 .21649 .36308 .20942 .35461 Mtetra
.564 .673 .912 r
.20942 .35461 .21649 .36308 .22692 .36041 .21977 .35299 Mtetra
.623 .728 .922 r
.21977 .35299 .22692 .36041 .23744 .35736 .2303 .34998 Mtetra
.622 .73 .924 r
.2303 .34998 .23744 .35736 .24796 .35479 .24088 .34699 Mtetra
.521 .678 .937 r
.24088 .34699 .24796 .35479 .26425 .28394 .25133 .34603 Mtetra
.399 .129 .384 r
.25133 .34603 .26425 .28394 .26961 .34386 .26268 .33497 Mtetra
.553 .66 .907 r
.26268 .33497 .26961 .34386 .28028 .34108 .27325 .33356 Mtetra
.63 .731 .921 r
.27325 .33356 .28028 .34108 .29105 .33771 .28403 .33033 Mtetra
.639 .739 .921 r
.28403 .33033 .29105 .33771 .30186 .33424 .29487 .32685 Mtetra
.639 .74 .922 r
.29487 .32685 .30186 .33424 .31272 .33087 .30576 .32336 Mtetra
.626 .733 .924 r
.30576 .32336 .31272 .33087 .32357 .32836 .31667 .32017 Mtetra
.406 .615 .936 r
.31667 .32017 .32357 .32836 .33525 .31296 .32738 .32108 Mtetra
.563 .847 .515 r
.32738 .32108 .33525 .31296 .3458 .31677 .33897 .30833 Mtetra
.592 .695 .914 r
.33897 .30833 .3458 .31677 .35683 .31355 .34998 .30595 Mtetra
.64 .738 .92 r
.34998 .30595 .35683 .31355 .36793 .30984 .3611 .30236 Mtetra
.649 .746 .92 r
.3611 .30236 .36793 .30984 .37909 .30596 .37228 .29851 Mtetra
.653 .749 .92 r
.37228 .29851 .37909 .30596 .3903 .30198 .38352 .29454 Mtetra
.656 .751 .92 r
.38352 .29454 .3903 .30198 .40156 .29793 .3948 .29049 Mtetra
.658 .753 .92 r
.3948 .29049 .40156 .29793 .41287 .29384 .40614 .28637 Mtetra
.659 .753 .92 r
.40614 .28637 .41287 .29384 .42422 .2897 .41752 .28222 Mtetra
.659 .754 .92 r
.41752 .28222 .42422 .2897 .43562 .28555 .42896 .27803 Mtetra
.42896 .27803 .43562 .28555 .44707 .28137 .44044 .27382 Mtetra
.44044 .27382 .44707 .28137 .45857 .27719 .45197 .2696 Mtetra
.659 .753 .92 r
.45197 .2696 .45857 .27719 .47011 .273 .46354 .26538 Mtetra
.658 .753 .92 r
.46354 .26538 .47011 .273 .48171 .26879 .47517 .26114 Mtetra
.47517 .26114 .48171 .26879 .49335 .26458 .48684 .25688 Mtetra
.48684 .25688 .49335 .26458 .50504 .26035 .49857 .25262 Mtetra
.49857 .25262 .50504 .26035 .51679 .2561 .51034 .24834 Mtetra
.51034 .24834 .51679 .2561 .52858 .25184 .52217 .24404 Mtetra
.52217 .24404 .52858 .25184 .54042 .24757 .53405 .23973 Mtetra
.657 .753 .92 r
.53405 .23973 .54042 .24757 .55231 .24327 .54597 .2354 Mtetra
.54597 .2354 .55231 .24327 .56426 .23896 .55795 .23106 Mtetra
.55795 .23106 .56426 .23896 .57625 .23464 .56998 .2267 Mtetra
.657 .752 .92 r
.56998 .2267 .57625 .23464 .5883 .23029 .58206 .22232 Mtetra
.58206 .22232 .5883 .23029 .6004 .22593 .5942 .21792 Mtetra
.5942 .21792 .6004 .22593 .61255 .22155 .60639 .21351 Mtetra
.60639 .21351 .61255 .22155 .62476 .21716 .61863 .20907 Mtetra
.61863 .20907 .62476 .21716 .63701 .21274 .63092 .20462 Mtetra
.63092 .20462 .63701 .21274 .64933 .20831 .64327 .20015 Mtetra
.64327 .20015 .64933 .20831 .66169 .20386 .65567 .19566 Mtetra
.65567 .19566 .66169 .20386 .67411 .19939 .66813 .19116 Mtetra
.66813 .19116 .67411 .19939 .68658 .1949 .68064 .18663 Mtetra
.68064 .18663 .68658 .1949 .69911 .19039 .69321 .18208 Mtetra
.69321 .18208 .69911 .19039 .7117 .18586 .70583 .17752 Mtetra
.70583 .17752 .7117 .18586 .72434 .18131 .71851 .17293 Mtetra
.71851 .17293 .72434 .18131 .73704 .17674 .73125 .16833 Mtetra
.575 .703 .929 r
.05809 .40194 .06557 .40935 .07511 .40897 .06784 .40009 Mtetra
.921 .702 .59 r
.06784 .40009 .07511 .40897 .08607 .39858 .08861 .3193 Mtetra
0 0 .161 r
.08861 .3193 .08607 .39858 .09575 .3978 .08834 .39021 Mtetra
.586 .703 .923 r
.08834 .39021 .09575 .3978 .10566 .39569 .09826 .38814 Mtetra
.539 .688 .935 r
.09826 .38814 .10566 .39569 .11378 .40802 .10811 .3869 Mtetra
.702 .559 .69 r
.10811 .3869 .11378 .40802 .12635 .3856 .11925 .37599 Mtetra
.483 .603 .896 r
.11925 .37599 .12635 .3856 .13638 .38354 .12902 .37608 Mtetra
.602 .716 .924 r
.12902 .37608 .13638 .38354 .14648 .38127 .13916 .37361 Mtetra
.527 .682 .936 r
.13916 .37361 .14648 .38127 .15099 .42805 .14918 .37256 Mtetra
.602 .407 .59 r
.14918 .37256 .15099 .42805 .16748 .37093 .16037 .36181 Mtetra
.52 .636 .904 r
.16037 .36181 .16748 .37093 .17772 .36859 .17044 .36112 Mtetra
.613 .721 .923 r
.17044 .36112 .17772 .36859 .18805 .36589 .18078 .35837 Mtetra
.592 .714 .928 r
.18078 .35837 .18805 .36589 .19815 .36579 .19113 .35606 Mtetra
.872 .723 .695 r
.19113 .35606 .19815 .36579 .20942 .35461 .20364 .33304 Mtetra
.062 .139 .633 r
.20364 .33304 .20942 .35461 .21977 .35299 .21259 .34528 Mtetra
.61 .717 .92 r
.21259 .34528 .21977 .35299 .2303 .34998 .22311 .34255 Mtetra
.626 .731 .923 r
.22311 .34255 .2303 .34998 .24088 .34699 .23372 .33943 Mtetra
.604 .721 .927 r
.23372 .33943 .24088 .34699 .25133 .34603 .24434 .33679 Mtetra
.937 .714 .576 r
.24434 .33679 .25133 .34603 .26268 .33497 .26086 .26562 Mtetra
0 0 .307 r
.26086 .26562 .26268 .33497 .27325 .33356 .26619 .3257 Mtetra
.613 .717 .919 r
.26619 .3257 .27325 .33356 .28403 .33033 .27696 .32284 Mtetra
.636 .737 .921 r
.27696 .32284 .28403 .33033 .29487 .32685 .28782 .3194 Mtetra
.64 .74 .921 r
.28782 .3194 .29487 .32685 .30576 .32336 .29873 .31586 Mtetra
.635 .738 .922 r
.29873 .31586 .30576 .32336 .31667 .32017 .30969 .31241 Mtetra
.598 .718 .928 r
.30969 .31241 .31667 .32017 .32738 .32108 .32064 .30983 Mtetra
.825 .71 .738 r
.32064 .30983 .32738 .32108 .33897 .30833 .33244 .29432 Mtetra
.351 .439 .811 r
.33244 .29432 .33897 .30833 .34998 .30595 .34308 .29808 Mtetra
.627 .727 .919 r
.34308 .29808 .34998 .30595 .3611 .30236 .35421 .29477 Mtetra
.646 .743 .92 r
.35421 .29477 .3611 .30236 .37228 .29851 .36542 .29099 Mtetra
.652 .748 .92 r
.36542 .29099 .37228 .29851 .38352 .29454 .37668 .28703 Mtetra
.655 .75 .92 r
.37668 .28703 .38352 .29454 .3948 .29049 .388 .28297 Mtetra
.657 .752 .92 r
.388 .28297 .3948 .29049 .40614 .28637 .39936 .27885 Mtetra
.658 .753 .92 r
.39936 .27885 .40614 .28637 .41752 .28222 .41078 .27467 Mtetra
.659 .754 .92 r
.41078 .27467 .41752 .28222 .42896 .27803 .42224 .27045 Mtetra
.42224 .27045 .42896 .27803 .44044 .27382 .43375 .26621 Mtetra
.43375 .26621 .44044 .27382 .45197 .2696 .44531 .26196 Mtetra
.44531 .26196 .45197 .2696 .46354 .26538 .45692 .25769 Mtetra
.658 .753 .92 r
.45692 .25769 .46354 .26538 .47517 .26114 .46858 .25342 Mtetra
.46858 .25342 .47517 .26114 .48684 .25688 .48029 .24913 Mtetra
.48029 .24913 .48684 .25688 .49857 .25262 .49204 .24483 Mtetra
.49204 .24483 .49857 .25262 .51034 .24834 .50385 .24051 Mtetra
.50385 .24051 .51034 .24834 .52217 .24404 .51571 .23618 Mtetra
.51571 .23618 .52217 .24404 .53405 .23973 .52762 .23183 Mtetra
.52762 .23183 .53405 .23973 .54597 .2354 .53958 .22747 Mtetra
.657 .753 .92 r
.53958 .22747 .54597 .2354 .55795 .23106 .55159 .22309 Mtetra
.55159 .22309 .55795 .23106 .56998 .2267 .56366 .21869 Mtetra
.56366 .21869 .56998 .2267 .58206 .22232 .57578 .21428 Mtetra
.657 .752 .92 r
.57578 .21428 .58206 .22232 .5942 .21792 .58795 .20985 Mtetra
.58795 .20985 .5942 .21792 .60639 .21351 .60017 .2054 Mtetra
.60017 .2054 .60639 .21351 .61863 .20907 .61245 .20093 Mtetra
.61245 .20093 .61863 .20907 .63092 .20462 .62478 .19644 Mtetra
.62478 .19644 .63092 .20462 .64327 .20015 .63716 .19193 Mtetra
.63716 .19193 .64327 .20015 .65567 .19566 .6496 .18741 Mtetra
.6496 .18741 .65567 .19566 .66813 .19116 .6621 .18286 Mtetra
.6621 .18286 .66813 .19116 .68064 .18663 .67465 .1783 Mtetra
.67465 .1783 .68064 .18663 .69321 .18208 .68725 .17371 Mtetra
.68725 .17371 .69321 .18208 .70583 .17752 .69992 .16911 Mtetra
.69992 .16911 .70583 .17752 .71851 .17293 .71264 .16449 Mtetra
.71264 .16449 .71851 .17293 .73125 .16833 .72541 .15984 Mtetra
.574 .695 .924 r
.05059 .39424 .05809 .40194 .06784 .40009 .06035 .39242 Mtetra
.489 .663 .939 r
.06035 .39242 .06784 .40009 .08861 .3193 .06997 .39198 Mtetra
.41 .141 .392 r
.06997 .39198 .08861 .3193 .08834 .39021 .08103 .38149 Mtetra
.525 .647 .911 r
.08103 .38149 .08834 .39021 .09826 .38814 .09079 .38066 Mtetra
.588 .71 .927 r
.09079 .38066 .09826 .38814 .10811 .3869 .10078 .37848 Mtetra
.701 .224 0 r
.10078 .37848 .10811 .3869 .11925 .37599 .10894 .3908 Mtetra
.802 .91 .514 r
.10894 .3908 .11925 .37599 .12902 .37608 .12165 .36824 Mtetra
.586 .699 .921 r
.12165 .36824 .12902 .37608 .13916 .37361 .13176 .36611 Mtetra
.594 .714 .927 r
.13176 .36611 .13916 .37361 .14918 .37256 .14195 .36378 Mtetra
.953 .619 .346 r
.14195 .36378 .14918 .37256 .16037 .36181 .14642 .4107 Mtetra
0 0 0 r
.14642 .4107 .16037 .36181 .17044 .36112 .16313 .35329 Mtetra
.597 .707 .921 r
.16313 .35329 .17044 .36112 .18078 .35837 .17346 .35088 Mtetra
.612 .723 .925 r
.17346 .35088 .18078 .35837 .19113 .35606 .18388 .34811 Mtetra
.469 .652 .939 r
.18388 .34811 .19113 .35606 .20364 .33304 .19406 .34796 Mtetra
0 0 0 r
.19406 .34796 .20364 .33304 .21259 .34528 .20545 .33667 Mtetra
.563 .674 .913 r
.20545 .33667 .21259 .34528 .22311 .34255 .21588 .33499 Mtetra
.623 .728 .922 r
.21588 .33499 .22311 .34255 .23372 .33943 .22651 .33191 Mtetra
.622 .729 .924 r
.22651 .33191 .23372 .33943 .24434 .33679 .23718 .32884 Mtetra
.521 .678 .936 r
.23718 .32884 .24434 .33679 .26086 .26562 .24772 .32783 Mtetra
.393 .121 .377 r
.24772 .32783 .26086 .26562 .26619 .3257 .25918 .31666 Mtetra
.553 .66 .907 r
.25918 .31666 .26619 .3257 .27696 .32284 .26985 .31519 Mtetra
.63 .731 .921 r
.26985 .31519 .27696 .32284 .28782 .3194 .28072 .31188 Mtetra
.639 .739 .921 r
.28072 .31188 .28782 .3194 .29873 .31586 .29166 .30832 Mtetra
.639 .74 .922 r
.29166 .30832 .29873 .31586 .30969 .31241 .30265 .30476 Mtetra
.626 .733 .924 r
.30265 .30476 .30969 .31241 .32064 .30983 .31366 .3015 Mtetra
.407 .615 .936 r
.31366 .3015 .32064 .30983 .33244 .29432 .32446 .30234 Mtetra
.576 .857 .527 r
.32446 .30234 .33244 .29432 .34308 .29808 .33618 .28949 Mtetra
.592 .695 .914 r
.33618 .28949 .34308 .29808 .35421 .29477 .34728 .28703 Mtetra
.64 .738 .92 r
.34728 .28703 .35421 .29477 .36542 .29099 .3585 .28336 Mtetra
.649 .746 .92 r
.3585 .28336 .36542 .29099 .37668 .28703 .36979 .27944 Mtetra
.653 .749 .92 r
.36979 .27944 .37668 .28703 .388 .28297 .38114 .27539 Mtetra
.656 .751 .92 r
.38114 .27539 .388 .28297 .39936 .27885 .39253 .27125 Mtetra
.658 .753 .92 r
.39253 .27125 .39936 .27885 .41078 .27467 .40398 .26705 Mtetra
.659 .753 .92 r
.40398 .26705 .41078 .27467 .42224 .27045 .41547 .26281 Mtetra
.659 .754 .92 r
.41547 .26281 .42224 .27045 .43375 .26621 .42701 .25854 Mtetra
.42701 .25854 .43375 .26621 .44531 .26196 .4386 .25425 Mtetra
.4386 .25425 .44531 .26196 .45692 .25769 .45025 .24995 Mtetra
.659 .753 .92 r
.45025 .24995 .45692 .25769 .46858 .25342 .46194 .24564 Mtetra
.658 .753 .92 r
.46194 .24564 .46858 .25342 .48029 .24913 .47368 .24131 Mtetra
.47368 .24131 .48029 .24913 .49204 .24483 .48547 .23697 Mtetra
.48547 .23697 .49204 .24483 .50385 .24051 .49731 .23262 Mtetra
.49731 .23262 .50385 .24051 .51571 .23618 .5092 .22826 Mtetra
.5092 .22826 .51571 .23618 .52762 .23183 .52114 .22387 Mtetra
.52114 .22387 .52762 .23183 .53958 .22747 .53314 .21947 Mtetra
.657 .753 .92 r
.53314 .21947 .53958 .22747 .55159 .22309 .54519 .21506 Mtetra
.54519 .21506 .55159 .22309 .56366 .21869 .55729 .21063 Mtetra
.55729 .21063 .56366 .21869 .57578 .21428 .56944 .20617 Mtetra
.657 .752 .92 r
.56944 .20617 .57578 .21428 .58795 .20985 .58165 .20171 Mtetra
.58165 .20171 .58795 .20985 .60017 .2054 .5939 .19722 Mtetra
.5939 .19722 .60017 .2054 .61245 .20093 .60622 .19271 Mtetra
.60622 .19271 .61245 .20093 .62478 .19644 .61859 .18819 Mtetra
.61859 .18819 .62478 .19644 .63716 .19193 .63101 .18364 Mtetra
.63101 .18364 .63716 .19193 .6496 .18741 .64349 .17908 Mtetra
.64349 .17908 .6496 .18741 .6621 .18286 .65602 .1745 Mtetra
.65602 .1745 .6621 .18286 .67465 .1783 .66861 .1699 Mtetra
.66861 .1699 .67465 .1783 .68725 .17371 .68125 .16527 Mtetra
.68125 .16527 .68725 .17371 .69992 .16911 .69395 .16063 Mtetra
.69395 .16063 .69992 .16911 .71264 .16449 .70671 .15597 Mtetra
.70671 .15597 .71264 .16449 .72541 .15984 .71953 .15129 Mtetra
.485 .613 .903 r
.04327 .38494 .05059 .39424 .06035 .39242 .05278 .38487 Mtetra
.575 .703 .929 r
.05278 .38487 .06035 .39242 .06997 .39198 .06262 .38296 Mtetra
.922 .702 .589 r
.06262 .38296 .06997 .39198 .08103 .38149 .08369 .3018 Mtetra
0 0 .153 r
.08369 .3018 .08103 .38149 .09079 .38066 .08329 .37293 Mtetra
.586 .703 .923 r
.08329 .37293 .09079 .38066 .10078 .37848 .09329 .3708 Mtetra
.539 .688 .935 r
.09329 .3708 .10078 .37848 .10894 .3908 .10323 .3695 Mtetra
.701 .558 .689 r
.10323 .3695 .10894 .3908 .12165 .36824 .11447 .35849 Mtetra
.482 .603 .896 r
.11447 .35849 .12165 .36824 .13176 .36611 .12431 .35853 Mtetra
.602 .716 .924 r
.12431 .35853 .13176 .36611 .14195 .36378 .13454 .35599 Mtetra
.527 .682 .936 r
.13454 .35599 .14195 .36378 .14642 .4107 .14465 .35488 Mtetra
.601 .405 .588 r
.14465 .35488 .14642 .4107 .16313 .35329 .15594 .34403 Mtetra
.52 .636 .904 r
.15594 .34403 .16313 .35329 .17346 .35088 .16609 .34327 Mtetra
.613 .721 .923 r
.16609 .34327 .17346 .35088 .18388 .34811 .17653 .34046 Mtetra
.592 .714 .928 r
.17653 .34046 .18388 .34811 .19406 .34796 .18697 .33808 Mtetra
.873 .724 .695 r
.18697 .33808 .19406 .34796 .20545 .33667 .19961 .31491 Mtetra
.057 .136 .631 r
.19961 .31491 .20545 .33667 .21588 .33499 .20862 .32715 Mtetra
.61 .717 .92 r
.20862 .32715 .21588 .33499 .22651 .33191 .21924 .32434 Mtetra
.626 .731 .923 r
.21924 .32434 .22651 .33191 .23718 .32884 .22994 .32115 Mtetra
.604 .721 .927 r
.22994 .32115 .23718 .32884 .24772 .32783 .24065 .31844 Mtetra
.938 .715 .574 r
.24065 .31844 .24772 .32783 .25918 .31666 .2574 .24694 Mtetra
0 0 .302 r
.2574 .24694 .25918 .31666 .26985 .31519 .26271 .30718 Mtetra
.613 .717 .919 r
.26271 .30718 .26985 .31519 .28072 .31188 .27357 .30425 Mtetra
.636 .737 .921 r
.27357 .30425 .28072 .31188 .29166 .30832 .28453 .30074 Mtetra
.64 .74 .921 r
.28453 .30074 .29166 .30832 .30265 .30476 .29554 .29711 Mtetra
.635 .738 .922 r
.29554 .29711 .30265 .30476 .31366 .3015 .3066 .29359 Mtetra
.598 .718 .928 r
.3066 .29359 .31366 .3015 .32446 .30234 .31765 .29094 Mtetra
.826 .711 .738 r
.31765 .29094 .32446 .30234 .33618 .28949 .32957 .2753 Mtetra
.35 .438 .811 r
.32957 .2753 .33618 .28949 .34728 .28703 .34031 .27901 Mtetra
.627 .727 .919 r
.34031 .27901 .34728 .28703 .3585 .28336 .35154 .27563 Mtetra
.646 .743 .92 r
.35154 .27563 .3585 .28336 .36979 .27944 .36285 .27176 Mtetra
.652 .748 .92 r
.36285 .27176 .36979 .27944 .38114 .27539 .37422 .26772 Mtetra
.655 .75 .92 r
.37422 .26772 .38114 .27539 .39253 .27125 .38565 .26358 Mtetra
.657 .752 .92 r
.38565 .26358 .39253 .27125 .40398 .26705 .39712 .25937 Mtetra
.658 .753 .92 r
.39712 .25937 .40398 .26705 .41547 .26281 .40865 .25511 Mtetra
.659 .754 .92 r
.40865 .25511 .41547 .26281 .42701 .25854 .42022 .25081 Mtetra
.42022 .25081 .42701 .25854 .4386 .25425 .43184 .24649 Mtetra
.43184 .24649 .4386 .25425 .45025 .24995 .44352 .24215 Mtetra
.44352 .24215 .45025 .24995 .46194 .24564 .45524 .2378 Mtetra
.658 .753 .92 r
.45524 .2378 .46194 .24564 .47368 .24131 .46701 .23344 Mtetra
.46701 .23344 .47368 .24131 .48547 .23697 .47884 .22906 Mtetra
.47884 .22906 .48547 .23697 .49731 .23262 .49071 .22467 Mtetra
.49071 .22467 .49731 .23262 .5092 .22826 .50264 .22027 Mtetra
.50264 .22027 .5092 .22826 .52114 .22387 .51461 .21585 Mtetra
.51461 .21585 .52114 .22387 .53314 .21947 .52664 .21141 Mtetra
.52664 .21141 .53314 .21947 .54519 .21506 .53873 .20696 Mtetra
.657 .753 .92 r
.53873 .20696 .54519 .21506 .55729 .21063 .55086 .20249 Mtetra
.55086 .20249 .55729 .21063 .56944 .20617 .56305 .198 Mtetra
.56305 .198 .56944 .20617 .58165 .20171 .57529 .1935 Mtetra
.657 .752 .92 r
.57529 .1935 .58165 .20171 .5939 .19722 .58759 .18897 Mtetra
.58759 .18897 .5939 .19722 .60622 .19271 .59994 .18443 Mtetra
.59994 .18443 .60622 .19271 .61859 .18819 .61234 .17987 Mtetra
.61234 .17987 .61859 .18819 .63101 .18364 .6248 .17529 Mtetra
.6248 .17529 .63101 .18364 .64349 .17908 .63732 .17069 Mtetra
.63732 .17069 .64349 .17908 .65602 .1745 .64989 .16606 Mtetra
.64989 .16606 .65602 .1745 .66861 .1699 .66252 .16142 Mtetra
.66252 .16142 .66861 .1699 .68125 .16527 .6752 .15676 Mtetra
.6752 .15676 .68125 .16527 .69395 .16063 .68794 .15208 Mtetra
.68794 .15208 .69395 .16063 .70671 .15597 .70074 .14738 Mtetra
.70074 .14738 .70671 .15597 .71953 .15129 .71359 .14266 Mtetra
.81 .875 .439 r
.03092 .40822 .04327 .38494 .05278 .38487 .04519 .37704 Mtetra
.574 .695 .924 r
.04519 .37704 .05278 .38487 .06262 .38296 .05504 .37516 Mtetra
.489 .663 .939 r
.05504 .37516 .06262 .38296 .08369 .3018 .06473 .37466 Mtetra
.403 .133 .386 r
.06473 .37466 .08369 .3018 .08329 .37293 .0759 .36408 Mtetra
.525 .647 .911 r
.0759 .36408 .08329 .37293 .09329 .3708 .08573 .36318 Mtetra
.588 .71 .927 r
.08573 .36318 .09329 .3708 .10323 .3695 .09581 .36094 Mtetra
.695 .219 0 r
.09581 .36094 .10323 .3695 .11447 .35849 .10401 .37326 Mtetra
.808 .915 .521 r
.10401 .37326 .11447 .35849 .12431 .35853 .11686 .35055 Mtetra
.586 .699 .921 r
.11686 .35055 .12431 .35853 .13454 .35599 .12706 .34836 Mtetra
.594 .714 .927 r
.12706 .34836 .13454 .35599 .14465 .35488 .13733 .34596 Mtetra
.953 .618 .341 r
.13733 .34596 .14465 .35488 .15594 .34403 .14176 .39302 Mtetra
0 0 0 r
.14176 .39302 .15594 .34403 .16609 .34327 .1587 .33531 Mtetra
.597 .707 .921 r
.1587 .33531 .16609 .34327 .17653 .34046 .16912 .33283 Mtetra
.612 .723 .925 r
.16912 .33283 .17653 .34046 .18697 .33808 .17962 .32999 Mtetra
.47 .652 .939 r
.17962 .32999 .18697 .33808 .19961 .31491 .1899 .32978 Mtetra
0 0 0 r
.1899 .32978 .19961 .31491 .20862 .32715 .20139 .31839 Mtetra
.563 .674 .913 r
.20139 .31839 .20862 .32715 .21924 .32434 .21192 .31664 Mtetra
.623 .728 .922 r
.21192 .31664 .21924 .32434 .22994 .32115 .22264 .31348 Mtetra
.622 .729 .924 r
.22264 .31348 .22994 .32115 .24065 .31844 .2334 .31035 Mtetra
.521 .678 .936 r
.2334 .31035 .24065 .31844 .2574 .24694 .24403 .30927 Mtetra
.386 .112 .37 r
.24403 .30927 .2574 .24694 .26271 .30718 .25561 .29799 Mtetra
.553 .66 .908 r
.25561 .29799 .26271 .30718 .27357 .30425 .26637 .29645 Mtetra
.63 .731 .921 r
.26637 .29645 .27357 .30425 .28453 .30074 .27734 .29307 Mtetra
.639 .739 .921 r
.27734 .29307 .28453 .30074 .29554 .29711 .28838 .28943 Mtetra
.639 .74 .922 r
.28838 .28943 .29554 .29711 .3066 .29359 .29947 .28579 Mtetra
.626 .733 .924 r
.29947 .28579 .3066 .29359 .31765 .29094 .31059 .28245 Mtetra
.408 .616 .935 r
.31059 .28245 .31765 .29094 .32957 .2753 .32149 .28324 Mtetra
.588 .866 .539 r
.32149 .28324 .32957 .2753 .34031 .27901 .33332 .27027 Mtetra
.592 .695 .914 r
.33332 .27027 .34031 .27901 .35154 .27563 .34453 .26773 Mtetra
.64 .738 .92 r
.34453 .26773 .35154 .27563 .36285 .27176 .35586 .26399 Mtetra
.649 .746 .92 r
.35586 .26399 .36285 .27176 .37422 .26772 .36726 .25998 Mtetra
.653 .749 .92 r
.36726 .25998 .37422 .26772 .38565 .26358 .37871 .25584 Mtetra
.656 .751 .92 r
.37871 .25584 .38565 .26358 .39712 .25937 .39021 .25162 Mtetra
.658 .753 .92 r
.39021 .25162 .39712 .25937 .40865 .25511 .40177 .24734 Mtetra
.659 .753 .92 r
.40177 .24734 .40865 .25511 .42022 .25081 .41337 .24302 Mtetra
.659 .754 .92 r
.41337 .24302 .42022 .25081 .43184 .24649 .42503 .23866 Mtetra
.42503 .23866 .43184 .24649 .44352 .24215 .43673 .23429 Mtetra
.43673 .23429 .44352 .24215 .45524 .2378 .44849 .2299 Mtetra
.659 .753 .92 r
.44849 .2299 .45524 .2378 .46701 .23344 .4603 .2255 Mtetra
.658 .753 .92 r
.4603 .2255 .46701 .23344 .47884 .22906 .47215 .22108 Mtetra
.47215 .22108 .47884 .22906 .49071 .22467 .48406 .21666 Mtetra
.48406 .21666 .49071 .22467 .50264 .22027 .49602 .21222 Mtetra
.49602 .21222 .50264 .22027 .51461 .21585 .50803 .20776 Mtetra
.50803 .20776 .51461 .21585 .52664 .21141 .5201 .20329 Mtetra
.5201 .20329 .52664 .21141 .53873 .20696 .53221 .1988 Mtetra
.657 .753 .92 r
.53221 .1988 .53873 .20696 .55086 .20249 .54438 .19429 Mtetra
.54438 .19429 .55086 .20249 .56305 .198 .55661 .18977 Mtetra
.55661 .18977 .56305 .198 .57529 .1935 .56889 .18522 Mtetra
.657 .752 .92 r
.56889 .18522 .57529 .1935 .58759 .18897 .58122 .18066 Mtetra
.58122 .18066 .58759 .18897 .59994 .18443 .5936 .17608 Mtetra
.5936 .17608 .59994 .18443 .61234 .17987 .60605 .17148 Mtetra
.60605 .17148 .61234 .17987 .6248 .17529 .61854 .16686 Mtetra
.61854 .16686 .6248 .17529 .63732 .17069 .6311 .16222 Mtetra
.6311 .16222 .63732 .17069 .64989 .16606 .64371 .15756 Mtetra
.64371 .15756 .64989 .16606 .66252 .16142 .65637 .15288 Mtetra
.65637 .15288 .66252 .16142 .6752 .15676 .6691 .14818 Mtetra
.6691 .14818 .6752 .15676 .68794 .15208 .68188 .14346 Mtetra
.68188 .14346 .68794 .15208 .70074 .14738 .69471 .13872 Mtetra
.69471 .13872 .70074 .14738 .71359 .14266 .70761 .13396 Mtetra
.659 .493 .649 r
.02663 .37823 .03092 .40822 .04519 .37704 .03779 .3676 Mtetra
.485 .613 .903 r
.03779 .3676 .04519 .37704 .05504 .37516 .04737 .36748 Mtetra
.575 .703 .929 r
.04737 .36748 .05504 .37516 .06473 .37466 .05729 .36551 Mtetra
.923 .703 .587 r
.05729 .36551 .06473 .37466 .0759 .36408 .07868 .28399 Mtetra
0 0 .146 r
.07868 .28399 .0759 .36408 .08573 .36318 .07815 .35533 Mtetra
.586 .703 .923 r
.07815 .35533 .08573 .36318 .09581 .36094 .08823 .35313 Mtetra
.54 .688 .935 r
.08823 .35313 .09581 .36094 .10401 .37326 .09824 .35177 Mtetra
.701 .558 .689 r
.09824 .35177 .10401 .37326 .11686 .35055 .10959 .34066 Mtetra
.482 .603 .896 r
.10959 .34066 .11686 .35055 .12706 .34836 .11952 .34064 Mtetra
.602 .716 .924 r
.11952 .34064 .12706 .34836 .13733 .34596 .12983 .33803 Mtetra
.528 .682 .936 r
.12983 .33803 .13733 .34596 .14176 .39302 .14002 .33685 Mtetra
.599 .402 .586 r
.14002 .33685 .14176 .39302 .1587 .33531 .15143 .3259 Mtetra
.52 .636 .904 r
.15143 .3259 .1587 .33531 .16912 .33283 .16166 .32509 Mtetra
.613 .721 .923 r
.16166 .32509 .16912 .33283 .17962 .32999 .17219 .3222 Mtetra
.592 .714 .928 r
.17219 .3222 .17962 .32999 .1899 .32978 .18272 .31975 Mtetra
.874 .725 .694 r
.18272 .31975 .1899 .32978 .20139 .31839 .1955 .29643 Mtetra
.053 .133 .629 r
.1955 .29643 .20139 .31839 .21192 .31664 .20457 .30865 Mtetra
.61 .717 .921 r
.20457 .30865 .21192 .31664 .22264 .31348 .21528 .30577 Mtetra
.626 .731 .923 r
.21528 .30577 .22264 .31348 .2334 .31035 .22608 .3025 Mtetra
.604 .72 .927 r
.22608 .3025 .2334 .31035 .24403 .30927 .23688 .29973 Mtetra
.939 .715 .572 r
.23688 .29973 .24403 .30927 .25561 .29799 .25387 .22791 Mtetra
0 0 .296 r
.25387 .22791 .25561 .29799 .26637 .29645 .25915 .2883 Mtetra
.613 .717 .919 r
.25915 .2883 .26637 .29645 .27734 .29307 .27011 .28529 Mtetra
.636 .737 .921 r
.27011 .28529 .27734 .29307 .28838 .28943 .28117 .2817 Mtetra
.64 .74 .921 r
.28117 .2817 .28838 .28943 .29947 .28579 .29229 .278 Mtetra
.635 .738 .922 r
.29229 .278 .29947 .28579 .31059 .28245 .30345 .2744 Mtetra
.598 .718 .928 r
.30345 .2744 .31059 .28245 .32149 .28324 .3146 .27167 Mtetra
.826 .712 .739 r
.3146 .27167 .32149 .28324 .33332 .27027 .32664 .2559 Mtetra
.348 .438 .811 r
.32664 .2559 .33332 .27027 .34453 .26773 .33747 .25956 Mtetra
.627 .727 .919 r
.33747 .25956 .34453 .26773 .35586 .26399 .34881 .2561 Mtetra
.646 .743 .92 r
.34881 .2561 .35586 .26399 .36726 .25998 .36024 .25215 Mtetra
.652 .748 .92 r
.36024 .25215 .36726 .25998 .37871 .25584 .37171 .24803 Mtetra
.655 .75 .92 r
.37171 .24803 .37871 .25584 .39021 .25162 .38325 .2438 Mtetra
.657 .752 .92 r
.38325 .2438 .39021 .25162 .40177 .24734 .39483 .23951 Mtetra
.658 .753 .92 r
.39483 .23951 .40177 .24734 .41337 .24302 .40647 .23516 Mtetra
.659 .754 .92 r
.40647 .23516 .41337 .24302 .42503 .23866 .41816 .23077 Mtetra
.41816 .23077 .42503 .23866 .43673 .23429 .4299 .22636 Mtetra
.4299 .22636 .43673 .23429 .44849 .2299 .44168 .22194 Mtetra
.44168 .22194 .44849 .2299 .4603 .2255 .45352 .2175 Mtetra
.658 .753 .92 r
.45352 .2175 .4603 .2255 .47215 .22108 .46541 .21304 Mtetra
.46541 .21304 .47215 .22108 .48406 .21666 .47736 .20858 Mtetra
.47736 .20858 .48406 .21666 .49602 .21222 .48935 .2041 Mtetra
.48935 .2041 .49602 .21222 .50803 .20776 .5014 .19961 Mtetra
.5014 .19961 .50803 .20776 .5201 .20329 .5135 .1951 Mtetra
.5135 .1951 .5201 .20329 .53221 .1988 .52565 .19057 Mtetra
.52565 .19057 .53221 .1988 .54438 .19429 .53785 .18603 Mtetra
.657 .753 .92 r
.53785 .18603 .54438 .19429 .55661 .18977 .55011 .18146 Mtetra
.55011 .18146 .55661 .18977 .56889 .18522 .56243 .17688 Mtetra
.56243 .17688 .56889 .18522 .58122 .18066 .5748 .17228 Mtetra
.657 .752 .92 r
.5748 .17228 .58122 .18066 .5936 .17608 .58722 .16766 Mtetra
.58722 .16766 .5936 .17608 .60605 .17148 .5997 .16302 Mtetra
.5997 .16302 .60605 .17148 .61854 .16686 .61223 .15836 Mtetra
.61223 .15836 .61854 .16686 .6311 .16222 .62483 .15369 Mtetra
.62483 .15369 .6311 .16222 .64371 .15756 .63747 .14899 Mtetra
.63747 .14899 .64371 .15756 .65637 .15288 .65018 .14427 Mtetra
.65018 .14427 .65637 .15288 .6691 .14818 .66294 .13953 Mtetra
.66294 .13953 .6691 .14818 .68188 .14346 .67576 .13477 Mtetra
.67576 .13477 .68188 .14346 .69471 .13872 .68864 .12999 Mtetra
.68864 .12999 .69471 .13872 .70761 .13396 .70158 .12519 Mtetra
.912 .507 .153 r
.01903 .36953 .02663 .37823 .03779 .3676 .02525 .39088 Mtetra
.816 .879 .447 r
.02525 .39088 .03779 .3676 .04737 .36748 .0397 .35952 Mtetra
.573 .695 .924 r
.0397 .35952 .04737 .36748 .05729 .36551 .04962 .35757 Mtetra
.489 .663 .939 r
.04962 .35757 .05729 .36551 .07868 .28399 .05939 .35702 Mtetra
.397 .124 .379 r
.05939 .35702 .07868 .28399 .07815 .35533 .07067 .34633 Mtetra
.525 .647 .911 r
.07067 .34633 .07815 .35533 .08823 .35313 .08058 .34538 Mtetra
.588 .71 .927 r
.08058 .34538 .08823 .35313 .09824 .35177 .09073 .34307 Mtetra
.689 .213 0 r
.09073 .34307 .09824 .35177 .10959 .34066 .09898 .35538 Mtetra
.814 .919 .528 r
.09898 .35538 .10959 .34066 .11952 .34064 .11197 .33252 Mtetra
.586 .7 .921 r
.11197 .33252 .11952 .34064 .12983 .33803 .12226 .33026 Mtetra
.594 .714 .927 r
.12226 .33026 .12983 .33803 .14002 .33685 .13262 .32779 Mtetra
.953 .617 .337 r
.13262 .32779 .14002 .33685 .15143 .3259 .13701 .37498 Mtetra
0 0 0 r
.13701 .37498 .15143 .3259 .16166 .32509 .15419 .31698 Mtetra
.597 .707 .921 r
.15419 .31698 .16166 .32509 .17219 .3222 .16469 .31443 Mtetra
.612 .723 .925 r
.16469 .31443 .17219 .3222 .18272 .31975 .17529 .31152 Mtetra
.47 .652 .939 r
.17529 .31152 .18272 .31975 .1955 .29643 .18565 .31125 Mtetra
0 0 0 r
.18565 .31125 .1955 .29643 .20457 .30865 .19726 .29975 Mtetra
.563 .674 .913 r
.19726 .29975 .20457 .30865 .21528 .30577 .20788 .29793 Mtetra
.623 .728 .922 r
.20788 .29793 .21528 .30577 .22608 .3025 .21869 .2947 Mtetra
.622 .729 .924 r
.21869 .2947 .22608 .3025 .23688 .29973 .22955 .29149 Mtetra
.521 .678 .936 r
.22955 .29149 .23688 .29973 .25387 .22791 .24028 .29034 Mtetra
.379 .103 .363 r
.24028 .29034 .25387 .22791 .25915 .2883 .25197 .27896 Mtetra
.553 .66 .908 r
.25197 .27896 .25915 .2883 .27011 .28529 .26283 .27734 Mtetra
.63 .731 .921 r
.26283 .27734 .27011 .28529 .28117 .2817 .2739 .27388 Mtetra
.639 .739 .921 r
.2739 .27388 .28117 .2817 .29229 .278 .28504 .27017 Mtetra
.639 .74 .922 r
.28504 .27017 .29229 .278 .30345 .2744 .29624 .26644 Mtetra
.626 .733 .924 r
.29624 .26644 .30345 .2744 .3146 .27167 .30746 .26303 Mtetra
.409 .616 .935 r
.30746 .26303 .3146 .27167 .32664 .2559 .31846 .26374 Mtetra
.6 .875 .551 r
.31846 .26374 .32664 .2559 .33747 .25956 .33041 .25066 Mtetra
.592 .695 .914 r
.33041 .25066 .33747 .25956 .34881 .2561 .34172 .24804 Mtetra
.64 .738 .92 r
.34172 .24804 .34881 .2561 .36024 .25215 .35316 .24422 Mtetra
.649 .746 .92 r
.35316 .24422 .36024 .25215 .37171 .24803 .36467 .24013 Mtetra
.653 .749 .92 r
.36467 .24013 .37171 .24803 .38325 .2438 .37623 .2359 Mtetra
.656 .751 .92 r
.37623 .2359 .38325 .2438 .39483 .23951 .38784 .2316 Mtetra
.658 .753 .92 r
.38784 .2316 .39483 .23951 .40647 .23516 .39951 .22723 Mtetra
.659 .753 .92 r
.39951 .22723 .40647 .23516 .41816 .23077 .41123 .22282 Mtetra
.659 .754 .92 r
.41123 .22282 .41816 .23077 .4299 .22636 .423 .21837 Mtetra
.423 .21837 .4299 .22636 .44168 .22194 .43482 .21391 Mtetra
.43482 .21391 .44168 .22194 .45352 .2175 .4467 .20943 Mtetra
.659 .753 .92 r
.4467 .20943 .45352 .2175 .46541 .21304 .45862 .20494 Mtetra
.658 .753 .92 r
.45862 .20494 .46541 .21304 .47736 .20858 .4706 .20044 Mtetra
.4706 .20044 .47736 .20858 .48935 .2041 .48263 .19592 Mtetra
.48263 .19592 .48935 .2041 .5014 .19961 .49471 .19139 Mtetra
.49471 .19139 .5014 .19961 .5135 .1951 .50684 .18684 Mtetra
.50684 .18684 .5135 .1951 .52565 .19057 .51903 .18227 Mtetra
.51903 .18227 .52565 .19057 .53785 .18603 .53127 .17769 Mtetra
.657 .753 .92 r
.53127 .17769 .53785 .18603 .55011 .18146 .54357 .17309 Mtetra
.54357 .17309 .55011 .18146 .56243 .17688 .55592 .16847 Mtetra
.55592 .16847 .56243 .17688 .5748 .17228 .56832 .16383 Mtetra
.657 .752 .92 r
.56832 .16383 .5748 .17228 .58722 .16766 .58078 .15917 Mtetra
.58078 .15917 .58722 .16766 .5997 .16302 .5933 .1545 Mtetra
.5933 .1545 .5997 .16302 .61223 .15836 .60587 .1498 Mtetra
.60587 .1498 .61223 .15836 .62483 .15369 .6185 .14508 Mtetra
.6185 .14508 .62483 .15369 .63747 .14899 .63119 .14034 Mtetra
.63119 .14034 .63747 .14899 .65018 .14427 .64393 .13558 Mtetra
.64393 .13558 .65018 .14427 .66294 .13953 .65673 .13081 Mtetra
.65673 .13081 .66294 .13953 .67576 .13477 .66959 .12601 Mtetra
.66959 .12601 .67576 .13477 .68864 .12999 .68251 .12118 Mtetra
.68251 .12118 .68864 .12999 .70158 .12519 .69549 .11634 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05eoo`0GD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBo@0GOol00`00
Oomoo`17Ool008Moo`<006=oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aB
o5;mD_`005;lD_d00U;l5goo00<007ooOol0AWoo0025Ool2001ROol085;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_dFOol00`00Oomoo`16
Ool0089oo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`00e;mD_aoo`0FOol00`00Oomoo`15Ool0081oo`8006=oo`0UD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_`05goo00<007ooOol0A7oo001mOol3001QOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo003D_eB
o7oo01Eoo`03001oogoo04Aoo`00Ngoo0P000Woo00<007ooOol0GGoo02aBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;m5goo00<007ooOol0@goo001hOol3001ROol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@0GOol00`00Oomoo`12Ool007Ioo`80065oo`0dD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`12Ool007=oo`<0065oo`9Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo004D_eBo5;lD_`GOol00`00Oomoo`11Ool0075o
o`80069oo`0iD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;l01Eoo`03001oo`00049oo`00KWoo0`00H7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomoo`10Ool006]oo`<0065o
o`11D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0oOol006Uoo`8000=oo`03001oogoo05]oo`03D_aBoE;l
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;m
D_aBo5;lD_d00e;l5Goo00<007ooOol0?goo001VOol3001OOol0BE;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m01Ioo`03001oogoo03ioo`00I7oo0P00H7oo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aB
o5;lD_d00U;l5Woo00<007ooOol0?Goo001QOol3001POol0Ce;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m01Eoo`03001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P00Ggoo00=Bo5;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007oo
Ool09Woo00<007ooOol04goo000dOol00`00Oomoo`02Ool00`00Oomoo`0POol3001POol0EE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo02Eo
o`03001oogoo01=oo`00>Goo00<007ooOol07Woo0P000Woo00<007ooOol0G7oo0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Eoo`03001oogoo02Ao
o`03001oo`0001Aoo`00;7oo1P001goo00<007ooOol06goo0`00Ggoo05aBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Woo00<007ooOol0
8goo00<007oo000057oo000eOol4000LOol2001POol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0FOol00`00Oomoo`0QOol0
1@00Oomoogoo00004goo000eOol00`00Oomoo`0JOol3001POol0HU;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol2
000SOol01@00Oomoogoo00004goo000eOol00`00Oomoo`0GOol3001OOol2D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d05Goo00<007ooOol07goo0`0000Aoo`000000019oo`00=Goo1@004goo0P00H7oo
06UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol0=goo001:Ool300000goo
001oo`1MOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol0
27oo1000:goo0018Ool2001OOol0L5;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m5Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0:7oo0015Ool3001OOol01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;l
D_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol0:7oo0013Ool2001POol0ME;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`0XOol0041oo`<005ioo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Eoo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo02Qoo`00?Woo0P00GGoo07mBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`0XOol003]oo`@005eoo`=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l
001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol057oo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol0:7oo000iOol20004Ool00`00Oomoo`0^Ool00ba[Oomo
o`0WOol0Q5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo00=oo`@002]oo`00=Woo0`00
=goo00</BWooOol08goo0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0COol200000goo001o
o`0bOol003=oo`<003Yoo`03<6//BWoo025oo`2;D_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d05Goo00<007ooOol0<Goo000aOol2000mOol00ba:;4]oo`0OOol00e;lD_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00800003D_aBoE;l009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Eoo`03001oogoo031oo`00;Woo
0`00?goo00</Jba:Ool06goo07=BoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@0300007E;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d05Goo00<007ooOol0;goo000/Ool4000oOol00ba;;4X/B`0HOol5B[`01dkl
C]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0300001U;mD_aBo5;lD_d0009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo1Eoo`03001oogoo
02moo`00:Woo0P00@goo00@/BS1[;4Y2_AIoo`04Bg1;LDJlB]d2B[`0K4JlD_e>g5;mC]aBoDklD_e>
g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@<0000TD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol0;Woo000ZOol20013
Ool012a;;4X/Bba;5Goo00A;L2Vi:KU;L@E:_09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l0P00
00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00U;l5Goo00<007ooOol0;Woo000@Ool50003Ool40004Ool40006Ool0
0`00Ool00012Ool012a:;6//BS1[5Goo00=ZefJf;KT00RVi06U>g4kmC]a>oDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`00`0002YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0]Ool0019oo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool200000goo001oo`10
Ool012a;;4X/Bba;57oo0VKG00=ZebVi:KT00RVi0dkL00E>gDkLD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l00000P000e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00EOol00`00Oomoo`0/Ool0019oo`03001oogoo009o
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0mOol01D:m
;4X`Jba:<6/037oo00i>g4kmC]a>oDkL<WdbGF[GI[IZefJfJ]LY^2fi0RVi065>g5;mC]aBoDkLD_e>
g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o0030000<U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`0/
Ool000Moo`H000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`0lOol00ba:;4//BP02;4/9Ool03DkLC_e>o5;mC]a>gDkLC_db
GC9mI]MZefKF009Ve`E:_004C]a>o4kLD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00IBoE;lD_aBo5;mD_`30003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_aoo`0DOol00`00Oomoo`0[Ool0019oo`03001oogoo009oo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0kOol01S1[;4X/Jba:<6/n
W@Aoo`1bD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_eV]V[GI[IZefJfBg57D4ZlA[a:gDZlD_e>g5;m
C]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0`0003UB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<0
07oo0000;7oo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
0Woo0P001Woo0P00>goo00H/BRa;;4X/Bba:<6/2Ool3C]`02U;mC]a>o4klD_e>g4kmC_aBoD[L0d[M
00EVeVKGI]MZed]@009;L0A:_005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_eBo0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol0:Woo000@Ool30004Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0=goo07LnWBa[;4X`Jba:
;6//BU;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDZlC]e:g4[MI[IZefJf:KTY^2fi:KU>oDkL
C_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00<00010D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_dEOol00`00Oomoo`0YOol0019oo`03001oogoo00=oo`@000Aoo`@000Eoo`03001oogoo00Qoo`03
001oogoo03Ioo`03@[d/BRa;009fd@96W004@Ya>g4kLC_d2C]`00dklD_e>g002C_`01TkmC]a>oDkL
C_e:g0=:g@03I]IVefKF00@Y^@05C]e>g4kLC]a>g@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
0e;mD_`000020003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Eoo`03001oogoo02Qoo`00:7oo00<007ooOol0
2Woo00<007ooOol0=Goo01h/BS1[M]5fdWJaAYa2W4JL@Ya6W4kLD_e>g5;mC]aBoDkLD_e>g4kmC]a>
oDkLC_dbG39m<UeZefJfJ]L2:KT0DRVh;KU>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m0P0004MBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Eoo`03001oogoo02Qoo`00:7oo0`002goo
00<007ooOol0=7oo00</BgKAM]400WKA00D024kLB]a>gD[L009>g00CC_e>g4klC]aBoDkLC_e>o4km
C]a>gDkL<WdbGFKGI]IZefKFI]L012Vi00I>g5;mC]a>o4kLD_d3D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00<0
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol09goo000XOol00`00Oomoo`0<
Ool00ba;Oomoo`0cOol087KAM]9f/GKBM]402@08C]e:g4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4km
C]a>oDkLJ]MV]V[GI[IZefJfB]d2B[`0BTJlB]e>g5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d30000CU;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02Ioo`00:7oo00<007oo
Ool037oo00<`J`00Ool0;7oo00A>g4kMC]a>g@92_@Ifd@0700P02D[LC]a:g4kMB]`00Tkl00YBoDkL
C_a>o5;mC]a>oDklB]e:g09:g@06J]MVeVKGI]I;L4M@1DZl00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol0
02Qoo`8000eoo`03;6]oo`0002Qoo`0YC_e>g4kmB]a>oDkLC_e:g4km?YefdWJaM]9fdGKBM[402@08
00U>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDZlC]e:g6[GI[IZe`02:KT0ARVh;KU>g4km
C]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m0`0005IBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l57oo00<007ooOol09Goo000XOol00`00Oomoo`0<Ool0131[Oomoo`008Woo0P0000e6
_4JLA[a6W4kMC]a>gDkLC]e>g4kMC]a>g@07M]43AY`3C]`04dkmC]a>o4klD_e>g4klC]a>oDkLC_e>
g4[MB]a:gFKFJ]MV]VKG00@Y^@07C]a>gDkLC]aBo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo0<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Eoo`03001oogoo02Aoo`00:7oo00<007oo
Ool02goo00<`Jba;Ool00Woo00<007ooOol07goo030006kE17=6_DJLA[a6W4kmC]a>oD[LC]e:g4kM
B]a>gGKAM]9f/GKBM]5fdT:LAYa2W4JL@YaBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL<WdbG39m
I[IZefJf;KT2:KT0?RVhC_e>g4kmC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d30000GE;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol2000VOol002Moo`03001oogoo00aoo`8`J`Ao
o`03001oogoo01eoo`0=001^eFkE17=6W4JlAYa6_4JLC]e>g4kmC]`00d[M00=:g7KAM]4017KA00X0
2D[LC]a:g4kMB]a>o4kLC_e>g09>o007D_e>g4kMC]a>oDkLC]d00S9m00EV]VKGI]IZefJf00@Y^@07
C_a>g5;mC]a>o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l0`000U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m009Bo1Aoo`03001oogoo02=oo`009goo0`0037oo00<`K2a[<8`017oo00<007ooOol0
77oo03=^eF[EK_H4L`BCB[a>gD[LC]e:_4kmC]a>oDkLC_e:g4kMB]afdWKAM]9f/GKB00P02DZlC]e:
g4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]a>oFJfJ]MV]V[GI[IZedJlB]d00TZl03I6_5;mC]aB
oDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d30000I5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l5Goo00<007ooOol08Woo000WOol00`00Oomoo`0;Ool0131[;6/`Jc1[1Goo00<007ooOol0
6Woo16kE0`Ac00Y:g4kLB]a>gD[LC]e>g4kMC]a>g@92_@Efd@<02@05B]a>g4[LC]e>g002C_`01e;m
C]a>oDklD_e>g4km009:g@08B]a:gFKFJ]MV]VKGAdm7D0E:_09Bo005D_e>o5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo080009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol0
8Woo000EOol40004Ool40006Ool00`00Oomoo`0;Ool012a[<6//Bc2<1Woo00<007ooOol04Woo00U>
oD[LC]e:g4km>WdjWF[EK_H00VkE06=Ze@BD17<4T`AcC_e>g4kmB]a>oDkLC_e:g4:mM]5fdWJaM]9f
dGKB00P02@0800U>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a:gDZlJ]MV]V[GI[H]^BVi;KTY
^4kmC]a>oDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`0006YBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo025oo`0057oo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo00=oo`03001oogoo00]oo`@`J`Moo`8000moo`09B]a:_4[MB[a>gD[LC]e:g4kM
00I^e@0=AYa6_4JLA[a6W4kMC]a>gDkLC]e>g4kMC]`01WKA00=fdT:LAY`00TJL0dkL00Y>oDkLC_a>
o5;mC]a>oDkLC_e>g0=:g@05B]aVefKFI]MV]P04:KT2C]`01TkMC_aBo5;lD_e>o09Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;m
D_aBo5;l0`0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo01=o
o`03001oogoo021oo`006Goo00@007ooOol000Aoo`03001oogoo00=oo`8000aoo`04;4/`K2a[<8`9
Ool00`00Oomoo`0<Ool02P00B]e:_4[MB[a:gDZlB]e6_4[M0VkE05mZeFkfK]D4TdJLA[e6W4JlB]a>
oDkLC_e:g4kMB]a>gD[LM]9fdGKBL[5fdWJaAYa2W4JL@Ya6W4kLD_e>g5;mC]aBoDkLD_e>g5;mC]aB
oDkLC]e:g4[M;UaZefJfJ]LY^2fi:KT]^DkLC_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l00<0001bD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol087oo
000<Ool60007Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol02goo0S1[00D/Jc1[<6]o
ocZM00Qoo`03001oogoo00Yoo`<00005C]e:g4kMB]a>g@02B]d00d[LK]E^e@03K]D02`AcA[a6W4Jl
AYa6_4kLC]e>g4kmB]`00d[M0gKA00ifdWKAM]402DkMB]a>g4[LC]e>g4klC]a>oDkL0Tkl00IBoDkL
C]e>g4kmC]`2<Wd01FKGI[IVefKFI]L012Vi00A>g4klC]aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`300000e;lD_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001B
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo
01moo`005Goo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02goo00L`K2a[<6//
Bc2<Ool`S009Ool00`00Oomoo`08Ool03WI9CI8nO4:L?W]>gD[LC]e:g4[MB[a:gDJlK_H2K]D0<V[E
K_H4LdkMB[a>gD[LC]e>g4kmC]a>oDkLC]e:g4kML[5fdWJaM]9b/@0900Q>gDZlC]e:g5;mC]aBoDkL
D_e>g5;mC]aBoDkLC_e>g4kmC]aZefJfJ]MV]V[GI[I:_4JlB]d2B[`08dkLD_e>g5;mC]aBoDklD_e>
g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_`00`0007UB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o00DOol00`00Oomoo`0OOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`80
00aoo`03;6/`Jc1[008`J`03Ool`Jgoo00Uoo`06001:gD[MB]a:gGIZ0goo00=fJP00BI800d9l00Dn
O4kMB]a>gD[L00=:g@E^e@84L`0:C]e:g4kLB]a>gDkLC]e>g4kMC]`2@[d01GKBM]5fdGKAM]800`09
00I>gD[LC]a:g5;mC]`2C_`01U;mC]a>oDklD_e>g0=:g@05B]aVefKFI]MV]P02Adl5B[`01DklD_aB
o5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0`00
00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0NOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Yoo`08;6/`Jba;<6`/Jc2<Ool`S0Qoo`08A[a:gDJlB]e:_4[MB[aj
JP9oo`0BMTUjJTUaBI99LD:L?Wa2W3ikC_e:g4kMB]`jWCYmK]EZeFkf0VkE04l4L`BD17<4Td[LC_e>
g4kmB]a>oDkLC_dnW7KBM[5fdW:aM]9f/@0900P02@08C_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>
g4kMB]a:gFJfJ]MV]V[G:KP]^BViC_e>g4kmC]a>oDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo0030000PE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001B
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomo
o`0MOol001Eoo`D000=oo`@000Eoo`03001oogoo00Yoo`<`J`05;6/`Jc1[?Yd`J`07Ool2Ii000dZl
B]e:_002B[`01T[MMTYfJWIZNVYfBP=9TP09B[a:g4ZlB]e:_4kMB]a>gD[L00I^e@0=A[a6W4JlAYa6
_4kLC]e>g4kMC]a>gDkLC]d00gKA00IfdWKAM]5fdDJL@Y`2AY`01TkmC]a>g4kLC_e>g09>o006D_e>
g4kmC]a>oD[L0d[M00AV]VKGI]IVe`<Y^@06C]e>g4kLC]aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;l0`0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aB
o5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00COol2
000OOol002Ioo`03001oogoo00Yoo`08;4/`K2a[<6//Bc2<<6/`S0Moo`0KIk1WSfN`B]a>gDZlC]e:
g7YZMTUjJWI9NVY9LDfBBG4004ZlB]e:_4[MB[a:gDZlB]e6_6kf009^e@1<J]E^mVkEA[a6W4JmAYa>
oD[LC_e>g4kmB]a>gD[LC]eb/GKBM[5fdW:aM]802DJL@Ya6W4:LD_e>g5;mC]aBoDkLD_e>g5;mC]aB
oDkLD_e:_4kMB]`bOFJfJ]MV]Rfi:KP]^BViC_e>g4kmC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d20000R5;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<0
07ooOol077oo000UOol00`00Ool0000:Ool2<6/00ba[<6/`J`02<6/0132<<6]oocZM17oo0UHe00/n
G3YK>Ua:g4[MB]a:gGIZNVYfBWIZ00=9TP@00004C]e:g4kMB]`3B]d00d[LK]E^e@03K]D02`AcA[a6
W4JlAYa>oDkLC]e>g4kmB]`00d[M0gKA00ifdWKA00T02DkMB]a>g4[LC_e>g4klC]aBoDkL0Tkl00a>
oDkLC]e>g4km<UdbOFKFI]MV]VKGI]H4:KT01E;mC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@0300001E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Aoo`03
001oogoo00Moo`D000moo`009Goo0P002goo00/`K2a[<6//Bc1/;6]:gDJlB]e6_4[M00=oo`0OFSEF
5EXe>U/nO3YK?Wa:g4kMB[ajJWI9NVYfBDfBBG59TTUa@Y`nO4:L?W]>gD[LC]e6_4[MB[a:gF[EK_H0
0VkE01AZe@BD17=>gDZlC]e:g4kmC]a>oDkLC_e:g4kMB]a>gG:aM]9f/GKB0`0901M>gDZlC]e>g5;m
C]aBoDkLD_e>g5;mC]a>oDkLC_e>g4kmI[IZefJfJ]MV]V[G009:_00DA[a:gDZlD_e>g5;mC]aBoDkL
D_e>o5;mC]aBoE;lD_e>g5;mD_aBo@<0002>D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`DOol00`00Oomoo`07Ool01@00Oomoogoo00003goo000UOol00`00Oomoo`0:Ool0
1Ba[<6]b/WKB@W`00T:L00A:gDZlB]e:g@9oo`03Ii1F=EXe009F=@04>U`nG3YK>U`2B]d017I:MVYf
JWYZ1DVB0d9l00E:g4kMB]a>gD[L00=:g@A^e@<4L`0=C]e:g4kLB]a>gDkLC]e>g4kM?Ye2_GKAM]80
0gKA0`0900M:g4kMB]a>g4klD_e>g002C_`01U;mC]a>oDklD_e:g0=:g@06I[IVefKFI]M3;T<_1DZl
00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@0300001E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0COol00`00Oomoo`07Ool00`00Oomoo`0@Ool002Eo
o`03001oogoo00Yoo`0_<6]b/GKBL[5fdSil@YdnO4:LA[a:gDJlE<1F5EXeEQEJ=EHEB]e6_4[MA[a:
gDZlB]efBGYZ0019TTUaCI99TDVBBG52W3il@Ya:g4kmB]a>gCYm>YdjOFkEJ]E^mP02K]D04PAc19@4
LdkmB]a>oDkLC_e:g4kmC]a2_G:aM]9f/GKBL[5fdP@02@0VC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;m
C]aBoDZlC]e:g6[GI[IZefJf;KTY^2fiC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBo@<0002FD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo
00<007ooOol01goo00<007ooOol03goo000UOol2000:Ool02c1[L[9fdW:bM[9b/P04B[a:_DZlB]d0
0T:m00=F=EXeESD00UHe00EWT6N?B[a:_4Zm009:_003B]ejJWI:00M9TP09001:g4ZlB]e:g4kMB]a>
gD[L00I^e@0=A[a6W4JlAYa>gDkLC]e>g4kMC]a>gDkLM]800gKA00=fdWKAM]800TJL00A2W4JLC]a>
o@=>g00:D_e>g4klC_a>oDkLC_e>g4[MB]`2B]d016KGI[IVefKF0bVi00M>g4kMC]a>g5;lD_e>o002
D_`01E;m00000000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m01Aoo`03001oogoo00Qoo`03001oogoo00ioo`009Goo00<007ooOol0
2Goo028jWGKBL[5fdW:aM]800`04A[a:gDJlA[e2_4JmEQEJ=EHEFSESSfN`HhmW/4[LC]e:_4kMMTUj
JTUaCI99LDVBBG5=TP80000:B[a:gDZlB]e6_4[MB[a:gDJlK_H2K]D0>6[EK]H4LdJlAYa6_DkLC_e:
g4kmC]a>gD[LC]e:g7KBL[5fdWJaM]9b/@0:@Ya6W4:LAYa>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>
g4[MB[a>gC9MJ]MV]V[G:KT]^BVhC_e>g4kmC]a>oDkLD_d30000WE;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Aoo`03
001oogoo00Qoo`03001oogoo00eoo`009Goo00<007ooOol00goo00A6_DJlA[e6_08nW@06M]9b/WJb
L[9fdW:b0P0400A:gDZlB[e:_092_@9F=@0<FSEWSeHeESDnG3YK>Ua:g4[MB]afJP001TVB0`0000E:
g4kMB]a>gD[L00=:g@E^e@0<19=6W4JlAYa6_4kLC_e>g4kMC]a:gD[L0T[M00EfdWKAM]9fdGKB0080
2@03B]a>gD[L009>g00CC_e>g4klC_aBoDkLC_a>g4kmC]a>gDkL<WdbGFKGI]IVefJfI]L00bVi00=>
o4kLD_d00`0000EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`03Ool01@00Oomoogoo00003goo
000TOol00`00Oomoo`04Ool0BfM]B]e6_4ZmA[a:gG:aM]9b/GKBL[5fdP0300@00d[MA[a:gDJlA[eF
5EXeEQEJ=EHEFSDjFcil>U]>gD[LC]efBDfBBG59TTUaCI99TDVBBI52W3il@Ya:g4kMB]a>gDJlB]e:
_4[MJ]E^eV[EK]D4L`RDB]a>gDZlC]e>g4kmC]a>oDkLC]e:g4kMB]afdW:aM]9f/@0200T06@0:B]a>
gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g6[GI[IZefJfJ]MV]T[M009:_0<0002TD_e>g5;m
C_aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00Aoo`<0011oo`0097oo0`000goo0fM]0TJm
00Y:gDJlA[eb/WKBL[9f/W:bM]92O092W009B]e:_4[MB]eJ=EHeIi1F=EXe009F=@03>U`nG3YK009:
g@03NVY2_DVB00I9TP09?Wa2O49l@Wa:g4kMB]a>gD[L009:g@A^e@0C19<4L`BCB]a>gD[LC]a:g4kM
C]a>gDkL@[dnWGKBM]5fdWKAM]800`0900A>g4[LC]e:g09>o00:D_e>g4klC_aBoDkLC_e>o4[MB]`2
B]d016KGI[IVefKF0T<^0P000dZl00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`A
Ool200000goo001oo`0GOol002Aoo`03001oogoo009oo`1>LN=Am3YL?W`jFd[MA[a:gDJlM]9b/GKB
L[5fdW:a@Y`nO4:M?Wa2W4JlB]e2_EXeEQEJ=EHEFSEF5FN@A[a:gDJlB]efBD:mBG5=TTVABI99LDfB
BI9=TTZlB]e:_4[MB]a>oD[LC]djOCZMJ]E^eF[EK]IZe@BD17<8U4kLC_e:g4kmC]a>oD[LC_e>g4:m
L[5fdWJaM]9b/@0:0`0901ABoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e:_4kMI[IZefJf0`00
0:/Y^4kmC]a>oDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol05Goo
000JOol40006Ool00`00Oomoo`02Ool3DO@00cYL?W`jG002A[d03D[MA[`nWG:bM]9b/WJbL[9:gDZl
B[e:_4[M0092_@03ESEJ=EHe009F=@05Ii1SSdZlB[a:_@02B[`00d:mBI99TP06BI802@00B[a:g4Zl
B]e:g4kMB]a>g@06K]D04dJLA[a6W4JlC]a>gDkLC]e>g4kMC]a>gDkLM]9fdGKBM]5fdWKA00=6W004
@Ya>g4kLC_d2C]`02dklD_e>g4klC]a>oDkLC_e>g4[MB]`00`0000EV]VKG:KT]^BVi009>g005C]e>
g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo01Eoo`006Goo00<0
07ooOol00Woo00<007ooOol00goo0300077TOomoogH4DM=Am57CDO@jG3il>U/n_CZM?Yeb/GKBL[5f
dW:aM]8014[MA[a:gDJl@[e2_4JmEQEJ=EHEFSESSfN@Hhm>gD[LC]e:_4:mBG59TTUaCI99TTfBBI42
0000<T[MB[a:gDZlB]e6_4[MB[a:gF[EK]IZeFkEJ]D8U4JLA[a6W4JmC]a>oD[LC_e:g4kMB]a>gD[L
M]9b/GKBL[5fdW:aAYa2W4JL@YaBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]`30000/biL<WeV]V[GI[IZ
ebVi;KU>g4kmC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007ooOol0
57oo000IOol00`00Oomoo`02Ool00`00Oomoo`03Ool01000LNAai77T1E7d00AWKDJlA[e6_08nW@06
M]9b/WJbL[9fdW:b0`0400=:_4ZmB[`00T:m0UHe00YJ=EHeESDjG3iL>U]:gD[LB]e2_@M9TP<00006
C]e:g4kMB]a>gD[L0T[M1FkE00X4L`BCAYa6_4JLA[a>g4kmC]a>g@9:g@0AB]a:gGKAM]9fdGKBM]5f
dP09C]a:g4kMB]a>o4kLC_e>g002C_`00e;mC]`0000200002DkLC]dbOC9mI[IVefJfI]MV]P02:KT0
1RfiC]a>o4kLD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol04goo
000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool0G`00OomahgH4LNAAm57CDOAAdfM]Hde:gDJlB[e6
_4[ML[5fdW:aM]9b/GKB?Wa2WCil@Ya6_4[MA[a2_EHEFSEF5EXeEQDnO3YK?W`jFcilB]a>gDUaCI99
TDVBBI5=TTVBCI8nNd:L?Wa>gD[LC]e:g4kMA[a:gDZl>YeZeFkFJ]D8U0Ac29A:g4kMB[a>gDkLC_e>
g4kmB]a>gD[LC]eb/GKBL[5fdW:a00X02DkMB]a>gDZlD_e>g5;mC]`00`0000]>g5;mC]a>oDkLC_eV
]V[GI[IZefJf0080002]B]e:_4ZlC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@0COol00`00Oomoo`0COol001Uoo`03001oogoo009oo`03001oogoo009oo`04001oog7TLN@5DO@3
Ifd2A[d02T[MA[a6_G:bM]9b/WJbL[9fdT9l0T:L00E:gDZlB]eD`5Xe00=F=@05FSEF=DZlB[a:_@02
B[`00d[MBI99TP06BI800d9l?Wa2O002@W`014[LC]e:g4kM0SZM1FkE00H4T`Ac19=:g4kMB]`2C]`0
0dkMC]a>g@02@[d01WKAM]9fdGKBM]5fdP<02@9>g003C_e>g00000800006C]a>oDklD_e>g4km0T[M
00E:g4[MI[IVefJf00<000A:_005C_aBo5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eB
o7oo01=oo`03001oogoo019oo`006Goo00<007ooOol00Woo00<007ooOol00Woo05T007ooOomai57C
DOAAde7dHdeoocYL?W`jFd[MA[a:gDJlM]9b/GKBL[5fdW:b@Y`nO4:M?Wa:gDJlB]e2_EXeEQEJ=EHe
IhmSKd[MA[a:gDJlB]e9LDVBBG5=TTVBCI99TDfBBI9:gDZlB]e:_4[MB]a>oD[L>YdfOFkFJ]E^eF[E
K]H4L`RD17<8U4kLC_e:g4kmC]a>oD[LC_e>g7KBL[5fdW:aM]9b/DJL@Ya6W4:L00<00031C]aBoDkL
D_e>g5;mC]aBoDkLD_e:g4[MB[aZefJf001V]V[G:KT]^DkLC_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol04Goo000IOol00`00Oomoo`02Ool00`00Oomo
o`02Ool20002Ool4DO@3Ool01cYL?W`jG3ilA[e:gDJl009b/P08M]9b/W:b00A:gDZlB[e:_092_@9F
=@06FSEF=EHeHhmWSf>?0TZl00=:_DZlB]d024VB00T004[MB[a:g4ZlC]e:g4kMB]`01fkE00Q6W4Jl
AYa6_4kLC]e>g4kM0T[M00U:g4[MB]efdWKAM]9fdGKBM]400`000dkL00]>oDkLC_a>o5;mC]a>oDkL
C_e>g4km009:g@05B]`bOFJfI]MV]P02:KT01RfiC]a>g4kLC]e>g09Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo006D_eBo5;lD_aBoE;l4goo00<007ooOol04Goo000JOol40005Ool00`00Oomoo`02Ool00e7d
DM=WK@04Ool09TJlB[e6_4[M>YdnWG:aM]9b/WKBL[401@04B]e6_4[MA[a:gD:lFSEF=EXeHfmWT6>?
IhmSKdkMB]a>gDZlCI99TDfBBI5=TTVBCI8400007TZlB]e:_4[MA[a:gDZlK]EZeFkFJ]E^eV[E29A6
W4JlAYa6_DkLC_e>g4kmB]a>gD[LC]eb/GKBL[5fdP800038@Ya6W4:LAYa>g5;mC]aBoDkLD_e>g5;m
C]a>oDkLC_e>g4km;UdbOFJfJ]MV]V[GI[H]fBVi;KU>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoA9oo`<0019oo`001Goo0P0000=oo`0000006Goo00<007ooOol00Woo0U7d
1Woo00I6_4JmA[`nWG:bM]83L[801WKB00@01004B]e:_0=:g@=F=@09IhmF=EHe>U`nG3YKB]e:g4[M
00M9TP03@W`nO49l0092O005B]a>gD[LB]e:g002B]d5K]D219<00d[LC]e:g002C]`00dkmC]a>g@02
B]d00d[LB]d0000200006gKBM]402T[LC]a:g4kMC]a>o4kLC_e>g4kmC_aBoDkLC]e>g4kmC]a>gFJf
I]MV]VKGI[IVe`04B[`01DkLC_a>g5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m01=oo`03001oogoo011oo`0017oo00<007ooOol00P006Woo00<007ooOol00Woo00=Am6M]Ool0
1Woo0416_4ZmA[afdW:bM]9b/GKBL[9fdSil@YdnO4[MA[a:gDJlFSEF5FN@ESEJ=EHE?W`jFcil>U]:
gDZlBI8nW4fBBI9=TTVACI99TT:L?W]2W3ilC]e:g4kMB]a:gDJlB]e:_6kFJ]E^eV[E29@4L`RDB]a>
gDZlC_e>g4kmC]a>o@<0000MM]9b/GKBL[5fdP0900Y:_4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e>g4kM
B]a:gDZlC]eV]V[GI[IZe`020000/4JlB]e:_5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_dCOol00`00Oomoo`0?Ool000Aoo`05001oogooOol0000IOol30003Ool00e7d
Oomoo`07Ool00dJmB]e6_002L[801WKBL[9b/W:bM]92O092W005B]e:_4[MB]eJ=@03ESD02EXeESE:
_4ZlB[e:_4[MBI92_@07BI80249l?Wa2O49lC]e:g4kMB]`3>Yd5K]D01`RD19<4Td[LC]e:g4kM00<0
000;C]e2_GKBM]5fdWKAM]9fd@0:00T02P03C]`02TkmC]a>o4klD_e>g4kmC]a>oDkL0d[M00Q:g6KG
I[IVefJf;KTY^Bfi0dZl00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m01=oo`03001oogoo00ioo`0017oo00D007ooOomoo`0001Uoo`03001oogoo00=oo`03Ifeoogoo
00Moo`0iB]e6_4[MA[afdW:bM]9b/GKBL[801Cil@YdnO4:m@[a6_EHeFSEF5EXeESESSf=^B]e6_4[M
A[a:gCjMCI99TDfBBI9=TTVACK99TT[MB[a:gDZlC]e:g4kmB]a>gF[EK]IZeFkFJ]E^eTJLA[a6W4Jm
00<0003FC_e>g4kmB]a>oG:aM]9b/GKBL[5fdW:aAYa2W4JLC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;m
C]a>gD[LB]e:_6[GI[IVebVh;MTY^BfiC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`COol00`00Oomoo`0>Ool000Aoo`05001oogooOol0000IOol00`00Oomoo`0>
Ool2A[d01D[MA[ab/W:bM]800W:b00D01005B[a:_DZl00=2_@04ESEJ=EHeESD3Hhl01D[MB]a:gD[L
@[d024VB00L004[MB[a:g4ZlB]e:g003B]d5K]D020RC00000000C]e>g4kMC]`3B]d01D[LB]efdGKB
M]400gKB00U2W4JLAYa6W4kLC_a>g4kmC]`00Tkl00IBoDkLC_e>g4kmC]`3B]d026JfI]MV]VKG:KT]
^BViC]d3C]`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4goo00<0
07ooOol03Goo0003Ool20002Ool2000IOol00`00Oomoo`0?Ool08cjm>YefdW:aM]9b/WKBL[401@04
B]e6_4[MA[a2_D:lFSEF=EXeEQEJ=CYK?W`jFdkMB]a>gCjLCI99TTfBBI5=/TVBCI800`0000]>gD[L
C]e:g4[MA[a:gDZlK]IZeFkF00<0003NA[e6W4JlAYa>oDkLC_e>g4kMB]a>gD[LM]9b/GKBL[5fdW:a
00Y:_4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL<Wd^GFKGI[IZefJf;KTY^2gI:KUBoDkL
D_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l4goo00<007ooOol0
37oo000ROol2000BOol00g:bM]9b/P02L[801WKB00@01004B]e:_09:g@06@[eF=EHeESEJ=EHe0SYL
00DnG3YKB]e:g4:m00M9TP0;CI8nO49l@Wa>gD[LC]e:g4kMB]a:g@030002K]D02`RD19=>g4[LC]e:
g4kMC]a>oDkLC]d00T[M00I:g7KBM]9fdWKAM]8200X05D[LC]a:g4kmC]a>o4kLC_e>g4kmC_aBoDkL
C]e>g4kmC]aVefJfI]MV]P020004B[`01E;mC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`015;mD_aBo5;l4Woo00<007ooOol037oo000ROol00`00Oomoo`0BOol017:bM]9b
/GKB0Woo028nO4:M?Wa:gDJlB]e6_5XeEQEJ=EHeFSEF5Cil>U/nO3YKB]e:_4fBBI5=TTVBCI99TDfb
BI92W3ik@Y`nO4kMB]a>o@<0000_>YeZeFkFJ]E^eV[E29@4LdkMB]a>gDZlC_e>g4kmB]a>oCjMM]9b
/GKBL[5fdW:a00X02DkMB[a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mB[a>gD[LB]e:_6[GI[IVe`030000
/dZlA[a:gDZlD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
4goo00<007ooOol02goo000QOol00`00Oomoo`0COol2L[84Ool02D:L@Wa2W4:LB]e:_4[M@[eJ=@03
ESD01f>?Hfi:_4ZlB[e:_4[M00U9TP04B]e:_4[LB[`2000014kMB]`jWCZM1FkE00`4T`RD19=>gDkL
C]e>g4kMC]a>gDkL@[d2M]801GKAM]9fdWKB00T00P0:00I>oDkLC]a>g5;mC]`2C_`01U;mC]a>oDkL
C_e:g0=:g@08I[IVefJfI]LY^Bfi:KU>g@=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoE;lD_`04Woo0P0037oo000QOol00`00Ool0000IOol07004B]e6_4[MA[a2
_D:lA[eF=EXeEQEJ=F=^HhmSKT[MA[a:gDJlB]e9TTfBBI5=/TVBCI99TTfb10000>]:_4kMB]a>oD[L
K]IZeFkFJ]E^eV[E29A6W4JlAYa>oDkLC_e:g4kmC]a>oD[LM]9b/GKBL[5fdW:aM]92W4JL@Ya>oDkL
D_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4[M;UaZefJf;KTY^2gI:KU>oDkLC_e>g5;mC]aBoDkL
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Oomoo`0:Ool0025o
o`8001Yoo`0800D014[MB[a:_DZlB]e2_@9F=@03FSESKV>?009SS`05Hfi:gD[LB]e:g006BI840000
1T[MB[a:g4ZlB]e:g09:g@E^e@0:19=6_4JLA[a6W4kMC]a>oDkLC]d2B]d01D[LM]9fdWKBL[400WKB
00Y6W4:LAYa6W4kmC]a>o4kLC_e>g09>o006D_e>g4kMC]a>oDkL0S9m00eVefJfI]MV]Rfi:KT]^BVi
D_e>g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0A
Ool2000;Ool000moo`@000Aoo`@000Ioo`03001oogoo01Uoo`0G00@01@0400E6_4[MA[a:gD:lFSEF
=F>?EQEJ=CYK?W`jFdkMB]a>gDVACK99TP030000?4VB@Y`nNd:L?Wa>gD[LC]e:g4[MA[a:gF[EK]IZ
eFkFJ]D8U0AcC]e:g4kMB[a>oDkLC_e>g4kMB]a>gD[LM]9b/GKBL[5fdP0:C]e:_4kMB]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4kmC]a>oDkLJ]MV]VKGI[IZe`9:_02eA[a:gDZlD_e>g5;mC]aBoDkLD_e>o5;m
C]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`03Woo0`0000=oo`00Ool02Woo000>
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol06Woo00E2O4:L@Ya2
W4Zl009:g@06@[eF=F>?ESEJ=EHe0SYL00@nG3YKB]e:g@<00003BI9=TTVB0099TP0;@W`nO49l@Wa>
gD[LC]e:g4[MB]a:g@02K]D04F[EK]D8T`RD19=>g4[LC]e:g4kMC]a>oDkL@[dn_GKBL[400gKB00Ub
/@0:00Y>gD[LC]a:g5;mC]`00Tkl00IBoDkLC_e>o5;mB]`3B]d014[LI]MV]VKG0P001DZl00EBoDkl
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo00Qoo`@0
00Aoo`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03001oogoo00=oo`8001aoo`0??Wa2WCil
@Ya6_4[MA[aJ=EHEFSEF=EXeEQE:gDJl00<0000[BI9=TTVACK99TTfBBI9=/TVB@Y`nNd:L?Wa>gD[L
C_e:g3ZM=We^eV[EK]IZeFkF19<8U0AcC_e>g4kmB]a>oDkLC_e:g4:mL[5fdW:aM]9b/GKB00T00P0:
0<e>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDZlC]e:g4[MI[IZefJfI]LY^2gIC]a>oDkLC_e>g5;m
C]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@06Ool30008
Ool00`00Oomoo`09Ool001=oo`04001oogoo0004Ool00`00Oomoo`02Ool2000NOol014ZlB[e:_4[M
0T:m00=F=EXeESD00UHe0`0000=:_4ZmB[`01TVB00i=TTVBBI8004[MB[a:g4ZlC]e:g4kMB]a^eF[E
0fkE00eZeDJlAYa6_4JLC]e>g4kMC]a>gDkLC]e>g003M]801G:aM]9fdWKB@Y`00TJL00I>oDkLC]a>
g4kmC]`2C_`01U;mC]a>oDkLC_e:g0=:g@08I[IV]fJf;KTY^BfiC]a>g@9>g003D_aBoDkl009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@00
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l0goo0`0037oo00<007oo
Ool027oo000?Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0NOol01dJlB]e6
_4:m@[a6_EHe00<0000>GfiSSem^C]e:g4kMB[a=/TVBCI99TTfbBI9=/P<0003`B]e:_4[MB[a:gDJl
B]e:_6kFJ]E^eV[EK]H4TdJmAYa6_4[LC_e>g4kmB]a>gD[LC]e:g7KBL[5fdW:aM]9b/DJL@Ya6W4:L
D_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_d^G39m;UeVefJfJ]MV]Rfi:KQ>oDkLC_e>g4kmC]aBoDkL
D_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0P003goo00<007oo
Ool027oo000?Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0OOol0
0dZlB[e:_00300002UHeFSEF=EHe>U`nG3YKB]e:g4[M0dVB00A=TTVBBI99TP@00007C]e:g4kMB]a:
gD[LB]d00VkE00eZeFkEK]D8U0RCA[a6W4JlC]a>gDkLC_e>g003B]d0:7:aM]9fdWKBL[9fdP0:C]e:
g4kLB]a>oDkLC_a>g4kmC]a>oDklD_e>g4kMC]a>oC9M<WeV]VKGI[IV]bVi;KTY^DklC]aBoDkLC_aB
o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo11oo`03001o
ogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol087oo
0P0003M6_4:mEQEJ=EHeFSEF5Cil>U/nO3YK?Wa:g4fBBI9=/TVBCI99TTfb001=/Sik@Y`nO4kMB]a>
gD[LB]e6_4[M>We^eVZeK]H4T`RD19=>gD[LC]e>g4kmC]a>oDkLC]e:g4kML[5fdW:aM]9b/@0200X0
5DkMB[a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_eV]V[GI[IVe`020002B[`0]dJlD_e>g5;m
C]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00?
Ool00`00Oomoo`08Ool000moo`D000=oo`@000Eoo`8001ioo`<00005B]e:_4[MB]eJ=@03ESD01EXe
ESE:_4ZlB[d00TZl00=9TT:mBI800TVB00I=TTVBCI99TT9l?W`2@W`014kMB]a>gD[L0SZM0fkE00iZ
eFkE29<8U4[LC]a:g4kMB]a>gDkLC]e>g4:m0WKB00Ab/WKBM]9fdP<02P06C_e>g4kLC]aBoDkL0Tkl
00IBoDkLC_e>g4kmB]`3B]d01FJfI[MV]VKG00001DZl00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo0moo`03001oogoo00Qoo`0087oo00<0
07ooOol06Woo0`0017oo0?m2_D:lA[e2_EXeEQEJ=EHeHhiOKT[MA[a:gDJlCK8nWDfBBI9=/TVB0019
TTfcBI9:gDZlB]e:_4kMB]a>oCYm>YeZ]FkFJ]E^eVZe29@4T`RDB]a>oDkLC_e:g4kmC]a>oD[LM]9b
/GKBL[5fdW:aAYa2W4JL@Ya>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDZlB]e:g6KGI[IZefJf;KTY
^4kmC]a>oDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_d000aBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d>Ool00`00Oomoo`08Ool0021oo`03001oogoo01Moo`<000Qoo`=2_@0>ESEJ
=EHeESEOKV>>GfiSKTZlB[e:_4:mBI9=TP99TP0<001=/TVBCI8004[MB[a:g4ZlC]e:g4kM0VkE00eZ
eFkEK]E^e@RCA[a6W4JlC]a>gDkLC]e>g003B]d01D[LM]9fdWKBL[800WKB14JL00I>oDkLC_a>g5;m
C]`2C_`01TkmC]a>oDkLB]e:g09:g@06I]MV]VJgI[H]^BVi0TkL00E>gDkLC]aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`0
0`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00eoo`03001o
ogoo00Qoo`007goo00<007ooOol05Goo0`003Goo01A2_5XeESEJ=Em^FSEF=Cil>U/nO4[LC]dnW4fb
BI9=/TVBCK=9TTfb0`000?=>gD[LC]e:g4[MA[a:gF[EK]IZ]FkFJ]D8U4JLA[e6W4JlAYa>oDkLC_e>
g4kMB]a>gG:aM]9b/GKBL[5fdP0:C]e:_4kMB]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]`bOBiLJ]MV
]VKGI[IZebVi;KTY^5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d03Goo00<007ooOol01goo000OOol2000COol3000AOol014:m
ESEF=EXe0UHe00HjG3iL>U/nG4[L@[d3BI801TfBBI9=TTVBCK8nO092O007C]e:g4kMB]a:gD[LB]d0
0VkE00eZeFkE29<8U4[LC]a:g4kMB]a>gDkLC_e>g003B]d01G:bM]9fdWKBL[800P0:01E>gD[LC]a:
g4kmC]a>o4kLD_e>g4kmC_a>oDkLC]e>g6KGI[IV]fJfI]L00P000dZl00M>o4kLD_e>g4klD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0<
Ool00`00Oomoo`07Ool001moo`03001oogoo00moo`<001Aoo`1?@[eF5F>?ESEJ=EHEFSE6_4[MA[a:
gDZlCI99TTfb001=/TVBCK=9TT:L?W]2W3ilC]e:g4kmB]`jWCIm>YeZeFkFJ[E^ePRC29A:_4kMB]a>
gDZlC_e>g4kmB]a2_G:aM]9b/GKBL[5fdP0:00/02TkmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MB[a:
gD[LI]MV]V[GI[H]f@00B]d00TZl0;U6_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00aoo`03001oogoo00Moo`007goo00<007oo
Ool037oo0`0067oo00EJ=EHeESEF=EXe009OKP0GB[a:_DZlB]e9TTfBBI8004VBCK99TTfBBI9:gDZl
B]a:_4kMB]a>gD[L>YeZe@03K]D03F[E29@8T`RDC]a>gDkLC]e>g4kMC]a>gDkL00=fdP03L[9fdWKB
00A6W006C_e>g4kLC_aBoDkL0Tkl00i>oDkLC_e>g4[MB]a:gFJfI]MV]VJgI[H]^BVi0TkL00I>gDkL
D_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00=BoE;lOol02Woo00<007ooOol01goo000OOol00`00Oomoo`09Ool3000KOol0oeHeFSEF5EXe
ESESKUm]Hhi6_4[MA[a2_DVBCK99TTfcBI9=/TVBCK<004[MB[a:gDZlC]e:g4kmB]a^eVZeK]IZeFkF
29=6_DJLA[a:g4kmC]a>oD[LC]e:g4kMB]afdW:aM]9b/GKBL[56W4:KAYa>g4kmC]aBoDkLD_e>g5;m
C]aBoDkLD_e>g4[MB[a:gBiMI]MV]V[G:KT]fBVhC_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo00035;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Yoo`03001oogoo
00Moo`007goo0P0027oo0P007goo00=F=EXeESD00Woo00HnG3YK?Ua:g4[MB]`2BI801DfbBI9=TTVB
CK800`0000I>gD[LC]e:g4[MB]`2B]d00fkEJ]E^e@02K]D02DJLA[a6W4JlAYa>gDkLC_e>g003B]d0
1g:bM]9fdWKBL[9fdP0:00=6W003C]a>oDkL009>o00?D_e>g4klC_a>oDkLC]e>g39m;UeV]fJfI]MV
]VJg008]^@05:KU>o4kLD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`08Ool00`00Oomoo`07Ool001ioo`03001oogoo
00Eoo`<0025oo`03FSEF=EXe009oo`18>U/nO3YKC]e:g4kMBI8004VBCK99TTfcBI9=/Sik@Y`nO4kM
B]a>gD[LB]e6_4[MJ]E^eVZeK]IZe@RDB[a>gD[LC]e:_4kmC]a>oDkLC]e:g4kML[5fdW:aM]9b/@0;
00Y>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g6KGI[IZefJfI]MV]T[M0TZl0;a6_5;mC]aB
oDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m2Woo00<007ooOol01Woo000NOol00`00Oomoo`02Ool3000TOol2ESD4Ool00cYL?U`j
F`02B]d02TfB@[e=TTVBCK99TTfBBI92O3il0T9l00M>gD[LC]e:g4[MB]a:g@02K]D03V[EK]D8U0RD
B]a>g4[LC]e:g4kMC]a>gDkL@[d2M]8017:bM]9fdWKB0`0:00I>gD[LC]a>o5;mC]`2C_`01U;mC]a>
oDklB]e:g09:g@04I]MV]VJgI[H20004B[`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0Yoo`03001oogoo00Ioo`007Woo00<0
07oo00000P00:7oo00=F5GooOol00goo0?m6_4[MA[a:gDVB@[e9TTfcBI9=/TVBCK=9TT[MB[a:gDZl
C]e:g4kmB]`jWCImK]IZeFkFJ[D8]0RC29@8TdkmC]a>oD[LC_e>g4kmB]afdW:aM]9b/GKBL[56W4:K
AYa2W4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MB[a:gFJfI]MV]V[G:KT]fBVhC_e>g4kmC]aBoDkL
D_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`000IB
oE;lD_eBo5;mD_`9Ool00`00Oomoo`06Ool001ioo`<0035oo`0GB[a:_DZlBI92_DfbBI9=TTVBCK99
TTfb001:gDZlB]a:_4[MB]a>gD[LK]EZe@03K]D02@RCA[a6W4JlAYa>gDkLC]e>g003B]d01d[LM]9f
dWKBL[9fdW;B00=6W007C]a>oDkLC]a>o5;mC]`00Tkl00Y>oDkLC_e>g4[MB]a:gC9MI]MV]P<]^@05
:KU>g4kLC]e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo0Qoo`03001oogoo00Ioo`0017oo1@000goo100017oo10001goo
00<007ooOol0<Goo00Y:g4kMB[a2_DVBCK99TTfcBI9=/P<0003hC]e:g4kMB]a>gDJlB]e:_6kFJ[E^
eV[EK]I6W4JmAYa6_4JLC_e>g4kmC]a>gD[LC]eb/GKBL[9fdW:aM]802TJL@Y]6W4kLD_e>g5;mC]aB
oDkLD_e>g4kmC]a>oDkL<Wd^GF[GI[IVefJf;MTY^BgI:KQBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Moo`03
001oogoo00Ioo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
00Eoo`80039oo`0;B]a:gD:mCI99TTfbBI9=/TVBCK8nO002@W`01dkMB]a>gD[LB]e:g4[M009^e@0=
J]E^eF[E29A:g4kLB]a>gD[LC]e>g4kmC]`00d[M00Ub/WKBL]9fdW:b00/02TkMB]`00TkL015>oDkL
C_a>o5;mC]a>oDklC_e>g4kMC]aVefJfI[MV]VKG00E:_004C_a>g5;mC]`2D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo0Moo`03
001oogoo00Ioo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
00Moo`03001oogoo031oo`10B[a2_DVBCK=9TTfbBI9=/dVB@Y`nNd:L?Wa2W4[LC]e:g4[MA[a:gF[E
K]IZ]FkF29<8]4ZlC]e:g4kMB[a>oDkLC_e:g4:mL[9fdW:aM]9b/WKB00X02d[LC]e:_4kMC]aBoDkL
D_e>g5;mC]aBoDkLB]e:_4[MB]aVefJfJ]L20000`TJlB]e:_4ZlA[aBoDkLD_e>g5;mC_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d6
Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`08Ool00`00Oomoo`0`Ool04D[MCK99TTfBBI9=/TVBCK99TT[MB[a:g4ZlB]e:g4kMB]`00SZM
00A^eF[EK]EZe@<8U00D29=>gDkLC]e>g4kMC]a>gCjMM]9bdWKBL[9fdW;B00/02P0;C]a>o@9>g00@
C_aBoDkLC_a>g4kmC]a>oDkLB]e:g4[MI[IVefJfI[L2;KT3C]`01TkMC]aBo5;lD_e>o09Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
0e;mD_aoo`06Ool00`00Oomoo`05Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`09Ool00`00Oomoo`0`Ool0odVBCK99TTfcBI9=/dVBCK<004[MB[a:gDZlB]e:
g4kmB]a^eVZeK]IZeFkFJ[E6_DJLA[a6W4kmC]a>oD[LC_e>g4kmL[5fdW:bM]9b/GKBL[96W4:KAYa>
g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MB[a:gBiMI]MV]RgI:KT]fDkLC_e>g4kmC]aBoDkLD_e>
g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o00015;mD_aBoE;l1Woo00<007ooOol01Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`0017oo00<007ooOol02Woo0P00<7oo00Q2_DVBCK99TTfbBI9=/TVB0`0000E:g4kMB]a>gD[L
009:g@0>K]EZeFkEJ]E^e@RCA[a6W4JlAYa>gDkLC_e>g0=:g@07L[9fdW:bM]9b/WKB00/00dJL00=>
g4kmC]`00Tkl00iBoDkLC_a>g4kmC]a>gDkL<Wd^GFJgI[IVefJf0bfi00E>g4klC]aBoDkL009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lOol017oo00<007ooOol01Goo0004Ool30004Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol037oo00<007ooOol0;Goo048nW4fcBI9=/TVBCK=9TP00BI92W3il@Ya:g4kM
B]a:gDJlB]eZeFkFJ[E^eV[E3;@8TdkMB]a>gDZlC_e>g4kmC]a>gD[LC]eb/GKBL[9fdW:a00/02TkM
B[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLI]MV]VKGI[IVedJlB]d2B[`0`DkLD_e>g5;mC]aB
oDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l00Aoo`03001oogoo00Eoo`001Woo00<007ooOol00goo100017oo100047oo
00<007ooOol0;7oo00Y2_DVBCK99TTfbBI9=/P00CK8nO0=2O00MB]a>gD[LB]e:g4[MJ]E^eF[EK]EZ
e@Rd29=>g4[LC]e:g4kMC]a>gDkL@[eb/WKBL[9fdW:bM]802P0200/01TkMB]a>g4klD_e>g09>o003
D_e>g4km009:g@08B]a:gD[MI]MV]VJgI[H000A:_005C_aBo5;lD_e>o002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eo
ogoo009oo`03001oogoo00Eoo`00:Goo00<007ooOol0;7oo0?m=/TVBCK=9TTfcBI9=/dVBCK=:_4[M
B[a:gD[LC_e:g3ZM=We^eV[EK]IZ]FkF29<<]0RCC_e>g4kmB]a>oDkLC_e:g7KBL[9fdW:aM]9b/TJL
@Y]6W4:LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LB]e:_4[MI[IVefJfI]LY^BgIC]a>oDkLC_e>g5;m
C]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d000IBo5;mD_aBoE;lD_d3Ool00`00Oomoo`05Ool002Yoo`03001oogoo02]oo`07BI9=
/TVBCK99TTfbBI800Tfb01H004ZlB]a:_4[MB]a>gD[LK]EZeFkEJ]E^eF[E2;A6W4JlAYa>gDkLC]e>
g0=:g@07B]afdW:bM]9b/WKB00/014JL01=>oDkLC]a>o5;mC]a>o4kLC_e>g4kmC]a:gD[LB]eV]VKG
I[IV]`02;KT3C]`01DkMD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`3Ool00`00Oomoo`05Ool002]oo`8002ao
o`07BI9=/TVBCK<004fcBI800`000?]:g4kMB]a>gDJlB]e:_6kFJ[E^eVZeK]H8TdJmAYa6_4JLC_e>
g4kmC]a>gD[LC]eb/GKBL[9fdW:a00/02TkMB[a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL<WeV
]VKGI[IVefJf;MTY^BgIC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00=oo`03001oogoo00Ao
o`00;Goo00<007ooOol0:Goo00E=/TVBCK99TP00009=/P0IOom2O49l@Wa:g4kMB]a>gD[LB]eZeFkE
J]E^eF[E3;@8U4kLB]a>gD[LC]e>g4kmC]`00d[M00Ab/WKBL[9fdP<02`06C]e:g4kLB]a>oDkL0Tkl
00aBoDkLC_e>g4kmC]a>gFJfI]MV]VJgI[H20003B[`014kLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;l
D_aBo09oo`03001oogoo00Aoo`00;Woo00<007ooOol0:7oo0499TTfcBI9=/dVBCK=9TWoo?W]2W3il
@Ya:g4kmB]a>gCIm>YeZ]FkFJ[E^eVZe3;@8TdkMB]a>gDZlC_e>g4kmB]a2_G:bM]9b/GKBL[802`0:
00/02TkmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4[MB[a:gFJfI]MV]VKGI[H004JlB]d2B[`0aDkLD_e>
g5;mC]aBoDklD_e>o5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo7oo00001Woo000_Ool00`00Oomoo`0WOol01dfb@[e=/TVB
CK99TTfb009oo`07B[a:g4ZlB]e:g4kMB]`00SZM01E^eF[EK]EZeFkE29@<]0RDC]e>g4kMC]a>gDkL
C]e>g7KBL[9fdW:bM]801DJL00]>oDkLC]a>g5;mC]a>o4kLC_e>g4km009:g@06B]aV]fJfI[MV]VJg
0Rfi0dkL00E>gDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lOol00006Ool0031oo`8002Moo`06
BI92_DVBCK=9TTfc17oo0?m:_4[MB[a:gD[LC_e:g6kFJ[E^eVZeK]IZ]@bdAYa6_4JLC_e>g4kmB]a>
gD[LC]e:g7KBL[9fdW:bM]92W4JL@Y]6W4:LD_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LB]e:_39mI[IV
efJfI]LY^BgIC]a>oDkLC_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
05;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00001Woo000bOol00`00
Oomoo`0UOol00d:mCK800002CK85Ool01D[LC]e:g4kMB]`00T[M00i^eF[EK]EZeFkE29@<]4JLA[a6
W4kMC]a>oDkL0d[M01eb/WKBL[9fdW:b00]:g4kMB]a>g4[LC_e>g4klC]aBoDkLC_e>o4kmC]a>gBiM
<WeV]VJgI[IV]fJf00<]^@04C]a>o4kLD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00=oo`03001oogoo00Ao
o`00<goo00<007ooOol097oo00E2_DVBCK=9TTfc00Ioo`0cB]a>gD[LC]e6_4[MB[a^eVZeK]IZ]@bd
29<<]4[LC]e:_4kmC]a>oDkLC]e:g4kML[9fdW:bM]802P0;B]a>gDZlC]e:g5;mC]aBoDkLD_e>g5;m
C]a>oDkLC_eV]VKGI[IVefJf00800030B]e:_4ZlC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l27oo00<007ooOol0
0goo000dOol00`00Oomoo`0SOol01D:mCK9=/TfbBI801goo00A:g4kMB]a>g@8jW@0EJ]E^eF[EK]EZ
e@bd29@<]4[LC]e:g4kMC]a>gDkL@[eb/WKBL[9bdW:b00@02`06C_e>g4kLC]aBoDkL0Tkl00]>oDkL
C_e>g4[MB]a:gFJfI[MV]VJg008]^@A:_004C_aBo5;lD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00=BoGooOol02Woo00<007ooOol00goo000eOol2
000TOol00dVBCK=9TP09Ool0k4[LC_e:g4kMJ[E^eVZeK]IZ]FkFAYa6_4JLA[e>g4kmB]a>oDkLC_e:
g7KBL[9fdW:bM]9b/TJL@Y]6W4:LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e:_6KGI[IVefJf;MT]
^BgIC]a>oDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_d?Ool00`00Oomoo`03Ool003Moo`03001oogoo025oo`030019TTfb00Yoo`0AB]a:
gD[MB]eZeFkEJ]E^eF[E3;A6W4JlAYa6_4kLC]e>g003B]d01T[LL]9b/WKBL[9bdPE6W006C_e>g4kl
C]aBoDkL0Tkl00Y>oDkLC]e>g39m;UeV]fJfI[MV]P<]^@=>g005C]eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00Oomoo`0AOol00`00Oomoo`03Ool003Qoo`03
001oogoo025oo`03CK=9TWoo00Yoo`0bA[a:gDZlK]IZ]FkFJ[E^ePRC3;A:g4kMB[a>gDkLC_e>g4kM
B]a>gG:bM]9b/WKBL[8034[LC]e:_4kMB]aBoDkLD_e>g5;mC]aBoDkLC_e>g4km;UdbOFJfI]MV]VKG
B[a:g@9:_02_C]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
0goo00<007ooOol047oo00<007ooOol00goo000iOol00`00Oomoo`0POol00dfbOomoo`0;Ool03D[L
B]e:gFkEJ]E^eF[EK]D8U0bdB]a>gD[L009>g003C_e>g4[M009:g@04L[9bdW:bM]8200/01d[LC]e:
g4kLB]aBoDkL009>o00;D_e>g4kmC_a>oDkLC]eV]VJgI[IV]`020004B[`01DklD_aBo5;mC_`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo008Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003Yo
o`80021oo`03CK=oogoo00aoo`0G=WdjWFZeK]IZ]FkFJ[D<]0RC3;A>g4kmB]a>oDkLC_e:g4:mL[9f
dW:bM]9b/P0200/0`@0<C]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDZlB]eV]VKGI[IVebfi;MU>
g4kmC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00]oo`03001oogoo00moo`03001o
ogoo00=oo`00?7oo00<007ooOol07Goo00=9TWooOol03Goo01MZeFkEJ]E^eF[EOol<]4JlAYa6_4kL
C]e>g4kMC]a>gDkLL]9b/WKBL[9bdW:b00=6W003C]a>oDkL009>g00>D_e>g4klC_a>oDkLC_e>g4[M
B]aV]fJfI[MV]P<]^@=>g005C]eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol03goo00<007ooOol03goo
00<007ooOol00Woo000mOol00`00Oomoo`0LOol00dfcOomoo`0>Ool00fZeK]IZ]@02Ool0c0bdAYa6
_4JLA[e>g4kmC]a>oD[LC]e:g7KBL[9fdW:bM]802dJL@Y]6W4kLD_e>g5;mC]aBoDkLD_e>g4kmC]a>
oDkL<Wd^GFKGI[IVefJf;MT]^BgIC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00ioo`03
001oogoo009oo`00?Woo00<007ooOol0;7oo00=^eF[EOol00Woo0Pbd00=:g4kMB]`00TkL00=>oDkL
C]d00T[M00E:g7;BL[9fdW:b00802`06C]e:g4kLC]a>oDkL0Tkl00eBoDkLC_e>o4kmC]a>gDkLI[MV
]VJgI[IV]`04B[`014kLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Uoo`03001oogoo00eoo`03001oogoo009oo`00?goo00<0
07ooOol0<Goo02X8T`bdB]a>gDZlC]e>g4kmB]a>oCjMM]9b/WKBL[9fdP0;00`02dkMB[a>gDkLD_e>
g5;mC]aBoDkLD_e>g4[MB[a:gD[LI]MV]VKGI[H004ZlB]d2B[`0V4kLD_e>g5;mC]aBoDklD_e>o5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dLOol00`00Oomoo`0=Ool0
0`00Oomoo`02Ool0041oo`80035oo`<<]00=C]a>gDkLC]e>g4kMC]a>gG:bM]9b/W;BL[8014JL01E>
oDkLC]a>g5;mC]a>o4kLC_e>g4kmC]a:gD[LB]eV]VJgI[IV]bfi;MT00dkL00E>gDklD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m021oo`03001oogoo00ao
o`03001oogoo009oo`00@Woo00<007ooOol0;goo0;a6_4JLA[e>g4kmB]a>oD[LC]e:g4kML[9fdW:b
M]=b/TJL@Y]6W4:LD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e:_4[MI[IVefJfI]L]^BgIC]a>oDkL
C_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l9Goo00<007ooOol0
2goo00<007ooOol00Woo0013Ool00`00Oomoo`0_Ool01dJlAYa6_4kLC_e>g4kM009:g@0MB]abdW:b
M]9b/W;B00]>gD[LC]a:g4kmC]a>o4kLD_e>g4kmC_a>oDkLC]e>g39mI[IV]fJfI[MV]P02;KT01BgI
C]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`XOol00`00Oomoo`0;Ool0
0`00Oomoo`02Ool004Aoo`03001oogoo02moo`0TC]e:_4kMC]a>oDkLC_e:g4kMB]afdg:bM]9b/P0<
00]>gDZlC]e:g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_eV]VKGI[IVefJf0P0008e:gDZlB[a:_5;mC]aB
oDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0;Goo00<007ooOol02goo00<007ooOol00Goo0015
Ool2000`Ool03DkMB]a>g4kLC]e>g4kM?[efdW:bL]9b/WKB00<02`06C_e>g4kLC]aBoDkL0Tkl00e>
oDkLC_e>g4[MB]a:gFJfI[MV]VJg;KT]f@03C]`01TkMC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02
D_`aOol00`00Oomoo`0:Ool00`00Oomoo`01Ool004Moo`03001oogoo02ioo`2[C_e:g4kmC]a>oD[L
C_eb/WKBL[9fdg:bM]92VdJL@Ya>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDZlI]MV]VKGI[H]fBfi
;MU>g4kmC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m03Eoo`03001oogoo00Uoo`03001oogoo005oo`00
B7oo00<007ooOol0;Woo00e>oDkLC]e>g4[MB]a:gG:bM]9b/W;BL[803003AY`01TkmC]a>o4kLD_e>
g09>o00:C_e>g4kMC]`bOBiMI[MV]VJgI[H2;KT01BgIC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0>7oo00<0
07ooOol02Goo00<007ooOol00Goo0019Ool00`00Oomoo`0^Ool08dkmC]a>oDkLC]e:g4kML[9fdW:b
M]<02`0<B[a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLI]MV]VKGI[IVedZlB]d00TZl07e>g5;m
C]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l03eoo`03001oogoo00Qoo`03001oogoo005oo`00BWoo0P00;goo00i>gDkLC]e>g4:mL[9b
dW:bL]9b/P0<00/034[L0TkL00YBoDkLC_a>o5;mC]a>oDklB]e:g09:g@05I[MV]VJgI[H00004B[`0
14klD_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
D_aoo`10Ool00`00Oomoo`07Ool00`00Oomoo`01Ool004aoo`03001oogoo02eoo`2IC_e:g4kmC]af
dW:bM]=b/WKBL[96W4:LAYa>g5;mC]a>oDkLD_e>g5;mC]aBoDkLB]e:_4[MI[IVef:fI]L]^BgIC]a>
oDkLC_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m04Io
o`03001oogoo00Ioo`03001oogoo005oo`00CGoo00<007ooOol0;Goo00U:gD[LB]e:gG;BL[9bdW:b
L]8014JL00E>g4klC]a>oDkL009>o00=D_e>g4kmC]a:gD[LB]eV]VJgI[IV]bfi;MT00dkL00E>gE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`17Ool00`00Oomoo`07
Ool10001Ool1Ool004ioo`03001oogoo02eoo`2AC]e:g4kML[9fdW:bM]=b/P0<B[a>gD[LC]e>g5;m
C]aBoDkLD_e>g5;mC]a>oDkL<Wd^GFKGI[IV]f:f;MT]^BgIC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;m
C]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d0CGoo00<007ooOol01Woo0@000Goo0Goo001?Ool2000^Ool01D[M
B]a:gG:bL]800W:b0P0<00E:g4kLC]a>gDkL009>o00<D_e>g4kmC_aBoDkLC]e>g6JgI[IV]fJf0P00
14Zl0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo59oo`03001oogoo00Eoo`40005oo`5oo`00
DGoo00<007ooOol0;7oo08Q2_G:bM]=b/WKBL[80300;00a>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e:
_4[MB]aV]f:fI]MV]RgI;KQ>oDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5Eoo`03001oogoo
00Eoo`40005oo`5oo`00DWoo00<007ooOol0;7oo00AbdW:bL[9b/P9oo`A6W09>g00BC_e>g4klC_aB
oDkLC_e>g4kmB]a:gFJfI[MV]VJg;KT]fBfi0TkL00E>gDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo5Uoo`03001o
ogoo00Aoo`40005oo`5oo`00Dgoo00<007ooOol0;7oo00=fdW:bOol00Woo07/02dkMB]a>gDZlD_e>
g5;mC]aBoDkLD_e:g4kmC]a>oBiM<WeV]VJgH[IVebfi;MT]^5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>
g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0GGoo00<0
07ooOol00goo0@000Goo0Goo001DOol00`00Oomoo`0`Ool200`2C]`04DkMB]a>o4klD_e>g4kmC_aB
oDkLC]e>g4kmI[IV]fJfI[L00P000dZl00A>o4kLD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lHWoo00<007ooOol00goo0@000Goo001EOol2
000`Ool0600;00`02e;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4[MB]aV]f:fI]MV]RgI;KQ:g@9:_01G
C]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l06Qoo`03
001oogoo00=oo`40005oo`00Egoo00<007ooOol0;Woo0dJL0TkL00Y>oDkLC_a>o5;mC]a>oDkLC_e:
g09:g@06I[MV]VJg;KT]fBfi0TkL00E>gDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o004D_eBo5;lD_a/Ool00`00Oomoo`02Ool10001Ool005Qoo`03001oogoo02eoo`1YAYa2W4JLC]aB
oDkLD_e>g5;mC]aBoD[LC_e>g4km;UdbOFJfI[MR]VKG;KT]fBfhD_e>g5;mC]aBoDkLD_e>g5;mD_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m075oo`05001oogooOol00001Ool005Uoo`03001oogoo02eoo`9>
g00BC]e>g4klC]a>oDkLC_e>o5;mC]a>gDkLC_eV]VJgI[IV]fJf14Zl00A>o4kLD_e>g09Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m009Bo7Eoo`04001oogoo0001Ool005Yoo`8002ioo`0EC]e:g4kMC]aBoDkL
D_e>g5;mC]aBoDZlB]e:g4[MH[IVefJfI[L004[M00=:_019D_e>g5;mC]aBoDklD_e>g5;mD_aBoDkl
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d0N7oo00@007ooOol0005oo`00G7oo00<007ooOol0;7oo0TkL00Y>oDkLC_a>o5;mC]a>oDkLC_e:
g09:g@06I[MV]VJgI[H]fBfi0TkL00I>gDkLD_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo7aoo`03001oo`00005o
o`00GGoo00<007ooOol0;7oo05UBoDkLD_e>g5;mC]aBoDkLD_e>g5;mB[a:gD[LI[MR]VKGI[H]fBfh
<MU>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m081oo`40005oo`400000GWoo00<007ooOol0;7oo015>o4kLC_e>g4km
C_aBoDkLC]e>g4kmC]aV]fJfI[MV]VJg00A:_006C]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo8Aoo`800000Ggoo0P00;Goo015BoDkL
D_e>g5;mC]aBoDkLB]e:g4[MB[aVefJfI[L]^00000=:_00lB]e>g5;mC]aBoDklD_e>g5;mD_aBoDkl
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lR7oo0P00001QOol00`00Oomoo`0/Ool0
1dklD_e>g4kmC]a>oDkL00=:g@04I[IV]fJfI[L2;KT01dkLC]e>g4kLD_aBoDkl009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo08Yoo`800000HWoo00<007ooOol0;7oo
04A>g5;mC]aBoDkLD_e>g4[MB]a:gF:fI]MV]RgI;KPafDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mSGoo10000Woo001SOol00`00Oomoo`0/Ool034klD_e>g4kmC]a>oDkL
;Wd^GFJgI[IV]`A:_006C]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b<Ool40006Ool0
06Aoo`8002eoo`0<C]aBoDkLD_e>g4kmB]aVefJfI[MR]P000dZl02e:gDkLD_e>g5;mC_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d0Rgoo10002Woo001VOol00`00Oomoo`0[Ool014kLC_e>g4km0T[M00Q:g6JgI[IV
]bfi;MU>g4kM0TkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Yoo`@000ioo`00Igoo00<007ooOol0
:goo03A>g5;mC]a:gD[LB]eR]VKGI[IV]bfh<MU>g4kmC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoHYoo`<0019oo`00
J7oo00<007ooOol0:goo019>g4kmC]`^OBiMI[MV]VJgI[H]fBfi;MU>g5;mC]a>o4kLD_d3D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo029Ool4000E
Ool006Uoo`8002aoo`09C]a>oD[LI]MV]VJgH[IV]`00009:_00QB]e:_5;mC]aBoDkLD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m08Qoo`@001Uoo`00Jgoo
00<007ooOol0:Woo0T[M00Q:g6JgI[IV]fJf;MT]^DkM0dkL00EBoDklD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;lRWoo10007Goo001/Ool00`00Oomoo`0ZOol08D[LB]e:_6Jg
I[IV]f:f<MT]^DkmC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo029
Ool4000QOol006eoo`03001oogoo02Yoo`0>;Ud^OFJfI[MV]VJg;KT]fBfiD_e>g4klC]aBo@=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;lRGoo0`009Goo001^Ool00`00Oomoo`0ZOol06FJfI[MR]VJg
;KT004ZlB]e:_5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;l08Qoo`@002Qoo`00Kgoo0P00
:goo00IV]VJgOomoobfiC]d3C]`01E;mC_aBo5;lD_d00e;l00ABoE;lD_aBo8Moo`@002aoo`00LGoo
00<007ooOol0;7oo00hafBfi<MU>g4kmC]aBoDkLD_e>g5;mC]aBoE;lQWoo1000<7oo001bOol00`00
Oomoo`0[Ool4B[`014kLC_a>g5;m0e;lQGoo1000=7oo001cOol00`00Oomoo`0[Ool014ZlB]e:_4Zl
Qgoo1000>7oo001dOol2000/Ool00`00Oomoo`24Ool3000lOol007Ioo`03001oogoo02Uoo`03001o
ogoo081oo`@003moo`00Mgoo00<007ooOol0:7oo00<007ooOol0O7oo1000@goo001hOol00`00Oomo
o`0WOol00`00Oomoo`1hOol40017Ool007Uoo`8002Moo`03001oogoo07Aoo`@004]oo`00Ngoo00<0
07ooOol097oo00<007ooOol0LGoo0`00Cgoo001lOol00`00Oomoo`0SOol00`00Oomoo`1]Ool4001B
Ool007eoo`03001oogoo029oo`03001oogoo06Uoo`@005Ioo`00OWoo0P008Woo00<007ooOol0IGoo
1000FWoo0020Ool00`00Oomoo`0OOol00`00Oomoo`1QOol4001NOol0085oo`03001oogoo01ioo`03
001oogoo05ioo`<0069oo`00PWoo00<007ooOol07Goo00<007ooOol0FWoo1000IGoo0023Ool00`00
Oomoo`0LOol00`00Oomoo`1FOol4001YOol008Aoo`8001aoo`03001oogoo059oo`@006eoo`00QWoo
00<007ooOol06Goo00<007ooOol0CWoo1000LGoo0027Ool00`00Oomoo`0HOol00`00Oomoo`1;Ool3
001eOol008Qoo`03001oogoo01Moo`03001oogoo04Moo`@007Qoo`00RGoo0P005goo00<007ooOol0
@goo1000O7oo002;Ool00`00Oomoo`0DOol00`00Oomoo`0oOol40020Ool008aoo`03001oogoo019o
o`03001oogoo03aoo`@008Aoo`00SGoo00<007ooOol04Goo00<007ooOol0>Goo0`00R7oo002>Ool2
000AOol00`00Oomoo`0eOol4002;Ool0091oo`03001oogoo00ioo`03001oogoo035oo`@008moo`00
TGoo00<007ooOol03Goo00<007ooOol0;Goo1000Tgoo002BOol00`00Oomoo`0<Ool00`00Oomoo`0Y
Ool4002GOol009=oo`8000aoo`03001oogoo02Eoo`@009]oo`00UGoo00<007ooOol02Goo00<007oo
Ool08Woo0`00Wgoo002FOol00`00Oomoo`08Ool00`00Oomoo`0NOol4002ROol009Moo`03001oogoo
00Moo`03001oogoo01Yoo`@00:Ioo`00V7oo00<007ooOol01Woo00<007ooOol05Woo1000ZWoo002I
Ool20006Ool00`00Oomoo`0BOol4002^Ool009]oo`03001oogoo00=oo`03001oogoo00moo`<00;9o
o`00W7oo00<007ooOol00Woo00<007ooOol02goo1000]Goo002MOol01@00Oomoogoo00002Goo1000
^Goo002NOol200000goo001oo`04Ool4002mOol00:1oo`800003Ool0000000800<5oo`00XGoo0P00
aGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.516 .286 .505 r
.39622 .70103 .40387 .63964 .41065 .69812 .4054 .69189 Mtetra
.566 .663 .903 r
.4054 .69189 .41065 .69812 .41958 .69642 .4143 .69146 Mtetra
.637 .735 .919 r
.4143 .69146 .41958 .69642 .42855 .69416 .42328 .68936 Mtetra
.648 .745 .92 r
.42328 .68936 .42855 .69416 .43756 .69174 .43231 .68698 Mtetra
.653 .749 .92 r
.43231 .68698 .43756 .69174 .4466 .68922 .44137 .68448 Mtetra
.656 .751 .92 r
.44137 .68448 .4466 .68922 .45567 .68665 .45046 .68192 Mtetra
.657 .752 .92 r
.45046 .68192 .45567 .68665 .46478 .68403 .45958 .6793 Mtetra
.658 .753 .92 r
.45958 .6793 .46478 .68403 .47391 .68138 .46873 .67664 Mtetra
.659 .754 .92 r
.46873 .67664 .47391 .68138 .48307 .67872 .47792 .67397 Mtetra
.47792 .67397 .48307 .67872 .49227 .67605 .48713 .67128 Mtetra
.48713 .67128 .49227 .67605 .50149 .67338 .49638 .66859 Mtetra
.49638 .66859 .50149 .67338 .51075 .67071 .50566 .6659 Mtetra
.658 .753 .92 r
.50566 .6659 .51075 .67071 .52004 .66803 .51496 .6632 Mtetra
.51496 .6632 .52004 .66803 .52936 .66535 .5243 .6605 Mtetra
.5243 .6605 .52936 .66535 .53871 .66266 .53367 .6578 Mtetra
.53367 .6578 .53871 .66266 .54809 .65997 .54308 .65509 Mtetra
.54308 .65509 .54809 .65997 .5575 .65727 .55251 .65237 Mtetra
.55251 .65237 .5575 .65727 .56694 .65457 .56198 .64965 Mtetra
.657 .753 .92 r
.56198 .64965 .56694 .65457 .57642 .65185 .57147 .64691 Mtetra
.57147 .64691 .57642 .65185 .58593 .64913 .58101 .64418 Mtetra
.58101 .64418 .58593 .64913 .59547 .6464 .59057 .64143 Mtetra
.657 .752 .92 r
.59057 .64143 .59547 .6464 .60505 .64367 .60017 .63867 Mtetra
.60017 .63867 .60505 .64367 .61466 .64092 .6098 .63591 Mtetra
.6098 .63591 .61466 .64092 .6243 .63817 .61946 .63314 Mtetra
.61946 .63314 .6243 .63817 .63397 .63541 .62915 .63036 Mtetra
.62915 .63036 .63397 .63541 .64368 .63264 .63888 .62757 Mtetra
.63888 .62757 .64368 .63264 .65342 .62986 .64865 .62477 Mtetra
.64865 .62477 .65342 .62986 .66319 .62707 .65844 .62197 Mtetra
.65844 .62197 .66319 .62707 .673 .62427 .66828 .61915 Mtetra
.66828 .61915 .673 .62427 .68284 .62146 .67814 .61633 Mtetra
.67814 .61633 .68284 .62146 .69272 .61865 .68804 .61349 Mtetra
.68804 .61349 .69272 .61865 .70263 .61582 .69798 .61065 Mtetra
.69798 .61065 .70263 .61582 .71257 .61299 .70794 .6078 Mtetra
.70794 .6078 .71257 .61299 .72255 .61015 .71795 .60494 Mtetra
.71795 .60494 .72255 .61015 .73257 .60729 .72799 .60206 Mtetra
.72799 .60206 .73257 .60729 .74262 .60443 .73806 .59918 Mtetra
.73806 .59918 .74262 .60443 .7527 .60156 .74817 .59629 Mtetra
.74817 .59629 .7527 .60156 .76282 .59868 .75832 .59339 Mtetra
.75832 .59339 .76282 .59868 .77298 .59579 .7685 .59048 Mtetra
.7685 .59048 .77298 .59579 .78317 .59288 .77872 .58756 Mtetra
.77872 .58756 .78317 .59288 .7934 .58997 .78897 .58463 Mtetra
.78897 .58463 .7934 .58997 .80366 .58705 .79926 .58169 Mtetra
.79926 .58169 .80366 .58705 .81396 .58412 .80959 .57874 Mtetra
.80959 .57874 .81396 .58412 .8243 .58118 .81996 .57578 Mtetra
.81996 .57578 .8243 .58118 .83468 .57823 .83036 .5728 Mtetra
.83036 .5728 .83468 .57823 .84509 .57526 .8408 .56982 Mtetra
.8408 .56982 .84509 .57526 .85554 .57229 .85127 .56683 Mtetra
.85127 .56683 .85554 .57229 .86603 .56931 .86179 .56383 Mtetra
.86179 .56383 .86603 .56931 .87655 .56632 .87234 .56082 Mtetra
.87234 .56082 .87655 .56632 .88711 .56331 .88293 .55779 Mtetra
.88293 .55779 .88711 .56331 .89771 .5603 .89356 .55476 Mtetra
.89356 .55476 .89771 .5603 .90835 .55727 .90422 .55171 Mtetra
.90422 .55171 .90835 .55727 .91903 .55424 .91493 .54866 Mtetra
.91493 .54866 .91903 .55424 .92974 .55119 .92567 .54559 Mtetra
.92567 .54559 .92974 .55119 .9405 .54814 .93646 .54251 Mtetra
.93646 .54251 .9405 .54814 .95129 .54507 .94728 .53942 Mtetra
.94728 .53942 .95129 .54507 .96213 .54199 .95814 .53632 Mtetra
.95814 .53632 .96213 .54199 .973 .5389 .96905 .53321 Mtetra
.96905 .53321 .973 .5389 .98391 .5358 .97999 .53009 Mtetra
.917 .703 .598 r
.39093 .69452 .39622 .70103 .4054 .69189 .40218 .6275 Mtetra
0 0 .454 r
.40218 .6275 .4054 .69189 .4143 .69146 .40899 .6862 Mtetra
.621 .72 .917 r
.40899 .6862 .4143 .69146 .42328 .68936 .41798 .68447 Mtetra
.644 .742 .92 r
.41798 .68447 .42328 .68936 .43231 .68698 .42702 .68217 Mtetra
.651 .747 .92 r
.42702 .68217 .43231 .68698 .44137 .68448 .4361 .6797 Mtetra
.654 .75 .92 r
.4361 .6797 .44137 .68448 .45046 .68192 .44521 .67714 Mtetra
.657 .752 .92 r
.44521 .67714 .45046 .68192 .45958 .6793 .45435 .67453 Mtetra
.658 .753 .92 r
.45435 .67453 .45958 .6793 .46873 .67664 .46352 .67187 Mtetra
.659 .754 .92 r
.46352 .67187 .46873 .67664 .47792 .67397 .47273 .66918 Mtetra
.47273 .66918 .47792 .67397 .48713 .67128 .48196 .66648 Mtetra
.48196 .66648 .48713 .67128 .49638 .66859 .49123 .66377 Mtetra
.49123 .66377 .49638 .66859 .50566 .6659 .50053 .66106 Mtetra
.658 .753 .92 r
.50053 .66106 .50566 .6659 .51496 .6632 .50986 .65834 Mtetra
.50986 .65834 .51496 .6632 .5243 .6605 .51922 .65562 Mtetra
.51922 .65562 .5243 .6605 .53367 .6578 .52861 .6529 Mtetra
.52861 .6529 .53367 .6578 .54308 .65509 .53803 .65017 Mtetra
.53803 .65017 .54308 .65509 .55251 .65237 .54749 .64743 Mtetra
.54749 .64743 .55251 .65237 .56198 .64965 .55698 .64469 Mtetra
.55698 .64469 .56198 .64965 .57147 .64691 .5665 .64194 Mtetra
.657 .753 .92 r
.5665 .64194 .57147 .64691 .58101 .64418 .57605 .63919 Mtetra
.57605 .63919 .58101 .64418 .59057 .64143 .58563 .63642 Mtetra
.58563 .63642 .59057 .64143 .60017 .63867 .59525 .63365 Mtetra
.657 .752 .92 r
.59525 .63365 .60017 .63867 .6098 .63591 .60491 .63087 Mtetra
.60491 .63087 .6098 .63591 .61946 .63314 .61459 .62808 Mtetra
.61459 .62808 .61946 .63314 .62915 .63036 .62431 .62528 Mtetra
.62431 .62528 .62915 .63036 .63888 .62757 .63406 .62247 Mtetra
.63406 .62247 .63888 .62757 .64865 .62477 .64385 .61966 Mtetra
.64385 .61966 .64865 .62477 .65844 .62197 .65367 .61683 Mtetra
.65367 .61683 .65844 .62197 .66828 .61915 .66352 .614 Mtetra
.66352 .614 .66828 .61915 .67814 .61633 .67341 .61116 Mtetra
.67341 .61116 .67814 .61633 .68804 .61349 .68334 .6083 Mtetra
.68334 .6083 .68804 .61349 .69798 .61065 .69329 .60544 Mtetra
.69329 .60544 .69798 .61065 .70794 .6078 .70329 .60257 Mtetra
.70329 .60257 .70794 .6078 .71795 .60494 .71332 .59969 Mtetra
.71332 .59969 .71795 .60494 .72799 .60206 .72338 .5968 Mtetra
.72338 .5968 .72799 .60206 .73806 .59918 .73348 .5939 Mtetra
.73348 .5939 .73806 .59918 .74817 .59629 .74362 .59099 Mtetra
.74362 .59099 .74817 .59629 .75832 .59339 .75379 .58807 Mtetra
.75379 .58807 .75832 .59339 .7685 .59048 .76399 .58514 Mtetra
.76399 .58514 .7685 .59048 .77872 .58756 .77424 .5822 Mtetra
.77424 .5822 .77872 .58756 .78897 .58463 .78452 .57925 Mtetra
.78452 .57925 .78897 .58463 .79926 .58169 .79484 .57629 Mtetra
.79484 .57629 .79926 .58169 .80959 .57874 .80519 .57332 Mtetra
.80519 .57332 .80959 .57874 .81996 .57578 .81558 .57034 Mtetra
.81558 .57034 .81996 .57578 .83036 .5728 .82601 .56735 Mtetra
.82601 .56735 .83036 .5728 .8408 .56982 .83647 .56434 Mtetra
.83647 .56434 .8408 .56982 .85127 .56683 .84698 .56133 Mtetra
.84698 .56133 .85127 .56683 .86179 .56383 .85752 .55831 Mtetra
.85752 .55831 .86179 .56383 .87234 .56082 .8681 .55528 Mtetra
.8681 .55528 .87234 .56082 .88293 .55779 .87872 .55223 Mtetra
.87872 .55223 .88293 .55779 .89356 .55476 .88937 .54918 Mtetra
.88937 .54918 .89356 .55476 .90422 .55171 .90007 .54611 Mtetra
.90007 .54611 .90422 .55171 .91493 .54866 .9108 .54304 Mtetra
.9108 .54304 .91493 .54866 .92567 .54559 .92158 .53995 Mtetra
.92158 .53995 .92567 .54559 .93646 .54251 .93239 .53685 Mtetra
.93239 .53685 .93646 .54251 .94728 .53942 .94324 .53374 Mtetra
.94324 .53374 .94728 .53942 .95814 .53632 .95413 .53062 Mtetra
.95413 .53062 .95814 .53632 .96905 .53321 .96506 .52749 Mtetra
.96506 .52749 .96905 .53321 .97999 .53009 .97604 .52434 Mtetra
.526 .684 .938 r
.38555 .68918 .39093 .69452 .40218 .6275 .39444 .6891 Mtetra
.513 .283 .502 r
.39444 .6891 .40218 .6275 .40899 .6862 .40369 .67989 Mtetra
.566 .663 .903 r
.40369 .67989 .40899 .6862 .41798 .68447 .41265 .67943 Mtetra
.637 .735 .919 r
.41265 .67943 .41798 .68447 .42702 .68217 .42171 .67729 Mtetra
.648 .745 .92 r
.42171 .67729 .42702 .68217 .4361 .6797 .4308 .67487 Mtetra
.653 .749 .92 r
.4308 .67487 .4361 .6797 .44521 .67714 .43993 .67233 Mtetra
.656 .751 .92 r
.43993 .67233 .44521 .67714 .45435 .67453 .44909 .66972 Mtetra
.657 .752 .92 r
.44909 .66972 .45435 .67453 .46352 .67187 .45828 .66706 Mtetra
.658 .753 .92 r
.45828 .66706 .46352 .67187 .47273 .66918 .46751 .66437 Mtetra
.659 .754 .92 r
.46751 .66437 .47273 .66918 .48196 .66648 .47676 .66165 Mtetra
.47676 .66165 .48196 .66648 .49123 .66377 .48605 .65892 Mtetra
.48605 .65892 .49123 .66377 .50053 .66106 .49537 .65619 Mtetra
.49537 .65619 .50053 .66106 .50986 .65834 .50472 .65345 Mtetra
.658 .753 .92 r
.50472 .65345 .50986 .65834 .51922 .65562 .5141 .65071 Mtetra
.5141 .65071 .51922 .65562 .52861 .6529 .52351 .64797 Mtetra
.52351 .64797 .52861 .6529 .53803 .65017 .53296 .64522 Mtetra
.53296 .64522 .53803 .65017 .54749 .64743 .54243 .64247 Mtetra
.54243 .64247 .54749 .64743 .55698 .64469 .55194 .63971 Mtetra
.55194 .63971 .55698 .64469 .5665 .64194 .56149 .63694 Mtetra
.657 .753 .92 r
.56149 .63694 .5665 .64194 .57605 .63919 .57106 .63417 Mtetra
.57106 .63417 .57605 .63919 .58563 .63642 .58067 .63138 Mtetra
.58067 .63138 .58563 .63642 .59525 .63365 .59031 .62859 Mtetra
.657 .752 .92 r
.59031 .62859 .59525 .63365 .60491 .63087 .59998 .62579 Mtetra
.59998 .62579 .60491 .63087 .61459 .62808 .60969 .62299 Mtetra
.60969 .62299 .61459 .62808 .62431 .62528 .61943 .62017 Mtetra
.61943 .62017 .62431 .62528 .63406 .62247 .62921 .61734 Mtetra
.62921 .61734 .63406 .62247 .64385 .61966 .63902 .61451 Mtetra
.63902 .61451 .64385 .61966 .65367 .61683 .64886 .61167 Mtetra
.64886 .61167 .65367 .61683 .66352 .614 .65874 .60881 Mtetra
.65874 .60881 .66352 .614 .67341 .61116 .66865 .60595 Mtetra
.66865 .60595 .67341 .61116 .68334 .6083 .6786 .60308 Mtetra
.6786 .60308 .68334 .6083 .69329 .60544 .68858 .6002 Mtetra
.68858 .6002 .69329 .60544 .70329 .60257 .6986 .59731 Mtetra
.6986 .59731 .70329 .60257 .71332 .59969 .70865 .59441 Mtetra
.70865 .59441 .71332 .59969 .72338 .5968 .71874 .5915 Mtetra
.71874 .5915 .72338 .5968 .73348 .5939 .72887 .58858 Mtetra
.72887 .58858 .73348 .5939 .74362 .59099 .73903 .58565 Mtetra
.73903 .58565 .74362 .59099 .75379 .58807 .74922 .58271 Mtetra
.74922 .58271 .75379 .58807 .76399 .58514 .75946 .57976 Mtetra
.75946 .57976 .76399 .58514 .77424 .5822 .76973 .5768 Mtetra
.76973 .5768 .77424 .5822 .78452 .57925 .78003 .57383 Mtetra
.78003 .57383 .78452 .57925 .79484 .57629 .79038 .57085 Mtetra
.79038 .57085 .79484 .57629 .80519 .57332 .80076 .56786 Mtetra
.80076 .56786 .80519 .57332 .81558 .57034 .81117 .56486 Mtetra
.81117 .56486 .81558 .57034 .82601 .56735 .82163 .56185 Mtetra
.82163 .56185 .82601 .56735 .83647 .56434 .83212 .55883 Mtetra
.83212 .55883 .83647 .56434 .84698 .56133 .84265 .5558 Mtetra
.84265 .5558 .84698 .56133 .85752 .55831 .85322 .55275 Mtetra
.85322 .55275 .85752 .55831 .8681 .55528 .86383 .5497 Mtetra
.86383 .5497 .8681 .55528 .87872 .55223 .87448 .54664 Mtetra
.87448 .54664 .87872 .55223 .88937 .54918 .88516 .54356 Mtetra
.88516 .54356 .88937 .54918 .90007 .54611 .89588 .54047 Mtetra
.89588 .54047 .90007 .54611 .9108 .54304 .90665 .53738 Mtetra
.90665 .53738 .9108 .54304 .92158 .53995 .91745 .53427 Mtetra
.91745 .53427 .92158 .53995 .93239 .53685 .92829 .53115 Mtetra
.92829 .53115 .93239 .53685 .94324 .53374 .93917 .52802 Mtetra
.93917 .52802 .94324 .53374 .95413 .53062 .95009 .52488 Mtetra
.95009 .52488 .95413 .53062 .96506 .52749 .96106 .52172 Mtetra
.96106 .52172 .96506 .52749 .97604 .52434 .97206 .51856 Mtetra
.611 .725 .927 r
.38014 .6841 .38555 .68918 .39444 .6891 .3891 .6825 Mtetra
.918 .703 .597 r
.3891 .6825 .39444 .6891 .40369 .67989 .40047 .61516 Mtetra
0 0 .45 r
.40047 .61516 .40369 .67989 .41265 .67943 .4073 .67409 Mtetra
.621 .72 .917 r
.4073 .67409 .41265 .67943 .42171 .67729 .41636 .67232 Mtetra
.644 .742 .92 r
.41636 .67232 .42171 .67729 .4308 .67487 .42547 .66998 Mtetra
.651 .747 .92 r
.42547 .66998 .4308 .67487 .43993 .67233 .43462 .66747 Mtetra
.654 .75 .92 r
.43462 .66747 .43993 .67233 .44909 .66972 .4438 .66488 Mtetra
.657 .752 .92 r
.4438 .66488 .44909 .66972 .45828 .66706 .45301 .66222 Mtetra
.658 .753 .92 r
.45301 .66222 .45828 .66706 .46751 .66437 .46225 .65952 Mtetra
.659 .754 .92 r
.46225 .65952 .46751 .66437 .47676 .66165 .47153 .65679 Mtetra
.47153 .65679 .47676 .66165 .48605 .65892 .48084 .65405 Mtetra
.48084 .65405 .48605 .65892 .49537 .65619 .49018 .65129 Mtetra
.49018 .65129 .49537 .65619 .50472 .65345 .49955 .64854 Mtetra
.658 .753 .92 r
.49955 .64854 .50472 .65345 .5141 .65071 .50895 .64578 Mtetra
.50895 .64578 .5141 .65071 .52351 .64797 .51838 .64301 Mtetra
.51838 .64301 .52351 .64797 .53296 .64522 .52785 .64025 Mtetra
.52785 .64025 .53296 .64522 .54243 .64247 .53735 .63747 Mtetra
.53735 .63747 .54243 .64247 .55194 .63971 .54688 .63469 Mtetra
.54688 .63469 .55194 .63971 .56149 .63694 .55644 .63191 Mtetra
.55644 .63191 .56149 .63694 .57106 .63417 .56604 .62911 Mtetra
.657 .753 .92 r
.56604 .62911 .57106 .63417 .58067 .63138 .57567 .62631 Mtetra
.57567 .62631 .58067 .63138 .59031 .62859 .58533 .6235 Mtetra
.58533 .6235 .59031 .62859 .59998 .62579 .59503 .62069 Mtetra
.657 .752 .92 r
.59503 .62069 .59998 .62579 .60969 .62299 .60476 .61786 Mtetra
.60476 .61786 .60969 .62299 .61943 .62017 .61453 .61502 Mtetra
.61453 .61502 .61943 .62017 .62921 .61734 .62432 .61218 Mtetra
.62432 .61218 .62921 .61734 .63902 .61451 .63416 .60933 Mtetra
.63416 .60933 .63902 .61451 .64886 .61167 .64402 .60647 Mtetra
.64402 .60647 .64886 .61167 .65874 .60881 .65393 .60359 Mtetra
.65393 .60359 .65874 .60881 .66865 .60595 .66386 .60071 Mtetra
.66386 .60071 .66865 .60595 .6786 .60308 .67383 .59782 Mtetra
.67383 .59782 .6786 .60308 .68858 .6002 .68384 .59492 Mtetra
.68384 .59492 .68858 .6002 .6986 .59731 .69388 .59201 Mtetra
.69388 .59201 .6986 .59731 .70865 .59441 .70396 .5891 Mtetra
.70396 .5891 .70865 .59441 .71874 .5915 .71408 .58617 Mtetra
.71408 .58617 .71874 .5915 .72887 .58858 .72422 .58323 Mtetra
.72422 .58323 .72887 .58858 .73903 .58565 .73441 .58028 Mtetra
.73441 .58028 .73903 .58565 .74922 .58271 .74463 .57732 Mtetra
.74463 .57732 .74922 .58271 .75946 .57976 .75489 .57435 Mtetra
.75489 .57435 .75946 .57976 .76973 .5768 .76519 .57137 Mtetra
.76519 .57137 .76973 .5768 .78003 .57383 .77552 .56838 Mtetra
.77552 .56838 .78003 .57383 .79038 .57085 .78589 .56538 Mtetra
.78589 .56538 .79038 .57085 .80076 .56786 .7963 .56237 Mtetra
.7963 .56237 .80076 .56786 .81117 .56486 .80674 .55935 Mtetra
.80674 .55935 .81117 .56486 .82163 .56185 .81722 .55632 Mtetra
.81722 .55632 .82163 .56185 .83212 .55883 .82774 .55328 Mtetra
.82774 .55328 .83212 .55883 .84265 .5558 .8383 .55023 Mtetra
.8383 .55023 .84265 .5558 .85322 .55275 .8489 .54716 Mtetra
.8489 .54716 .85322 .55275 .86383 .5497 .85953 .54409 Mtetra
.85953 .54409 .86383 .5497 .87448 .54664 .87021 .541 Mtetra
.87021 .541 .87448 .54664 .88516 .54356 .88092 .53791 Mtetra
.88092 .53791 .88516 .54356 .89588 .54047 .89167 .5348 Mtetra
.89167 .5348 .89588 .54047 .90665 .53738 .90246 .53168 Mtetra
.90246 .53168 .90665 .53738 .91745 .53427 .91329 .52855 Mtetra
.91329 .52855 .91745 .53427 .92829 .53115 .92417 .52541 Mtetra
.92417 .52541 .92829 .53115 .93917 .52802 .93508 .52226 Mtetra
.93508 .52226 .93917 .52802 .95009 .52488 .94603 .51909 Mtetra
.94603 .51909 .95009 .52488 .96106 .52172 .95702 .51592 Mtetra
.95702 .51592 .96106 .52172 .97206 .51856 .96805 .51273 Mtetra
.63 .735 .923 r
.37468 .6791 .38014 .6841 .3891 .6825 .38368 .67709 Mtetra
.526 .684 .938 r
.38368 .67709 .3891 .6825 .40047 .61516 .39263 .67698 Mtetra
.51 .279 .499 r
.39263 .67698 .40047 .61516 .4073 .67409 .40195 .6677 Mtetra
.566 .663 .903 r
.40195 .6677 .4073 .67409 .41636 .67232 .41099 .6672 Mtetra
.637 .735 .919 r
.41099 .6672 .41636 .67232 .42547 .66998 .42011 .66502 Mtetra
.648 .745 .92 r
.42011 .66502 .42547 .66998 .43462 .66747 .42927 .66256 Mtetra
.653 .749 .92 r
.42927 .66256 .43462 .66747 .4438 .66488 .43847 .65999 Mtetra
.656 .751 .92 r
.43847 .65999 .4438 .66488 .45301 .66222 .4477 .65734 Mtetra
.657 .752 .92 r
.4477 .65734 .45301 .66222 .46225 .65952 .45697 .65463 Mtetra
.658 .753 .92 r
.45697 .65463 .46225 .65952 .47153 .65679 .46626 .6519 Mtetra
.659 .754 .92 r
.46626 .6519 .47153 .65679 .48084 .65405 .47559 .64914 Mtetra
.47559 .64914 .48084 .65405 .49018 .65129 .48495 .64636 Mtetra
.48495 .64636 .49018 .65129 .49955 .64854 .49434 .64359 Mtetra
.49434 .64359 .49955 .64854 .50895 .64578 .50377 .64081 Mtetra
.658 .753 .92 r
.50377 .64081 .50895 .64578 .51838 .64301 .51322 .63802 Mtetra
.51322 .63802 .51838 .64301 .52785 .64025 .52271 .63524 Mtetra
.52271 .63524 .52785 .64025 .53735 .63747 .53223 .63245 Mtetra
.53223 .63245 .53735 .63747 .54688 .63469 .54178 .62965 Mtetra
.54178 .62965 .54688 .63469 .55644 .63191 .55137 .62684 Mtetra
.55137 .62684 .55644 .63191 .56604 .62911 .56099 .62403 Mtetra
.657 .753 .92 r
.56099 .62403 .56604 .62911 .57567 .62631 .57064 .62121 Mtetra
.57064 .62121 .57567 .62631 .58533 .6235 .58032 .61838 Mtetra
.58032 .61838 .58533 .6235 .59503 .62069 .59004 .61555 Mtetra
.657 .752 .92 r
.59004 .61555 .59503 .62069 .60476 .61786 .5998 .6127 Mtetra
.5998 .6127 .60476 .61786 .61453 .61502 .60959 .60985 Mtetra
.60959 .60985 .61453 .61502 .62432 .61218 .61941 .60698 Mtetra
.61941 .60698 .62432 .61218 .63416 .60933 .62926 .60411 Mtetra
.62926 .60411 .63416 .60933 .64402 .60647 .63915 .60123 Mtetra
.63915 .60123 .64402 .60647 .65393 .60359 .64908 .59834 Mtetra
.64908 .59834 .65393 .60359 .66386 .60071 .65904 .59544 Mtetra
.65904 .59544 .66386 .60071 .67383 .59782 .66904 .59253 Mtetra
.66904 .59253 .67383 .59782 .68384 .59492 .67907 .58961 Mtetra
.67907 .58961 .68384 .59492 .69388 .59201 .68914 .58668 Mtetra
.68914 .58668 .69388 .59201 .70396 .5891 .69924 .58375 Mtetra
.69924 .58375 .70396 .5891 .71408 .58617 .70938 .5808 Mtetra
.70938 .5808 .71408 .58617 .72422 .58323 .71955 .57784 Mtetra
.71955 .57784 .72422 .58323 .73441 .58028 .72976 .57487 Mtetra
.72976 .57487 .73441 .58028 .74463 .57732 .74001 .57189 Mtetra
.74001 .57189 .74463 .57732 .75489 .57435 .75029 .5689 Mtetra
.75029 .5689 .75489 .57435 .76519 .57137 .76062 .5659 Mtetra
.76062 .5659 .76519 .57137 .77552 .56838 .77097 .56289 Mtetra
.77097 .56289 .77552 .56838 .78589 .56538 .78137 .55988 Mtetra
.78137 .55988 .78589 .56538 .7963 .56237 .7918 .55684 Mtetra
.7918 .55684 .7963 .56237 .80674 .55935 .80228 .5538 Mtetra
.80228 .5538 .80674 .55935 .81722 .55632 .81278 .55075 Mtetra
.81278 .55075 .81722 .55632 .82774 .55328 .82333 .54769 Mtetra
.82333 .54769 .82774 .55328 .8383 .55023 .83392 .54462 Mtetra
.83392 .54462 .8383 .55023 .8489 .54716 .84454 .54153 Mtetra
.84454 .54153 .8489 .54716 .85953 .54409 .85521 .53844 Mtetra
.85521 .53844 .85953 .54409 .87021 .541 .86591 .53533 Mtetra
.86591 .53533 .87021 .541 .88092 .53791 .87665 .53221 Mtetra
.87665 .53221 .88092 .53791 .89167 .5348 .88743 .52908 Mtetra
.88743 .52908 .89167 .5348 .90246 .53168 .89825 .52594 Mtetra
.89825 .52594 .90246 .53168 .91329 .52855 .90911 .52279 Mtetra
.90911 .52279 .91329 .52855 .92417 .52541 .92001 .51963 Mtetra
.92001 .51963 .92417 .52541 .93508 .52226 .93095 .51646 Mtetra
.93095 .51646 .93508 .52226 .94603 .51909 .94194 .51327 Mtetra
.94194 .51327 .94603 .51909 .95702 .51592 .95296 .51007 Mtetra
.95296 .51007 .95702 .51592 .96805 .51273 .96402 .50687 Mtetra
.637 .739 .922 r
.3692 .67411 .37468 .6791 .38368 .67709 .37821 .67193 Mtetra
.611 .725 .927 r
.37821 .67193 .38368 .67709 .39263 .67698 .38724 .67029 Mtetra
.919 .704 .595 r
.38724 .67029 .39263 .67698 .40195 .6677 .39874 .60264 Mtetra
0 0 .447 r
.39874 .60264 .40195 .6677 .41099 .6672 .40559 .66179 Mtetra
.62 .72 .917 r
.40559 .66179 .41099 .6672 .42011 .66502 .41471 .65998 Mtetra
.644 .742 .92 r
.41471 .65998 .42011 .66502 .42927 .66256 .42389 .6576 Mtetra
.651 .747 .92 r
.42389 .6576 .42927 .66256 .43847 .65999 .43311 .65505 Mtetra
.654 .75 .92 r
.43311 .65505 .43847 .65999 .4477 .65734 .44236 .65241 Mtetra
.657 .752 .92 r
.44236 .65241 .4477 .65734 .45697 .65463 .45165 .64971 Mtetra
.658 .753 .92 r
.45165 .64971 .45697 .65463 .46626 .6519 .46096 .64697 Mtetra
.659 .754 .92 r
.46096 .64697 .46626 .6519 .47559 .64914 .47031 .6442 Mtetra
.47031 .6442 .47559 .64914 .48495 .64636 .47969 .64141 Mtetra
.47969 .64141 .48495 .64636 .49434 .64359 .4891 .63861 Mtetra
.4891 .63861 .49434 .64359 .50377 .64081 .49855 .63581 Mtetra
.658 .753 .92 r
.49855 .63581 .50377 .64081 .51322 .63802 .50803 .63301 Mtetra
.50803 .63301 .51322 .63802 .52271 .63524 .51753 .6302 Mtetra
.51753 .6302 .52271 .63524 .53223 .63245 .52708 .62739 Mtetra
.52708 .62739 .53223 .63245 .54178 .62965 .53665 .62457 Mtetra
.53665 .62457 .54178 .62965 .55137 .62684 .54626 .62175 Mtetra
.54626 .62175 .55137 .62684 .56099 .62403 .5559 .61891 Mtetra
.5559 .61891 .56099 .62403 .57064 .62121 .56558 .61607 Mtetra
.657 .753 .92 r
.56558 .61607 .57064 .62121 .58032 .61838 .57528 .61323 Mtetra
.57528 .61323 .58032 .61838 .59004 .61555 .58503 .61037 Mtetra
.58503 .61037 .59004 .61555 .5998 .6127 .5948 .60751 Mtetra
.657 .752 .92 r
.5948 .60751 .5998 .6127 .60959 .60985 .60461 .60464 Mtetra
.60461 .60464 .60959 .60985 .61941 .60698 .61446 .60175 Mtetra
.61446 .60175 .61941 .60698 .62926 .60411 .62434 .59886 Mtetra
.62434 .59886 .62926 .60411 .63915 .60123 .63425 .59596 Mtetra
.63425 .59596 .63915 .60123 .64908 .59834 .6442 .59305 Mtetra
.6442 .59305 .64908 .59834 .65904 .59544 .65419 .59013 Mtetra
.65419 .59013 .65904 .59544 .66904 .59253 .66421 .58721 Mtetra
.66421 .58721 .66904 .59253 .67907 .58961 .67426 .58427 Mtetra
.67426 .58427 .67907 .58961 .68914 .58668 .68436 .58132 Mtetra
.68436 .58132 .68914 .58668 .69924 .58375 .69448 .57836 Mtetra
.69448 .57836 .69924 .58375 .70938 .5808 .70465 .57539 Mtetra
.70465 .57539 .70938 .5808 .71955 .57784 .71485 .57242 Mtetra
.71485 .57242 .71955 .57784 .72976 .57487 .72508 .56943 Mtetra
.72508 .56943 .72976 .57487 .74001 .57189 .73536 .56643 Mtetra
.73536 .56643 .74001 .57189 .75029 .5689 .74567 .56342 Mtetra
.74567 .56342 .75029 .5689 .76062 .5659 .75601 .5604 Mtetra
.75601 .5604 .76062 .5659 .77097 .56289 .7664 .55737 Mtetra
.7664 .55737 .77097 .56289 .78137 .55988 .77682 .55433 Mtetra
.77682 .55433 .78137 .55988 .7918 .55684 .78728 .55128 Mtetra
.78728 .55128 .7918 .55684 .80228 .5538 .79778 .54822 Mtetra
.79778 .54822 .80228 .5538 .81278 .55075 .80832 .54515 Mtetra
.80832 .54515 .81278 .55075 .82333 .54769 .81889 .54206 Mtetra
.81889 .54206 .82333 .54769 .83392 .54462 .82951 .53897 Mtetra
.82951 .53897 .83392 .54462 .84454 .54153 .84016 .53586 Mtetra
.84016 .53586 .84454 .54153 .85521 .53844 .85085 .53275 Mtetra
.85085 .53275 .85521 .53844 .86591 .53533 .86158 .52962 Mtetra
.86158 .52962 .86591 .53533 .87665 .53221 .87235 .52648 Mtetra
.87235 .52648 .87665 .53221 .88743 .52908 .88316 .52333 Mtetra
.88316 .52333 .88743 .52908 .89825 .52594 .89401 .52017 Mtetra
.89401 .52017 .89825 .52594 .90911 .52279 .9049 .517 Mtetra
.9049 .517 .90911 .52279 .92001 .51963 .91583 .51381 Mtetra
.91583 .51381 .92001 .51963 .93095 .51646 .9268 .51062 Mtetra
.9268 .51062 .93095 .51646 .94194 .51327 .93781 .50741 Mtetra
.93781 .50741 .94194 .51327 .95296 .51007 .94887 .50419 Mtetra
.94887 .50419 .95296 .51007 .96402 .50687 .95996 .50096 Mtetra
.64 .74 .922 r
.36367 .66911 .3692 .67411 .37821 .67193 .37271 .66686 Mtetra
.63 .735 .923 r
.37271 .66686 .37821 .67193 .38724 .67029 .38177 .6648 Mtetra
.526 .684 .938 r
.38177 .6648 .38724 .67029 .39874 .60264 .3908 .66466 Mtetra
.507 .274 .496 r
.3908 .66466 .39874 .60264 .40559 .66179 .40019 .65531 Mtetra
.565 .663 .903 r
.40019 .65531 .40559 .66179 .41471 .65998 .40929 .65478 Mtetra
.637 .735 .919 r
.40929 .65478 .41471 .65998 .42389 .6576 .41848 .65256 Mtetra
.648 .745 .92 r
.41848 .65256 .42389 .6576 .43311 .65505 .42772 .65006 Mtetra
.653 .749 .92 r
.42772 .65006 .43311 .65505 .44236 .65241 .43699 .64744 Mtetra
.656 .751 .92 r
.43699 .64744 .44236 .65241 .45165 .64971 .44629 .64475 Mtetra
.657 .752 .92 r
.44629 .64475 .45165 .64971 .46096 .64697 .45563 .642 Mtetra
.658 .753 .92 r
.45563 .642 .46096 .64697 .47031 .6442 .465 .63922 Mtetra
.659 .754 .92 r
.465 .63922 .47031 .6442 .47969 .64141 .4744 .63642 Mtetra
.4744 .63642 .47969 .64141 .4891 .63861 .48383 .6336 Mtetra
.48383 .6336 .4891 .63861 .49855 .63581 .4933 .63078 Mtetra
.4933 .63078 .49855 .63581 .50803 .63301 .5028 .62796 Mtetra
.658 .753 .92 r
.5028 .62796 .50803 .63301 .51753 .6302 .51233 .62513 Mtetra
.51233 .62513 .51753 .6302 .52708 .62739 .52189 .6223 Mtetra
.52189 .6223 .52708 .62739 .53665 .62457 .53149 .61946 Mtetra
.53149 .61946 .53665 .62457 .54626 .62175 .54112 .61662 Mtetra
.54112 .61662 .54626 .62175 .5559 .61891 .55078 .61376 Mtetra
.55078 .61376 .5559 .61891 .56558 .61607 .56048 .61091 Mtetra
.657 .753 .92 r
.56048 .61091 .56558 .61607 .57528 .61323 .57021 .60804 Mtetra
.57021 .60804 .57528 .61323 .58503 .61037 .57998 .60517 Mtetra
.57998 .60517 .58503 .61037 .5948 .60751 .58978 .60228 Mtetra
.657 .752 .92 r
.58978 .60228 .5948 .60751 .60461 .60464 .59961 .59939 Mtetra
.59961 .59939 .60461 .60464 .61446 .60175 .60948 .59649 Mtetra
.60948 .59649 .61446 .60175 .62434 .59886 .61938 .59358 Mtetra
.61938 .59358 .62434 .59886 .63425 .59596 .62932 .59066 Mtetra
.62932 .59066 .63425 .59596 .6442 .59305 .63929 .58773 Mtetra
.63929 .58773 .6442 .59305 .65419 .59013 .6493 .58479 Mtetra
.6493 .58479 .65419 .59013 .66421 .58721 .65935 .58184 Mtetra
.65935 .58184 .66421 .58721 .67426 .58427 .66943 .57889 Mtetra
.66943 .57889 .67426 .58427 .68436 .58132 .67954 .57592 Mtetra
.67954 .57592 .68436 .58132 .69448 .57836 .6897 .57294 Mtetra
.6897 .57294 .69448 .57836 .70465 .57539 .69989 .56995 Mtetra
.69989 .56995 .70465 .57539 .71485 .57242 .71011 .56696 Mtetra
.71011 .56696 .71485 .57242 .72508 .56943 .72037 .56395 Mtetra
.72037 .56395 .72508 .56943 .73536 .56643 .73067 .56093 Mtetra
.73067 .56093 .73536 .56643 .74567 .56342 .74101 .5579 Mtetra
.74101 .5579 .74567 .56342 .75601 .5604 .75138 .55486 Mtetra
.75138 .55486 .75601 .5604 .7664 .55737 .76179 .55181 Mtetra
.76179 .55181 .7664 .55737 .77682 .55433 .77224 .54875 Mtetra
.77224 .54875 .77682 .55433 .78728 .55128 .78273 .54568 Mtetra
.78273 .54568 .78728 .55128 .79778 .54822 .79326 .5426 Mtetra
.79326 .5426 .79778 .54822 .80832 .54515 .80382 .5395 Mtetra
.80382 .5395 .80832 .54515 .81889 .54206 .81442 .5364 Mtetra
.81442 .5364 .81889 .54206 .82951 .53897 .82506 .53328 Mtetra
.82506 .53328 .82951 .53897 .84016 .53586 .83574 .53016 Mtetra
.83574 .53016 .84016 .53586 .85085 .53275 .84646 .52702 Mtetra
.84646 .52702 .85085 .53275 .86158 .52962 .85722 .52387 Mtetra
.85722 .52387 .86158 .52962 .87235 .52648 .86802 .52071 Mtetra
.86802 .52071 .87235 .52648 .88316 .52333 .87886 .51754 Mtetra
.87886 .51754 .88316 .52333 .89401 .52017 .88974 .51436 Mtetra
.88974 .51436 .89401 .52017 .9049 .517 .90066 .51116 Mtetra
.90066 .51116 .9049 .517 .91583 .51381 .91162 .50795 Mtetra
.91162 .50795 .91583 .51381 .9268 .51062 .92262 .50474 Mtetra
.92262 .50474 .9268 .51062 .93781 .50741 .93366 .50151 Mtetra
.93366 .50151 .93781 .50741 .94887 .50419 .94475 .49827 Mtetra
.94475 .49827 .94887 .50419 .95996 .50096 .95587 .49501 Mtetra
.64 .74 .921 r
.35812 .66407 .36367 .66911 .37271 .66686 .36717 .66179 Mtetra
.637 .739 .922 r
.36717 .66179 .37271 .66686 .38177 .6648 .37626 .65957 Mtetra
.611 .725 .927 r
.37626 .65957 .38177 .6648 .3908 .66466 .38536 .65789 Mtetra
.92 .704 .594 r
.38536 .65789 .3908 .66466 .40019 .65531 .39698 .58992 Mtetra
0 0 .443 r
.39698 .58992 .40019 .65531 .40929 .65478 .40384 .64929 Mtetra
.62 .72 .917 r
.40384 .64929 .40929 .65478 .41848 .65256 .41304 .64744 Mtetra
.644 .742 .92 r
.41304 .64744 .41848 .65256 .42772 .65006 .42229 .64502 Mtetra
.651 .747 .92 r
.42229 .64502 .42772 .65006 .43699 .64744 .43158 .64243 Mtetra
.654 .75 .92 r
.43158 .64243 .43699 .64744 .44629 .64475 .4409 .63974 Mtetra
.657 .752 .92 r
.4409 .63974 .44629 .64475 .45563 .642 .45026 .637 Mtetra
.658 .753 .92 r
.45026 .637 .45563 .642 .465 .63922 .45965 .63421 Mtetra
.659 .754 .92 r
.45965 .63421 .465 .63922 .4744 .63642 .46907 .6314 Mtetra
.46907 .6314 .4744 .63642 .48383 .6336 .47853 .62856 Mtetra
.47853 .62856 .48383 .6336 .4933 .63078 .48801 .62572 Mtetra
.48801 .62572 .4933 .63078 .5028 .62796 .49753 .62288 Mtetra
.658 .753 .92 r
.49753 .62288 .5028 .62796 .51233 .62513 .50709 .62003 Mtetra
.50709 .62003 .51233 .62513 .52189 .6223 .51667 .61717 Mtetra
.51667 .61717 .52189 .6223 .53149 .61946 .52629 .61432 Mtetra
.52629 .61432 .53149 .61946 .54112 .61662 .53594 .61145 Mtetra
.53594 .61145 .54112 .61662 .55078 .61376 .54563 .60858 Mtetra
.54563 .60858 .55078 .61376 .56048 .61091 .55535 .6057 Mtetra
.55535 .6057 .56048 .61091 .57021 .60804 .5651 .60282 Mtetra
.657 .753 .92 r
.5651 .60282 .57021 .60804 .57998 .60517 .57489 .59993 Mtetra
.57489 .59993 .57998 .60517 .58978 .60228 .58471 .59702 Mtetra
.58471 .59702 .58978 .60228 .59961 .59939 .59457 .59411 Mtetra
.657 .752 .92 r
.59457 .59411 .59961 .59939 .60948 .59649 .60446 .59119 Mtetra
.60446 .59119 .60948 .59649 .61938 .59358 .61439 .58826 Mtetra
.61439 .58826 .61938 .59358 .62932 .59066 .62435 .58532 Mtetra
.62435 .58532 .62932 .59066 .63929 .58773 .63435 .58237 Mtetra
.63435 .58237 .63929 .58773 .6493 .58479 .64438 .57942 Mtetra
.64438 .57942 .6493 .58479 .65935 .58184 .65445 .57645 Mtetra
.65445 .57645 .65935 .58184 .66943 .57889 .66456 .57347 Mtetra
.66456 .57347 .66943 .57889 .67954 .57592 .6747 .57048 Mtetra
.6747 .57048 .67954 .57592 .6897 .57294 .68488 .56748 Mtetra
.68488 .56748 .6897 .57294 .69989 .56995 .69509 .56448 Mtetra
.69509 .56448 .69989 .56995 .71011 .56696 .70534 .56146 Mtetra
.70534 .56146 .71011 .56696 .72037 .56395 .71563 .55843 Mtetra
.71563 .55843 .72037 .56395 .73067 .56093 .72596 .55539 Mtetra
.72596 .55539 .73067 .56093 .74101 .5579 .73632 .55234 Mtetra
.73632 .55234 .74101 .5579 .75138 .55486 .74672 .54928 Mtetra
.74672 .54928 .75138 .55486 .76179 .55181 .75716 .54621 Mtetra
.75716 .54621 .76179 .55181 .77224 .54875 .76763 .54313 Mtetra
.76763 .54313 .77224 .54875 .78273 .54568 .77815 .54004 Mtetra
.77815 .54004 .78273 .54568 .79326 .5426 .7887 .53693 Mtetra
.7887 .53693 .79326 .5426 .80382 .5395 .79929 .53382 Mtetra
.79929 .53382 .80382 .5395 .81442 .5364 .80992 .53069 Mtetra
.80992 .53069 .81442 .5364 .82506 .53328 .82059 .52756 Mtetra
.82059 .52756 .82506 .53328 .83574 .53016 .8313 .52441 Mtetra
.8313 .52441 .83574 .53016 .84646 .52702 .84205 .52125 Mtetra
.84205 .52125 .84646 .52702 .85722 .52387 .85284 .51808 Mtetra
.85284 .51808 .85722 .52387 .86802 .52071 .86367 .5149 Mtetra
.86367 .5149 .86802 .52071 .87886 .51754 .87453 .51171 Mtetra
.87453 .51171 .87886 .51754 .88974 .51436 .88544 .5085 Mtetra
.88544 .5085 .88974 .51436 .90066 .51116 .89639 .50528 Mtetra
.89639 .50528 .90066 .51116 .91162 .50795 .90738 .50206 Mtetra
.90738 .50206 .91162 .50795 .92262 .50474 .91841 .49882 Mtetra
.91841 .49882 .92262 .50474 .93366 .50151 .92949 .49556 Mtetra
.92949 .49556 .93366 .50151 .94475 .49827 .9406 .4923 Mtetra
.9406 .4923 .94475 .49827 .95587 .49501 .95176 .48902 Mtetra
.639 .739 .921 r
.35253 .65897 .35812 .66407 .36717 .66179 .3616 .65671 Mtetra
.64 .74 .922 r
.3616 .65671 .36717 .66179 .37626 .65957 .37071 .65441 Mtetra
.63 .735 .923 r
.37071 .65441 .37626 .65957 .38536 .65789 .37984 .65232 Mtetra
.527 .684 .938 r
.37984 .65232 .38536 .65789 .39698 .58992 .38893 .65215 Mtetra
.504 .27 .493 r
.38893 .65215 .39698 .58992 .40384 .64929 .3984 .64273 Mtetra
.565 .663 .903 r
.3984 .64273 .40384 .64929 .41304 .64744 .40757 .64216 Mtetra
.637 .735 .919 r
.40757 .64216 .41304 .64744 .42229 .64502 .41683 .6399 Mtetra
.648 .745 .92 r
.41683 .6399 .42229 .64502 .43158 .64243 .42614 .63736 Mtetra
.653 .749 .92 r
.42614 .63736 .43158 .64243 .4409 .63974 .43548 .63469 Mtetra
.656 .751 .92 r
.43548 .63469 .4409 .63974 .45026 .637 .44486 .63196 Mtetra
.657 .752 .92 r
.44486 .63196 .45026 .637 .45965 .63421 .45427 .62917 Mtetra
.658 .753 .92 r
.45427 .62917 .45965 .63421 .46907 .6314 .46371 .62634 Mtetra
.659 .754 .92 r
.46371 .62634 .46907 .6314 .47853 .62856 .47319 .62349 Mtetra
.47319 .62349 .47853 .62856 .48801 .62572 .4827 .62063 Mtetra
.4827 .62063 .48801 .62572 .49753 .62288 .49224 .61776 Mtetra
.49224 .61776 .49753 .62288 .50709 .62003 .50181 .61489 Mtetra
.658 .753 .92 r
.50181 .61489 .50709 .62003 .51667 .61717 .51142 .61202 Mtetra
.51142 .61202 .51667 .61717 .52629 .61432 .52106 .60914 Mtetra
.52106 .60914 .52629 .61432 .53594 .61145 .53074 .60626 Mtetra
.53074 .60626 .53594 .61145 .54563 .60858 .54044 .60337 Mtetra
.54044 .60337 .54563 .60858 .55535 .6057 .55019 .60047 Mtetra
.55019 .60047 .55535 .6057 .5651 .60282 .55996 .59756 Mtetra
.657 .753 .92 r
.55996 .59756 .5651 .60282 .57489 .59993 .56977 .59465 Mtetra
.56977 .59465 .57489 .59993 .58471 .59702 .57962 .59173 Mtetra
.57962 .59173 .58471 .59702 .59457 .59411 .5895 .5888 Mtetra
.657 .752 .92 r
.5895 .5888 .59457 .59411 .60446 .59119 .59942 .58586 Mtetra
.59942 .58586 .60446 .59119 .61439 .58826 .60937 .58291 Mtetra
.60937 .58291 .61439 .58826 .62435 .58532 .61935 .57995 Mtetra
.61935 .57995 .62435 .58532 .63435 .58237 .62938 .57698 Mtetra
.62938 .57698 .63435 .58237 .64438 .57942 .63943 .574 Mtetra
.63943 .574 .64438 .57942 .65445 .57645 .64953 .57102 Mtetra
.64953 .57102 .65445 .57645 .66456 .57347 .65966 .56802 Mtetra
.65966 .56802 .66456 .57347 .6747 .57048 .66982 .56501 Mtetra
.66982 .56501 .6747 .57048 .68488 .56748 .68003 .56199 Mtetra
.68003 .56199 .68488 .56748 .69509 .56448 .69027 .55896 Mtetra
.69027 .55896 .69509 .56448 .70534 .56146 .70054 .55593 Mtetra
.70054 .55593 .70534 .56146 .71563 .55843 .71086 .55288 Mtetra
.71086 .55288 .71563 .55843 .72596 .55539 .72121 .54982 Mtetra
.72121 .54982 .72596 .55539 .73632 .55234 .7316 .54675 Mtetra
.7316 .54675 .73632 .55234 .74672 .54928 .74202 .54367 Mtetra
.74202 .54367 .74672 .54928 .75716 .54621 .75249 .54057 Mtetra
.75249 .54057 .75716 .54621 .76763 .54313 .76299 .53747 Mtetra
.76299 .53747 .76763 .54313 .77815 .54004 .77353 .53436 Mtetra
.77353 .53436 .77815 .54004 .7887 .53693 .78411 .53123 Mtetra
.78411 .53123 .7887 .53693 .79929 .53382 .79473 .5281 Mtetra
.79473 .5281 .79929 .53382 .80992 .53069 .80539 .52495 Mtetra
.80539 .52495 .80992 .53069 .82059 .52756 .81609 .52179 Mtetra
.81609 .52179 .82059 .52756 .8313 .52441 .82683 .51863 Mtetra
.82683 .51863 .8313 .52441 .84205 .52125 .8376 .51544 Mtetra
.8376 .51544 .84205 .52125 .85284 .51808 .84842 .51225 Mtetra
.84842 .51225 .85284 .51808 .86367 .5149 .85928 .50905 Mtetra
.85928 .50905 .86367 .5149 .87453 .51171 .87017 .50583 Mtetra
.87017 .50583 .87453 .51171 .88544 .5085 .88111 .50261 Mtetra
.88111 .50261 .88544 .5085 .89639 .50528 .89209 .49937 Mtetra
.89209 .49937 .89639 .50528 .90738 .50206 .90311 .49612 Mtetra
.90311 .49612 .90738 .50206 .91841 .49882 .91417 .49285 Mtetra
.91417 .49285 .91841 .49882 .92949 .49556 .92528 .48958 Mtetra
.92528 .48958 .92949 .49556 .9406 .4923 .93642 .48629 Mtetra
.93642 .48629 .9406 .4923 .95176 .48902 .94761 .48299 Mtetra
.635 .735 .921 r
.34691 .65377 .35253 .65897 .3616 .65671 .35599 .65159 Mtetra
.64 .74 .921 r
.35599 .65159 .3616 .65671 .37071 .65441 .36512 .64927 Mtetra
.637 .739 .922 r
.36512 .64927 .37071 .65441 .37984 .65232 .37427 .64701 Mtetra
.611 .725 .927 r
.37427 .64701 .37984 .65232 .38893 .65215 .38344 .64529 Mtetra
.921 .705 .593 r
.38344 .64529 .38893 .65215 .3984 .64273 .39518 .57699 Mtetra
0 0 .44 r
.39518 .57699 .3984 .64273 .40757 .64216 .40207 .63659 Mtetra
.62 .72 .917 r
.40207 .63659 .40757 .64216 .41683 .6399 .41134 .6347 Mtetra
.644 .742 .92 r
.41134 .6347 .41683 .6399 .42614 .63736 .42066 .63223 Mtetra
.651 .747 .92 r
.42066 .63223 .42614 .63736 .43548 .63469 .43003 .6296 Mtetra
.654 .75 .92 r
.43003 .6296 .43548 .63469 .44486 .63196 .43942 .62687 Mtetra
.657 .752 .92 r
.43942 .62687 .44486 .63196 .45427 .62917 .44885 .62408 Mtetra
.658 .753 .92 r
.44885 .62408 .45427 .62917 .46371 .62634 .45832 .62125 Mtetra
.659 .754 .92 r
.45832 .62125 .46371 .62634 .47319 .62349 .46781 .61839 Mtetra
.46781 .61839 .47319 .62349 .4827 .62063 .47734 .61551 Mtetra
.47734 .61551 .4827 .62063 .49224 .61776 .48691 .61262 Mtetra
.48691 .61262 .49224 .61776 .50181 .61489 .4965 .60973 Mtetra
.658 .753 .92 r
.4965 .60973 .50181 .61489 .51142 .61202 .50613 .60683 Mtetra
.50613 .60683 .51142 .61202 .52106 .60914 .5158 .60393 Mtetra
.5158 .60393 .52106 .60914 .53074 .60626 .52549 .60103 Mtetra
.52549 .60103 .53074 .60626 .54044 .60337 .53522 .59812 Mtetra
.53522 .59812 .54044 .60337 .55019 .60047 .54499 .5952 Mtetra
.54499 .5952 .55019 .60047 .55996 .59756 .55479 .59228 Mtetra
.55479 .59228 .55996 .59756 .56977 .59465 .56462 .58934 Mtetra
.657 .753 .92 r
.56462 .58934 .56977 .59465 .57962 .59173 .57449 .5864 Mtetra
.57449 .5864 .57962 .59173 .5895 .5888 .5844 .58345 Mtetra
.5844 .58345 .5895 .5888 .59942 .58586 .59434 .58049 Mtetra
.657 .752 .92 r
.59434 .58049 .59942 .58586 .60937 .58291 .60431 .57752 Mtetra
.60431 .57752 .60937 .58291 .61935 .57995 .61432 .57454 Mtetra
.61432 .57454 .61935 .57995 .62938 .57698 .62437 .57155 Mtetra
.62437 .57155 .62938 .57698 .63943 .574 .63445 .56856 Mtetra
.63445 .56856 .63943 .574 .64953 .57102 .64457 .56555 Mtetra
.64457 .56555 .64953 .57102 .65966 .56802 .65472 .56253 Mtetra
.65472 .56253 .65966 .56802 .66982 .56501 .66492 .5595 Mtetra
.66492 .5595 .66982 .56501 .68003 .56199 .67514 .55646 Mtetra
.67514 .55646 .68003 .56199 .69027 .55896 .68541 .55341 Mtetra
.68541 .55341 .69027 .55896 .70054 .55593 .69571 .55036 Mtetra
.69571 .55036 .70054 .55593 .71086 .55288 .70605 .54729 Mtetra
.70605 .54729 .71086 .55288 .72121 .54982 .71643 .54421 Mtetra
.71643 .54421 .72121 .54982 .7316 .54675 .72684 .54111 Mtetra
.72684 .54111 .7316 .54675 .74202 .54367 .7373 .53801 Mtetra
.7373 .53801 .74202 .54367 .75249 .54057 .74779 .5349 Mtetra
.74779 .5349 .75249 .54057 .76299 .53747 .75832 .53178 Mtetra
.75832 .53178 .76299 .53747 .77353 .53436 .76889 .52864 Mtetra
.76889 .52864 .77353 .53436 .78411 .53123 .7795 .5255 Mtetra
.7795 .5255 .78411 .53123 .79473 .5281 .79014 .52234 Mtetra
.79014 .52234 .79473 .5281 .80539 .52495 .80083 .51917 Mtetra
.80083 .51917 .80539 .52495 .81609 .52179 .81156 .51599 Mtetra
.81156 .51599 .81609 .52179 .82683 .51863 .82232 .5128 Mtetra
.82232 .5128 .82683 .51863 .8376 .51544 .83313 .5096 Mtetra
.83313 .5096 .8376 .51544 .84842 .51225 .84397 .50638 Mtetra
.84397 .50638 .84842 .51225 .85928 .50905 .85486 .50316 Mtetra
.85486 .50316 .85928 .50905 .87017 .50583 .86579 .49992 Mtetra
.86579 .49992 .87017 .50583 .88111 .50261 .87675 .49667 Mtetra
.87675 .49667 .88111 .50261 .89209 .49937 .88776 .49341 Mtetra
.88776 .49341 .89209 .49937 .90311 .49612 .89881 .49014 Mtetra
.89881 .49014 .90311 .49612 .91417 .49285 .90991 .48685 Mtetra
.90991 .48685 .91417 .49285 .92528 .48958 .92104 .48355 Mtetra
.92104 .48355 .92528 .48958 .93642 .48629 .93222 .48024 Mtetra
.93222 .48024 .93642 .48629 .94761 .48299 .94343 .47692 Mtetra
.626 .727 .92 r
.34126 .64841 .34691 .65377 .35599 .65159 .35035 .64641 Mtetra
.639 .739 .921 r
.35035 .64641 .35599 .65159 .36512 .64927 .35949 .6441 Mtetra
.64 .74 .922 r
.35949 .6441 .36512 .64927 .37427 .64701 .36867 .64177 Mtetra
.63 .735 .923 r
.36867 .64177 .37427 .64701 .38344 .64529 .37787 .63964 Mtetra
.527 .684 .938 r
.37787 .63964 .38344 .64529 .39518 .57699 .38703 .63943 Mtetra
.501 .266 .49 r
.38703 .63943 .39518 .57699 .40207 .63659 .39658 .62994 Mtetra
.565 .663 .903 r
.39658 .62994 .40207 .63659 .41134 .6347 .40582 .62934 Mtetra
.637 .735 .919 r
.40582 .62934 .41134 .6347 .42066 .63223 .41516 .62704 Mtetra
.648 .745 .92 r
.41516 .62704 .42066 .63223 .43003 .6296 .42453 .62445 Mtetra
.653 .749 .92 r
.42453 .62445 .43003 .6296 .43942 .62687 .43395 .62174 Mtetra
.656 .751 .92 r
.43395 .62174 .43942 .62687 .44885 .62408 .4434 .61895 Mtetra
.657 .752 .92 r
.4434 .61895 .44885 .62408 .45832 .62125 .45289 .61612 Mtetra
.658 .753 .92 r
.45289 .61612 .45832 .62125 .46781 .61839 .46241 .61325 Mtetra
.659 .754 .92 r
.46241 .61325 .46781 .61839 .47734 .61551 .47196 .61035 Mtetra
.47196 .61035 .47734 .61551 .48691 .61262 .48154 .60744 Mtetra
.48154 .60744 .48691 .61262 .4965 .60973 .49116 .60453 Mtetra
.49116 .60453 .4965 .60973 .50613 .60683 .50081 .60161 Mtetra
.658 .753 .92 r
.50081 .60161 .50613 .60683 .5158 .60393 .5105 .59869 Mtetra
.5105 .59869 .5158 .60393 .52549 .60103 .52022 .59577 Mtetra
.52022 .59577 .52549 .60103 .53522 .59812 .52997 .59284 Mtetra
.52997 .59284 .53522 .59812 .54499 .5952 .53976 .5899 Mtetra
.53976 .5899 .54499 .5952 .55479 .59228 .54958 .58695 Mtetra
.54958 .58695 .55479 .59228 .56462 .58934 .55944 .584 Mtetra
.657 .753 .92 r
.55944 .584 .56462 .58934 .57449 .5864 .56933 .58104 Mtetra
.56933 .58104 .57449 .5864 .5844 .58345 .57926 .57807 Mtetra
.57926 .57807 .5844 .58345 .59434 .58049 .58922 .57509 Mtetra
.657 .752 .92 r
.58922 .57509 .59434 .58049 .60431 .57752 .59922 .5721 Mtetra
.59922 .5721 .60431 .57752 .61432 .57454 .60926 .5691 Mtetra
.60926 .5691 .61432 .57454 .62437 .57155 .61933 .56609 Mtetra
.61933 .56609 .62437 .57155 .63445 .56856 .62943 .56307 Mtetra
.62943 .56307 .63445 .56856 .64457 .56555 .63958 .56004 Mtetra
.63958 .56004 .64457 .56555 .65472 .56253 .64976 .557 Mtetra
.64976 .557 .65472 .56253 .66492 .5595 .65997 .55396 Mtetra
.65997 .55396 .66492 .5595 .67514 .55646 .67023 .5509 Mtetra
.67023 .5509 .67514 .55646 .68541 .55341 .68052 .54783 Mtetra
.68052 .54783 .68541 .55341 .69571 .55036 .69085 .54475 Mtetra
.69085 .54475 .69571 .55036 .70605 .54729 .70121 .54166 Mtetra
.70121 .54166 .70605 .54729 .71643 .54421 .71162 .53856 Mtetra
.71162 .53856 .71643 .54421 .72684 .54111 .72206 .53544 Mtetra
.72206 .53544 .72684 .54111 .7373 .53801 .73254 .53232 Mtetra
.73254 .53232 .7373 .53801 .74779 .5349 .74306 .52919 Mtetra
.74306 .52919 .74779 .5349 .75832 .53178 .75362 .52604 Mtetra
.75362 .52604 .75832 .53178 .76889 .52864 .76421 .52289 Mtetra
.76421 .52289 .76889 .52864 .7795 .5255 .77485 .51972 Mtetra
.77485 .51972 .7795 .5255 .79014 .52234 .78552 .51654 Mtetra
.78552 .51654 .79014 .52234 .80083 .51917 .79624 .51335 Mtetra
.79624 .51335 .80083 .51917 .81156 .51599 .80699 .51015 Mtetra
.80699 .51015 .81156 .51599 .82232 .5128 .81778 .50693 Mtetra
.81778 .50693 .82232 .5128 .83313 .5096 .82862 .50371 Mtetra
.82862 .50371 .83313 .5096 .84397 .50638 .83949 .50047 Mtetra
.83949 .50047 .84397 .50638 .85486 .50316 .85041 .49723 Mtetra
.85041 .49723 .85486 .50316 .86579 .49992 .86137 .49397 Mtetra
.86137 .49397 .86579 .49992 .87675 .49667 .87236 .49069 Mtetra
.87236 .49069 .87675 .49667 .88776 .49341 .8834 .48741 Mtetra
.8834 .48741 .88776 .49341 .89881 .49014 .89448 .48411 Mtetra
.89448 .48411 .89881 .49014 .90991 .48685 .90561 .4808 Mtetra
.90561 .4808 .90991 .48685 .92104 .48355 .91677 .47748 Mtetra
.91677 .47748 .92104 .48355 .93222 .48024 .92798 .47415 Mtetra
.92798 .47415 .93222 .48024 .94343 .47692 .93923 .4708 Mtetra
.603 .705 .916 r
.3356 .64262 .34126 .64841 .35035 .64641 .34468 .64113 Mtetra
.635 .735 .921 r
.34468 .64113 .35035 .64641 .35949 .6441 .35383 .6389 Mtetra
.64 .74 .921 r
.35383 .6389 .35949 .6441 .36867 .64177 .36303 .63654 Mtetra
.637 .739 .922 r
.36303 .63654 .36867 .64177 .37787 .63964 .37226 .63424 Mtetra
.611 .725 .927 r
.37226 .63424 .37787 .63964 .38703 .63943 .38149 .63248 Mtetra
.922 .706 .592 r
.38149 .63248 .38703 .63943 .39658 .62994 .39336 .56386 Mtetra
0 0 .436 r
.39336 .56386 .39658 .62994 .40582 .62934 .40027 .62367 Mtetra
.62 .72 .917 r
.40027 .62367 .40582 .62934 .41516 .62704 .40961 .62174 Mtetra
.644 .742 .92 r
.40961 .62174 .41516 .62704 .42453 .62445 .41901 .61924 Mtetra
.651 .747 .92 r
.41901 .61924 .42453 .62445 .43395 .62174 .42844 .61656 Mtetra
.654 .75 .92 r
.42844 .61656 .43395 .62174 .4434 .61895 .43792 .61378 Mtetra
.657 .752 .92 r
.43792 .61378 .4434 .61895 .45289 .61612 .44742 .61095 Mtetra
.658 .753 .92 r
.44742 .61095 .45289 .61612 .46241 .61325 .45696 .60807 Mtetra
.659 .754 .92 r
.45696 .60807 .46241 .61325 .47196 .61035 .46653 .60516 Mtetra
.46653 .60516 .47196 .61035 .48154 .60744 .47614 .60224 Mtetra
.47614 .60224 .48154 .60744 .49116 .60453 .48578 .5993 Mtetra
.48578 .5993 .49116 .60453 .50081 .60161 .49546 .59636 Mtetra
.658 .753 .92 r
.49546 .59636 .50081 .60161 .5105 .59869 .50516 .59342 Mtetra
.50516 .59342 .5105 .59869 .52022 .59577 .51491 .59047 Mtetra
.51491 .59047 .52022 .59577 .52997 .59284 .52468 .58752 Mtetra
.52468 .58752 .52997 .59284 .53976 .5899 .53449 .58456 Mtetra
.53449 .58456 .53976 .5899 .54958 .58695 .54434 .58159 Mtetra
.54434 .58159 .54958 .58695 .55944 .584 .55422 .57862 Mtetra
.55422 .57862 .55944 .584 .56933 .58104 .56414 .57564 Mtetra
.657 .753 .92 r
.56414 .57564 .56933 .58104 .57926 .57807 .57409 .57265 Mtetra
.57409 .57265 .57926 .57807 .58922 .57509 .58408 .56965 Mtetra
.58408 .56965 .58922 .57509 .59922 .5721 .5941 .56664 Mtetra
.657 .752 .92 r
.5941 .56664 .59922 .5721 .60926 .5691 .60416 .56362 Mtetra
.60416 .56362 .60926 .5691 .61933 .56609 .61425 .56059 Mtetra
.61425 .56059 .61933 .56609 .62943 .56307 .62438 .55755 Mtetra
.62438 .55755 .62943 .56307 .63958 .56004 .63455 .5545 Mtetra
.63455 .5545 .63958 .56004 .64976 .557 .64476 .55144 Mtetra
.64476 .55144 .64976 .557 .65997 .55396 .655 .54837 Mtetra
.655 .54837 .65997 .55396 .67023 .5509 .66528 .54529 Mtetra
.66528 .54529 .67023 .5509 .68052 .54783 .67559 .5422 Mtetra
.67559 .5422 .68052 .54783 .69085 .54475 .68595 .5391 Mtetra
.68595 .5391 .69085 .54475 .70121 .54166 .69634 .53599 Mtetra
.69634 .53599 .70121 .54166 .71162 .53856 .70677 .53287 Mtetra
.70677 .53287 .71162 .53856 .72206 .53544 .71724 .52973 Mtetra
.71724 .52973 .72206 .53544 .73254 .53232 .72775 .52659 Mtetra
.72775 .52659 .73254 .53232 .74306 .52919 .73829 .52343 Mtetra
.73829 .52343 .74306 .52919 .75362 .52604 .74888 .52027 Mtetra
.74888 .52027 .75362 .52604 .76421 .52289 .7595 .51709 Mtetra
.7595 .51709 .76421 .52289 .77485 .51972 .77017 .5139 Mtetra
.77017 .5139 .77485 .51972 .78552 .51654 .78087 .5107 Mtetra
.78087 .5107 .78552 .51654 .79624 .51335 .79161 .50749 Mtetra
.79161 .50749 .79624 .51335 .80699 .51015 .80239 .50426 Mtetra
.80239 .50426 .80699 .51015 .81778 .50693 .81322 .50103 Mtetra
.81322 .50103 .81778 .50693 .82862 .50371 .82408 .49778 Mtetra
.82408 .49778 .82862 .50371 .83949 .50047 .83499 .49452 Mtetra
.83499 .49452 .83949 .50047 .85041 .49723 .84593 .49125 Mtetra
.84593 .49125 .85041 .49723 .86137 .49397 .85692 .48797 Mtetra
.85692 .48797 .86137 .49397 .87236 .49069 .86794 .48467 Mtetra
.86794 .48467 .87236 .49069 .8834 .48741 .87901 .48137 Mtetra
.87901 .48137 .8834 .48741 .89448 .48411 .89013 .47805 Mtetra
.89013 .47805 .89448 .48411 .90561 .4808 .90128 .47472 Mtetra
.90128 .47472 .90561 .4808 .91677 .47748 .91248 .47137 Mtetra
.91248 .47137 .91677 .47748 .92798 .47415 .92371 .46801 Mtetra
.92371 .46801 .92798 .47415 .93923 .4708 .935 .46465 Mtetra
.496 .594 .882 r
.33002 .63472 .3356 .64262 .34468 .64113 .33898 .63569 Mtetra
.626 .727 .92 r
.33898 .63569 .34468 .64113 .35383 .6389 .34814 .63364 Mtetra
.639 .739 .921 r
.34814 .63364 .35383 .6389 .36303 .63654 .35735 .6313 Mtetra
.64 .74 .922 r
.35735 .6313 .36303 .63654 .37226 .63424 .3666 .62892 Mtetra
.63 .735 .923 r
.3666 .62892 .37226 .63424 .38149 .63248 .37587 .62675 Mtetra
.527 .684 .938 r
.37587 .62675 .38149 .63248 .39336 .56386 .3851 .62651 Mtetra
.498 .262 .487 r
.3851 .62651 .39336 .56386 .40027 .62367 .39473 .61693 Mtetra
.565 .663 .903 r
.39473 .61693 .40027 .62367 .40961 .62174 .40404 .6163 Mtetra
.637 .735 .919 r
.40404 .6163 .40961 .62174 .41901 .61924 .41345 .61396 Mtetra
.648 .745 .92 r
.41345 .61396 .41901 .61924 .42844 .61656 .4229 .61132 Mtetra
.653 .749 .92 r
.4229 .61132 .42844 .61656 .43792 .61378 .43239 .60857 Mtetra
.656 .751 .92 r
.43239 .60857 .43792 .61378 .44742 .61095 .44192 .60574 Mtetra
.657 .752 .92 r
.44192 .60574 .44742 .61095 .45696 .60807 .45148 .60286 Mtetra
.658 .753 .92 r
.45148 .60286 .45696 .60807 .46653 .60516 .46108 .59994 Mtetra
.659 .754 .92 r
.46108 .59994 .46653 .60516 .47614 .60224 .47071 .59699 Mtetra
.47071 .59699 .47614 .60224 .48578 .5993 .48037 .59404 Mtetra
.48037 .59404 .48578 .5993 .49546 .59636 .49006 .59108 Mtetra
.49006 .59108 .49546 .59636 .50516 .59342 .4998 .58811 Mtetra
.658 .753 .92 r
.4998 .58811 .50516 .59342 .51491 .59047 .50956 .58514 Mtetra
.50956 .58514 .51491 .59047 .52468 .58752 .51936 .58217 Mtetra
.51936 .58217 .52468 .58752 .53449 .58456 .52919 .57919 Mtetra
.52919 .57919 .53449 .58456 .54434 .58159 .53906 .5762 Mtetra
.53906 .5762 .54434 .58159 .55422 .57862 .54897 .57321 Mtetra
.54897 .57321 .55422 .57862 .56414 .57564 .55891 .5702 Mtetra
.657 .753 .92 r
.55891 .5702 .56414 .57564 .57409 .57265 .56888 .56719 Mtetra
.56888 .56719 .57409 .57265 .58408 .56965 .57889 .56417 Mtetra
.57889 .56417 .58408 .56965 .5941 .56664 .58894 .56114 Mtetra
.657 .752 .92 r
.58894 .56114 .5941 .56664 .60416 .56362 .59902 .5581 Mtetra
.59902 .5581 .60416 .56362 .61425 .56059 .60914 .55505 Mtetra
.60914 .55505 .61425 .56059 .62438 .55755 .6193 .55199 Mtetra
.6193 .55199 .62438 .55755 .63455 .5545 .62949 .54892 Mtetra
.62949 .54892 .63455 .5545 .64476 .55144 .63972 .54584 Mtetra
.63972 .54584 .64476 .55144 .655 .54837 .64999 .54275 Mtetra
.64999 .54275 .655 .54837 .66528 .54529 .6603 .53965 Mtetra
.6603 .53965 .66528 .54529 .67559 .5422 .67064 .53654 Mtetra
.67064 .53654 .67559 .5422 .68595 .5391 .68102 .53342 Mtetra
.68102 .53342 .68595 .5391 .69634 .53599 .69144 .53029 Mtetra
.69144 .53029 .69634 .53599 .70677 .53287 .70189 .52714 Mtetra
.70189 .52714 .70677 .53287 .71724 .52973 .71239 .52399 Mtetra
.71239 .52399 .71724 .52973 .72775 .52659 .72292 .52082 Mtetra
.72292 .52082 .72775 .52659 .73829 .52343 .7335 .51764 Mtetra
.7335 .51764 .73829 .52343 .74888 .52027 .74411 .51446 Mtetra
.74411 .51446 .74888 .52027 .7595 .51709 .75476 .51126 Mtetra
.75476 .51126 .7595 .51709 .77017 .5139 .76545 .50804 Mtetra
.76545 .50804 .77017 .5139 .78087 .5107 .77618 .50482 Mtetra
.77618 .50482 .78087 .5107 .79161 .50749 .78695 .50159 Mtetra
.78695 .50159 .79161 .50749 .80239 .50426 .79777 .49834 Mtetra
.79777 .49834 .80239 .50426 .81322 .50103 .80862 .49508 Mtetra
.80862 .49508 .81322 .50103 .82408 .49778 .81951 .49181 Mtetra
.81951 .49181 .82408 .49778 .83499 .49452 .83044 .48853 Mtetra
.83044 .48853 .83499 .49452 .84593 .49125 .84142 .48524 Mtetra
.84142 .48524 .84593 .49125 .85692 .48797 .85244 .48193 Mtetra
.85244 .48193 .85692 .48797 .86794 .48467 .86349 .47861 Mtetra
.86349 .47861 .86794 .48467 .87901 .48137 .87459 .47528 Mtetra
.87459 .47528 .87901 .48137 .89013 .47805 .88574 .47194 Mtetra
.88574 .47194 .89013 .47805 .90128 .47472 .89692 .46858 Mtetra
.89692 .46858 .90128 .47472 .91248 .47137 .90815 .46522 Mtetra
.90815 .46522 .91248 .47137 .92371 .46801 .91942 .46184 Mtetra
.91942 .46184 .92371 .46801 .935 .46465 .93073 .45844 Mtetra
0 0 0 r
.3233 .64605 .33002 .63472 .33898 .63569 .33326 .62981 Mtetra
.602 .705 .916 r
.33326 .62981 .33898 .63569 .34814 .63364 .34241 .62829 Mtetra
.635 .735 .921 r
.34241 .62829 .34814 .63364 .35735 .6313 .35164 .62601 Mtetra
.64 .74 .921 r
.35164 .62601 .35735 .6313 .3666 .62892 .36091 .62361 Mtetra
.637 .739 .922 r
.36091 .62361 .3666 .62892 .37587 .62675 .3702 .62126 Mtetra
.611 .725 .927 r
.3702 .62126 .37587 .62675 .3851 .62651 .37951 .61947 Mtetra
.923 .706 .59 r
.37951 .61947 .3851 .62651 .39473 .61693 .39152 .55052 Mtetra
0 0 .433 r
.39152 .55052 .39473 .61693 .40404 .6163 .39844 .61055 Mtetra
.62 .72 .917 r
.39844 .61055 .40404 .6163 .41345 .61396 .40786 .60858 Mtetra
.644 .742 .92 r
.40786 .60858 .41345 .61396 .4229 .61132 .41733 .60603 Mtetra
.651 .747 .92 r
.41733 .60603 .4229 .61132 .43239 .60857 .42684 .6033 Mtetra
.654 .75 .92 r
.42684 .6033 .43239 .60857 .44192 .60574 .43638 .60048 Mtetra
.657 .752 .92 r
.43638 .60048 .44192 .60574 .45148 .60286 .44597 .5976 Mtetra
.658 .753 .92 r
.44597 .5976 .45148 .60286 .46108 .59994 .45558 .59467 Mtetra
.659 .754 .92 r
.45558 .59467 .46108 .59994 .47071 .59699 .46523 .59172 Mtetra
.46523 .59172 .47071 .59699 .48037 .59404 .47492 .58874 Mtetra
.47492 .58874 .48037 .59404 .49006 .59108 .48464 .58576 Mtetra
.48464 .58576 .49006 .59108 .4998 .58811 .49439 .58277 Mtetra
.658 .753 .92 r
.49439 .58277 .4998 .58811 .50956 .58514 .50418 .57978 Mtetra
.50418 .57978 .50956 .58514 .51936 .58217 .514 .57678 Mtetra
.514 .57678 .51936 .58217 .52919 .57919 .52386 .57378 Mtetra
.52386 .57378 .52919 .57919 .53906 .5762 .53375 .57077 Mtetra
.53375 .57077 .53906 .5762 .54897 .57321 .54368 .56776 Mtetra
.54368 .56776 .54897 .57321 .55891 .5702 .55364 .56473 Mtetra
.55364 .56473 .55891 .5702 .56888 .56719 .56364 .5617 Mtetra
.657 .753 .92 r
.56364 .5617 .56888 .56719 .57889 .56417 .57368 .55866 Mtetra
.57368 .55866 .57889 .56417 .58894 .56114 .58375 .55561 Mtetra
.58375 .55561 .58894 .56114 .59902 .5581 .59386 .55255 Mtetra
.657 .752 .92 r
.59386 .55255 .59902 .5581 .60914 .55505 .604 .54948 Mtetra
.604 .54948 .60914 .55505 .6193 .55199 .61418 .5464 Mtetra
.61418 .5464 .6193 .55199 .62949 .54892 .6244 .54331 Mtetra
.6244 .54331 .62949 .54892 .63972 .54584 .63466 .54021 Mtetra
.63466 .54021 .63972 .54584 .64999 .54275 .64495 .53709 Mtetra
.64495 .53709 .64999 .54275 .6603 .53965 .65528 .53397 Mtetra
.65528 .53397 .6603 .53965 .67064 .53654 .66565 .53084 Mtetra
.66565 .53084 .67064 .53654 .68102 .53342 .67605 .5277 Mtetra
.67605 .5277 .68102 .53342 .69144 .53029 .6865 .52454 Mtetra
.6865 .52454 .69144 .53029 .70189 .52714 .69698 .52138 Mtetra
.69698 .52138 .70189 .52714 .71239 .52399 .70751 .5182 Mtetra
.70751 .5182 .71239 .52399 .72292 .52082 .71807 .51501 Mtetra
.71807 .51501 .72292 .52082 .7335 .51764 .72867 .51181 Mtetra
.72867 .51181 .7335 .51764 .74411 .51446 .73931 .5086 Mtetra
.73931 .5086 .74411 .51446 .75476 .51126 .74999 .50538 Mtetra
.74999 .50538 .75476 .51126 .76545 .50804 .76071 .50215 Mtetra
.76071 .50215 .76545 .50804 .77618 .50482 .77147 .4989 Mtetra
.77147 .4989 .77618 .50482 .78695 .50159 .78226 .49564 Mtetra
.78226 .49564 .78695 .50159 .79777 .49834 .79311 .49238 Mtetra
.79311 .49238 .79777 .49834 .80862 .49508 .80399 .48909 Mtetra
.80399 .48909 .80862 .49508 .81951 .49181 .81491 .4858 Mtetra
.81491 .4858 .81951 .49181 .83044 .48853 .82587 .4825 Mtetra
.82587 .4825 .83044 .48853 .84142 .48524 .83688 .47918 Mtetra
.83688 .47918 .84142 .48524 .85244 .48193 .84792 .47585 Mtetra
.84792 .47585 .85244 .48193 .86349 .47861 .85901 .47251 Mtetra
.85901 .47251 .86349 .47861 .87459 .47528 .87014 .46916 Mtetra
.87014 .46916 .87459 .47528 .88574 .47194 .88132 .46579 Mtetra
.88132 .46579 .88574 .47194 .89692 .46858 .89253 .46241 Mtetra
.89253 .46241 .89692 .46858 .90815 .46522 .90379 .45902 Mtetra
.90379 .45902 .90815 .46522 .91942 .46184 .91509 .45561 Mtetra
.91509 .45561 .91942 .46184 .93073 .45844 .92644 .4522 Mtetra
.733 .605 .715 r
.318 .63184 .3233 .64605 .33326 .62981 .32764 .62181 Mtetra
.495 .594 .882 r
.32764 .62181 .33326 .62981 .34241 .62829 .33666 .62275 Mtetra
.626 .727 .92 r
.33666 .62275 .34241 .62829 .35164 .62601 .34589 .62067 Mtetra
.639 .739 .921 r
.34589 .62067 .35164 .62601 .36091 .62361 .35518 .61828 Mtetra
.64 .74 .922 r
.35518 .61828 .36091 .62361 .3702 .62126 .3645 .61586 Mtetra
.63 .735 .923 r
.3645 .61586 .3702 .62126 .37951 .61947 .37384 .61364 Mtetra
.527 .684 .938 r
.37384 .61364 .37951 .61947 .39152 .55052 .38314 .61337 Mtetra
.494 .257 .483 r
.38314 .61337 .39152 .55052 .39844 .61055 .39285 .60372 Mtetra
.565 .663 .904 r
.39285 .60372 .39844 .61055 .40786 .60858 .40223 .60305 Mtetra
.637 .735 .919 r
.40223 .60305 .40786 .60858 .41733 .60603 .41172 .60066 Mtetra
.648 .745 .92 r
.41172 .60066 .41733 .60603 .42684 .6033 .42124 .59798 Mtetra
.653 .749 .92 r
.42124 .59798 .42684 .6033 .43638 .60048 .43081 .59518 Mtetra
.656 .751 .92 r
.43081 .59518 .43638 .60048 .44597 .5976 .44041 .5923 Mtetra
.657 .752 .92 r
.44041 .5923 .44597 .5976 .45558 .59467 .45005 .58937 Mtetra
.658 .753 .92 r
.45005 .58937 .45558 .59467 .46523 .59172 .45973 .5864 Mtetra
.659 .754 .92 r
.45973 .5864 .46523 .59172 .47492 .58874 .46943 .58341 Mtetra
.46943 .58341 .47492 .58874 .48464 .58576 .47917 .58041 Mtetra
.47917 .58041 .48464 .58576 .49439 .58277 .48895 .5774 Mtetra
.48895 .5774 .49439 .58277 .50418 .57978 .49876 .57438 Mtetra
.658 .753 .92 r
.49876 .57438 .50418 .57978 .514 .57678 .50861 .57137 Mtetra
.50861 .57137 .514 .57678 .52386 .57378 .51849 .56834 Mtetra
.51849 .56834 .52386 .57378 .53375 .57077 .5284 .56531 Mtetra
.5284 .56531 .53375 .57077 .54368 .56776 .53835 .56227 Mtetra
.53835 .56227 .54368 .56776 .55364 .56473 .54834 .55923 Mtetra
.54834 .55923 .55364 .56473 .56364 .5617 .55836 .55618 Mtetra
.657 .753 .92 r
.55836 .55618 .56364 .5617 .57368 .55866 .56842 .55311 Mtetra
.56842 .55311 .57368 .55866 .58375 .55561 .57852 .55004 Mtetra
.57852 .55004 .58375 .55561 .59386 .55255 .58865 .54696 Mtetra
.657 .752 .92 r
.58865 .54696 .59386 .55255 .604 .54948 .59882 .54387 Mtetra
.59882 .54387 .604 .54948 .61418 .5464 .60903 .54076 Mtetra
.60903 .54076 .61418 .5464 .6244 .54331 .61927 .53765 Mtetra
.61927 .53765 .6244 .54331 .63466 .54021 .62955 .53453 Mtetra
.62955 .53453 .63466 .54021 .64495 .53709 .63987 .5314 Mtetra
.63987 .5314 .64495 .53709 .65528 .53397 .65023 .52825 Mtetra
.65023 .52825 .65528 .53397 .66565 .53084 .66062 .5251 Mtetra
.66062 .5251 .66565 .53084 .67605 .5277 .67106 .52193 Mtetra
.67106 .52193 .67605 .5277 .6865 .52454 .68153 .51876 Mtetra
.68153 .51876 .6865 .52454 .69698 .52138 .69204 .51557 Mtetra
.69204 .51557 .69698 .52138 .70751 .5182 .70259 .51237 Mtetra
.70259 .51237 .70751 .5182 .71807 .51501 .71318 .50916 Mtetra
.71318 .50916 .71807 .51501 .72867 .51181 .7238 .50594 Mtetra
.7238 .50594 .72867 .51181 .73931 .5086 .73447 .50271 Mtetra
.73447 .50271 .73931 .5086 .74999 .50538 .74518 .49946 Mtetra
.74518 .49946 .74999 .50538 .76071 .50215 .75593 .49621 Mtetra
.75593 .49621 .76071 .50215 .77147 .4989 .76671 .49294 Mtetra
.76671 .49294 .77147 .4989 .78226 .49564 .77754 .48966 Mtetra
.77754 .48966 .78226 .49564 .79311 .49238 .78841 .48637 Mtetra
.78841 .48637 .79311 .49238 .80399 .48909 .79932 .48307 Mtetra
.79932 .48307 .80399 .48909 .81491 .4858 .81027 .47975 Mtetra
.81027 .47975 .81491 .4858 .82587 .4825 .82127 .47642 Mtetra
.82127 .47642 .82587 .4825 .83688 .47918 .8323 .47308 Mtetra
.8323 .47308 .83688 .47918 .84792 .47585 .84338 .46973 Mtetra
.84338 .46973 .84792 .47585 .85901 .47251 .8545 .46636 Mtetra
.8545 .46636 .85901 .47251 .87014 .46916 .86566 .46299 Mtetra
.86566 .46299 .87014 .46916 .88132 .46579 .87686 .4596 Mtetra
.87686 .4596 .88132 .46579 .89253 .46241 .88811 .45619 Mtetra
.88811 .45619 .89253 .46241 .90379 .45902 .8994 .45278 Mtetra
.8994 .45278 .90379 .45902 .91509 .45561 .91073 .44935 Mtetra
.91073 .44935 .91509 .45561 .92644 .4522 .92211 .44591 Mtetra
0 .125 .642 r
.31222 .62548 .318 .63184 .32764 .62181 .32084 .63313 Mtetra
0 0 0 r
.32084 .63313 .32764 .62181 .33666 .62275 .33089 .61679 Mtetra
.602 .705 .916 r
.33089 .61679 .33666 .62275 .34589 .62067 .34011 .61523 Mtetra
.635 .735 .921 r
.34011 .61523 .34589 .62067 .35518 .61828 .34941 .61291 Mtetra
.64 .74 .921 r
.34941 .61291 .35518 .61828 .3645 .61586 .35875 .61046 Mtetra
.637 .739 .922 r
.35875 .61046 .3645 .61586 .37384 .61364 .36812 .60807 Mtetra
.611 .725 .927 r
.36812 .60807 .37384 .61364 .38314 .61337 .3775 .60623 Mtetra
.925 .707 .589 r
.3775 .60623 .38314 .61337 .39285 .60372 .38964 .53696 Mtetra
0 0 .429 r
.38964 .53696 .39285 .60372 .40223 .60305 .39658 .59721 Mtetra
.62 .72 .917 r
.39658 .59721 .40223 .60305 .41172 .60066 .40607 .59519 Mtetra
.644 .742 .92 r
.40607 .59519 .41172 .60066 .42124 .59798 .41562 .5926 Mtetra
.651 .747 .92 r
.41562 .5926 .42124 .59798 .43081 .59518 .4252 .58982 Mtetra
.654 .75 .92 r
.4252 .58982 .43081 .59518 .44041 .5923 .43483 .58696 Mtetra
.657 .752 .92 r
.43483 .58696 .44041 .5923 .45005 .58937 .44449 .58403 Mtetra
.658 .753 .92 r
.44449 .58403 .45005 .58937 .45973 .5864 .45418 .58105 Mtetra
.659 .754 .92 r
.45418 .58105 .45973 .5864 .46943 .58341 .46391 .57805 Mtetra
.46391 .57805 .46943 .58341 .47917 .58041 .47368 .57502 Mtetra
.47368 .57502 .47917 .58041 .48895 .5774 .48347 .57199 Mtetra
.48347 .57199 .48895 .5774 .49876 .57438 .49331 .56895 Mtetra
.658 .753 .92 r
.49331 .56895 .49876 .57438 .50861 .57137 .50318 .56591 Mtetra
.50318 .56591 .50861 .57137 .51849 .56834 .51308 .56286 Mtetra
.51308 .56286 .51849 .56834 .5284 .56531 .52302 .55981 Mtetra
.52302 .55981 .5284 .56531 .53835 .56227 .53299 .55675 Mtetra
.53299 .55675 .53835 .56227 .54834 .55923 .54301 .55369 Mtetra
.54301 .55369 .54834 .55923 .55836 .55618 .55305 .55061 Mtetra
.55305 .55061 .55836 .55618 .56842 .55311 .56314 .54753 Mtetra
.657 .753 .92 r
.56314 .54753 .56842 .55311 .57852 .55004 .57326 .54443 Mtetra
.57326 .54443 .57852 .55004 .58865 .54696 .58341 .54133 Mtetra
.58341 .54133 .58865 .54696 .59882 .54387 .59361 .53822 Mtetra
.657 .752 .92 r
.59361 .53822 .59882 .54387 .60903 .54076 .60384 .53509 Mtetra
.60384 .53509 .60903 .54076 .61927 .53765 .61411 .53196 Mtetra
.61411 .53196 .61927 .53765 .62955 .53453 .62442 .52882 Mtetra
.62442 .52882 .62955 .53453 .63987 .5314 .63476 .52566 Mtetra
.63476 .52566 .63987 .5314 .65023 .52825 .64514 .5225 Mtetra
.64514 .5225 .65023 .52825 .66062 .5251 .65556 .51932 Mtetra
.65556 .51932 .66062 .5251 .67106 .52193 .66602 .51613 Mtetra
.66602 .51613 .67106 .52193 .68153 .51876 .67652 .51294 Mtetra
.67652 .51294 .68153 .51876 .69204 .51557 .68706 .50973 Mtetra
.68706 .50973 .69204 .51557 .70259 .51237 .69764 .50651 Mtetra
.69764 .50651 .70259 .51237 .71318 .50916 .70825 .50327 Mtetra
.70825 .50327 .71318 .50916 .7238 .50594 .71891 .50003 Mtetra
.71891 .50003 .7238 .50594 .73447 .50271 .7296 .49677 Mtetra
.7296 .49677 .73447 .50271 .74518 .49946 .74034 .49351 Mtetra
.74034 .49351 .74518 .49946 .75593 .49621 .75111 .49023 Mtetra
.75111 .49023 .75593 .49621 .76671 .49294 .76193 .48694 Mtetra
.76193 .48694 .76671 .49294 .77754 .48966 .77279 .48363 Mtetra
.77279 .48363 .77754 .48966 .78841 .48637 .78369 .48032 Mtetra
.78369 .48032 .78841 .48637 .79932 .48307 .79463 .47699 Mtetra
.79463 .47699 .79932 .48307 .81027 .47975 .80561 .47365 Mtetra
.80561 .47365 .81027 .47975 .82127 .47642 .81663 .4703 Mtetra
.81663 .4703 .82127 .47642 .8323 .47308 .82769 .46694 Mtetra
.82769 .46694 .8323 .47308 .84338 .46973 .8388 .46356 Mtetra
.8388 .46356 .84338 .46973 .8545 .46636 .84995 .46017 Mtetra
.84995 .46017 .8545 .46636 .86566 .46299 .86114 .45677 Mtetra
.86114 .45677 .86566 .46299 .87686 .4596 .87238 .45336 Mtetra
.87238 .45336 .87686 .4596 .88811 .45619 .88366 .44993 Mtetra
.88366 .44993 .88811 .45619 .8994 .45278 .89498 .44649 Mtetra
.89498 .44649 .8994 .45278 .91073 .44935 .90635 .44304 Mtetra
.90635 .44304 .91073 .44935 .92211 .44591 .91775 .43957 Mtetra
.567 .703 .933 r
.30636 .61977 .31222 .62548 .32084 .63313 .3155 .61881 Mtetra
.733 .605 .715 r
.3155 .61881 .32084 .63313 .33089 .61679 .32521 .6087 Mtetra
.495 .594 .882 r
.32521 .6087 .33089 .61679 .34011 .61523 .3343 .60961 Mtetra
.626 .727 .92 r
.3343 .60961 .34011 .61523 .34941 .61291 .34361 .60748 Mtetra
.639 .739 .921 r
.34361 .60748 .34941 .61291 .35875 .61046 .35296 .60505 Mtetra
.64 .74 .922 r
.35296 .60505 .35875 .61046 .36812 .60807 .36236 .60258 Mtetra
.63 .735 .923 r
.36236 .60258 .36812 .60807 .3775 .60623 .37177 .60032 Mtetra
.528 .684 .937 r
.37177 .60032 .3775 .60623 .38964 .53696 .38115 .60001 Mtetra
.491 .252 .48 r
.38115 .60001 .38964 .53696 .39658 .59721 .39094 .59028 Mtetra
.565 .663 .904 r
.39094 .59028 .39658 .59721 .40607 .59519 .40039 .58958 Mtetra
.637 .735 .919 r
.40039 .58958 .40607 .59519 .41562 .5926 .40995 .58714 Mtetra
.648 .745 .92 r
.40995 .58714 .41562 .5926 .4252 .58982 .41956 .58441 Mtetra
.653 .749 .92 r
.41956 .58441 .4252 .58982 .43483 .58696 .4292 .58156 Mtetra
.656 .751 .92 r
.4292 .58156 .43483 .58696 .44449 .58403 .43888 .57864 Mtetra
.657 .752 .92 r
.43888 .57864 .44449 .58403 .45418 .58105 .4486 .57566 Mtetra
.658 .753 .92 r
.4486 .57566 .45418 .58105 .46391 .57805 .45835 .57264 Mtetra
.659 .754 .92 r
.45835 .57264 .46391 .57805 .47368 .57502 .46814 .5696 Mtetra
.46814 .5696 .47368 .57502 .48347 .57199 .47796 .56655 Mtetra
.47796 .56655 .48347 .57199 .49331 .56895 .48782 .56349 Mtetra
.48782 .56349 .49331 .56895 .50318 .56591 .49771 .56042 Mtetra
.658 .753 .92 r
.49771 .56042 .50318 .56591 .51308 .56286 .50764 .55735 Mtetra
.50764 .55735 .51308 .56286 .52302 .55981 .5176 .55428 Mtetra
.5176 .55428 .52302 .55981 .53299 .55675 .5276 .5512 Mtetra
.5276 .5512 .53299 .55675 .54301 .55369 .53763 .54811 Mtetra
.53763 .54811 .54301 .55369 .55305 .55061 .54771 .54501 Mtetra
.54771 .54501 .55305 .55061 .56314 .54753 .55781 .5419 Mtetra
.657 .753 .92 r
.55781 .5419 .56314 .54753 .57326 .54443 .56796 .53879 Mtetra
.56796 .53879 .57326 .54443 .58341 .54133 .57814 .53566 Mtetra
.57814 .53566 .58341 .54133 .59361 .53822 .58836 .53253 Mtetra
.657 .752 .92 r
.58836 .53253 .59361 .53822 .60384 .53509 .59862 .52938 Mtetra
.59862 .52938 .60384 .53509 .61411 .53196 .60891 .52623 Mtetra
.60891 .52623 .61411 .53196 .62442 .52882 .61924 .52306 Mtetra
.61924 .52306 .62442 .52882 .63476 .52566 .62961 .51989 Mtetra
.62961 .51989 .63476 .52566 .64514 .5225 .64002 .5167 Mtetra
.64002 .5167 .64514 .5225 .65556 .51932 .65047 .5135 Mtetra
.65047 .5135 .65556 .51932 .66602 .51613 .66096 .51029 Mtetra
.66096 .51029 .66602 .51613 .67652 .51294 .67148 .50707 Mtetra
.67148 .50707 .67652 .51294 .68706 .50973 .68205 .50384 Mtetra
.68205 .50384 .68706 .50973 .69764 .50651 .69265 .5006 Mtetra
.69265 .5006 .69764 .50651 .70825 .50327 .70329 .49734 Mtetra
.70329 .49734 .70825 .50327 .71891 .50003 .71398 .49408 Mtetra
.71398 .49408 .71891 .50003 .7296 .49677 .7247 .4908 Mtetra
.7247 .4908 .7296 .49677 .74034 .49351 .73546 .48751 Mtetra
.73546 .48751 .74034 .49351 .75111 .49023 .74627 .48421 Mtetra
.74627 .48421 .75111 .49023 .76193 .48694 .75711 .48089 Mtetra
.75711 .48089 .76193 .48694 .77279 .48363 .768 .47757 Mtetra
.768 .47757 .77279 .48363 .78369 .48032 .77893 .47423 Mtetra
.77893 .47423 .78369 .48032 .79463 .47699 .7899 .47088 Mtetra
.7899 .47088 .79463 .47699 .80561 .47365 .80091 .46752 Mtetra
.80091 .46752 .80561 .47365 .81663 .4703 .81196 .46414 Mtetra
.81196 .46414 .81663 .4703 .82769 .46694 .82305 .46075 Mtetra
.82305 .46075 .82769 .46694 .8388 .46356 .83419 .45735 Mtetra
.83419 .45735 .8388 .46356 .84995 .46017 .84537 .45394 Mtetra
.84537 .45394 .84995 .46017 .86114 .45677 .8566 .45051 Mtetra
.8566 .45051 .86114 .45677 .87238 .45336 .86786 .44707 Mtetra
.86786 .44707 .87238 .45336 .88366 .44993 .87917 .44362 Mtetra
.87917 .44362 .88366 .44993 .89498 .44649 .89053 .44016 Mtetra
.89053 .44016 .89498 .44649 .90635 .44304 .90192 .43668 Mtetra
.90192 .43668 .90635 .44304 .91775 .43957 .91337 .43319 Mtetra
.613 .725 .926 r
.30046 .61421 .30636 .61977 .3155 .61881 .30966 .61235 Mtetra
0 .131 .647 r
.30966 .61235 .3155 .61881 .32521 .6087 .31834 .62 Mtetra
0 0 0 r
.31834 .62 .32521 .6087 .3343 .60961 .32848 .60355 Mtetra
.602 .705 .916 r
.32848 .60355 .3343 .60961 .34361 .60748 .33777 .60195 Mtetra
.635 .735 .921 r
.33777 .60195 .34361 .60748 .35296 .60505 .34714 .59959 Mtetra
.64 .74 .921 r
.34714 .59959 .35296 .60505 .36236 .60258 .35655 .5971 Mtetra
.637 .739 .922 r
.35655 .5971 .36236 .60258 .37177 .60032 .366 .59466 Mtetra
.611 .725 .926 r
.366 .59466 .37177 .60032 .38115 .60001 .37546 .59278 Mtetra
.926 .707 .588 r
.37546 .59278 .38115 .60001 .39094 .59028 .38773 .52318 Mtetra
0 0 .425 r
.38773 .52318 .39094 .59028 .40039 .58958 .39469 .58365 Mtetra
.62 .72 .917 r
.39469 .58365 .40039 .58958 .40995 .58714 .40425 .58159 Mtetra
.644 .742 .92 r
.40425 .58159 .40995 .58714 .41956 .58441 .41388 .57894 Mtetra
.651 .747 .92 r
.41388 .57894 .41956 .58441 .4292 .58156 .42354 .57612 Mtetra
.654 .75 .92 r
.42354 .57612 .4292 .58156 .43888 .57864 .43324 .5732 Mtetra
.657 .752 .92 r
.43324 .5732 .43888 .57864 .4486 .57566 .44298 .57022 Mtetra
.658 .753 .92 r
.44298 .57022 .4486 .57566 .45835 .57264 .45276 .5672 Mtetra
.659 .754 .92 r
.45276 .5672 .45835 .57264 .46814 .5696 .46257 .56414 Mtetra
.46257 .56414 .46814 .5696 .47796 .56655 .47241 .56107 Mtetra
.47241 .56107 .47796 .56655 .48782 .56349 .48229 .55799 Mtetra
.48229 .55799 .48782 .56349 .49771 .56042 .49221 .5549 Mtetra
.658 .753 .92 r
.49221 .5549 .49771 .56042 .50764 .55735 .50216 .5518 Mtetra
.50216 .5518 .50764 .55735 .5176 .55428 .51214 .54871 Mtetra
.51214 .54871 .5176 .55428 .5276 .5512 .52217 .5456 Mtetra
.52217 .5456 .5276 .5512 .53763 .54811 .53223 .54249 Mtetra
.53223 .54249 .53763 .54811 .54771 .54501 .54232 .53937 Mtetra
.54232 .53937 .54771 .54501 .55781 .5419 .55245 .53624 Mtetra
.55245 .53624 .55781 .5419 .56796 .53879 .56262 .53311 Mtetra
.657 .753 .92 r
.56262 .53311 .56796 .53879 .57814 .53566 .57283 .52996 Mtetra
.57283 .52996 .57814 .53566 .58836 .53253 .58307 .5268 Mtetra
.58307 .5268 .58836 .53253 .59862 .52938 .59336 .52364 Mtetra
.657 .752 .92 r
.59336 .52364 .59862 .52938 .60891 .52623 .60368 .52046 Mtetra
.60368 .52046 .60891 .52623 .61924 .52306 .61404 .51727 Mtetra
.61404 .51727 .61924 .52306 .62961 .51989 .62443 .51407 Mtetra
.62443 .51407 .62961 .51989 .64002 .5167 .63487 .51086 Mtetra
.63487 .51086 .64002 .5167 .65047 .5135 .64534 .50764 Mtetra
.64534 .50764 .65047 .5135 .66096 .51029 .65585 .50441 Mtetra
.65585 .50441 .66096 .51029 .67148 .50707 .66641 .50117 Mtetra
.66641 .50117 .67148 .50707 .68205 .50384 .677 .49791 Mtetra
.677 .49791 .68205 .50384 .69265 .5006 .68763 .49465 Mtetra
.68763 .49465 .69265 .5006 .70329 .49734 .6983 .49137 Mtetra
.6983 .49137 .70329 .49734 .71398 .49408 .70901 .48808 Mtetra
.70901 .48808 .71398 .49408 .7247 .4908 .71976 .48478 Mtetra
.71976 .48478 .7247 .4908 .73546 .48751 .73055 .48147 Mtetra
.73055 .48147 .73546 .48751 .74627 .48421 .74139 .47814 Mtetra
.74139 .47814 .74627 .48421 .75711 .48089 .75226 .47481 Mtetra
.75226 .47481 .75711 .48089 .768 .47757 .76318 .47146 Mtetra
.76318 .47146 .768 .47757 .77893 .47423 .77413 .46809 Mtetra
.77413 .46809 .77893 .47423 .7899 .47088 .78513 .46472 Mtetra
.78513 .46472 .7899 .47088 .80091 .46752 .79617 .46133 Mtetra
.79617 .46133 .80091 .46752 .81196 .46414 .80726 .45793 Mtetra
.80726 .45793 .81196 .46414 .82305 .46075 .81838 .45452 Mtetra
.81838 .45452 .82305 .46075 .83419 .45735 .82955 .4511 Mtetra
.82955 .4511 .83419 .45735 .84537 .45394 .84076 .44766 Mtetra
.84076 .44766 .84537 .45394 .8566 .45051 .85202 .44421 Mtetra
.85202 .44421 .8566 .45051 .86786 .44707 .86331 .44075 Mtetra
.86331 .44075 .86786 .44707 .87917 .44362 .87466 .43727 Mtetra
.87466 .43727 .87917 .44362 .89053 .44016 .88604 .43378 Mtetra
.88604 .43378 .89053 .44016 .90192 .43668 .89747 .43028 Mtetra
.89747 .43028 .90192 .43668 .91337 .43319 .90895 .42676 Mtetra
.624 .731 .923 r
.29451 .60867 .30046 .61421 .30966 .61235 .30375 .60655 Mtetra
.567 .703 .933 r
.30375 .60655 .30966 .61235 .31834 .62 .31296 .60555 Mtetra
.733 .606 .715 r
.31296 .60555 .31834 .62 .32848 .60355 .32275 .59536 Mtetra
.495 .594 .882 r
.32275 .59536 .32848 .60355 .33777 .60195 .33191 .59624 Mtetra
.626 .727 .92 r
.33191 .59624 .33777 .60195 .34714 .59959 .34128 .59407 Mtetra
.639 .739 .921 r
.34128 .59407 .34714 .59959 .35655 .5971 .35071 .59159 Mtetra
.64 .74 .922 r
.35071 .59159 .35655 .5971 .366 .59466 .36018 .58908 Mtetra
.63 .735 .923 r
.36018 .58908 .366 .59466 .37546 .59278 .36967 .58677 Mtetra
.528 .684 .937 r
.36967 .58677 .37546 .59278 .38773 .52318 .37912 .58643 Mtetra
.488 .248 .476 r
.37912 .58643 .38773 .52318 .39469 .58365 .38899 .57662 Mtetra
.564 .663 .904 r
.38899 .57662 .39469 .58365 .40425 .58159 .39852 .57588 Mtetra
.637 .735 .919 r
.39852 .57588 .40425 .58159 .41388 .57894 .40816 .57339 Mtetra
.648 .745 .92 r
.40816 .57339 .41388 .57894 .42354 .57612 .41784 .57062 Mtetra
.653 .749 .92 r
.41784 .57062 .42354 .57612 .43324 .5732 .42757 .56772 Mtetra
.656 .751 .92 r
.42757 .56772 .43324 .5732 .44298 .57022 .43733 .56474 Mtetra
.657 .752 .92 r
.43733 .56474 .44298 .57022 .45276 .5672 .44712 .56171 Mtetra
.658 .753 .92 r
.44712 .56171 .45276 .5672 .46257 .56414 .45696 .55865 Mtetra
.659 .754 .92 r
.45696 .55865 .46257 .56414 .47241 .56107 .46682 .55556 Mtetra
.46682 .55556 .47241 .56107 .48229 .55799 .47673 .55245 Mtetra
.47673 .55245 .48229 .55799 .49221 .5549 .48666 .54934 Mtetra
.48666 .54934 .49221 .5549 .50216 .5518 .49664 .54622 Mtetra
.658 .753 .92 r
.49664 .54622 .50216 .5518 .51214 .54871 .50665 .5431 Mtetra
.50665 .5431 .51214 .54871 .52217 .5456 .5167 .53997 Mtetra
.5167 .53997 .52217 .5456 .53223 .54249 .52678 .53684 Mtetra
.52678 .53684 .53223 .54249 .54232 .53937 .5369 .5337 Mtetra
.5369 .5337 .54232 .53937 .55245 .53624 .54706 .53055 Mtetra
.54706 .53055 .55245 .53624 .56262 .53311 .55725 .52739 Mtetra
.657 .753 .92 r
.55725 .52739 .56262 .53311 .57283 .52996 .56748 .52422 Mtetra
.56748 .52422 .57283 .52996 .58307 .5268 .57775 .52104 Mtetra
.57775 .52104 .58307 .5268 .59336 .52364 .58806 .51785 Mtetra
.657 .752 .92 r
.58806 .51785 .59336 .52364 .60368 .52046 .59841 .51465 Mtetra
.59841 .51465 .60368 .52046 .61404 .51727 .60879 .51144 Mtetra
.60879 .51144 .61404 .51727 .62443 .51407 .61921 .50822 Mtetra
.61921 .50822 .62443 .51407 .63487 .51086 .62968 .50499 Mtetra
.62968 .50499 .63487 .51086 .64534 .50764 .64018 .50174 Mtetra
.64018 .50174 .64534 .50764 .65585 .50441 .65072 .49849 Mtetra
.65072 .49849 .65585 .50441 .66641 .50117 .66129 .49522 Mtetra
.66129 .49522 .66641 .50117 .677 .49791 .67191 .49195 Mtetra
.67191 .49195 .677 .49791 .68763 .49465 .68257 .48866 Mtetra
.68257 .48866 .68763 .49465 .6983 .49137 .69327 .48536 Mtetra
.69327 .48536 .6983 .49137 .70901 .48808 .70401 .48205 Mtetra
.70401 .48205 .70901 .48808 .71976 .48478 .71479 .47872 Mtetra
.71479 .47872 .71976 .48478 .73055 .48147 .72561 .47539 Mtetra
.72561 .47539 .73055 .48147 .74139 .47814 .73647 .47204 Mtetra
.73647 .47204 .74139 .47814 .75226 .47481 .74738 .46868 Mtetra
.74738 .46868 .75226 .47481 .76318 .47146 .75832 .4653 Mtetra
.75832 .4653 .76318 .47146 .77413 .46809 .76931 .46192 Mtetra
.76931 .46192 .77413 .46809 .78513 .46472 .78034 .45852 Mtetra
.78034 .45852 .78513 .46472 .79617 .46133 .79141 .45511 Mtetra
.79141 .45511 .79617 .46133 .80726 .45793 .80252 .45168 Mtetra
.80252 .45168 .80726 .45793 .81838 .45452 .81368 .44825 Mtetra
.81368 .44825 .81838 .45452 .82955 .4511 .82488 .4448 Mtetra
.82488 .4448 .82955 .4511 .84076 .44766 .83612 .44134 Mtetra
.83612 .44134 .84076 .44766 .85202 .44421 .8474 .43786 Mtetra
.8474 .43786 .85202 .44421 .86331 .44075 .85873 .43437 Mtetra
.85873 .43437 .86331 .44075 .87466 .43727 .87011 .43087 Mtetra
.87011 .43087 .87466 .43727 .88604 .43378 .88153 .42736 Mtetra
.88153 .42736 .88604 .43378 .89747 .43028 .89299 .42383 Mtetra
.89299 .42383 .89747 .43028 .90895 .42676 .9045 .42029 Mtetra
.626 .731 .922 r
.28853 .60308 .29451 .60867 .30375 .60655 .29778 .60091 Mtetra
.613 .725 .926 r
.29778 .60091 .30375 .60655 .31296 .60555 .30706 .59901 Mtetra
0 .136 .652 r
.30706 .59901 .31296 .60555 .32275 .59536 .3158 .60666 Mtetra
0 0 0 r
.3158 .60666 .32275 .59536 .33191 .59624 .32603 .5901 Mtetra
.602 .705 .917 r
.32603 .5901 .33191 .59624 .34128 .59407 .33539 .58845 Mtetra
.635 .735 .921 r
.33539 .58845 .34128 .59407 .35071 .59159 .34484 .58605 Mtetra
.64 .74 .921 r
.34484 .58605 .35071 .59159 .36018 .58908 .35432 .58351 Mtetra
.637 .739 .922 r
.35432 .58351 .36018 .58908 .36967 .58677 .36384 .58103 Mtetra
.611 .725 .926 r
.36384 .58103 .36967 .58677 .37912 .58643 .37337 .5791 Mtetra
.927 .708 .586 r
.37337 .5791 .37912 .58643 .38899 .57662 .38578 .50917 Mtetra
0 0 .421 r
.38578 .50917 .38899 .57662 .39852 .57588 .39277 .56985 Mtetra
.62 .72 .917 r
.39277 .56985 .39852 .57588 .40816 .57339 .40241 .56775 Mtetra
.644 .742 .92 r
.40241 .56775 .40816 .57339 .41784 .57062 .41211 .56505 Mtetra
.651 .747 .92 r
.41211 .56505 .41784 .57062 .42757 .56772 .42185 .56218 Mtetra
.654 .75 .92 r
.42185 .56218 .42757 .56772 .43733 .56474 .43163 .55922 Mtetra
.657 .752 .92 r
.43163 .55922 .43733 .56474 .44712 .56171 .44145 .55619 Mtetra
.658 .753 .92 r
.44145 .55619 .44712 .56171 .45696 .55865 .45131 .55311 Mtetra
.659 .754 .92 r
.45131 .55311 .45696 .55865 .46682 .55556 .4612 .55 Mtetra
.4612 .55 .46682 .55556 .47673 .55245 .47112 .54688 Mtetra
.47112 .54688 .47673 .55245 .48666 .54934 .48109 .54374 Mtetra
.48109 .54374 .48666 .54934 .49664 .54622 .49108 .5406 Mtetra
.658 .753 .92 r
.49108 .5406 .49664 .54622 .50665 .5431 .50112 .53746 Mtetra
.50112 .53746 .50665 .5431 .5167 .53997 .51119 .5343 Mtetra
.51119 .5343 .5167 .53997 .52678 .53684 .5213 .53115 Mtetra
.5213 .53115 .52678 .53684 .5369 .5337 .53144 .52798 Mtetra
.53144 .52798 .5369 .5337 .54706 .53055 .54162 .52481 Mtetra
.54162 .52481 .54706 .53055 .55725 .52739 .55184 .52163 Mtetra
.55184 .52163 .55725 .52739 .56748 .52422 .5621 .51844 Mtetra
.657 .753 .92 r
.5621 .51844 .56748 .52422 .57775 .52104 .5724 .51524 Mtetra
.5724 .51524 .57775 .52104 .58806 .51785 .58273 .51202 Mtetra
.58273 .51202 .58806 .51785 .59841 .51465 .5931 .5088 Mtetra
.657 .752 .92 r
.5931 .5088 .59841 .51465 .60879 .51144 .60351 .50557 Mtetra
.60351 .50557 .60879 .51144 .61921 .50822 .61396 .50233 Mtetra
.61396 .50233 .61921 .50822 .62968 .50499 .62445 .49907 Mtetra
.62445 .49907 .62968 .50499 .64018 .50174 .63498 .49581 Mtetra
.63498 .49581 .64018 .50174 .65072 .49849 .64554 .49253 Mtetra
.64554 .49253 .65072 .49849 .66129 .49522 .65615 .48924 Mtetra
.65615 .48924 .66129 .49522 .67191 .49195 .66679 .48594 Mtetra
.66679 .48594 .67191 .49195 .68257 .48866 .67748 .48263 Mtetra
.67748 .48263 .68257 .48866 .69327 .48536 .68821 .4793 Mtetra
.68821 .4793 .69327 .48536 .70401 .48205 .69897 .47597 Mtetra
.69897 .47597 .70401 .48205 .71479 .47872 .70978 .47262 Mtetra
.70978 .47262 .71479 .47872 .72561 .47539 .72063 .46926 Mtetra
.72063 .46926 .72561 .47539 .73647 .47204 .73152 .46589 Mtetra
.73152 .46589 .73647 .47204 .74738 .46868 .74246 .4625 Mtetra
.74246 .4625 .74738 .46868 .75832 .4653 .75343 .45911 Mtetra
.75343 .45911 .75832 .4653 .76931 .46192 .76445 .4557 Mtetra
.76445 .4557 .76931 .46192 .78034 .45852 .7755 .45227 Mtetra
.7755 .45227 .78034 .45852 .79141 .45511 .78661 .44884 Mtetra
.78661 .44884 .79141 .45511 .80252 .45168 .79775 .44539 Mtetra
.79775 .44539 .80252 .45168 .81368 .44825 .80894 .44193 Mtetra
.80894 .44193 .81368 .44825 .82488 .4448 .82017 .43846 Mtetra
.82017 .43846 .82488 .4448 .83612 .44134 .83144 .43497 Mtetra
.83144 .43497 .83612 .44134 .8474 .43786 .84276 .43147 Mtetra
.84276 .43147 .8474 .43786 .85873 .43437 .85412 .42795 Mtetra
.85412 .42795 .85873 .43437 .87011 .43087 .86553 .42443 Mtetra
.86553 .42443 .87011 .43087 .88153 .42736 .87698 .42089 Mtetra
.87698 .42089 .88153 .42736 .89299 .42383 .88847 .41733 Mtetra
.88847 .41733 .89299 .42383 .9045 .42029 .90001 .41377 Mtetra
.621 .725 .921 r
.28251 .59734 .28853 .60308 .29778 .60091 .29178 .59528 Mtetra
.624 .731 .923 r
.29178 .59528 .29778 .60091 .30706 .59901 .30109 .59312 Mtetra
.567 .703 .933 r
.30109 .59312 .30706 .59901 .3158 .60666 .31037 .59208 Mtetra
.733 .606 .715 r
.31037 .59208 .3158 .60666 .32603 .5901 .32024 .58181 Mtetra
.494 .594 .882 r
.32024 .58181 .32603 .5901 .33539 .58845 .32947 .58266 Mtetra
.626 .727 .92 r
.32947 .58266 .33539 .58845 .34484 .58605 .33892 .58044 Mtetra
.639 .739 .921 r
.33892 .58044 .34484 .58605 .35432 .58351 .34843 .57791 Mtetra
.64 .74 .922 r
.34843 .57791 .35432 .58351 .36384 .58103 .35797 .57535 Mtetra
.63 .735 .923 r
.35797 .57535 .36384 .58103 .37337 .5791 .36754 .573 Mtetra
.528 .684 .937 r
.36754 .573 .37337 .5791 .38578 .50917 .37706 .57262 Mtetra
.484 .243 .472 r
.37706 .57262 .38578 .50917 .39277 .56985 .38702 .56273 Mtetra
.564 .663 .904 r
.38702 .56273 .39277 .56985 .40241 .56775 .39662 .56195 Mtetra
.637 .735 .919 r
.39662 .56195 .40241 .56775 .41211 .56505 .40634 .55941 Mtetra
.648 .745 .92 r
.40634 .55941 .41211 .56505 .42185 .56218 .4161 .55659 Mtetra
.653 .749 .92 r
.4161 .55659 .42185 .56218 .43163 .55922 .4259 .55364 Mtetra
.656 .751 .92 r
.4259 .55364 .43163 .55922 .44145 .55619 .43574 .55061 Mtetra
.657 .752 .92 r
.43574 .55061 .44145 .55619 .45131 .55311 .44562 .54753 Mtetra
.658 .753 .92 r
.44562 .54753 .45131 .55311 .4612 .55 .45553 .54441 Mtetra
.659 .754 .92 r
.45553 .54441 .4612 .55 .47112 .54688 .46548 .54127 Mtetra
.46548 .54127 .47112 .54688 .48109 .54374 .47547 .53811 Mtetra
.47547 .53811 .48109 .54374 .49108 .5406 .48549 .53494 Mtetra
.48549 .53494 .49108 .5406 .50112 .53746 .49555 .53177 Mtetra
.658 .753 .92 r
.49555 .53177 .50112 .53746 .51119 .5343 .50565 .5286 Mtetra
.50565 .5286 .51119 .5343 .5213 .53115 .51578 .52542 Mtetra
.51578 .52542 .5213 .53115 .53144 .52798 .52595 .52223 Mtetra
.52595 .52223 .53144 .52798 .54162 .52481 .53615 .51903 Mtetra
.53615 .51903 .54162 .52481 .55184 .52163 .5464 .51583 Mtetra
.5464 .51583 .55184 .52163 .5621 .51844 .55668 .51262 Mtetra
.657 .753 .92 r
.55668 .51262 .5621 .51844 .5724 .51524 .567 .50939 Mtetra
.567 .50939 .5724 .51524 .58273 .51202 .57736 .50616 Mtetra
.57736 .50616 .58273 .51202 .5931 .5088 .58776 .50291 Mtetra
.657 .752 .92 r
.58776 .50291 .5931 .5088 .60351 .50557 .59819 .49966 Mtetra
.59819 .49966 .60351 .50557 .61396 .50233 .60867 .49639 Mtetra
.60867 .49639 .61396 .50233 .62445 .49907 .61918 .49311 Mtetra
.61918 .49311 .62445 .49907 .63498 .49581 .62974 .48982 Mtetra
.62974 .48982 .63498 .49581 .64554 .49253 .64033 .48652 Mtetra
.64033 .48652 .64554 .49253 .65615 .48924 .65097 .48321 Mtetra
.65097 .48321 .65615 .48924 .66679 .48594 .66164 .47989 Mtetra
.66164 .47989 .66679 .48594 .67748 .48263 .67235 .47655 Mtetra
.67235 .47655 .67748 .48263 .68821 .4793 .68311 .47321 Mtetra
.68311 .47321 .68821 .4793 .69897 .47597 .6939 .46985 Mtetra
.6939 .46985 .69897 .47597 .70978 .47262 .70474 .46647 Mtetra
.70474 .46647 .70978 .47262 .72063 .46926 .71562 .46309 Mtetra
.71562 .46309 .72063 .46926 .73152 .46589 .72654 .45969 Mtetra
.72654 .45969 .73152 .46589 .74246 .4625 .7375 .45629 Mtetra
.7375 .45629 .74246 .4625 .75343 .45911 .7485 .45286 Mtetra
.7485 .45286 .75343 .45911 .76445 .4557 .75955 .44943 Mtetra
.75955 .44943 .76445 .4557 .7755 .45227 .77064 .44598 Mtetra
.77064 .44598 .7755 .45227 .78661 .44884 .78177 .44252 Mtetra
.78177 .44252 .78661 .44884 .79775 .44539 .79294 .43905 Mtetra
.79294 .43905 .79775 .44539 .80894 .44193 .80416 .43556 Mtetra
.80416 .43556 .80894 .44193 .82017 .43846 .81542 .43207 Mtetra
.81542 .43207 .82017 .43846 .83144 .43497 .82673 .42855 Mtetra
.82673 .42855 .83144 .43497 .84276 .43147 .83808 .42503 Mtetra
.83808 .42503 .84276 .43147 .85412 .42795 .84947 .42149 Mtetra
.84947 .42149 .85412 .42795 .86553 .42443 .86091 .41794 Mtetra
.86091 .41794 .86553 .42443 .87698 .42089 .87239 .41437 Mtetra
.87239 .41437 .87698 .42089 .88847 .41733 .88392 .41079 Mtetra
.88392 .41079 .88847 .41733 .90001 .41377 .8955 .4072 Mtetra
.602 .708 .918 r
.27648 .59125 .28251 .59734 .29178 .59528 .28574 .58959 Mtetra
.626 .731 .922 r
.28574 .58959 .29178 .59528 .30109 .59312 .29507 .58738 Mtetra
.613 .725 .926 r
.29507 .58738 .30109 .59312 .31037 .59208 .30442 .58544 Mtetra
0 .141 .658 r
.30442 .58544 .31037 .59208 .32024 .58181 .31321 .59308 Mtetra
.607 .8 .378 r
.31321 .59308 .32024 .58181 .32947 .58266 .32354 .57642 Mtetra
.602 .706 .917 r
.32354 .57642 .32947 .58266 .33892 .58044 .33297 .57473 Mtetra
.635 .735 .921 r
.33297 .57473 .33892 .58044 .34843 .57791 .34249 .57228 Mtetra
.64 .74 .921 r
.34249 .57228 .34843 .57791 .35797 .57535 .35206 .56969 Mtetra
.637 .739 .922 r
.35206 .56969 .35797 .57535 .36754 .573 .36165 .56716 Mtetra
.611 .725 .926 r
.36165 .56716 .36754 .573 .37706 .57262 .37126 .56519 Mtetra
.928 .708 .585 r
.37126 .56519 .37706 .57262 .38702 .56273 .38381 .49492 Mtetra
0 0 .417 r
.38381 .49492 .38702 .56273 .39662 .56195 .39081 .55583 Mtetra
.62 .72 .917 r
.39081 .55583 .39662 .56195 .40634 .55941 .40053 .55367 Mtetra
.644 .742 .92 r
.40053 .55367 .40634 .55941 .4161 .55659 .41031 .55093 Mtetra
.651 .747 .92 r
.41031 .55093 .4161 .55659 .4259 .55364 .42013 .54801 Mtetra
.654 .75 .92 r
.42013 .54801 .4259 .55364 .43574 .55061 .43 .54499 Mtetra
.657 .752 .92 r
.43 .54499 .43574 .55061 .44562 .54753 .4399 .54191 Mtetra
.658 .753 .92 r
.4399 .54191 .44562 .54753 .45553 .54441 .44983 .53878 Mtetra
.659 .754 .92 r
.44983 .53878 .45553 .54441 .46548 .54127 .45981 .53562 Mtetra
.45981 .53562 .46548 .54127 .47547 .53811 .46982 .53244 Mtetra
.46982 .53244 .47547 .53811 .48549 .53494 .47986 .52925 Mtetra
.47986 .52925 .48549 .53494 .49555 .53177 .48994 .52606 Mtetra
.658 .753 .92 r
.48994 .52606 .49555 .53177 .50565 .5286 .50006 .52286 Mtetra
.50006 .52286 .50565 .5286 .51578 .52542 .51022 .51965 Mtetra
.51022 .51965 .51578 .52542 .52595 .52223 .52042 .51644 Mtetra
.52042 .51644 .52595 .52223 .53615 .51903 .53065 .51322 Mtetra
.53065 .51322 .53615 .51903 .5464 .51583 .54092 .50999 Mtetra
.54092 .50999 .5464 .51583 .55668 .51262 .55122 .50676 Mtetra
.55122 .50676 .55668 .51262 .567 .50939 .56157 .50351 Mtetra
.657 .753 .92 r
.56157 .50351 .567 .50939 .57736 .50616 .57195 .50025 Mtetra
.57195 .50025 .57736 .50616 .58776 .50291 .58238 .49698 Mtetra
.58238 .49698 .58776 .50291 .59819 .49966 .59284 .4937 Mtetra
.657 .752 .92 r
.59284 .4937 .59819 .49966 .60867 .49639 .60334 .49041 Mtetra
.60334 .49041 .60867 .49639 .61918 .49311 .61388 .48711 Mtetra
.61388 .48711 .61918 .49311 .62974 .48982 .62446 .4838 Mtetra
.62446 .4838 .62974 .48982 .64033 .48652 .63509 .48048 Mtetra
.63509 .48048 .64033 .48652 .65097 .48321 .64575 .47714 Mtetra
.64575 .47714 .65097 .48321 .66164 .47989 .65645 .4738 Mtetra
.65645 .4738 .66164 .47989 .67235 .47655 .66719 .47044 Mtetra
.66719 .47044 .67235 .47655 .68311 .47321 .67797 .46707 Mtetra
.67797 .46707 .68311 .47321 .6939 .46985 .6888 .46368 Mtetra
.6888 .46368 .6939 .46985 .70474 .46647 .69966 .46029 Mtetra
.69966 .46029 .70474 .46647 .71562 .46309 .71057 .45688 Mtetra
.71057 .45688 .71562 .46309 .72654 .45969 .72152 .45346 Mtetra
.72152 .45346 .72654 .45969 .7375 .45629 .73251 .45002 Mtetra
.73251 .45002 .7375 .45629 .7485 .45286 .74354 .44658 Mtetra
.74354 .44658 .7485 .45286 .75955 .44943 .75462 .44312 Mtetra
.75462 .44312 .75955 .44943 .77064 .44598 .76574 .43965 Mtetra
.76574 .43965 .77064 .44598 .78177 .44252 .7769 .43616 Mtetra
.7769 .43616 .78177 .44252 .79294 .43905 .78811 .43267 Mtetra
.78811 .43267 .79294 .43905 .80416 .43556 .79935 .42915 Mtetra
.79935 .42915 .80416 .43556 .81542 .43207 .81065 .42563 Mtetra
.81065 .42563 .81542 .43207 .82673 .42855 .82198 .42209 Mtetra
.82198 .42209 .82673 .42855 .83808 .42503 .83337 .41854 Mtetra
.83337 .41854 .83808 .42503 .84947 .42149 .84479 .41498 Mtetra
.84479 .41498 .84947 .42149 .86091 .41794 .85626 .4114 Mtetra
.85626 .4114 .86091 .41794 .87239 .41437 .86778 .40781 Mtetra
.86778 .40781 .87239 .41437 .88392 .41079 .87934 .4042 Mtetra
.87934 .4042 .88392 .41079 .8955 .4072 .89095 .40058 Mtetra
.52 .627 .897 r
.27053 .58363 .27648 .59125 .28574 .58959 .27966 .58377 Mtetra
.621 .725 .921 r
.27966 .58377 .28574 .58959 .29507 .58738 .289 .58166 Mtetra
.624 .731 .923 r
.289 .58166 .29507 .58738 .30442 .58544 .29839 .57946 Mtetra
.567 .703 .933 r
.29839 .57946 .30442 .58544 .31321 .59308 .30774 .57837 Mtetra
.733 .606 .715 r
.30774 .57837 .31321 .59308 .32354 .57642 .31769 .56802 Mtetra
.494 .594 .882 r
.31769 .56802 .32354 .57642 .33297 .57473 .327 .56884 Mtetra
.626 .727 .92 r
.327 .56884 .33297 .57473 .34249 .57228 .33652 .56658 Mtetra
.639 .739 .921 r
.33652 .56658 .34249 .57228 .35206 .56969 .3461 .564 Mtetra
.64 .74 .922 r
.3461 .564 .35206 .56969 .36165 .56716 .35572 .56139 Mtetra
.63 .735 .923 r
.35572 .56139 .36165 .56716 .37126 .56519 .36537 .55899 Mtetra
.528 .684 .937 r
.36537 .55899 .37126 .56519 .38381 .49492 .37496 .55857 Mtetra
.48 .238 .469 r
.37496 .55857 .38381 .49492 .39081 .55583 .385 .5486 Mtetra
.564 .663 .904 r
.385 .5486 .39081 .55583 .40053 .55367 .39469 .54777 Mtetra
.637 .735 .92 r
.39469 .54777 .40053 .55367 .41031 .55093 .40448 .54519 Mtetra
.648 .745 .92 r
.40448 .54519 .41031 .55093 .42013 .54801 .41433 .54232 Mtetra
.653 .749 .92 r
.41433 .54232 .42013 .54801 .43 .54499 .42421 .53931 Mtetra
.656 .751 .92 r
.42421 .53931 .43 .54499 .4399 .54191 .43413 .53624 Mtetra
.657 .752 .92 r
.43413 .53624 .4399 .54191 .44983 .53878 .44409 .5331 Mtetra
.658 .753 .92 r
.44409 .5331 .44983 .53878 .45981 .53562 .45409 .52993 Mtetra
.659 .754 .92 r
.45409 .52993 .45981 .53562 .46982 .53244 .46412 .52673 Mtetra
.46412 .52673 .46982 .53244 .47986 .52925 .47419 .52352 Mtetra
.47419 .52352 .47986 .52925 .48994 .52606 .4843 .5203 Mtetra
.4843 .5203 .48994 .52606 .50006 .52286 .49444 .51708 Mtetra
.658 .753 .92 r
.49444 .51708 .50006 .52286 .51022 .51965 .50463 .51385 Mtetra
.50463 .51385 .51022 .51965 .52042 .51644 .51484 .51061 Mtetra
.51484 .51061 .52042 .51644 .53065 .51322 .5251 .50737 Mtetra
.5251 .50737 .53065 .51322 .54092 .50999 .5354 .50412 Mtetra
.5354 .50412 .54092 .50999 .55122 .50676 .54573 .50085 Mtetra
.54573 .50085 .55122 .50676 .56157 .50351 .5561 .49758 Mtetra
.657 .753 .92 r
.5561 .49758 .56157 .50351 .57195 .50025 .56651 .4943 Mtetra
.56651 .4943 .57195 .50025 .58238 .49698 .57696 .49101 Mtetra
.57696 .49101 .58238 .49698 .59284 .4937 .58745 .48771 Mtetra
.657 .752 .92 r
.58745 .48771 .59284 .4937 .60334 .49041 .59798 .4844 Mtetra
.59798 .4844 .60334 .49041 .61388 .48711 .60855 .48107 Mtetra
.60855 .48107 .61388 .48711 .62446 .4838 .61915 .47774 Mtetra
.61915 .47774 .62446 .4838 .63509 .48048 .6298 .47439 Mtetra
.6298 .47439 .63509 .48048 .64575 .47714 .64049 .47103 Mtetra
.64049 .47103 .64575 .47714 .65645 .4738 .65122 .46766 Mtetra
.65122 .46766 .65645 .4738 .66719 .47044 .66199 .46428 Mtetra
.66199 .46428 .66719 .47044 .67797 .46707 .6728 .46088 Mtetra
.6728 .46088 .67797 .46707 .6888 .46368 .68365 .45747 Mtetra
.68365 .45747 .6888 .46368 .69966 .46029 .69455 .45405 Mtetra
.69455 .45405 .69966 .46029 .71057 .45688 .70548 .45062 Mtetra
.70548 .45062 .71057 .45688 .72152 .45346 .71646 .44718 Mtetra
.71646 .44718 .72152 .45346 .73251 .45002 .72748 .44372 Mtetra
.72748 .44372 .73251 .45002 .74354 .44658 .73855 .44025 Mtetra
.73855 .44025 .74354 .44658 .75462 .44312 .74965 .43676 Mtetra
.74965 .43676 .75462 .44312 .76574 .43965 .7608 .43327 Mtetra
.7608 .43327 .76574 .43965 .7769 .43616 .77199 .42976 Mtetra
.77199 .42976 .7769 .43616 .78811 .43267 .78323 .42623 Mtetra
.78323 .42623 .78811 .43267 .79935 .42915 .79451 .4227 Mtetra
.79451 .4227 .79935 .42915 .81065 .42563 .80584 .41915 Mtetra
.80584 .41915 .81065 .42563 .82198 .42209 .8172 .41558 Mtetra
.8172 .41558 .82198 .42209 .83337 .41854 .82862 .41201 Mtetra
.82862 .41201 .83337 .41854 .84479 .41498 .84008 .40842 Mtetra
.84008 .40842 .84479 .41498 .85626 .4114 .85158 .40481 Mtetra
.85158 .40481 .85626 .4114 .86778 .40781 .86313 .40119 Mtetra
.86313 .40119 .86778 .40781 .87934 .4042 .87472 .39756 Mtetra
.87472 .39756 .87934 .4042 .89095 .40058 .88636 .39391 Mtetra
0 0 0 r
.26214 .60739 .27053 .58363 .27966 .58377 .27358 .57759 Mtetra
.602 .708 .919 r
.27358 .57759 .27966 .58377 .289 .58166 .2829 .57589 Mtetra
.626 .731 .922 r
.2829 .57589 .289 .58166 .29839 .57946 .2923 .57363 Mtetra
.613 .725 .926 r
.2923 .57363 .29839 .57946 .30774 .57837 .30173 .57164 Mtetra
0 .146 .663 r
.30173 .57164 .30774 .57837 .31769 .56802 .31058 .57928 Mtetra
.617 .808 .388 r
.31058 .57928 .31769 .56802 .327 .56884 .321 .56251 Mtetra
.602 .706 .917 r
.321 .56251 .327 .56884 .33652 .56658 .33051 .56077 Mtetra
.635 .735 .921 r
.33051 .56077 .33652 .56658 .3461 .564 .34011 .55827 Mtetra
.64 .74 .921 r
.34011 .55827 .3461 .564 .35572 .56139 .34975 .55563 Mtetra
.637 .739 .922 r
.34975 .55563 .35572 .56139 .36537 .55899 .35942 .55306 Mtetra
.611 .725 .926 r
.35942 .55306 .36537 .55899 .37496 .55857 .36911 .55104 Mtetra
.929 .709 .583 r
.36911 .55104 .37496 .55857 .385 .5486 .3818 .48044 Mtetra
0 0 .413 r
.3818 .48044 .385 .5486 .39469 .54777 .38882 .54156 Mtetra
.62 .72 .918 r
.38882 .54156 .39469 .54777 .40448 .54519 .39862 .53935 Mtetra
.644 .742 .92 r
.39862 .53935 .40448 .54519 .41433 .54232 .40848 .53656 Mtetra
.651 .747 .92 r
.40848 .53656 .41433 .54232 .42421 .53931 .41839 .53358 Mtetra
.654 .75 .92 r
.41839 .53358 .42421 .53931 .43413 .53624 .42833 .53051 Mtetra
.657 .752 .92 r
.42833 .53051 .43413 .53624 .44409 .5331 .43831 .52738 Mtetra
.658 .753 .92 r
.43831 .52738 .44409 .5331 .45409 .52993 .44833 .5242 Mtetra
.659 .754 .92 r
.44833 .5242 .45409 .52993 .46412 .52673 .45839 .52098 Mtetra
.45839 .52098 .46412 .52673 .47419 .52352 .46848 .51775 Mtetra
.46848 .51775 .47419 .52352 .4843 .5203 .47862 .51451 Mtetra
.47862 .51451 .4843 .5203 .49444 .51708 .48878 .51126 Mtetra
.658 .753 .92 r
.48878 .51126 .49444 .51708 .50463 .51385 .49899 .508 Mtetra
.49899 .508 .50463 .51385 .51484 .51061 .50923 .50474 Mtetra
.50923 .50474 .51484 .51061 .5251 .50737 .51952 .50147 Mtetra
.51952 .50147 .5251 .50737 .5354 .50412 .52984 .4982 Mtetra
.52984 .4982 .5354 .50412 .54573 .50085 .5402 .49491 Mtetra
.5402 .49491 .54573 .50085 .5561 .49758 .55059 .49162 Mtetra
.55059 .49162 .5561 .49758 .56651 .4943 .56103 .48831 Mtetra
.657 .753 .92 r
.56103 .48831 .56651 .4943 .57696 .49101 .57151 .485 Mtetra
.57151 .485 .57696 .49101 .58745 .48771 .58202 .48167 Mtetra
.58202 .48167 .58745 .48771 .59798 .4844 .59258 .47834 Mtetra
.657 .752 .92 r
.59258 .47834 .59798 .4844 .60855 .48107 .60317 .47499 Mtetra
.60317 .47499 .60855 .48107 .61915 .47774 .61381 .47163 Mtetra
.61381 .47163 .61915 .47774 .6298 .47439 .62448 .46826 Mtetra
.62448 .46826 .6298 .47439 .64049 .47103 .6352 .46488 Mtetra
.6352 .46488 .64049 .47103 .65122 .46766 .64596 .46148 Mtetra
.64596 .46148 .65122 .46766 .66199 .46428 .65675 .45807 Mtetra
.65675 .45807 .66199 .46428 .6728 .46088 .66759 .45465 Mtetra
.66759 .45465 .6728 .46088 .68365 .45747 .67847 .45122 Mtetra
.67847 .45122 .68365 .45747 .69455 .45405 .6894 .44778 Mtetra
.6894 .44778 .69455 .45405 .70548 .45062 .70036 .44432 Mtetra
.70036 .44432 .70548 .45062 .71646 .44718 .71137 .44085 Mtetra
.71137 .44085 .71646 .44718 .72748 .44372 .72242 .43737 Mtetra
.72242 .43737 .72748 .44372 .73855 .44025 .73351 .43387 Mtetra
.73351 .43387 .73855 .44025 .74965 .43676 .74465 .43036 Mtetra
.74465 .43036 .74965 .43676 .7608 .43327 .75583 .42684 Mtetra
.75583 .42684 .7608 .43327 .77199 .42976 .76705 .42331 Mtetra
.76705 .42331 .77199 .42976 .78323 .42623 .77832 .41976 Mtetra
.77832 .41976 .78323 .42623 .79451 .4227 .78963 .41619 Mtetra
.78963 .41619 .79451 .4227 .80584 .41915 .80099 .41262 Mtetra
.80099 .41262 .80584 .41915 .8172 .41558 .81239 .40903 Mtetra
.81239 .40903 .8172 .41558 .82862 .41201 .82383 .40543 Mtetra
.82383 .40543 .82862 .41201 .84008 .40842 .83533 .40181 Mtetra
.83533 .40181 .84008 .40842 .85158 .40481 .84686 .39818 Mtetra
.84686 .39818 .85158 .40481 .86313 .40119 .85844 .39453 Mtetra
.85844 .39453 .86313 .40119 .87472 .39756 .87007 .39087 Mtetra
.87007 .39087 .87472 .39756 .88636 .39391 .88175 .3872 Mtetra
.667 .505 .656 r
.25764 .57961 .26214 .60739 .27358 .57759 .26756 .56986 Mtetra
.52 .627 .897 r
.26756 .56986 .27358 .57759 .2829 .57589 .27677 .56997 Mtetra
.621 .725 .921 r
.27677 .56997 .2829 .57589 .2923 .57363 .28618 .56781 Mtetra
.624 .731 .923 r
.28618 .56781 .2923 .57363 .30173 .57164 .29564 .56556 Mtetra
.567 .703 .933 r
.29564 .56556 .30173 .57164 .31058 .57928 .30506 .56444 Mtetra
.734 .606 .715 r
.30506 .56444 .31058 .57928 .321 .56251 .3151 .55401 Mtetra
.493 .594 .883 r
.3151 .55401 .321 .56251 .33051 .56077 .32448 .55479 Mtetra
.626 .727 .92 r
.32448 .55479 .33051 .56077 .34011 .55827 .33408 .55247 Mtetra
.639 .739 .921 r
.33408 .55247 .34011 .55827 .34975 .55563 .34374 .54985 Mtetra
.64 .74 .922 r
.34374 .54985 .34975 .55563 .35942 .55306 .35343 .54719 Mtetra
.63 .735 .923 r
.35343 .54719 .35942 .55306 .36911 .55104 .36316 .54474 Mtetra
.529 .684 .937 r
.36316 .54474 .36911 .55104 .3818 .48044 .37283 .54428 Mtetra
.477 .232 .465 r
.37283 .54428 .3818 .48044 .38882 .54156 .38296 .53423 Mtetra
.564 .663 .904 r
.38296 .53423 .38882 .54156 .39862 .53935 .39272 .53336 Mtetra
.637 .735 .92 r
.39272 .53336 .39862 .53935 .40848 .53656 .4026 .53072 Mtetra
.648 .745 .92 r
.4026 .53072 .40848 .53656 .41839 .53358 .41252 .5278 Mtetra
.653 .749 .92 r
.41252 .5278 .41839 .53358 .42833 .53051 .42249 .52474 Mtetra
.656 .751 .92 r
.42249 .52474 .42833 .53051 .43831 .52738 .43249 .52161 Mtetra
.657 .752 .92 r
.43249 .52161 .43831 .52738 .44833 .5242 .44254 .51842 Mtetra
.658 .753 .92 r
.44254 .51842 .44833 .5242 .45839 .52098 .45262 .51519 Mtetra
.659 .754 .92 r
.45262 .51519 .45839 .52098 .46848 .51775 .46274 .51194 Mtetra
.46274 .51194 .46848 .51775 .47862 .51451 .47289 .50867 Mtetra
.47289 .50867 .47862 .51451 .48878 .51126 .48309 .5054 Mtetra
.48309 .5054 .48878 .51126 .49899 .508 .49332 .50212 Mtetra
.658 .753 .92 r
.49332 .50212 .49899 .508 .50923 .50474 .50359 .49883 Mtetra
.50359 .49883 .50923 .50474 .51952 .50147 .51389 .49554 Mtetra
.51389 .49554 .51952 .50147 .52984 .4982 .52424 .49224 Mtetra
.52424 .49224 .52984 .4982 .5402 .49491 .53462 .48893 Mtetra
.53462 .48893 .5402 .49491 .55059 .49162 .54505 .48561 Mtetra
.54505 .48561 .55059 .49162 .56103 .48831 .55551 .48228 Mtetra
.657 .753 .92 r
.55551 .48228 .56103 .48831 .57151 .485 .56601 .47895 Mtetra
.56601 .47895 .57151 .485 .58202 .48167 .57655 .4756 Mtetra
.57655 .4756 .58202 .48167 .59258 .47834 .58714 .47224 Mtetra
.657 .752 .92 r
.58714 .47224 .59258 .47834 .60317 .47499 .59776 .46886 Mtetra
.59776 .46886 .60317 .47499 .61381 .47163 .60842 .46548 Mtetra
.60842 .46548 .61381 .47163 .62448 .46826 .61912 .46208 Mtetra
.61912 .46208 .62448 .46826 .6352 .46488 .62987 .45868 Mtetra
.62987 .45868 .6352 .46488 .64596 .46148 .64065 .45526 Mtetra
.64065 .45526 .64596 .46148 .65675 .45807 .65148 .45183 Mtetra
.65148 .45183 .65675 .45807 .66759 .45465 .66235 .44838 Mtetra
.66235 .44838 .66759 .45465 .67847 .45122 .67326 .44492 Mtetra
.67326 .44492 .67847 .45122 .6894 .44778 .68421 .44146 Mtetra
.68421 .44146 .6894 .44778 .70036 .44432 .69521 .43797 Mtetra
.69521 .43797 .70036 .44432 .71137 .44085 .70624 .43448 Mtetra
.70624 .43448 .71137 .44085 .72242 .43737 .71732 .43097 Mtetra
.71732 .43097 .72242 .43737 .73351 .43387 .72845 .42745 Mtetra
.72845 .42745 .73351 .43387 .74465 .43036 .73961 .42392 Mtetra
.73961 .42392 .74465 .43036 .75583 .42684 .75082 .42037 Mtetra
.75082 .42037 .75583 .42684 .76705 .42331 .76208 .41681 Mtetra
.76208 .41681 .76705 .42331 .77832 .41976 .77338 .41323 Mtetra
.77338 .41323 .77832 .41976 .78963 .41619 .78472 .40964 Mtetra
.78472 .40964 .78963 .41619 .80099 .41262 .79611 .40604 Mtetra
.79611 .40604 .80099 .41262 .81239 .40903 .80754 .40243 Mtetra
.80754 .40243 .81239 .40903 .82383 .40543 .81902 .3988 Mtetra
.81902 .3988 .82383 .40543 .83533 .40181 .83054 .39515 Mtetra
.83054 .39515 .83533 .40181 .84686 .39818 .84211 .39149 Mtetra
.84211 .39149 .84686 .39818 .85844 .39453 .85373 .38782 Mtetra
.85373 .38782 .85844 .39453 .87007 .39087 .86539 .38414 Mtetra
.86539 .38414 .87007 .39087 .88175 .3872 .87709 .38044 Mtetra
.91 .505 .147 r
.25151 .57258 .25764 .57961 .26756 .56986 .25906 .59366 Mtetra
0 0 0 r
.25906 .59366 .26756 .56986 .27677 .56997 .27062 .56369 Mtetra
.602 .708 .919 r
.27062 .56369 .27677 .56997 .28618 .56781 .28002 .56195 Mtetra
.626 .731 .922 r
.28002 .56195 .28618 .56781 .29564 .56556 .28949 .55964 Mtetra
.613 .725 .926 r
.28949 .55964 .29564 .56556 .30506 .56444 .29899 .5576 Mtetra
0 .151 .668 r
.29899 .5576 .30506 .56444 .3151 .55401 .30791 .56524 Mtetra
.627 .815 .398 r
.30791 .56524 .3151 .55401 .32448 .55479 .31842 .54835 Mtetra
.602 .706 .917 r
.31842 .54835 .32448 .55479 .33408 .55247 .32801 .54658 Mtetra
.635 .735 .921 r
.32801 .54658 .33408 .55247 .34374 .54985 .33768 .54402 Mtetra
.64 .74 .921 r
.33768 .54402 .34374 .54985 .35343 .54719 .3474 .54134 Mtetra
.637 .739 .922 r
.3474 .54134 .35343 .54719 .36316 .54474 .35715 .53871 Mtetra
.611 .725 .926 r
.35715 .53871 .36316 .54474 .37283 .54428 .36692 .53664 Mtetra
.93 .71 .582 r
.36692 .53664 .37283 .54428 .38296 .53423 .37976 .46571 Mtetra
0 0 .409 r
.37976 .46571 .38296 .53423 .39272 .53336 .3868 .52704 Mtetra
.62 .72 .918 r
.3868 .52704 .39272 .53336 .4026 .53072 .39668 .52479 Mtetra
.644 .742 .92 r
.39668 .52479 .4026 .53072 .41252 .5278 .40662 .52194 Mtetra
.651 .747 .92 r
.40662 .52194 .41252 .5278 .42249 .52474 .41661 .51891 Mtetra
.654 .75 .92 r
.41661 .51891 .42249 .52474 .43249 .52161 .42663 .51579 Mtetra
.657 .752 .92 r
.42663 .51579 .43249 .52161 .44254 .51842 .4367 .5126 Mtetra
.658 .753 .92 r
.4367 .5126 .44254 .51842 .45262 .51519 .44681 .50936 Mtetra
.659 .754 .92 r
.44681 .50936 .45262 .51519 .46274 .51194 .45695 .50609 Mtetra
.45695 .50609 .46274 .51194 .47289 .50867 .46713 .5028 Mtetra
.46713 .5028 .47289 .50867 .48309 .5054 .47735 .4995 Mtetra
.47735 .4995 .48309 .5054 .49332 .50212 .4876 .4962 Mtetra
.658 .753 .92 r
.4876 .4962 .49332 .50212 .50359 .49883 .4979 .49288 Mtetra
.4979 .49288 .50359 .49883 .51389 .49554 .50823 .48957 Mtetra
.50823 .48957 .51389 .49554 .52424 .49224 .5186 .48624 Mtetra
.5186 .48624 .52424 .49224 .53462 .48893 .52901 .48291 Mtetra
.52901 .48291 .53462 .48893 .54505 .48561 .53946 .47957 Mtetra
.53946 .47957 .54505 .48561 .55551 .48228 .54995 .47621 Mtetra
.54995 .47621 .55551 .48228 .56601 .47895 .56048 .47285 Mtetra
.657 .753 .92 r
.56048 .47285 .56601 .47895 .57655 .4756 .57105 .46948 Mtetra
.57105 .46948 .57655 .4756 .58714 .47224 .58166 .46609 Mtetra
.58166 .46609 .58714 .47224 .59776 .46886 .59231 .46269 Mtetra
.657 .752 .92 r
.59231 .46269 .59776 .46886 .60842 .46548 .603 .45929 Mtetra
.603 .45929 .60842 .46548 .61912 .46208 .61373 .45587 Mtetra
.61373 .45587 .61912 .46208 .62987 .45868 .6245 .45243 Mtetra
.6245 .45243 .62987 .45868 .64065 .45526 .63531 .44899 Mtetra
.63531 .44899 .64065 .45526 .65148 .45183 .64617 .44553 Mtetra
.64617 .44553 .65148 .45183 .66235 .44838 .65706 .44206 Mtetra
.65706 .44206 .66235 .44838 .67326 .44492 .668 .43858 Mtetra
.668 .43858 .67326 .44492 .68421 .44146 .67899 .43509 Mtetra
.67899 .43509 .68421 .44146 .69521 .43797 .69001 .43158 Mtetra
.69001 .43158 .69521 .43797 .70624 .43448 .70108 .42806 Mtetra
.70108 .42806 .70624 .43448 .71732 .43097 .71219 .42453 Mtetra
.71219 .42453 .71732 .43097 .72845 .42745 .72334 .42098 Mtetra
.72334 .42098 .72845 .42745 .73961 .42392 .73454 .41742 Mtetra
.73454 .41742 .73961 .42392 .75082 .42037 .74578 .41385 Mtetra
.74578 .41385 .75082 .42037 .76208 .41681 .75706 .41026 Mtetra
.75706 .41026 .76208 .41681 .77338 .41323 .76839 .40666 Mtetra
.76839 .40666 .77338 .41323 .78472 .40964 .77977 .40304 Mtetra
.77977 .40304 .78472 .40964 .79611 .40604 .79119 .39942 Mtetra
.79119 .39942 .79611 .40604 .80754 .40243 .80265 .39577 Mtetra
.80265 .39577 .80754 .40243 .81902 .3988 .81416 .39212 Mtetra
.81416 .39212 .81902 .3988 .83054 .39515 .82572 .38845 Mtetra
.82572 .38845 .83054 .39515 .84211 .39149 .83732 .38476 Mtetra
.83732 .38476 .84211 .39149 .85373 .38782 .84897 .38106 Mtetra
.84897 .38106 .85373 .38782 .86539 .38414 .86067 .37735 Mtetra
.86067 .37735 .86539 .38414 .87709 .38044 .87241 .37362 Mtetra
.542 .691 .936 r
.24527 .5664 .25151 .57258 .25906 .59366 .25453 .56569 Mtetra
.666 .504 .656 r
.25453 .56569 .25906 .59366 .27062 .56369 .26455 .55586 Mtetra
.52 .627 .897 r
.26455 .55586 .27062 .56369 .28002 .56195 .27382 .55593 Mtetra
.621 .725 .921 r
.27382 .55593 .28002 .56195 .28949 .55964 .28331 .55373 Mtetra
.624 .731 .923 r
.28331 .55373 .28949 .55964 .29899 .5576 .29284 .55143 Mtetra
.568 .703 .933 r
.29284 .55143 .29899 .5576 .30791 .56524 .30234 .55026 Mtetra
.734 .606 .715 r
.30234 .55026 .30791 .56524 .31842 .54835 .31247 .53975 Mtetra
.493 .593 .883 r
.31247 .53975 .31842 .54835 .32801 .54658 .32191 .54049 Mtetra
.626 .727 .92 r
.32191 .54049 .32801 .54658 .33768 .54402 .33159 .53813 Mtetra
.639 .739 .921 r
.33159 .53813 .33768 .54402 .3474 .54134 .34133 .53546 Mtetra
.64 .74 .922 r
.34133 .53546 .3474 .54134 .35715 .53871 .35111 .53275 Mtetra
.63 .735 .923 r
.35111 .53275 .35715 .53871 .36692 .53664 .36091 .53025 Mtetra
.529 .683 .937 r
.36091 .53025 .36692 .53664 .37976 .46571 .37066 .52974 Mtetra
.473 .227 .46 r
.37066 .52974 .37976 .46571 .3868 .52704 .38088 .51961 Mtetra
.564 .663 .904 r
.38088 .51961 .3868 .52704 .39668 .52479 .39072 .51869 Mtetra
.637 .735 .92 r
.39072 .51869 .39668 .52479 .40662 .52194 .40068 .51601 Mtetra
.648 .745 .92 r
.40068 .51601 .40662 .52194 .41661 .51891 .41069 .51302 Mtetra
.653 .749 .92 r
.41069 .51302 .41661 .51891 .42663 .51579 .42074 .50991 Mtetra
.656 .751 .92 r
.42074 .50991 .42663 .51579 .4367 .5126 .43083 .50673 Mtetra
.657 .752 .92 r
.43083 .50673 .4367 .5126 .44681 .50936 .44095 .50348 Mtetra
.658 .753 .92 r
.44095 .50348 .44681 .50936 .45695 .50609 .45112 .5002 Mtetra
.659 .754 .92 r
.45112 .5002 .45695 .50609 .46713 .5028 .46133 .49689 Mtetra
.46133 .49689 .46713 .5028 .47735 .4995 .47157 .49357 Mtetra
.47157 .49357 .47735 .4995 .4876 .4962 .48185 .49023 Mtetra
.48185 .49023 .4876 .4962 .4979 .49288 .49217 .4869 Mtetra
.658 .753 .92 r
.49217 .4869 .4979 .49288 .50823 .48957 .50253 .48355 Mtetra
.50253 .48355 .50823 .48957 .5186 .48624 .51293 .4802 Mtetra
.51293 .4802 .5186 .48624 .52901 .48291 .52336 .47684 Mtetra
.52336 .47684 .52901 .48291 .53946 .47957 .53384 .47348 Mtetra
.53384 .47348 .53946 .47957 .54995 .47621 .54435 .4701 Mtetra
.54435 .4701 .54995 .47621 .56048 .47285 .55491 .46671 Mtetra
.657 .753 .92 r
.55491 .46671 .56048 .47285 .57105 .46948 .5655 .46331 Mtetra
.5655 .46331 .57105 .46948 .58166 .46609 .57614 .4599 Mtetra
.57614 .4599 .58166 .46609 .59231 .46269 .58682 .45648 Mtetra
.657 .752 .92 r
.58682 .45648 .59231 .46269 .603 .45929 .59753 .45305 Mtetra
.59753 .45305 .603 .45929 .61373 .45587 .60829 .4496 Mtetra
.60829 .4496 .61373 .45587 .6245 .45243 .61909 .44615 Mtetra
.61909 .44615 .6245 .45243 .63531 .44899 .62993 .44268 Mtetra
.62993 .44268 .63531 .44899 .64617 .44553 .64082 .4392 Mtetra
.64082 .4392 .64617 .44553 .65706 .44206 .65174 .4357 Mtetra
.65174 .4357 .65706 .44206 .668 .43858 .66271 .4322 Mtetra
.66271 .4322 .668 .43858 .67899 .43509 .67372 .42868 Mtetra
.67372 .42868 .67899 .43509 .69001 .43158 .68478 .42514 Mtetra
.68478 .42514 .69001 .43158 .70108 .42806 .69587 .4216 Mtetra
.69587 .4216 .70108 .42806 .71219 .42453 .70701 .41804 Mtetra
.70701 .41804 .71219 .42453 .72334 .42098 .7182 .41447 Mtetra
.7182 .41447 .72334 .42098 .73454 .41742 .72943 .41088 Mtetra
.72943 .41088 .73454 .41742 .74578 .41385 .7407 .40728 Mtetra
.7407 .40728 .74578 .41385 .75706 .41026 .75201 .40367 Mtetra
.75201 .40367 .75706 .41026 .76839 .40666 .76338 .40004 Mtetra
.76338 .40004 .76839 .40666 .77977 .40304 .77478 .3964 Mtetra
.77478 .3964 .77977 .40304 .79119 .39942 .78623 .39274 Mtetra
.78623 .39274 .79119 .39942 .80265 .39577 .79773 .38907 Mtetra
.79773 .38907 .80265 .39577 .81416 .39212 .80928 .38539 Mtetra
.80928 .38539 .81416 .39212 .82572 .38845 .82086 .38169 Mtetra
.82086 .38169 .82572 .38845 .83732 .38476 .8325 .37798 Mtetra
.8325 .37798 .83732 .38476 .84897 .38106 .84418 .37425 Mtetra
.84418 .37425 .84897 .38106 .86067 .37735 .85591 .37051 Mtetra
.85591 .37051 .86067 .37735 .87241 .37362 .86769 .36676 Mtetra
.602 .719 .927 r
.23898 .56038 .24527 .5664 .25453 .56569 .24834 .55856 Mtetra
.909 .502 .141 r
.24834 .55856 .25453 .56569 .26455 .55586 .25594 .5797 Mtetra
0 0 0 r
.25594 .5797 .26455 .55586 .27382 .55593 .26761 .54956 Mtetra
.602 .708 .919 r
.26761 .54956 .27382 .55593 .28331 .55373 .27708 .54777 Mtetra
.626 .731 .922 r
.27708 .54777 .28331 .55373 .29284 .55143 .28664 .54541 Mtetra
.613 .725 .926 r
.28664 .54541 .29284 .55143 .30234 .55026 .29621 .54333 Mtetra
0 .156 .673 r
.29621 .54333 .30234 .55026 .31247 .53975 .30519 .55096 Mtetra
.637 .823 .408 r
.30519 .55096 .31247 .53975 .32191 .54049 .3158 .53396 Mtetra
.602 .706 .917 r
.3158 .53396 .32191 .54049 .33159 .53813 .32547 .53213 Mtetra
.635 .735 .921 r
.32547 .53213 .33159 .53813 .34133 .53546 .33522 .52953 Mtetra
.64 .74 .921 r
.33522 .52953 .34133 .53546 .35111 .53275 .34501 .52679 Mtetra
.637 .739 .922 r
.34501 .52679 .35111 .53275 .36091 .53025 .35485 .52411 Mtetra
.611 .725 .926 r
.35485 .52411 .36091 .53025 .37066 .52974 .36469 .522 Mtetra
.932 .71 .58 r
.36469 .522 .37066 .52974 .38088 .51961 .37769 .45073 Mtetra
0 0 .405 r
.37769 .45073 .38088 .51961 .39072 .51869 .38474 .51227 Mtetra
.62 .72 .918 r
.38474 .51227 .39072 .51869 .40068 .51601 .3947 .50997 Mtetra
.644 .742 .92 r
.3947 .50997 .40068 .51601 .41069 .51302 .40473 .50707 Mtetra
.651 .747 .92 r
.40473 .50707 .41069 .51302 .42074 .50991 .4148 .50398 Mtetra
.654 .75 .92 r
.4148 .50398 .42074 .50991 .43083 .50673 .42491 .5008 Mtetra
.657 .752 .92 r
.42491 .5008 .43083 .50673 .44095 .50348 .43506 .49756 Mtetra
.658 .753 .92 r
.43506 .49756 .44095 .50348 .45112 .5002 .44525 .49426 Mtetra
.659 .754 .92 r
.44525 .49426 .45112 .5002 .46133 .49689 .45548 .49094 Mtetra
.45548 .49094 .46133 .49689 .47157 .49357 .46575 .48759 Mtetra
.46575 .48759 .47157 .49357 .48185 .49023 .47606 .48423 Mtetra
.47606 .48423 .48185 .49023 .49217 .4869 .4864 .48087 Mtetra
.658 .753 .92 r
.4864 .48087 .49217 .4869 .50253 .48355 .49679 .4775 Mtetra
.49679 .4775 .50253 .48355 .51293 .4802 .50721 .47412 Mtetra
.50721 .47412 .51293 .4802 .52336 .47684 .51767 .47074 Mtetra
.51767 .47074 .52336 .47684 .53384 .47348 .52817 .46734 Mtetra
.52817 .46734 .53384 .47348 .54435 .4701 .53871 .46394 Mtetra
.53871 .46394 .54435 .4701 .55491 .46671 .5493 .46053 Mtetra
.5493 .46053 .55491 .46671 .5655 .46331 .55992 .45711 Mtetra
.657 .753 .92 r
.55992 .45711 .5655 .46331 .57614 .4599 .57058 .45367 Mtetra
.57058 .45367 .57614 .4599 .58682 .45648 .58129 .45023 Mtetra
.58129 .45023 .58682 .45648 .59753 .45305 .59203 .44677 Mtetra
.657 .752 .92 r
.59203 .44677 .59753 .45305 .60829 .4496 .60282 .4433 Mtetra
.60282 .4433 .60829 .4496 .61909 .44615 .61365 .43982 Mtetra
.61365 .43982 .61909 .44615 .62993 .44268 .62452 .43632 Mtetra
.62452 .43632 .62993 .44268 .64082 .4392 .63543 .43281 Mtetra
.63543 .43281 .64082 .4392 .65174 .4357 .64638 .4293 Mtetra
.64638 .4293 .65174 .4357 .66271 .4322 .65738 .42576 Mtetra
.65738 .42576 .66271 .4322 .67372 .42868 .66842 .42222 Mtetra
.66842 .42222 .67372 .42868 .68478 .42514 .67951 .41866 Mtetra
.67951 .41866 .68478 .42514 .69587 .4216 .69063 .41509 Mtetra
.69063 .41509 .69587 .4216 .70701 .41804 .7018 .4115 Mtetra
.7018 .4115 .70701 .41804 .7182 .41447 .71302 .4079 Mtetra
.71302 .4079 .7182 .41447 .72943 .41088 .72428 .40429 Mtetra
.72428 .40429 .72943 .41088 .7407 .40728 .73558 .40066 Mtetra
.73558 .40066 .7407 .40728 .75201 .40367 .74693 .39702 Mtetra
.74693 .39702 .75201 .40367 .76338 .40004 .75832 .39337 Mtetra
.75832 .39337 .76338 .40004 .77478 .3964 .76976 .3897 Mtetra
.76976 .3897 .77478 .3964 .78623 .39274 .78124 .38602 Mtetra
.78124 .38602 .78623 .39274 .79773 .38907 .79277 .38232 Mtetra
.79277 .38232 .79773 .38907 .80928 .38539 .80435 .37861 Mtetra
.80435 .37861 .80928 .38539 .82086 .38169 .81597 .37489 Mtetra
.81597 .37489 .82086 .38169 .8325 .37798 .82764 .37115 Mtetra
.82764 .37115 .8325 .37798 .84418 .37425 .83936 .36739 Mtetra
.83936 .36739 .84418 .37425 .85591 .37051 .85112 .36362 Mtetra
.85112 .36362 .85591 .37051 .86769 .36676 .86293 .35984 Mtetra
.614 .723 .924 r
.23264 .55436 .23898 .56038 .24834 .55856 .24204 .55228 Mtetra
.543 .691 .936 r
.24204 .55228 .24834 .55856 .25594 .5797 .25138 .55153 Mtetra
.666 .503 .655 r
.25138 .55153 .25594 .5797 .26761 .54956 .26148 .54162 Mtetra
.52 .627 .897 r
.26148 .54162 .26761 .54956 .27708 .54777 .27083 .54166 Mtetra
.621 .725 .921 r
.27083 .54166 .27708 .54777 .28664 .54541 .28039 .5394 Mtetra
.624 .731 .923 r
.28039 .5394 .28664 .54541 .29621 .54333 .29 .53705 Mtetra
.568 .703 .933 r
.29 .53705 .29621 .54333 .30519 .55096 .29957 .53584 Mtetra
.734 .607 .715 r
.29957 .53584 .30519 .55096 .3158 .53396 .30979 .52524 Mtetra
.492 .593 .883 r
.30979 .52524 .3158 .53396 .32547 .53213 .31931 .52595 Mtetra
.626 .727 .92 r
.31931 .52595 .32547 .53213 .33522 .52953 .32907 .52354 Mtetra
.639 .739 .921 r
.32907 .52354 .33522 .52953 .34501 .52679 .33888 .52081 Mtetra
.64 .74 .922 r
.33888 .52081 .34501 .52679 .35485 .52411 .34874 .51805 Mtetra
.63 .735 .923 r
.34874 .51805 .35485 .52411 .36469 .522 .35862 .5155 Mtetra
.529 .683 .937 r
.35862 .5155 .36469 .522 .37769 .45073 .36845 .51495 Mtetra
.469 .222 .456 r
.36845 .51495 .37769 .45073 .38474 .51227 .37876 .50473 Mtetra
.564 .663 .904 r
.37876 .50473 .38474 .51227 .3947 .50997 .38868 .50377 Mtetra
.637 .735 .92 r
.38868 .50377 .3947 .50997 .40473 .50707 .39873 .50103 Mtetra
.648 .745 .92 r
.39873 .50103 .40473 .50707 .4148 .50398 .40882 .49799 Mtetra
.653 .749 .92 r
.40882 .49799 .4148 .50398 .42491 .5008 .41895 .49482 Mtetra
.656 .751 .92 r
.41895 .49482 .42491 .5008 .43506 .49756 .42913 .49158 Mtetra
.657 .752 .92 r
.42913 .49158 .43506 .49756 .44525 .49426 .43934 .48828 Mtetra
.658 .753 .92 r
.43934 .48828 .44525 .49426 .45548 .49094 .4496 .48494 Mtetra
.659 .754 .92 r
.4496 .48494 .45548 .49094 .46575 .48759 .45989 .48157 Mtetra
.45989 .48157 .46575 .48759 .47606 .48423 .47022 .47819 Mtetra
.47022 .47819 .47606 .48423 .4864 .48087 .48059 .4748 Mtetra
.48059 .4748 .4864 .48087 .49679 .4775 .491 .4714 Mtetra
.658 .753 .92 r
.491 .4714 .49679 .4775 .50721 .47412 .50145 .468 Mtetra
.50145 .468 .50721 .47412 .51767 .47074 .51194 .46459 Mtetra
.51194 .46459 .51767 .47074 .52817 .46734 .52247 .46117 Mtetra
.52247 .46117 .52817 .46734 .53871 .46394 .53304 .45774 Mtetra
.53304 .45774 .53871 .46394 .5493 .46053 .54365 .4543 Mtetra
.54365 .4543 .5493 .46053 .55992 .45711 .5543 .45086 Mtetra
.657 .753 .92 r
.5543 .45086 .55992 .45711 .57058 .45367 .56499 .4474 Mtetra
.56499 .4474 .57058 .45367 .58129 .45023 .57572 .44392 Mtetra
.57572 .44392 .58129 .45023 .59203 .44677 .58649 .44044 Mtetra
.657 .752 .92 r
.58649 .44044 .59203 .44677 .60282 .4433 .59731 .43695 Mtetra
.59731 .43695 .60282 .4433 .61365 .43982 .60816 .43344 Mtetra
.60816 .43344 .61365 .43982 .62452 .43632 .61906 .42992 Mtetra
.61906 .42992 .62452 .43632 .63543 .43281 .63 .42639 Mtetra
.63 .42639 .63543 .43281 .64638 .4293 .64099 .42284 Mtetra
.64099 .42284 .64638 .4293 .65738 .42576 .65201 .41928 Mtetra
.65201 .41928 .65738 .42576 .66842 .42222 .66308 .41571 Mtetra
.66308 .41571 .66842 .42222 .67951 .41866 .6742 .41213 Mtetra
.6742 .41213 .67951 .41866 .69063 .41509 .68535 .40853 Mtetra
.68535 .40853 .69063 .41509 .7018 .4115 .69655 .40492 Mtetra
.69655 .40492 .7018 .4115 .71302 .4079 .7078 .40129 Mtetra
.7078 .40129 .71302 .4079 .72428 .40429 .71909 .39765 Mtetra
.71909 .39765 .72428 .40429 .73558 .40066 .73042 .394 Mtetra
.73042 .394 .73558 .40066 .74693 .39702 .7418 .39033 Mtetra
.7418 .39033 .74693 .39702 .75832 .39337 .75323 .38665 Mtetra
.75323 .38665 .75832 .39337 .76976 .3897 .7647 .38296 Mtetra
.7647 .38296 .76976 .3897 .78124 .38602 .77622 .37925 Mtetra
.77622 .37925 .78124 .38602 .79277 .38232 .78778 .37552 Mtetra
.78778 .37552 .79277 .38232 .80435 .37861 .79939 .37178 Mtetra
.79939 .37178 .80435 .37861 .81597 .37489 .81104 .36803 Mtetra
.81104 .36803 .81597 .37489 .82764 .37115 .82275 .36426 Mtetra
.82275 .36426 .82764 .37115 .83936 .36739 .8345 .36048 Mtetra
.8345 .36048 .83936 .36739 .85112 .36362 .84629 .35668 Mtetra
.84629 .35668 .85112 .36362 .86293 .35984 .85814 .35287 Mtetra
.61 .718 .922 r
.22627 .54817 .23264 .55436 .24204 .55228 .23569 .54617 Mtetra
.602 .719 .927 r
.23569 .54617 .24204 .55228 .25138 .55153 .24513 .5443 Mtetra
.907 .499 .134 r
.24513 .5443 .25138 .55153 .26148 .54162 .25276 .56549 Mtetra
0 0 0 r
.25276 .56549 .26148 .54162 .27083 .54166 .26455 .53518 Mtetra
.602 .708 .919 r
.26455 .53518 .27083 .54166 .28039 .5394 .2741 .53334 Mtetra
.626 .731 .922 r
.2741 .53334 .28039 .5394 .29 .53705 .28373 .53093 Mtetra
.613 .725 .926 r
.28373 .53093 .29 .53705 .29957 .53584 .29338 .5288 Mtetra
0 .161 .677 r
.29338 .5288 .29957 .53584 .30979 .52524 .30242 .53643 Mtetra
.646 .831 .417 r
.30242 .53643 .30979 .52524 .31931 .52595 .31313 .51931 Mtetra
.602 .706 .917 r
.31313 .51931 .31931 .52595 .32907 .52354 .32288 .51744 Mtetra
.635 .735 .921 r
.32288 .51744 .32907 .52354 .33888 .52081 .33271 .51479 Mtetra
.64 .74 .921 r
.33271 .51479 .33888 .52081 .34874 .51805 .34259 .51199 Mtetra
.637 .739 .922 r
.34259 .51199 .34874 .51805 .35862 .5155 .3525 .50926 Mtetra
.612 .725 .926 r
.3525 .50926 .35862 .5155 .36845 .51495 .36242 .50709 Mtetra
.933 .711 .579 r
.36242 .50709 .36845 .51495 .37876 .50473 .37557 .43549 Mtetra
0 0 .401 r
.37557 .43549 .37876 .50473 .38868 .50377 .38264 .49724 Mtetra
.62 .72 .918 r
.38264 .49724 .38868 .50377 .39873 .50103 .39269 .49488 Mtetra
.644 .742 .92 r
.39269 .49488 .39873 .50103 .40882 .49799 .4028 .49193 Mtetra
.651 .747 .92 r
.4028 .49193 .40882 .49799 .41895 .49482 .41295 .48879 Mtetra
.654 .75 .92 r
.41295 .48879 .41895 .49482 .42913 .49158 .42315 .48555 Mtetra
.657 .752 .92 r
.42315 .48555 .42913 .49158 .43934 .48828 .43339 .48225 Mtetra
.658 .753 .92 r
.43339 .48225 .43934 .48828 .4496 .48494 .44367 .4789 Mtetra
.659 .754 .92 r
.44367 .4789 .4496 .48494 .45989 .48157 .45399 .47551 Mtetra
.45399 .47551 .45989 .48157 .47022 .47819 .46435 .4721 Mtetra
.46435 .4721 .47022 .47819 .48059 .4748 .47474 .46869 Mtetra
.47474 .46869 .48059 .4748 .491 .4714 .48518 .46526 Mtetra
.658 .753 .92 r
.48518 .46526 .491 .4714 .50145 .468 .49565 .46183 Mtetra
.49565 .46183 .50145 .468 .51194 .46459 .50617 .4584 Mtetra
.50617 .4584 .51194 .46459 .52247 .46117 .51672 .45495 Mtetra
.51672 .45495 .52247 .46117 .53304 .45774 .52732 .4515 Mtetra
.52732 .4515 .53304 .45774 .54365 .4543 .53795 .44803 Mtetra
.53795 .44803 .54365 .4543 .5543 .45086 .54863 .44456 Mtetra
.54863 .44456 .5543 .45086 .56499 .4474 .55935 .44108 Mtetra
.657 .753 .92 r
.55935 .44108 .56499 .4474 .57572 .44392 .57011 .43758 Mtetra
.57011 .43758 .57572 .44392 .58649 .44044 .58091 .43407 Mtetra
.58091 .43407 .58649 .44044 .59731 .43695 .59175 .43055 Mtetra
.657 .752 .92 r
.59175 .43055 .59731 .43695 .60816 .43344 .60264 .42702 Mtetra
.60264 .42702 .60816 .43344 .61906 .42992 .61356 .42347 Mtetra
.61356 .42347 .61906 .42992 .63 .42639 .62453 .41991 Mtetra
.62453 .41991 .63 .42639 .64099 .42284 .63555 .41634 Mtetra
.63555 .41634 .64099 .42284 .65201 .41928 .6466 .41276 Mtetra
.6466 .41276 .65201 .41928 .66308 .41571 .6577 .40916 Mtetra
.6577 .40916 .66308 .41571 .6742 .41213 .66885 .40555 Mtetra
.66885 .40555 .6742 .41213 .68535 .40853 .68004 .40192 Mtetra
.68004 .40192 .68535 .40853 .69655 .40492 .69127 .39828 Mtetra
.69127 .39828 .69655 .40492 .7078 .40129 .70254 .39463 Mtetra
.70254 .39463 .7078 .40129 .71909 .39765 .71386 .39097 Mtetra
.71386 .39097 .71909 .39765 .73042 .394 .72523 .38729 Mtetra
.72523 .38729 .73042 .394 .7418 .39033 .73664 .38359 Mtetra
.73664 .38359 .7418 .39033 .75323 .38665 .7481 .37988 Mtetra
.7481 .37988 .75323 .38665 .7647 .38296 .7596 .37616 Mtetra
.7596 .37616 .7647 .38296 .77622 .37925 .77115 .37242 Mtetra
.77115 .37242 .77622 .37925 .78778 .37552 .78275 .36867 Mtetra
.78275 .36867 .78778 .37552 .79939 .37178 .79439 .36491 Mtetra
.79439 .36491 .79939 .37178 .81104 .36803 .80608 .36112 Mtetra
.80608 .36112 .81104 .36803 .82275 .36426 .81782 .35733 Mtetra
.81782 .35733 .82275 .36426 .8345 .36048 .8296 .35352 Mtetra
.8296 .35352 .8345 .36048 .84629 .35668 .84143 .34969 Mtetra
.84143 .34969 .84629 .35668 .85814 .35287 .85331 .34585 Mtetra
.584 .694 .918 r
.21991 .5415 .22627 .54817 .23569 .54617 .22929 .54005 Mtetra
.614 .723 .924 r
.22929 .54005 .23569 .54617 .24513 .5443 .23876 .53792 Mtetra
.543 .691 .936 r
.23876 .53792 .24513 .5443 .25276 .56549 .24817 .53713 Mtetra
.665 .503 .654 r
.24817 .53713 .25276 .56549 .26455 .53518 .25836 .52714 Mtetra
.519 .627 .898 r
.25836 .52714 .26455 .53518 .2741 .53334 .26778 .52713 Mtetra
.621 .725 .921 r
.26778 .52713 .2741 .53334 .28373 .53093 .27742 .52483 Mtetra
.624 .731 .923 r
.27742 .52483 .28373 .53093 .29338 .5288 .2871 .52243 Mtetra
.568 .703 .932 r
.2871 .52243 .29338 .5288 .30242 .53643 .29675 .52117 Mtetra
.734 .607 .715 r
.29675 .52117 .30242 .53643 .31313 .51931 .30706 .51048 Mtetra
.492 .593 .883 r
.30706 .51048 .31313 .51931 .32288 .51744 .31665 .51115 Mtetra
.626 .727 .92 r
.31665 .51115 .32288 .51744 .33271 .51479 .32649 .50869 Mtetra
.639 .739 .921 r
.32649 .50869 .33271 .51479 .34259 .51199 .33639 .50591 Mtetra
.64 .74 .922 r
.33639 .50591 .34259 .51199 .3525 .50926 .34633 .50309 Mtetra
.63 .735 .923 r
.34633 .50309 .3525 .50926 .36242 .50709 .3563 .50049 Mtetra
.53 .683 .936 r
.3563 .50049 .36242 .50709 .37557 .43549 .36621 .49989 Mtetra
.464 .216 .452 r
.36621 .49989 .37557 .43549 .38264 .49724 .37661 .48959 Mtetra
.564 .663 .904 r
.37661 .48959 .38264 .49724 .39269 .49488 .38661 .48858 Mtetra
.637 .735 .92 r
.38661 .48858 .39269 .49488 .4028 .49193 .39674 .48578 Mtetra
.648 .745 .92 r
.39674 .48578 .4028 .49193 .41295 .48879 .40692 .48269 Mtetra
.653 .749 .92 r
.40692 .48269 .41295 .48879 .42315 .48555 .41714 .47947 Mtetra
.656 .751 .92 r
.41714 .47947 .42315 .48555 .43339 .48225 .4274 .47616 Mtetra
.657 .752 .92 r
.4274 .47616 .43339 .48225 .44367 .4789 .4377 .4728 Mtetra
.658 .753 .92 r
.4377 .4728 .44367 .4789 .45399 .47551 .44805 .4694 Mtetra
.659 .754 .92 r
.44805 .4694 .45399 .47551 .46435 .4721 .45843 .46598 Mtetra
.45843 .46598 .46435 .4721 .47474 .46869 .46885 .46253 Mtetra
.46885 .46253 .47474 .46869 .48518 .46526 .47931 .45908 Mtetra
.47931 .45908 .48518 .46526 .49565 .46183 .48981 .45563 Mtetra
.658 .753 .92 r
.48981 .45563 .49565 .46183 .50617 .4584 .50036 .45216 Mtetra
.50036 .45216 .50617 .4584 .51672 .45495 .51094 .44869 Mtetra
.51094 .44869 .51672 .45495 .52732 .4515 .52156 .44521 Mtetra
.52156 .44521 .52732 .4515 .53795 .44803 .53222 .44172 Mtetra
.53222 .44172 .53795 .44803 .54863 .44456 .54293 .43822 Mtetra
.54293 .43822 .54863 .44456 .55935 .44108 .55367 .43471 Mtetra
.657 .753 .92 r
.55367 .43471 .55935 .44108 .57011 .43758 .56446 .43119 Mtetra
.56446 .43119 .57011 .43758 .58091 .43407 .57529 .42765 Mtetra
.57529 .42765 .58091 .43407 .59175 .43055 .58616 .42411 Mtetra
.657 .752 .92 r
.58616 .42411 .59175 .43055 .60264 .42702 .59707 .42055 Mtetra
.59707 .42055 .60264 .42702 .61356 .42347 .60803 .41697 Mtetra
.60803 .41697 .61356 .42347 .62453 .41991 .61903 .41339 Mtetra
.61903 .41339 .62453 .41991 .63555 .41634 .63007 .40979 Mtetra
.63007 .40979 .63555 .41634 .6466 .41276 .64116 .40618 Mtetra
.64116 .40618 .6466 .41276 .6577 .40916 .65229 .40256 Mtetra
.65229 .40256 .6577 .40916 .66885 .40555 .66346 .39892 Mtetra
.66346 .39892 .66885 .40555 .68004 .40192 .67468 .39527 Mtetra
.67468 .39527 .68004 .40192 .69127 .39828 .68594 .3916 Mtetra
.68594 .3916 .69127 .39828 .70254 .39463 .69725 .38792 Mtetra
.69725 .38792 .70254 .39463 .71386 .39097 .7086 .38423 Mtetra
.7086 .38423 .71386 .39097 .72523 .38729 .72 .38052 Mtetra
.72 .38052 .72523 .38729 .73664 .38359 .73144 .3768 Mtetra
.73144 .3768 .73664 .38359 .7481 .37988 .74293 .37307 Mtetra
.74293 .37307 .7481 .37988 .7596 .37616 .75447 .36931 Mtetra
.75447 .36931 .7596 .37616 .77115 .37242 .76605 .36555 Mtetra
.76605 .36555 .77115 .37242 .78275 .36867 .77768 .36177 Mtetra
.77768 .36177 .78275 .36867 .79439 .36491 .78935 .35798 Mtetra
.78935 .35798 .79439 .36491 .80608 .36112 .80108 .35417 Mtetra
.80108 .35417 .80608 .36112 .81782 .35733 .81285 .35034 Mtetra
.81285 .35034 .81782 .35733 .8296 .35352 .82467 .3465 Mtetra
.82467 .3465 .8296 .35352 .84143 .34969 .83653 .34265 Mtetra
.83653 .34265 .84143 .34969 .85331 .34585 .84845 .33877 Mtetra
.429 .538 .865 r
.21377 .53184 .21991 .5415 .22929 .54005 .22285 .53376 Mtetra
.61 .718 .922 r
.22285 .53376 .22929 .54005 .23876 .53792 .23234 .53171 Mtetra
.602 .719 .927 r
.23234 .53171 .23876 .53792 .24817 .53713 .24186 .52979 Mtetra
.905 .496 .127 r
.24186 .52979 .24817 .53713 .25836 .52714 .24952 .55104 Mtetra
0 0 0 r
.24952 .55104 .25836 .52714 .26778 .52713 .26144 .52055 Mtetra
.602 .708 .919 r
.26144 .52055 .26778 .52713 .27742 .52483 .27106 .51866 Mtetra
.626 .731 .922 r
.27106 .51866 .27742 .52483 .2871 .52243 .28077 .51621 Mtetra
.613 .725 .926 r
.28077 .51621 .2871 .52243 .29675 .52117 .2905 .51403 Mtetra
0 .166 .682 r
.2905 .51403 .29675 .52117 .30706 .51048 .29961 .52164 Mtetra
.655 .838 .427 r
.29961 .52164 .30706 .51048 .31665 .51115 .31042 .50441 Mtetra
.602 .706 .917 r
.31042 .50441 .31665 .51115 .32649 .50869 .32024 .50249 Mtetra
.635 .735 .921 r
.32024 .50249 .32649 .50869 .33639 .50591 .33015 .49978 Mtetra
.64 .74 .921 r
.33015 .49978 .33639 .50591 .34633 .50309 .34011 .49693 Mtetra
.637 .739 .922 r
.34011 .49693 .34633 .50309 .3563 .50049 .35011 .49414 Mtetra
.612 .725 .926 r
.35011 .49414 .3563 .50049 .36621 .49989 .36012 .49192 Mtetra
.934 .711 .577 r
.36012 .49192 .36621 .49989 .37661 .48959 .37343 .41998 Mtetra
0 0 .397 r
.37343 .41998 .37661 .48959 .38661 .48858 .38051 .48194 Mtetra
.62 .72 .918 r
.38051 .48194 .38661 .48858 .39674 .48578 .39064 .47953 Mtetra
.644 .742 .92 r
.39064 .47953 .39674 .48578 .40692 .48269 .40084 .47652 Mtetra
.651 .747 .92 r
.40084 .47652 .40692 .48269 .41714 .47947 .41108 .47332 Mtetra
.654 .75 .92 r
.41108 .47332 .41714 .47947 .4274 .47616 .42137 .47003 Mtetra
.657 .752 .92 r
.42137 .47003 .4274 .47616 .4377 .4728 .43169 .46666 Mtetra
.658 .753 .92 r
.43169 .46666 .4377 .4728 .44805 .4694 .44206 .46325 Mtetra
.659 .754 .92 r
.44206 .46325 .44805 .4694 .45843 .46598 .45247 .45981 Mtetra
.45247 .45981 .45843 .46598 .46885 .46253 .46292 .45634 Mtetra
.46292 .45634 .46885 .46253 .47931 .45908 .47341 .45286 Mtetra
.47341 .45286 .47931 .45908 .48981 .45563 .48393 .44938 Mtetra
.658 .753 .92 r
.48393 .44938 .48981 .45563 .50036 .45216 .4945 .44588 Mtetra
.4945 .44588 .50036 .45216 .51094 .44869 .50511 .44239 Mtetra
.50511 .44239 .51094 .44869 .52156 .44521 .51576 .43888 Mtetra
.51576 .43888 .52156 .44521 .53222 .44172 .52645 .43536 Mtetra
.52645 .43536 .53222 .44172 .54293 .43822 .53718 .43184 Mtetra
.53718 .43184 .54293 .43822 .55367 .43471 .54795 .4283 Mtetra
.54795 .4283 .55367 .43471 .56446 .43119 .55877 .42475 Mtetra
.657 .753 .92 r
.55877 .42475 .56446 .43119 .57529 .42765 .56963 .42119 Mtetra
.56963 .42119 .57529 .42765 .58616 .42411 .58053 .41762 Mtetra
.58053 .41762 .58616 .42411 .59707 .42055 .59147 .41403 Mtetra
.657 .752 .92 r
.59147 .41403 .59707 .42055 .60803 .41697 .60245 .41043 Mtetra
.60245 .41043 .60803 .41697 .61903 .41339 .61348 .40682 Mtetra
.61348 .40682 .61903 .41339 .63007 .40979 .62455 .4032 Mtetra
.62455 .4032 .63007 .40979 .64116 .40618 .63567 .39956 Mtetra
.63567 .39956 .64116 .40618 .65229 .40256 .64683 .39591 Mtetra
.64683 .39591 .65229 .40256 .66346 .39892 .65803 .39224 Mtetra
.65803 .39224 .66346 .39892 .67468 .39527 .66928 .38856 Mtetra
.66928 .38856 .67468 .39527 .68594 .3916 .68057 .38487 Mtetra
.68057 .38487 .68594 .3916 .69725 .38792 .69191 .38117 Mtetra
.69191 .38117 .69725 .38792 .7086 .38423 .7033 .37744 Mtetra
.7033 .37744 .7086 .38423 .72 .38052 .71473 .37371 Mtetra
.71473 .37371 .72 .38052 .73144 .3768 .7262 .36996 Mtetra
.7262 .36996 .73144 .3768 .74293 .37307 .73772 .3662 Mtetra
.73772 .3662 .74293 .37307 .75447 .36931 .74929 .36242 Mtetra
.74929 .36242 .75447 .36931 .76605 .36555 .76091 .35862 Mtetra
.76091 .35862 .76605 .36555 .77768 .36177 .77257 .35482 Mtetra
.77257 .35482 .77768 .36177 .78935 .35798 .78428 .35099 Mtetra
.78428 .35099 .78935 .35798 .80108 .35417 .79604 .34715 Mtetra
.79604 .34715 .80108 .35417 .81285 .35034 .80784 .3433 Mtetra
.80784 .3433 .81285 .35034 .82467 .3465 .81969 .33943 Mtetra
.81969 .33943 .82467 .3465 .83653 .34265 .8316 .33555 Mtetra
.8316 .33555 .83653 .34265 .84845 .33877 .84355 .33165 Mtetra
.687 .907 .561 r
.20588 .54038 .21377 .53184 .22285 .53376 .21642 .52698 Mtetra
.584 .694 .918 r
.21642 .52698 .22285 .53376 .23234 .53171 .22587 .52549 Mtetra
.614 .723 .924 r
.22587 .52549 .23234 .53171 .24186 .52979 .23543 .52331 Mtetra
.543 .691 .935 r
.23543 .52331 .24186 .52979 .24952 .55104 .24491 .52248 Mtetra
.665 .502 .654 r
.24491 .52248 .24952 .55104 .26144 .52055 .25518 .5124 Mtetra
.519 .627 .898 r
.25518 .5124 .26144 .52055 .27106 .51866 .26468 .51235 Mtetra
.621 .725 .921 r
.26468 .51235 .27106 .51866 .28077 .51621 .27439 .51 Mtetra
.624 .731 .923 r
.27439 .51 .28077 .51621 .2905 .51403 .28416 .50755 Mtetra
.568 .703 .932 r
.28416 .50755 .2905 .51403 .29961 .52164 .29388 .50624 Mtetra
.735 .607 .715 r
.29388 .50624 .29961 .52164 .31042 .50441 .30429 .49546 Mtetra
.492 .593 .883 r
.30429 .49546 .31042 .50441 .32024 .50249 .31396 .4961 Mtetra
.626 .728 .92 r
.31396 .4961 .32024 .50249 .33015 .49978 .32388 .49358 Mtetra
.639 .739 .921 r
.32388 .49358 .33015 .49978 .34011 .49693 .33386 .49074 Mtetra
.64 .74 .922 r
.33386 .49074 .34011 .49693 .35011 .49414 .34388 .48787 Mtetra
.63 .735 .923 r
.34388 .48787 .35011 .49414 .36012 .49192 .35393 .48521 Mtetra
.53 .683 .936 r
.35393 .48521 .36012 .49192 .37343 .41998 .36392 .48457 Mtetra
.46 .21 .447 r
.36392 .48457 .37343 .41998 .38051 .48194 .37441 .47418 Mtetra
.563 .664 .905 r
.37441 .47418 .38051 .48194 .39064 .47953 .3845 .47312 Mtetra
.637 .735 .92 r
.3845 .47312 .39064 .47953 .40084 .47652 .39471 .47027 Mtetra
.648 .745 .92 r
.39471 .47027 .40084 .47652 .41108 .47332 .40498 .46711 Mtetra
.653 .749 .92 r
.40498 .46711 .41108 .47332 .42137 .47003 .41529 .46383 Mtetra
.656 .751 .92 r
.41529 .46383 .42137 .47003 .43169 .46666 .42564 .46047 Mtetra
.657 .752 .92 r
.42564 .46047 .43169 .46666 .44206 .46325 .43603 .45705 Mtetra
.658 .753 .92 r
.43603 .45705 .44206 .46325 .45247 .45981 .44647 .45359 Mtetra
.659 .754 .92 r
.44647 .45359 .45247 .45981 .46292 .45634 .45694 .4501 Mtetra
.45694 .4501 .46292 .45634 .47341 .45286 .46746 .4466 Mtetra
.46746 .4466 .47341 .45286 .48393 .44938 .47801 .44308 Mtetra
.47801 .44308 .48393 .44938 .4945 .44588 .4886 .43956 Mtetra
.658 .753 .92 r
.4886 .43956 .4945 .44588 .50511 .44239 .49924 .43604 Mtetra
.49924 .43604 .50511 .44239 .51576 .43888 .50992 .4325 Mtetra
.50992 .4325 .51576 .43888 .52645 .43536 .52063 .42896 Mtetra
.52063 .42896 .52645 .43536 .53718 .43184 .53139 .42541 Mtetra
.53139 .42541 .53718 .43184 .54795 .4283 .54219 .42184 Mtetra
.54219 .42184 .54795 .4283 .55877 .42475 .55304 .41827 Mtetra
.657 .753 .92 r
.55304 .41827 .55877 .42475 .56963 .42119 .56392 .41468 Mtetra
.56392 .41468 .56963 .42119 .58053 .41762 .57485 .41108 Mtetra
.57485 .41108 .58053 .41762 .59147 .41403 .58582 .40747 Mtetra
.657 .752 .92 r
.58582 .40747 .59147 .41403 .60245 .41043 .59684 .40384 Mtetra
.59684 .40384 .60245 .41043 .61348 .40682 .60789 .4002 Mtetra
.60789 .4002 .61348 .40682 .62455 .4032 .619 .39655 Mtetra
.619 .39655 .62455 .4032 .63567 .39956 .63014 .39289 Mtetra
.63014 .39289 .63567 .39956 .64683 .39591 .64133 .38921 Mtetra
.64133 .38921 .64683 .39591 .65803 .39224 .65257 .38552 Mtetra
.65257 .38552 .65803 .39224 .66928 .38856 .66384 .38181 Mtetra
.66384 .38181 .66928 .38856 .68057 .38487 .67517 .37809 Mtetra
.67517 .37809 .68057 .38487 .69191 .38117 .68654 .37436 Mtetra
.68654 .37436 .69191 .38117 .7033 .37744 .69795 .37061 Mtetra
.69795 .37061 .7033 .37744 .71473 .37371 .70942 .36685 Mtetra
.70942 .36685 .71473 .37371 .7262 .36996 .72092 .36307 Mtetra
.72092 .36307 .7262 .36996 .73772 .3662 .73248 .35928 Mtetra
.73248 .35928 .73772 .3662 .74929 .36242 .74408 .35547 Mtetra
.74408 .35547 .74929 .36242 .76091 .35862 .75573 .35165 Mtetra
.75573 .35165 .76091 .35862 .77257 .35482 .76742 .34781 Mtetra
.76742 .34781 .77257 .35482 .78428 .35099 .77917 .34396 Mtetra
.77917 .34396 .78428 .35099 .79604 .34715 .79096 .34009 Mtetra
.79096 .34009 .79604 .34715 .80784 .3433 .8028 .33621 Mtetra
.8028 .33621 .80784 .3433 .81969 .33943 .81468 .33231 Mtetra
.81468 .33231 .81969 .33943 .8316 .33555 .82662 .32839 Mtetra
.82662 .32839 .8316 .33555 .84355 .33165 .83861 .32446 Mtetra
.767 .652 .736 r
.19986 .52852 .20588 .54038 .21642 .52698 .21023 .51721 Mtetra
.429 .537 .865 r
.21023 .51721 .21642 .52698 .22587 .52549 .21937 .5191 Mtetra
.61 .718 .922 r
.21937 .5191 .22587 .52549 .23543 .52331 .22894 .517 Mtetra
.602 .719 .927 r
.22894 .517 .23543 .52331 .24491 .52248 .23853 .51503 Mtetra
.903 .493 .12 r
.23853 .51503 .24491 .52248 .25518 .5124 .24623 .53633 Mtetra
0 0 0 r
.24623 .53633 .25518 .5124 .26468 .51235 .25827 .50567 Mtetra
.602 .708 .919 r
.25827 .50567 .26468 .51235 .27439 .51 .26797 .50373 Mtetra
.626 .731 .922 r
.26797 .50373 .27439 .51 .28416 .50755 .27776 .50122 Mtetra
.613 .725 .926 r
.27776 .50122 .28416 .50755 .29388 .50624 .28757 .49899 Mtetra
0 .171 .687 r
.28757 .49899 .29388 .50624 .30429 .49546 .29674 .50659 Mtetra
.664 .845 .436 r
.29674 .50659 .30429 .49546 .31396 .4961 .30766 .48925 Mtetra
.602 .706 .917 r
.30766 .48925 .31396 .4961 .32388 .49358 .31756 .48727 Mtetra
.635 .735 .921 r
.31756 .48727 .32388 .49358 .33386 .49074 .32755 .48451 Mtetra
.64 .74 .921 r
.32755 .48451 .33386 .49074 .34388 .48787 .3376 .4816 Mtetra
.637 .739 .922 r
.3376 .4816 .34388 .48787 .35393 .48521 .34768 .47876 Mtetra
.612 .725 .926 r
.34768 .47876 .35393 .48521 .36392 .48457 .35777 .47648 Mtetra
.935 .712 .576 r
.35777 .47648 .36392 .48457 .37441 .47418 .37124 .40421 Mtetra
0 0 .392 r
.37124 .40421 .37441 .47418 .3845 .47312 .37834 .46637 Mtetra
.62 .72 .918 r
.37834 .46637 .3845 .47312 .39471 .47027 .38855 .46391 Mtetra
.644 .742 .92 r
.38855 .46391 .39471 .47027 .40498 .46711 .39884 .46083 Mtetra
.651 .747 .92 r
.39884 .46083 .40498 .46711 .41529 .46383 .40917 .45758 Mtetra
.654 .75 .92 r
.40917 .45758 .41529 .46383 .42564 .46047 .41955 .45422 Mtetra
.657 .752 .92 r
.41955 .45422 .42564 .46047 .43603 .45705 .42996 .4508 Mtetra
.658 .753 .92 r
.42996 .4508 .43603 .45705 .44647 .45359 .44042 .44732 Mtetra
.659 .754 .92 r
.44042 .44732 .44647 .45359 .45694 .4501 .45092 .44382 Mtetra
.45092 .44382 .45694 .4501 .46746 .4466 .46146 .44029 Mtetra
.46146 .44029 .46746 .4466 .47801 .44308 .47204 .43675 Mtetra
.47204 .43675 .47801 .44308 .4886 .43956 .48267 .4332 Mtetra
.658 .753 .92 r
.48267 .4332 .4886 .43956 .49924 .43604 .49333 .42964 Mtetra
.49333 .42964 .49924 .43604 .50992 .4325 .50403 .42608 Mtetra
.50403 .42608 .50992 .4325 .52063 .42896 .51478 .42251 Mtetra
.51478 .42251 .52063 .42896 .53139 .42541 .52556 .41893 Mtetra
.52556 .41893 .53139 .42541 .54219 .42184 .53639 .41534 Mtetra
.53639 .41534 .54219 .42184 .55304 .41827 .54726 .41174 Mtetra
.54726 .41174 .55304 .41827 .56392 .41468 .55818 .40812 Mtetra
.657 .753 .92 r
.55818 .40812 .56392 .41468 .57485 .41108 .56913 .4045 Mtetra
.56913 .4045 .57485 .41108 .58582 .40747 .58013 .40086 Mtetra
.58013 .40086 .58582 .40747 .59684 .40384 .59118 .3972 Mtetra
.657 .752 .92 r
.59118 .3972 .59684 .40384 .60789 .4002 .60226 .39354 Mtetra
.60226 .39354 .60789 .4002 .619 .39655 .6134 .38986 Mtetra
.6134 .38986 .619 .39655 .63014 .39289 .62457 .38617 Mtetra
.62457 .38617 .63014 .39289 .64133 .38921 .63579 .38246 Mtetra
.63579 .38246 .64133 .38921 .65257 .38552 .64706 .37874 Mtetra
.64706 .37874 .65257 .38552 .66384 .38181 .65837 .37501 Mtetra
.65837 .37501 .66384 .38181 .67517 .37809 .66972 .37126 Mtetra
.66972 .37126 .67517 .37809 .68654 .37436 .68112 .3675 Mtetra
.68112 .3675 .68654 .37436 .69795 .37061 .69257 .36372 Mtetra
.69257 .36372 .69795 .37061 .70942 .36685 .70407 .35993 Mtetra
.70407 .35993 .70942 .36685 .72092 .36307 .71561 .35612 Mtetra
.71561 .35612 .72092 .36307 .73248 .35928 .72719 .3523 Mtetra
.72719 .3523 .73248 .35928 .74408 .35547 .73883 .34847 Mtetra
.73883 .34847 .74408 .35547 .75573 .35165 .75051 .34462 Mtetra
.75051 .34462 .75573 .35165 .76742 .34781 .76224 .34075 Mtetra
.76224 .34075 .76742 .34781 .77917 .34396 .77401 .33687 Mtetra
.77401 .33687 .77917 .34396 .79096 .34009 .78584 .33297 Mtetra
.78584 .33297 .79096 .34009 .8028 .33621 .79771 .32906 Mtetra
.79771 .32906 .8028 .33621 .81468 .33231 .80964 .32513 Mtetra
.80964 .32513 .81468 .33231 .82662 .32839 .82161 .32119 Mtetra
.82161 .32119 .82662 .32839 .83861 .32446 .83363 .31723 Mtetra
.081 .431 .873 r
.19334 .5215 .19986 .52852 .21023 .51721 .20224 .52571 Mtetra
.696 .913 .57 r
.20224 .52571 .21023 .51721 .21937 .5191 .21287 .51222 Mtetra
.584 .694 .918 r
.21287 .51222 .21937 .5191 .22894 .517 .2224 .51067 Mtetra
.614 .723 .924 r
.2224 .51067 .22894 .517 .23853 .51503 .23203 .50845 Mtetra
.543 .69 .935 r
.23203 .50845 .23853 .51503 .24623 .53633 .24159 .50757 Mtetra
.664 .501 .653 r
.24159 .50757 .24623 .53633 .25827 .50567 .25195 .4974 Mtetra
.519 .627 .898 r
.25195 .4974 .25827 .50567 .26797 .50373 .26152 .49731 Mtetra
.621 .725 .921 r
.26152 .49731 .26797 .50373 .27776 .50122 .27132 .49491 Mtetra
.624 .731 .923 r
.27132 .49491 .27776 .50122 .28757 .49899 .28116 .4924 Mtetra
.568 .703 .932 r
.28116 .4924 .28757 .49899 .29674 .50659 .29097 .49105 Mtetra
.735 .607 .716 r
.29097 .49105 .29674 .50659 .30766 .48925 .30146 .48018 Mtetra
.491 .593 .883 r
.30146 .48018 .30766 .48925 .31756 .48727 .31121 .48077 Mtetra
.626 .728 .92 r
.31121 .48077 .31756 .48727 .32755 .48451 .32121 .4782 Mtetra
.639 .739 .921 r
.32121 .4782 .32755 .48451 .3376 .4816 .33127 .47531 Mtetra
.64 .74 .922 r
.33127 .47531 .3376 .4816 .34768 .47876 .34138 .47238 Mtetra
.63 .735 .923 r
.34138 .47238 .34768 .47876 .35777 .47648 .35152 .46966 Mtetra
.53 .683 .936 r
.35152 .46966 .35777 .47648 .37124 .40421 .36159 .46897 Mtetra
.456 .204 .443 r
.36159 .46897 .37124 .40421 .37834 .46637 .37218 .45849 Mtetra
.563 .664 .905 r
.37218 .45849 .37834 .46637 .38855 .46391 .38235 .45738 Mtetra
.637 .735 .92 r
.38235 .45738 .38855 .46391 .39884 .46083 .39265 .45447 Mtetra
.648 .745 .92 r
.39265 .45447 .39884 .46083 .40917 .45758 .40301 .45126 Mtetra
.653 .749 .92 r
.40301 .45126 .40917 .45758 .41955 .45422 .41341 .44791 Mtetra
.656 .751 .92 r
.41341 .44791 .41955 .45422 .42996 .4508 .42385 .44449 Mtetra
.657 .752 .92 r
.42385 .44449 .42996 .4508 .44042 .44732 .43434 .44101 Mtetra
.658 .753 .92 r
.43434 .44101 .44042 .44732 .45092 .44382 .44486 .43748 Mtetra
.659 .754 .92 r
.44486 .43748 .45092 .44382 .46146 .44029 .45543 .43393 Mtetra
.45543 .43393 .46146 .44029 .47204 .43675 .46603 .43037 Mtetra
.46603 .43037 .47204 .43675 .48267 .4332 .47668 .42679 Mtetra
.47668 .42679 .48267 .4332 .49333 .42964 .48737 .4232 Mtetra
.658 .753 .92 r
.48737 .4232 .49333 .42964 .50403 .42608 .4981 .41961 Mtetra
.4981 .41961 .50403 .42608 .51478 .42251 .50888 .41601 Mtetra
.50888 .41601 .51478 .42251 .52556 .41893 .51969 .41241 Mtetra
.51969 .41241 .52556 .41893 .53639 .41534 .53055 .40879 Mtetra
.53055 .40879 .53639 .41534 .54726 .41174 .54145 .40516 Mtetra
.54145 .40516 .54726 .41174 .55818 .40812 .55239 .40152 Mtetra
.657 .753 .92 r
.55239 .40152 .55818 .40812 .56913 .4045 .56337 .39786 Mtetra
.56337 .39786 .56913 .4045 .58013 .40086 .5744 .3942 Mtetra
.5744 .3942 .58013 .40086 .59118 .3972 .58548 .39052 Mtetra
.657 .752 .92 r
.58548 .39052 .59118 .3972 .60226 .39354 .59659 .38682 Mtetra
.59659 .38682 .60226 .39354 .6134 .38986 .60776 .38312 Mtetra
.60776 .38312 .6134 .38986 .62457 .38617 .61896 .3794 Mtetra
.61896 .3794 .62457 .38617 .63579 .38246 .63021 .37566 Mtetra
.63021 .37566 .63579 .38246 .64706 .37874 .64151 .37192 Mtetra
.64151 .37192 .64706 .37874 .65837 .37501 .65285 .36816 Mtetra
.65285 .36816 .65837 .37501 .66972 .37126 .66424 .36438 Mtetra
.66424 .36438 .66972 .37126 .68112 .3675 .67567 .36059 Mtetra
.67567 .36059 .68112 .3675 .69257 .36372 .68715 .35678 Mtetra
.68715 .35678 .69257 .36372 .70407 .35993 .69867 .35296 Mtetra
.69867 .35296 .70407 .35993 .71561 .35612 .71025 .34913 Mtetra
.71025 .34913 .71561 .35612 .72719 .3523 .72187 .34528 Mtetra
.72187 .34528 .72719 .3523 .73883 .34847 .73353 .34141 Mtetra
.73353 .34141 .73883 .34847 .75051 .34462 .74525 .33753 Mtetra
.74525 .33753 .75051 .34462 .76224 .34075 .75701 .33364 Mtetra
.75701 .33364 .76224 .34075 .77401 .33687 .76882 .32973 Mtetra
.76882 .32973 .77401 .33687 .78584 .33297 .78068 .3258 Mtetra
.78068 .3258 .78584 .33297 .79771 .32906 .79259 .32186 Mtetra
.79259 .32186 .79771 .32906 .80964 .32513 .80455 .3179 Mtetra
.80455 .3179 .80964 .32513 .82161 .32119 .81656 .31392 Mtetra
.81656 .31392 .82161 .32119 .83363 .31723 .82861 .30993 Mtetra
.565 .7 .932 r
.18672 .51499 .19334 .5215 .20224 .52571 .19616 .51373 Mtetra
.767 .653 .736 r
.19616 .51373 .20224 .52571 .21287 .51222 .20662 .50232 Mtetra
.428 .537 .866 r
.20662 .50232 .21287 .51222 .2224 .51067 .21583 .50418 Mtetra
.61 .718 .922 r
.21583 .50418 .2224 .51067 .23203 .50845 .22547 .50203 Mtetra
.602 .719 .927 r
.22547 .50203 .23203 .50845 .24159 .50757 .23514 .50001 Mtetra
.901 .489 .113 r
.23514 .50001 .24159 .50757 .25195 .4974 .24288 .52136 Mtetra
0 0 0 r
.24288 .52136 .25195 .4974 .26152 .49731 .25505 .49052 Mtetra
.602 .708 .919 r
.25505 .49052 .26152 .49731 .27132 .49491 .26483 .48853 Mtetra
.626 .731 .922 r
.26483 .48853 .27132 .49491 .28116 .4924 .2747 .48597 Mtetra
.613 .725 .925 r
.2747 .48597 .28116 .4924 .29097 .49105 .28458 .48368 Mtetra
0 .176 .692 r
.28458 .48368 .29097 .49105 .30146 .48018 .29383 .49128 Mtetra
.673 .852 .445 r
.29383 .49128 .30146 .48018 .31121 .48077 .30484 .47381 Mtetra
.602 .706 .917 r
.30484 .47381 .31121 .48077 .32121 .4782 .31483 .47178 Mtetra
.635 .735 .921 r
.31483 .47178 .32121 .4782 .33127 .47531 .32491 .46896 Mtetra
.64 .74 .921 r
.32491 .46896 .33127 .47531 .34138 .47238 .33504 .466 Mtetra
.637 .739 .922 r
.33504 .466 .34138 .47238 .35152 .46966 .3452 .4631 Mtetra
.612 .725 .926 r
.3452 .4631 .35152 .46966 .36159 .46897 .35538 .46077 Mtetra
.936 .712 .574 r
.35538 .46077 .36159 .46897 .37218 .45849 .36901 .38815 Mtetra
0 0 .388 r
.36901 .38815 .37218 .45849 .38235 .45738 .37612 .45052 Mtetra
.62 .72 .918 r
.37612 .45052 .38235 .45738 .39265 .45447 .38643 .44799 Mtetra
.644 .742 .92 r
.38643 .44799 .39265 .45447 .40301 .45126 .3968 .44486 Mtetra
.651 .747 .92 r
.3968 .44486 .40301 .45126 .41341 .44791 .40723 .44154 Mtetra
.654 .75 .92 r
.40723 .44154 .41341 .44791 .42385 .44449 .41769 .43813 Mtetra
.657 .752 .92 r
.41769 .43813 .42385 .44449 .43434 .44101 .4282 .43464 Mtetra
.658 .753 .92 r
.4282 .43464 .43434 .44101 .44486 .43748 .43875 .4311 Mtetra
.659 .754 .92 r
.43875 .4311 .44486 .43748 .45543 .43393 .44935 .42753 Mtetra
.44935 .42753 .45543 .43393 .46603 .43037 .45998 .42394 Mtetra
.45998 .42394 .46603 .43037 .47668 .42679 .47066 .42033 Mtetra
.47066 .42033 .47668 .42679 .48737 .4232 .48137 .41672 Mtetra
.658 .753 .92 r
.48137 .41672 .48737 .4232 .4981 .41961 .49213 .4131 Mtetra
.49213 .4131 .4981 .41961 .50888 .41601 .50293 .40947 Mtetra
.50293 .40947 .50888 .41601 .51969 .41241 .51377 .40584 Mtetra
.51377 .40584 .51969 .41241 .53055 .40879 .52466 .40219 Mtetra
.52466 .40219 .53055 .40879 .54145 .40516 .53559 .39853 Mtetra
.53559 .39853 .54145 .40516 .55239 .40152 .54656 .39486 Mtetra
.54656 .39486 .55239 .40152 .56337 .39786 .55757 .39118 Mtetra
.657 .753 .92 r
.55757 .39118 .56337 .39786 .5744 .3942 .56863 .38749 Mtetra
.56863 .38749 .5744 .3942 .58548 .39052 .57973 .38378 Mtetra
.57973 .38378 .58548 .39052 .59659 .38682 .59088 .38006 Mtetra
.657 .752 .92 r
.59088 .38006 .59659 .38682 .60776 .38312 .60207 .37633 Mtetra
.60207 .37633 .60776 .38312 .61896 .3794 .61331 .37258 Mtetra
.61331 .37258 .61896 .3794 .63021 .37566 .62459 .36882 Mtetra
.62459 .36882 .63021 .37566 .64151 .37192 .63592 .36504 Mtetra
.63592 .36504 .64151 .37192 .65285 .36816 .64729 .36125 Mtetra
.64729 .36125 .65285 .36816 .66424 .36438 .65871 .35745 Mtetra
.65871 .35745 .66424 .36438 .67567 .36059 .67017 .35363 Mtetra
.67017 .35363 .67567 .36059 .68715 .35678 .68169 .34979 Mtetra
.68169 .34979 .68715 .35678 .69867 .35296 .69324 .34594 Mtetra
.69324 .34594 .69867 .35296 .71025 .34913 .70485 .34208 Mtetra
.70485 .34208 .71025 .34913 .72187 .34528 .7165 .3382 Mtetra
.7165 .3382 .72187 .34528 .73353 .34141 .7282 .33431 Mtetra
.7282 .33431 .73353 .34141 .74525 .33753 .73995 .3304 Mtetra
.73995 .3304 .74525 .33753 .75701 .33364 .75175 .32647 Mtetra
.75175 .32647 .75701 .33364 .76882 .32973 .76359 .32253 Mtetra
.76359 .32253 .76882 .32973 .78068 .3258 .77549 .31857 Mtetra
.77549 .31857 .78068 .3258 .79259 .32186 .78743 .3146 Mtetra
.78743 .3146 .79259 .32186 .80455 .3179 .79942 .31061 Mtetra
.79942 .31061 .80455 .3179 .81656 .31392 .81147 .30661 Mtetra
.81147 .30661 .81656 .31392 .82861 .30993 .82356 .30258 Mtetra
.6 .716 .926 r
.18005 .50854 .18672 .51499 .19616 .51373 .18957 .5066 Mtetra
.085 .433 .874 r
.18957 .5066 .19616 .51373 .20662 .50232 .19853 .51079 Mtetra
.704 .919 .579 r
.19853 .51079 .20662 .50232 .21583 .50418 .20926 .49719 Mtetra
.584 .694 .918 r
.20926 .49719 .21583 .50418 .22547 .50203 .21887 .49559 Mtetra
.614 .723 .924 r
.21887 .49559 .22547 .50203 .23514 .50001 .22857 .49332 Mtetra
.543 .69 .935 r
.22857 .49332 .23514 .50001 .24288 .52136 .2382 .49239 Mtetra
.664 .5 .653 r
.2382 .49239 .24288 .52136 .25505 .49052 .24867 .48214 Mtetra
.518 .627 .898 r
.24867 .48214 .25505 .49052 .26483 .48853 .25831 .48201 Mtetra
.621 .725 .921 r
.25831 .48201 .26483 .48853 .2747 .48597 .26818 .47954 Mtetra
.624 .731 .923 r
.26818 .47954 .2747 .48597 .28458 .48368 .27811 .47698 Mtetra
.568 .703 .932 r
.27811 .47698 .28458 .48368 .29383 .49128 .288 .47558 Mtetra
.735 .608 .716 r
.288 .47558 .29383 .49128 .30484 .47381 .29859 .46462 Mtetra
.491 .593 .884 r
.29859 .46462 .30484 .47381 .31483 .47178 .30841 .46517 Mtetra
.626 .728 .92 r
.30841 .46517 .31483 .47178 .32491 .46896 .3185 .46254 Mtetra
.639 .739 .921 r
.3185 .46254 .32491 .46896 .33504 .466 .32865 .45959 Mtetra
.64 .74 .922 r
.32865 .45959 .33504 .466 .3452 .4631 .33884 .4566 Mtetra
.63 .735 .923 r
.33884 .4566 .3452 .4631 .35538 .46077 .34906 .45383 Mtetra
.53 .683 .936 r
.34906 .45383 .35538 .46077 .36901 .38815 .35922 .45309 Mtetra
.451 .198 .438 r
.35922 .45309 .36901 .38815 .37612 .45052 .36991 .44252 Mtetra
.563 .664 .905 r
.36991 .44252 .37612 .45052 .38643 .44799 .38017 .44135 Mtetra
.637 .735 .92 r
.38017 .44135 .38643 .44799 .3968 .44486 .39056 .43838 Mtetra
.648 .745 .92 r
.39056 .43838 .3968 .44486 .40723 .44154 .401 .43511 Mtetra
.653 .749 .92 r
.401 .43511 .40723 .44154 .41769 .43813 .41149 .4317 Mtetra
.656 .751 .92 r
.41149 .4317 .41769 .43813 .4282 .43464 .42203 .42822 Mtetra
.657 .752 .92 r
.42203 .42822 .4282 .43464 .43875 .4311 .4326 .42467 Mtetra
.658 .753 .92 r
.4326 .42467 .43875 .4311 .44935 .42753 .44322 .42108 Mtetra
.659 .754 .92 r
.44322 .42108 .44935 .42753 .45998 .42394 .45388 .41747 Mtetra
.45388 .41747 .45998 .42394 .47066 .42033 .46459 .41383 Mtetra
.46459 .41383 .47066 .42033 .48137 .41672 .47533 .41019 Mtetra
.47533 .41019 .48137 .41672 .49213 .4131 .48612 .40654 Mtetra
.658 .753 .92 r
.48612 .40654 .49213 .4131 .50293 .40947 .49694 .40289 Mtetra
.49694 .40289 .50293 .40947 .51377 .40584 .50782 .39922 Mtetra
.50782 .39922 .51377 .40584 .52466 .40219 .51873 .39555 Mtetra
.51873 .39555 .52466 .40219 .53559 .39853 .52969 .39186 Mtetra
.52969 .39186 .53559 .39853 .54656 .39486 .54069 .38816 Mtetra
.54069 .38816 .54656 .39486 .55757 .39118 .55173 .38445 Mtetra
.657 .753 .92 r
.55173 .38445 .55757 .39118 .56863 .38749 .56282 .38073 Mtetra
.56282 .38073 .56863 .38749 .57973 .38378 .57395 .37699 Mtetra
.57395 .37699 .57973 .38378 .59088 .38006 .58513 .37325 Mtetra
.657 .752 .92 r
.58513 .37325 .59088 .38006 .60207 .37633 .59635 .36948 Mtetra
.59635 .36948 .60207 .37633 .61331 .37258 .60762 .36571 Mtetra
.60762 .36571 .61331 .37258 .62459 .36882 .61893 .36192 Mtetra
.61893 .36192 .62459 .36882 .63592 .36504 .63029 .35811 Mtetra
.63029 .35811 .63592 .36504 .64729 .36125 .64169 .35429 Mtetra
.64169 .35429 .64729 .36125 .65871 .35745 .65314 .35046 Mtetra
.65314 .35046 .65871 .35745 .67017 .35363 .66464 .34661 Mtetra
.66464 .34661 .67017 .35363 .68169 .34979 .67618 .34275 Mtetra
.67618 .34275 .68169 .34979 .69324 .34594 .68777 .33887 Mtetra
.68777 .33887 .69324 .34594 .70485 .34208 .69941 .33498 Mtetra
.69941 .33498 .70485 .34208 .7165 .3382 .71109 .33107 Mtetra
.71109 .33107 .7165 .3382 .7282 .33431 .72283 .32714 Mtetra
.72283 .32714 .7282 .33431 .73995 .3304 .73461 .3232 Mtetra
.73461 .3232 .73995 .3304 .75175 .32647 .74644 .31925 Mtetra
.74644 .31925 .75175 .32647 .76359 .32253 .75832 .31528 Mtetra
.75832 .31528 .76359 .32253 .77549 .31857 .77025 .31129 Mtetra
.77025 .31129 .77549 .31857 .78743 .3146 .78223 .30729 Mtetra
.78223 .30729 .78743 .3146 .79942 .31061 .79426 .30327 Mtetra
.79426 .30327 .79942 .31061 .81147 .30661 .80634 .29923 Mtetra
.80634 .29923 .81147 .30661 .82356 .30258 .81847 .29518 Mtetra
.6 .713 .923 r
.17334 .50195 .18005 .50854 .18957 .5066 .18288 .49998 Mtetra
.565 .7 .932 r
.18288 .49998 .18957 .5066 .19853 .51079 .19239 .49867 Mtetra
.767 .654 .736 r
.19239 .49867 .19853 .51079 .20926 .49719 .20294 .48717 Mtetra
.427 .537 .866 r
.20294 .48717 .20926 .49719 .21887 .49559 .21223 .489 Mtetra
.61 .718 .922 r
.21223 .489 .21887 .49559 .22857 .49332 .22194 .48679 Mtetra
.602 .719 .927 r
.22194 .48679 .22857 .49332 .2382 .49239 .23169 .48472 Mtetra
.899 .486 .106 r
.23169 .48472 .2382 .49239 .24867 .48214 .23947 .50612 Mtetra
0 0 0 r
.23947 .50612 .24867 .48214 .25831 .48201 .25177 .4751 Mtetra
.602 .708 .919 r
.25177 .4751 .25831 .48201 .26818 .47954 .26163 .47306 Mtetra
.626 .731 .922 r
.26163 .47306 .26818 .47954 .27811 .47698 .27158 .47044 Mtetra
.613 .725 .925 r
.27158 .47044 .27811 .47698 .288 .47558 .28155 .4681 Mtetra
0 .181 .696 r
.28155 .4681 .288 .47558 .29859 .46462 .29086 .47568 Mtetra
.682 .859 .455 r
.29086 .47568 .29859 .46462 .30841 .46517 .30198 .45809 Mtetra
.602 .706 .917 r
.30198 .45809 .30841 .46517 .3185 .46254 .31205 .45601 Mtetra
.635 .735 .921 r
.31205 .45601 .3185 .46254 .32865 .45959 .32221 .45313 Mtetra
.64 .74 .921 r
.32221 .45313 .32865 .45959 .33884 .4566 .33243 .45011 Mtetra
.637 .739 .922 r
.33243 .45011 .33884 .4566 .34906 .45383 .34268 .44715 Mtetra
.612 .725 .926 r
.34268 .44715 .34906 .45383 .35922 .45309 .35295 .44476 Mtetra
.937 .713 .572 r
.35295 .44476 .35922 .45309 .36991 .44252 .36675 .37181 Mtetra
0 0 .383 r
.36675 .37181 .36991 .44252 .38017 .44135 .37387 .43438 Mtetra
.62 .72 .918 r
.37387 .43438 .38017 .44135 .39056 .43838 .38427 .43179 Mtetra
.644 .742 .92 r
.38427 .43179 .39056 .43838 .401 .43511 .39473 .4286 Mtetra
.651 .747 .92 r
.39473 .4286 .401 .43511 .41149 .4317 .40525 .42522 Mtetra
.654 .75 .92 r
.40525 .42522 .41149 .4317 .42203 .42822 .41581 .42173 Mtetra
.657 .752 .92 r
.41581 .42173 .42203 .42822 .4326 .42467 .42641 .41818 Mtetra
.658 .753 .92 r
.42641 .41818 .4326 .42467 .44322 .42108 .43706 .41458 Mtetra
.659 .754 .92 r
.43706 .41458 .44322 .42108 .45388 .41747 .44774 .41095 Mtetra
.44774 .41095 .45388 .41747 .46459 .41383 .45847 .40729 Mtetra
.45847 .40729 .46459 .41383 .47533 .41019 .46924 .40362 Mtetra
.46924 .40362 .47533 .41019 .48612 .40654 .48006 .39994 Mtetra
.658 .753 .92 r
.48006 .39994 .48612 .40654 .49694 .40289 .49091 .39625 Mtetra
.49091 .39625 .49694 .40289 .50782 .39922 .50181 .39256 Mtetra
.50181 .39256 .50782 .39922 .51873 .39555 .51275 .38885 Mtetra
.51275 .38885 .51873 .39555 .52969 .39186 .52374 .38514 Mtetra
.52374 .38514 .52969 .39186 .54069 .38816 .53477 .38141 Mtetra
.53477 .38141 .54069 .38816 .55173 .38445 .54584 .37767 Mtetra
.54584 .37767 .55173 .38445 .56282 .38073 .55696 .37392 Mtetra
.657 .753 .92 r
.55696 .37392 .56282 .38073 .57395 .37699 .56812 .37016 Mtetra
.56812 .37016 .57395 .37699 .58513 .37325 .57933 .36638 Mtetra
.57933 .36638 .58513 .37325 .59635 .36948 .59058 .36259 Mtetra
.657 .752 .92 r
.59058 .36259 .59635 .36948 .60762 .36571 .60188 .35879 Mtetra
.60188 .35879 .60762 .36571 .61893 .36192 .61322 .35497 Mtetra
.61322 .35497 .61893 .36192 .63029 .35811 .62461 .35113 Mtetra
.62461 .35113 .63029 .35811 .64169 .35429 .63605 .34729 Mtetra
.63605 .34729 .64169 .35429 .65314 .35046 .64753 .34342 Mtetra
.64753 .34342 .65314 .35046 .66464 .34661 .65906 .33955 Mtetra
.65906 .33955 .66464 .34661 .67618 .34275 .67063 .33565 Mtetra
.67063 .33565 .67618 .34275 .68777 .33887 .68226 .33174 Mtetra
.68226 .33174 .68777 .33887 .69941 .33498 .69393 .32782 Mtetra
.69393 .32782 .69941 .33498 .71109 .33107 .70565 .32388 Mtetra
.70565 .32388 .71109 .33107 .72283 .32714 .71741 .31993 Mtetra
.71741 .31993 .72283 .32714 .73461 .3232 .72923 .31596 Mtetra
.72923 .31596 .73461 .3232 .74644 .31925 .7411 .31197 Mtetra
.7411 .31197 .74644 .31925 .75832 .31528 .75301 .30797 Mtetra
.75301 .30797 .75832 .31528 .77025 .31129 .76498 .30395 Mtetra
.76498 .30395 .77025 .31129 .78223 .30729 .77699 .29992 Mtetra
.77699 .29992 .78223 .30729 .79426 .30327 .78905 .29587 Mtetra
.78905 .29587 .79426 .30327 .80634 .29923 .80117 .2918 Mtetra
.80117 .2918 .80634 .29923 .81847 .29518 .81333 .28771 Mtetra
.57 .684 .917 r
.16665 .49476 .17334 .50195 .18288 .49998 .17613 .49343 Mtetra
.6 .716 .926 r
.17613 .49343 .18288 .49998 .19239 .49867 .18573 .49143 Mtetra
.089 .435 .875 r
.18573 .49143 .19239 .49867 .20294 .48717 .19476 .49559 Mtetra
.712 .924 .588 r
.19476 .49559 .20294 .48717 .21223 .489 .20559 .4819 Mtetra
.584 .694 .918 r
.20559 .4819 .21223 .489 .22194 .48679 .21527 .48025 Mtetra
.614 .723 .924 r
.21527 .48025 .22194 .48679 .23169 .48472 .22505 .47792 Mtetra
.544 .69 .935 r
.22505 .47792 .23169 .48472 .23947 .50612 .23476 .47694 Mtetra
.663 .499 .652 r
.23476 .47694 .23947 .50612 .25177 .4751 .24532 .4666 Mtetra
.518 .627 .898 r
.24532 .4666 .25177 .4751 .26163 .47306 .25504 .46642 Mtetra
.621 .725 .921 r
.25504 .46642 .26163 .47306 .27158 .47044 .265 .46391 Mtetra
.624 .731 .923 r
.265 .46391 .27158 .47044 .28155 .4681 .275 .46129 Mtetra
.568 .703 .932 r
.275 .46129 .28155 .4681 .29086 .47568 .28497 .45983 Mtetra
.735 .608 .716 r
.28497 .45983 .29086 .47568 .30198 .45809 .29566 .44878 Mtetra
.49 .593 .884 r
.29566 .44878 .30198 .45809 .31205 .45601 .30556 .44928 Mtetra
.626 .728 .92 r
.30556 .44928 .31205 .45601 .32221 .45313 .31574 .4466 Mtetra
.639 .739 .921 r
.31574 .4466 .32221 .45313 .33243 .45011 .32597 .44359 Mtetra
.64 .74 .922 r
.32597 .44359 .33243 .45011 .34268 .44715 .33625 .44054 Mtetra
.63 .735 .923 r
.33625 .44054 .34268 .44715 .35295 .44476 .34656 .43771 Mtetra
.531 .683 .936 r
.34656 .43771 .35295 .44476 .36675 .37181 .35681 .43691 Mtetra
.446 .192 .433 r
.35681 .43691 .36675 .37181 .37387 .43438 .36759 .42625 Mtetra
.563 .664 .905 r
.36759 .42625 .37387 .43438 .38427 .43179 .37794 .42503 Mtetra
.637 .735 .92 r
.37794 .42503 .38427 .43179 .39473 .4286 .38842 .422 Mtetra
.648 .745 .92 r
.38842 .422 .39473 .4286 .40525 .42522 .39896 .41866 Mtetra
.653 .749 .92 r
.39896 .41866 .40525 .42522 .41581 .42173 .40954 .41519 Mtetra
.656 .751 .92 r
.40954 .41519 .41581 .42173 .42641 .41818 .42017 .41164 Mtetra
.657 .752 .92 r
.42017 .41164 .42641 .41818 .43706 .41458 .43084 .40803 Mtetra
.658 .753 .92 r
.43084 .40803 .43706 .41458 .44774 .41095 .44156 .40438 Mtetra
.659 .754 .92 r
.44156 .40438 .44774 .41095 .45847 .40729 .45231 .40069 Mtetra
.45231 .40069 .45847 .40729 .46924 .40362 .46311 .397 Mtetra
.46311 .397 .46924 .40362 .48006 .39994 .47395 .39329 Mtetra
.47395 .39329 .48006 .39994 .49091 .39625 .48484 .38957 Mtetra
.658 .753 .92 r
.48484 .38957 .49091 .39625 .50181 .39256 .49577 .38584 Mtetra
.49577 .38584 .50181 .39256 .51275 .38885 .50674 .38211 Mtetra
.50674 .38211 .51275 .38885 .52374 .38514 .51775 .37837 Mtetra
.51775 .37837 .52374 .38514 .53477 .38141 .52881 .37461 Mtetra
.52881 .37461 .53477 .38141 .54584 .37767 .53991 .37084 Mtetra
.53991 .37084 .54584 .37767 .55696 .37392 .55106 .36706 Mtetra
.657 .753 .92 r
.55106 .36706 .55696 .37392 .56812 .37016 .56225 .36327 Mtetra
.56225 .36327 .56812 .37016 .57933 .36638 .57349 .35947 Mtetra
.57349 .35947 .57933 .36638 .59058 .36259 .58477 .35565 Mtetra
.657 .752 .92 r
.58477 .35565 .59058 .36259 .60188 .35879 .5961 .35181 Mtetra
.5961 .35181 .60188 .35879 .61322 .35497 .60747 .34796 Mtetra
.60747 .34796 .61322 .35497 .62461 .35113 .61889 .3441 Mtetra
.61889 .3441 .62461 .35113 .63605 .34729 .63036 .34022 Mtetra
.63036 .34022 .63605 .34729 .64753 .34342 .64187 .33633 Mtetra
.64187 .33633 .64753 .34342 .65906 .33955 .65343 .33242 Mtetra
.65343 .33242 .65906 .33955 .67063 .33565 .66504 .3285 Mtetra
.66504 .3285 .67063 .33565 .68226 .33174 .6767 .32456 Mtetra
.6767 .32456 .68226 .33174 .69393 .32782 .6884 .32061 Mtetra
.6884 .32061 .69393 .32782 .70565 .32388 .70016 .31664 Mtetra
.70016 .31664 .70565 .32388 .71741 .31993 .71196 .31266 Mtetra
.71196 .31266 .71741 .31993 .72923 .31596 .72381 .30866 Mtetra
.72381 .30866 .72923 .31596 .7411 .31197 .73571 .30464 Mtetra
.73571 .30464 .7411 .31197 .75301 .30797 .74766 .30061 Mtetra
.74766 .30061 .75301 .30797 .76498 .30395 .75966 .29656 Mtetra
.75966 .29656 .76498 .30395 .77699 .29992 .77171 .29249 Mtetra
.77171 .29249 .77699 .29992 .78905 .29587 .78381 .28841 Mtetra
.78381 .28841 .78905 .29587 .80117 .2918 .79596 .28431 Mtetra
.79596 .28431 .80117 .2918 .81333 .28771 .80816 .28019 Mtetra
.332 .443 .824 r
.16042 .48293 .16665 .49476 .17613 .49343 .16935 .48672 Mtetra
.6 .713 .923 r
.16935 .48672 .17613 .49343 .18573 .49143 .17897 .48471 Mtetra
.565 .7 .932 r
.17897 .48471 .18573 .49143 .19476 .49559 .18856 .48335 Mtetra
.768 .654 .737 r
.18856 .48335 .19476 .49559 .20559 .4819 .19921 .47176 Mtetra
.426 .537 .866 r
.19921 .47176 .20559 .4819 .21527 .48025 .20856 .47354 Mtetra
.61 .718 .922 r
.20856 .47354 .21527 .48025 .22505 .47792 .21835 .47128 Mtetra
.602 .719 .927 r
.21835 .47128 .22505 .47792 .23476 .47694 .22818 .46916 Mtetra
.897 .483 .098 r
.22818 .46916 .23476 .47694 .24532 .4666 .236 .4906 Mtetra
0 0 0 r
.236 .4906 .24532 .4666 .25504 .46642 .24843 .45941 Mtetra
.601 .708 .919 r
.24843 .45941 .25504 .46642 .265 .46391 .25837 .45731 Mtetra
.626 .731 .922 r
.25837 .45731 .265 .46391 .275 .46129 .2684 .45463 Mtetra
.613 .725 .925 r
.2684 .45463 .275 .46129 .28497 .45983 .27846 .45223 Mtetra
0 .185 .701 r
.27846 .45223 .28497 .45983 .29566 .44878 .28783 .4598 Mtetra
.691 .865 .464 r
.28783 .4598 .29566 .44878 .30556 .44928 .29906 .44209 Mtetra
.602 .706 .917 r
.29906 .44209 .30556 .44928 .31574 .4466 .30922 .43995 Mtetra
.635 .735 .921 r
.30922 .43995 .31574 .4466 .32597 .44359 .31947 .43701 Mtetra
.64 .74 .921 r
.31947 .43701 .32597 .44359 .33625 .44054 .32977 .43393 Mtetra
.637 .739 .922 r
.32977 .43393 .33625 .44054 .34656 .43771 .34011 .43091 Mtetra
.612 .725 .926 r
.34011 .43091 .34656 .43771 .35681 .43691 .35047 .42846 Mtetra
.939 .714 .571 r
.35047 .42846 .35681 .43691 .36759 .42625 .36444 .35517 Mtetra
0 0 .379 r
.36444 .35517 .36759 .42625 .37794 .42503 .37158 .41793 Mtetra
.62 .72 .918 r
.37158 .41793 .37794 .42503 .38842 .422 .38207 .41529 Mtetra
.644 .742 .92 r
.38207 .41529 .38842 .422 .39896 .41866 .39262 .41203 Mtetra
.651 .747 .92 r
.39262 .41203 .39896 .41866 .40954 .41519 .40323 .40859 Mtetra
.654 .75 .92 r
.40323 .40859 .40954 .41519 .42017 .41164 .41388 .40504 Mtetra
.657 .752 .92 r
.41388 .40504 .42017 .41164 .43084 .40803 .42458 .40142 Mtetra
.658 .753 .92 r
.42458 .40142 .43084 .40803 .44156 .40438 .43532 .39775 Mtetra
.659 .754 .92 r
.43532 .39775 .44156 .40438 .45231 .40069 .44611 .39405 Mtetra
.44611 .39405 .45231 .40069 .46311 .397 .45693 .39033 Mtetra
.45693 .39033 .46311 .397 .47395 .39329 .4678 .38659 Mtetra
.4678 .38659 .47395 .39329 .48484 .38957 .47872 .38284 Mtetra
.658 .753 .92 r
.47872 .38284 .48484 .38957 .49577 .38584 .48967 .37908 Mtetra
.48967 .37908 .49577 .38584 .50674 .38211 .50067 .37532 Mtetra
.50067 .37532 .50674 .38211 .51775 .37837 .51172 .37155 Mtetra
.51172 .37155 .51775 .37837 .52881 .37461 .5228 .36776 Mtetra
.5228 .36776 .52881 .37461 .53991 .37084 .53394 .36396 Mtetra
.53394 .36396 .53991 .37084 .55106 .36706 .54511 .36016 Mtetra
.54511 .36016 .55106 .36706 .56225 .36327 .55633 .35633 Mtetra
.657 .753 .92 r
.55633 .35633 .56225 .36327 .57349 .35947 .5676 .3525 Mtetra
.5676 .3525 .57349 .35947 .58477 .35565 .57891 .34865 Mtetra
.57891 .34865 .58477 .35565 .5961 .35181 .59027 .34479 Mtetra
.657 .752 .92 r
.59027 .34479 .5961 .35181 .60747 .34796 .60168 .34091 Mtetra
.60168 .34091 .60747 .34796 .61889 .3441 .61313 .33702 Mtetra
.61313 .33702 .61889 .3441 .63036 .34022 .62463 .33311 Mtetra
.62463 .33311 .63036 .34022 .64187 .33633 .63618 .32919 Mtetra
.63618 .32919 .64187 .33633 .65343 .33242 .64777 .32525 Mtetra
.64777 .32525 .65343 .33242 .66504 .3285 .65941 .3213 Mtetra
.65941 .3213 .66504 .3285 .6767 .32456 .6711 .31733 Mtetra
.6711 .31733 .6767 .32456 .6884 .32061 .68284 .31334 Mtetra
.68284 .31334 .6884 .32061 .70016 .31664 .69463 .30934 Mtetra
.69463 .30934 .70016 .31664 .71196 .31266 .70646 .30533 Mtetra
.70646 .30533 .71196 .31266 .72381 .30866 .71835 .3013 Mtetra
.71835 .3013 .72381 .30866 .73571 .30464 .73028 .29725 Mtetra
.73028 .29725 .73571 .30464 .74766 .30061 .74227 .29318 Mtetra
.74227 .29318 .74766 .30061 .75966 .29656 .7543 .2891 Mtetra
.7543 .2891 .75966 .29656 .77171 .29249 .76639 .28501 Mtetra
.76639 .28501 .77171 .29249 .78381 .28841 .77852 .28089 Mtetra
.77852 .28089 .78381 .28841 .79596 .28431 .79071 .27676 Mtetra
.79071 .27676 .79596 .28431 .80816 .28019 .80295 .27261 Mtetra
.624 .892 .574 r
.15192 .49112 .16042 .48293 .16935 .48672 .16259 .47942 Mtetra
.57 .684 .917 r
.16259 .47942 .16935 .48672 .17897 .48471 .17215 .47804 Mtetra
.6 .716 .926 r
.17215 .47804 .17897 .48471 .18856 .48335 .18182 .47599 Mtetra
.092 .437 .876 r
.18182 .47599 .18856 .48335 .19921 .47176 .19092 .48013 Mtetra
.72 .929 .596 r
.19092 .48013 .19921 .47176 .20856 .47354 .20185 .46633 Mtetra
.584 .694 .918 r
.20185 .46633 .20856 .47354 .21835 .47128 .21161 .46463 Mtetra
.614 .723 .924 r
.21161 .46463 .21835 .47128 .22818 .46916 .22147 .46224 Mtetra
.544 .69 .935 r
.22147 .46224 .22818 .46916 .236 .4906 .23126 .46122 Mtetra
.663 .498 .651 r
.23126 .46122 .236 .4906 .24843 .45941 .24191 .45079 Mtetra
.518 .627 .898 r
.24191 .45079 .24843 .45941 .25837 .45731 .25171 .45056 Mtetra
.621 .725 .921 r
.25171 .45056 .25837 .45731 .2684 .45463 .26175 .44798 Mtetra
.624 .731 .923 r
.26175 .44798 .2684 .45463 .27846 .45223 .27184 .44531 Mtetra
.568 .703 .932 r
.27184 .44531 .27846 .45223 .28783 .4598 .28189 .4438 Mtetra
.735 .608 .716 r
.28189 .4438 .28783 .4598 .29906 .44209 .29268 .43265 Mtetra
.49 .593 .884 r
.29268 .43265 .29906 .44209 .30922 .43995 .30267 .43311 Mtetra
.626 .728 .92 r
.30267 .43311 .30922 .43995 .31947 .43701 .31292 .43036 Mtetra
.639 .739 .921 r
.31292 .43036 .31947 .43701 .32977 .43393 .32325 .42729 Mtetra
.64 .74 .922 r
.32325 .42729 .32977 .43393 .34011 .43091 .33362 .42418 Mtetra
.63 .735 .923 r
.33362 .42418 .34011 .43091 .35047 .42846 .34401 .42129 Mtetra
.531 .683 .936 r
.34401 .42129 .35047 .42846 .36444 .35517 .35435 .42044 Mtetra
.441 .185 .428 r
.35435 .42044 .36444 .35517 .37158 .41793 .36523 .40968 Mtetra
.563 .664 .905 r
.36523 .40968 .37158 .41793 .38207 .41529 .37567 .40841 Mtetra
.637 .735 .92 r
.37567 .40841 .38207 .41529 .39262 .41203 .38625 .40531 Mtetra
.648 .745 .92 r
.38625 .40531 .39262 .41203 .40323 .40859 .39688 .40191 Mtetra
.653 .749 .92 r
.39688 .40191 .40323 .40859 .41388 .40504 .40755 .39838 Mtetra
.656 .751 .92 r
.40755 .39838 .41388 .40504 .42458 .40142 .41828 .39476 Mtetra
.657 .752 .92 r
.41828 .39476 .42458 .40142 .43532 .39775 .42905 .39108 Mtetra
.658 .753 .92 r
.42905 .39108 .43532 .39775 .44611 .39405 .43986 .38736 Mtetra
.659 .754 .92 r
.43986 .38736 .44611 .39405 .45693 .39033 .45071 .38361 Mtetra
.45071 .38361 .45693 .39033 .4678 .38659 .46161 .37984 Mtetra
.46161 .37984 .4678 .38659 .47872 .38284 .47255 .37606 Mtetra
.47255 .37606 .47872 .38284 .48967 .37908 .48354 .37227 Mtetra
.658 .753 .92 r
.48354 .37227 .48967 .37908 .50067 .37532 .49456 .36848 Mtetra
.49456 .36848 .50067 .37532 .51172 .37155 .50564 .36467 Mtetra
.50564 .36467 .51172 .37155 .5228 .36776 .51675 .36086 Mtetra
.51675 .36086 .5228 .36776 .53394 .36396 .52791 .35703 Mtetra
.52791 .35703 .53394 .36396 .54511 .36016 .53912 .3532 Mtetra
.53912 .3532 .54511 .36016 .55633 .35633 .55037 .34934 Mtetra
.657 .753 .92 r
.55037 .34934 .55633 .35633 .5676 .3525 .56167 .34548 Mtetra
.56167 .34548 .5676 .3525 .57891 .34865 .57302 .3416 Mtetra
.57302 .3416 .57891 .34865 .59027 .34479 .58441 .33771 Mtetra
.657 .752 .92 r
.58441 .33771 .59027 .34479 .60168 .34091 .59584 .3338 Mtetra
.59584 .3338 .60168 .34091 .61313 .33702 .60733 .32988 Mtetra
.60733 .32988 .61313 .33702 .62463 .33311 .61886 .32594 Mtetra
.61886 .32594 .62463 .33311 .63618 .32919 .63044 .32199 Mtetra
.63044 .32199 .63618 .32919 .64777 .32525 .64206 .31802 Mtetra
.64206 .31802 .64777 .32525 .65941 .3213 .65374 .31404 Mtetra
.65374 .31404 .65941 .3213 .6711 .31733 .66546 .31004 Mtetra
.66546 .31004 .6711 .31733 .68284 .31334 .67723 .30602 Mtetra
.67723 .30602 .68284 .31334 .69463 .30934 .68905 .30199 Mtetra
.68905 .30199 .69463 .30934 .70646 .30533 .70092 .29794 Mtetra
.70092 .29794 .70646 .30533 .71835 .3013 .71284 .29388 Mtetra
.71284 .29388 .71835 .3013 .73028 .29725 .72481 .2898 Mtetra
.72481 .2898 .73028 .29725 .74227 .29318 .73683 .28571 Mtetra
.73683 .28571 .74227 .29318 .7543 .2891 .7489 .28159 Mtetra
.7489 .28159 .7543 .2891 .76639 .28501 .76102 .27746 Mtetra
.76102 .27746 .76639 .28501 .77852 .28089 .77319 .27332 Mtetra
.77319 .27332 .77852 .28089 .79071 .27676 .78542 .26915 Mtetra
.78542 .26915 .79071 .27676 .80295 .27261 .79769 .26497 Mtetra
.8 .686 .74 r
.14543 .48075 .15192 .49112 .16259 .47942 .1563 .46747 Mtetra
.331 .442 .824 r
.1563 .46747 .16259 .47942 .17215 .47804 .1653 .47123 Mtetra
.6 .713 .923 r
.1653 .47123 .17215 .47804 .18182 .47599 .17499 .46916 Mtetra
.565 .7 .932 r
.17499 .46916 .18182 .47599 .19092 .48013 .18465 .46775 Mtetra
.768 .655 .737 r
.18465 .46775 .19092 .48013 .20185 .46633 .1954 .45606 Mtetra
.426 .536 .866 r
.1954 .45606 .20185 .46633 .21161 .46463 .20482 .45781 Mtetra
.61 .718 .922 r
.20482 .45781 .21161 .46463 .22147 .46224 .2147 .45549 Mtetra
.602 .719 .927 r
.2147 .45549 .22147 .46224 .23126 .46122 .22461 .45331 Mtetra
.895 .479 .091 r
.22461 .45331 .23126 .46122 .24191 .45079 .23246 .4748 Mtetra
0 0 0 r
.23246 .4748 .24191 .45079 .25171 .45056 .24503 .44343 Mtetra
.601 .708 .919 r
.24503 .44343 .25171 .45056 .26175 .44798 .25505 .44127 Mtetra
.626 .731 .922 r
.25505 .44127 .26175 .44798 .27184 .44531 .26517 .43854 Mtetra
.613 .725 .925 r
.26517 .43854 .27184 .44531 .28189 .4438 .27531 .43608 Mtetra
0 .19 .705 r
.27531 .43608 .28189 .4438 .29268 .43265 .28475 .44363 Mtetra
.7 .872 .473 r
.28475 .44363 .29268 .43265 .30267 .43311 .2961 .4258 Mtetra
.602 .706 .917 r
.2961 .4258 .30267 .43311 .31292 .43036 .30634 .4236 Mtetra
.635 .735 .921 r
.30634 .4236 .31292 .43036 .32325 .42729 .31668 .4206 Mtetra
.64 .74 .921 r
.31668 .4206 .32325 .42729 .33362 .42418 .32707 .41745 Mtetra
.637 .739 .922 r
.32707 .41745 .33362 .42418 .34401 .42129 .3375 .41437 Mtetra
.612 .725 .926 r
.3375 .41437 .34401 .42129 .35435 .42044 .34794 .41186 Mtetra
.94 .714 .569 r
.34794 .41186 .35435 .42044 .36523 .40968 .3621 .33823 Mtetra
0 0 .374 r
.3621 .33823 .36523 .40968 .37567 .40841 .36925 .40119 Mtetra
.62 .72 .918 r
.36925 .40119 .37567 .40841 .38625 .40531 .37982 .39848 Mtetra
.644 .742 .92 r
.37982 .39848 .38625 .40531 .39688 .40191 .39047 .39516 Mtetra
.651 .747 .92 r
.39047 .39516 .39688 .40191 .40755 .39838 .40118 .39165 Mtetra
.654 .75 .92 r
.40118 .39165 .40755 .39838 .41828 .39476 .41193 .38803 Mtetra
.657 .752 .92 r
.41193 .38803 .41828 .39476 .42905 .39108 .42272 .38435 Mtetra
.658 .753 .92 r
.42272 .38435 .42905 .39108 .43986 .38736 .43356 .38061 Mtetra
.659 .754 .92 r
.43356 .38061 .43986 .38736 .45071 .38361 .44444 .37684 Mtetra
.44444 .37684 .45071 .38361 .46161 .37984 .45537 .37304 Mtetra
.45537 .37304 .46161 .37984 .47255 .37606 .46634 .36923 Mtetra
.46634 .36923 .47255 .37606 .48354 .37227 .47735 .36541 Mtetra
.658 .753 .92 r
.47735 .36541 .48354 .37227 .49456 .36848 .48841 .36159 Mtetra
.48841 .36159 .49456 .36848 .50564 .36467 .49951 .35775 Mtetra
.49951 .35775 .50564 .36467 .51675 .36086 .51066 .35391 Mtetra
.51066 .35391 .51675 .36086 .52791 .35703 .52185 .35005 Mtetra
.52185 .35005 .52791 .35703 .53912 .3532 .53308 .34618 Mtetra
.53308 .34618 .53912 .3532 .55037 .34934 .54437 .3423 Mtetra
.54437 .3423 .55037 .34934 .56167 .34548 .5557 .33841 Mtetra
.657 .753 .92 r
.5557 .33841 .56167 .34548 .57302 .3416 .56707 .3345 Mtetra
.56707 .3345 .57302 .3416 .58441 .33771 .57849 .33057 Mtetra
.57849 .33057 .58441 .33771 .59584 .3338 .58996 .32664 Mtetra
.657 .752 .92 r
.58996 .32664 .59584 .3338 .60733 .32988 .60148 .32268 Mtetra
.60148 .32268 .60733 .32988 .61886 .32594 .61304 .31872 Mtetra
.61304 .31872 .61886 .32594 .63044 .32199 .62465 .31473 Mtetra
.62465 .31473 .63044 .32199 .64206 .31802 .63631 .31073 Mtetra
.63631 .31073 .64206 .31802 .65374 .31404 .64802 .30672 Mtetra
.64802 .30672 .65374 .31404 .66546 .31004 .65977 .30269 Mtetra
.65977 .30269 .66546 .31004 .67723 .30602 .67158 .29864 Mtetra
.67158 .29864 .67723 .30602 .68905 .30199 .68343 .29458 Mtetra
.68343 .29458 .68905 .30199 .70092 .29794 .69534 .2905 Mtetra
.69534 .2905 .70092 .29794 .71284 .29388 .70729 .28641 Mtetra
.70729 .28641 .71284 .29388 .72481 .2898 .7193 .2823 Mtetra
.7193 .2823 .72481 .2898 .73683 .28571 .73135 .27817 Mtetra
.73135 .27817 .73683 .28571 .7489 .28159 .74346 .27402 Mtetra
.74346 .27402 .7489 .28159 .76102 .27746 .75561 .26986 Mtetra
.75561 .26986 .76102 .27746 .77319 .27332 .76782 .26568 Mtetra
.76782 .26568 .77319 .27332 .78542 .26915 .78008 .26148 Mtetra
.78008 .26148 .78542 .26915 .79769 .26497 .7924 .25727 Mtetra
.299 .564 .929 r
.13854 .47348 .14543 .48075 .1563 .46747 .14769 .47561 Mtetra
.634 .9 .585 r
.14769 .47561 .1563 .46747 .1653 .47123 .15846 .46381 Mtetra
.57 .684 .917 r
.15846 .46381 .1653 .47123 .17499 .46916 .16809 .46238 Mtetra
.6 .716 .926 r
.16809 .46238 .17499 .46916 .18465 .46775 .17785 .46028 Mtetra
.096 .438 .877 r
.17785 .46028 .18465 .46775 .1954 .45606 .18701 .46438 Mtetra
.728 .934 .605 r
.18701 .46438 .1954 .45606 .20482 .45781 .19804 .45048 Mtetra
.584 .694 .918 r
.19804 .45048 .20482 .45781 .2147 .45549 .20788 .44872 Mtetra
.614 .723 .924 r
.20788 .44872 .2147 .45549 .22461 .45331 .21783 .44628 Mtetra
.544 .69 .935 r
.21783 .44628 .22461 .45331 .23246 .4748 .22769 .4452 Mtetra
.662 .497 .651 r
.22769 .4452 .23246 .4748 .24503 .44343 .23844 .43468 Mtetra
.518 .627 .898 r
.23844 .43468 .24503 .44343 .25505 .44127 .24832 .4344 Mtetra
.621 .725 .921 r
.24832 .4344 .25505 .44127 .26517 .43854 .25844 .43177 Mtetra
.624 .731 .923 r
.25844 .43177 .26517 .43854 .27531 .43608 .26862 .42904 Mtetra
.568 .703 .932 r
.26862 .42904 .27531 .43608 .28475 .44363 .27876 .42747 Mtetra
.736 .608 .716 r
.27876 .42747 .28475 .44363 .2961 .4258 .28964 .41623 Mtetra
.489 .593 .884 r
.28964 .41623 .2961 .4258 .30634 .4236 .29971 .41664 Mtetra
.626 .728 .92 r
.29971 .41664 .30634 .4236 .31668 .4206 .31006 .41383 Mtetra
.639 .739 .921 r
.31006 .41383 .31668 .4206 .32707 .41745 .32047 .41069 Mtetra
.64 .74 .922 r
.32047 .41069 .32707 .41745 .3375 .41437 .33093 .40752 Mtetra
.63 .735 .923 r
.33093 .40752 .3375 .41437 .34794 .41186 .34142 .40456 Mtetra
.531 .683 .936 r
.34142 .40456 .34794 .41186 .3621 .33823 .35185 .40366 Mtetra
.436 .178 .423 r
.35185 .40366 .3621 .33823 .36925 .40119 .36283 .3928 Mtetra
.563 .664 .905 r
.36283 .3928 .36925 .40119 .37982 .39848 .37336 .39148 Mtetra
.637 .735 .92 r
.37336 .39148 .37982 .39848 .39047 .39516 .38403 .38831 Mtetra
.648 .745 .92 r
.38403 .38831 .39047 .39516 .40118 .39165 .39475 .38484 Mtetra
.653 .749 .92 r
.39475 .38484 .40118 .39165 .41193 .38803 .40553 .38124 Mtetra
.656 .751 .92 r
.40553 .38124 .41193 .38803 .42272 .38435 .41635 .37755 Mtetra
.657 .752 .92 r
.41635 .37755 .42272 .38435 .43356 .38061 .42722 .37381 Mtetra
.658 .753 .92 r
.42722 .37381 .43356 .38061 .44444 .37684 .43813 .37001 Mtetra
.659 .754 .92 r
.43813 .37001 .44444 .37684 .45537 .37304 .44908 .36619 Mtetra
.44908 .36619 .45537 .37304 .46634 .36923 .46008 .36235 Mtetra
.46008 .36235 .46634 .36923 .47735 .36541 .47112 .35851 Mtetra
.47112 .35851 .47735 .36541 .48841 .36159 .48221 .35465 Mtetra
.658 .753 .92 r
.48221 .35465 .48841 .36159 .49951 .35775 .49334 .35078 Mtetra
.49334 .35078 .49951 .35775 .51066 .35391 .50451 .3469 Mtetra
.50451 .3469 .51066 .35391 .52185 .35005 .51574 .34302 Mtetra
.51574 .34302 .52185 .35005 .53308 .34618 .527 .33912 Mtetra
.527 .33912 .53308 .34618 .54437 .3423 .53832 .33521 Mtetra
.53832 .33521 .54437 .3423 .5557 .33841 .54968 .33128 Mtetra
.657 .753 .92 r
.54968 .33128 .5557 .33841 .56707 .3345 .56108 .32734 Mtetra
.56108 .32734 .56707 .3345 .57849 .33057 .57253 .32339 Mtetra
.57253 .32339 .57849 .33057 .58996 .32664 .58403 .31942 Mtetra
.657 .752 .92 r
.58403 .31942 .58996 .32664 .60148 .32268 .59558 .31543 Mtetra
.59558 .31543 .60148 .32268 .61304 .31872 .60718 .31144 Mtetra
.60718 .31144 .61304 .31872 .62465 .31473 .61882 .30742 Mtetra
.61882 .30742 .62465 .31473 .63631 .31073 .63051 .30339 Mtetra
.63051 .30339 .63631 .31073 .64802 .30672 .64225 .29935 Mtetra
.64225 .29935 .64802 .30672 .65977 .30269 .65404 .29529 Mtetra
.65404 .29529 .65977 .30269 .67158 .29864 .66588 .29121 Mtetra
.66588 .29121 .67158 .29864 .68343 .29458 .67777 .28711 Mtetra
.67777 .28711 .68343 .29458 .69534 .2905 .68971 .283 Mtetra
.68971 .283 .69534 .2905 .70729 .28641 .7017 .27888 Mtetra
.7017 .27888 .70729 .28641 .7193 .2823 .71374 .27473 Mtetra
.71374 .27473 .7193 .2823 .73135 .27817 .72583 .27057 Mtetra
.72583 .27057 .73135 .27817 .74346 .27402 .73797 .26639 Mtetra
.73797 .26639 .74346 .27402 .75561 .26986 .75017 .2622 Mtetra
.75017 .2622 .75561 .26986 .76782 .26568 .76241 .25799 Mtetra
.76241 .25799 .76782 .26568 .78008 .26148 .77471 .25376 Mtetra
.77471 .25376 .78008 .26148 .7924 .25727 .78706 .24951 Mtetra
.568 .701 .931 r
.13155 .46659 .13854 .47348 .14769 .47561 .14113 .46511 Mtetra
.8 .687 .74 r
.14113 .46511 .14769 .47561 .15846 .46381 .15211 .45172 Mtetra
.329 .441 .824 r
.15211 .45172 .15846 .46381 .16809 .46238 .16117 .45545 Mtetra
.6 .713 .923 r
.16117 .45545 .16809 .46238 .17785 .46028 .17094 .45333 Mtetra
.565 .7 .932 r
.17094 .45333 .17785 .46028 .18701 .46438 .18068 .45186 Mtetra
.769 .655 .737 r
.18068 .45186 .18701 .46438 .19804 .45048 .19153 .44008 Mtetra
.425 .536 .866 r
.19153 .44008 .19804 .45048 .20788 .44872 .20102 .44179 Mtetra
.61 .718 .922 r
.20102 .44179 .20788 .44872 .21783 .44628 .21098 .43942 Mtetra
.602 .719 .927 r
.21098 .43942 .21783 .44628 .22769 .4452 .22097 .43718 Mtetra
.893 .476 .084 r
.22097 .43718 .22769 .4452 .23844 .43468 .22886 .45871 Mtetra
0 0 0 r
.22886 .45871 .23844 .43468 .24832 .4344 .24157 .42715 Mtetra
.601 .708 .919 r
.24157 .42715 .24832 .4344 .25844 .43177 .25167 .42494 Mtetra
.626 .731 .922 r
.25167 .42494 .25844 .43177 .26862 .42904 .26188 .42214 Mtetra
.613 .725 .925 r
.26188 .42214 .26862 .42904 .27876 .42747 .2721 .41963 Mtetra
0 .195 .709 r
.2721 .41963 .27876 .42747 .28964 .41623 .28162 .42716 Mtetra
.708 .878 .482 r
.28162 .42716 .28964 .41623 .29971 .41664 .29307 .4092 Mtetra
.602 .706 .917 r
.29307 .4092 .29971 .41664 .31006 .41383 .3034 .40694 Mtetra
.635 .735 .921 r
.3034 .40694 .31006 .41383 .32047 .41069 .31383 .40388 Mtetra
.64 .74 .921 r
.31383 .40388 .32047 .41069 .33093 .40752 .32431 .40067 Mtetra
.637 .739 .922 r
.32431 .40067 .33093 .40752 .34142 .40456 .33484 .39752 Mtetra
.612 .725 .926 r
.33484 .39752 .34142 .40456 .35185 .40366 .34537 .39495 Mtetra
.941 .715 .567 r
.34537 .39495 .35185 .40366 .36283 .3928 .35971 .32098 Mtetra
0 0 .37 r
.35971 .32098 .36283 .3928 .37336 .39148 .36687 .38413 Mtetra
.62 .72 .918 r
.36687 .38413 .37336 .39148 .38403 .38831 .37754 .38136 Mtetra
.644 .742 .92 r
.37754 .38136 .38403 .38831 .39475 .38484 .38829 .37796 Mtetra
.651 .747 .92 r
.38829 .37796 .39475 .38484 .40553 .38124 .39908 .37438 Mtetra
.654 .75 .92 r
.39908 .37438 .40553 .38124 .41635 .37755 .40993 .3707 Mtetra
.657 .752 .92 r
.40993 .3707 .41635 .37755 .42722 .37381 .42082 .36694 Mtetra
.658 .753 .92 r
.42082 .36694 .42722 .37381 .43813 .37001 .43176 .36314 Mtetra
.659 .754 .92 r
.43176 .36314 .43813 .37001 .44908 .36619 .44275 .35929 Mtetra
.44275 .35929 .44908 .36619 .46008 .36235 .45377 .35543 Mtetra
.45377 .35543 .46008 .36235 .47112 .35851 .46484 .35155 Mtetra
.46484 .35155 .47112 .35851 .48221 .35465 .47596 .34766 Mtetra
.658 .753 .92 r
.47596 .34766 .48221 .35465 .49334 .35078 .48712 .34376 Mtetra
.48712 .34376 .49334 .35078 .50451 .3469 .49833 .33985 Mtetra
.49833 .33985 .50451 .3469 .51574 .34302 .50958 .33593 Mtetra
.50958 .33593 .51574 .34302 .527 .33912 .52087 .332 Mtetra
.52087 .332 .527 .33912 .53832 .33521 .53222 .32806 Mtetra
.53222 .32806 .53832 .33521 .54968 .33128 .54361 .3241 Mtetra
.54361 .3241 .54968 .33128 .56108 .32734 .55505 .32013 Mtetra
.657 .753 .92 r
.55505 .32013 .56108 .32734 .57253 .32339 .56653 .31614 Mtetra
.56653 .31614 .57253 .32339 .58403 .31942 .57806 .31215 Mtetra
.57806 .31215 .58403 .31942 .59558 .31543 .58964 .30813 Mtetra
.657 .752 .92 r
.58964 .30813 .59558 .31543 .60718 .31144 .60127 .3041 Mtetra
.60127 .3041 .60718 .31144 .61882 .30742 .61295 .30006 Mtetra
.61295 .30006 .61882 .30742 .63051 .30339 .62467 .29599 Mtetra
.62467 .29599 .63051 .30339 .64225 .29935 .63644 .29192 Mtetra
.63644 .29192 .64225 .29935 .65404 .29529 .64827 .28782 Mtetra
.64827 .28782 .65404 .29529 .66588 .29121 .66014 .28371 Mtetra
.66014 .28371 .66588 .29121 .67777 .28711 .67206 .27959 Mtetra
.67206 .27959 .67777 .28711 .68971 .283 .68404 .27544 Mtetra
.68404 .27544 .68971 .283 .7017 .27888 .69606 .27129 Mtetra
.69606 .27129 .7017 .27888 .71374 .27473 .70814 .26711 Mtetra
.70814 .26711 .71374 .27473 .72583 .27057 .72026 .26291 Mtetra
.72026 .26291 .72583 .27057 .73797 .26639 .73244 .2587 Mtetra
.73244 .2587 .73797 .26639 .75017 .2622 .74467 .25448 Mtetra
.74467 .25448 .75017 .2622 .76241 .25799 .75696 .25023 Mtetra
.75696 .25023 .76241 .25799 .77471 .25376 .76929 .24597 Mtetra
.76929 .24597 .77471 .25376 .78706 .24951 .78168 .24168 Mtetra
.591 .71 .926 r
.12452 .45967 .13155 .46659 .14113 .46511 .13417 .45772 Mtetra
.3 .564 .929 r
.13417 .45772 .14113 .46511 .15211 .45172 .14338 .45981 Mtetra
.645 .907 .595 r
.14338 .45981 .15211 .45172 .16117 .45545 .15426 .44792 Mtetra
.57 .684 .918 r
.15426 .44792 .16117 .45545 .17094 .45333 .16397 .44644 Mtetra
.6 .716 .926 r
.16397 .44644 .17094 .45333 .18068 .45186 .1738 .44427 Mtetra
.1 .44 .878 r
.1738 .44427 .18068 .45186 .19153 .44008 .18302 .44835 Mtetra
.736 .939 .613 r
.18302 .44835 .19153 .44008 .20102 .44179 .19417 .43434 Mtetra
.584 .694 .918 r
.19417 .43434 .20102 .44179 .21098 .43942 .20408 .43253 Mtetra
.614 .723 .924 r
.20408 .43253 .21098 .43942 .22097 .43718 .21411 .43003 Mtetra
.544 .69 .935 r
.21411 .43003 .22097 .43718 .22886 .45871 .22406 .42889 Mtetra
.662 .497 .65 r
.22406 .42889 .22886 .45871 .24157 .42715 .23491 .41828 Mtetra
.517 .627 .899 r
.23491 .41828 .24157 .42715 .25167 .42494 .24487 .41795 Mtetra
.621 .725 .921 r
.24487 .41795 .25167 .42494 .26188 .42214 .25508 .41526 Mtetra
.624 .731 .923 r
.25508 .41526 .26188 .42214 .2721 .41963 .26534 .41246 Mtetra
.569 .703 .932 r
.26534 .41246 .2721 .41963 .28162 .42716 .27556 .41084 Mtetra
.736 .609 .716 r
.27556 .41084 .28162 .42716 .29307 .4092 .28655 .3995 Mtetra
.489 .593 .884 r
.28655 .3995 .29307 .4092 .3034 .40694 .2967 .39986 Mtetra
.626 .728 .92 r
.2967 .39986 .3034 .40694 .31383 .40388 .30714 .39698 Mtetra
.639 .739 .921 r
.30714 .39698 .31383 .40388 .32431 .40067 .31765 .39378 Mtetra
.64 .74 .922 r
.31765 .39378 .32431 .40067 .33484 .39752 .3282 .39055 Mtetra
.63 .735 .923 r
.3282 .39055 .33484 .39752 .34537 .39495 .33878 .38752 Mtetra
.532 .683 .935 r
.33878 .38752 .34537 .39495 .35971 .32098 .34929 .38656 Mtetra
.431 .171 .417 r
.34929 .38656 .35971 .32098 .36687 .38413 .36038 .37561 Mtetra
.562 .664 .905 r
.36038 .37561 .36687 .38413 .37754 .38136 .37101 .37422 Mtetra
.637 .735 .92 r
.37101 .37422 .37754 .38136 .38829 .37796 .38177 .37099 Mtetra
.648 .745 .92 r
.38177 .37099 .38829 .37796 .39908 .37438 .39259 .36745 Mtetra
.653 .749 .92 r
.39259 .36745 .39908 .37438 .40993 .3707 .40347 .36378 Mtetra
.656 .751 .92 r
.40347 .36378 .40993 .3707 .42082 .36694 .41439 .36002 Mtetra
.657 .752 .92 r
.41439 .36002 .42082 .36694 .43176 .36314 .42535 .3562 Mtetra
.658 .753 .92 r
.42535 .3562 .43176 .36314 .44275 .35929 .43636 .35234 Mtetra
.659 .754 .92 r
.43636 .35234 .44275 .35929 .45377 .35543 .44742 .34845 Mtetra
.44742 .34845 .45377 .35543 .46484 .35155 .45852 .34454 Mtetra
.45852 .34454 .46484 .35155 .47596 .34766 .46966 .34061 Mtetra
.46966 .34061 .47596 .34766 .48712 .34376 .48085 .33668 Mtetra
.658 .753 .92 r
.48085 .33668 .48712 .34376 .49833 .33985 .49209 .33274 Mtetra
.49209 .33274 .49833 .33985 .50958 .33593 .50337 .32879 Mtetra
.50337 .32879 .50958 .33593 .52087 .332 .5147 .32483 Mtetra
.5147 .32483 .52087 .332 .53222 .32806 .52607 .32085 Mtetra
.52607 .32085 .53222 .32806 .54361 .3241 .5375 .31687 Mtetra
.5375 .31687 .54361 .3241 .55505 .32013 .54896 .31286 Mtetra
.657 .753 .92 r
.54896 .31286 .55505 .32013 .56653 .31614 .56048 .30885 Mtetra
.56048 .30885 .56653 .31614 .57806 .31215 .57204 .30482 Mtetra
.57204 .30482 .57806 .31215 .58964 .30813 .58366 .30077 Mtetra
.657 .752 .92 r
.58366 .30077 .58964 .30813 .60127 .3041 .59532 .29671 Mtetra
.59532 .29671 .60127 .3041 .61295 .30006 .60703 .29263 Mtetra
.60703 .29263 .61295 .30006 .62467 .29599 .61878 .28854 Mtetra
.61878 .28854 .62467 .29599 .63644 .29192 .63059 .28443 Mtetra
.63059 .28443 .63644 .29192 .64827 .28782 .64245 .2803 Mtetra
.64245 .2803 .64827 .28782 .66014 .28371 .65436 .27616 Mtetra
.65436 .27616 .66014 .28371 .67206 .27959 .66631 .272 Mtetra
.66631 .272 .67206 .27959 .68404 .27544 .67832 .26783 Mtetra
.67832 .26783 .68404 .27544 .69606 .27129 .69038 .26363 Mtetra
.69038 .26363 .69606 .27129 .70814 .26711 .70249 .25942 Mtetra
.70249 .25942 .70814 .26711 .72026 .26291 .71466 .2552 Mtetra
.71466 .2552 .72026 .26291 .73244 .2587 .72687 .25095 Mtetra
.72687 .25095 .73244 .2587 .74467 .25448 .73914 .24669 Mtetra
.73914 .24669 .74467 .25448 .75696 .25023 .75146 .24241 Mtetra
.75146 .24241 .75696 .25023 .76929 .24597 .76383 .23811 Mtetra
.76383 .23811 .76929 .24597 .78168 .24168 .77626 .2338 Mtetra
.576 .693 .921 r
.11749 .45235 .12452 .45967 .13417 .45772 .1271 .45071 Mtetra
.568 .701 .931 r
.1271 .45071 .13417 .45772 .14338 .45981 .13676 .44918 Mtetra
.801 .688 .74 r
.13676 .44918 .14338 .45981 .15426 .44792 .14784 .43569 Mtetra
.328 .441 .824 r
.14784 .43569 .15426 .44792 .16397 .44644 .15696 .43939 Mtetra
.6 .713 .923 r
.15696 .43939 .16397 .44644 .1738 .44427 .16681 .43721 Mtetra
.565 .7 .932 r
.16681 .43721 .1738 .44427 .18302 .44835 .17663 .43569 Mtetra
.769 .656 .737 r
.17663 .43569 .18302 .44835 .19417 .43434 .18758 .42381 Mtetra
.424 .536 .866 r
.18758 .42381 .19417 .43434 .20408 .43253 .19715 .42547 Mtetra
.61 .718 .922 r
.19715 .42547 .20408 .43253 .21411 .43003 .20719 .42304 Mtetra
.602 .719 .927 r
.20719 .42304 .21411 .43003 .22406 .42889 .21726 .42075 Mtetra
.89 .472 .076 r
.21726 .42075 .22406 .42889 .23491 .41828 .22519 .44231 Mtetra
0 0 0 r
.22519 .44231 .23491 .41828 .24487 .41795 .23804 .41058 Mtetra
.601 .708 .919 r
.23804 .41058 .24487 .41795 .25508 .41526 .24823 .40831 Mtetra
.626 .731 .922 r
.24823 .40831 .25508 .41526 .26534 .41246 .25852 .40544 Mtetra
.613 .725 .925 r
.25852 .40544 .26534 .41246 .27556 .41084 .26883 .40287 Mtetra
0 .199 .714 r
.26883 .40287 .27556 .41084 .28655 .3995 .27842 .41038 Mtetra
.716 .884 .49 r
.27842 .41038 .28655 .3995 .2967 .39986 .28999 .3923 Mtetra
.602 .706 .917 r
.28999 .3923 .2967 .39986 .30714 .39698 .30041 .38997 Mtetra
.635 .735 .921 r
.30041 .38997 .30714 .39698 .31765 .39378 .31093 .38684 Mtetra
.64 .74 .921 r
.31093 .38684 .31765 .39378 .3282 .39055 .32151 .38357 Mtetra
.637 .739 .922 r
.32151 .38357 .3282 .39055 .33878 .38752 .33212 .38035 Mtetra
.612 .725 .926 r
.33212 .38035 .33878 .38752 .34929 .38656 .34275 .37772 Mtetra
.942 .715 .565 r
.34275 .37772 .34929 .38656 .36038 .37561 .35727 .30341 Mtetra
0 0 .365 r
.35727 .30341 .36038 .37561 .37101 .37422 .36444 .36674 Mtetra
.62 .72 .918 r
.36444 .36674 .37101 .37422 .38177 .37099 .37521 .3639 Mtetra
.644 .742 .92 r
.37521 .3639 .38177 .37099 .39259 .36745 .38605 .36044 Mtetra
.651 .747 .92 r
.38605 .36044 .39259 .36745 .40347 .36378 .39695 .35679 Mtetra
.654 .75 .92 r
.39695 .35679 .40347 .36378 .41439 .36002 .4079 .35304 Mtetra
.657 .752 .92 r
.4079 .35304 .41439 .36002 .42535 .3562 .41889 .34921 Mtetra
.658 .753 .92 r
.41889 .34921 .42535 .3562 .43636 .35234 .42993 .34533 Mtetra
.659 .754 .92 r
.42993 .34533 .43636 .35234 .44742 .34845 .44102 .34141 Mtetra
.44102 .34141 .44742 .34845 .45852 .34454 .45214 .33747 Mtetra
.45214 .33747 .45852 .34454 .46966 .34061 .46332 .33352 Mtetra
.46332 .33352 .46966 .34061 .48085 .33668 .47454 .32955 Mtetra
.658 .753 .92 r
.47454 .32955 .48085 .33668 .49209 .33274 .48581 .32558 Mtetra
.48581 .32558 .49209 .33274 .50337 .32879 .49712 .3216 Mtetra
.49712 .3216 .50337 .32879 .5147 .32483 .50848 .3176 Mtetra
.50848 .3176 .5147 .32483 .52607 .32085 .51988 .3136 Mtetra
.51988 .3136 .52607 .32085 .5375 .31687 .53133 .30958 Mtetra
.53133 .30958 .5375 .31687 .54896 .31286 .54283 .30554 Mtetra
.54283 .30554 .54896 .31286 .56048 .30885 .55438 .30149 Mtetra
.657 .753 .92 r
.55438 .30149 .56048 .30885 .57204 .30482 .56598 .29743 Mtetra
.56598 .29743 .57204 .30482 .58366 .30077 .57762 .29335 Mtetra
.57762 .29335 .58366 .30077 .59532 .29671 .58932 .28926 Mtetra
.657 .752 .92 r
.58932 .28926 .59532 .29671 .60703 .29263 .60106 .28515 Mtetra
.60106 .28515 .60703 .29263 .61878 .28854 .61285 .28103 Mtetra
.61285 .28103 .61878 .28854 .63059 .28443 .62469 .27688 Mtetra
.62469 .27688 .63059 .28443 .64245 .2803 .63658 .27273 Mtetra
.63658 .27273 .64245 .2803 .65436 .27616 .64853 .26855 Mtetra
.64853 .26855 .65436 .27616 .66631 .272 .66052 .26436 Mtetra
.66052 .26436 .66631 .272 .67832 .26783 .67256 .26015 Mtetra
.67256 .26015 .67832 .26783 .69038 .26363 .68466 .25592 Mtetra
.68466 .25592 .69038 .26363 .70249 .25942 .6968 .25168 Mtetra
.6968 .25168 .70249 .25942 .71466 .2552 .709 .24742 Mtetra
.709 .24742 .71466 .2552 .72687 .25095 .72125 .24314 Mtetra
.72125 .24314 .72687 .25095 .73914 .24669 .73356 .23885 Mtetra
.73356 .23885 .73914 .24669 .75146 .24241 .74591 .23453 Mtetra
.74591 .23453 .75146 .24241 .76383 .23811 .75832 .2302 Mtetra
.75832 .2302 .76383 .23811 .77626 .2338 .77079 .22585 Mtetra
.452 .574 .886 r
.11068 .44278 .11749 .45235 .1271 .45071 .11999 .44367 Mtetra
.591 .71 .926 r
.11999 .44367 .1271 .45071 .13676 .44918 .12971 .44167 Mtetra
.302 .565 .929 r
.12971 .44167 .13676 .44918 .14784 .43569 .139 .44373 Mtetra
.655 .914 .606 r
.139 .44373 .14784 .43569 .15696 .43939 .14997 .43173 Mtetra
.57 .684 .918 r
.14997 .43173 .15696 .43939 .16681 .43721 .15976 .4302 Mtetra
.6 .716 .926 r
.15976 .4302 .16681 .43721 .17663 .43569 .16967 .42798 Mtetra
.103 .442 .879 r
.16967 .42798 .17663 .43569 .18758 .42381 .17897 .43202 Mtetra
.743 .944 .62 r
.17897 .43202 .18758 .42381 .19715 .42547 .19022 .4179 Mtetra
.584 .694 .918 r
.19022 .4179 .19715 .42547 .20719 .42304 .20021 .41603 Mtetra
.614 .723 .924 r
.20021 .41603 .20719 .42304 .21726 .42075 .21033 .41347 Mtetra
.544 .69 .935 r
.21033 .41347 .21726 .42075 .22519 .44231 .22036 .41228 Mtetra
.661 .496 .649 r
.22036 .41228 .22519 .44231 .23804 .41058 .23131 .40158 Mtetra
.517 .627 .899 r
.23131 .40158 .23804 .41058 .24823 .40831 .24135 .40119 Mtetra
.621 .725 .921 r
.24135 .40119 .24823 .40831 .25852 .40544 .25165 .39844 Mtetra
.624 .731 .923 r
.25165 .39844 .25852 .40544 .26883 .40287 .262 .39557 Mtetra
.569 .702 .932 r
.262 .39557 .26883 .40287 .27842 .41038 .27231 .39389 Mtetra
.736 .609 .716 r
.27231 .39389 .27842 .41038 .28999 .3923 .2834 .38246 Mtetra
.489 .593 .884 r
.2834 .38246 .28999 .3923 .30041 .38997 .29364 .38276 Mtetra
.626 .728 .92 r
.29364 .38276 .30041 .38997 .31093 .38684 .30417 .37982 Mtetra
.639 .739 .921 r
.30417 .37982 .31093 .38684 .32151 .38357 .31477 .37656 Mtetra
.64 .74 .922 r
.31477 .37656 .32151 .38357 .33212 .38035 .32541 .37325 Mtetra
.63 .735 .923 r
.32541 .37325 .33212 .38035 .34275 .37772 .33609 .37016 Mtetra
.532 .683 .935 r
.33609 .37016 .34275 .37772 .35727 .30341 .34669 .36914 Mtetra
.426 .164 .412 r
.34669 .36914 .35727 .30341 .36444 .36674 .35789 .35809 Mtetra
.562 .664 .905 r
.35789 .35809 .36444 .36674 .37521 .3639 .36861 .35664 Mtetra
.637 .735 .92 r
.36861 .35664 .37521 .3639 .38605 .36044 .37947 .35334 Mtetra
.648 .745 .92 r
.37947 .35334 .38605 .36044 .39695 .35679 .39039 .34973 Mtetra
.653 .749 .92 r
.39039 .34973 .39695 .35679 .4079 .35304 .40136 .34598 Mtetra
.656 .751 .92 r
.40136 .34598 .4079 .35304 .41889 .34921 .41238 .34215 Mtetra
.657 .752 .92 r
.41238 .34215 .41889 .34921 .42993 .34533 .42345 .33826 Mtetra
.658 .753 .92 r
.42345 .33826 .42993 .34533 .44102 .34141 .43456 .33432 Mtetra
.659 .754 .92 r
.43456 .33432 .44102 .34141 .45214 .33747 .44572 .33036 Mtetra
.44572 .33036 .45214 .33747 .46332 .33352 .45693 .32637 Mtetra
.45693 .32637 .46332 .33352 .47454 .32955 .46818 .32237 Mtetra
.46818 .32237 .47454 .32955 .48581 .32558 .47947 .31837 Mtetra
.658 .753 .92 r
.47947 .31837 .48581 .32558 .49712 .3216 .49082 .31435 Mtetra
.49082 .31435 .49712 .3216 .50848 .3176 .50221 .31032 Mtetra
.50221 .31032 .50848 .3176 .51988 .3136 .51364 .30628 Mtetra
.51364 .30628 .51988 .3136 .53133 .30958 .52513 .30223 Mtetra
.52513 .30223 .53133 .30958 .54283 .30554 .53666 .29816 Mtetra
.53666 .29816 .54283 .30554 .55438 .30149 .54824 .29408 Mtetra
.657 .753 .92 r
.54824 .29408 .55438 .30149 .56598 .29743 .55987 .28999 Mtetra
.55987 .28999 .56598 .29743 .57762 .29335 .57154 .28588 Mtetra
.57154 .28588 .57762 .29335 .58932 .28926 .58327 .28175 Mtetra
.657 .752 .92 r
.58327 .28175 .58932 .28926 .60106 .28515 .59505 .27761 Mtetra
.59505 .27761 .60106 .28515 .61285 .28103 .60687 .27345 Mtetra
.60687 .27345 .61285 .28103 .62469 .27688 .61875 .26928 Mtetra
.61875 .26928 .62469 .27688 .63658 .27273 .63067 .26509 Mtetra
.63067 .26509 .63658 .27273 .64853 .26855 .64265 .26088 Mtetra
.64265 .26088 .64853 .26855 .66052 .26436 .65468 .25665 Mtetra
.65468 .25665 .66052 .26436 .67256 .26015 .66675 .25241 Mtetra
.66675 .25241 .67256 .26015 .68466 .25592 .67889 .24815 Mtetra
.67889 .24815 .68466 .25592 .6968 .25168 .69107 .24387 Mtetra
.69107 .24387 .6968 .25168 .709 .24742 .7033 .23958 Mtetra
.7033 .23958 .709 .24742 .72125 .24314 .71559 .23527 Mtetra
.71559 .23527 .72125 .24314 .73356 .23885 .72793 .23094 Mtetra
.72793 .23094 .73356 .23885 .74591 .23453 .74033 .22659 Mtetra
.74033 .22659 .74591 .23453 .75832 .2302 .75277 .22222 Mtetra
.75277 .22222 .75832 .2302 .77079 .22585 .76528 .21783 Mtetra
.8 .946 .598 r
.10124 .45335 .11068 .44278 .11999 .44367 .11288 .43624 Mtetra
.576 .693 .921 r
.11288 .43624 .11999 .44367 .12971 .44167 .12257 .43455 Mtetra
.568 .701 .931 r
.12257 .43455 .12971 .44167 .139 .44373 .1323 .43296 Mtetra
.801 .688 .74 r
.1323 .43296 .139 .44373 .14997 .43173 .14349 .41937 Mtetra
.326 .44 .824 r
.14349 .41937 .14997 .43173 .15976 .4302 .15268 .42303 Mtetra
.6 .713 .923 r
.15268 .42303 .15976 .4302 .16967 .42798 .16261 .42079 Mtetra
.565 .7 .932 r
.16261 .42079 .16967 .42798 .17897 .43202 .17251 .41921 Mtetra
.77 .656 .737 r
.17251 .41921 .17897 .43202 .19022 .4179 .18356 .40724 Mtetra
.423 .536 .867 r
.18356 .40724 .19022 .4179 .20021 .41603 .1932 .40886 Mtetra
.61 .718 .922 r
.1932 .40886 .20021 .41603 .21033 .41347 .20333 .40636 Mtetra
.603 .719 .926 r
.20333 .40636 .21033 .41347 .22036 .41228 .21349 .40401 Mtetra
.888 .469 .068 r
.21349 .40401 .22036 .41228 .23131 .40158 .22145 .42561 Mtetra
.663 .759 .274 r
.22145 .42561 .23131 .40158 .24135 .40119 .23445 .39369 Mtetra
.601 .708 .919 r
.23445 .39369 .24135 .40119 .25165 .39844 .24473 .39136 Mtetra
.626 .731 .922 r
.24473 .39136 .25165 .39844 .262 .39557 .2551 .38843 Mtetra
.613 .725 .925 r
.2551 .38843 .262 .39557 .27231 .39389 .26551 .38579 Mtetra
0 .204 .718 r
.26551 .38579 .27231 .39389 .2834 .38246 .27517 .39328 Mtetra
.724 .89 .499 r
.27517 .39328 .2834 .38246 .29364 .38276 .28685 .37507 Mtetra
.602 .706 .917 r
.28685 .37507 .29364 .38276 .30417 .37982 .29736 .37268 Mtetra
.635 .735 .921 r
.29736 .37268 .30417 .37982 .31477 .37656 .30798 .36949 Mtetra
.64 .74 .921 r
.30798 .36949 .31477 .37656 .32541 .37325 .31865 .36614 Mtetra
.637 .739 .922 r
.31865 .36614 .32541 .37325 .33609 .37016 .32936 .36286 Mtetra
.612 .725 .926 r
.32936 .36286 .33609 .37016 .34669 .36914 .34008 .36016 Mtetra
.944 .716 .563 r
.34008 .36016 .34669 .36914 .35789 .35809 .35479 .28551 Mtetra
0 0 .36 r
.35479 .28551 .35789 .35809 .36861 .35664 .36197 .34902 Mtetra
.62 .72 .918 r
.36197 .34902 .36861 .35664 .37947 .35334 .37284 .34612 Mtetra
.644 .742 .92 r
.37284 .34612 .37947 .35334 .39039 .34973 .38378 .34259 Mtetra
.651 .747 .92 r
.38378 .34259 .39039 .34973 .40136 .34598 .39478 .33886 Mtetra
.654 .75 .92 r
.39478 .33886 .40136 .34598 .41238 .34215 .40583 .33503 Mtetra
.657 .752 .92 r
.40583 .33503 .41238 .34215 .42345 .33826 .41692 .33113 Mtetra
.658 .753 .92 r
.41692 .33113 .42345 .33826 .43456 .33432 .42806 .32718 Mtetra
.659 .754 .92 r
.42806 .32718 .43456 .33432 .44572 .33036 .43925 .32319 Mtetra
.43925 .32319 .44572 .33036 .45693 .32637 .45049 .31917 Mtetra
.45049 .31917 .45693 .32637 .46818 .32237 .46177 .31514 Mtetra
.46177 .31514 .46818 .32237 .47947 .31837 .47309 .3111 Mtetra
.658 .753 .92 r
.47309 .3111 .47947 .31837 .49082 .31435 .48447 .30705 Mtetra
.48447 .30705 .49082 .31435 .50221 .31032 .49589 .30299 Mtetra
.49589 .30299 .50221 .31032 .51364 .30628 .50735 .29891 Mtetra
.50735 .29891 .51364 .30628 .52513 .30223 .51887 .29483 Mtetra
.51887 .29483 .52513 .30223 .53666 .29816 .53043 .29073 Mtetra
.53043 .29073 .53666 .29816 .54824 .29408 .54205 .28662 Mtetra
.54205 .28662 .54824 .29408 .55987 .28999 .55371 .28249 Mtetra
.657 .753 .92 r
.55371 .28249 .55987 .28999 .57154 .28588 .56542 .27835 Mtetra
.56542 .27835 .57154 .28588 .58327 .28175 .57718 .27419 Mtetra
.57718 .27419 .58327 .28175 .59505 .27761 .58898 .27001 Mtetra
.657 .752 .92 r
.58898 .27001 .59505 .27761 .60687 .27345 .60084 .26582 Mtetra
.60084 .26582 .60687 .27345 .61875 .26928 .61275 .26161 Mtetra
.61275 .26161 .61875 .26928 .63067 .26509 .62471 .25739 Mtetra
.62471 .25739 .63067 .26509 .64265 .26088 .63672 .25315 Mtetra
.63672 .25315 .64265 .26088 .65468 .25665 .64879 .24889 Mtetra
.64879 .24889 .65468 .25665 .66675 .25241 .6609 .24461 Mtetra
.6609 .24461 .66675 .25241 .67889 .24815 .67307 .24032 Mtetra
.67307 .24032 .67889 .24815 .69107 .24387 .68529 .23601 Mtetra
.68529 .23601 .69107 .24387 .7033 .23958 .69756 .23168 Mtetra
.69756 .23168 .7033 .23958 .71559 .23527 .70988 .22733 Mtetra
.70988 .22733 .71559 .23527 .72793 .23094 .72226 .22296 Mtetra
.72226 .22296 .72793 .23094 .74033 .22659 .73469 .21858 Mtetra
.73469 .21858 .74033 .22659 .75277 .22222 .74718 .21418 Mtetra
.74718 .21418 .75277 .22222 .76528 .21783 .75972 .20976 Mtetra
.734 .609 .718 r
.09513 .43746 .10124 .45335 .11288 .43624 .106 .42654 Mtetra
.451 .574 .887 r
.106 .42654 .11288 .43624 .12257 .43455 .11538 .42739 Mtetra
.591 .71 .926 r
.11538 .42739 .12257 .43455 .1323 .43296 .12518 .42533 Mtetra
.304 .565 .929 r
.12518 .42533 .1323 .43296 .14349 .41937 .13453 .42734 Mtetra
.665 .921 .616 r
.13453 .42734 .14349 .41937 .15268 .42303 .14561 .41525 Mtetra
.57 .684 .918 r
.14561 .41525 .15268 .42303 .16261 .42079 .15548 .41366 Mtetra
.6 .716 .926 r
.15548 .41366 .16261 .42079 .17251 .41921 .16547 .41138 Mtetra
.107 .443 .879 r
.16547 .41138 .17251 .41921 .18356 .40724 .17483 .41539 Mtetra
.75 .948 .628 r
.17483 .41539 .18356 .40724 .1932 .40886 .1862 .40116 Mtetra
.584 .694 .918 r
.1862 .40116 .1932 .40886 .20333 .40636 .19628 .39923 Mtetra
.614 .723 .924 r
.19628 .39923 .20333 .40636 .21349 .40401 .20648 .39661 Mtetra
.544 .69 .935 r
.20648 .39661 .21349 .40401 .22145 .42561 .21659 .39536 Mtetra
.661 .495 .649 r
.21659 .39536 .22145 .42561 .23445 .39369 .22764 .38456 Mtetra
.517 .627 .899 r
.22764 .38456 .23445 .39369 .24473 .39136 .23777 .38412 Mtetra
.621 .725 .921 r
.23777 .38412 .24473 .39136 .2551 .38843 .24815 .3813 Mtetra
.624 .731 .923 r
.24815 .3813 .2551 .38843 .26551 .38579 .2586 .37837 Mtetra
.569 .702 .932 r
.2586 .37837 .26551 .38579 .27517 .39328 .26899 .37663 Mtetra
.736 .609 .716 r
.26899 .37663 .27517 .39328 .28685 .37507 .28019 .36509 Mtetra
.488 .593 .885 r
.28019 .36509 .28685 .37507 .29736 .37268 .29052 .36534 Mtetra
.626 .728 .92 r
.29052 .36534 .29736 .37268 .30798 .36949 .30114 .36234 Mtetra
.639 .739 .921 r
.30114 .36234 .30798 .36949 .31865 .36614 .31183 .359 Mtetra
.64 .74 .922 r
.31183 .359 .31865 .36614 .32936 .36286 .32257 .35562 Mtetra
.63 .735 .923 r
.32257 .35562 .32936 .36286 .34008 .36016 .33334 .35246 Mtetra
.532 .683 .935 r
.33334 .35246 .34008 .36016 .35479 .28551 .34404 .35138 Mtetra
.42 .156 .406 r
.34404 .35138 .35479 .28551 .36197 .34902 .35535 .34023 Mtetra
.562 .664 .905 r
.35535 .34023 .36197 .34902 .37284 .34612 .36616 .33872 Mtetra
.637 .735 .92 r
.36616 .33872 .37284 .34612 .38378 .34259 .37712 .33535 Mtetra
.648 .745 .92 r
.37712 .33535 .38378 .34259 .39478 .33886 .38814 .33166 Mtetra
.653 .749 .92 r
.38814 .33166 .39478 .33886 .40583 .33503 .39922 .32784 Mtetra
.656 .751 .92 r
.39922 .32784 .40583 .33503 .41692 .33113 .41034 .32394 Mtetra
.657 .752 .92 r
.41034 .32394 .41692 .33113 .42806 .32718 .42151 .31997 Mtetra
.658 .753 .92 r
.42151 .31997 .42806 .32718 .43925 .32319 .43273 .31596 Mtetra
.659 .754 .92 r
.43273 .31596 .43925 .32319 .45049 .31917 .44399 .31191 Mtetra
.44399 .31191 .45049 .31917 .46177 .31514 .45531 .30785 Mtetra
.45531 .30785 .46177 .31514 .47309 .3111 .46666 .30378 Mtetra
.46666 .30378 .47309 .3111 .48447 .30705 .47807 .29969 Mtetra
.658 .753 .92 r
.47807 .29969 .48447 .30705 .49589 .30299 .48952 .29559 Mtetra
.48952 .29559 .49589 .30299 .50735 .29891 .50102 .29149 Mtetra
.50102 .29149 .50735 .29891 .51887 .29483 .51256 .28737 Mtetra
.51256 .28737 .51887 .29483 .53043 .29073 .52416 .28324 Mtetra
.52416 .28324 .53043 .29073 .54205 .28662 .5358 .27909 Mtetra
.5358 .27909 .54205 .28662 .55371 .28249 .5475 .27493 Mtetra
.657 .753 .92 r
.5475 .27493 .55371 .28249 .56542 .27835 .55924 .27075 Mtetra
.55924 .27075 .56542 .27835 .57718 .27419 .57103 .26656 Mtetra
.57103 .26656 .57718 .27419 .58898 .27001 .58288 .26235 Mtetra
.657 .752 .92 r
.58288 .26235 .58898 .27001 .60084 .26582 .59477 .25813 Mtetra
.59477 .25813 .60084 .26582 .61275 .26161 .60671 .25389 Mtetra
.60671 .25389 .61275 .26161 .62471 .25739 .61871 .24963 Mtetra
.61871 .24963 .62471 .25739 .63672 .25315 .63075 .24535 Mtetra
.63075 .24535 .63672 .25315 .64879 .24889 .64285 .24106 Mtetra
.64285 .24106 .64879 .24889 .6609 .24461 .655 .23675 Mtetra
.655 .23675 .6609 .24461 .67307 .24032 .6672 .23242 Mtetra
.6672 .23242 .67307 .24032 .68529 .23601 .67946 .22808 Mtetra
.67946 .22808 .68529 .23601 .69756 .23168 .69177 .22371 Mtetra
.69177 .22371 .69756 .23168 .70988 .22733 .70413 .21933 Mtetra
.70413 .21933 .70988 .22733 .72226 .22296 .71654 .21493 Mtetra
.71654 .21493 .72226 .22296 .73469 .21858 .72901 .21051 Mtetra
.72901 .21051 .73469 .21858 .74718 .21418 .74154 .20607 Mtetra
.74154 .20607 .74718 .21418 .75972 .20976 .75412 .20161 Mtetra
0 .103 .622 r
.08795 .42952 .09513 .43746 .106 .42654 .09642 .43707 Mtetra
.806 .949 .605 r
.09642 .43707 .106 .42654 .11538 .42739 .10818 .41983 Mtetra
.576 .693 .921 r
.10818 .41983 .11538 .42739 .12518 .42533 .11795 .41808 Mtetra
.568 .701 .931 r
.11795 .41808 .12518 .42533 .13453 .42734 .12776 .41644 Mtetra
.802 .689 .74 r
.12776 .41644 .13453 .42734 .14561 .41525 .13906 .40274 Mtetra
.325 .439 .824 r
.13906 .40274 .14561 .41525 .15548 .41366 .14832 .40637 Mtetra
.6 .713 .923 r
.14832 .40637 .15548 .41366 .16547 .41138 .15833 .40406 Mtetra
.565 .7 .932 r
.15833 .40406 .16547 .41138 .17483 .41539 .16831 .40243 Mtetra
.77 .657 .738 r
.16831 .40243 .17483 .41539 .1862 .40116 .17947 .39035 Mtetra
.422 .536 .867 r
.17947 .39035 .1862 .40116 .19628 .39923 .18919 .39193 Mtetra
.61 .718 .922 r
.18919 .39193 .19628 .39923 .20648 .39661 .1994 .38937 Mtetra
.603 .719 .926 r
.1994 .38937 .20648 .39661 .21659 .39536 .20964 .38695 Mtetra
.885 .465 .06 r
.20964 .38695 .21659 .39536 .22764 .38456 .21764 .40859 Mtetra
.673 .766 .283 r
.21764 .40859 .22764 .38456 .23777 .38412 .23079 .37649 Mtetra
.601 .708 .919 r
.23079 .37649 .23777 .38412 .24815 .3813 .24115 .37409 Mtetra
.626 .731 .922 r
.24115 .37409 .24815 .3813 .2586 .37837 .25162 .3711 Mtetra
.613 .725 .925 r
.25162 .3711 .2586 .37837 .26899 .37663 .26211 .36839 Mtetra
0 .209 .722 r
.26211 .36839 .26899 .37663 .28019 .36509 .27185 .37585 Mtetra
.732 .895 .507 r
.27185 .37585 .28019 .36509 .29052 .36534 .28366 .35752 Mtetra
.602 .706 .917 r
.28366 .35752 .29052 .36534 .30114 .36234 .29426 .35506 Mtetra
.635 .735 .921 r
.29426 .35506 .30114 .36234 .31183 .359 .30497 .3518 Mtetra
.64 .74 .921 r
.30497 .3518 .31183 .359 .32257 .35562 .31573 .34838 Mtetra
.637 .739 .922 r
.31573 .34838 .32257 .35562 .33334 .35246 .32654 .34503 Mtetra
.612 .725 .926 r
.32654 .34503 .33334 .35246 .34404 .35138 .33736 .34226 Mtetra
.945 .716 .562 r
.33736 .34226 .34404 .35138 .35535 .34023 .35226 .26728 Mtetra
0 0 .355 r
.35226 .26728 .35535 .34023 .36616 .33872 .35945 .33096 Mtetra
.62 .72 .918 r
.35945 .33096 .36616 .33872 .37712 .33535 .37042 .32799 Mtetra
.644 .742 .92 r
.37042 .32799 .37712 .33535 .38814 .33166 .38146 .32438 Mtetra
.651 .747 .92 r
.38146 .32438 .38814 .33166 .39922 .32784 .39256 .32058 Mtetra
.654 .75 .92 r
.39256 .32058 .39922 .32784 .41034 .32394 .40371 .31668 Mtetra
.657 .752 .92 r
.40371 .31668 .41034 .32394 .42151 .31997 .41491 .3127 Mtetra
.658 .753 .92 r
.41491 .3127 .42151 .31997 .43273 .31596 .42616 .30867 Mtetra
.659 .754 .92 r
.42616 .30867 .43273 .31596 .44399 .31191 .43745 .3046 Mtetra
.43745 .3046 .44399 .31191 .45531 .30785 .44879 .30051 Mtetra
.44879 .30051 .45531 .30785 .46666 .30378 .46018 .2964 Mtetra
.46018 .2964 .46666 .30378 .47807 .29969 .47162 .29228 Mtetra
.658 .753 .92 r
.47162 .29228 .47807 .29969 .48952 .29559 .4831 .28815 Mtetra
.4831 .28815 .48952 .29559 .50102 .29149 .49463 .28401 Mtetra
.49463 .28401 .50102 .29149 .51256 .28737 .50621 .27985 Mtetra
.50621 .27985 .51256 .28737 .52416 .28324 .51784 .27569 Mtetra
.51784 .27569 .52416 .28324 .5358 .27909 .52951 .27151 Mtetra
.52951 .27151 .5358 .27909 .5475 .27493 .54124 .26731 Mtetra
.54124 .26731 .5475 .27493 .55924 .27075 .55302 .2631 Mtetra
.657 .753 .92 r
.55302 .2631 .55924 .27075 .57103 .26656 .56484 .25888 Mtetra
.56484 .25888 .57103 .26656 .58288 .26235 .57672 .25464 Mtetra
.57672 .25464 .58288 .26235 .59477 .25813 .58865 .25038 Mtetra
.657 .752 .92 r
.58865 .25038 .59477 .25813 .60671 .25389 .60062 .2461 Mtetra
.60062 .2461 .60671 .25389 .61871 .24963 .61265 .24181 Mtetra
.61265 .24181 .61871 .24963 .63075 .24535 .62474 .2375 Mtetra
.62474 .2375 .63075 .24535 .64285 .24106 .63687 .23317 Mtetra
.63687 .23317 .64285 .24106 .655 .23675 .64905 .22883 Mtetra
.64905 .22883 .655 .23675 .6672 .23242 .66129 .22446 Mtetra
.66129 .22446 .6672 .23242 .67946 .22808 .67358 .22008 Mtetra
.67358 .22008 .67946 .22808 .69177 .22371 .68593 .21568 Mtetra
.68593 .21568 .69177 .22371 .70413 .21933 .69833 .21126 Mtetra
.69833 .21126 .70413 .21933 .71654 .21493 .71078 .20683 Mtetra
.71078 .20683 .71654 .21493 .72901 .21051 .72329 .20237 Mtetra
.72329 .20237 .72901 .21051 .74154 .20607 .73585 .1979 Mtetra
.73585 .1979 .74154 .20607 .75412 .20161 .74847 .1934 Mtetra
.542 .688 .934 r
.08063 .42219 .08795 .42952 .09642 .43707 .09026 .42101 Mtetra
.734 .609 .718 r
.09026 .42101 .09642 .43707 .10818 .41983 .10123 .41 Mtetra
.451 .574 .887 r
.10123 .41 .10818 .41983 .11795 .41808 .11068 .4108 Mtetra
.591 .71 .926 r
.11068 .4108 .11795 .41808 .12776 .41644 .12056 .40868 Mtetra
.305 .565 .929 r
.12056 .40868 .12776 .41644 .13906 .40274 .12998 .41066 Mtetra
.675 .927 .626 r
.12998 .41066 .13906 .40274 .14832 .40637 .14117 .39846 Mtetra
.57 .684 .918 r
.14117 .39846 .14832 .40637 .15833 .40406 .15112 .39681 Mtetra
.6 .716 .926 r
.15112 .39681 .15833 .40406 .16831 .40243 .16119 .39447 Mtetra
.11 .445 .88 r
.16119 .39447 .16831 .40243 .17947 .39035 .17062 .39844 Mtetra
.757 .952 .636 r
.17062 .39844 .17947 .39035 .18919 .39193 .1821 .3841 Mtetra
.584 .694 .918 r
.1821 .3841 .18919 .39193 .1994 .38937 .19226 .38211 Mtetra
.614 .723 .924 r
.19226 .38211 .1994 .38937 .20964 .38695 .20255 .37942 Mtetra
.545 .69 .934 r
.20255 .37942 .20964 .38695 .21764 .40859 .21275 .37812 Mtetra
.66 .494 .648 r
.21275 .37812 .21764 .40859 .23079 .37649 .22391 .36722 Mtetra
.516 .627 .899 r
.22391 .36722 .23079 .37649 .24115 .37409 .23411 .36672 Mtetra
.621 .725 .921 r
.23411 .36672 .24115 .37409 .25162 .3711 .24459 .36383 Mtetra
.624 .731 .923 r
.24459 .36383 .25162 .3711 .26211 .36839 .25513 .36084 Mtetra
.569 .702 .932 r
.25513 .36084 .26211 .36839 .27185 .37585 .26561 .35903 Mtetra
.737 .609 .716 r
.26561 .35903 .27185 .37585 .28366 .35752 .27692 .34739 Mtetra
.488 .593 .885 r
.27692 .34739 .28366 .35752 .29426 .35506 .28734 .34759 Mtetra
.626 .728 .92 r
.28734 .34759 .29426 .35506 .30497 .3518 .29805 .34451 Mtetra
.639 .739 .921 r
.29805 .34451 .30497 .3518 .31573 .34838 .30884 .34111 Mtetra
.64 .74 .922 r
.30884 .34111 .31573 .34838 .32654 .34503 .31968 .33766 Mtetra
.63 .735 .923 r
.31968 .33766 .32654 .34503 .33736 .34226 .33055 .33443 Mtetra
.532 .683 .935 r
.33055 .33443 .33736 .34226 .35226 .26728 .34134 .33328 Mtetra
.414 .149 .4 r
.34134 .33328 .35226 .26728 .35945 .33096 .35276 .32203 Mtetra
.562 .664 .906 r
.35276 .32203 .35945 .33096 .37042 .32799 .36367 .32045 Mtetra
.637 .735 .92 r
.36367 .32045 .37042 .32799 .38146 .32438 .37473 .317 Mtetra
.648 .745 .92 r
.37473 .317 .38146 .32438 .39256 .32058 .38586 .31324 Mtetra
.653 .749 .92 r
.38586 .31324 .39256 .32058 .40371 .31668 .39703 .30935 Mtetra
.656 .751 .92 r
.39703 .30935 .40371 .31668 .41491 .3127 .40826 .30537 Mtetra
.657 .752 .92 r
.40826 .30537 .41491 .3127 .42616 .30867 .41954 .30132 Mtetra
.658 .753 .92 r
.41954 .30132 .42616 .30867 .43745 .3046 .43086 .29723 Mtetra
.659 .754 .92 r
.43086 .29723 .43745 .3046 .44879 .30051 .44223 .29311 Mtetra
.44223 .29311 .44879 .30051 .46018 .2964 .45365 .28896 Mtetra
.45365 .28896 .46018 .2964 .47162 .29228 .46512 .28481 Mtetra
.46512 .28481 .47162 .29228 .4831 .28815 .47663 .28064 Mtetra
.658 .753 .92 r
.47663 .28064 .4831 .28815 .49463 .28401 .48819 .27647 Mtetra
.48819 .27647 .49463 .28401 .50621 .27985 .49981 .27228 Mtetra
.49981 .27228 .50621 .27985 .51784 .27569 .51147 .26808 Mtetra
.51147 .26808 .51784 .27569 .52951 .27151 .52318 .26387 Mtetra
.52318 .26387 .52951 .27151 .54124 .26731 .53493 .25964 Mtetra
.53493 .25964 .54124 .26731 .55302 .2631 .54674 .25539 Mtetra
.657 .753 .92 r
.54674 .25539 .55302 .2631 .56484 .25888 .5586 .25113 Mtetra
.5586 .25113 .56484 .25888 .57672 .25464 .57051 .24686 Mtetra
.57051 .24686 .57672 .25464 .58865 .25038 .58247 .24256 Mtetra
.657 .752 .92 r
.58247 .24256 .58865 .25038 .60062 .2461 .59449 .23825 Mtetra
.59449 .23825 .60062 .2461 .61265 .24181 .60655 .23392 Mtetra
.60655 .23392 .61265 .24181 .62474 .2375 .61867 .22958 Mtetra
.61867 .22958 .62474 .2375 .63687 .23317 .63084 .22522 Mtetra
.63084 .22522 .63687 .23317 .64905 .22883 .64306 .22084 Mtetra
.64306 .22084 .64905 .22883 .66129 .22446 .65533 .21644 Mtetra
.65533 .21644 .66129 .22446 .67358 .22008 .66766 .21202 Mtetra
.66766 .21202 .67358 .22008 .68593 .21568 .68005 .20759 Mtetra
.68005 .20759 .68593 .21568 .69833 .21126 .69248 .20313 Mtetra
.69248 .20313 .69833 .21126 .71078 .20683 .70497 .19866 Mtetra
.70497 .19866 .71078 .20683 .72329 .20237 .71752 .19417 Mtetra
.71752 .19417 .72329 .20237 .73585 .1979 .73012 .18965 Mtetra
.73012 .18965 .73585 .1979 .74847 .1934 .74278 .18512 Mtetra
.58 .703 .927 r
.07326 .41484 .08063 .42219 .09026 .42101 .083 .41295 Mtetra
0 .108 .627 r
.083 .41295 .09026 .42101 .10123 .41 .09152 .42048 Mtetra
.811 .953 .612 r
.09152 .42048 .10123 .41 .11068 .4108 .1034 .40312 Mtetra
.576 .693 .921 r
.1034 .40312 .11068 .4108 .12056 .40868 .11325 .40131 Mtetra
.568 .701 .931 r
.11325 .40131 .12056 .40868 .12998 .41066 .12314 .39961 Mtetra
.802 .69 .741 r
.12314 .39961 .12998 .41066 .14117 .39846 .13455 .3858 Mtetra
.323 .439 .824 r
.13455 .3858 .14117 .39846 .15112 .39681 .14387 .38939 Mtetra
.6 .713 .923 r
.14387 .38939 .15112 .39681 .16119 .39447 .15397 .38703 Mtetra
.566 .7 .932 r
.15397 .38703 .16119 .39447 .17062 .39844 .16403 .38533 Mtetra
.77 .657 .738 r
.16403 .38533 .17062 .39844 .1821 .3841 .1753 .37315 Mtetra
.422 .535 .867 r
.1753 .37315 .1821 .3841 .19226 .38211 .18509 .37468 Mtetra
.61 .718 .922 r
.18509 .37468 .19226 .38211 .20255 .37942 .19539 .37206 Mtetra
.603 .719 .926 r
.19539 .37206 .20255 .37942 .21275 .37812 .20572 .36957 Mtetra
.882 .461 .053 r
.20572 .36957 .21275 .37812 .22391 .36722 .21376 .39125 Mtetra
.682 .773 .292 r
.21376 .39125 .22391 .36722 .23411 .36672 .22706 .35896 Mtetra
.601 .708 .919 r
.22706 .35896 .23411 .36672 .24459 .36383 .23751 .35649 Mtetra
.626 .731 .922 r
.23751 .35649 .24459 .36383 .25513 .36084 .24807 .35343 Mtetra
.613 .725 .925 r
.24807 .35343 .25513 .36084 .26561 .35903 .25866 .35066 Mtetra
0 .213 .726 r
.25866 .35066 .26561 .35903 .27692 .34739 .26847 .35809 Mtetra
.74 .9 .516 r
.26847 .35809 .27692 .34739 .28734 .34759 .2804 .33962 Mtetra
.602 .706 .917 r
.2804 .33962 .28734 .34759 .29805 .34451 .29109 .33711 Mtetra
.635 .735 .921 r
.29109 .33711 .29805 .34451 .30884 .34111 .3019 .33377 Mtetra
.64 .74 .921 r
.3019 .33377 .30884 .34111 .31968 .33766 .31276 .33028 Mtetra
.637 .739 .922 r
.31276 .33028 .31968 .33766 .33055 .33443 .32367 .32685 Mtetra
.612 .725 .926 r
.32367 .32685 .33055 .33443 .34134 .33328 .33458 .32401 Mtetra
.946 .717 .56 r
.33458 .32401 .34134 .33328 .35276 .32203 .34969 .24869 Mtetra
0 0 .35 r
.34969 .24869 .35276 .32203 .36367 .32045 .35689 .31255 Mtetra
.62 .72 .918 r
.35689 .31255 .36367 .32045 .37473 .317 .36795 .3095 Mtetra
.644 .742 .92 r
.36795 .3095 .37473 .317 .38586 .31324 .3791 .30582 Mtetra
.651 .747 .92 r
.3791 .30582 .38586 .31324 .39703 .30935 .3903 .30194 Mtetra
.654 .75 .92 r
.3903 .30194 .39703 .30935 .40826 .30537 .40156 .29796 Mtetra
.657 .752 .92 r
.40156 .29796 .40826 .30537 .41954 .30132 .41286 .29391 Mtetra
.658 .753 .92 r
.41286 .29391 .41954 .30132 .43086 .29723 .42422 .2898 Mtetra
.659 .754 .92 r
.42422 .2898 .43086 .29723 .44223 .29311 .43562 .28565 Mtetra
.43562 .28565 .44223 .29311 .45365 .28896 .44707 .28147 Mtetra
.44707 .28147 .45365 .28896 .46512 .28481 .45857 .27728 Mtetra
.45857 .27728 .46512 .28481 .47663 .28064 .47011 .27308 Mtetra
.658 .753 .92 r
.47011 .27308 .47663 .28064 .48819 .27647 .48171 .26887 Mtetra
.48171 .26887 .48819 .27647 .49981 .27228 .49335 .26465 Mtetra
.49335 .26465 .49981 .27228 .51147 .26808 .50504 .26041 Mtetra
.50504 .26041 .51147 .26808 .52318 .26387 .51679 .25616 Mtetra
.51679 .25616 .52318 .26387 .53493 .25964 .52858 .2519 Mtetra
.52858 .2519 .53493 .25964 .54674 .25539 .54042 .24762 Mtetra
.54042 .24762 .54674 .25539 .5586 .25113 .55231 .24333 Mtetra
.657 .753 .92 r
.55231 .24333 .5586 .25113 .57051 .24686 .56426 .23901 Mtetra
.56426 .23901 .57051 .24686 .58247 .24256 .57625 .23469 Mtetra
.57625 .23469 .58247 .24256 .59449 .23825 .5883 .23034 Mtetra
.657 .752 .92 r
.5883 .23034 .59449 .23825 .60655 .23392 .6004 .22598 Mtetra
.6004 .22598 .60655 .23392 .61867 .22958 .61255 .2216 Mtetra
.61255 .2216 .61867 .22958 .63084 .22522 .62476 .2172 Mtetra
.62476 .2172 .63084 .22522 .64306 .22084 .63702 .21278 Mtetra
.63702 .21278 .64306 .22084 .65533 .21644 .64933 .20835 Mtetra
.64933 .20835 .65533 .21644 .66766 .21202 .66169 .2039 Mtetra
.66169 .2039 .66766 .21202 .68005 .20759 .67411 .19942 Mtetra
.67411 .19942 .68005 .20759 .69248 .20313 .68659 .19493 Mtetra
.68659 .19493 .69248 .20313 .70497 .19866 .69912 .19042 Mtetra
.69912 .19042 .70497 .19866 .71752 .19417 .7117 .18589 Mtetra
.7117 .18589 .71752 .19417 .73012 .18965 .72434 .18135 Mtetra
.72434 .18135 .73012 .18965 .74278 .18512 .73704 .17678 Mtetra
.561 .682 .921 r
.0659 .40699 .07326 .41484 .083 .41295 .07559 .4055 Mtetra
.542 .688 .934 r
.07559 .4055 .083 .41295 .09152 .42048 .0853 .40426 Mtetra
.734 .609 .718 r
.0853 .40426 .09152 .42048 .1034 .40312 .09637 .39315 Mtetra
.45 .574 .887 r
.09637 .39315 .1034 .40312 .11325 .40131 .10589 .39391 Mtetra
.591 .71 .926 r
.10589 .39391 .11325 .40131 .12314 .39961 .11585 .39173 Mtetra
.307 .566 .929 r
.11585 .39173 .12314 .39961 .13455 .3858 .12535 .39365 Mtetra
.684 .933 .635 r
.12535 .39365 .13455 .3858 .14387 .38939 .13664 .38136 Mtetra
.569 .684 .918 r
.13664 .38136 .14387 .38939 .15397 .38703 .14667 .37964 Mtetra
.6 .716 .926 r
.14667 .37964 .15397 .38703 .16403 .38533 .15683 .37724 Mtetra
.114 .447 .881 r
.15683 .37724 .16403 .38533 .1753 .37315 .16633 .38117 Mtetra
.764 .956 .643 r
.16633 .38117 .1753 .37315 .18509 .37468 .17792 .36672 Mtetra
.584 .694 .918 r
.17792 .36672 .18509 .37468 .19539 .37206 .18817 .36467 Mtetra
.614 .723 .924 r
.18817 .36467 .19539 .37206 .20572 .36957 .19855 .36191 Mtetra
.545 .69 .934 r
.19855 .36191 .20572 .36957 .21376 .39125 .20883 .36055 Mtetra
.66 .493 .647 r
.20883 .36055 .21376 .39125 .22706 .35896 .2201 .34954 Mtetra
.516 .627 .899 r
.2201 .34954 .22706 .35896 .23751 .35649 .23039 .34899 Mtetra
.621 .725 .921 r
.23039 .34899 .23751 .35649 .24807 .35343 .24096 .34603 Mtetra
.624 .731 .923 r
.24096 .34603 .24807 .35343 .25866 .35066 .25159 .34297 Mtetra
.569 .702 .932 r
.25159 .34297 .25866 .35066 .26847 .35809 .26217 .3411 Mtetra
.737 .61 .716 r
.26217 .3411 .26847 .35809 .2804 .33962 .27359 .32935 Mtetra
.487 .593 .885 r
.27359 .32935 .2804 .33962 .29109 .33711 .28409 .32949 Mtetra
.626 .728 .92 r
.28409 .32949 .29109 .33711 .3019 .33377 .2949 .32634 Mtetra
.639 .739 .921 r
.2949 .32634 .3019 .33377 .31276 .33028 .30579 .32286 Mtetra
.64 .74 .922 r
.30579 .32286 .31276 .33028 .32367 .32685 .31673 .31934 Mtetra
.63 .735 .923 r
.31673 .31934 .32367 .32685 .33458 .32401 .32769 .31604 Mtetra
.533 .683 .935 r
.32769 .31604 .33458 .32401 .34969 .24869 .33859 .31483 Mtetra
.408 .141 .393 r
.33859 .31483 .34969 .24869 .35689 .31255 .35012 .30347 Mtetra
.562 .664 .906 r
.35012 .30347 .35689 .31255 .36795 .3095 .36113 .30182 Mtetra
.637 .735 .92 r
.36113 .30182 .36795 .3095 .3791 .30582 .37229 .2983 Mtetra
.648 .745 .92 r
.37229 .2983 .3791 .30582 .3903 .30194 .38352 .29446 Mtetra
.653 .749 .92 r
.38352 .29446 .3903 .30194 .40156 .29796 .3948 .29049 Mtetra
.656 .751 .92 r
.3948 .29049 .40156 .29796 .41286 .29391 .40614 .28642 Mtetra
.657 .752 .92 r
.40614 .28642 .41286 .29391 .42422 .2898 .41752 .2823 Mtetra
.658 .753 .92 r
.41752 .2823 .42422 .2898 .43562 .28565 .42895 .27813 Mtetra
.659 .754 .92 r
.42895 .27813 .43562 .28565 .44707 .28147 .44044 .27392 Mtetra
.44044 .27392 .44707 .28147 .45857 .27728 .45196 .2697 Mtetra
.45196 .2697 .45857 .27728 .47011 .27308 .46354 .26546 Mtetra
.46354 .26546 .47011 .27308 .48171 .26887 .47517 .26121 Mtetra
.658 .753 .92 r
.47517 .26121 .48171 .26887 .49335 .26465 .48684 .25696 Mtetra
.48684 .25696 .49335 .26465 .50504 .26041 .49857 .25268 Mtetra
.49857 .25268 .50504 .26041 .51679 .25616 .51034 .2484 Mtetra
.51034 .2484 .51679 .25616 .52858 .2519 .52217 .2441 Mtetra
.52217 .2441 .52858 .2519 .54042 .24762 .53405 .23979 Mtetra
.53405 .23979 .54042 .24762 .55231 .24333 .54597 .23546 Mtetra
.657 .753 .92 r
.54597 .23546 .55231 .24333 .56426 .23901 .55795 .23111 Mtetra
.55795 .23111 .56426 .23901 .57625 .23469 .56998 .22675 Mtetra
.56998 .22675 .57625 .23469 .5883 .23034 .58206 .22237 Mtetra
.657 .752 .92 r
.58206 .22237 .5883 .23034 .6004 .22598 .5942 .21797 Mtetra
.5942 .21797 .6004 .22598 .61255 .2216 .60639 .21355 Mtetra
.60639 .21355 .61255 .2216 .62476 .2172 .61863 .20912 Mtetra
.61863 .20912 .62476 .2172 .63702 .21278 .63092 .20467 Mtetra
.63092 .20467 .63702 .21278 .64933 .20835 .64327 .20019 Mtetra
.64327 .20019 .64933 .20835 .66169 .2039 .65567 .1957 Mtetra
.65567 .1957 .66169 .2039 .67411 .19942 .66813 .1912 Mtetra
.66813 .1912 .67411 .19942 .68659 .19493 .68064 .18667 Mtetra
.68064 .18667 .68659 .19493 .69912 .19042 .69321 .18212 Mtetra
.69321 .18212 .69912 .19042 .7117 .18589 .70583 .17756 Mtetra
.70583 .17756 .7117 .18589 .72434 .18135 .71851 .17297 Mtetra
.71851 .17297 .72434 .18135 .73704 .17678 .73125 .16836 Mtetra
.351 .479 .849 r
.05903 .39539 .0659 .40699 .07559 .4055 .06814 .39803 Mtetra
.58 .703 .927 r
.06814 .39803 .07559 .4055 .0853 .40426 .07795 .39607 Mtetra
0 .114 .632 r
.07795 .39607 .0853 .40426 .09637 .39315 .08653 .40358 Mtetra
.817 .956 .618 r
.08653 .40358 .09637 .39315 .10589 .39391 .09853 .3861 Mtetra
.576 .693 .921 r
.09853 .3861 .10589 .39391 .11585 .39173 .10846 .38423 Mtetra
.568 .701 .931 r
.10846 .38423 .11585 .39173 .12535 .39365 .11843 .38246 Mtetra
.803 .691 .741 r
.11843 .38246 .12535 .39365 .13664 .38136 .12995 .36855 Mtetra
.322 .438 .824 r
.12995 .36855 .13664 .38136 .14667 .37964 .13934 .37209 Mtetra
.6 .713 .923 r
.13934 .37209 .14667 .37964 .15683 .37724 .14952 .36967 Mtetra
.566 .7 .932 r
.14952 .36967 .15683 .37724 .16633 .38117 .15967 .36791 Mtetra
.771 .658 .738 r
.15967 .36791 .16633 .38117 .17792 .36672 .17105 .35563 Mtetra
.421 .535 .867 r
.17105 .35563 .17792 .36672 .18817 .36467 .18092 .3571 Mtetra
.61 .718 .922 r
.18092 .3571 .18817 .36467 .19855 .36191 .19131 .35441 Mtetra
.603 .719 .926 r
.19131 .35441 .19855 .36191 .20883 .36055 .20172 .35186 Mtetra
.879 .457 .045 r
.20172 .35186 .20883 .36055 .2201 .34954 .2098 .37357 Mtetra
.691 .78 .301 r
.2098 .37357 .2201 .34954 .23039 .34899 .22325 .34109 Mtetra
.601 .708 .919 r
.22325 .34109 .23039 .34899 .24096 .34603 .2338 .33856 Mtetra
.626 .731 .922 r
.2338 .33856 .24096 .34603 .25159 .34297 .24446 .33543 Mtetra
.613 .725 .925 r
.24446 .33543 .25159 .34297 .26217 .3411 .25513 .33258 Mtetra
0 .218 .73 r
.25513 .33258 .26217 .3411 .27359 .32935 .26502 .33999 Mtetra
.747 .906 .524 r
.26502 .33999 .27359 .32935 .28409 .32949 .27707 .32139 Mtetra
.601 .706 .917 r
.27707 .32139 .28409 .32949 .2949 .32634 .28786 .3188 Mtetra
.635 .735 .921 r
.28786 .3188 .2949 .32634 .30579 .32286 .29877 .31538 Mtetra
.64 .74 .921 r
.29877 .31538 .30579 .32286 .31673 .31934 .30973 .31182 Mtetra
.637 .739 .922 r
.30973 .31182 .31673 .31934 .32769 .31604 .32074 .30832 Mtetra
.612 .725 .926 r
.32074 .30832 .32769 .31604 .33859 .31483 .33175 .30541 Mtetra
.947 .717 .558 r
.33175 .30541 .33859 .31483 .35012 .30347 .34706 .22975 Mtetra
0 0 .345 r
.34706 .22975 .35012 .30347 .36113 .30182 .35427 .29377 Mtetra
.62 .72 .918 r
.35427 .29377 .36113 .30182 .37229 .2983 .36544 .29065 Mtetra
.644 .742 .92 r
.36544 .29065 .37229 .2983 .38352 .29446 .37669 .28689 Mtetra
.651 .747 .92 r
.37669 .28689 .38352 .29446 .3948 .29049 .388 .28294 Mtetra
.654 .75 .92 r
.388 .28294 .3948 .29049 .40614 .28642 .39936 .27887 Mtetra
.657 .752 .92 r
.39936 .27887 .40614 .28642 .41752 .2823 .41077 .27474 Mtetra
.658 .753 .92 r
.41077 .27474 .41752 .2823 .42895 .27813 .42224 .27055 Mtetra
.659 .754 .92 r
.42224 .27055 .42895 .27813 .44044 .27392 .43375 .26631 Mtetra
.43375 .26631 .44044 .27392 .45196 .2697 .44531 .26206 Mtetra
.44531 .26206 .45196 .2697 .46354 .26546 .45692 .25778 Mtetra
.45692 .25778 .46354 .26546 .47517 .26121 .46858 .2535 Mtetra
.658 .753 .92 r
.46858 .2535 .47517 .26121 .48684 .25696 .48029 .2492 Mtetra
.48029 .2492 .48684 .25696 .49857 .25268 .49204 .2449 Mtetra
.49204 .2449 .49857 .25268 .51034 .2484 .50385 .24058 Mtetra
.50385 .24058 .51034 .2484 .52217 .2441 .51571 .23624 Mtetra
.51571 .23624 .52217 .2441 .53405 .23979 .52762 .23189 Mtetra
.52762 .23189 .53405 .23979 .54597 .23546 .53958 .22753 Mtetra
.53958 .22753 .54597 .23546 .55795 .23111 .5516 .22314 Mtetra
.657 .753 .92 r
.5516 .22314 .55795 .23111 .56998 .22675 .56366 .21874 Mtetra
.56366 .21874 .56998 .22675 .58206 .22237 .57578 .21433 Mtetra
.57578 .21433 .58206 .22237 .5942 .21797 .58795 .20989 Mtetra
.657 .752 .92 r
.58795 .20989 .5942 .21797 .60639 .21355 .60017 .20544 Mtetra
.60017 .20544 .60639 .21355 .61863 .20912 .61245 .20097 Mtetra
.61245 .20097 .61863 .20912 .63092 .20467 .62478 .19648 Mtetra
.62478 .19648 .63092 .20467 .64327 .20019 .63717 .19197 Mtetra
.63717 .19197 .64327 .20019 .65567 .1957 .64961 .18745 Mtetra
.64961 .18745 .65567 .1957 .66813 .1912 .6621 .1829 Mtetra
.6621 .1829 .66813 .1912 .68064 .18667 .67465 .17834 Mtetra
.67465 .17834 .68064 .18667 .69321 .18212 .68726 .17375 Mtetra
.68726 .17375 .69321 .18212 .70583 .17756 .69992 .16915 Mtetra
.69992 .16915 .70583 .17756 .71851 .17297 .71264 .16452 Mtetra
.71264 .16452 .71851 .17297 .73125 .16836 .72541 .15988 Mtetra
.769 .973 .695 r
.04929 .40301 .05903 .39539 .06814 .39803 .06069 .39005 Mtetra
.561 .682 .921 r
.06069 .39005 .06814 .39803 .07795 .39607 .07046 .38849 Mtetra
.542 .688 .934 r
.07046 .38849 .07795 .39607 .08653 .40358 .08024 .3872 Mtetra
.734 .609 .718 r
.08024 .3872 .08653 .40358 .09853 .3861 .09142 .37599 Mtetra
.45 .574 .887 r
.09142 .37599 .09853 .3861 .10846 .38423 .10102 .37669 Mtetra
.591 .71 .926 r
.10102 .37669 .10846 .38423 .11843 .38246 .11106 .37445 Mtetra
.308 .566 .929 r
.11106 .37445 .11843 .38246 .12995 .36855 .12063 .37633 Mtetra
.693 .939 .645 r
.12063 .37633 .12995 .36855 .13934 .37209 .13203 .36393 Mtetra
.569 .684 .918 r
.13203 .36393 .13934 .37209 .14952 .36967 .14214 .36215 Mtetra
.6 .716 .926 r
.14214 .36215 .14952 .36967 .15967 .36791 .15239 .35968 Mtetra
.117 .448 .882 r
.15239 .35968 .15967 .36791 .17105 .35563 .16196 .36357 Mtetra
.77 .96 .65 r
.16196 .36357 .17105 .35563 .18092 .3571 .17367 .34901 Mtetra
.583 .694 .918 r
.17367 .34901 .18092 .3571 .19131 .35441 .18401 .34689 Mtetra
.614 .723 .924 r
.18401 .34689 .19131 .35441 .20172 .35186 .19447 .34406 Mtetra
.545 .69 .934 r
.19447 .34406 .20172 .35186 .2098 .37357 .20484 .34263 Mtetra
.659 .492 .647 r
.20484 .34263 .2098 .37357 .22325 .34109 .21622 .33153 Mtetra
.516 .627 .899 r
.21622 .33153 .22325 .34109 .2338 .33856 .2266 .33092 Mtetra
.62 .725 .921 r
.2266 .33092 .2338 .33856 .24446 .33543 .23726 .32789 Mtetra
.624 .731 .923 r
.23726 .32789 .24446 .33543 .25513 .33258 .24799 .32475 Mtetra
.569 .702 .931 r
.24799 .32475 .25513 .33258 .26502 .33999 .25866 .32281 Mtetra
.737 .61 .716 r
.25866 .32281 .26502 .33999 .27707 .32139 .27019 .31096 Mtetra
.487 .593 .885 r
.27019 .31096 .27707 .32139 .28786 .3188 .28078 .31104 Mtetra
.626 .728 .92 r
.28078 .31104 .28786 .3188 .29877 .31538 .2917 .30782 Mtetra
.639 .739 .921 r
.2917 .30782 .29877 .31538 .30973 .31182 .30268 .30426 Mtetra
.64 .74 .922 r
.30268 .30426 .30973 .31182 .32074 .30832 .31372 .30066 Mtetra
.63 .735 .923 r
.31372 .30066 .32074 .30832 .33175 .30541 .32479 .29728 Mtetra
.533 .683 .935 r
.32479 .29728 .33175 .30541 .34706 .22975 .33578 .29601 Mtetra
.402 .133 .387 r
.33578 .29601 .34706 .22975 .35427 .29377 .34742 .28454 Mtetra
.562 .664 .906 r
.34742 .28454 .35427 .29377 .36544 .29065 .35853 .28282 Mtetra
.637 .735 .92 r
.35853 .28282 .36544 .29065 .37669 .28689 .3698 .27922 Mtetra
.648 .745 .92 r
.3698 .27922 .37669 .28689 .388 .28294 .38114 .2753 Mtetra
.653 .749 .92 r
.38114 .2753 .388 .28294 .39936 .27887 .39253 .27125 Mtetra
.656 .751 .92 r
.39253 .27125 .39936 .27887 .41077 .27474 .40397 .26711 Mtetra
.657 .752 .92 r
.40397 .26711 .41077 .27474 .42224 .27055 .41547 .2629 Mtetra
.658 .753 .92 r
.41547 .2629 .42224 .27055 .43375 .26631 .42701 .25864 Mtetra
.659 .754 .92 r
.42701 .25864 .43375 .26631 .44531 .26206 .4386 .25436 Mtetra
.4386 .25436 .44531 .26206 .45692 .25778 .45024 .25005 Mtetra
.45024 .25005 .45692 .25778 .46858 .2535 .46193 .24573 Mtetra
.46193 .24573 .46858 .2535 .48029 .2492 .47368 .24139 Mtetra
.658 .753 .92 r
.47368 .24139 .48029 .2492 .49204 .2449 .48547 .23705 Mtetra
.48547 .23705 .49204 .2449 .50385 .24058 .49731 .23269 Mtetra
.49731 .23269 .50385 .24058 .51571 .23624 .5092 .22832 Mtetra
.5092 .22832 .51571 .23624 .52762 .23189 .52114 .22393 Mtetra
.52114 .22393 .52762 .23189 .53958 .22753 .53314 .21953 Mtetra
.53314 .21953 .53958 .22753 .5516 .22314 .54519 .21511 Mtetra
.657 .753 .92 r
.54519 .21511 .5516 .22314 .56366 .21874 .55729 .21068 Mtetra
.55729 .21068 .56366 .21874 .57578 .21433 .56944 .20622 Mtetra
.56944 .20622 .57578 .21433 .58795 .20989 .58165 .20175 Mtetra
.657 .752 .92 r
.58165 .20175 .58795 .20989 .60017 .20544 .59391 .19726 Mtetra
.59391 .19726 .60017 .20544 .61245 .20097 .60622 .19276 Mtetra
.60622 .19276 .61245 .20097 .62478 .19648 .61859 .18823 Mtetra
.61859 .18823 .62478 .19648 .63717 .19197 .63101 .18369 Mtetra
.63101 .18369 .63717 .19197 .64961 .18745 .64349 .17912 Mtetra
.64349 .17912 .64961 .18745 .6621 .1829 .65602 .17454 Mtetra
.65602 .17454 .6621 .1829 .67465 .17834 .66861 .16994 Mtetra
.66861 .16994 .67465 .17834 .68726 .17375 .68125 .16531 Mtetra
.68125 .16531 .68726 .17375 .69992 .16915 .69396 .16067 Mtetra
.69396 .16067 .69992 .16915 .71264 .16452 .70671 .15601 Mtetra
.70671 .15601 .71264 .16452 .72541 .15988 .71953 .15132 Mtetra
.783 .672 .742 r
.04236 .39097 .04929 .40301 .06069 .39005 .05375 .3783 Mtetra
.35 .479 .849 r
.05375 .3783 .06069 .39005 .07046 .38849 .06292 .38089 Mtetra
.58 .703 .927 r
.06292 .38089 .07046 .38849 .08024 .3872 .07281 .37888 Mtetra
0 .119 .637 r
.07281 .37888 .08024 .3872 .09142 .37599 .08144 .38635 Mtetra
.822 .958 .624 r
.08144 .38635 .09142 .37599 .10102 .37669 .09357 .36875 Mtetra
.576 .693 .921 r
.09357 .36875 .10102 .37669 .11106 .37445 .10358 .36682 Mtetra
.568 .701 .931 r
.10358 .36682 .11106 .37445 .12063 .37633 .11363 .36499 Mtetra
.804 .691 .741 r
.11363 .36499 .12063 .37633 .13203 .36393 .12527 .35096 Mtetra
.32 .437 .824 r
.12527 .35096 .13203 .36393 .14214 .36215 .13473 .35447 Mtetra
.6 .713 .923 r
.13473 .35447 .14214 .36215 .15239 .35968 .14499 .35197 Mtetra
.566 .7 .932 r
.14499 .35197 .15239 .35968 .16196 .36357 .15523 .35015 Mtetra
.771 .659 .738 r
.15523 .35015 .16196 .36357 .17367 .34901 .16672 .33776 Mtetra
.42 .535 .867 r
.16672 .33776 .17367 .34901 .18401 .34689 .17667 .33919 Mtetra
.61 .718 .922 r
.17667 .33919 .18401 .34689 .19447 .34406 .18714 .33643 Mtetra
.603 .719 .926 r
.18714 .33643 .19447 .34406 .20484 .34263 .19765 .33381 Mtetra
.876 .453 .037 r
.19765 .33381 .20484 .34263 .21622 .33153 .20577 .35554 Mtetra
.699 .787 .31 r
.20577 .35554 .21622 .33153 .2266 .33092 .21938 .32287 Mtetra
.601 .708 .919 r
.21938 .32287 .2266 .33092 .23726 .32789 .23002 .32027 Mtetra
.626 .731 .922 r
.23002 .32027 .23726 .32789 .24799 .32475 .24077 .31707 Mtetra
.613 .725 .925 r
.24077 .31707 .24799 .32475 .25866 .32281 .25154 .31415 Mtetra
0 .222 .734 r
.25154 .31415 .25866 .32281 .27019 .31096 .2615 .32152 Mtetra
.754 .911 .532 r
.2615 .32152 .27019 .31096 .28078 .31104 .27369 .30279 Mtetra
.601 .706 .917 r
.27369 .30279 .28078 .31104 .2917 .30782 .28457 .30013 Mtetra
.635 .735 .921 r
.28457 .30013 .2917 .30782 .30268 .30426 .29558 .29664 Mtetra
.64 .74 .921 r
.29558 .29664 .30268 .30426 .31372 .30066 .30664 .293 Mtetra
.637 .739 .922 r
.30664 .293 .31372 .30066 .32479 .29728 .31775 .28942 Mtetra
.612 .725 .926 r
.31775 .28942 .32479 .29728 .33578 .29601 .32887 .28643 Mtetra
.949 .718 .556 r
.32887 .28643 .33578 .29601 .34742 .28454 .34439 .21044 Mtetra
0 0 .34 r
.34439 .21044 .34742 .28454 .35853 .28282 .3516 .27463 Mtetra
.62 .72 .918 r
.3516 .27463 .35853 .28282 .3698 .27922 .36287 .27142 Mtetra
.644 .742 .92 r
.36287 .27142 .3698 .27922 .38114 .2753 .37423 .26758 Mtetra
.651 .747 .92 r
.37423 .26758 .38114 .2753 .39253 .27125 .38565 .26355 Mtetra
.654 .75 .92 r
.38565 .26355 .39253 .27125 .40397 .26711 .39712 .2594 Mtetra
.657 .752 .92 r
.39712 .2594 .40397 .26711 .41547 .2629 .40864 .25518 Mtetra
.658 .753 .92 r
.40864 .25518 .41547 .2629 .42701 .25864 .42022 .25091 Mtetra
.659 .754 .92 r
.42022 .25091 .42701 .25864 .4386 .25436 .43184 .24659 Mtetra
.43184 .24659 .4386 .25436 .45024 .25005 .44351 .24225 Mtetra
.44351 .24225 .45024 .25005 .46193 .24573 .45524 .23789 Mtetra
.45524 .23789 .46193 .24573 .47368 .24139 .46701 .23352 Mtetra
.658 .753 .92 r
.46701 .23352 .47368 .24139 .48547 .23705 .47884 .22914 Mtetra
.47884 .22914 .48547 .23705 .49731 .23269 .49071 .22474 Mtetra
.49071 .22474 .49731 .23269 .5092 .22832 .50264 .22033 Mtetra
.50264 .22033 .5092 .22832 .52114 .22393 .51461 .21591 Mtetra
.51461 .21591 .52114 .22393 .53314 .21953 .52664 .21147 Mtetra
.52664 .21147 .53314 .21953 .54519 .21511 .53873 .20702 Mtetra
.53873 .20702 .54519 .21511 .55729 .21068 .55086 .20254 Mtetra
.657 .753 .92 r
.55086 .20254 .55729 .21068 .56944 .20622 .56305 .19805 Mtetra
.56305 .19805 .56944 .20622 .58165 .20175 .57529 .19355 Mtetra
.57529 .19355 .58165 .20175 .59391 .19726 .58759 .18902 Mtetra
.657 .752 .92 r
.58759 .18902 .59391 .19726 .60622 .19276 .59994 .18448 Mtetra
.59994 .18448 .60622 .19276 .61859 .18823 .61234 .17991 Mtetra
.61234 .17991 .61859 .18823 .63101 .18369 .6248 .17533 Mtetra
.6248 .17533 .63101 .18369 .64349 .17912 .63732 .17073 Mtetra
.63732 .17073 .64349 .17912 .65602 .17454 .64989 .16611 Mtetra
.64989 .16611 .65602 .17454 .66861 .16994 .66252 .16146 Mtetra
.66252 .16146 .66861 .16994 .68125 .16531 .6752 .1568 Mtetra
.6752 .1568 .68125 .16531 .69396 .16067 .68794 .15212 Mtetra
.68794 .15212 .69396 .16067 .70671 .15601 .70074 .14742 Mtetra
.70074 .14742 .70671 .15601 .71953 .15132 .7136 .1427 Mtetra
.18 .493 .904 r
.0348 .38286 .04236 .39097 .05375 .3783 .04387 .38585 Mtetra
.775 .976 .702 r
.04387 .38585 .05375 .3783 .06292 .38089 .05538 .37278 Mtetra
.56 .682 .921 r
.05538 .37278 .06292 .38089 .07281 .37888 .06523 .37116 Mtetra
.542 .688 .934 r
.06523 .37116 .07281 .37888 .08144 .38635 .07509 .36981 Mtetra
.735 .61 .718 r
.07509 .36981 .08144 .38635 .09357 .36875 .08638 .3585 Mtetra
.449 .574 .887 r
.08638 .3585 .09357 .36875 .10358 .36682 .09605 .35915 Mtetra
.591 .71 .926 r
.09605 .35915 .10358 .36682 .11363 .36499 .10617 .35684 Mtetra
.31 .567 .929 r
.10617 .35684 .11363 .36499 .12527 .35096 .11581 .35867 Mtetra
.702 .945 .654 r
.11581 .35867 .12527 .35096 .13473 .35447 .12733 .34616 Mtetra
.569 .684 .918 r
.12733 .34616 .13473 .35447 .14499 .35197 .13753 .34432 Mtetra
.6 .716 .926 r
.13753 .34432 .14499 .35197 .15523 .35015 .14786 .34178 Mtetra
.121 .45 .883 r
.14786 .34178 .15523 .35015 .16672 .33776 .15751 .34563 Mtetra
.777 .963 .657 r
.15751 .34563 .16672 .33776 .17667 .33919 .16933 .33095 Mtetra
.583 .695 .918 r
.16933 .33095 .17667 .33919 .18714 .33643 .17976 .32877 Mtetra
.614 .723 .924 r
.17976 .32877 .18714 .33643 .19765 .33381 .19031 .32587 Mtetra
.545 .69 .934 r
.19031 .32587 .19765 .33381 .20577 .35554 .20078 .32437 Mtetra
.658 .491 .646 r
.20078 .32437 .20577 .35554 .21938 .32287 .21226 .31317 Mtetra
.516 .627 .899 r
.21226 .31317 .21938 .32287 .23002 .32027 .22273 .31249 Mtetra
.62 .725 .921 r
.22273 .31249 .23002 .32027 .24077 .31707 .23349 .30939 Mtetra
.624 .731 .923 r
.23349 .30939 .24077 .31707 .25154 .31415 .24431 .30618 Mtetra
.569 .702 .931 r
.24431 .30618 .25154 .31415 .2615 .32152 .25508 .30417 Mtetra
.738 .61 .716 r
.25508 .30417 .2615 .32152 .27369 .30279 .26672 .29221 Mtetra
.486 .593 .885 r
.26672 .29221 .27369 .30279 .28457 .30013 .27741 .29222 Mtetra
.626 .728 .92 r
.27741 .29222 .28457 .30013 .29558 .29664 .28842 .28893 Mtetra
.639 .739 .921 r
.28842 .28893 .29558 .29664 .30664 .293 .29951 .28529 Mtetra
.64 .74 .922 r
.29951 .28529 .30664 .293 .31775 .28942 .31065 .28162 Mtetra
.63 .735 .923 r
.31065 .28162 .31775 .28942 .32887 .28643 .32182 .27816 Mtetra
.533 .683 .934 r
.32182 .27816 .32887 .28643 .34439 .21044 .33292 .27681 Mtetra
.395 .124 .38 r
.33292 .27681 .34439 .21044 .3516 .27463 .34467 .26523 Mtetra
.561 .664 .906 r
.34467 .26523 .3516 .27463 .36287 .27142 .35589 .26344 Mtetra
.637 .735 .92 r
.35589 .26344 .36287 .27142 .37423 .26758 .36727 .25976 Mtetra
.648 .745 .92 r
.36727 .25976 .37423 .26758 .38565 .26355 .37871 .25576 Mtetra
.653 .749 .92 r
.37871 .25576 .38565 .26355 .39712 .2594 .39021 .25162 Mtetra
.656 .751 .92 r
.39021 .25162 .39712 .2594 .40864 .25518 .40176 .2474 Mtetra
.657 .752 .92 r
.40176 .2474 .40864 .25518 .42022 .25091 .41337 .2431 Mtetra
.658 .753 .92 r
.41337 .2431 .42022 .25091 .43184 .24659 .42502 .23876 Mtetra
.659 .754 .92 r
.42502 .23876 .43184 .24659 .44351 .24225 .43673 .23439 Mtetra
.43673 .23439 .44351 .24225 .45524 .23789 .44849 .22999 Mtetra
.44849 .22999 .45524 .23789 .46701 .23352 .46029 .22558 Mtetra
.46029 .22558 .46701 .23352 .47884 .22914 .47215 .22116 Mtetra
.658 .753 .92 r
.47215 .22116 .47884 .22914 .49071 .22474 .48406 .21673 Mtetra
.48406 .21673 .49071 .22474 .50264 .22033 .49602 .21228 Mtetra
.49602 .21228 .50264 .22033 .51461 .21591 .50803 .20782 Mtetra
.50803 .20782 .51461 .21591 .52664 .21147 .5201 .20335 Mtetra
.5201 .20335 .52664 .21147 .53873 .20702 .53221 .19885 Mtetra
.53221 .19885 .53873 .20702 .55086 .20254 .54438 .19435 Mtetra
.657 .753 .92 r
.54438 .19435 .55086 .20254 .56305 .19805 .55661 .18982 Mtetra
.55661 .18982 .56305 .19805 .57529 .19355 .56889 .18527 Mtetra
.56889 .18527 .57529 .19355 .58759 .18902 .58122 .18071 Mtetra
.657 .752 .92 r
.58122 .18071 .58759 .18902 .59994 .18448 .59361 .17613 Mtetra
.59361 .17613 .59994 .18448 .61234 .17991 .60605 .17152 Mtetra
.60605 .17152 .61234 .17991 .6248 .17533 .61855 .1669 Mtetra
.61855 .1669 .6248 .17533 .63732 .17073 .6311 .16226 Mtetra
.6311 .16226 .63732 .17073 .64989 .16611 .64371 .1576 Mtetra
.64371 .1576 .64989 .16611 .66252 .16146 .65637 .15292 Mtetra
.65637 .15292 .66252 .16146 .6752 .1568 .6691 .14822 Mtetra
.6691 .14822 .6752 .1568 .68794 .15212 .68188 .1435 Mtetra
.68188 .1435 .68794 .15212 .70074 .14742 .69472 .13876 Mtetra
.69472 .13876 .70074 .14742 .7136 .1427 .70761 .134 Mtetra
.549 .69 .932 r
.02711 .37514 .0348 .38286 .04387 .38585 .03687 .37366 Mtetra
.783 .673 .742 r
.03687 .37366 .04387 .38585 .05538 .37278 .04836 .36088 Mtetra
.348 .478 .849 r
.04836 .36088 .05538 .37278 .06523 .37116 .0576 .36343 Mtetra
.58 .703 .927 r
.0576 .36343 .06523 .37116 .07509 .36981 .06757 .36135 Mtetra
0 .124 .643 r
.06757 .36135 .07509 .36981 .08638 .3585 .07625 .3688 Mtetra
.827 .961 .63 r
.07625 .3688 .08638 .3585 .09605 .35915 .08851 .35107 Mtetra
.576 .693 .921 r
.08851 .35107 .09605 .35915 .10617 .35684 .09861 .34907 Mtetra
.568 .701 .931 r
.09861 .34907 .10617 .35684 .11581 .35867 .10874 .34718 Mtetra
.804 .692 .741 r
.10874 .34718 .11581 .35867 .12733 .34616 .12049 .33304 Mtetra
.319 .436 .824 r
.12049 .33304 .12733 .34616 .13753 .34432 .13002 .3365 Mtetra
.6 .713 .923 r
.13002 .3365 .13753 .34432 .14786 .34178 .14038 .33394 Mtetra
.566 .7 .932 r
.14038 .33394 .14786 .34178 .15751 .34563 .1507 .33205 Mtetra
.772 .659 .738 r
.1507 .33205 .15751 .34563 .16933 .33095 .1623 .31955 Mtetra
.419 .535 .867 r
.1623 .31955 .16933 .33095 .17976 .32877 .17233 .32092 Mtetra
.61 .718 .922 r
.17233 .32092 .17976 .32877 .19031 .32587 .1829 .31809 Mtetra
.603 .719 .926 r
.1829 .31809 .19031 .32587 .20078 .32437 .1935 .3154 Mtetra
.873 .449 .028 r
.1935 .3154 .20078 .32437 .21226 .31317 .20165 .33716 Mtetra
.708 .794 .319 r
.20165 .33716 .21226 .31317 .22273 .31249 .21543 .3043 Mtetra
.601 .708 .919 r
.21543 .3043 .22273 .31249 .23349 .30939 .22616 .30163 Mtetra
.626 .731 .922 r
.22616 .30163 .23349 .30939 .24431 .30618 .23701 .29835 Mtetra
.613 .725 .925 r
.23701 .29835 .24431 .30618 .25508 .30417 .24788 .29536 Mtetra
0 .226 .737 r
.24788 .29536 .25508 .30417 .26672 .29221 .25792 .3027 Mtetra
.761 .915 .54 r
.25792 .3027 .26672 .29221 .27741 .29222 .27023 .28382 Mtetra
.601 .706 .917 r
.27023 .28382 .27741 .29222 .28842 .28893 .28122 .28109 Mtetra
.635 .735 .921 r
.28122 .28109 .28842 .28893 .29951 .28529 .29232 .27752 Mtetra
.64 .74 .921 r
.29232 .27752 .29951 .28529 .31065 .28162 .30349 .2738 Mtetra
.637 .739 .922 r
.30349 .2738 .31065 .28162 .32182 .27816 .3147 .27014 Mtetra
.612 .725 .926 r
.3147 .27014 .32182 .27816 .33292 .27681 .32592 .26707 Mtetra
.95 .718 .554 r
.32592 .26707 .33292 .27681 .34467 .26523 .34166 .19075 Mtetra
0 0 .335 r
.34166 .19075 .34467 .26523 .35589 .26344 .34887 .25509 Mtetra
.62 .72 .918 r
.34887 .25509 .35589 .26344 .36727 .25976 .36025 .25181 Mtetra
.644 .742 .92 r
.36025 .25181 .36727 .25976 .37871 .25576 .37172 .24789 Mtetra
.651 .747 .92 r
.37172 .24789 .37871 .25576 .39021 .25162 .38325 .24376 Mtetra
.654 .75 .92 r
.38325 .24376 .39021 .25162 .40176 .2474 .39483 .23953 Mtetra
.657 .752 .92 r
.39483 .23953 .40176 .2474 .41337 .2431 .40647 .23523 Mtetra
.658 .753 .92 r
.40647 .23523 .41337 .2431 .42502 .23876 .41815 .23087 Mtetra
.659 .754 .92 r
.41815 .23087 .42502 .23876 .43673 .23439 .42989 .22646 Mtetra
.42989 .22646 .43673 .23439 .44849 .22999 .44168 .22203 Mtetra
.44168 .22203 .44849 .22999 .46029 .22558 .45352 .21759 Mtetra
.45352 .21759 .46029 .22558 .47215 .22116 .46541 .21313 Mtetra
.658 .753 .92 r
.46541 .21313 .47215 .22116 .48406 .21673 .47736 .20866 Mtetra
.47736 .20866 .48406 .21673 .49602 .21228 .48935 .20417 Mtetra
.48935 .20417 .49602 .21228 .50803 .20782 .5014 .19967 Mtetra
.5014 .19967 .50803 .20782 .5201 .20335 .5135 .19516 Mtetra
.5135 .19516 .5201 .20335 .53221 .19885 .52565 .19063 Mtetra
.52565 .19063 .53221 .19885 .54438 .19435 .53785 .18608 Mtetra
.53785 .18608 .54438 .19435 .55661 .18982 .55011 .18151 Mtetra
.657 .753 .92 r
.55011 .18151 .55661 .18982 .56889 .18527 .56243 .17693 Mtetra
.56243 .17693 .56889 .18527 .58122 .18071 .5748 .17233 Mtetra
.5748 .17233 .58122 .18071 .59361 .17613 .58722 .16771 Mtetra
.657 .752 .92 r
.58722 .16771 .59361 .17613 .60605 .17152 .5997 .16307 Mtetra
.5997 .16307 .60605 .17152 .61855 .1669 .61224 .15841 Mtetra
.61224 .15841 .61855 .1669 .6311 .16226 .62483 .15373 Mtetra
.62483 .15373 .6311 .16226 .64371 .1576 .63747 .14903 Mtetra
.63747 .14903 .64371 .1576 .65637 .15292 .65018 .14431 Mtetra
.65018 .14431 .65637 .15292 .6691 .14822 .66294 .13957 Mtetra
.66294 .13957 .6691 .14822 .68188 .1435 .67576 .13481 Mtetra
.67576 .13481 .68188 .1435 .69472 .13876 .68864 .13003 Mtetra
.68864 .13003 .69472 .13876 .70761 .134 .70158 .12523 Mtetra
.567 .693 .925 r
.0194 .36723 .02711 .37514 .03687 .37366 .02921 .36542 Mtetra
.183 .494 .904 r
.02921 .36542 .03687 .37366 .04836 .36088 .03835 .36836 Mtetra
.781 .979 .708 r
.03835 .36836 .04836 .36088 .0576 .36343 .04998 .35518 Mtetra
.56 .682 .921 r
.04998 .35518 .0576 .36343 .06757 .36135 .0599 .3535 Mtetra
.542 .688 .934 r
.0599 .3535 .06757 .36135 .07625 .3688 .06984 .35209 Mtetra
.735 .61 .718 r
.06984 .35209 .07625 .3688 .08851 .35107 .08124 .34067 Mtetra
.449 .574 .887 r
.08124 .34067 .08851 .35107 .09861 .34907 .09098 .34127 Mtetra
.591 .71 .926 r
.09098 .34127 .09861 .34907 .10874 .34718 .10119 .33889 Mtetra
.311 .567 .929 r
.10119 .33889 .10874 .34718 .12049 .33304 .11091 .34067 Mtetra
.711 .95 .663 r
.11091 .34067 .12049 .33304 .13002 .3365 .12254 .32805 Mtetra
.569 .684 .918 r
.12254 .32805 .13002 .3365 .14038 .33394 .13282 .32615 Mtetra
.6 .716 .926 r
.13282 .32615 .14038 .33394 .1507 .33205 .14325 .32354 Mtetra
.124 .451 .884 r
.14325 .32354 .1507 .33205 .1623 .31955 .15296 .32734 Mtetra
.783 .966 .664 r
.15296 .32734 .1623 .31955 .17233 .32092 .16491 .31254 Mtetra
.583 .695 .918 r
.16491 .31254 .17233 .32092 .1829 .31809 .17543 .31029 Mtetra
.614 .723 .924 r
.17543 .31029 .1829 .31809 .1935 .3154 .18608 .30732 Mtetra
.545 .69 .934 r
.18608 .30732 .1935 .3154 .20165 .33716 .19663 .30576 Mtetra
.658 .49 .645 r
.19663 .30576 .20165 .33716 .21543 .3043 .20823 .29444 Mtetra
.515 .627 .9 r
.20823 .29444 .21543 .3043 .22616 .30163 .21879 .2937 Mtetra
.62 .725 .921 r
.21879 .2937 .22616 .30163 .23701 .29835 .22965 .29052 Mtetra
.624 .731 .923 r
.22965 .29052 .23701 .29835 .24788 .29536 .24056 .28724 Mtetra
.569 .702 .931 r
.24056 .28724 .24788 .29536 .25792 .3027 .25142 .28515 Mtetra
.738 .611 .716 r
.25142 .28515 .25792 .3027 .27023 .28382 .26319 .27308 Mtetra
.486 .593 .886 r
.26319 .27308 .27023 .28382 .28122 .28109 .27397 .27303 Mtetra
.626 .728 .92 r
.27397 .27303 .28122 .28109 .29232 .27752 .28508 .26966 Mtetra
.639 .739 .921 r
.28508 .26966 .29232 .27752 .30349 .2738 .29627 .26594 Mtetra
.64 .74 .922 r
.29627 .26594 .30349 .2738 .3147 .27014 .30752 .26219 Mtetra
.63 .735 .923 r
.30752 .26219 .3147 .27014 .32592 .26707 .3188 .25865 Mtetra
.533 .683 .934 r
.3188 .25865 .32592 .26707 .34166 .19075 .32999 .25723 Mtetra
.389 .115 .373 r
.32999 .25723 .34166 .19075 .34887 .25509 .34187 .24554 Mtetra
.561 .664 .906 r
.34187 .24554 .34887 .25509 .36025 .25181 .35319 .24367 Mtetra
.637 .735 .92 r
.35319 .24367 .36025 .25181 .37172 .24789 .36468 .23991 Mtetra
.648 .745 .92 r
.36468 .23991 .37172 .24789 .38325 .24376 .37623 .23582 Mtetra
.653 .749 .92 r
.37623 .23582 .38325 .24376 .39483 .23953 .38784 .2316 Mtetra
.656 .751 .92 r
.38784 .2316 .39483 .23953 .40647 .23523 .39951 .22728 Mtetra
.657 .752 .92 r
.39951 .22728 .40647 .23523 .41815 .23087 .41123 .2229 Mtetra
.658 .753 .92 r
.41123 .2229 .41815 .23087 .42989 .22646 .423 .21847 Mtetra
.659 .754 .92 r
.423 .21847 .42989 .22646 .44168 .22203 .43482 .21401 Mtetra
.43482 .21401 .44168 .22203 .45352 .21759 .44669 .20953 Mtetra
.44669 .20953 .45352 .21759 .46541 .21313 .45862 .20503 Mtetra
.45862 .20503 .46541 .21313 .47736 .20866 .4706 .20052 Mtetra
.658 .753 .92 r
.4706 .20052 .47736 .20866 .48935 .20417 .48262 .19599 Mtetra
.48262 .19599 .48935 .20417 .5014 .19967 .49471 .19145 Mtetra
.49471 .19145 .5014 .19967 .5135 .19516 .50684 .1869 Mtetra
.50684 .1869 .5135 .19516 .52565 .19063 .51903 .18233 Mtetra
.51903 .18233 .52565 .19063 .53785 .18608 .53127 .17775 Mtetra
.53127 .17775 .53785 .18608 .55011 .18151 .54357 .17314 Mtetra
.657 .753 .92 r
.54357 .17314 .55011 .18151 .56243 .17693 .55592 .16852 Mtetra
.55592 .16852 .56243 .17693 .5748 .17233 .56832 .16388 Mtetra
.56832 .16388 .5748 .17233 .58722 .16771 .58078 .15922 Mtetra
.657 .752 .92 r
.58078 .15922 .58722 .16771 .5997 .16307 .5933 .15454 Mtetra
.5933 .15454 .5997 .16307 .61224 .15841 .60587 .14984 Mtetra
.60587 .14984 .61224 .15841 .62483 .15373 .6185 .14512 Mtetra
.6185 .14512 .62483 .15373 .63747 .14903 .63119 .14039 Mtetra
.63119 .14039 .63747 .14903 .65018 .14431 .64393 .13563 Mtetra
.64393 .13563 .65018 .14431 .66294 .13957 .65674 .13085 Mtetra
.65674 .13085 .66294 .13957 .67576 .13481 .6696 .12605 Mtetra
.6696 .12605 .67576 .13481 .68864 .13003 .68251 .12122 Mtetra
.68251 .12122 .68864 .13003 .70158 .12523 .69549 .11638 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05eoo`0GD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBo@0GOol00`00
Oomoo`17Ool008Moo`<006=oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aB
o5;mD_`005;lD_d00U;l5goo00<007ooOol0AWoo0025Ool2001ROol085;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_dFOol00`00Oomoo`16
Ool0089oo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`00e;mD_aoo`0FOol00`00Oomoo`15Ool0081oo`8006=oo`0UD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_`05goo00<007ooOol0A7oo001mOol3001QOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo003D_eB
o7oo01Eoo`03001oogoo04Aoo`00Ngoo0P000Woo00<007ooOol0GGoo02aBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;m5goo00<007ooOol0@goo001hOol3001ROol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@0GOol00`00Oomoo`12Ool007Ioo`80065oo`0dD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`12Ool007=oo`<0065oo`9Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo004D_eBo5;lD_`GOol00`00Oomoo`11Ool0075o
o`80069oo`0iD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;l01Eoo`03001oo`00049oo`00KWoo0`00H7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomoo`10Ool006]oo`<0065o
o`11D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0oOol006Uoo`8000=oo`03001oogoo05]oo`03D_aBoE;l
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;m
D_aBo5;lD_d00e;l5Goo00<007ooOol0?goo001VOol3001OOol0BE;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m01Ioo`03001oogoo03ioo`00I7oo0P00H7oo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aB
o5;lD_d00U;l5Woo00<007ooOol0?Goo001QOol3001POol0Ce;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m01Eoo`03001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P00Ggoo00=Bo5;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007oo
Ool09Woo00<007ooOol04goo000dOol00`00Oomoo`02Ool00`00Oomoo`0POol3001POol0EE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo02Eo
o`03001oogoo01=oo`00>Goo00<007ooOol07Woo0P000Woo00<007ooOol0G7oo0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Eoo`03001oogoo02Ao
o`03001oo`0001Aoo`00;7oo1P001goo00<007ooOol06goo0`00<goo00</BWooOol0:Goo05aBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
5Woo00<007ooOol08goo00<007oo000057oo000eOol4000LOol2000fOol00c1[;4]oo`0WOol2D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@0FOol00`00Oomoo`0QOol01@00Oomoogoo00004goo000eOol00`00Oomoo`0JOol3000h
Ool00ba;<6]oo`0UOol0HU;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol2000SOol01@00Oomoogoo00004goo000e
Ool00`00Oomoo`0GOol3000kOol2;6/ROol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<0
07ooOol07goo0`0000Aoo`000000019oo`00=Goo1@004goo0P00?Woo00</BS1[Ool07goo06UBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol0=goo001:Ool300000goo001oo`0l
Ool00d:m<6//B`0NOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<0
07ooOol027oo1000:goo0018Ool20012Ool00c1[;4/`J`0JOol0L5;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0
:7oo0015Ool30014Ool00ba;;6//J`0HOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0:7oo0013
Ool20017Ool0131[;4X`Jba;5Goo07EBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0:7oo0010
Ool30019Ool012a[<6//Bba[4Goo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol0:7oo000nOol2001;Ool01D:L<6//Bc1[;4X03Goo07mBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003]oo`@004aoo`05<6//Bba[;6/`J`0<Ool3
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo01Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00
>Goo0P0017oo00<007ooOol0BGoo00D/Bc1[;4X`Jba;00Yoo`24D_eBo5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l5Goo00<007ooOol00goo1000:goo000fOol3001BOol2;6/00c1[;4//J`06Ool01DklD_aBo5;m
C_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo015oo`800003Ool007oo039oo`00<goo0`00EGoo
00D/BS1[;4/`Jba:009oo`2=D_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
01Eoo`03001oogoo035oo`00<Goo0P00Egoo00A2_C1[;4//J`E6W006D_e>g4klC]aBoDkl0U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d00000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0`Ool002ioo`<005Uoo`05@[d/Bc1[
M[1jd@02AY`0L4:KA[a>g5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0`0001eB
oE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Eo
o`03001oogoo02moo`00;7oo1000FWoo00H/Bba[M]5jdGK@00X4AY`01TklD_e>g5;lC_aBo@=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_d00000001Bo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol0;goo000ZOol2001NOol0LC1[M[1jdGK@
N]402@0:B]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d00`0002ABoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol0
0`00Oomoo`0^Ool002Yoo`8005ioo`03M]5jdGK@009fd@0500X02@0:C]a>g@02C]`00dklD_e>g002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006
D_eBo5;lD_aBoE;l0P0000EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Goo00<007ooOol0;Woo000@Ool50003
Ool40004Ool40006Ool00`00Ool0001HOol0LDkLD_e>g4:mM[1jdGK@N]5f/7[A00T02P09C]e:g4kM
B]a>gDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`00`0002YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0]Ool0
019oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool200000goo
001oo`1DOol024kmC]a>oDkLC_e2_G[AM]02M]400g[AM]002P0200X02@09C_a>g5;mC]a>o5;lD_e>
o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`3
0003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Eoo`03001oogoo02aoo`004Woo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`8000=oo`03001oogoo04io
o`0BC]aBoDkLD_e>g5;mC]a>oDkLD_efd7[AM[1jdGK@N]52VdJl0TJL05e2Ve;mC]aBoDkLD_e>o5;m
C]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`00039Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol0;7oo0007Ool60005
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol0BWoo015>g4klC_aBoDkLC_e>o5;mC]a>gD[MC]e:g4kMM]5jdGK@00=fd@A6W005
C]a>o4kLD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l
00000P000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D0
05;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol057oo00<0
07ooOol0:goo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol0AGoo01]>oDkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC_e:
g4kMB]ajdGK@N]5f/7[AM]16W4:KA[`00TJL05E>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo0030000>E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Ool0000/Ool0019oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`02Ool20006Ool20010Ool01eifFUHnFcYK?U/jFdkM00=>
g00>D_e>g4klC_aBoDkLC_e>o5;mC]a>gD[MC]e:g0Efd@0300Y>gDkL009>g006C]e>g5;lC_aBoDkL
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l00000P000e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`DOol00`00Oomoo`0ZOol0
011oo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`0mOol07EYEGWIJESiL>S/nG4kLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4:m@Ye2
_GJ`N]5fd7[AM[000P0:059>gD[LC]e:g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o0<00010D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0YOol0019oo`03001oogoo00=oo`@000Aoo`@000Eoo`03
001oogoo00Qoo`03001oogoo03]oo`0?FUINMUYFGWHjFciK>U/nFdkLC_e>g4klC]aBoDkL009>o007
D_e>g4kmC]a>oDkL@[d01WKA100:00E>g4klC]aBoDkl009Bo005D_e>o5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`3
0003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m01Eoo`03001oogoo02Qoo`00:7oo00<007ooOol02Woo00<007oo
Ool0>Goo029JEEifFUINMUYEGWI:_4[MB[a>gDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e2W7[A
M]1jdGJ`N]5fd4JL@Y]6_096W01:C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@800017D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo00EOol00`00Oomoo`0XOol002Qoo`<000]oo`03001oogoo03Aoo`09A]e6
_DJmA[eNMUYFGWIJEUif009OT007B[a:g4ZlB]a:_5;mC]`00Tkl00UBoDkLC_e>o5;mC]a>oDkLC_d0
1gKA14JL00EBoDkLC_a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l0`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;m
D_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;l
D_`EOol00`00Oomoo`0WOol002Qoo`03001oogoo00aoo`03001oogoo02moo`0XC]a>oD[LC_e>g4KM
A[a:gDJlGWIJEEifFUIS/En@Hk5>g4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LC]ef/7[A
M]1jdGJ`N]42AY`0AT:KA[a6W5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0`0004iBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0VOol002Qoo`03001oogoo00eoo`03001oogoo02]oo`03
C]a>gDkL009>g005C_e>g4kMC]a6g@02A[d02UYFGWIJEUifFUHnFcYK?U]>g4kM0TkL00=>o5;mC]`0
0Tkl00QBoDkLC_e>o5;mB]a>gD[M1WKA00<02TkLC]d00dkL00EBoDkLD_a>o5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol002Qoo`8000moo`03
001oogoo02Eoo`0`DM=Am3ik@W`nNd9lB]a>gD[LC_e:g4kMB]a>oD[LA]e6_5ifFUIS/EYEGWHjFciL
>S]>oDkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kmB]ajdGJ`N]5fd7[A0P0:041:g4kMB]a>
gD[LD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@<0001FD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Ao
o`03001oogoo02Eoo`00:7oo00<007ooOol03goo00<007ooOol097oo00EAm57CDO@nO49l008nO00G
C]a>oDkLC]e>g4kMB]a>gD[L0=M6_EifFUINMUYFGWHjFciK>U]>o4kLC_e>g002C_`02U;mC]a>o4kl
C_e>g4kmC]a>oD:m1WKA0`0:00M>g4kMC]a>o4kLD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`00e;mD_aBo0030002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`EOol00`00Oomoo`0TOol002Qoo`03001oogoo011oo`03
001oogoo029oo`0aDOAAde7dDM=Am4ZlB]e:_4kMC]a>oDkLC_e:g4kMB]a>oD[LGWIJEEifFUINMUYE
C]e:_4[MB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkL@[ef/7[AM]1jdGJ`N]40100:03Q>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0`0005eBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
4goo0P009Woo000WOol00`00Oomoo`0BOol00`00Oomoo`0POol00e7dDM=Am002DO@0357CF`U:g4[M
B[a:g4kLC_e>g4kMA[e6g@96_@05FUINMUYFGWIJEP02Gi0024[LB[a:g4ZlC_a>g4kmC]`2C_`025;m
C]a>oDkLC_e>g4kmC]`7M]44AY`01TkLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oE;lD_`00`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Aoo`03001oogoo02=oo`009goo0`004goo00<007ooOol0
67oo01m>gD[LC_e:g4Jm@[a6_E7CDOAAde7dDM=K:EL9C]e:_4[MB[a>gDkLC_e:g4kmA[a6gDJlB]eJ
EUifFUENMP02Gi006TZlC]e:_4[MB[aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>oD[LN]5f/7[AM]5j
dGJ`A[`2AY`0<T:KA[a>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d30000I5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol08Woo000WOol00`00Oomoo`0DOol00`00Oomoo`0COol0
0dZlB[e6_002B[`01TkMB]a>gDkLA[e2_@=Am005DM=Am5/9FbUG2@02C]`03DkMC]a>g4kLC_e>g4kM
A[e6gDJmGWIJEUif00AOT0=>g006C]e>g4klC_aBoDkL0Tkl00MBoDkLC_e:gDkMB]a>g@06M]40100:
C]a>g4kM0TkL00I>o5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo080009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006
D_eBo5;lD_aBoE;l57oo00<007ooOol08Woo000EOol40004Ool40006Ool00`00Oomoo`0EOol00`00
Oomoo`0AOol0?f>dHmE6_4ZmA[a:gD[LC]e:g4kmB]a6_E7CDOAAde7dE`UAm3ik@W`nNdkmB]a>gD[L
C_e>g4kmB]a>oDJlA]eJEEifGi1NMUYE?U`jFciLC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
C]e:g4kmM]5jdGJ`N]5fd@0200X0;TkMB]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l0`0006YB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo025oo`0057oo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo01Ioo`80011oo`ASe004B[a:_DJlB[`2
B]d01D[LB]e2_E7dDM<00e7d00EAdd9l?Wa2O3il009>g00FC]e>g4kMB]a>gD[LC]e6_DKMFUINMUYF
GWHjFciK>U/nFcYKC_a>g4kmC]`2C_`02E;mC]a>o4kLC_e>g4kmC]a2_@06M]4200X3C]`01TkMC]aB
o5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oGooOol04goo00<007ooOol087oo000IOol01000Oomoo`0017oo00<007ooOol00goo0P006Goo00<0
07ooOol03Goo045RUejF=Q/b6SHKB]a>gDZlC]e:g4kMB]a>gD:mDOAAde/ZDM=Am57C@W`nNd9l?W]>
oDkLC_e>g4kmB]a>gD[LC_eJEUifFUENMUYFGWI:_4kMB[a:gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>
oDkLD_e2WG[AM[1jdGKAN]5f/00;00802P0WC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l00<0001bD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol087oo000<Ool6
0007Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol06Woo00<007ooOol02goo00]RUejF
HYMRUSHK<QXb6d[LC]e:g4kM009:g@05B]a2_E7dDOAAd`03DO@02EL9B]a:g4[MB[a>gDkLC_e>g002
A[d01dKMA[eNMUYFGWIJEUif009OT00BB[a:g4ZlB]a>g4klC]aBoDkLC_e>o5;mC]a>oDkLC_e>g4km
1gKA0dJL00E>g4klC]aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo004D_eBo5;lD_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo01moo`005Goo10000goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol06goo00<007ooOol00goo04M:gDZlC]e:g0gL2K]RUejFHYMN
UV:G<QXf6c8J=Q]:g4kMB]a>oD:mA[e2_57dE`UAm57CDOAG2E/9B[a>gDZlB]e:_4kmC]a>oD[LB]e6
_4KMA[aNMUYFGWIJEEn@Ghm:gDZlC]e:_4[MC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kMB]a>oGKAN]5f
/7[A009fd@0S@Y]6_4JLAYa2Ve;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo0030000NE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01moo`005Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo0P007Goo0U^d00I6_DJlA[a6_4[MB]`2B]d04V:GGYIRUf:F
HYMNUV:GB[a:_DJlB[a>g4kMB]a>gD:mA[eAd`=Am004DM=G2EL9E`T3C]`01TkMC]a>gDkLC_e>g096
_@04A]eJEUifFUH4Gi001TkMC]a>g4kLC]e>g09>o00:D_e>g4kmC_aBoDkLC]e:gDkMB]`6M]402P0:
C]a>g4kLC]e>g5;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aB
o5;l0`0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0NOol001Eoo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo009oo`03001oogoo01]oo`1;FmAG]5_EEkA6_DJLB[e6_4KMA[a6gDJlHYMNUV:G
GYIRUendHmA6_4ZmA[a>oD[LC]e:g4km@[eK:E7CDOAAde7dDM=2O3ik@Wa:g4kmB]a>gD[LC_e>g4km
B]a:gDJlGWIJEEn@FUINMSXk?U`jFdkmC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g7[A
009fd@0OM[1jd@0:00]:g4kMB]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5<MD_`00`00085Bo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol07Goo000EOol50003Ool4
0005Ool00`00Oomoo`0JOol015^d9SeV]f:f0RFi00E:gD[LB]e:g4KM0096_@04HYIRUejFHYL3Hm@2
B[`00dZmA[a:g@02B]d01D[L@[e2_E7dDM<00e7d00@nO49l?Wa2O0=>g006C]e:g4kMB]a>gD[L0TJm
00iNMUYFGWIJESiK>U/nFcYK?U]>g4klC]a>oDkL0Tkl00QBoDkLC_e>g4kmC]a>oD:m1WKA0P0:00I>
gDkLC]a>g4kMC_`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0<00003D_aBoE;l009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoE;lD_`04goo0P007goo000VOol00`00Oomoo`0IOol0BbHm8SaVef:fI[LUVBVj
9KU:gDZlC]e:_4KMA[a6gEjFHYMNUV:GGYHf6c8JC]e:g4kMB[a>gD[LC]e:g4JmDM=Am57CDOAAde7d
?W]2O3ik@Wa>g4kmC]a>oD[LC_e:g4kMB]aNMUYFGWIJEEifFUI>gDZlC]e:_4kMC]aBoDkLD_e>g5;m
C]aBoDkLD_e>g4kmC]a2_@02M]4077J`N]5fdGKA00X02`0:D_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;m0P0008QBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03
001oogoo01aoo`009Goo00<007oo000047oo00EJEUif=S/f?4Zl00=:g@059S`V?BHmI[MR]P03I[L2
9KT054[LB]e:g4[MB]a6gDJmHYMRUV:GGYIRUc8K=Q/b6TkMB]a>gD[LC]d2B]d01D:mDOAAm5L9DM<0
0U7d00YG2DZlB]a:g4[MC]a>gDkLC_e>g096_@0>A]eJEUifFUINMUYFGi1OSd[LB[a:g4ZlC_e>g09>
o00:D_e>g4kmC_aBoDkLC_e>g4kmC]`7M]43AY`01E;mC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_d00000001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`DOol00`00Oomo
o`07Ool5000?Ool002Eoo`80011oo`1HFUINMUYE>U`f>cYLA[a:gDZlB]e6_6KGH[IV]f:fI]MR]RFj
9ITY^T[LB]e:_4kMB]`=g0VkHYMNUV:GGYIRUc8J=Q/b6TkmB]a>gD[LC_e2_DJmDM=Am57CDOAAdeL9
E`QG2DZlC]e:_4[MB]a>oDkLC_e:g4[MA[a6gEYEGWIJEUifFfmOT4ZlC]e:_4kMB[aBoDkLD_e>g5;m
C]aBoDkLD_e:g4kmB]a>gD[LN]42M]4057JaN]5fdDJL@Y]6_4JLD_e>g5;mC]aBoDkLD_e>o5;mC]aB
oE;lD_d30000SU;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<0
07ooOol01goo00D007ooOomoo`0000moo`009Goo00<007ooOol03Woo00EJEUifFUINMUYF008f>`06
=Sa6_DJmA[e6gDJm0fJg00AR]UNdEkA6_@96_09:g@09B]a:gD[MHYMNUV:GHYIRUejF009:_006B[e6
_4kMC]a>gD[L0T:m00=6_E7CDO@00U7d00AG25L9E`UG2@=>g005C]e>g4kMC]a>o@03A[d02EifFUIN
MUn?Gi1KSen@C]a>g@03C]`03E;mC]a>o4klD_e>g4kmC_aBoD[LC]e:gDkM00Ifd@0300Y>gDkL009>
g005D_e>g5;lC_aBo@03D_`01E;m00000000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00IBoE;lD_aBo5;mD_`DOol00`00Oomoo`07Ool00`00Oomoo`0@Ool002Eoo`03001oogoo
00eoo`1LFUINMUYEGWIJEUifA[a:gDJlB[e6_4[MA[a6gF:fI]MR]U^dEk=Ke4JlA[e6W4ZmA[a6gDJl
A]eNUV:GGYIRUejFHmAO/d[MA[a:_DJlC_e:g4kMB]a6_D:mDOAAde7dDM=Am3ik@W`nNd9lB]a>oD[L
C_e:g4kmC]a>oDJlB]eJEUifFfmNMUYF?U`j>ciLC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[L
C_e:g4kMM[5jd@9fd@0<M[402`0:C]e:g4kMB]a>gDkLD_e>g5;m0`0009IBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`07Ool0
0`00Oomoo`0?Ool002Eoo`8000]oo`=2_@07GWIJEUifFUINMVOCJm<00dJl00M:_DJmA[e6_DKMH[IG
]002I[L29KT01T[LB]e:g4[MB]a6g@96_@03HYIRUejF00=Se005A[a:_4ZlB[e6_003B]d2@[d2DO@0
257CDOAAm57d?Wa2O3ilC]d3C]`01DkMB]a>gD[LC]d00TJm00mJEUifFUINESYK?U/jFciK>U]>oDkL
C_a>g5;mC]`00Tkl00EBoDkLC_e>g4km0092_@Ifd@0800X02dkLC]e>g4klC]aBo@<00005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
Oomoo`0BOol00`00Oomoo`08Ool00`00Oomoo`0>Ool002Eoo`03001oogoo00Eoo`1RGmESmTJLA[e2
W4Jm@[e6_D:lGWIJEUifFUE[e6NcJm=6_4[MA[a:_DJlB]e6_2HmH[IV]f:f9KXUVBVjB[a:gDZlC]e6
_4KMA[aRUejFHYMNUV:G<QXf6dZlC]e:g4kMB[a>gD[LC]e2_57dDM=Am57CDOAAde7d?W]2O3ikC_e>
g4kmC]a>gD[LC_e:g4kMFUENMUYFGWIJEEifB[a>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>
g4km@Yajd@9fd@08M[5jdGKA00/02P0;C]aBo@<0002MD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001B
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d057oo00<007ooOol0
27oo00<007ooOol03Goo000UOol00`00Oomoo`05Ool01F?FHmESeTJlA[d00TJl0T:m00EJEUifFUIN
MUYF008f>`03=Sa:_4[M009:g@059S`V?FJgI[MR]P02I[L49KT02T[MB]a:gDJmA]e6_F:GHYIRUejF
0S8K00Hf6d[LC]e:g4kMB]`2B]d01TJmDM=Am5L9DOAAl`9Am009E`Q:_4[LB]a>oDkLC]e>g4km00=6
_@0>GWIJEUiFFUINMU]_Fhm:_4[LB[a:g4ZlD_e>g09>o009D_e>g4kmC_a>oDkLC_e>g4km00Ifd@03
00]6W00000800005D_e>g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol00goo00D007ooOomoo`0000mo
o`0097oo00<007ooOol01Goo06ESmV:FH[LYfRgkA[a:gDJlB]e2_EifFUE[e5YFGWIJECYL=S/jG4Jl
B]e:_4[MH[IV]f:fI[MR]VJgA[a6_DJLB[e6_4[MB[a>g@Vk3M]NUV:GGYIRUejF=Q/b6SHK<QY>oD[L
C]e:g4Jm@[eAm57CDOAAde7dDM=G2E;XB]e:_4kMB[a>oD[LC_e>g4kmA[a:gDJlGWIJEEifFUIOSe]_
Gi1>g4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[LC]ef/G[A009fd@<0002TAYa2VdJlC]aB
oDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00Aoo`<0011oo`0097oo00D004JmA[a6_DJl00<E
o003HYIR]f:G00<YfP0:A[e:gDJlB[e2_EifFUINMUYFGWH3=S/01SHlA[e6_DJmA]eR]P=V]`04Ek=G
]4JlA[d2A[`2B]d02D[LB]eRUV:GGYIRUf:FHYM6_002B[`01TZmA[a>gDkLC]e:g092_@03DOAAle7d
009Am004E^QG25L8C]d3C]`01DkmC]a>gDkLC_d00TJm00YJEUifFUINEUYF?U/jFciKC]a>g@9>g003
C_aBoDkL009>o008D_e>g4kmC_a>gD[LC]e:g@9fd@800005M]402P0;C]a>g@02C]`01TklD_e>g5;l
C_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo004D_eBo5;lD_`AOol200000goo001oo`0GOol002Aoo`1Z0016_4[MA[a6_A7K5OaRUV:g
HYIR]f:F:OXYfRgkA[a:gDJlB]eJEUifFUENMUYFGWI6_4[MA[a:_DJlB]e6_4KMH[IV]f:fI[LU^E^d
A[a6_DJLB[e6_4KMA[a6gEjFHYMNUV:GGk=Se4JlB]e6_4ZmB]a>oD[LC]e:g4JmDM=Am57CDOABj57d
?W]2O3ikC]e:g4kmB]a>gD[LC_e:g4kMA[aNMUYFGhmJEEif>U/nG3Xk?Ua>g4kmC]a>oDkLD_e>g5;m
C]aBoDkLD_e>g4kMB]`30000ZgJaN]5fd@0;00X02d[LC]e:g4kMC]aBoDkLD_e>g5;mC]aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o00DOol00`00Oomoo`0EOol001Yoo`@000Ioo`0>001oodJlA[e6_4JmHYIR]f:GH[MRUV:gA[a6_@96
_0=2_@05GWIJEUifFUINMP02Im<3A[`01TZmA[e6_DJmI[MR]P=V]`8U^@0?B]a:gD[LB]e6_DKMA[eR
Uf:FHYMNUUoDGk=Se4Jl009:_003B[e:g4[M009:g@05@[eAm57dDOAAl`02DO@06T9l?Wa2O3ilC_e>
g4kMC]a>oD[LC]e:g03FA[eNEUYFGWIJEUiF>U/nFcYK?U]>g4kmC]`2C_`01U;mC]a>o4klC_e>g0<0
0003@[efdGKA00=fd@802`0900X02dkLD_e>g4klD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4goo00<0
07ooOol05Goo000IOol00`00Oomoo`02Ool00`00Oomoo`03Ool0I000Oomood:lA[e2_4JmHYIR]f:F
H[MOeF?fAYa6_D:LA[e2_DJm@[aNMUYFGWIW/V_CIk=[ddJlB]e:_4[M8S`V?B8l9SeR]VJgH[HY^RFi
:KY:_4[MB[a>gDJlA]e6_6:GGYISe5jFHYLb6SHKB[a>gD[LC]e:g4kMB]a>gD:lDOAAdeL9DM=Am57C
B]e:_4kMB[a>oDkLC_e>g4kMB]a>oD[LGWIJEEifFUINMUYEC]e:_4kMB[a>gDkLD_e>g5;mC]aBoDkL
0`0000I>g5;mC]a>oGJaN]42M]40ZgJaA[a6W4JL@Y]6_4kLD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo00COol00`00Oomoo`0DOol001Uoo`03001oogoo009oo`03001oogoo00=oo`80009oo`08@[e6
_D:mH[MRUV:gHmESeP9Se@04A[a6_DJlA[`2@[d01EYFGWIJEUifFUH00SHk00<j?4ZlB]d00T[M00DV
?2HmI[MV]f:f009V]`<U^@9:g@0AB]a:g@fkA]eNUV:GHYIRUejF=Q/b6cHKB]a>gD[LC]e:g002B]d0
0dJmDO=Am002DO@0357cDOABj4[MB[a:g4kLC_e>g4kMC]a6g@96_@0?FUINMUYFGUIJEU^?Ffm:g4Zl
B]a:_4[LC_aBoDkL00<00008C]a>oDklC]e:g4kMB]e>g@Efd@A6W007C_a>g5;mC]a>o5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo003D_eBo5;l01Aoo`03001oogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo05U2_4Jm@[aR]eoE5OaRUV:g:MX]ndJlB]e6_4[M@[e6_EYEGWIJEUif=S/jG3Hk>Ua6
_4[MB[a:gF:fI[MR]VJgH[IV]dJlA[e6W4ZmB]a:gDZlC]d9^`gKGYIRUejFHYMNUSHK<QXf6d[LC_e:
g4kM@[a6_D:mDOABj57dDM=Am5;XE`Q:_4[MB[a>gDkLC_e:g4kmC]a6gDJlB]eJEUifFUENMU]_FhmK
KTkmC]a>oDkL00<0000>C]aBoDkLD_e>g5;mC]a>gD[LC_e:g7KAM[5fdP9fd@2Z@Y]6_4JLAYa2Ve;m
C]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA=oo`03001oogoo01=oo`006Goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol017oo11Gl00=RUV:gHYL00bWJ00=6_D[MA[`00P1c00ENMUYFFUIJ
EUif00<f>`06>Sa6_DJmA[e6gF:f0fJg0UNc00A6_4JmA[a6_09:g@09B]a:gF:FHYMNUV:GHYIRUdJl
009:_005B[e:g4kMC]a>g@02@[d2DO@0257cDOAAm5L8D^QG24kLC]d3C]`02dkmC]a>gDkLA]e6_EiF
FUINMUYFGUH00SiK00@jF`000000009>g003C_aBoDkL009>o008D_e>g4kmB]e>gD[LC]e:g@Afd@0:
00]>g4kLC]a>gDkLD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0COol00`00Oomoo`0BOol0
01Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`1A4M/Eo6:FH[MRUV:gHYHYnRWJ
;O]6_4[MA[aNMUYFGWIJEEifIk9WddJlB]e6_4ZmA[a:gDJlI[MR]VJgH[IV]bFi:KY6_4JmAYa:_DJl
A]e6_4KMGYIRUejFHYMO/eoDA[a:gDJlB[e:g4kmB]a>gD:lE`UAde7dDM=G257C@W`nNd9lB]a>gD[L
C_e:g4kMB]a>oD[LA]eJEEifFfmNMUYE00<0000B>S]>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD:M
@[ef/GKB0WKA0:ef/GKB00X02d[LC]e:g4kMB]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ao
o`03001oogoo015oo`006Goo00<007ooOol00Woo00<007ooOol00Woo0P001goo00QRUV:gHYMR]f:F
H[M6_4Jm0TJl0T:m0eYF00ENMUYFIm=W/fOC00=6_006B[e6_DJmA[eV]f:f0VJg0bFi00Y:g4[MB]a:
gDJmA]e6_F:GHYIRU`=O/`06Gm=:g4kMB]a>gD[L0T[M00=6_E7cDO@0157d00lnO49l?Wa2O4kLC_e>
g4kMC]a>gD[LC]d0]TKMFUH00`0000UJESiK?U/nFcYKC_a>g4kmC]`00Tkl00QBoDkLC_a>g4kmC]a>
oD:m1WKA100;00A>o4kLD_e>g09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04Woo00<007oo
Ool04Goo000JOol40005Ool00`00Oomoo`07Ool0BV:FH[MRUV:gGmESmTJLA[e2W4Jm@[e6_EYEGWIJ
EVOCIk9[dfNbIm=6_4[MB[a:gB8l9SdR?6JgH[IV]f:f:KXU^BVjB[a:gDZlC]e6_4KMA[aRUencHYMN
USHk<QXf6dZlC]e:g4kMB]a>gD[LA[eAde7dD^QAm57CEOA:_4[MB[a>gDkLC_e>g4kmC]a>gD[LC_d2
00005UYEGWIJEU^?Efi>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;m0WKA00If/GKBM]5f
dGJaA[`2AY`0Z4JKD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA9oo`<0019oo`001Goo
0P0000=oo`0000006Goo00<007ooOol01goo00=R]f:FH[L00Woo0RWJ00]6_4JmA[a6_4:mGWIJEVOC
Ik=NMUYF008f>`06>Sa:_4[MB]dV?BHl0fJg00=R]VJg9KT00bFi0T[M011:g4[M2K/=^`VkHYMRUV:G
<QXf6c8KC]e:g4kMB]a>g@=2_@03DOAAle7d00=Am004D^Q:g4[MB[`2B]`00dkmC]a>g@0300001EiF
FUINMUYFGUH00U]_00E:_4[LB[a:g4Zl009>o00;D_e>g4kmC_aBoDkLC_e:gDkMB]a>g@06M]45AY`0
15;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0AOol00`00Oomoo`0@Ool000Ao
o`03001oogoo008001Yoo`03001oogoo00Qoo`03H[Moogoo009oo`0n:MX]ndJlB]e6_4[M@[eNMUYE
GWIJEUif=S/jG3Hk>Ua6_4[MB[aV]f:fI[MR]VJgDi=G/dJlA[e6W4ZmB]a:gDZl3M`9^f:GGYIRUejF
HYLb6SHk<QY>gD[LC_e:g4kM@[a6_E7CE`QAdeGdDM=C25;WE`Q:g4kMB]a>o@<0000MC_e6_4KMA[aN
MUYFGWIGKU^?FfiKSdkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>o@02M]40/7JaM]9f
/@0;B]a>gD[LC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001B
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dCOol00`00Oomoo`0?
Ool000Aoo`05001oogooOol0000IOol3000>Ool3:MX01TJmB]e6_4ZmFUINMP=JEP05GWI6_4JlA[a:
_@03A[d02FJgH[IV]fJgEk=CTeNcA[a6_@02A[`2B]d01T[LHYMRUV:GGYIRU`9O/`09A[a:_4ZlC]e:
g4kMC]a>gD:m00IAm003@W`nO49l00<0009>g00:C_e>g4kMA[e6gEYFGUIKKeifFUH3?U/3C]`03dkM
C]a>o4klD_e>g4kmC_aBoDkLC_e:gDkMB]a>g@04M]4200/3C]`01TkMC]aBo4klD_e>o09Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00=BoGooOol04Goo00<007ooOol03Woo0004Ool01@00Oomoogoo00006Goo
00<007ooOol03goo03LYnRWJ;O]2_DJm@[aNMUYFGWIJEEifIk9WddJlB]e6_4ZmA[a:gDJlI[MR]UNc
H[IV]bFi:KY:_4[MB[a>gDJlA]e6_6:GGYIRUe^cGm=O/dZmA[a:gDJlB[e:g4kMB]a6_E;XEOAAde7d
DM=Em0030000:4kmB]a>gD[LC_e:g4kMB]a>oDJlA]eJEEifFUINMSXk?U`jFciL>S]BoDkLD_e>g5;m
C]aBoDkLD_e>g4kmC]aBoD:MM]5f/GKBM[5fdGJa0P0;0:a>gD[LC]e:g4kMC]aBoDkLD_e>g5;mD_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo1=oo`03001oogoo00ioo`0017oo00D007ooOomoo`0001Uoo`03001o
ogoo011oo`03A[e6_4Jl00=2_@9JEP05GWIJEVNcIk9Wd`03A[`01TZmA[e6_DJm9SeR]P9V]`06:KTU
^BFiB]a:gD[L0TJm00i6gEjFHYMRUV:GGYHf6c8KC]e:g4kMB]a>gD[L0T[M00=6_E7dDO@00`0002EA
m3il@W`nO4kMC]a>oDkLC]e:g4kMB]a>gEYFGWIJEUiFFUINMTZlB]a:_4[LB[a>o4kLC_e>g4kmC_aB
oDkLC_e>g4kmC]a2_@06M]4300/01U;mC]a>o4kLD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00AB
oE;lD_aBo1=oo`03001oogoo00eoo`000goo0P000Woo0P006Goo00<007ooOol047oo0316W4Jm@Ya6
_D:mA[eJEEifFUINMUYE>U`f>cYLA[a:gDZlB]dR?2HmH[IV]f:fI[MR]RVj9KTY^TZlB]e:_4KMA[a6
gEjF3MaNUV:G<QXf>c8JC]e:_4kMB]a>gD[LC]d30000gUGdDM=Am57C001:_4[MB[a>oDkLC_e>g4km
A[a6gDJlGWIJEUifFUENMUM^Ffm:_4kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLM]9f/GKA
M[5fdWJaM]96VdJlAYaBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1=o
o`03001oogoo00aoo`008Woo0P004Woo00Y6_D[MA[a:_D:mGWIJEVNcFUINMP<f>`03>Sa:_4[M009:
g@08H[IV]fJgI[MR]VJgA[a6_@96_09:g@0>B]`9^`Vk3K]NUV:GHYIRUc8J=Q/b6cHKB]a>g@<00003
@[eAm57d00=Am080009:g00>B]e:_4[LC]a>oDkLC]e6_DKMA[eNEUYFGWIJEP9KKP06Ffm>g4kLC]a>
gDkL0Tkl00YBoDkLC_e>o5;mC]a>gD[MC]e:g0Ifd@A6W005D_e>g5;lC_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo004D_eBo5;lD_`BOol00`00Oomoo`0<Ool0029oo`03001oogoo019oo`0XA[a:gDJl
B]e2_EifFUENMUYFGWHf>cYL=S/jG4JlB]e6_4KMH[IV]f:fI[MCTUNcA[a6_DJLC]e:g4[MB[a>gEjF
HYMNMV:GGYI:_DJlB]d300002DkmB]a6_D:lA[eAde7dDM=Em0030000fDkmB]a>gD[LC_e>g4kmB]a>
oDJlA]eJEEifFUINMUYE?U`jFciLC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC]ef/GKBM[5f
dWJaM]802dkMB]a>gD[LD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01=o
o`03001oogoo00]oo`008Goo00<007ooOol057oo00I6_D[MA[a:_EYFGWH3FUH01FNbA[a6_4JlB[d0
0dJm00=V]f:fI[L00VJg0RFi00=6_4JmA[`00TJm00I6gDJmA[eRUV:GGYH2Gk<20002B[`01TZmB]a>
gDkLA[e2_@EAm003?Wa2O3il009>g00>C]e>g4kLB]a>gD[LC]e6_EifFUIKKUYFGWHjF`<nF`=>g00=
C]e>g4klC_aBoDkLC_e>o5;mC]a>gD[MC]d01GKA0P0;00I>gDkLC]a>g4kMC_`2D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`04Woo0P0037oo000QOol00`00Ool0000EOol08D:mA[e2
_5ifFUINMUYEIm=S/VOCA[a:gDJlB[e6_4[MA[aV]f:fI[MR]RVj9KTY^TZlB]e:_4KMA[a6gDJlHYMN
UP030000je^bGk=:_4kMB]a>gD[LC]e2_DJmDM=Em57CDOAAdd9l?W]2O3ik@Wa>g4kmC]a>oD[LC]e:
g4kmA[aNMUYEGWIJEUif>S/nG3YK?Ua>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4:mM[5fdWJaM]9f
/GKB00/0300;D_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=o
o`03001oogoo00Yoo`008Goo0P005goo0d:m0UYF00=NMVNbIk800VNb00E:_4[MB]e:gB8l008V?@0<
I[MR]VJgI[LY^BFiB]e:g4[MB]a:gDJm0`0000eO/f:GGYHf6c8K=Q]:g4kMB]a:gD[LB]e2_@06DO@2
B]`08T[MB[a:g4kLC_e>g4kMB]a>gD[LC]eJEUifFUINEUM^Ffi:_4[LB[a:g4kLC_a>g4kmC]a>oDkl
D_e>g4kmC]a>oDkL1WKA00T02dJLAYa6W5;mC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eBo7oo015oo`8000]oo`003goo100017oo10001Woo00<007ooOol05goo01U2_DJm
FUENMV>bGWIJECYL=S/jG4JlB]e:_2Hm8SaV]f:fI[MR]VJg9KTY^RFiC]e:g0030000l`Vk3K/9^f:G
GYIRUc8J=S/b6TkMB[a>gD[LA[e2_4JmDM=Am000EOAAle7d001>gDZlB]e:_4kMC]a>oD[LC_e6_4KM
A[aNMUYFGWIJEE]_Efi>gDZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kMB]afdWJaM]9b/GKB
00]6W4JKA[a6W5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00>
Ool300000goo001oo`0:Ool000ioo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool0
0`00Oomoo`0HOol2@[d3FUH01Uif=S/f>cHk>Sa:_09:g@03I[MR]VJg009V]`9CTP04A[`000000002
B]d04D[L2K/9^f:GGYIRUejFHYLb6SHK<Q]>gD[LC]e>g4Jm@[d01E7d100000=>g4kMC]`00TkL00U>
oDkLA[e6_DKMFUINEUYFFfh00eM^00I>gDkLC]a>g4kMC]`2C_`02E;mC]a>oDklD_e>g4kMB]e>g@05
M]4200/02DkMC]a>g4kLD_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d02Woo100017oo00<007ooOol02Goo000COol01000Oomoo`0017oo00<007ooOol00goo0P006Woo
015JEUifFUENMUYFGWI6_4[MA[a:_DJlB]e6_6JgH[IV]f:f00<0003jA[a6_DJLB[e:g4[MB[aRUejF
HYMNMV:GFk9O/dJlB]e6_4kMB]a>oD[LC]e2_5GdDO=Am57CEO@nNd9l?W]2O4[LC]e:g4kmC]a>oD[L
B]e6_4KMFUEKKeYFGWHj>ciL>U]>oDkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kML[5fdWJa
M]802`0<00]>gD[LC]e:g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d6Ool30008Ool00`00Oomoo`09Ool001=oo`04001oogoo0004Ool00`00Oomoo`02Ool2000KOol2
FUH01EifFUIJEV>bIk800dJl00A:_DJmA[e6_@<0009V]`8U^@0?B]a:gD[LB]e6_DKMA[eRUejFHYMK
/UncFk9:_DJl009:_005B]e:g4[MB]e6_@05DO@0349l?Wa2O3ik@Wa>g4kmC]a>gD[LC]e:g096_@06
GWIJEUiFFUHnFcYK0ciK00E>g4klC]a>oDkL009>o007D_e>g4kmC]a>oDkL@[d01GKA100;00IBoDkL
C_a>g5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`3Ool3000<Ool00`00
Oomoo`08Ool000moo`@000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo01]oo`0:GWIJ
EUifHk9Wdf>bIm96_4[MA[`30000C4Jl9SeR]VJgH[HY^RFi:KY:_4[MB[a>gDJlA]eNMV:GGYIRUeif
=S/b6TkMB[a>gD[LC]e:g4kMB]a6_E7CEOAAle7dDM=>gDZlB]e:_4kMC]a>oDkLC_e:g4kMB]a>oEYF
GWIJEEifFUI>gDZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4km?YafdWJaM]9b/GKB0TJL0;=6
VdJlAYaBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0080
00moo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol06goo0eYF0Woo0SHk0`000T[M00DR?2HmI[MV]f:f009V]`03:KTU^BFi009:g@0CB]a:gDJm
A]eNUV:GGYIRUc8J=Q/b6dkMB]a>gD[LC]e:g4[M@[d01E7d00T004[LB]a:gDZlC]e>g4kmC]`00TJm
00I6gDJmGUIJEUifFUH2Efh01T[LB[a:g4ZlB]a>g09>o009D_e>g4kmC_aBoDkLC_e>g4km00Ifd@A6
W006C]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l47oo00<0
07ooOol027oo000?Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0L
Ool015YEOomoogoo0P0002Pf>cYL=S]:gDZlB]eR]VJgH[IV]f:fI[M6_4JmAYa:_D[LB]e:_0fk2K]R
UeifHYMNUV:G<QXf>c8JC]e:g4kmB]a>gD:lA[eAle7dDM=Em0@0003MB[a:gDZlC_e>g4kmB]a:gDJl
A]e6_5ifFUINMUM=EfiGCDkmC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC]eb/GKBM[5fdW:a
00`02dJLAY]6_4kLD_e>g5;mC_aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo00?Ool00`00Oomoo`08Ool000moo`D000=oo`@000Eoo`8001ioo`<0009oo`96_006B[e6_4Jm
A[e6gF:f0fJg00A?TU>BA[a6_@96_09:g@06B]aRUejFHYMNUV:G0U^b00U6_4ZlB[a>gD[LC]e>g4kM
@[d0157d00a2O3il@W`nNd9lC]a>gDkLC]e>g4kmC]`2A[d01TKMFUINEUYFGWHjF`8nF`06C]e>g4kL
C]a>gDkL0Tkl00UBoDkLC_e>o5;mB]a>gD[MC]d017KA0`0;00I>gDkLC]a>o5;mC]`2D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00?Ool00`00Oomoo`08Ool0021oo`03
001oogoo01Yoo`<000Ioo`3oB]e6_4ZmA[a:gDJlI[MR]U>BH[IV]bFi:KY:_4[MB[a>gDJlA]e6_6:G
GYIRUe^BGk=K/TZmA[a:gDJlC]e:g4kMB]a6_E7CEOAAl`00DM=2O3ik@W`nNdkmB]a>gD[LC_e:g4kM
B]`0]TJlA]eJEEifFUHnG3Xk?U`jFe;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;m?Ya2_GJaM]9b/GKB
M[40300;00a:g4kMB]a>gDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m000:D_aBoE;lD_eB
o5;mD_aBoE;lD_d>Ool00`00Oomoo`08Ool0021oo`03001oogoo01Moo`<000Yoo`96_00>B[e6_DJm
A[dV?F:fI[MR]bVi9KTY^D[LB]e:g096_@06A]eNUV:GGYIRUejF0SHK00I>gD[LC]e:g4[MB]`2B]d7
DO@08cil@W`nNdkMC]a>oDkLC]e:g4kMB]a>gEYFGWIJEUiFFUI:g4ZlB]a:_4kmC]a>o4kLC_e>g4km
C_aBoDkLC_e>g4km@[d01GKA00/02`0<00/02dkLD_e>g4klD_aBoDkl009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00eoo`03001oogoo00Qoo`007goo00<007ooOol0
5Goo0`003Woo055:gDZlB]dR?2HmH[IV]f:FI[MR]RVj9KTY^TZlB]e:_4KMA[a6gEif2K]NUV:G<QXf
>c8JC]e:_4kMB]a>gD[LC]e2_E7dDM=Em57cDOAAd`00B[a:gDZlC_e>g4kmC]a:gDJlA]e6_5ifFUIN
MUYEGWICCDkMB[a>gDZlC]e>g5;mC]aBoDkLD_e>g4kmC]aBoDkLC_eb/GKBM[5fdW:aM]800TJL0;I6
VdJlC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m3Goo00<007ooOol01goo000OOol2000COol3000AOol02TZlB]e:gD[MH[IV]f:gI[MR]VJg14Jl
0T[M00U:g0Vk2K/9^ejFHYMNUV:G<QX00SHK00E>gD[LC]e>g4kM0092_@EAm080009:g006B]e:_4kM
C]a>oDkL0TJm00U6gDJmGUIJEUifEdeGCUM=C]d00dkL00e>gDkLC_a>o5;mC]a>oDklC]e:g4kMB]e>
g@03M]400gKBM]56W004AY`00dklD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0<Ool00`00Oomoo`07Ool001moo`03001oogoo00moo`<0
01Eoo`0VA[a:gDJlA]eRUVJgH[IV]dmaDi96_4JmAYa>gD[LB]e:_4kMGYIRUeifHYMNUTZmA[a:gDJl
C]e:g4kmB]a6_D:lEOAAle7dDM=Em0<0003PC_e:g4kMB]a>oDkLC_e:g4[MA[a6gEYEGWIJEUif>S/n
G3YKC_e>g4kmC]a>oDkLD_e>g5;mC]aBoDkLC]e:g4kmB]a>gG:aM]9f/GKB00]>gD[LC]e:g4kMC]aB
oDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0aoo`03
001oogoo00Moo`007goo00<007ooOol037oo0`006Goo0dJm00MV]f:fI[MR]fJg9KTY^@03A[`2A[d0
1TKMA[e6_EjFHYMNUP9K/P09B[e6_4ZlB[a:_D[LC]e>g4Jm00AAm005001Am3il@W`nN`02C]`01TkM
C]a>gD[LC]e:g096_@06GWIJEUiFFUHnFcYK0SiK00I>oDkLC_a>g4kmC]`2C_`015;mC]a>oDkl0T:m
0WKA00IfdWKAM]5fd@0<00/2C]`01TkMC]a>g5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol02Woo00<007ooOol01goo000OOol00`00Oomoo`09
Ool3000MOol0odJlB]e6_6Jg8SaV]f:f:KXU^BWJB[a:gDZlA]e6_4KMA[aRUejFHYMNMSHk<QY>gDZl
C]e:g4kMB]a>gD:mDOAAdeGdDO=Am57CEO@nNd9l?W]>oDkLC_e>g4kmB]a>gD[L0;I6_5ifFUENMUYF
C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mC]a2_G:aM]9f/GKBL[5fdP0;00`02e;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0002U;mD_aBoE;lD_eBo5;mD_aB
oE;l2Woo00<007ooOol01goo000OOol20008Ool2000QOol05B8l9SdR?FJgH[IV]f:g:KTU^BViB]a:
gD[LB]e6_DKMA[eRUejFHYLb6P02=Q/024kMB]a>gD[LC]e:g4[M@[d2DO@09`00DOAAm57d001:g4[M
B[a>gDkLC_e>g4kMB]a>gD[LGUIJEUifFUIGCE==B]a:_4[LC]a>oDkLC_a>g5;mC]a>oDklC_e>g4km
C]afdP03M]400gKBM]5fd@03AY`01dklC]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol027oo00<007ooOol01goo000NOol00`00Oomo
o`05Ool3000UOol03FJgH[IV]f:FI[M6_4JmAYa:_D[LB]e:_4kM0089^`0CGWIRUejFHYLb6SHk<QXf
6d[LC_e:g4kM@[a6_E7cDOAAdeGdDO<00P0002U>gDZlC]e:_4kmC]a>oD[LB]e6_4KMFUENMUYFGWIC
CEM^Dde>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC_e:g7KBL[5fdWJaM]9b/DJl0096W02hAY]B
oDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d:Ool00`00Oomoo`06Ool001ioo`03001oogoo009oo`<002Uoo`05I[MR]fJgCg5?T@04A[`2
B]d02D[LB]eNUV:GGYIRUejFB[e6_002B[`024ZmB]a>gDkLA[e2_E7d0003DO@30002C]`01TkMC]a>
gDkLC_e>g096_@06GWIJEUiFFUINMSYK0SiK00I>gDkLC]a>o5;mC]`2C_`02E;mC]a>oDklC]e:g4kM
B]efdP03M]402WKB00]>g4kLC]e>g5;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0Yoo`03001oogoo00Ioo`007Woo00<007oo00000P00;7oo
00=RUVJgH[H00Woo0?lYfRFiA[e6W4ZmA[a6gDJlA]eNUV:GGWIK/UNAB[e6_4[MA[a:_D[LC_e:g4Jm
DM=Em57cDOAAdeGd?W]2O3ikC_e:g4kMB]a>oD[LC]e:g4[MA[aNMU==GWIJESiL>S/nG3YKC_e>g4km
C]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kmB]afdW:aM]9f/@0<00]>gD[LC]e:g5;mC]aBoDkLD_eBo5;m
C]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d000=Bo5;mD_`02Goo00<0
07ooOol01Woo000NOol3000_Ool04V:fOomoogoo9KTY^BFiB]e:g4[MA[e6gDJmHYMNUV:GGYIRU`8f
6`08B]a>gD[LC]e:g4[M@[d000EAm00L@W`nO49l?W]>gDkLC_e>g4kMB]a>gD[LA[eJEUifFUINEUYF
B]a:_4[LB[a>oDkLC_a>g5;mC]`2C_`01DkmC]a>oDkL@[d00gKA00=fdWKAM]400P0<00D02dklC]aB
oDkL009Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00ABoE;lD_aBo0Qoo`03001oogoo00Ioo`0017oo1@000goo100017oo10001goo00<007ooOol0<goo
01XU^BWJB[a:gDZlC]e6_4KMA[aRUejFHYMNMSHk<QXf6dZlC]e:g4kMB]a>gD:mDOAAdeGd0U7d02YA
ddkMB[a>gDZlC_e>g4kmC]a>oD[LC]e:g5ifFUINMUYEEdeCCDkMB[a>gDkLD_e>g5;mC]aBoDkLD_e>
g4kmC]aBoDkLM]9b/GKBM[5fdW:a00`2AY`0^dJKD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Moo`03001oogoo00Ioo`00
1Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`8003=oo`03
:KTU^BVi009:g@09B]a:g@Vk2K]NUV:GGYIRUejF00<f6`04B]a>gDkLC]d2@[d2DO@01@00DOAAm57d
00000T[L00I:gDZlC]e>g4kmC]`2A[d01DKMFUINEUYFGWH00e==00I:g4ZlB]a>o5;mC]`2C_`02E;m
C]a>oDklC]e:g4kMB]efdP03M]400gKB00a6W003AY`015;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`0
0003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00Moo`03001oogoo00Io
o`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Moo`03001o
ogoo035oo`0KA[e6W4ZmB]a:gDZlC]eNUV:GGWIRUejFHYM6_4[MA[a:_D[LC_e:g4Jm@[aEm57cDOAA
deGd00<0003UC_e:g4kMB]a>oDkLC_e:g4[MA[aNMUYEGWIJEUif>S/nG3YKC_e>g4kmC]aBoDkLD_e>
g5;mC]aBoDkLC]e:g4kmM[5fdW:aM]9b/@0<00]>gD[LC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d01Woo00<007ooOol0
1Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol027oo00<0
07ooOol0<Goo0dJl00]6_DKMA[e6_EjFHYMNUV:GEi5K/TJl009:_006B[e:g4kMC]a6_D:m1E7d00<n
O49l?W/00TkL00I>gDkLC]e:gDkMB]`2A[d01UifDdeNEUYF?U/jF`8nF`06C]e>g4kLC_aBoDkL0Tkl
00]BoDkLC_e>o4kMB]a>gGKAM]9fdGKB00<0309>g006C]e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Ioo`03001oogoo
00Eoo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Uoo`03
001oogoo035oo`0GB]e:_4kMA[a6gDJlHYMNUV:GGWIRUc8J=Q]:_4kMB]a>gD[LC]e2_DJmDM=Em002
DO@0jE7c@W`nNd9l?W]>oDkLC_e>g4kmB]a>g@2DB]eJEUifFUENMUYFC]e:_4kMB[aBoDkLD_e>g5;m
C]aBoDkLC_e>g5;mC]a2_G:aM]9b/GKBL[40300;00`02e;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`01Woo00<007oo
Ool01Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol02Woo
0P00<Woo00Y:gD[LB]e6_DKMA[eRUejFHYMNUP<f6`07B]a>gD[LC]e:g4[M@[d01U7d0T[L00i:gDZl
C]e>g4kmC]a>gD[MC]eJEUiFFUINMUYF0U==00I:g4ZlB]a>g4kmC]`2C_`03U;mC]a>oDklC_e>g4km
C]afdWKAM]9fdGKBM[44AY`014klC]aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Aoo`03001oogoo00Eoo`00
17oo0`0017oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00aoo`03001oogoo031oo`0C
B]e:_4kM1I/9^eifHYMNUV:GGWHf>c8J=Q]:g4kmB]a>gD:lA[d00U7d02iAdeGdDOAAm000C]e:_4kM
B[a>oDkLC_e:g4[MA[aNMUYEGWIJEUifCbaCCE</C]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4km
B]afdW:aM]9b/GKBAY]6_096W02mAY]BoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Aoo`03001oogoo00Eoo`001Woo
00<007ooOol00goo100017oo100047oo00<007ooOol0;goo0T[M00U:g4[MGYIRUejFHYMNUV:GA[`0
0TZl00I:_D[LC]e>g4Jm@[d5DO@30002C]`01TkMC]a>gDkLC_e>g096_@06GWIJEUiFFUINMSYK0SiK
00I>gDkLC]a>o5;mC]`2C_`03E;mC]a>oDklC]e:g4kMM]5fdWJaM]9fd@0<00=>g006C]e>g5;lC_aB
oDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoGooOol00Woo00<007ooOol01Goo000YOol00`00Oomoo`0_Ool054JlA]e6_4KMGYIR
UeifHYMGTE^AA[a:gDJlB[e:g4kmB]a6_D:lEO@2DO@0:U7cEO@nNd9l?W]>oD[LC]e:g4kmB]a>gD[L
B]eJEUifCbaNMUYF?U`j>ciL>U]>oDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC_eb/GKBL[5fdP80
3030B]a>gD[LC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0goo00<007ooOol01Goo000ZOol00`00Oomoo`0_Ool0
24JmA]e6_F:GGYIRUejFHYL2=Q/024[LC]e:g4kMB]a:gD:mA[d6DO@03Sil@W`nNdkMC]a>oDkLC]e:
gDkM09E6_EYFGWH3FUH01T[LB[a:g4ZlC_e>g09>o00>D_e>g4klC_a>oDkLC_e>g4:mM[5fdWKAM]9f
/@<03005C]a>o4kLD_e>g002D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0=oo`03001oogoo00Eoo`00:goo0P00<7oo0416_4KM
A[aRU`FKHYMNMSHk<QXf6dZlC]e:g4kMB]a>gD:mDOAAleGdDOAEm57c001:_4kMB[a>oDkLC_e>g4km
B]a>gEYEGWIJEUifFUECCDl/C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mC]afdW:aM]9b/GKB
L[56_096W02oC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo003Ool00`00Oomoo`04Ool002eoo`03001oogoo
02ioo`071K/9^`FkHYMNUV:GGYH00cHK00A:g4kMC]a>g@92_@EAm080009:g006B]e:_4kMC]a>oDkL
0TJm00UNMUYFFUIJEUifCbaCC5</C]d00dkL015BoDkLC_a>o5;mC]a>oDklC]e:g4kMB]efdWJaM]9f
dGKB00A6W005C]aBo4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo09oo`03001oogoo00Aoo`00;Woo00<007ooOol0
;goo01=RUeifHYMNMV:GA[a:gDJlB[e:g4kmB]a>gD:lEOAAm5GdDO=Em0030000k4kmB]a>gD[LC_e>
g4kmB]a:gDJlGWIJEEifFUINMSXk?U`jFdkmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[LM]9b
/GKBL[4034[LC]e:g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo7oo0006Ool002moo`03001oogoo02mo
o`03HYMNUV:G009GT@05A[a:_4ZlB[e:g002B]d00dJm@[eAm002DO@01@00DO@nO49l?W/00TkL00Y>
gDkLC]e:gDkMB]a6_EYFGWI?;09JEP0:?U/jFciK?U]>oDkLC_a>g5;mC]`2C_`02e;mC]a>oDkl@[ef
/GKBM]5fdWJaM]800P0<0dkL00E>gDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00=oo`00Ool01Goo000`Ool2
000_Ool0>eifHYMNMWoo<QXf6dZlC]e:g4kMB]a>gD[LA[eAleGdDOAEm57cEO@nNd9l?W]>oDkLC_e>
g4kmB]a>gD[LB]eJEUifFUENMUYFC]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mC]afdW:aM]9b
/GKBL[400`0<0<=>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00001Woo000bOol00`00Oomoo`0]
Ool00ejFOomoo`03=Q/01d[LC]e:g4kMB]a:gD:m00IAm008001:g4[MB[a>gDkLC_e>g096_@06A]eJ
EUYFFUINMUYF0Tl/00I:g4ZlB]a:_5;mC]`2C_`03U;mC]a>oDklC_e>g4kmM]5fdWJaM]9fdGKB00`3
AY`014kLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@02D_`3Ool00`00Oomoo`04Ool003=oo`03001oogoo031oo`0>=S/b
6SHKB]a>oD[LC]e2_4JmDOAEm57cEOAAm0<0000UB[a>gDZlC_e>g4kmB]a:gDJlA]eJEEifFUICC4l/
Dda?;4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oG:aM]9b/GKBL[400P0<0;a6_4JLAYa>g5;m
C]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l27oo00<007ooOol00goo000dOol00`00Oomoo`0`Ool2B[`01DZmB]a>gDkLC]d00T:m1E7d
00Y2O3ik@Wa>g4kMC]a>gDkLC_e>g096_@05GWIJEUYFFUINMP03?U/01TkMC]a>g4kLD_e>g09>o007
D_e>g4kmC_a>gD[LC]d00WKB00=b/GKB00`00P0<0TkL00E>gDkLD_a>o5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@0<Ool00`00Oomoo`03Ool003Eoo`80
031oo`0fA[a:gDJlB[e:g4kMB]a6_D:lEOAAm5GdDO=Em3ik@W`nNd9lB]a>gD[LC_e:g4kMB]a:gDJl
GWIJEEifFUHnG3Xk?U`jFe;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4:mL[5fdW:aM]9b/@0=0`0<0;=>
gD[LC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m00mo
o`03001oogoo00=oo`00=goo00<007ooOol0;Woo00E:g4kMB]a>gD[L009:g@03A[eAm57d00AAm00;
B]a:gDZlB]a>g4kmC]a>gD[MC]e:g002FUH05UifFUIJEUYFB]a:_4[LB[a>oDkLC_a>g5;mC]a>oDkl
C_e>g4kmC]afdW:a0gKB1DJL00A>o4kLD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo003001oogoo015oo`03001oogoo00=oo`00>7oo00<007ooOol0;Woo03I:_4kMB]a>gD[L
C]e2_EGdDO=Em57dEOAAl`00B[a>gDZlC]e>g4kmC]a:gDJlA]eJEEifFUINMUYECba?:dkMB[a>gDZl
D_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[LM]9b/GKBL[5fdTJKA[`2AY`0ZdJKD_e>g5;mC]aBoDklD_e>
g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo003Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool003Uoo`03
001oogoo02ioo`04B]a>gDkLC]d2@[d5DO@300000dkLC]e>g002C]`01DkmC]a6_DJmA]d00eYF00EN
MSiK?U/nFdkM00=>g00;D_e>g4klC_aBoDkLC_e>o4kMB]a>g@02M]8017:aM]9fdP0<1DkL00ABo4kl
D_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l27oo00<007ooOol03goo00<007ooOol00goo000jOol2
000_Ool0fT[LC_e:g4kMB]a6_E7dEOAAleGdDOA2O3ik@Wa:g4kMB]a>oDkLC_e:g4[MA[aNMUYEGWIJ
ESiL>U/nG3YKC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kmL[5fdW:aM]80300=B]a>gD[LC]e>
g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d;Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003aoo`03001o
ogoo02eoo`05B]a:gD[MB]e2_@05DO@2@W`02Cik@Wa>g4kmC]a>gD[MC]e:g002A[d015ifFUIJEUYF
13iK00I>oDkLC_a>g5;mC]`2C_`01TkmC]a>oDkL@[eb/@=fdP09L[40300<00a>g4klC]aBoDkl009B
o005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_aoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool003eoo`03001oogoo02moo`0`
B]a>gE7cEOAAm5GdDO=F54ZlC]e:_4kMC]a>oDkLC_e:g4kMB]aNMUYFGWIJEEifB`]>gDZlC]e:_5;m
C]aBoDkLD_e>g5;mC]a>oDkLD_e>g7KBL[5fdW:aM]9b/DJl0TJL09e>g5;mC]aBoDkLD_e>o5;mC]aB
oE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol0
0`00Oomoo`0>Ool00`00Oomoo`02Ool003ioo`03001oogoo02moo`03@[e6_E7d00AAm00;001:g4[M
B[a:g4kLC_e>g4kMA[e6g@03FUH02UifBb]?:dl[B]a:_4[LB[aBoDkL0Tkl00YBoDkLC_e>o4kMB]a>
gD[MM]9b/@=fdPA6W004C]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`00e;mOomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`02Ool003moo`03001o
ogoo02ioo`06A[e2_EGdDO=F557d0`000;i:g4kMB]a>oDkLC_e:g4kmA[a6gEYEGWIJEUif>U/nG3YK
C_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kmL[5fdW:aM]9b/@0=B]a>gD[LC]e>g5;mC]aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAaoo`03001oogoo00eo
o`03001oogoo009oo`00@7oo0P00;goo00=2_E7dDO@00e7d00E2O3ik@Wa>g4kM009>g006B]e>gD[L
C]e6_Eif0eYF13iK00I>oDkLC_a>g5;mC]`2C_`01e;mC]a>oDklC]e:g4kM009fdP04L[9fdP0<00d4
C]`014klD_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0NOol0
0`00Oomoo`0<Ool00`00Oomoo`02Ool0049oo`03001oogoo02aoo`2o@[aF557dEOAAleHDDOA2O3ik
@Wa>g4kmC]a>oD[LC]e:g4kmA[aNMUYEGWIJETkMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
@[eb/GKBL[5fdW:a00d0300=C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo00UOol00`00Oomoo`0;Ool00`00Oomoo`02Ool004=oo`03001oogoo02aoo`03@[eAm57d00=A
m00;001:gDZlB]a>g4kmC]a>gDJmA]e6_@02FUH02UifFUI;:d/;B]a:_4[LB[aBoDkL0Tkl00YBoDkL
C_e>o4kmC]a>oDkLM]9b/P=fdP0300a6W4JL0096W003C_a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
15;mD_aBo5;l:7oo00<007ooOol02goo00<007ooOol00Woo0014Ool00`00Oomoo`0[Ool01DJmDO=F
557dEO@00`000:m>gDZlC]e>g4kmB]a>oDJlA]e6_5ifFUINMT/;Cb];2dkmC]a>oDkLD_e>g5;mC]aB
oDkLD_e>g4kMB]a>oD[LM]9b/GKBL[403@0<C]e:g4kMB]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@0]Ool00`00Oomoo`0;Ool00`00Oomoo`01Ool004Eoo`8002]oo`03@[eAm57d009Am005OolnNd9l
@Wa>g@03C]`01DkmC]a>gDJmA]d00eYF00ENMSiK?U/nFdkM00=>g00BD_e>g4klC_aBoDkLC_e>o4kM
B]a>gGJbM]9b/WKB00`03@0<14kL0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo35oo`03001oogoo00Yoo`03001o
ogoo005oo`00Agoo00<007ooOol0:Goo00=Am5GdDO<00Woo0:]2O3ik@W`nNdkmC]a>oDkLC]e:g4km
A[a6gEYEGWIJEUif>U/nG3YKD_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkL@[eb/GKBL[5fdW:a00d0300=
C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d0=Goo00<007ooOol02Goo00<007ooOol00Goo0018Ool00`00Oomo
o`0XOol3DO@3Ool03D[MB[a:g4[LC_e>g4kMC]a>gD[LC]eJEUif00=JEP0F001:_4[LB[a>oDkLC_a>
g5;mC]a>oDklC_e>g4kmC]afdW:bM]9f/WKBL[83AY`014kLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo3Uoo`03001oogoo00Uoo`03
001oogoo005oo`00BGoo00<007ooOol0:7oo00=F557dOol00goo00i>gDZlC]e:_4kmB]a>oDkLA]e6
_5ifFUINMUYE0`0001I:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC]e:g4kmB]afdW:aM]9b/GKBAY]6_096
W01iC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`0?Goo00<007ooOol027oo00<007ooOol00Goo001:Ool2000XOol00e7dOomoo`04Ool02TkM
C]a>g4kLC_e>g4kMC]a6gDJm0UYF00=NMUYF?U/00SiK0dkL015>gDkLC_a>o5;mC]a>oDklC]e:g4kM
M[9fdW:bM]9b/P0=00E>g003D_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;m
D_aBo5;lD_eBo45oo`03001oogoo00Moo`03001oogoo005oo`00C7oo00<007ooOol09Goo00=Em7oo
Ool01Goo09U>gD[LC_e:g4kMB]a>oD[LA]eJEEifFUINMSYK?U`jFciKC]aBoDkLD_e>g5;mC]aBoDkL
D_e>g4kMB]a>oG:aM]9b/GKB00`03D[LC]e:g4kMC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d0AWoo00<007ooOol01Woo00<007ooOol00Goo001=Ool00`00Oomoo`0]Ool0
2DkmC]a>gDkLC]e:g4kMB]e6g@03FUH05UifB[a:g4ZlB]a>g4klC]a>oDkLC_e>o5;mC]a>oDkL@[eb
/WKBL[9fdW:b0`0=00E>g4klC]aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
Oomoo`17Ool00`00Oomoo`07Ool10001Ool1Ool004ioo`03001oogoo02ioo`0:C]a>oDkLA]e6_4[M
FUINMUYEGWH200005TZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e>g7KBL[5fdW:aM]9b/DJl0TJL
06a6Ve;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_e=Ool00`00Oomoo`06Ool10001Ool1
Ool004moo`8002moo`04C]a>gDkLA]d2A[d015YFGWIJEUYF0SiK0dkL019>gDkLC_a>o5;mC]a>oDkl
D_e:g4kMB]efdW:bM]9b/WKB00d4C]`015;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;lDWoo00<007ooOol0
1Goo0@000Goo0Goo001AOol00`00Oomoo`0]Ool0Qd[LC_e>g4KMA[aNMUYFGWIJECiL>U/nFdkLC_e>
g4kmC]aBoDkLD_e>g5;mC]aBoD[LC_e:g7KBL[5fdW:b00d034kMB]a>gD[LD_e>g5;mC]aBoE;lD_e>
g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o01EOol00`00Oomoo`05Ool10001Ool1Ool0059oo`03001oogoo02eoo`05B]a>gD[MA]e6_@02FUH0
0eiFFUHnF`02?U/01DkLC_a>g4kmC]`00Tkl00]BoDkLC_e>g4km@[efdW:bM]9b/WKB00<03@04C_a>
g5;mC]`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_aIOol00`00Oomoo`04Ool10001Ool1Ool005=oo`03001oogoo02eoo`07B]a>
oD[LGWIJEEifFUH00P0001E>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_eb/GKBL[9fdW:a00d0
0TJL05m6Ve;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l05eoo`03001oogoo00=oo`40005oo`5oo`00E7oo00<007ooOol0;Goo0TJm
00=JEUiFFUH010000TkL019>gDkLC_a>o5;mC]a>oDklD_e:g4kMB]e>gG:bM]9b/WKB00d4AY`015;l
C_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l069o
o`03001oogoo00=oo`40005oo`00EGoo0P00;Woo07I6_4[MFUINMUYEGWHjFciK>U]>oDkLC_e>g5;m
C]aBoDkLD_e>g5;mB]a>oD[LM]9b/GKBL[803@0<C]e:g4kMB]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoFEoo`03001oogoo00=oo`40005oo`00Egoo00<007oo
Ool0;7oo00E6_EYFFUINEUYF00<nF`05C]a>o4kLC_e>g002C_`02e;mC]a>oDkLC_e2_GKBL[9fdW:b
M]800`0=00A>o4kLD_e>g09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_a/Ool00`00
Oomoo`02Ool10001Ool005Qoo`03001oogoo02]oo`0KGWIJEEifFUINMP00C]e:_4kMC]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4kmL[5fdW:bM]9b/GKB0096W01>AY]BoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mLGoo00D007ooOomoo`00005oo`00FGoo00<007ooOol0:Woo00AJEUiFFUIJEP<00004
B]a:_4[LC]`2C_`03U;mC]a>oDklD_e:g4kMB]e>gG:bM]9b/WKBL[84AY`015;lC_aBoDkL0U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_aBo01eOol01000Oomoo`000Goo001JOol2000[Ool0I5YFGWIJEGoo>U/nFcYKC_e>
g4kmC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4kML[5fdW:bM]803DkMB]a>gD[LD_e>g5;mC]aBoE;lD_e>
g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mN7oo00@007ooOol0005oo`00G7oo00<007ooOol0:7oo0UYF0Woo13iK00A>o4kLC_e>g09>o005
D_e>g4kmC_aBo@02@[d01G:bM]9b/W;BL[800`0=0dkL0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_alOol00`00Ool00001Ool0
05eoo`03001oogoo02Qoo`0IGWIoogooOom>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g7KB
L[9fdW:aM]800TJL0496VdJlC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_f0Ool10001Ool1000005ioo`03001oogoo02eoo`03B[a:
g4Zl009>o00?D_e>g4kmC_aBoDkLC]e:gDkMB]abdW:bM]9b/P0=00A6W003C_aBoDkL009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b4Ool2000005moo`80
02ioo`1?C]a>oDkLC_e>g5;mC]aBoDkLD_e>g4kmB]a>gG:aM]9b/WKB00d03T[LC]e:g4kMC]aBoDkL
D_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0R7oo0P00001QOol00`00
Oomoo`0/Ool00dkLC_e>g002C_`035;mC]a>o4klD_e>g4kMB]e>gG:bL]9b/P<03@=>g09Bo005D_e>
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo08Yoo`800000HWoo00<007ooOol0
;7oo011>g5;mC]aBoDkLD_e>g5;mC]a>oDkL@[eb/WKBL[9fdP<03@0aD_e>g5;mC]aBoDkLD_e>g5;m
D_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d0SGoo10000Woo001SOol00`00Oomoo`0/Ool00dklD_e>g002C_`0
2e;mC]a>oDkLC_e>g7;BL[9fdW:bL]8014JL00=>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b<
Ool40006Ool006Aoo`8002eoo`0lC]aBoDkLD_e>g5;mC]aBoD[LC]e:g7KBL[9fdW:b00i:g4kMB]a>
gDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mRgoo10002Woo001VOol00`00Oomoo`0[Ool00dklD_e>g002C_`0
2E;mC]a>gD[MC]eb/W;BL[9fdP0200d4C]`00e;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lRWoo10003Woo001WOol00`00
Oomoo`0[Ool0=4kLD_e>g5;mC]a>oDkL@[eb/WKBL[9fdW:b00h03@0>C]aBoDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mRWoo0`00
4Woo001XOol00`00Oomoo`0[Ool02TklD_e>g4kmC]a>oDkLL]9b/WKB0g:b14JL00EBoDkLC_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo8Uoo`@001Eo
o`00JGoo0P00;7oo02a>g5;mC]aBoD[LC]e:g7KBL[9fdW:bM]803DkMB]a>gD[LD_e>g5;mD_aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MR7oo10006Goo001[Ool00`00
Oomoo`0ZOol01dklD_e>g4kmB]e>gD[L009b/P04M]9b/P0=00d3C]`00e;lD_e>o002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Moo`@001eoo`00K7oo00<007ooOol0:Woo
025>g4kmC]aBoCjmM]9b/WKBL[9fdP0=00h03E;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_`0RGoo10008Goo001]Ool00`00Oomoo`0[Ool01DkmC]a>oG:bM]800g:b00T03TJLAYa6
W5;mC]a>o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo8Uoo`<002Eoo`00KWoo00<007ooOol0:goo01Q>
gD[LC_eb/WKBL[9fd`0=C]e:g4kMB]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_b8Ool4000XOol006mo
o`8002aoo`08C]e:g4kML[9bdW:b00h03@A>g005D_e>o5;lD_aBo@03D_b7Ool4000/Ool0075oo`03
001oogoo02Yoo`0@M]9b/WKCL[9fdP0=00h03E;mC]aBoDkLD_e>g5;mC]b6Ool4000`Ool0079oo`03
001oogoo02Uoo`06L[9bdW:bL[8007oo14JLR7oo1000=7oo001cOol00`00Oomoo`0YOol017:bM]9o
o`00RGoo1000>7oo001dOol2000/Ool00`00Oomoo`24Ool3000lOol007Ioo`03001oogoo02Uoo`03
001oogoo081oo`@003moo`00Mgoo00<007ooOol0:7oo00<007ooOol0O7oo1000@goo001hOol00`00
Oomoo`0WOol00`00Oomoo`1hOol40017Ool007Uoo`8002Moo`03001oogoo07Aoo`@004]oo`00Ngoo
00<007ooOol097oo00<007ooOol0LGoo0`00Cgoo001lOol00`00Oomoo`0SOol00`00Oomoo`1]Ool4
001BOol007eoo`03001oogoo029oo`03001oogoo06Uoo`@005Ioo`00OWoo0P008Woo00<007ooOol0
IGoo1000FWoo0020Ool00`00Oomoo`0OOol00`00Oomoo`1QOol4001NOol0085oo`03001oogoo01io
o`03001oogoo05ioo`<0069oo`00PWoo00<007ooOol07Goo00<007ooOol0FWoo1000IGoo0023Ool0
0`00Oomoo`0LOol00`00Oomoo`1FOol4001YOol008Aoo`8001aoo`03001oogoo059oo`@006eoo`00
QWoo00<007ooOol06Goo00<007ooOol0CWoo1000LGoo0027Ool00`00Oomoo`0HOol00`00Oomoo`1;
Ool3001eOol008Qoo`03001oogoo01Moo`03001oogoo04Moo`@007Qoo`00RGoo0P005goo00<007oo
Ool0@goo1000O7oo002;Ool00`00Oomoo`0DOol00`00Oomoo`0oOol40020Ool008aoo`03001oogoo
019oo`03001oogoo03aoo`@008Aoo`00SGoo00<007ooOol04Goo00<007ooOol0>Goo0`00R7oo002>
Ool2000AOol00`00Oomoo`0eOol4002;Ool0091oo`03001oogoo00ioo`03001oogoo035oo`@008mo
o`00TGoo00<007ooOol03Goo00<007ooOol0;Goo1000Tgoo002BOol00`00Oomoo`0<Ool00`00Oomo
o`0YOol4002GOol009=oo`8000aoo`03001oogoo02Eoo`@009]oo`00UGoo00<007ooOol02Goo00<0
07ooOol08Woo0`00Wgoo002FOol00`00Oomoo`08Ool00`00Oomoo`0NOol4002ROol009Moo`03001o
ogoo00Moo`03001oogoo01Yoo`@00:Ioo`00V7oo00<007ooOol01Woo00<007ooOol05Woo1000ZWoo
002IOol20006Ool00`00Oomoo`0BOol4002^Ool009]oo`03001oogoo00=oo`03001oogoo00moo`<0
0;9oo`00W7oo00<007ooOol00Woo00<007ooOol02goo1000]Goo002MOol01@00Oomoogoo00002Goo
1000^Goo002NOol200000goo001oo`04Ool4002mOol00:1oo`800003Ool0000000800<5oo`00XGoo
0P00aGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.575 .708 .932 r
.39632 .69843 .40163 .70356 .41024 .71096 .40521 .69755 Mtetra
.734 .607 .715 r
.40521 .69755 .41024 .71096 .41961 .69526 .41441 .68778 Mtetra
.509 .598 .879 r
.41441 .68778 .41961 .69526 .42856 .69381 .4233 .68877 Mtetra
.633 .731 .919 r
.4233 .68877 .42856 .69381 .43756 .69159 .43231 .68675 Mtetra
.647 .744 .92 r
.43231 .68675 .43756 .69159 .4466 .68917 .44137 .68439 Mtetra
.652 .748 .92 r
.44137 .68439 .4466 .68917 .45567 .68666 .45046 .6819 Mtetra
.655 .751 .92 r
.45046 .6819 .45567 .68666 .46477 .68409 .45958 .67934 Mtetra
.657 .752 .92 r
.45958 .67934 .46477 .68409 .47391 .68146 .46873 .67671 Mtetra
.658 .753 .92 r
.46873 .67671 .47391 .68146 .48307 .67881 .47792 .67406 Mtetra
.659 .754 .92 r
.47792 .67406 .48307 .67881 .49227 .67614 .48713 .67137 Mtetra
.48713 .67137 .49227 .67614 .50149 .67347 .49638 .66868 Mtetra
.49638 .66868 .50149 .67347 .51075 .67078 .50565 .66598 Mtetra
.50565 .66598 .51075 .67078 .52004 .6681 .51496 .66327 Mtetra
.658 .753 .92 r
.51496 .66327 .52004 .6681 .52936 .66541 .5243 .66057 Mtetra
.5243 .66057 .52936 .66541 .53871 .66272 .53367 .65786 Mtetra
.53367 .65786 .53871 .66272 .54809 .66003 .54308 .65514 Mtetra
.54308 .65514 .54809 .66003 .5575 .65732 .55251 .65242 Mtetra
.55251 .65242 .5575 .65732 .56695 .65462 .56198 .6497 Mtetra
.56198 .6497 .56695 .65462 .57642 .6519 .57148 .64696 Mtetra
.657 .753 .92 r
.57148 .64696 .57642 .6519 .58593 .64918 .58101 .64422 Mtetra
.58101 .64422 .58593 .64918 .59547 .64645 .59057 .64147 Mtetra
.59057 .64147 .59547 .64645 .60505 .64371 .60017 .63872 Mtetra
.60017 .63872 .60505 .64371 .61466 .64096 .6098 .63595 Mtetra
.657 .752 .92 r
.6098 .63595 .61466 .64096 .6243 .63821 .61946 .63318 Mtetra
.61946 .63318 .6243 .63821 .63397 .63545 .62916 .6304 Mtetra
.62916 .6304 .63397 .63545 .64368 .63267 .63889 .62761 Mtetra
.63889 .62761 .64368 .63267 .65342 .62989 .64865 .62481 Mtetra
.64865 .62481 .65342 .62989 .66319 .6271 .65845 .622 Mtetra
.65845 .622 .66319 .6271 .673 .62431 .66828 .61919 Mtetra
.66828 .61919 .673 .62431 .68284 .6215 .67814 .61636 Mtetra
.67814 .61636 .68284 .6215 .69272 .61868 .68804 .61353 Mtetra
.68804 .61353 .69272 .61868 .70263 .61586 .69798 .61068 Mtetra
.69798 .61068 .70263 .61586 .71257 .61302 .70795 .60783 Mtetra
.70795 .60783 .71257 .61302 .72255 .61018 .71795 .60497 Mtetra
.71795 .60497 .72255 .61018 .73257 .60733 .72799 .6021 Mtetra
.72799 .6021 .73257 .60733 .74262 .60446 .73806 .59921 Mtetra
.73806 .59921 .74262 .60446 .7527 .60159 .74818 .59632 Mtetra
.74818 .59632 .7527 .60159 .76282 .59871 .75832 .59342 Mtetra
.75832 .59342 .76282 .59871 .77298 .59582 .7685 .59051 Mtetra
.7685 .59051 .77298 .59582 .78317 .59291 .77872 .58759 Mtetra
.77872 .58759 .78317 .59291 .7934 .59 .78898 .58466 Mtetra
.78898 .58466 .7934 .59 .80367 .58708 .79927 .58172 Mtetra
.79927 .58172 .80367 .58708 .81397 .58415 .80959 .57877 Mtetra
.80959 .57877 .81397 .58415 .82431 .58121 .81996 .5758 Mtetra
.81996 .5758 .82431 .58121 .83468 .57825 .83036 .57283 Mtetra
.83036 .57283 .83468 .57825 .84509 .57529 .8408 .56985 Mtetra
.8408 .56985 .84509 .57529 .85554 .57232 .85127 .56686 Mtetra
.85127 .56686 .85554 .57232 .86603 .56934 .86179 .56386 Mtetra
.86179 .56386 .86603 .56934 .87655 .56634 .87234 .56084 Mtetra
.87234 .56084 .87655 .56634 .88711 .56334 .88293 .55782 Mtetra
.88293 .55782 .88711 .56334 .89772 .56032 .89356 .55478 Mtetra
.89356 .55478 .89772 .56032 .90835 .5573 .90423 .55174 Mtetra
.90423 .55174 .90835 .5573 .91903 .55426 .91493 .54868 Mtetra
.91493 .54868 .91903 .55426 .92975 .55122 .92568 .54561 Mtetra
.92568 .54561 .92975 .55122 .9405 .54816 .93646 .54254 Mtetra
.93646 .54254 .9405 .54816 .9513 .54509 .94728 .53945 Mtetra
.94728 .53945 .9513 .54509 .96213 .54201 .95815 .53635 Mtetra
.95815 .53635 .96213 .54201 .973 .53892 .96905 .53324 Mtetra
.96905 .53324 .973 .53892 .98392 .53582 .97999 .53011 Mtetra
.62 .73 .925 r
.39097 .69346 .39632 .69843 .40521 .69755 .3999 .6917 Mtetra
0 .163 .676 r
.3999 .6917 .40521 .69755 .41441 .68778 .40856 .6991 Mtetra
0 0 0 r
.40856 .6991 .41441 .68778 .4233 .68877 .41802 .6833 Mtetra
.61 .709 .915 r
.41802 .6833 .4233 .68877 .43231 .68675 .42703 .68181 Mtetra
.642 .74 .92 r
.42703 .68181 .43231 .68675 .44137 .68439 .4361 .67955 Mtetra
.65 .747 .92 r
.4361 .67955 .44137 .68439 .45046 .6819 .44521 .6771 Mtetra
.654 .75 .92 r
.44521 .6771 .45046 .6819 .45958 .67934 .45435 .67454 Mtetra
.656 .751 .92 r
.45435 .67454 .45958 .67934 .46873 .67671 .46352 .67193 Mtetra
.658 .753 .92 r
.46352 .67193 .46873 .67671 .47792 .67406 .47273 .66927 Mtetra
.659 .753 .92 r
.47273 .66927 .47792 .67406 .48713 .67137 .48196 .66657 Mtetra
.659 .754 .92 r
.48196 .66657 .48713 .67137 .49638 .66868 .49123 .66386 Mtetra
.49123 .66386 .49638 .66868 .50565 .66598 .50053 .66114 Mtetra
.50053 .66114 .50565 .66598 .51496 .66327 .50986 .65842 Mtetra
.658 .753 .92 r
.50986 .65842 .51496 .66327 .5243 .66057 .51922 .65569 Mtetra
.51922 .65569 .5243 .66057 .53367 .65786 .52861 .65296 Mtetra
.52861 .65296 .53367 .65786 .54308 .65514 .53803 .65023 Mtetra
.53803 .65023 .54308 .65514 .55251 .65242 .54749 .64749 Mtetra
.54749 .64749 .55251 .65242 .56198 .6497 .55698 .64474 Mtetra
.55698 .64474 .56198 .6497 .57148 .64696 .5665 .64199 Mtetra
.5665 .64199 .57148 .64696 .58101 .64422 .57605 .63923 Mtetra
.657 .753 .92 r
.57605 .63923 .58101 .64422 .59057 .64147 .58564 .63647 Mtetra
.58564 .63647 .59057 .64147 .60017 .63872 .59525 .63369 Mtetra
.59525 .63369 .60017 .63872 .6098 .63595 .60491 .63091 Mtetra
.657 .752 .92 r
.60491 .63091 .6098 .63595 .61946 .63318 .61459 .62812 Mtetra
.61459 .62812 .61946 .63318 .62916 .6304 .62431 .62532 Mtetra
.62431 .62532 .62916 .6304 .63889 .62761 .63406 .62251 Mtetra
.63406 .62251 .63889 .62761 .64865 .62481 .64385 .6197 Mtetra
.64385 .6197 .64865 .62481 .65845 .622 .65367 .61687 Mtetra
.65367 .61687 .65845 .622 .66828 .61919 .66352 .61404 Mtetra
.66352 .61404 .66828 .61919 .67814 .61636 .67341 .61119 Mtetra
.67341 .61119 .67814 .61636 .68804 .61353 .68334 .60834 Mtetra
.68334 .60834 .68804 .61353 .69798 .61068 .6933 .60548 Mtetra
.6933 .60548 .69798 .61068 .70795 .60783 .70329 .6026 Mtetra
.70329 .6026 .70795 .60783 .71795 .60497 .71332 .59972 Mtetra
.71332 .59972 .71795 .60497 .72799 .6021 .72338 .59683 Mtetra
.72338 .59683 .72799 .6021 .73806 .59921 .73348 .59393 Mtetra
.73348 .59393 .73806 .59921 .74818 .59632 .74362 .59102 Mtetra
.74362 .59102 .74818 .59632 .75832 .59342 .75379 .5881 Mtetra
.75379 .5881 .75832 .59342 .7685 .59051 .764 .58517 Mtetra
.764 .58517 .7685 .59051 .77872 .58759 .77424 .58223 Mtetra
.77424 .58223 .77872 .58759 .78898 .58466 .78452 .57928 Mtetra
.78452 .57928 .78898 .58466 .79927 .58172 .79484 .57632 Mtetra
.79484 .57632 .79927 .58172 .80959 .57877 .80519 .57335 Mtetra
.80519 .57335 .80959 .57877 .81996 .5758 .81558 .57037 Mtetra
.81558 .57037 .81996 .5758 .83036 .57283 .82601 .56737 Mtetra
.82601 .56737 .83036 .57283 .8408 .56985 .83648 .56437 Mtetra
.83648 .56437 .8408 .56985 .85127 .56686 .84698 .56136 Mtetra
.84698 .56136 .85127 .56686 .86179 .56386 .85752 .55834 Mtetra
.85752 .55834 .86179 .56386 .87234 .56084 .8681 .5553 Mtetra
.8681 .5553 .87234 .56084 .88293 .55782 .87872 .55226 Mtetra
.87872 .55226 .88293 .55782 .89356 .55478 .88938 .5492 Mtetra
.88938 .5492 .89356 .55478 .90423 .55174 .90007 .54614 Mtetra
.90007 .54614 .90423 .55174 .91493 .54868 .9108 .54306 Mtetra
.9108 .54306 .91493 .54868 .92568 .54561 .92158 .53997 Mtetra
.92158 .53997 .92568 .54561 .93646 .54254 .93239 .53687 Mtetra
.93239 .53687 .93646 .54254 .94728 .53945 .94324 .53376 Mtetra
.94324 .53376 .94728 .53945 .95815 .53635 .95414 .53064 Mtetra
.95414 .53064 .95815 .53635 .96905 .53324 .96507 .52751 Mtetra
.96507 .52751 .96905 .53324 .97999 .53011 .97604 .52437 Mtetra
.633 .737 .923 r
.38558 .68853 .39097 .69346 .3999 .6917 .39454 .68648 Mtetra
.575 .708 .932 r
.39454 .68648 .3999 .6917 .40856 .6991 .40349 .68557 Mtetra
.734 .607 .715 r
.40349 .68557 .40856 .6991 .41802 .6833 .41277 .67574 Mtetra
.508 .598 .879 r
.41277 .67574 .41802 .6833 .42703 .68181 .42172 .67669 Mtetra
.633 .731 .919 r
.42172 .67669 .42703 .68181 .4361 .67955 .43081 .67464 Mtetra
.647 .744 .92 r
.43081 .67464 .4361 .67955 .44521 .6771 .43993 .67224 Mtetra
.652 .748 .92 r
.43993 .67224 .44521 .6771 .45435 .67454 .44909 .66971 Mtetra
.655 .751 .92 r
.44909 .66971 .45435 .67454 .46352 .67193 .45828 .6671 Mtetra
.657 .752 .92 r
.45828 .6671 .46352 .67193 .47273 .66927 .46751 .66444 Mtetra
.658 .753 .92 r
.46751 .66444 .47273 .66927 .48196 .66657 .47676 .66174 Mtetra
.659 .754 .92 r
.47676 .66174 .48196 .66657 .49123 .66386 .48605 .65901 Mtetra
.48605 .65901 .49123 .66386 .50053 .66114 .49537 .65628 Mtetra
.49537 .65628 .50053 .66114 .50986 .65842 .50472 .65353 Mtetra
.50472 .65353 .50986 .65842 .51922 .65569 .5141 .65079 Mtetra
.658 .753 .92 r
.5141 .65079 .51922 .65569 .52861 .65296 .52351 .64804 Mtetra
.52351 .64804 .52861 .65296 .53803 .65023 .53296 .64528 Mtetra
.53296 .64528 .53803 .65023 .54749 .64749 .54243 .64253 Mtetra
.54243 .64253 .54749 .64749 .55698 .64474 .55194 .63976 Mtetra
.55194 .63976 .55698 .64474 .5665 .64199 .56149 .63699 Mtetra
.56149 .63699 .5665 .64199 .57605 .63923 .57106 .63421 Mtetra
.657 .753 .92 r
.57106 .63421 .57605 .63923 .58564 .63647 .58067 .63143 Mtetra
.58067 .63143 .58564 .63647 .59525 .63369 .59031 .62864 Mtetra
.59031 .62864 .59525 .63369 .60491 .63091 .59998 .62584 Mtetra
.59998 .62584 .60491 .63091 .61459 .62812 .60969 .62303 Mtetra
.657 .752 .92 r
.60969 .62303 .61459 .62812 .62431 .62532 .61943 .62021 Mtetra
.61943 .62021 .62431 .62532 .63406 .62251 .62921 .61738 Mtetra
.62921 .61738 .63406 .62251 .64385 .6197 .63902 .61455 Mtetra
.63902 .61455 .64385 .6197 .65367 .61687 .64886 .6117 Mtetra
.64886 .6117 .65367 .61687 .66352 .61404 .65874 .60885 Mtetra
.65874 .60885 .66352 .61404 .67341 .61119 .66865 .60599 Mtetra
.66865 .60599 .67341 .61119 .68334 .60834 .6786 .60312 Mtetra
.6786 .60312 .68334 .60834 .6933 .60548 .68859 .60023 Mtetra
.68859 .60023 .6933 .60548 .70329 .6026 .6986 .59734 Mtetra
.6986 .59734 .70329 .6026 .71332 .59972 .70866 .59444 Mtetra
.70866 .59444 .71332 .59972 .72338 .59683 .71875 .59153 Mtetra
.71875 .59153 .72338 .59683 .73348 .59393 .72887 .58861 Mtetra
.72887 .58861 .73348 .59393 .74362 .59102 .73903 .58568 Mtetra
.73903 .58568 .74362 .59102 .75379 .5881 .74923 .58274 Mtetra
.74923 .58274 .75379 .5881 .764 .58517 .75946 .57979 Mtetra
.75946 .57979 .764 .58517 .77424 .58223 .76973 .57683 Mtetra
.76973 .57683 .77424 .58223 .78452 .57928 .78004 .57386 Mtetra
.78004 .57386 .78452 .57928 .79484 .57632 .79038 .57088 Mtetra
.79038 .57088 .79484 .57632 .80519 .57335 .80076 .56789 Mtetra
.80076 .56789 .80519 .57335 .81558 .57037 .81118 .56489 Mtetra
.81118 .56489 .81558 .57037 .82601 .56737 .82163 .56188 Mtetra
.82163 .56188 .82601 .56737 .83648 .56437 .83213 .55886 Mtetra
.83213 .55886 .83648 .56437 .84698 .56136 .84266 .55583 Mtetra
.84266 .55583 .84698 .56136 .85752 .55834 .85322 .55278 Mtetra
.85322 .55278 .85752 .55834 .8681 .5553 .86383 .54973 Mtetra
.86383 .54973 .8681 .5553 .87872 .55226 .87448 .54666 Mtetra
.87448 .54666 .87872 .55226 .88938 .5492 .88516 .54359 Mtetra
.88516 .54359 .88938 .5492 .90007 .54614 .89589 .5405 Mtetra
.89589 .5405 .90007 .54614 .9108 .54306 .90665 .5374 Mtetra
.90665 .5374 .9108 .54306 .92158 .53997 .91745 .53429 Mtetra
.91745 .53429 .92158 .53997 .93239 .53687 .92829 .53117 Mtetra
.92829 .53117 .93239 .53687 .94324 .53376 .93918 .52804 Mtetra
.93918 .52804 .94324 .53376 .95414 .53064 .9501 .5249 Mtetra
.9501 .5249 .95414 .53064 .96507 .52751 .96106 .52175 Mtetra
.96106 .52175 .96507 .52751 .97604 .52437 .97206 .51858 Mtetra
.638 .74 .922 r
.38016 .68361 .38558 .68853 .39454 .68648 .38914 .68144 Mtetra
.62 .73 .925 r
.38914 .68144 .39454 .68648 .40349 .68557 .39814 .67964 Mtetra
0 .168 .681 r
.39814 .67964 .40349 .68557 .41277 .67574 .40687 .68704 Mtetra
0 0 0 r
.40687 .68704 .41277 .67574 .42172 .67669 .4164 .67115 Mtetra
.61 .709 .915 r
.4164 .67115 .42172 .67669 .43081 .67464 .42548 .66962 Mtetra
.642 .74 .92 r
.42548 .66962 .43081 .67464 .43993 .67224 .43462 .66733 Mtetra
.65 .747 .92 r
.43462 .66733 .43993 .67224 .44909 .66971 .4438 .66483 Mtetra
.654 .75 .92 r
.4438 .66483 .44909 .66971 .45828 .6671 .45301 .66223 Mtetra
.656 .751 .92 r
.45301 .66223 .45828 .6671 .46751 .66444 .46225 .65958 Mtetra
.658 .753 .92 r
.46225 .65958 .46751 .66444 .47676 .66174 .47153 .65687 Mtetra
.659 .753 .92 r
.47153 .65687 .47676 .66174 .48605 .65901 .48084 .65414 Mtetra
.659 .754 .92 r
.48084 .65414 .48605 .65901 .49537 .65628 .49018 .65138 Mtetra
.49018 .65138 .49537 .65628 .50472 .65353 .49955 .64862 Mtetra
.49955 .64862 .50472 .65353 .5141 .65079 .50895 .64585 Mtetra
.658 .753 .92 r
.50895 .64585 .5141 .65079 .52351 .64804 .51838 .64308 Mtetra
.51838 .64308 .52351 .64804 .53296 .64528 .52785 .64031 Mtetra
.52785 .64031 .53296 .64528 .54243 .64253 .53735 .63753 Mtetra
.53735 .63753 .54243 .64253 .55194 .63976 .54688 .63475 Mtetra
.54688 .63475 .55194 .63976 .56149 .63699 .55644 .63196 Mtetra
.55644 .63196 .56149 .63699 .57106 .63421 .56604 .62916 Mtetra
.56604 .62916 .57106 .63421 .58067 .63143 .57567 .62636 Mtetra
.657 .753 .92 r
.57567 .62636 .58067 .63143 .59031 .62864 .58533 .62355 Mtetra
.58533 .62355 .59031 .62864 .59998 .62584 .59503 .62073 Mtetra
.59503 .62073 .59998 .62584 .60969 .62303 .60476 .6179 Mtetra
.657 .752 .92 r
.60476 .6179 .60969 .62303 .61943 .62021 .61453 .61507 Mtetra
.61453 .61507 .61943 .62021 .62921 .61738 .62432 .61222 Mtetra
.62432 .61222 .62921 .61738 .63902 .61455 .63416 .60937 Mtetra
.63416 .60937 .63902 .61455 .64886 .6117 .64403 .6065 Mtetra
.64403 .6065 .64886 .6117 .65874 .60885 .65393 .60363 Mtetra
.65393 .60363 .65874 .60885 .66865 .60599 .66386 .60075 Mtetra
.66386 .60075 .66865 .60599 .6786 .60312 .67384 .59786 Mtetra
.67384 .59786 .6786 .60312 .68859 .60023 .68384 .59496 Mtetra
.68384 .59496 .68859 .60023 .6986 .59734 .69389 .59205 Mtetra
.69389 .59205 .6986 .59734 .70866 .59444 .70396 .58913 Mtetra
.70396 .58913 .70866 .59444 .71875 .59153 .71408 .5862 Mtetra
.71408 .5862 .71875 .59153 .72887 .58861 .72423 .58326 Mtetra
.72423 .58326 .72887 .58861 .73903 .58568 .73441 .58031 Mtetra
.73441 .58031 .73903 .58568 .74923 .58274 .74463 .57735 Mtetra
.74463 .57735 .74923 .58274 .75946 .57979 .75489 .57438 Mtetra
.75489 .57438 .75946 .57979 .76973 .57683 .76519 .5714 Mtetra
.76519 .5714 .76973 .57683 .78004 .57386 .77552 .56841 Mtetra
.77552 .56841 .78004 .57386 .79038 .57088 .78589 .56541 Mtetra
.78589 .56541 .79038 .57088 .80076 .56789 .7963 .5624 Mtetra
.7963 .5624 .80076 .56789 .81118 .56489 .80674 .55938 Mtetra
.80674 .55938 .81118 .56489 .82163 .56188 .81722 .55635 Mtetra
.81722 .55635 .82163 .56188 .83213 .55886 .82774 .55331 Mtetra
.82774 .55331 .83213 .55886 .84266 .55583 .8383 .55025 Mtetra
.8383 .55025 .84266 .55583 .85322 .55278 .8489 .54719 Mtetra
.8489 .54719 .85322 .55278 .86383 .54973 .85954 .54411 Mtetra
.85954 .54411 .86383 .54973 .87448 .54666 .87021 .54103 Mtetra
.87021 .54103 .87448 .54666 .88516 .54359 .88092 .53793 Mtetra
.88092 .53793 .88516 .54359 .89589 .5405 .89167 .53482 Mtetra
.89167 .53482 .89589 .5405 .90665 .5374 .90247 .53171 Mtetra
.90247 .53171 .90665 .5374 .91745 .53429 .9133 .52858 Mtetra
.9133 .52858 .91745 .53429 .92829 .53117 .92417 .52543 Mtetra
.92417 .52543 .92829 .53117 .93918 .52804 .93508 .52228 Mtetra
.93508 .52228 .93918 .52804 .9501 .5249 .94603 .51912 Mtetra
.94603 .51912 .9501 .5249 .96106 .52175 .95702 .51594 Mtetra
.95702 .51594 .96106 .52175 .97206 .51858 .96806 .51276 Mtetra
.64 .74 .921 r
.3747 .67867 .38016 .68361 .38914 .68144 .3837 .67644 Mtetra
.633 .737 .923 r
.3837 .67644 .38914 .68144 .39814 .67964 .39273 .67435 Mtetra
.575 .708 .932 r
.39273 .67435 .39814 .67964 .40687 .68704 .40175 .67341 Mtetra
.735 .607 .715 r
.40175 .67341 .40687 .68704 .4164 .67115 .41111 .6635 Mtetra
.508 .598 .879 r
.41111 .6635 .4164 .67115 .42548 .66962 .42013 .66443 Mtetra
.633 .731 .919 r
.42013 .66443 .42548 .66962 .43462 .66733 .42928 .66234 Mtetra
.647 .744 .92 r
.42928 .66234 .43462 .66733 .4438 .66483 .43847 .6599 Mtetra
.652 .748 .92 r
.43847 .6599 .4438 .66483 .45301 .66223 .4477 .65732 Mtetra
.655 .751 .92 r
.4477 .65732 .45301 .66223 .46225 .65958 .45697 .65467 Mtetra
.657 .752 .92 r
.45697 .65467 .46225 .65958 .47153 .65687 .46626 .65197 Mtetra
.658 .753 .92 r
.46626 .65197 .47153 .65687 .48084 .65414 .47559 .64922 Mtetra
.659 .754 .92 r
.47559 .64922 .48084 .65414 .49018 .65138 .48495 .64646 Mtetra
.48495 .64646 .49018 .65138 .49955 .64862 .49434 .64368 Mtetra
.49434 .64368 .49955 .64862 .50895 .64585 .50376 .64089 Mtetra
.50376 .64089 .50895 .64585 .51838 .64308 .51322 .6381 Mtetra
.658 .753 .92 r
.51322 .6381 .51838 .64308 .52785 .64031 .52271 .6353 Mtetra
.52271 .6353 .52785 .64031 .53735 .63753 .53223 .63251 Mtetra
.53223 .63251 .53735 .63753 .54688 .63475 .54178 .6297 Mtetra
.54178 .6297 .54688 .63475 .55644 .63196 .55137 .6269 Mtetra
.55137 .6269 .55644 .63196 .56604 .62916 .56099 .62408 Mtetra
.56099 .62408 .56604 .62916 .57567 .62636 .57064 .62126 Mtetra
.657 .753 .92 r
.57064 .62126 .57567 .62636 .58533 .62355 .58033 .61843 Mtetra
.58033 .61843 .58533 .62355 .59503 .62073 .59005 .61559 Mtetra
.59005 .61559 .59503 .62073 .60476 .6179 .5998 .61274 Mtetra
.5998 .61274 .60476 .6179 .61453 .61507 .60959 .60989 Mtetra
.657 .752 .92 r
.60959 .60989 .61453 .61507 .62432 .61222 .61941 .60702 Mtetra
.61941 .60702 .62432 .61222 .63416 .60937 .62926 .60415 Mtetra
.62926 .60415 .63416 .60937 .64403 .6065 .63916 .60127 Mtetra
.63916 .60127 .64403 .6065 .65393 .60363 .64908 .59838 Mtetra
.64908 .59838 .65393 .60363 .66386 .60075 .65904 .59548 Mtetra
.65904 .59548 .66386 .60075 .67384 .59786 .66904 .59257 Mtetra
.66904 .59257 .67384 .59786 .68384 .59496 .67907 .58965 Mtetra
.67907 .58965 .68384 .59496 .69389 .59205 .68914 .58672 Mtetra
.68914 .58672 .69389 .59205 .70396 .58913 .69924 .58378 Mtetra
.69924 .58378 .70396 .58913 .71408 .5862 .70938 .58083 Mtetra
.70938 .58083 .71408 .5862 .72423 .58326 .71955 .57787 Mtetra
.71955 .57787 .72423 .58326 .73441 .58031 .72976 .5749 Mtetra
.72976 .5749 .73441 .58031 .74463 .57735 .74001 .57192 Mtetra
.74001 .57192 .74463 .57735 .75489 .57438 .7503 .56893 Mtetra
.7503 .56893 .75489 .57438 .76519 .5714 .76062 .56594 Mtetra
.76062 .56594 .76519 .5714 .77552 .56841 .77098 .56293 Mtetra
.77098 .56293 .77552 .56841 .78589 .56541 .78137 .5599 Mtetra
.78137 .5599 .78589 .56541 .7963 .5624 .79181 .55687 Mtetra
.79181 .55687 .7963 .5624 .80674 .55938 .80228 .55383 Mtetra
.80228 .55383 .80674 .55938 .81722 .55635 .81279 .55078 Mtetra
.81279 .55078 .81722 .55635 .82774 .55331 .82333 .54772 Mtetra
.82333 .54772 .82774 .55331 .8383 .55025 .83392 .54464 Mtetra
.83392 .54464 .8383 .55025 .8489 .54719 .84455 .54156 Mtetra
.84455 .54156 .8489 .54719 .85954 .54411 .85521 .53846 Mtetra
.85521 .53846 .85954 .54411 .87021 .54103 .86591 .53536 Mtetra
.86591 .53536 .87021 .54103 .88092 .53793 .87665 .53224 Mtetra
.87665 .53224 .88092 .53793 .89167 .53482 .88743 .52911 Mtetra
.88743 .52911 .89167 .53482 .90247 .53171 .89825 .52597 Mtetra
.89825 .52597 .90247 .53171 .9133 .52858 .90912 .52282 Mtetra
.90912 .52282 .9133 .52858 .92417 .52543 .92002 .51966 Mtetra
.92002 .51966 .92417 .52543 .93508 .52228 .93096 .51648 Mtetra
.93096 .51648 .93508 .52228 .94603 .51912 .94194 .5133 Mtetra
.94194 .5133 .94603 .51912 .95702 .51594 .95296 .5101 Mtetra
.95296 .5101 .95702 .51594 .96806 .51276 .96403 .50689 Mtetra
.64 .74 .921 r
.36922 .67368 .3747 .67867 .3837 .67644 .37823 .67144 Mtetra
.638 .74 .922 r
.37823 .67144 .3837 .67644 .39273 .67435 .38728 .66923 Mtetra
.62 .73 .925 r
.38728 .66923 .39273 .67435 .40175 .67341 .39635 .66739 Mtetra
0 .173 .686 r
.39635 .66739 .40175 .67341 .41111 .6635 .40514 .6748 Mtetra
0 0 0 r
.40514 .6748 .41111 .6635 .42013 .66443 .41475 .6588 Mtetra
.61 .709 .915 r
.41475 .6588 .42013 .66443 .42928 .66234 .4239 .65724 Mtetra
.642 .74 .92 r
.4239 .65724 .42928 .66234 .43847 .6599 .43312 .6549 Mtetra
.65 .747 .92 r
.43312 .6549 .43847 .6599 .4477 .65732 .44236 .65236 Mtetra
.654 .75 .92 r
.44236 .65236 .4477 .65732 .45697 .65467 .45165 .64973 Mtetra
.656 .751 .92 r
.45165 .64973 .45697 .65467 .46626 .65197 .46096 .64703 Mtetra
.658 .753 .92 r
.46096 .64703 .46626 .65197 .47559 .64922 .47031 .64428 Mtetra
.659 .753 .92 r
.47031 .64428 .47559 .64922 .48495 .64646 .47969 .6415 Mtetra
.659 .754 .92 r
.47969 .6415 .48495 .64646 .49434 .64368 .4891 .6387 Mtetra
.4891 .6387 .49434 .64368 .50376 .64089 .49855 .63589 Mtetra
.49855 .63589 .50376 .64089 .51322 .6381 .50802 .63308 Mtetra
.658 .753 .92 r
.50802 .63308 .51322 .6381 .52271 .6353 .51753 .63027 Mtetra
.51753 .63027 .52271 .6353 .53223 .63251 .52708 .62745 Mtetra
.52708 .62745 .53223 .63251 .54178 .6297 .53665 .62463 Mtetra
.53665 .62463 .54178 .6297 .55137 .6269 .54626 .6218 Mtetra
.54626 .6218 .55137 .6269 .56099 .62408 .5559 .61897 Mtetra
.5559 .61897 .56099 .62408 .57064 .62126 .56558 .61612 Mtetra
.56558 .61612 .57064 .62126 .58033 .61843 .57528 .61328 Mtetra
.657 .753 .92 r
.57528 .61328 .58033 .61843 .59005 .61559 .58503 .61042 Mtetra
.58503 .61042 .59005 .61559 .5998 .61274 .5948 .60755 Mtetra
.5948 .60755 .5998 .61274 .60959 .60989 .60461 .60468 Mtetra
.657 .752 .92 r
.60461 .60468 .60959 .60989 .61941 .60702 .61446 .60179 Mtetra
.61446 .60179 .61941 .60702 .62926 .60415 .62434 .5989 Mtetra
.62434 .5989 .62926 .60415 .63916 .60127 .63425 .596 Mtetra
.63425 .596 .63916 .60127 .64908 .59838 .6442 .59309 Mtetra
.6442 .59309 .64908 .59838 .65904 .59548 .65419 .59017 Mtetra
.65419 .59017 .65904 .59548 .66904 .59257 .66421 .58724 Mtetra
.66421 .58724 .66904 .59257 .67907 .58965 .67427 .5843 Mtetra
.67427 .5843 .67907 .58965 .68914 .58672 .68436 .58135 Mtetra
.68436 .58135 .68914 .58672 .69924 .58378 .69448 .5784 Mtetra
.69448 .5784 .69924 .58378 .70938 .58083 .70465 .57543 Mtetra
.70465 .57543 .70938 .58083 .71955 .57787 .71485 .57245 Mtetra
.71485 .57245 .71955 .57787 .72976 .5749 .72509 .56946 Mtetra
.72509 .56946 .72976 .5749 .74001 .57192 .73536 .56646 Mtetra
.73536 .56646 .74001 .57192 .7503 .56893 .74567 .56345 Mtetra
.74567 .56345 .7503 .56893 .76062 .56594 .75602 .56043 Mtetra
.75602 .56043 .76062 .56594 .77098 .56293 .7664 .5574 Mtetra
.7664 .5574 .77098 .56293 .78137 .5599 .77682 .55436 Mtetra
.77682 .55436 .78137 .5599 .79181 .55687 .78729 .55131 Mtetra
.78729 .55131 .79181 .55687 .80228 .55383 .79778 .54825 Mtetra
.79778 .54825 .80228 .55383 .81279 .55078 .80832 .54517 Mtetra
.80832 .54517 .81279 .55078 .82333 .54772 .8189 .54209 Mtetra
.8189 .54209 .82333 .54772 .83392 .54464 .82951 .539 Mtetra
.82951 .539 .83392 .54464 .84455 .54156 .84016 .53589 Mtetra
.84016 .53589 .84455 .54156 .85521 .53846 .85085 .53277 Mtetra
.85085 .53277 .85521 .53846 .86591 .53536 .86158 .52965 Mtetra
.86158 .52965 .86591 .53536 .87665 .53224 .87235 .52651 Mtetra
.87235 .52651 .87665 .53224 .88743 .52911 .88316 .52336 Mtetra
.88316 .52336 .88743 .52911 .89825 .52597 .89401 .5202 Mtetra
.89401 .5202 .89825 .52597 .90912 .52282 .9049 .51702 Mtetra
.9049 .51702 .90912 .52282 .92002 .51966 .91583 .51384 Mtetra
.91583 .51384 .92002 .51966 .93096 .51648 .92681 .51064 Mtetra
.92681 .51064 .93096 .51648 .94194 .5133 .93782 .50743 Mtetra
.93782 .50743 .94194 .5133 .95296 .5101 .94887 .50422 Mtetra
.94887 .50422 .95296 .5101 .96403 .50689 .95996 .50098 Mtetra
.638 .738 .921 r
.3637 .66863 .36922 .67368 .37823 .67144 .37273 .66642 Mtetra
.64 .74 .921 r
.37273 .66642 .37823 .67144 .38728 .66923 .3818 .66415 Mtetra
.633 .737 .923 r
.3818 .66415 .38728 .66923 .39635 .66739 .3909 .66202 Mtetra
.576 .708 .932 r
.3909 .66202 .39635 .66739 .40514 .6748 .39999 .66104 Mtetra
.735 .607 .715 r
.39999 .66104 .40514 .6748 .41475 .6588 .40941 .65106 Mtetra
.508 .598 .879 r
.40941 .65106 .41475 .6588 .4239 .65724 .4185 .65197 Mtetra
.633 .731 .919 r
.4185 .65197 .4239 .65724 .43312 .6549 .42772 .64983 Mtetra
.647 .744 .92 r
.42772 .64983 .43312 .6549 .44236 .65236 .43699 .64735 Mtetra
.652 .748 .92 r
.43699 .64735 .44236 .65236 .45165 .64973 .44629 .64474 Mtetra
.655 .751 .92 r
.44629 .64474 .45165 .64973 .46096 .64703 .45563 .64204 Mtetra
.657 .752 .92 r
.45563 .64204 .46096 .64703 .47031 .64428 .465 .63929 Mtetra
.658 .753 .92 r
.465 .63929 .47031 .64428 .47969 .6415 .4744 .63651 Mtetra
.659 .754 .92 r
.4744 .63651 .47969 .6415 .4891 .6387 .48383 .63369 Mtetra
.48383 .63369 .4891 .6387 .49855 .63589 .4933 .63087 Mtetra
.4933 .63087 .49855 .63589 .50802 .63308 .5028 .62804 Mtetra
.5028 .62804 .50802 .63308 .51753 .63027 .51233 .6252 Mtetra
.658 .753 .92 r
.51233 .6252 .51753 .63027 .52708 .62745 .52189 .62236 Mtetra
.52189 .62236 .52708 .62745 .53665 .62463 .53149 .61952 Mtetra
.53149 .61952 .53665 .62463 .54626 .6218 .54112 .61667 Mtetra
.54112 .61667 .54626 .6218 .5559 .61897 .55078 .61382 Mtetra
.55078 .61382 .5559 .61897 .56558 .61612 .56048 .61096 Mtetra
.56048 .61096 .56558 .61612 .57528 .61328 .57021 .60809 Mtetra
.657 .753 .92 r
.57021 .60809 .57528 .61328 .58503 .61042 .57998 .60521 Mtetra
.57998 .60521 .58503 .61042 .5948 .60755 .58978 .60233 Mtetra
.58978 .60233 .5948 .60755 .60461 .60468 .59961 .59943 Mtetra
.59961 .59943 .60461 .60468 .61446 .60179 .60948 .59653 Mtetra
.657 .752 .92 r
.60948 .59653 .61446 .60179 .62434 .5989 .61938 .59362 Mtetra
.61938 .59362 .62434 .5989 .63425 .596 .62932 .5907 Mtetra
.62932 .5907 .63425 .596 .6442 .59309 .63929 .58777 Mtetra
.63929 .58777 .6442 .59309 .65419 .59017 .6493 .58483 Mtetra
.6493 .58483 .65419 .59017 .66421 .58724 .65935 .58188 Mtetra
.65935 .58188 .66421 .58724 .67427 .5843 .66943 .57892 Mtetra
.66943 .57892 .67427 .5843 .68436 .58135 .67955 .57595 Mtetra
.67955 .57595 .68436 .58135 .69448 .5784 .6897 .57298 Mtetra
.6897 .57298 .69448 .5784 .70465 .57543 .69989 .56999 Mtetra
.69989 .56999 .70465 .57543 .71485 .57245 .71011 .56699 Mtetra
.71011 .56699 .71485 .57245 .72509 .56946 .72037 .56398 Mtetra
.72037 .56398 .72509 .56946 .73536 .56646 .73067 .56096 Mtetra
.73067 .56096 .73536 .56646 .74567 .56345 .74101 .55793 Mtetra
.74101 .55793 .74567 .56345 .75602 .56043 .75138 .55489 Mtetra
.75138 .55489 .75602 .56043 .7664 .5574 .7618 .55184 Mtetra
.7618 .55184 .7664 .5574 .77682 .55436 .77225 .54878 Mtetra
.77225 .54878 .77682 .55436 .78729 .55131 .78273 .54571 Mtetra
.78273 .54571 .78729 .55131 .79778 .54825 .79326 .54262 Mtetra
.79326 .54262 .79778 .54825 .80832 .54517 .80382 .53953 Mtetra
.80382 .53953 .80832 .54517 .8189 .54209 .81443 .53643 Mtetra
.81443 .53643 .8189 .54209 .82951 .539 .82507 .53331 Mtetra
.82507 .53331 .82951 .539 .84016 .53589 .83575 .53018 Mtetra
.83575 .53018 .84016 .53589 .85085 .53277 .84647 .52705 Mtetra
.84647 .52705 .85085 .53277 .86158 .52965 .85723 .5239 Mtetra
.85723 .5239 .86158 .52965 .87235 .52651 .86803 .52074 Mtetra
.86803 .52074 .87235 .52651 .88316 .52336 .87886 .51757 Mtetra
.87886 .51757 .88316 .52336 .89401 .5202 .88974 .51438 Mtetra
.88974 .51438 .89401 .5202 .9049 .51702 .90066 .51119 Mtetra
.90066 .51119 .9049 .51702 .91583 .51384 .91162 .50798 Mtetra
.91162 .50798 .91583 .51384 .92681 .51064 .92263 .50476 Mtetra
.92263 .50476 .92681 .51064 .93782 .50743 .93367 .50153 Mtetra
.93367 .50153 .93782 .50743 .94887 .50422 .94475 .49829 Mtetra
.94475 .49829 .94887 .50422 .95996 .50098 .95588 .49504 Mtetra
.633 .733 .92 r
.35815 .66346 .3637 .66863 .37273 .66642 .36719 .66135 Mtetra
.64 .74 .921 r
.36719 .66135 .37273 .66642 .3818 .66415 .37628 .65907 Mtetra
.638 .74 .922 r
.37628 .65907 .3818 .66415 .3909 .66202 .3854 .65682 Mtetra
.62 .73 .925 r
.3854 .65682 .3909 .66202 .39999 .66104 .39454 .65495 Mtetra
0 .178 .691 r
.39454 .65495 .39999 .66104 .40941 .65106 .40339 .66236 Mtetra
0 0 0 r
.40339 .66236 .40941 .65106 .4185 .65197 .41308 .64626 Mtetra
.609 .709 .915 r
.41308 .64626 .4185 .65197 .42772 .64983 .4223 .64466 Mtetra
.642 .74 .92 r
.4223 .64466 .42772 .64983 .43699 .64735 .43158 .64228 Mtetra
.65 .747 .92 r
.43158 .64228 .43699 .64735 .44629 .64474 .44091 .6397 Mtetra
.654 .75 .92 r
.44091 .6397 .44629 .64474 .45563 .64204 .45026 .63702 Mtetra
.656 .751 .92 r
.45026 .63702 .45563 .64204 .465 .63929 .45965 .63427 Mtetra
.658 .753 .92 r
.45965 .63427 .465 .63929 .4744 .63651 .46907 .63148 Mtetra
.659 .753 .92 r
.46907 .63148 .4744 .63651 .48383 .63369 .47853 .62865 Mtetra
.659 .754 .92 r
.47853 .62865 .48383 .63369 .4933 .63087 .48801 .62581 Mtetra
.48801 .62581 .4933 .63087 .5028 .62804 .49753 .62296 Mtetra
.49753 .62296 .5028 .62804 .51233 .6252 .50709 .6201 Mtetra
.658 .753 .92 r
.50709 .6201 .51233 .6252 .52189 .62236 .51667 .61724 Mtetra
.51667 .61724 .52189 .62236 .53149 .61952 .52629 .61438 Mtetra
.52629 .61438 .53149 .61952 .54112 .61667 .53594 .61151 Mtetra
.53594 .61151 .54112 .61667 .55078 .61382 .54563 .60864 Mtetra
.54563 .60864 .55078 .61382 .56048 .61096 .55535 .60576 Mtetra
.55535 .60576 .56048 .61096 .57021 .60809 .5651 .60287 Mtetra
.5651 .60287 .57021 .60809 .57998 .60521 .57489 .59997 Mtetra
.657 .753 .92 r
.57489 .59997 .57998 .60521 .58978 .60233 .58472 .59707 Mtetra
.58472 .59707 .58978 .60233 .59961 .59943 .59457 .59416 Mtetra
.59457 .59416 .59961 .59943 .60948 .59653 .60446 .59123 Mtetra
.657 .752 .92 r
.60446 .59123 .60948 .59653 .61938 .59362 .61439 .5883 Mtetra
.61439 .5883 .61938 .59362 .62932 .5907 .62435 .58536 Mtetra
.62435 .58536 .62932 .5907 .63929 .58777 .63435 .58241 Mtetra
.63435 .58241 .63929 .58777 .6493 .58483 .64439 .57945 Mtetra
.64439 .57945 .6493 .58483 .65935 .58188 .65445 .57649 Mtetra
.65445 .57649 .65935 .58188 .66943 .57892 .66456 .57351 Mtetra
.66456 .57351 .66943 .57892 .67955 .57595 .6747 .57052 Mtetra
.6747 .57052 .67955 .57595 .6897 .57298 .68488 .56752 Mtetra
.68488 .56752 .6897 .57298 .69989 .56999 .69509 .56451 Mtetra
.69509 .56451 .69989 .56999 .71011 .56699 .70534 .56149 Mtetra
.70534 .56149 .71011 .56699 .72037 .56398 .71563 .55846 Mtetra
.71563 .55846 .72037 .56398 .73067 .56096 .72596 .55542 Mtetra
.72596 .55542 .73067 .56096 .74101 .55793 .73632 .55237 Mtetra
.73632 .55237 .74101 .55793 .75138 .55489 .74672 .54931 Mtetra
.74672 .54931 .75138 .55489 .7618 .55184 .75716 .54624 Mtetra
.75716 .54624 .7618 .55184 .77225 .54878 .76764 .54316 Mtetra
.76764 .54316 .77225 .54878 .78273 .54571 .77815 .54007 Mtetra
.77815 .54007 .78273 .54571 .79326 .54262 .7887 .53696 Mtetra
.7887 .53696 .79326 .54262 .80382 .53953 .79929 .53385 Mtetra
.79929 .53385 .80382 .53953 .81443 .53643 .80993 .53072 Mtetra
.80993 .53072 .81443 .53643 .82507 .53331 .82059 .52759 Mtetra
.82059 .52759 .82507 .53331 .83575 .53018 .8313 .52444 Mtetra
.8313 .52444 .83575 .53018 .84647 .52705 .84205 .52128 Mtetra
.84205 .52128 .84647 .52705 .85723 .5239 .85284 .51811 Mtetra
.85284 .51811 .85723 .5239 .86803 .52074 .86367 .51493 Mtetra
.86367 .51493 .86803 .52074 .87886 .51757 .87454 .51173 Mtetra
.87454 .51173 .87886 .51757 .88974 .51438 .88544 .50853 Mtetra
.88544 .50853 .88974 .51438 .90066 .51119 .89639 .50531 Mtetra
.89639 .50531 .90066 .51119 .91162 .50798 .90738 .50208 Mtetra
.90738 .50208 .91162 .50798 .92263 .50476 .91842 .49884 Mtetra
.91842 .49884 .92263 .50476 .93367 .50153 .92949 .49559 Mtetra
.92949 .49559 .93367 .50153 .94475 .49829 .9406 .49232 Mtetra
.9406 .49232 .94475 .49829 .95588 .49504 .95176 .48905 Mtetra
.621 .722 .919 r
.35257 .65807 .35815 .66346 .36719 .66135 .36162 .65622 Mtetra
.638 .738 .921 r
.36162 .65622 .36719 .66135 .37628 .65907 .37073 .65397 Mtetra
.64 .74 .921 r
.37073 .65397 .37628 .65907 .3854 .65682 .37987 .65166 Mtetra
.633 .737 .923 r
.37987 .65166 .3854 .65682 .39454 .65495 .38903 .6495 Mtetra
.576 .707 .932 r
.38903 .6495 .39454 .65495 .40339 .66236 .39819 .64848 Mtetra
.735 .608 .716 r
.39819 .64848 .40339 .66236 .41308 .64626 .4077 .63842 Mtetra
.507 .598 .879 r
.4077 .63842 .41308 .64626 .4223 .64466 .41685 .6393 Mtetra
.633 .731 .919 r
.41685 .6393 .4223 .64466 .43158 .64228 .42615 .63713 Mtetra
.647 .744 .92 r
.42615 .63713 .43158 .64228 .44091 .6397 .43548 .6346 Mtetra
.652 .748 .92 r
.43548 .6346 .44091 .6397 .45026 .63702 .44486 .63194 Mtetra
.655 .751 .92 r
.44486 .63194 .45026 .63702 .45965 .63427 .45427 .62921 Mtetra
.657 .752 .92 r
.45427 .62921 .45965 .63427 .46907 .63148 .46371 .62641 Mtetra
.658 .753 .92 r
.46371 .62641 .46907 .63148 .47853 .62865 .47319 .62358 Mtetra
.659 .754 .92 r
.47319 .62358 .47853 .62865 .48801 .62581 .4827 .62072 Mtetra
.4827 .62072 .48801 .62581 .49753 .62296 .49224 .61785 Mtetra
.49224 .61785 .49753 .62296 .50709 .6201 .50181 .61497 Mtetra
.50181 .61497 .50709 .6201 .51667 .61724 .51142 .61209 Mtetra
.658 .753 .92 r
.51142 .61209 .51667 .61724 .52629 .61438 .52106 .60921 Mtetra
.52106 .60921 .52629 .61438 .53594 .61151 .53074 .60632 Mtetra
.53074 .60632 .53594 .61151 .54563 .60864 .54044 .60342 Mtetra
.54044 .60342 .54563 .60864 .55535 .60576 .55019 .60052 Mtetra
.55019 .60052 .55535 .60576 .5651 .60287 .55996 .59762 Mtetra
.55996 .59762 .5651 .60287 .57489 .59997 .56978 .5947 Mtetra
.657 .753 .92 r
.56978 .5947 .57489 .59997 .58472 .59707 .57962 .59178 Mtetra
.57962 .59178 .58472 .59707 .59457 .59416 .5895 .58884 Mtetra
.5895 .58884 .59457 .59416 .60446 .59123 .59942 .5859 Mtetra
.59942 .5859 .60446 .59123 .61439 .5883 .60937 .58295 Mtetra
.657 .752 .92 r
.60937 .58295 .61439 .5883 .62435 .58536 .61936 .57999 Mtetra
.61936 .57999 .62435 .58536 .63435 .58241 .62938 .57702 Mtetra
.62938 .57702 .63435 .58241 .64439 .57945 .63944 .57404 Mtetra
.63944 .57404 .64439 .57945 .65445 .57649 .64953 .57105 Mtetra
.64953 .57105 .65445 .57649 .66456 .57351 .65966 .56805 Mtetra
.65966 .56805 .66456 .57351 .6747 .57052 .66983 .56505 Mtetra
.66983 .56505 .6747 .57052 .68488 .56752 .68003 .56203 Mtetra
.68003 .56203 .68488 .56752 .69509 .56451 .69027 .559 Mtetra
.69027 .559 .69509 .56451 .70534 .56149 .70055 .55596 Mtetra
.70055 .55596 .70534 .56149 .71563 .55846 .71086 .55291 Mtetra
.71086 .55291 .71563 .55846 .72596 .55542 .72121 .54985 Mtetra
.72121 .54985 .72596 .55542 .73632 .55237 .7316 .54678 Mtetra
.7316 .54678 .73632 .55237 .74672 .54931 .74203 .5437 Mtetra
.74203 .5437 .74672 .54931 .75716 .54624 .75249 .54061 Mtetra
.75249 .54061 .75716 .54624 .76764 .54316 .76299 .5375 Mtetra
.76299 .5375 .76764 .54316 .77815 .54007 .77354 .53439 Mtetra
.77354 .53439 .77815 .54007 .7887 .53696 .78412 .53126 Mtetra
.78412 .53126 .7887 .53696 .79929 .53385 .79474 .52813 Mtetra
.79474 .52813 .79929 .53385 .80993 .53072 .80539 .52498 Mtetra
.80539 .52498 .80993 .53072 .82059 .52759 .81609 .52182 Mtetra
.81609 .52182 .82059 .52759 .8313 .52444 .82683 .51865 Mtetra
.82683 .51865 .8313 .52444 .84205 .52128 .83761 .51547 Mtetra
.83761 .51547 .84205 .52128 .85284 .51811 .84842 .51228 Mtetra
.84842 .51228 .85284 .51811 .86367 .51493 .85928 .50908 Mtetra
.85928 .50908 .86367 .51493 .87454 .51173 .87018 .50586 Mtetra
.87018 .50586 .87454 .51173 .88544 .50853 .88112 .50263 Mtetra
.88112 .50263 .88544 .50853 .89639 .50531 .8921 .49939 Mtetra
.8921 .49939 .89639 .50531 .90738 .50208 .90312 .49614 Mtetra
.90312 .49614 .90738 .50208 .91842 .49884 .91418 .49288 Mtetra
.91418 .49288 .91842 .49884 .92949 .49559 .92528 .4896 Mtetra
.92528 .4896 .92949 .49559 .9406 .49232 .93643 .48632 Mtetra
.93643 .48632 .9406 .49232 .95176 .48905 .94761 .48302 Mtetra
.585 .687 .912 r
.347 .65202 .35257 .65807 .36162 .65622 .35602 .65098 Mtetra
.633 .733 .92 r
.35602 .65098 .36162 .65622 .37073 .65397 .36514 .64883 Mtetra
.64 .74 .921 r
.36514 .64883 .37073 .65397 .37987 .65166 .3743 .64651 Mtetra
.638 .74 .922 r
.3743 .64651 .37987 .65166 .38903 .6495 .38348 .64421 Mtetra
.62 .73 .925 r
.38348 .64421 .38903 .6495 .39819 .64848 .39269 .6423 Mtetra
0 .183 .695 r
.39269 .6423 .39819 .64848 .4077 .63842 .40161 .64971 Mtetra
0 0 0 r
.40161 .64971 .4077 .63842 .41685 .6393 .41138 .63351 Mtetra
.609 .709 .915 r
.41138 .63351 .41685 .6393 .42615 .63713 .42067 .63187 Mtetra
.642 .74 .92 r
.42067 .63187 .42615 .63713 .43548 .6346 .43003 .62945 Mtetra
.65 .747 .92 r
.43003 .62945 .43548 .6346 .44486 .63194 .43942 .62682 Mtetra
.654 .75 .92 r
.43942 .62682 .44486 .63194 .45427 .62921 .44885 .6241 Mtetra
.656 .751 .92 r
.44885 .6241 .45427 .62921 .46371 .62641 .45832 .62131 Mtetra
.658 .753 .92 r
.45832 .62131 .46371 .62641 .47319 .62358 .46781 .61847 Mtetra
.659 .753 .92 r
.46781 .61847 .47319 .62358 .4827 .62072 .47734 .6156 Mtetra
.659 .754 .92 r
.47734 .6156 .4827 .62072 .49224 .61785 .48691 .61271 Mtetra
.48691 .61271 .49224 .61785 .50181 .61497 .4965 .60981 Mtetra
.4965 .60981 .50181 .61497 .51142 .61209 .50613 .60691 Mtetra
.658 .753 .92 r
.50613 .60691 .51142 .61209 .52106 .60921 .5158 .604 Mtetra
.5158 .604 .52106 .60921 .53074 .60632 .52549 .60109 Mtetra
.52549 .60109 .53074 .60632 .54044 .60342 .53523 .59818 Mtetra
.53523 .59818 .54044 .60342 .55019 .60052 .54499 .59526 Mtetra
.54499 .59526 .55019 .60052 .55996 .59762 .55479 .59233 Mtetra
.55479 .59233 .55996 .59762 .56978 .5947 .56462 .58939 Mtetra
.56462 .58939 .56978 .5947 .57962 .59178 .57449 .58645 Mtetra
.657 .753 .92 r
.57449 .58645 .57962 .59178 .5895 .58884 .5844 .5835 Mtetra
.5844 .5835 .5895 .58884 .59942 .5859 .59434 .58053 Mtetra
.59434 .58053 .59942 .5859 .60937 .58295 .60431 .57756 Mtetra
.657 .752 .92 r
.60431 .57756 .60937 .58295 .61936 .57999 .61432 .57458 Mtetra
.61432 .57458 .61936 .57999 .62938 .57702 .62437 .57159 Mtetra
.62437 .57159 .62938 .57702 .63944 .57404 .63445 .56859 Mtetra
.63445 .56859 .63944 .57404 .64953 .57105 .64457 .56559 Mtetra
.64457 .56559 .64953 .57105 .65966 .56805 .65473 .56257 Mtetra
.65473 .56257 .65966 .56805 .66983 .56505 .66492 .55954 Mtetra
.66492 .55954 .66983 .56505 .68003 .56203 .67515 .5565 Mtetra
.67515 .5565 .68003 .56203 .69027 .559 .68541 .55345 Mtetra
.68541 .55345 .69027 .559 .70055 .55596 .69571 .55039 Mtetra
.69571 .55039 .70055 .55596 .71086 .55291 .70605 .54732 Mtetra
.70605 .54732 .71086 .55291 .72121 .54985 .71643 .54424 Mtetra
.71643 .54424 .72121 .54985 .7316 .54678 .72685 .54115 Mtetra
.72685 .54115 .7316 .54678 .74203 .5437 .7373 .53804 Mtetra
.7373 .53804 .74203 .5437 .75249 .54061 .74779 .53493 Mtetra
.74779 .53493 .75249 .54061 .76299 .5375 .75832 .53181 Mtetra
.75832 .53181 .76299 .5375 .77354 .53439 .76889 .52867 Mtetra
.76889 .52867 .77354 .53439 .78412 .53126 .7795 .52553 Mtetra
.7795 .52553 .78412 .53126 .79474 .52813 .79015 .52237 Mtetra
.79015 .52237 .79474 .52813 .80539 .52498 .80083 .5192 Mtetra
.80083 .5192 .80539 .52498 .81609 .52182 .81156 .51602 Mtetra
.81156 .51602 .81609 .52182 .82683 .51865 .82232 .51283 Mtetra
.82232 .51283 .82683 .51865 .83761 .51547 .83313 .50963 Mtetra
.83313 .50963 .83761 .51547 .84842 .51228 .84398 .50641 Mtetra
.84398 .50641 .84842 .51228 .85928 .50908 .85486 .50318 Mtetra
.85486 .50318 .85928 .50908 .87018 .50586 .86579 .49995 Mtetra
.86579 .49995 .87018 .50586 .88112 .50263 .87676 .4967 Mtetra
.87676 .4967 .88112 .50263 .8921 .49939 .88777 .49344 Mtetra
.88777 .49344 .8921 .49939 .90312 .49614 .89882 .49016 Mtetra
.89882 .49016 .90312 .49614 .91418 .49288 .90991 .48688 Mtetra
.90991 .48688 .91418 .49288 .92528 .4896 .92104 .48358 Mtetra
.92104 .48358 .92528 .4896 .93643 .48632 .93222 .48027 Mtetra
.93222 .48027 .93643 .48632 .94761 .48302 .94344 .47695 Mtetra
.338 .411 .79 r
.3417 .6401 .347 .65202 .35602 .65098 .3504 .6455 Mtetra
.621 .722 .919 r
.3504 .6455 .35602 .65098 .36514 .64883 .35952 .64362 Mtetra
.638 .738 .921 r
.35952 .64362 .36514 .64883 .3743 .64651 .36869 .64133 Mtetra
.64 .74 .921 r
.36869 .64133 .3743 .64651 .38348 .64421 .3779 .63898 Mtetra
.633 .737 .923 r
.3779 .63898 .38348 .64421 .39269 .6423 .38714 .63677 Mtetra
.576 .707 .932 r
.38714 .63677 .39269 .6423 .40161 .64971 .39637 .63572 Mtetra
.735 .608 .716 r
.39637 .63572 .40161 .64971 .41138 .63351 .40595 .62558 Mtetra
.507 .598 .879 r
.40595 .62558 .41138 .63351 .42067 .63187 .41517 .62643 Mtetra
.633 .731 .919 r
.41517 .62643 .42067 .63187 .43003 .62945 .42454 .62421 Mtetra
.647 .744 .92 r
.42454 .62421 .43003 .62945 .43942 .62682 .43395 .62165 Mtetra
.652 .748 .92 r
.43395 .62165 .43942 .62682 .44885 .6241 .4434 .61894 Mtetra
.655 .751 .92 r
.4434 .61894 .44885 .6241 .45832 .62131 .45289 .61616 Mtetra
.657 .752 .92 r
.45289 .61616 .45832 .62131 .46781 .61847 .4624 .61332 Mtetra
.658 .753 .92 r
.4624 .61332 .46781 .61847 .47734 .6156 .47196 .61044 Mtetra
.659 .754 .92 r
.47196 .61044 .47734 .6156 .48691 .61271 .48154 .60754 Mtetra
.48154 .60754 .48691 .61271 .4965 .60981 .49116 .60462 Mtetra
.49116 .60462 .4965 .60981 .50613 .60691 .50081 .6017 Mtetra
.50081 .6017 .50613 .60691 .5158 .604 .5105 .59877 Mtetra
.658 .753 .92 r
.5105 .59877 .5158 .604 .52549 .60109 .52022 .59583 Mtetra
.52022 .59583 .52549 .60109 .53523 .59818 .52997 .5929 Mtetra
.52997 .5929 .53523 .59818 .54499 .59526 .53976 .58996 Mtetra
.53976 .58996 .54499 .59526 .55479 .59233 .54958 .58701 Mtetra
.54958 .58701 .55479 .59233 .56462 .58939 .55944 .58405 Mtetra
.55944 .58405 .56462 .58939 .57449 .58645 .56933 .58109 Mtetra
.657 .753 .92 r
.56933 .58109 .57449 .58645 .5844 .5835 .57926 .57811 Mtetra
.57926 .57811 .5844 .5835 .59434 .58053 .58922 .57513 Mtetra
.58922 .57513 .59434 .58053 .60431 .57756 .59922 .57214 Mtetra
.59922 .57214 .60431 .57756 .61432 .57458 .60926 .56914 Mtetra
.657 .752 .92 r
.60926 .56914 .61432 .57458 .62437 .57159 .61933 .56613 Mtetra
.61933 .56613 .62437 .57159 .63445 .56859 .62944 .56311 Mtetra
.62944 .56311 .63445 .56859 .64457 .56559 .63958 .56008 Mtetra
.63958 .56008 .64457 .56559 .65473 .56257 .64976 .55704 Mtetra
.64976 .55704 .65473 .56257 .66492 .55954 .65998 .55399 Mtetra
.65998 .55399 .66492 .55954 .67515 .5565 .67023 .55093 Mtetra
.67023 .55093 .67515 .5565 .68541 .55345 .68052 .54786 Mtetra
.68052 .54786 .68541 .55345 .69571 .55039 .69085 .54478 Mtetra
.69085 .54478 .69571 .55039 .70605 .54732 .70121 .54169 Mtetra
.70121 .54169 .70605 .54732 .71643 .54424 .71162 .53859 Mtetra
.71162 .53859 .71643 .54424 .72685 .54115 .72206 .53548 Mtetra
.72206 .53548 .72685 .54115 .7373 .53804 .73254 .53235 Mtetra
.73254 .53235 .7373 .53804 .74779 .53493 .74306 .52922 Mtetra
.74306 .52922 .74779 .53493 .75832 .53181 .75362 .52607 Mtetra
.75362 .52607 .75832 .53181 .76889 .52867 .76421 .52292 Mtetra
.76421 .52292 .76889 .52867 .7795 .52553 .77485 .51975 Mtetra
.77485 .51975 .7795 .52553 .79015 .52237 .78552 .51657 Mtetra
.78552 .51657 .79015 .52237 .80083 .5192 .79624 .51338 Mtetra
.79624 .51338 .80083 .5192 .81156 .51602 .80699 .51018 Mtetra
.80699 .51018 .81156 .51602 .82232 .51283 .81779 .50696 Mtetra
.81779 .50696 .82232 .51283 .83313 .50963 .82862 .50374 Mtetra
.82862 .50374 .83313 .50963 .84398 .50641 .8395 .5005 Mtetra
.8395 .5005 .84398 .50641 .85486 .50318 .85041 .49725 Mtetra
.85041 .49725 .85486 .50318 .86579 .49995 .86137 .49399 Mtetra
.86137 .49399 .86579 .49995 .87676 .4967 .87237 .49072 Mtetra
.87237 .49072 .87676 .4967 .88777 .49344 .88341 .48744 Mtetra
.88341 .48744 .88777 .49344 .89882 .49016 .89449 .48414 Mtetra
.89449 .48414 .89882 .49016 .90991 .48688 .90561 .48083 Mtetra
.90561 .48083 .90991 .48688 .92104 .48358 .91678 .47751 Mtetra
.91678 .47751 .92104 .48358 .93222 .48027 .92798 .47418 Mtetra
.92798 .47418 .93222 .48027 .94344 .47695 .93923 .47083 Mtetra
0 0 0 r
.33521 .6497 .3417 .6401 .3504 .6455 .34477 .63937 Mtetra
.585 .687 .912 r
.34477 .63937 .3504 .6455 .35952 .64362 .35386 .63829 Mtetra
.633 .733 .92 r
.35386 .63829 .35952 .64362 .36869 .64133 .36305 .6361 Mtetra
.64 .74 .921 r
.36305 .6361 .36869 .64133 .3779 .63898 .37228 .63374 Mtetra
.638 .74 .922 r
.37228 .63374 .3779 .63898 .38714 .63677 .38154 .6314 Mtetra
.62 .73 .925 r
.38154 .6314 .38714 .63677 .39637 .63572 .39082 .62945 Mtetra
0 .188 .7 r
.39082 .62945 .39637 .63572 .40595 .62558 .39979 .63686 Mtetra
0 0 0 r
.39979 .63686 .40595 .62558 .41517 .62643 .40965 .62055 Mtetra
.609 .709 .915 r
.40965 .62055 .41517 .62643 .42454 .62421 .41902 .61887 Mtetra
.642 .74 .92 r
.41902 .61887 .42454 .62421 .43395 .62165 .42845 .61641 Mtetra
.65 .747 .92 r
.42845 .61641 .43395 .62165 .4434 .61894 .43792 .61374 Mtetra
.654 .75 .92 r
.43792 .61374 .4434 .61894 .45289 .61616 .44742 .61097 Mtetra
.656 .751 .92 r
.44742 .61097 .45289 .61616 .4624 .61332 .45696 .60813 Mtetra
.658 .753 .92 r
.45696 .60813 .4624 .61332 .47196 .61044 .46653 .60525 Mtetra
.659 .753 .92 r
.46653 .60525 .47196 .61044 .48154 .60754 .47614 .60233 Mtetra
.659 .754 .92 r
.47614 .60233 .48154 .60754 .49116 .60462 .48578 .59939 Mtetra
.48578 .59939 .49116 .60462 .50081 .6017 .49546 .59645 Mtetra
.49546 .59645 .50081 .6017 .5105 .59877 .50516 .5935 Mtetra
.658 .753 .92 r
.50516 .5935 .5105 .59877 .52022 .59583 .51491 .59054 Mtetra
.51491 .59054 .52022 .59583 .52997 .5929 .52468 .58758 Mtetra
.52468 .58758 .52997 .5929 .53976 .58996 .53449 .58462 Mtetra
.53449 .58462 .53976 .58996 .54958 .58701 .54434 .58165 Mtetra
.54434 .58165 .54958 .58701 .55944 .58405 .55422 .57867 Mtetra
.55422 .57867 .55944 .58405 .56933 .58109 .56414 .57569 Mtetra
.56414 .57569 .56933 .58109 .57926 .57811 .57409 .5727 Mtetra
.657 .753 .92 r
.57409 .5727 .57926 .57811 .58922 .57513 .58408 .56969 Mtetra
.58408 .56969 .58922 .57513 .59922 .57214 .5941 .56668 Mtetra
.5941 .56668 .59922 .57214 .60926 .56914 .60416 .56366 Mtetra
.657 .752 .92 r
.60416 .56366 .60926 .56914 .61933 .56613 .61425 .56063 Mtetra
.61425 .56063 .61933 .56613 .62944 .56311 .62438 .55759 Mtetra
.62438 .55759 .62944 .56311 .63958 .56008 .63455 .55454 Mtetra
.63455 .55454 .63958 .56008 .64976 .55704 .64476 .55148 Mtetra
.64476 .55148 .64976 .55704 .65998 .55399 .655 .54841 Mtetra
.655 .54841 .65998 .55399 .67023 .55093 .66528 .54533 Mtetra
.66528 .54533 .67023 .55093 .68052 .54786 .6756 .54224 Mtetra
.6756 .54224 .68052 .54786 .69085 .54478 .68595 .53914 Mtetra
.68595 .53914 .69085 .54478 .70121 .54169 .69634 .53603 Mtetra
.69634 .53603 .70121 .54169 .71162 .53859 .70677 .5329 Mtetra
.70677 .5329 .71162 .53859 .72206 .53548 .71724 .52977 Mtetra
.71724 .52977 .72206 .53548 .73254 .53235 .72775 .52662 Mtetra
.72775 .52662 .73254 .53235 .74306 .52922 .7383 .52347 Mtetra
.7383 .52347 .74306 .52922 .75362 .52607 .74888 .5203 Mtetra
.74888 .5203 .75362 .52607 .76421 .52292 .7595 .51712 Mtetra
.7595 .51712 .76421 .52292 .77485 .51975 .77017 .51393 Mtetra
.77017 .51393 .77485 .51975 .78552 .51657 .78087 .51073 Mtetra
.78087 .51073 .78552 .51657 .79624 .51338 .79161 .50752 Mtetra
.79161 .50752 .79624 .51338 .80699 .51018 .8024 .50429 Mtetra
.8024 .50429 .80699 .51018 .81779 .50696 .81322 .50106 Mtetra
.81322 .50106 .81779 .50696 .82862 .50374 .82408 .49781 Mtetra
.82408 .49781 .82862 .50374 .8395 .5005 .83499 .49455 Mtetra
.83499 .49455 .8395 .5005 .85041 .49725 .84593 .49128 Mtetra
.84593 .49128 .85041 .49725 .86137 .49399 .85692 .488 Mtetra
.85692 .488 .86137 .49399 .87237 .49072 .86795 .4847 Mtetra
.86795 .4847 .87237 .49072 .88341 .48744 .87902 .48139 Mtetra
.87902 .48139 .88341 .48744 .89449 .48414 .89013 .47807 Mtetra
.89013 .47807 .89449 .48414 .90561 .48083 .90128 .47474 Mtetra
.90128 .47474 .90561 .48083 .91678 .47751 .91248 .4714 Mtetra
.91248 .4714 .91678 .47751 .92798 .47418 .92372 .46804 Mtetra
.92372 .46804 .92798 .47418 .93923 .47083 .935 .46467 Mtetra
.818 .697 .732 r
.32965 .64136 .33521 .6497 .34477 .63937 .33943 .62734 Mtetra
.336 .41 .79 r
.33943 .62734 .34477 .63937 .35386 .63829 .34819 .63273 Mtetra
.621 .722 .919 r
.34819 .63273 .35386 .63829 .36305 .6361 .35738 .63081 Mtetra
.638 .738 .921 r
.35738 .63081 .36305 .6361 .37228 .63374 .36662 .62848 Mtetra
.64 .74 .921 r
.36662 .62848 .37228 .63374 .38154 .6314 .3759 .62608 Mtetra
.633 .737 .923 r
.3759 .62608 .38154 .6314 .39082 .62945 .38521 .62383 Mtetra
.576 .707 .932 r
.38521 .62383 .39082 .62945 .39979 .63686 .39451 .62274 Mtetra
.735 .608 .716 r
.39451 .62274 .39979 .63686 .40965 .62055 .40417 .61253 Mtetra
.506 .598 .88 r
.40417 .61253 .40965 .62055 .41902 .61887 .41347 .61335 Mtetra
.633 .731 .919 r
.41347 .61335 .41902 .61887 .42845 .61641 .42291 .61109 Mtetra
.647 .744 .92 r
.42291 .61109 .42845 .61641 .43792 .61374 .4324 .60848 Mtetra
.652 .748 .92 r
.4324 .60848 .43792 .61374 .44742 .61097 .44192 .60573 Mtetra
.655 .751 .92 r
.44192 .60573 .44742 .61097 .45696 .60813 .45148 .6029 Mtetra
.657 .752 .92 r
.45148 .6029 .45696 .60813 .46653 .60525 .46108 .60001 Mtetra
.658 .753 .92 r
.46108 .60001 .46653 .60525 .47614 .60233 .4707 .59708 Mtetra
.659 .754 .92 r
.4707 .59708 .47614 .60233 .48578 .59939 .48037 .59413 Mtetra
.48037 .59413 .48578 .59939 .49546 .59645 .49006 .59117 Mtetra
.49006 .59117 .49546 .59645 .50516 .5935 .49979 .58819 Mtetra
.49979 .58819 .50516 .5935 .51491 .59054 .50956 .58522 Mtetra
.658 .753 .92 r
.50956 .58522 .51491 .59054 .52468 .58758 .51936 .58224 Mtetra
.51936 .58224 .52468 .58758 .53449 .58462 .52919 .57925 Mtetra
.52919 .57925 .53449 .58462 .54434 .58165 .53906 .57626 Mtetra
.53906 .57626 .54434 .58165 .55422 .57867 .54897 .57326 Mtetra
.54897 .57326 .55422 .57867 .56414 .57569 .55891 .57026 Mtetra
.55891 .57026 .56414 .57569 .57409 .5727 .56888 .56724 Mtetra
.657 .753 .92 r
.56888 .56724 .57409 .5727 .58408 .56969 .57889 .56422 Mtetra
.57889 .56422 .58408 .56969 .5941 .56668 .58894 .56119 Mtetra
.58894 .56119 .5941 .56668 .60416 .56366 .59902 .55815 Mtetra
.59902 .55815 .60416 .56366 .61425 .56063 .60914 .55509 Mtetra
.657 .752 .92 r
.60914 .55509 .61425 .56063 .62438 .55759 .6193 .55203 Mtetra
.6193 .55203 .62438 .55759 .63455 .55454 .62949 .54896 Mtetra
.62949 .54896 .63455 .55454 .64476 .55148 .63972 .54588 Mtetra
.63972 .54588 .64476 .55148 .655 .54841 .64999 .54279 Mtetra
.64999 .54279 .655 .54841 .66528 .54533 .6603 .53969 Mtetra
.6603 .53969 .66528 .54533 .6756 .54224 .67064 .53658 Mtetra
.67064 .53658 .6756 .54224 .68595 .53914 .68102 .53345 Mtetra
.68102 .53345 .68595 .53914 .69634 .53603 .69144 .53032 Mtetra
.69144 .53032 .69634 .53603 .70677 .5329 .7019 .52718 Mtetra
.7019 .52718 .70677 .5329 .71724 .52977 .71239 .52402 Mtetra
.71239 .52402 .71724 .52977 .72775 .52662 .72293 .52085 Mtetra
.72293 .52085 .72775 .52662 .7383 .52347 .7335 .51768 Mtetra
.7335 .51768 .7383 .52347 .74888 .5203 .74411 .51449 Mtetra
.74411 .51449 .74888 .5203 .7595 .51712 .75476 .51129 Mtetra
.75476 .51129 .7595 .51712 .77017 .51393 .76545 .50808 Mtetra
.76545 .50808 .77017 .51393 .78087 .51073 .77619 .50485 Mtetra
.77619 .50485 .78087 .51073 .79161 .50752 .78696 .50162 Mtetra
.78696 .50162 .79161 .50752 .8024 .50429 .79777 .49837 Mtetra
.79777 .49837 .8024 .50429 .81322 .50106 .80862 .49511 Mtetra
.80862 .49511 .81322 .50106 .82408 .49781 .81951 .49184 Mtetra
.81951 .49184 .82408 .49781 .83499 .49455 .83045 .48856 Mtetra
.83045 .48856 .83499 .49455 .84593 .49128 .84142 .48527 Mtetra
.84142 .48527 .84593 .49128 .85692 .488 .85244 .48196 Mtetra
.85244 .48196 .85692 .488 .86795 .4847 .8635 .47864 Mtetra
.8635 .47864 .86795 .4847 .87902 .48139 .8746 .47531 Mtetra
.8746 .47531 .87902 .48139 .89013 .47807 .88574 .47197 Mtetra
.88574 .47197 .89013 .47807 .90128 .47474 .89692 .46861 Mtetra
.89692 .46861 .90128 .47474 .91248 .4714 .90815 .46524 Mtetra
.90815 .46524 .91248 .4714 .92372 .46804 .91942 .46186 Mtetra
.91942 .46186 .92372 .46804 .935 .46467 .93073 .45847 Mtetra
.398 .618 .94 r
.32391 .63543 .32965 .64136 .33943 .62734 .33287 .63693 Mtetra
0 0 0 r
.33287 .63693 .33943 .62734 .34819 .63273 .34251 .62651 Mtetra
.585 .687 .912 r
.34251 .62651 .34819 .63273 .35738 .63081 .35167 .6254 Mtetra
.633 .733 .92 r
.35167 .6254 .35738 .63081 .36662 .62848 .36093 .62317 Mtetra
.64 .74 .921 r
.36093 .62317 .36662 .62848 .3759 .62608 .37023 .62076 Mtetra
.638 .74 .922 r
.37023 .62076 .3759 .62608 .38521 .62383 .37956 .61838 Mtetra
.62 .73 .925 r
.37956 .61838 .38521 .62383 .39451 .62274 .38891 .61638 Mtetra
0 .192 .704 r
.38891 .61638 .39451 .62274 .40417 .61253 .39795 .62379 Mtetra
0 0 0 r
.39795 .62379 .40417 .61253 .41347 .61335 .4079 .60738 Mtetra
.609 .709 .915 r
.4079 .60738 .41347 .61335 .42291 .61109 .41734 .60566 Mtetra
.642 .74 .92 r
.41734 .60566 .42291 .61109 .4324 .60848 .42684 .60315 Mtetra
.65 .747 .92 r
.42684 .60315 .4324 .60848 .44192 .60573 .43639 .60043 Mtetra
.654 .75 .92 r
.43639 .60043 .44192 .60573 .45148 .6029 .44597 .59762 Mtetra
.656 .751 .92 r
.44597 .59762 .45148 .6029 .46108 .60001 .45558 .59473 Mtetra
.658 .753 .92 r
.45558 .59473 .46108 .60001 .4707 .59708 .46523 .5918 Mtetra
.659 .753 .92 r
.46523 .5918 .4707 .59708 .48037 .59413 .47492 .58884 Mtetra
.659 .754 .92 r
.47492 .58884 .48037 .59413 .49006 .59117 .48464 .58585 Mtetra
.48464 .58585 .49006 .59117 .49979 .58819 .49439 .58286 Mtetra
.49439 .58286 .49979 .58819 .50956 .58522 .50418 .57986 Mtetra
.658 .753 .92 r
.50418 .57986 .50956 .58522 .51936 .58224 .514 .57686 Mtetra
.514 .57686 .51936 .58224 .52919 .57925 .52386 .57385 Mtetra
.52386 .57385 .52919 .57925 .53906 .57626 .53375 .57083 Mtetra
.53375 .57083 .53906 .57626 .54897 .57326 .54368 .56782 Mtetra
.54368 .56782 .54897 .57326 .55891 .57026 .55364 .56479 Mtetra
.55364 .56479 .55891 .57026 .56888 .56724 .56364 .56175 Mtetra
.56364 .56175 .56888 .56724 .57889 .56422 .57368 .55871 Mtetra
.657 .753 .92 r
.57368 .55871 .57889 .56422 .58894 .56119 .58375 .55566 Mtetra
.58375 .55566 .58894 .56119 .59902 .55815 .59386 .55259 Mtetra
.59386 .55259 .59902 .55815 .60914 .55509 .604 .54952 Mtetra
.657 .752 .92 r
.604 .54952 .60914 .55509 .6193 .55203 .61418 .54644 Mtetra
.61418 .54644 .6193 .55203 .62949 .54896 .6244 .54335 Mtetra
.6244 .54335 .62949 .54896 .63972 .54588 .63466 .54025 Mtetra
.63466 .54025 .63972 .54588 .64999 .54279 .64495 .53713 Mtetra
.64495 .53713 .64999 .54279 .6603 .53969 .65528 .53401 Mtetra
.65528 .53401 .6603 .53969 .67064 .53658 .66565 .53088 Mtetra
.66565 .53088 .67064 .53658 .68102 .53345 .67606 .52773 Mtetra
.67606 .52773 .68102 .53345 .69144 .53032 .6865 .52458 Mtetra
.6865 .52458 .69144 .53032 .7019 .52718 .69698 .52141 Mtetra
.69698 .52141 .7019 .52718 .71239 .52402 .70751 .51823 Mtetra
.70751 .51823 .71239 .52402 .72293 .52085 .71807 .51505 Mtetra
.71807 .51505 .72293 .52085 .7335 .51768 .72867 .51185 Mtetra
.72867 .51185 .7335 .51768 .74411 .51449 .73931 .50863 Mtetra
.73931 .50863 .74411 .51449 .75476 .51129 .74999 .50541 Mtetra
.74999 .50541 .75476 .51129 .76545 .50808 .76071 .50218 Mtetra
.76071 .50218 .76545 .50808 .77619 .50485 .77147 .49893 Mtetra
.77147 .49893 .77619 .50485 .78696 .50162 .78227 .49567 Mtetra
.78227 .49567 .78696 .50162 .79777 .49837 .79311 .49241 Mtetra
.79311 .49241 .79777 .49837 .80862 .49511 .80399 .48912 Mtetra
.80399 .48912 .80862 .49511 .81951 .49184 .81491 .48583 Mtetra
.81491 .48583 .81951 .49184 .83045 .48856 .82587 .48253 Mtetra
.82587 .48253 .83045 .48856 .84142 .48527 .83688 .47921 Mtetra
.83688 .47921 .84142 .48527 .85244 .48196 .84793 .47588 Mtetra
.84793 .47588 .85244 .48196 .8635 .47864 .85901 .47254 Mtetra
.85901 .47254 .8635 .47864 .8746 .47531 .87014 .46918 Mtetra
.87014 .46918 .8746 .47531 .88574 .47197 .88132 .46582 Mtetra
.88132 .46582 .88574 .47197 .89692 .46861 .89253 .46244 Mtetra
.89253 .46244 .89692 .46861 .90815 .46524 .90379 .45905 Mtetra
.90379 .45905 .90815 .46524 .91942 .46186 .91509 .45564 Mtetra
.91509 .45564 .91942 .46186 .93073 .45847 .92644 .45222 Mtetra
.591 .715 .929 r
.31812 .62987 .32391 .63543 .33287 .63693 .32725 .62849 Mtetra
.818 .698 .732 r
.32725 .62849 .33287 .63693 .34251 .62651 .33712 .61437 Mtetra
.335 .409 .79 r
.33712 .61437 .34251 .62651 .35167 .6254 .34594 .61976 Mtetra
.621 .722 .919 r
.34594 .61976 .35167 .6254 .36093 .62317 .3552 .61779 Mtetra
.638 .738 .921 r
.3552 .61779 .36093 .62317 .37023 .62076 .36452 .61541 Mtetra
.64 .74 .921 r
.36452 .61541 .37023 .62076 .37956 .61838 .37387 .61297 Mtetra
.633 .737 .923 r
.37387 .61297 .37956 .61838 .38891 .61638 .38325 .61068 Mtetra
.576 .707 .932 r
.38325 .61068 .38891 .61638 .39795 .62379 .39262 .60955 Mtetra
.736 .608 .716 r
.39262 .60955 .39795 .62379 .4079 .60738 .40237 .59926 Mtetra
.506 .598 .88 r
.40237 .59926 .4079 .60738 .41734 .60566 .41174 .60005 Mtetra
.633 .731 .919 r
.41174 .60005 .41734 .60566 .42684 .60315 .42125 .59775 Mtetra
.647 .744 .92 r
.42125 .59775 .42684 .60315 .43639 .60043 .43081 .59509 Mtetra
.652 .748 .92 r
.43081 .59509 .43639 .60043 .44597 .59762 .44042 .59229 Mtetra
.655 .751 .92 r
.44042 .59229 .44597 .59762 .45558 .59473 .45005 .58941 Mtetra
.657 .752 .92 r
.45005 .58941 .45558 .59473 .46523 .5918 .45972 .58648 Mtetra
.658 .753 .92 r
.45972 .58648 .46523 .5918 .47492 .58884 .46943 .5835 Mtetra
.659 .754 .92 r
.46943 .5835 .47492 .58884 .48464 .58585 .47917 .5805 Mtetra
.47917 .5805 .48464 .58585 .49439 .58286 .48895 .57749 Mtetra
.48895 .57749 .49439 .58286 .50418 .57986 .49876 .57447 Mtetra
.49876 .57447 .50418 .57986 .514 .57686 .50861 .57144 Mtetra
.658 .753 .92 r
.50861 .57144 .514 .57686 .52386 .57385 .51849 .56841 Mtetra
.51849 .56841 .52386 .57385 .53375 .57083 .5284 .56537 Mtetra
.5284 .56537 .53375 .57083 .54368 .56782 .53835 .56233 Mtetra
.53835 .56233 .54368 .56782 .55364 .56479 .54834 .55928 Mtetra
.54834 .55928 .55364 .56479 .56364 .56175 .55837 .55623 Mtetra
.55837 .55623 .56364 .56175 .57368 .55871 .56842 .55316 Mtetra
.657 .753 .92 r
.56842 .55316 .57368 .55871 .58375 .55566 .57852 .55009 Mtetra
.57852 .55009 .58375 .55566 .59386 .55259 .58865 .547 Mtetra
.58865 .547 .59386 .55259 .604 .54952 .59882 .54391 Mtetra
.59882 .54391 .604 .54952 .61418 .54644 .60903 .54081 Mtetra
.657 .752 .92 r
.60903 .54081 .61418 .54644 .6244 .54335 .61927 .53769 Mtetra
.61927 .53769 .6244 .54335 .63466 .54025 .62955 .53457 Mtetra
.62955 .53457 .63466 .54025 .64495 .53713 .63987 .53144 Mtetra
.63987 .53144 .64495 .53713 .65528 .53401 .65023 .52829 Mtetra
.65023 .52829 .65528 .53401 .66565 .53088 .66062 .52514 Mtetra
.66062 .52514 .66565 .53088 .67606 .52773 .67106 .52197 Mtetra
.67106 .52197 .67606 .52773 .6865 .52458 .68153 .51879 Mtetra
.68153 .51879 .6865 .52458 .69698 .52141 .69204 .51561 Mtetra
.69204 .51561 .69698 .52141 .70751 .51823 .70259 .51241 Mtetra
.70259 .51241 .70751 .51823 .71807 .51505 .71318 .5092 Mtetra
.71318 .5092 .71807 .51505 .72867 .51185 .72381 .50597 Mtetra
.72381 .50597 .72867 .51185 .73931 .50863 .73447 .50274 Mtetra
.73447 .50274 .73931 .50863 .74999 .50541 .74518 .4995 Mtetra
.74518 .4995 .74999 .50541 .76071 .50218 .75593 .49624 Mtetra
.75593 .49624 .76071 .50218 .77147 .49893 .76672 .49297 Mtetra
.76672 .49297 .77147 .49893 .78227 .49567 .77755 .48969 Mtetra
.77755 .48969 .78227 .49567 .79311 .49241 .78841 .4864 Mtetra
.78841 .4864 .79311 .49241 .80399 .48912 .79932 .4831 Mtetra
.79932 .4831 .80399 .48912 .81491 .48583 .81028 .47978 Mtetra
.81028 .47978 .81491 .48583 .82587 .48253 .82127 .47645 Mtetra
.82127 .47645 .82587 .48253 .83688 .47921 .8323 .47311 Mtetra
.8323 .47311 .83688 .47921 .84793 .47588 .84338 .46976 Mtetra
.84338 .46976 .84793 .47588 .85901 .47254 .8545 .46639 Mtetra
.8545 .46639 .85901 .47254 .87014 .46918 .86566 .46301 Mtetra
.86566 .46301 .87014 .46918 .88132 .46582 .87687 .45962 Mtetra
.87687 .45962 .88132 .46582 .89253 .46244 .88811 .45622 Mtetra
.88811 .45622 .89253 .46244 .90379 .45905 .8994 .4528 Mtetra
.8994 .4528 .90379 .45905 .91509 .45564 .91074 .44937 Mtetra
.91074 .44937 .91509 .45564 .92644 .45222 .92211 .44593 Mtetra
.618 .728 .925 r
.31229 .62441 .31812 .62987 .32725 .62849 .32147 .62247 Mtetra
.399 .619 .94 r
.32147 .62247 .32725 .62849 .33712 .61437 .33049 .62394 Mtetra
0 0 0 r
.33049 .62394 .33712 .61437 .34594 .61976 .34021 .61345 Mtetra
.585 .687 .912 r
.34021 .61345 .34594 .61976 .3552 .61779 .34944 .61229 Mtetra
.633 .733 .92 r
.34944 .61229 .3552 .61779 .36452 .61541 .35877 .61002 Mtetra
.64 .74 .921 r
.35877 .61002 .36452 .61541 .37387 .61297 .36814 .60757 Mtetra
.638 .74 .922 r
.36814 .60757 .37387 .61297 .38325 .61068 .37755 .60514 Mtetra
.62 .73 .925 r
.37755 .60514 .38325 .61068 .39262 .60955 .38697 .6031 Mtetra
0 .197 .709 r
.38697 .6031 .39262 .60955 .40237 .59926 .39608 .61051 Mtetra
0 0 0 r
.39608 .61051 .40237 .59926 .41174 .60005 .40611 .59399 Mtetra
.609 .709 .915 r
.40611 .59399 .41174 .60005 .42125 .59775 .41563 .59223 Mtetra
.642 .74 .92 r
.41563 .59223 .42125 .59775 .43081 .59509 .42521 .58967 Mtetra
.65 .747 .92 r
.42521 .58967 .43081 .59509 .44042 .59229 .43483 .58691 Mtetra
.654 .75 .92 r
.43483 .58691 .44042 .59229 .45005 .58941 .44449 .58404 Mtetra
.656 .751 .92 r
.44449 .58404 .45005 .58941 .45972 .58648 .45418 .58111 Mtetra
.658 .753 .92 r
.45418 .58111 .45972 .58648 .46943 .5835 .46391 .57813 Mtetra
.659 .753 .92 r
.46391 .57813 .46943 .5835 .47917 .5805 .47367 .57512 Mtetra
.659 .754 .92 r
.47367 .57512 .47917 .5805 .48895 .57749 .48347 .57208 Mtetra
.48347 .57208 .48895 .57749 .49876 .57447 .49331 .56904 Mtetra
.49331 .56904 .49876 .57447 .50861 .57144 .50318 .56599 Mtetra
.658 .753 .92 r
.50318 .56599 .50861 .57144 .51849 .56841 .51308 .56294 Mtetra
.51308 .56294 .51849 .56841 .5284 .56537 .52302 .55988 Mtetra
.52302 .55988 .5284 .56537 .53835 .56233 .53299 .55681 Mtetra
.53299 .55681 .53835 .56233 .54834 .55928 .54301 .55374 Mtetra
.54301 .55374 .54834 .55928 .55837 .55623 .55305 .55066 Mtetra
.55305 .55066 .55837 .55623 .56842 .55316 .56314 .54758 Mtetra
.56314 .54758 .56842 .55316 .57852 .55009 .57326 .54448 Mtetra
.657 .753 .92 r
.57326 .54448 .57852 .55009 .58865 .547 .58341 .54138 Mtetra
.58341 .54138 .58865 .547 .59882 .54391 .59361 .53826 Mtetra
.59361 .53826 .59882 .54391 .60903 .54081 .60384 .53514 Mtetra
.657 .752 .92 r
.60384 .53514 .60903 .54081 .61927 .53769 .61411 .532 Mtetra
.61411 .532 .61927 .53769 .62955 .53457 .62442 .52886 Mtetra
.62442 .52886 .62955 .53457 .63987 .53144 .63476 .5257 Mtetra
.63476 .5257 .63987 .53144 .65023 .52829 .64514 .52254 Mtetra
.64514 .52254 .65023 .52829 .66062 .52514 .65556 .51936 Mtetra
.65556 .51936 .66062 .52514 .67106 .52197 .66602 .51617 Mtetra
.66602 .51617 .67106 .52197 .68153 .51879 .67652 .51297 Mtetra
.67652 .51297 .68153 .51879 .69204 .51561 .68706 .50976 Mtetra
.68706 .50976 .69204 .51561 .70259 .51241 .69764 .50654 Mtetra
.69764 .50654 .70259 .51241 .71318 .5092 .70825 .50331 Mtetra
.70825 .50331 .71318 .5092 .72381 .50597 .71891 .50006 Mtetra
.71891 .50006 .72381 .50597 .73447 .50274 .7296 .49681 Mtetra
.7296 .49681 .73447 .50274 .74518 .4995 .74034 .49354 Mtetra
.74034 .49354 .74518 .4995 .75593 .49624 .75112 .49026 Mtetra
.75112 .49026 .75593 .49624 .76672 .49297 .76193 .48697 Mtetra
.76193 .48697 .76672 .49297 .77755 .48969 .77279 .48367 Mtetra
.77279 .48367 .77755 .48969 .78841 .4864 .78369 .48035 Mtetra
.78369 .48035 .78841 .4864 .79932 .4831 .79463 .47702 Mtetra
.79463 .47702 .79932 .4831 .81028 .47978 .80561 .47368 Mtetra
.80561 .47368 .81028 .47978 .82127 .47645 .81663 .47033 Mtetra
.81663 .47033 .82127 .47645 .8323 .47311 .8277 .46697 Mtetra
.8277 .46697 .8323 .47311 .84338 .46976 .8388 .46359 Mtetra
.8388 .46359 .84338 .46976 .8545 .46639 .84995 .4602 Mtetra
.84995 .4602 .8545 .46639 .86566 .46301 .86115 .4568 Mtetra
.86115 .4568 .86566 .46301 .87687 .45962 .87238 .45338 Mtetra
.87238 .45338 .87687 .45962 .88811 .45622 .88366 .44996 Mtetra
.88366 .44996 .88811 .45622 .8994 .4528 .89498 .44652 Mtetra
.89498 .44652 .8994 .4528 .91074 .44937 .90635 .44306 Mtetra
.90635 .44306 .91074 .44937 .92211 .44593 .91776 .4396 Mtetra
.626 .731 .923 r
.30642 .61894 .31229 .62441 .32147 .62247 .31562 .61683 Mtetra
.591 .715 .929 r
.31562 .61683 .32147 .62247 .33049 .62394 .32482 .6154 Mtetra
.819 .699 .732 r
.32482 .6154 .33049 .62394 .34021 .61345 .33477 .60119 Mtetra
.333 .409 .79 r
.33477 .60119 .34021 .61345 .34944 .61229 .34366 .60656 Mtetra
.621 .722 .919 r
.34366 .60656 .34944 .61229 .35877 .61002 .35299 .60455 Mtetra
.638 .738 .921 r
.35299 .60455 .35877 .61002 .36814 .60757 .36238 .60213 Mtetra
.64 .74 .921 r
.36238 .60213 .36814 .60757 .37755 .60514 .3718 .59965 Mtetra
.633 .737 .923 r
.3718 .59965 .37755 .60514 .38697 .6031 .38126 .59731 Mtetra
.576 .707 .932 r
.38126 .59731 .38697 .6031 .39608 .61051 .39071 .59614 Mtetra
.736 .608 .716 r
.39071 .59614 .39608 .61051 .40611 .59399 .40053 .58577 Mtetra
.506 .598 .88 r
.40053 .58577 .40611 .59399 .41563 .59223 .40997 .58653 Mtetra
.633 .731 .919 r
.40997 .58653 .41563 .59223 .42521 .58967 .41957 .58418 Mtetra
.647 .744 .92 r
.41957 .58418 .42521 .58967 .43483 .58691 .42921 .58147 Mtetra
.652 .748 .92 r
.42921 .58147 .43483 .58691 .44449 .58404 .43888 .57863 Mtetra
.655 .751 .92 r
.43888 .57863 .44449 .58404 .45418 .58111 .4486 .5757 Mtetra
.657 .752 .92 r
.4486 .5757 .45418 .58111 .46391 .57813 .45835 .57272 Mtetra
.658 .753 .92 r
.45835 .57272 .46391 .57813 .47367 .57512 .46814 .56969 Mtetra
.659 .754 .92 r
.46814 .56969 .47367 .57512 .48347 .57208 .47796 .56664 Mtetra
.47796 .56664 .48347 .57208 .49331 .56904 .48782 .56358 Mtetra
.48782 .56358 .49331 .56904 .50318 .56599 .49771 .5605 Mtetra
.49771 .5605 .50318 .56599 .51308 .56294 .50764 .55743 Mtetra
.658 .753 .92 r
.50764 .55743 .51308 .56294 .52302 .55988 .5176 .55435 Mtetra
.5176 .55435 .52302 .55988 .53299 .55681 .5276 .55126 Mtetra
.5276 .55126 .53299 .55681 .54301 .55374 .53763 .54817 Mtetra
.53763 .54817 .54301 .55374 .55305 .55066 .54771 .54507 Mtetra
.54771 .54507 .55305 .55066 .56314 .54758 .55781 .54196 Mtetra
.55781 .54196 .56314 .54758 .57326 .54448 .56796 .53884 Mtetra
.657 .753 .92 r
.56796 .53884 .57326 .54448 .58341 .54138 .57814 .53571 Mtetra
.57814 .53571 .58341 .54138 .59361 .53826 .58836 .53258 Mtetra
.58836 .53258 .59361 .53826 .60384 .53514 .59862 .52943 Mtetra
.59862 .52943 .60384 .53514 .61411 .532 .60891 .52627 Mtetra
.657 .752 .92 r
.60891 .52627 .61411 .532 .62442 .52886 .61924 .52311 Mtetra
.61924 .52311 .62442 .52886 .63476 .5257 .62961 .51993 Mtetra
.62961 .51993 .63476 .5257 .64514 .52254 .64002 .51674 Mtetra
.64002 .51674 .64514 .52254 .65556 .51936 .65047 .51354 Mtetra
.65047 .51354 .65556 .51936 .66602 .51617 .66096 .51033 Mtetra
.66096 .51033 .66602 .51617 .67652 .51297 .67148 .50711 Mtetra
.67148 .50711 .67652 .51297 .68706 .50976 .68205 .50388 Mtetra
.68205 .50388 .68706 .50976 .69764 .50654 .69265 .50063 Mtetra
.69265 .50063 .69764 .50654 .70825 .50331 .70329 .49738 Mtetra
.70329 .49738 .70825 .50331 .71891 .50006 .71398 .49411 Mtetra
.71398 .49411 .71891 .50006 .7296 .49681 .7247 .49083 Mtetra
.7247 .49083 .7296 .49681 .74034 .49354 .73547 .48754 Mtetra
.73547 .48754 .74034 .49354 .75112 .49026 .74627 .48424 Mtetra
.74627 .48424 .75112 .49026 .76193 .48697 .75712 .48092 Mtetra
.75712 .48092 .76193 .48697 .77279 .48367 .768 .4776 Mtetra
.768 .4776 .77279 .48367 .78369 .48035 .77893 .47426 Mtetra
.77893 .47426 .78369 .48035 .79463 .47702 .7899 .47091 Mtetra
.7899 .47091 .79463 .47702 .80561 .47368 .80091 .46755 Mtetra
.80091 .46755 .80561 .47368 .81663 .47033 .81196 .46417 Mtetra
.81196 .46417 .81663 .47033 .8277 .46697 .82306 .46078 Mtetra
.82306 .46078 .8277 .46697 .8388 .46359 .8342 .45738 Mtetra
.8342 .45738 .8388 .46359 .84995 .4602 .84538 .45397 Mtetra
.84538 .45397 .84995 .4602 .86115 .4568 .8566 .45054 Mtetra
.8566 .45054 .86115 .4568 .87238 .45338 .86787 .4471 Mtetra
.86787 .4471 .87238 .45338 .88366 .44996 .87918 .44365 Mtetra
.87918 .44365 .88366 .44996 .89498 .44652 .89053 .44018 Mtetra
.89053 .44018 .89498 .44652 .90635 .44306 .90193 .43671 Mtetra
.90193 .43671 .90635 .44306 .91776 .4396 .91337 .43322 Mtetra
.625 .729 .922 r
.30051 .61339 .30642 .61894 .31562 .61683 .30973 .61128 Mtetra
.618 .728 .924 r
.30973 .61128 .31562 .61683 .32482 .6154 .31898 .60929 Mtetra
.4 .619 .94 r
.31898 .60929 .32482 .6154 .33477 .60119 .32807 .61074 Mtetra
0 0 0 r
.32807 .61074 .33477 .60119 .34366 .60656 .33787 .60016 Mtetra
.584 .688 .912 r
.33787 .60016 .34366 .60656 .35299 .60455 .34717 .59897 Mtetra
.633 .733 .92 r
.34717 .59897 .35299 .60455 .36238 .60213 .35658 .59665 Mtetra
.64 .74 .921 r
.35658 .59665 .36238 .60213 .3718 .59965 .36602 .59416 Mtetra
.638 .74 .922 r
.36602 .59416 .3718 .59965 .38126 .59731 .3755 .59168 Mtetra
.62 .73 .925 r
.3755 .59168 .38126 .59731 .39071 .59614 .385 .5896 Mtetra
0 .202 .713 r
.385 .5896 .39071 .59614 .40053 .58577 .39418 .59701 Mtetra
0 0 0 r
.39418 .59701 .40053 .58577 .40997 .58653 .4043 .58038 Mtetra
.609 .709 .915 r
.4043 .58038 .40997 .58653 .41957 .58418 .41389 .57857 Mtetra
.642 .74 .92 r
.41389 .57857 .41957 .58418 .42921 .58147 .42355 .57597 Mtetra
.65 .747 .92 r
.42355 .57597 .42921 .58147 .43888 .57863 .43325 .57315 Mtetra
.654 .75 .92 r
.43325 .57315 .43888 .57863 .4486 .5757 .44298 .57024 Mtetra
.656 .751 .92 r
.44298 .57024 .4486 .5757 .45835 .57272 .45276 .56726 Mtetra
.658 .753 .92 r
.45276 .56726 .45835 .57272 .46814 .56969 .46256 .56423 Mtetra
.659 .753 .92 r
.46256 .56423 .46814 .56969 .47796 .56664 .47241 .56116 Mtetra
.659 .754 .92 r
.47241 .56116 .47796 .56664 .48782 .56358 .48229 .55808 Mtetra
.48229 .55808 .48782 .56358 .49771 .5605 .4922 .55498 Mtetra
.4922 .55498 .49771 .5605 .50764 .55743 .50216 .55188 Mtetra
.658 .753 .92 r
.50216 .55188 .50764 .55743 .5176 .55435 .51214 .54878 Mtetra
.51214 .54878 .5176 .55435 .5276 .55126 .52217 .54567 Mtetra
.52217 .54567 .5276 .55126 .53763 .54817 .53223 .54255 Mtetra
.53223 .54255 .53763 .54817 .54771 .54507 .54232 .53943 Mtetra
.54232 .53943 .54771 .54507 .55781 .54196 .55245 .5363 Mtetra
.55245 .5363 .55781 .54196 .56796 .53884 .56262 .53316 Mtetra
.56262 .53316 .56796 .53884 .57814 .53571 .57283 .53001 Mtetra
.657 .753 .92 r
.57283 .53001 .57814 .53571 .58836 .53258 .58308 .52685 Mtetra
.58308 .52685 .58836 .53258 .59862 .52943 .59336 .52368 Mtetra
.59336 .52368 .59862 .52943 .60891 .52627 .60368 .5205 Mtetra
.657 .752 .92 r
.60368 .5205 .60891 .52627 .61924 .52311 .61404 .51731 Mtetra
.61404 .51731 .61924 .52311 .62961 .51993 .62443 .51411 Mtetra
.62443 .51411 .62961 .51993 .64002 .51674 .63487 .5109 Mtetra
.63487 .5109 .64002 .51674 .65047 .51354 .64534 .50768 Mtetra
.64534 .50768 .65047 .51354 .66096 .51033 .65585 .50445 Mtetra
.65585 .50445 .66096 .51033 .67148 .50711 .66641 .50121 Mtetra
.66641 .50121 .67148 .50711 .68205 .50388 .677 .49795 Mtetra
.677 .49795 .68205 .50388 .69265 .50063 .68763 .49468 Mtetra
.68763 .49468 .69265 .50063 .70329 .49738 .6983 .49141 Mtetra
.6983 .49141 .70329 .49738 .71398 .49411 .70901 .48812 Mtetra
.70901 .48812 .71398 .49411 .7247 .49083 .71976 .48481 Mtetra
.71976 .48481 .7247 .49083 .73547 .48754 .73056 .4815 Mtetra
.73056 .4815 .73547 .48754 .74627 .48424 .74139 .47818 Mtetra
.74139 .47818 .74627 .48424 .75712 .48092 .75226 .47484 Mtetra
.75226 .47484 .75712 .48092 .768 .4776 .76318 .47149 Mtetra
.76318 .47149 .768 .4776 .77893 .47426 .77414 .46813 Mtetra
.77414 .46813 .77893 .47426 .7899 .47091 .78514 .46475 Mtetra
.78514 .46475 .7899 .47091 .80091 .46755 .79618 .46136 Mtetra
.79618 .46136 .80091 .46755 .81196 .46417 .80726 .45796 Mtetra
.80726 .45796 .81196 .46417 .82306 .46078 .81838 .45455 Mtetra
.81838 .45455 .82306 .46078 .8342 .45738 .82955 .45113 Mtetra
.82955 .45113 .8342 .45738 .84538 .45397 .84076 .44769 Mtetra
.84076 .44769 .84538 .45397 .8566 .45054 .85202 .44424 Mtetra
.85202 .44424 .8566 .45054 .86787 .4471 .86332 .44077 Mtetra
.86332 .44077 .86787 .4471 .87918 .44365 .87466 .4373 Mtetra
.87466 .4373 .87918 .44365 .89053 .44018 .88605 .43381 Mtetra
.88605 .43381 .89053 .44018 .90193 .43671 .89748 .4303 Mtetra
.89748 .4303 .90193 .43671 .91337 .43322 .90895 .42679 Mtetra
.617 .721 .92 r
.29458 .60765 .30051 .61339 .30973 .61128 .3038 .60572 Mtetra
.626 .731 .923 r
.3038 .60572 .30973 .61128 .31898 .60929 .31308 .60356 Mtetra
.592 .715 .929 r
.31308 .60356 .31898 .60929 .32807 .61074 .32235 .6021 Mtetra
.819 .699 .732 r
.32235 .6021 .32807 .61074 .33787 .60016 .33238 .58779 Mtetra
.332 .408 .79 r
.33238 .58779 .33787 .60016 .34717 .59897 .34133 .59315 Mtetra
.621 .722 .919 r
.34133 .59315 .34717 .59897 .35658 .59665 .35074 .5911 Mtetra
.638 .738 .921 r
.35074 .5911 .35658 .59665 .36602 .59416 .3602 .58863 Mtetra
.64 .74 .921 r
.3602 .58863 .36602 .59416 .3755 .59168 .3697 .5861 Mtetra
.633 .737 .923 r
.3697 .5861 .3755 .59168 .385 .5896 .37924 .58372 Mtetra
.576 .707 .932 r
.37924 .58372 .385 .5896 .39418 .59701 .38876 .58251 Mtetra
.736 .609 .716 r
.38876 .58251 .39418 .59701 .4043 .58038 .39867 .57205 Mtetra
.505 .598 .88 r
.39867 .57205 .4043 .58038 .41389 .57857 .40818 .57278 Mtetra
.633 .731 .919 r
.40818 .57278 .41389 .57857 .42355 .57597 .41785 .57038 Mtetra
.647 .744 .92 r
.41785 .57038 .42355 .57597 .43325 .57315 .42757 .56763 Mtetra
.652 .748 .92 r
.42757 .56763 .43325 .57315 .44298 .57024 .43733 .56473 Mtetra
.655 .751 .92 r
.43733 .56473 .44298 .57024 .45276 .56726 .44712 .56175 Mtetra
.657 .752 .92 r
.44712 .56175 .45276 .56726 .46256 .56423 .45695 .55872 Mtetra
.658 .753 .92 r
.45695 .55872 .46256 .56423 .47241 .56116 .46682 .55565 Mtetra
.659 .754 .92 r
.46682 .55565 .47241 .56116 .48229 .55808 .47672 .55254 Mtetra
.47672 .55254 .48229 .55808 .4922 .55498 .48666 .54943 Mtetra
.48666 .54943 .4922 .55498 .50216 .55188 .49664 .5463 Mtetra
.49664 .5463 .50216 .55188 .51214 .54878 .50665 .54317 Mtetra
.658 .753 .92 r
.50665 .54317 .51214 .54878 .52217 .54567 .5167 .54004 Mtetra
.5167 .54004 .52217 .54567 .53223 .54255 .52678 .5369 Mtetra
.52678 .5369 .53223 .54255 .54232 .53943 .5369 .53376 Mtetra
.5369 .53376 .54232 .53943 .55245 .5363 .54706 .5306 Mtetra
.54706 .5306 .55245 .5363 .56262 .53316 .55725 .52744 Mtetra
.55725 .52744 .56262 .53316 .57283 .53001 .56748 .52427 Mtetra
.657 .753 .92 r
.56748 .52427 .57283 .53001 .58308 .52685 .57775 .52109 Mtetra
.57775 .52109 .58308 .52685 .59336 .52368 .58806 .5179 Mtetra
.58806 .5179 .59336 .52368 .60368 .5205 .59841 .5147 Mtetra
.59841 .5147 .60368 .5205 .61404 .51731 .60879 .51148 Mtetra
.657 .752 .92 r
.60879 .51148 .61404 .51731 .62443 .51411 .61922 .50826 Mtetra
.61922 .50826 .62443 .51411 .63487 .5109 .62968 .50503 Mtetra
.62968 .50503 .63487 .5109 .64534 .50768 .64018 .50178 Mtetra
.64018 .50178 .64534 .50768 .65585 .50445 .65072 .49853 Mtetra
.65072 .49853 .65585 .50445 .66641 .50121 .6613 .49526 Mtetra
.6613 .49526 .66641 .50121 .677 .49795 .67191 .49198 Mtetra
.67191 .49198 .677 .49795 .68763 .49468 .68257 .4887 Mtetra
.68257 .4887 .68763 .49468 .6983 .49141 .69327 .48539 Mtetra
.69327 .48539 .6983 .49141 .70901 .48812 .70401 .48208 Mtetra
.70401 .48208 .70901 .48812 .71976 .48481 .71479 .47876 Mtetra
.71479 .47876 .71976 .48481 .73056 .4815 .72561 .47542 Mtetra
.72561 .47542 .73056 .4815 .74139 .47818 .73647 .47207 Mtetra
.73647 .47207 .74139 .47818 .75226 .47484 .74738 .46871 Mtetra
.74738 .46871 .75226 .47484 .76318 .47149 .75832 .46533 Mtetra
.75832 .46533 .76318 .47149 .77414 .46813 .76931 .46195 Mtetra
.76931 .46195 .77414 .46813 .78514 .46475 .78034 .45855 Mtetra
.78034 .45855 .78514 .46475 .79618 .46136 .79141 .45514 Mtetra
.79141 .45514 .79618 .46136 .80726 .45796 .80252 .45171 Mtetra
.80252 .45171 .80726 .45796 .81838 .45455 .81368 .44828 Mtetra
.81368 .44828 .81838 .45455 .82955 .45113 .82488 .44483 Mtetra
.82488 .44483 .82955 .45113 .84076 .44769 .83612 .44137 Mtetra
.83612 .44137 .84076 .44769 .85202 .44424 .84741 .43789 Mtetra
.84741 .43789 .85202 .44424 .86332 .44077 .85874 .4344 Mtetra
.85874 .4344 .86332 .44077 .87466 .4373 .87011 .4309 Mtetra
.87011 .4309 .87466 .4373 .88605 .43381 .88153 .42738 Mtetra
.88153 .42738 .88605 .43381 .89748 .4303 .89299 .42386 Mtetra
.89299 .42386 .89748 .4303 .90895 .42679 .9045 .42031 Mtetra
.588 .694 .915 r
.28864 .60138 .29458 .60765 .3038 .60572 .29784 .60008 Mtetra
.625 .729 .922 r
.29784 .60008 .3038 .60572 .31308 .60356 .30713 .59792 Mtetra
.618 .728 .924 r
.30713 .59792 .31308 .60356 .32235 .6021 .31645 .5959 Mtetra
.4 .619 .94 r
.31645 .5959 .32235 .6021 .33238 .58779 .32561 .59731 Mtetra
0 0 0 r
.32561 .59731 .33238 .58779 .34133 .59315 .33549 .58666 Mtetra
.584 .688 .912 r
.33549 .58666 .34133 .59315 .35074 .5911 .34487 .58542 Mtetra
.633 .733 .92 r
.34487 .58542 .35074 .5911 .3602 .58863 .35435 .58306 Mtetra
.64 .74 .921 r
.35435 .58306 .3602 .58863 .3697 .5861 .36387 .58052 Mtetra
.638 .74 .922 r
.36387 .58052 .3697 .5861 .37924 .58372 .37342 .578 Mtetra
.62 .73 .925 r
.37342 .578 .37924 .58372 .38876 .58251 .383 .57587 Mtetra
0 .206 .717 r
.383 .57587 .38876 .58251 .39867 .57205 .39224 .58327 Mtetra
0 0 0 r
.39224 .58327 .39867 .57205 .40818 .57278 .40245 .56653 Mtetra
.609 .709 .915 r
.40245 .56653 .40818 .57278 .41785 .57038 .41212 .56468 Mtetra
.642 .74 .92 r
.41212 .56468 .41785 .57038 .42757 .56763 .42186 .56203 Mtetra
.65 .747 .92 r
.42186 .56203 .42757 .56763 .43733 .56473 .43164 .55917 Mtetra
.654 .75 .92 r
.43164 .55917 .43733 .56473 .44712 .56175 .44145 .5562 Mtetra
.656 .751 .92 r
.44145 .5562 .44712 .56175 .45695 .55872 .45131 .55317 Mtetra
.658 .753 .92 r
.45131 .55317 .45695 .55872 .46682 .55565 .4612 .55009 Mtetra
.659 .753 .92 r
.4612 .55009 .46682 .55565 .47672 .55254 .47112 .54697 Mtetra
.659 .754 .92 r
.47112 .54697 .47672 .55254 .48666 .54943 .48109 .54384 Mtetra
.48109 .54384 .48666 .54943 .49664 .5463 .49108 .54069 Mtetra
.49108 .54069 .49664 .5463 .50665 .54317 .50112 .53753 Mtetra
.658 .753 .92 r
.50112 .53753 .50665 .54317 .5167 .54004 .51119 .53438 Mtetra
.51119 .53438 .5167 .54004 .52678 .5369 .5213 .53121 Mtetra
.5213 .53121 .52678 .5369 .5369 .53376 .53144 .52804 Mtetra
.53144 .52804 .5369 .53376 .54706 .5306 .54163 .52487 Mtetra
.54163 .52487 .54706 .5306 .55725 .52744 .55184 .52168 Mtetra
.55184 .52168 .55725 .52744 .56748 .52427 .5621 .51849 Mtetra
.5621 .51849 .56748 .52427 .57775 .52109 .5724 .51528 Mtetra
.657 .753 .92 r
.5724 .51528 .57775 .52109 .58806 .5179 .58273 .51207 Mtetra
.58273 .51207 .58806 .5179 .59841 .5147 .5931 .50885 Mtetra
.5931 .50885 .59841 .5147 .60879 .51148 .60351 .50561 Mtetra
.657 .752 .92 r
.60351 .50561 .60879 .51148 .61922 .50826 .61396 .50237 Mtetra
.61396 .50237 .61922 .50826 .62968 .50503 .62445 .49911 Mtetra
.62445 .49911 .62968 .50503 .64018 .50178 .63498 .49585 Mtetra
.63498 .49585 .64018 .50178 .65072 .49853 .64554 .49257 Mtetra
.64554 .49257 .65072 .49853 .6613 .49526 .65615 .48928 Mtetra
.65615 .48928 .6613 .49526 .67191 .49198 .6668 .48598 Mtetra
.6668 .48598 .67191 .49198 .68257 .4887 .67748 .48266 Mtetra
.67748 .48266 .68257 .4887 .69327 .48539 .68821 .47934 Mtetra
.68821 .47934 .69327 .48539 .70401 .48208 .69898 .476 Mtetra
.69898 .476 .70401 .48208 .71479 .47876 .70979 .47265 Mtetra
.70979 .47265 .71479 .47876 .72561 .47542 .72063 .46929 Mtetra
.72063 .46929 .72561 .47542 .73647 .47207 .73153 .46592 Mtetra
.73153 .46592 .73647 .47207 .74738 .46871 .74246 .46254 Mtetra
.74246 .46254 .74738 .46871 .75832 .46533 .75343 .45914 Mtetra
.75343 .45914 .75832 .46533 .76931 .46195 .76445 .45573 Mtetra
.76445 .45573 .76931 .46195 .78034 .45855 .77551 .4523 Mtetra
.77551 .4523 .78034 .45855 .79141 .45514 .78661 .44887 Mtetra
.78661 .44887 .79141 .45514 .80252 .45171 .79775 .44542 Mtetra
.79775 .44542 .80252 .45171 .81368 .44828 .80894 .44196 Mtetra
.80894 .44196 .81368 .44828 .82488 .44483 .82017 .43849 Mtetra
.82017 .43849 .82488 .44483 .83612 .44137 .83144 .435 Mtetra
.83144 .435 .83612 .44137 .84741 .43789 .84276 .4315 Mtetra
.84276 .4315 .84741 .43789 .85874 .4344 .85412 .42798 Mtetra
.85412 .42798 .85874 .4344 .87011 .4309 .86553 .42446 Mtetra
.86553 .42446 .87011 .4309 .88153 .42738 .87698 .42091 Mtetra
.87698 .42091 .88153 .42738 .89299 .42386 .88847 .41736 Mtetra
.88847 .41736 .89299 .42386 .9045 .42031 .90002 .41379 Mtetra
.415 .511 .849 r
.28292 .59156 .28864 .60138 .29784 .60008 .29185 .59426 Mtetra
.617 .721 .92 r
.29185 .59426 .29784 .60008 .30713 .59792 .30115 .59228 Mtetra
.626 .731 .923 r
.30115 .59228 .30713 .59792 .31645 .5959 .31049 .59008 Mtetra
.592 .715 .929 r
.31049 .59008 .31645 .5959 .32561 .59731 .31984 .58857 Mtetra
.82 .7 .732 r
.31984 .58857 .32561 .59731 .33549 .58666 .32996 .57416 Mtetra
.33 .407 .79 r
.32996 .57416 .33549 .58666 .34487 .58542 .33897 .57952 Mtetra
.621 .722 .919 r
.33897 .57952 .34487 .58542 .35435 .58306 .34845 .57742 Mtetra
.638 .738 .921 r
.34845 .57742 .35435 .58306 .36387 .58052 .35799 .5749 Mtetra
.64 .74 .921 r
.35799 .5749 .36387 .58052 .37342 .578 .36757 .57232 Mtetra
.633 .737 .923 r
.36757 .57232 .37342 .578 .383 .57587 .37718 .56989 Mtetra
.576 .707 .932 r
.37718 .56989 .383 .57587 .39224 .58327 .38677 .56864 Mtetra
.736 .609 .716 r
.38677 .56864 .39224 .58327 .40245 .56653 .39677 .5581 Mtetra
.505 .598 .88 r
.39677 .5581 .40245 .56653 .41212 .56468 .40636 .55879 Mtetra
.633 .731 .919 r
.40636 .55879 .41212 .56468 .42186 .56203 .41611 .55635 Mtetra
.647 .744 .92 r
.41611 .55635 .42186 .56203 .43164 .55917 .42591 .55354 Mtetra
.652 .748 .92 r
.42591 .55354 .43164 .55917 .44145 .5562 .43574 .5506 Mtetra
.655 .751 .92 r
.43574 .5506 .44145 .5562 .45131 .55317 .44562 .54757 Mtetra
.657 .752 .92 r
.44562 .54757 .45131 .55317 .4612 .55009 .45553 .54449 Mtetra
.658 .753 .92 r
.45553 .54449 .4612 .55009 .47112 .54697 .46548 .54136 Mtetra
.659 .754 .92 r
.46548 .54136 .47112 .54697 .48109 .54384 .47547 .5382 Mtetra
.47547 .5382 .48109 .54384 .49108 .54069 .48549 .53504 Mtetra
.48549 .53504 .49108 .54069 .50112 .53753 .49555 .53186 Mtetra
.49555 .53186 .50112 .53753 .51119 .53438 .50565 .52867 Mtetra
.658 .753 .92 r
.50565 .52867 .51119 .53438 .5213 .53121 .51578 .52549 Mtetra
.51578 .52549 .5213 .53121 .53144 .52804 .52595 .52229 Mtetra
.52595 .52229 .53144 .52804 .54163 .52487 .53615 .51909 Mtetra
.53615 .51909 .54163 .52487 .55184 .52168 .5464 .51589 Mtetra
.5464 .51589 .55184 .52168 .5621 .51849 .55668 .51267 Mtetra
.55668 .51267 .5621 .51849 .5724 .51528 .567 .50944 Mtetra
.657 .753 .92 r
.567 .50944 .5724 .51528 .58273 .51207 .57736 .50621 Mtetra
.57736 .50621 .58273 .51207 .5931 .50885 .58776 .50296 Mtetra
.58776 .50296 .5931 .50885 .60351 .50561 .5982 .4997 Mtetra
.5982 .4997 .60351 .50561 .61396 .50237 .60867 .49643 Mtetra
.657 .752 .92 r
.60867 .49643 .61396 .50237 .62445 .49911 .61919 .49316 Mtetra
.61919 .49316 .62445 .49911 .63498 .49585 .62974 .48987 Mtetra
.62974 .48987 .63498 .49585 .64554 .49257 .64033 .48656 Mtetra
.64033 .48656 .64554 .49257 .65615 .48928 .65097 .48325 Mtetra
.65097 .48325 .65615 .48928 .6668 .48598 .66164 .47993 Mtetra
.66164 .47993 .6668 .48598 .67748 .48266 .67236 .47659 Mtetra
.67236 .47659 .67748 .48266 .68821 .47934 .68311 .47324 Mtetra
.68311 .47324 .68821 .47934 .69898 .476 .69391 .46988 Mtetra
.69391 .46988 .69898 .476 .70979 .47265 .70474 .46651 Mtetra
.70474 .46651 .70979 .47265 .72063 .46929 .71562 .46313 Mtetra
.71562 .46313 .72063 .46929 .73153 .46592 .72654 .45973 Mtetra
.72654 .45973 .73153 .46592 .74246 .46254 .7375 .45632 Mtetra
.7375 .45632 .74246 .46254 .75343 .45914 .74851 .4529 Mtetra
.74851 .4529 .75343 .45914 .76445 .45573 .75955 .44946 Mtetra
.75955 .44946 .76445 .45573 .77551 .4523 .77064 .44601 Mtetra
.77064 .44601 .77551 .4523 .78661 .44887 .78177 .44255 Mtetra
.78177 .44255 .78661 .44887 .79775 .44542 .79295 .43908 Mtetra
.79295 .43908 .79775 .44542 .80894 .44196 .80417 .4356 Mtetra
.80417 .4356 .80894 .44196 .82017 .43849 .81543 .4321 Mtetra
.81543 .4321 .82017 .43849 .83144 .435 .82673 .42858 Mtetra
.82673 .42858 .83144 .435 .84276 .4315 .83808 .42506 Mtetra
.83808 .42506 .84276 .4315 .85412 .42798 .84948 .42152 Mtetra
.84948 .42152 .85412 .42798 .86553 .42446 .86091 .41796 Mtetra
.86091 .41796 .86553 .42446 .87698 .42091 .8724 .4144 Mtetra
.8724 .4144 .87698 .42091 .88847 .41736 .88393 .41082 Mtetra
.88393 .41082 .88847 .41736 .90002 .41379 .8955 .40722 Mtetra
.559 .825 .467 r
.27585 .59991 .28292 .59156 .29185 .59426 .28586 .58789 Mtetra
.587 .694 .916 r
.28586 .58789 .29185 .59426 .30115 .59228 .29512 .58655 Mtetra
.625 .729 .922 r
.29512 .58655 .30115 .59228 .31049 .59008 .30449 .58435 Mtetra
.618 .728 .924 r
.30449 .58435 .31049 .59008 .31984 .58857 .31388 .58228 Mtetra
.401 .619 .94 r
.31388 .58228 .31984 .58857 .32996 .57416 .32311 .58366 Mtetra
0 0 0 r
.32311 .58366 .32996 .57416 .33897 .57952 .33308 .57293 Mtetra
.584 .688 .912 r
.33308 .57293 .33897 .57952 .34845 .57742 .34253 .57165 Mtetra
.633 .733 .92 r
.34253 .57165 .34845 .57742 .35799 .5749 .35208 .56924 Mtetra
.64 .74 .921 r
.35208 .56924 .35799 .5749 .36757 .57232 .36168 .56665 Mtetra
.638 .74 .922 r
.36168 .56665 .36757 .57232 .37718 .56989 .37131 .56408 Mtetra
.62 .73 .925 r
.37131 .56408 .37718 .56989 .38677 .56864 .38096 .56191 Mtetra
0 .211 .722 r
.38096 .56191 .38677 .56864 .39677 .5581 .39028 .5693 Mtetra
0 0 0 r
.39028 .5693 .39677 .5581 .40636 .55879 .40058 .55245 Mtetra
.609 .709 .915 r
.40058 .55245 .40636 .55879 .41611 .55635 .41032 .55056 Mtetra
.642 .74 .92 r
.41032 .55056 .41611 .55635 .42591 .55354 .42014 .54785 Mtetra
.65 .747 .92 r
.42014 .54785 .42591 .55354 .43574 .5506 .43 .54494 Mtetra
.654 .75 .92 r
.43 .54494 .43574 .5506 .44562 .54757 .4399 .54192 Mtetra
.656 .751 .92 r
.4399 .54192 .44562 .54757 .45553 .54449 .44983 .53884 Mtetra
.658 .753 .92 r
.44983 .53884 .45553 .54449 .46548 .54136 .4598 .5357 Mtetra
.659 .753 .92 r
.4598 .5357 .46548 .54136 .47547 .5382 .46981 .53253 Mtetra
.659 .754 .92 r
.46981 .53253 .47547 .5382 .48549 .53504 .47986 .52934 Mtetra
.47986 .52934 .48549 .53504 .49555 .53186 .48994 .52614 Mtetra
.48994 .52614 .49555 .53186 .50565 .52867 .50006 .52294 Mtetra
.658 .753 .92 r
.50006 .52294 .50565 .52867 .51578 .52549 .51022 .51972 Mtetra
.51022 .51972 .51578 .52549 .52595 .52229 .52042 .51651 Mtetra
.52042 .51651 .52595 .52229 .53615 .51909 .53065 .51328 Mtetra
.53065 .51328 .53615 .51909 .5464 .51589 .54092 .51005 Mtetra
.54092 .51005 .5464 .51589 .55668 .51267 .55122 .50681 Mtetra
.55122 .50681 .55668 .51267 .567 .50944 .56157 .50356 Mtetra
.56157 .50356 .567 .50944 .57736 .50621 .57196 .5003 Mtetra
.657 .753 .92 r
.57196 .5003 .57736 .50621 .58776 .50296 .58238 .49703 Mtetra
.58238 .49703 .58776 .50296 .5982 .4997 .59284 .49375 Mtetra
.59284 .49375 .5982 .4997 .60867 .49643 .60334 .49046 Mtetra
.657 .752 .92 r
.60334 .49046 .60867 .49643 .61919 .49316 .61388 .48716 Mtetra
.61388 .48716 .61919 .49316 .62974 .48987 .62447 .48384 Mtetra
.62447 .48384 .62974 .48987 .64033 .48656 .63509 .48052 Mtetra
.63509 .48052 .64033 .48656 .65097 .48325 .64575 .47718 Mtetra
.64575 .47718 .65097 .48325 .66164 .47993 .65645 .47383 Mtetra
.65645 .47383 .66164 .47993 .67236 .47659 .66719 .47047 Mtetra
.66719 .47047 .67236 .47659 .68311 .47324 .67797 .4671 Mtetra
.67797 .4671 .68311 .47324 .69391 .46988 .6888 .46372 Mtetra
.6888 .46372 .69391 .46988 .70474 .46651 .69966 .46032 Mtetra
.69966 .46032 .70474 .46651 .71562 .46313 .71057 .45691 Mtetra
.71057 .45691 .71562 .46313 .72654 .45973 .72152 .45349 Mtetra
.72152 .45349 .72654 .45973 .7375 .45632 .73251 .45006 Mtetra
.73251 .45006 .7375 .45632 .74851 .4529 .74355 .44661 Mtetra
.74355 .44661 .74851 .4529 .75955 .44946 .75462 .44315 Mtetra
.75462 .44315 .75955 .44946 .77064 .44601 .76574 .43968 Mtetra
.76574 .43968 .77064 .44601 .78177 .44255 .7769 .43619 Mtetra
.7769 .43619 .78177 .44255 .79295 .43908 .78811 .4327 Mtetra
.78811 .4327 .79295 .43908 .80417 .4356 .79936 .42919 Mtetra
.79936 .42919 .80417 .4356 .81543 .4321 .81065 .42566 Mtetra
.81065 .42566 .81543 .4321 .82673 .42858 .82199 .42212 Mtetra
.82199 .42212 .82673 .42858 .83808 .42506 .83337 .41857 Mtetra
.83337 .41857 .83808 .42506 .84948 .42152 .84479 .41501 Mtetra
.84479 .41501 .84948 .42152 .86091 .41796 .85626 .41143 Mtetra
.85626 .41143 .86091 .41796 .8724 .4144 .86778 .40783 Mtetra
.86778 .40783 .8724 .4144 .88393 .41082 .87934 .40423 Mtetra
.87934 .40423 .88393 .41082 .8955 .40722 .89095 .40061 Mtetra
.782 .669 .739 r
.27008 .58964 .27585 .59991 .28586 .58789 .28008 .57797 Mtetra
.414 .511 .849 r
.28008 .57797 .28586 .58789 .29512 .58655 .28907 .58063 Mtetra
.617 .721 .921 r
.28907 .58063 .29512 .58655 .30449 .58435 .29844 .57861 Mtetra
.626 .731 .923 r
.29844 .57861 .30449 .58435 .31388 .58228 .30786 .57637 Mtetra
.592 .715 .929 r
.30786 .57637 .31388 .58228 .32311 .58366 .31728 .57482 Mtetra
.821 .701 .732 r
.31728 .57482 .32311 .58366 .33308 .57293 .32749 .56031 Mtetra
.328 .406 .79 r
.32749 .56031 .33308 .57293 .34253 .57165 .33657 .56565 Mtetra
.62 .722 .919 r
.33657 .56565 .34253 .57165 .35208 .56924 .34613 .5635 Mtetra
.638 .738 .921 r
.34613 .5635 .35208 .56924 .36168 .56665 .35574 .56094 Mtetra
.64 .74 .921 r
.35574 .56094 .36168 .56665 .37131 .56408 .3654 .55831 Mtetra
.633 .737 .923 r
.3654 .55831 .37131 .56408 .38096 .56191 .37508 .55583 Mtetra
.576 .707 .931 r
.37508 .55583 .38096 .56191 .39028 .5693 .38476 .55454 Mtetra
.737 .609 .716 r
.38476 .55454 .39028 .5693 .40058 .55245 .39484 .54392 Mtetra
.504 .598 .88 r
.39484 .54392 .40058 .55245 .41032 .55056 .40451 .54457 Mtetra
.633 .731 .919 r
.40451 .54457 .41032 .55056 .42014 .54785 .41433 .54208 Mtetra
.647 .744 .92 r
.41433 .54208 .42014 .54785 .43 .54494 .42421 .53922 Mtetra
.652 .748 .92 r
.42421 .53922 .43 .54494 .4399 .54192 .43413 .53622 Mtetra
.655 .751 .92 r
.43413 .53622 .4399 .54192 .44983 .53884 .44409 .53314 Mtetra
.657 .752 .92 r
.44409 .53314 .44983 .53884 .4598 .5357 .45409 .53 Mtetra
.658 .753 .92 r
.45409 .53 .4598 .5357 .46981 .53253 .46412 .52682 Mtetra
.659 .754 .92 r
.46412 .52682 .46981 .53253 .47986 .52934 .47419 .52362 Mtetra
.47419 .52362 .47986 .52934 .48994 .52614 .4843 .52039 Mtetra
.4843 .52039 .48994 .52614 .50006 .52294 .49444 .51716 Mtetra
.49444 .51716 .50006 .52294 .51022 .51972 .50462 .51392 Mtetra
.658 .753 .92 r
.50462 .51392 .51022 .51972 .52042 .51651 .51484 .51068 Mtetra
.51484 .51068 .52042 .51651 .53065 .51328 .5251 .50743 Mtetra
.5251 .50743 .53065 .51328 .54092 .51005 .5354 .50417 Mtetra
.5354 .50417 .54092 .51005 .55122 .50681 .54573 .50091 Mtetra
.54573 .50091 .55122 .50681 .56157 .50356 .5561 .49764 Mtetra
.5561 .49764 .56157 .50356 .57196 .5003 .56651 .49435 Mtetra
.657 .753 .92 r
.56651 .49435 .57196 .5003 .58238 .49703 .57696 .49106 Mtetra
.57696 .49106 .58238 .49703 .59284 .49375 .58745 .48776 Mtetra
.58745 .48776 .59284 .49375 .60334 .49046 .59798 .48444 Mtetra
.59798 .48444 .60334 .49046 .61388 .48716 .60855 .48112 Mtetra
.657 .752 .92 r
.60855 .48112 .61388 .48716 .62447 .48384 .61916 .47778 Mtetra
.61916 .47778 .62447 .48384 .63509 .48052 .6298 .47443 Mtetra
.6298 .47443 .63509 .48052 .64575 .47718 .64049 .47107 Mtetra
.64049 .47107 .64575 .47718 .65645 .47383 .65122 .4677 Mtetra
.65122 .4677 .65645 .47383 .66719 .47047 .66199 .46431 Mtetra
.66199 .46431 .66719 .47047 .67797 .4671 .6728 .46092 Mtetra
.6728 .46092 .67797 .4671 .6888 .46372 .68366 .45751 Mtetra
.68366 .45751 .6888 .46372 .69966 .46032 .69455 .45409 Mtetra
.69455 .45409 .69966 .46032 .71057 .45691 .70549 .45066 Mtetra
.70549 .45066 .71057 .45691 .72152 .45349 .71647 .44721 Mtetra
.71647 .44721 .72152 .45349 .73251 .45006 .72749 .44375 Mtetra
.72749 .44375 .73251 .45006 .74355 .44661 .73855 .44028 Mtetra
.73855 .44028 .74355 .44661 .75462 .44315 .74966 .4368 Mtetra
.74966 .4368 .75462 .44315 .76574 .43968 .7608 .4333 Mtetra
.7608 .4333 .76574 .43968 .7769 .43619 .772 .42979 Mtetra
.772 .42979 .7769 .43619 .78811 .4327 .78323 .42627 Mtetra
.78323 .42627 .78811 .4327 .79936 .42919 .79451 .42273 Mtetra
.79451 .42273 .79936 .42919 .81065 .42566 .80584 .41918 Mtetra
.80584 .41918 .81065 .42566 .82199 .42212 .81721 .41561 Mtetra
.81721 .41561 .82199 .42212 .83337 .41857 .82862 .41204 Mtetra
.82862 .41204 .83337 .41857 .84479 .41501 .84008 .40845 Mtetra
.84008 .40845 .84479 .41501 .85626 .41143 .85158 .40484 Mtetra
.85158 .40484 .85626 .41143 .86778 .40783 .86313 .40122 Mtetra
.86313 .40122 .86778 .40783 .87934 .40423 .87473 .39759 Mtetra
.87473 .39759 .87934 .40423 .89095 .40061 .88637 .39394 Mtetra
.226 .521 .916 r
.26399 .58316 .27008 .58964 .28008 .57797 .27293 .58629 Mtetra
.57 .834 .478 r
.27293 .58629 .28008 .57797 .28907 .58063 .28302 .57417 Mtetra
.587 .694 .916 r
.28302 .57417 .28907 .58063 .29844 .57861 .29236 .57279 Mtetra
.625 .729 .922 r
.29236 .57279 .29844 .57861 .30786 .57637 .3018 .57055 Mtetra
.618 .728 .924 r
.3018 .57055 .30786 .57637 .31728 .57482 .31127 .56843 Mtetra
.402 .619 .94 r
.31127 .56843 .31728 .57482 .32749 .56031 .32056 .56978 Mtetra
0 0 0 r
.32056 .56978 .32749 .56031 .33657 .56565 .33062 .55896 Mtetra
.584 .688 .913 r
.33062 .55896 .33657 .56565 .34613 .5635 .34014 .55764 Mtetra
.632 .733 .921 r
.34014 .55764 .34613 .5635 .35574 .56094 .34977 .55518 Mtetra
.64 .74 .921 r
.34977 .55518 .35574 .56094 .3654 .55831 .35945 .55254 Mtetra
.638 .74 .922 r
.35945 .55254 .3654 .55831 .37508 .55583 .36916 .54993 Mtetra
.62 .73 .925 r
.36916 .54993 .37508 .55583 .38476 .55454 .37889 .5477 Mtetra
0 .216 .726 r
.37889 .5477 .38476 .55454 .39484 .54392 .38827 .55509 Mtetra
0 0 0 r
.38827 .55509 .39484 .54392 .40451 .54457 .39867 .53813 Mtetra
.609 .709 .915 r
.39867 .53813 .40451 .54457 .41433 .54208 .40849 .53619 Mtetra
.642 .74 .92 r
.40849 .53619 .41433 .54208 .42421 .53922 .41839 .53343 Mtetra
.65 .747 .92 r
.41839 .53343 .42421 .53922 .43413 .53622 .42833 .53047 Mtetra
.654 .75 .92 r
.42833 .53047 .43413 .53622 .44409 .53314 .43831 .5274 Mtetra
.656 .751 .92 r
.43831 .5274 .44409 .53314 .45409 .53 .44833 .52426 Mtetra
.658 .753 .92 r
.44833 .52426 .45409 .53 .46412 .52682 .45839 .52107 Mtetra
.659 .753 .92 r
.45839 .52107 .46412 .52682 .47419 .52362 .46848 .51785 Mtetra
.659 .754 .92 r
.46848 .51785 .47419 .52362 .4843 .52039 .47861 .5146 Mtetra
.47861 .5146 .4843 .52039 .49444 .51716 .48878 .51134 Mtetra
.48878 .51134 .49444 .51716 .50462 .51392 .49899 .50808 Mtetra
.658 .753 .92 r
.49899 .50808 .50462 .51392 .51484 .51068 .50923 .50481 Mtetra
.50923 .50481 .51484 .51068 .5251 .50743 .51952 .50154 Mtetra
.51952 .50154 .5251 .50743 .5354 .50417 .52984 .49826 Mtetra
.52984 .49826 .5354 .50417 .54573 .50091 .5402 .49497 Mtetra
.5402 .49497 .54573 .50091 .5561 .49764 .55059 .49167 Mtetra
.55059 .49167 .5561 .49764 .56651 .49435 .56103 .48837 Mtetra
.56103 .48837 .56651 .49435 .57696 .49106 .57151 .48505 Mtetra
.657 .753 .92 r
.57151 .48505 .57696 .49106 .58745 .48776 .58202 .48172 Mtetra
.58202 .48172 .58745 .48776 .59798 .48444 .59258 .47838 Mtetra
.59258 .47838 .59798 .48444 .60855 .48112 .60317 .47503 Mtetra
.657 .752 .92 r
.60317 .47503 .60855 .48112 .61916 .47778 .61381 .47167 Mtetra
.61381 .47167 .61916 .47778 .6298 .47443 .62448 .4683 Mtetra
.62448 .4683 .6298 .47443 .64049 .47107 .6352 .46492 Mtetra
.6352 .46492 .64049 .47107 .65122 .4677 .64596 .46152 Mtetra
.64596 .46152 .65122 .4677 .66199 .46431 .65676 .45811 Mtetra
.65676 .45811 .66199 .46431 .6728 .46092 .66759 .45469 Mtetra
.66759 .45469 .6728 .46092 .68366 .45751 .67848 .45126 Mtetra
.67848 .45126 .68366 .45751 .69455 .45409 .6894 .44781 Mtetra
.6894 .44781 .69455 .45409 .70549 .45066 .70037 .44436 Mtetra
.70037 .44436 .70549 .45066 .71647 .44721 .71137 .44089 Mtetra
.71137 .44089 .71647 .44721 .72749 .44375 .72242 .4374 Mtetra
.72242 .4374 .72749 .44375 .73855 .44028 .73352 .43391 Mtetra
.73352 .43391 .73855 .44028 .74966 .4368 .74465 .4304 Mtetra
.74465 .4304 .74966 .4368 .7608 .4333 .75583 .42687 Mtetra
.75583 .42687 .7608 .4333 .772 .42979 .76706 .42334 Mtetra
.76706 .42334 .772 .42979 .78323 .42627 .77832 .41979 Mtetra
.77832 .41979 .78323 .42627 .79451 .42273 .78964 .41623 Mtetra
.78964 .41623 .79451 .42273 .80584 .41918 .80099 .41265 Mtetra
.80099 .41265 .80584 .41918 .81721 .41561 .81239 .40906 Mtetra
.81239 .40906 .81721 .41561 .82862 .41204 .82384 .40546 Mtetra
.82384 .40546 .82862 .41204 .84008 .40845 .83533 .40184 Mtetra
.83533 .40184 .84008 .40845 .85158 .40484 .84686 .39821 Mtetra
.84686 .39821 .85158 .40484 .86313 .40122 .85845 .39456 Mtetra
.85845 .39456 .86313 .40122 .87473 .39759 .87007 .3909 Mtetra
.87007 .3909 .87473 .39759 .88637 .39394 .88175 .38723 Mtetra
.576 .706 .931 r
.25783 .57716 .26399 .58316 .27293 .58629 .26711 .5759 Mtetra
.782 .67 .739 r
.26711 .5759 .27293 .58629 .28302 .57417 .27719 .56414 Mtetra
.413 .511 .849 r
.27719 .56414 .28302 .57417 .29236 .57279 .28625 .56678 Mtetra
.617 .721 .921 r
.28625 .56678 .29236 .57279 .3018 .57055 .29569 .56471 Mtetra
.626 .731 .923 r
.29569 .56471 .3018 .57055 .31127 .56843 .30519 .56242 Mtetra
.592 .715 .929 r
.30519 .56242 .31127 .56843 .32056 .56978 .31468 .56083 Mtetra
.821 .702 .732 r
.31468 .56083 .32056 .56978 .33062 .55896 .32498 .54622 Mtetra
.327 .405 .79 r
.32498 .54622 .33062 .55896 .34014 .55764 .33413 .55154 Mtetra
.62 .722 .919 r
.33413 .55154 .34014 .55764 .34977 .55518 .34376 .54935 Mtetra
.638 .738 .921 r
.34376 .54935 .34977 .55518 .35945 .55254 .35346 .54674 Mtetra
.64 .74 .921 r
.35346 .54674 .35945 .55254 .36916 .54993 .36319 .54406 Mtetra
.633 .737 .923 r
.36319 .54406 .36916 .54993 .37889 .5477 .37295 .54153 Mtetra
.577 .707 .931 r
.37295 .54153 .37889 .5477 .38827 .55509 .38271 .54019 Mtetra
.737 .609 .716 r
.38271 .54019 .38827 .55509 .39867 .53813 .39287 .52948 Mtetra
.504 .598 .881 r
.39287 .52948 .39867 .53813 .40849 .53619 .40262 .5301 Mtetra
.633 .731 .919 r
.40262 .5301 .40849 .53619 .41839 .53343 .41253 .52756 Mtetra
.647 .744 .92 r
.41253 .52756 .41839 .53343 .42833 .53047 .42249 .52465 Mtetra
.652 .748 .92 r
.42249 .52465 .42833 .53047 .43831 .5274 .43249 .5216 Mtetra
.655 .751 .92 r
.43249 .5216 .43831 .5274 .44833 .52426 .44254 .51846 Mtetra
.657 .752 .92 r
.44254 .51846 .44833 .52426 .45839 .52107 .45262 .51527 Mtetra
.658 .753 .92 r
.45262 .51527 .45839 .52107 .46848 .51785 .46273 .51203 Mtetra
.659 .754 .92 r
.46273 .51203 .46848 .51785 .47861 .5146 .47289 .50877 Mtetra
.47289 .50877 .47861 .5146 .48878 .51134 .48308 .50549 Mtetra
.48308 .50549 .48878 .51134 .49899 .50808 .49332 .5022 Mtetra
.49332 .5022 .49899 .50808 .50923 .50481 .50359 .49891 Mtetra
.658 .753 .92 r
.50359 .49891 .50923 .50481 .51952 .50154 .51389 .49561 Mtetra
.51389 .49561 .51952 .50154 .52984 .49826 .52424 .4923 Mtetra
.52424 .4923 .52984 .49826 .5402 .49497 .53462 .48899 Mtetra
.53462 .48899 .5402 .49497 .55059 .49167 .54505 .48567 Mtetra
.54505 .48567 .55059 .49167 .56103 .48837 .55551 .48234 Mtetra
.55551 .48234 .56103 .48837 .57151 .48505 .56601 .479 Mtetra
.657 .753 .92 r
.56601 .479 .57151 .48505 .58202 .48172 .57655 .47565 Mtetra
.57655 .47565 .58202 .48172 .59258 .47838 .58714 .47228 Mtetra
.58714 .47228 .59258 .47838 .60317 .47503 .59776 .46891 Mtetra
.59776 .46891 .60317 .47503 .61381 .47167 .60842 .46552 Mtetra
.657 .752 .92 r
.60842 .46552 .61381 .47167 .62448 .4683 .61912 .46213 Mtetra
.61912 .46213 .62448 .4683 .6352 .46492 .62987 .45872 Mtetra
.62987 .45872 .6352 .46492 .64596 .46152 .64065 .4553 Mtetra
.64065 .4553 .64596 .46152 .65676 .45811 .65148 .45187 Mtetra
.65148 .45187 .65676 .45811 .66759 .45469 .66235 .44842 Mtetra
.66235 .44842 .66759 .45469 .67848 .45126 .67326 .44496 Mtetra
.67326 .44496 .67848 .45126 .6894 .44781 .68421 .44149 Mtetra
.68421 .44149 .6894 .44781 .70037 .44436 .69521 .43801 Mtetra
.69521 .43801 .70037 .44436 .71137 .44089 .70624 .43451 Mtetra
.70624 .43451 .71137 .44089 .72242 .4374 .71732 .43101 Mtetra
.71732 .43101 .72242 .4374 .73352 .43391 .72845 .42748 Mtetra
.72845 .42748 .73352 .43391 .74465 .4304 .73961 .42395 Mtetra
.73961 .42395 .74465 .4304 .75583 .42687 .75083 .4204 Mtetra
.75083 .4204 .75583 .42687 .76706 .42334 .76208 .41684 Mtetra
.76208 .41684 .76706 .42334 .77832 .41979 .77338 .41326 Mtetra
.77338 .41326 .77832 .41979 .78964 .41623 .78472 .40968 Mtetra
.78472 .40968 .78964 .41623 .80099 .41265 .79611 .40607 Mtetra
.79611 .40607 .80099 .41265 .81239 .40906 .80754 .40246 Mtetra
.80754 .40246 .81239 .40906 .82384 .40546 .81902 .39883 Mtetra
.81902 .39883 .82384 .40546 .83533 .40184 .83054 .39518 Mtetra
.83054 .39518 .83533 .40184 .84686 .39821 .84211 .39152 Mtetra
.84211 .39152 .84686 .39821 .85845 .39456 .85373 .38785 Mtetra
.85373 .38785 .85845 .39456 .87007 .3909 .86539 .38416 Mtetra
.86539 .38416 .87007 .3909 .88175 .38723 .8771 .38046 Mtetra
.609 .722 .925 r
.25161 .57124 .25783 .57716 .26711 .5759 .26096 .56933 Mtetra
.228 .522 .916 r
.26096 .56933 .26711 .5759 .27719 .56414 .26996 .57243 Mtetra
.582 .843 .49 r
.26996 .57243 .27719 .56414 .28625 .56678 .28014 .56022 Mtetra
.587 .694 .916 r
.28014 .56022 .28625 .56678 .29569 .56471 .28955 .5588 Mtetra
.625 .729 .922 r
.28955 .5588 .29569 .56471 .30519 .56242 .29907 .55651 Mtetra
.618 .728 .924 r
.29907 .55651 .30519 .56242 .31468 .56083 .30861 .55434 Mtetra
.403 .619 .939 r
.30861 .55434 .31468 .56083 .32498 .54622 .31798 .55566 Mtetra
0 0 0 r
.31798 .55566 .32498 .54622 .33413 .55154 .32812 .54476 Mtetra
.584 .688 .913 r
.32812 .54476 .33413 .55154 .34376 .54935 .33772 .54339 Mtetra
.632 .733 .921 r
.33772 .54339 .34376 .54935 .35346 .54674 .34743 .54088 Mtetra
.64 .74 .921 r
.34743 .54088 .35346 .54674 .36319 .54406 .35718 .53819 Mtetra
.638 .739 .922 r
.35718 .53819 .36319 .54406 .37295 .54153 .36697 .53552 Mtetra
.62 .73 .925 r
.36697 .53552 .37295 .54153 .38271 .54019 .37678 .53325 Mtetra
0 .22 .73 r
.37678 .53325 .38271 .54019 .39287 .52948 .38624 .54063 Mtetra
0 0 0 r
.38624 .54063 .39287 .52948 .40262 .5301 .39672 .52356 Mtetra
.609 .709 .915 r
.39672 .52356 .40262 .5301 .41253 .52756 .40663 .52157 Mtetra
.642 .74 .92 r
.40663 .52157 .41253 .52756 .42249 .52465 .41661 .51876 Mtetra
.65 .747 .92 r
.41661 .51876 .42249 .52465 .43249 .5216 .42664 .51574 Mtetra
.654 .75 .92 r
.42664 .51574 .43249 .5216 .44254 .51846 .4367 .51262 Mtetra
.656 .751 .92 r
.4367 .51262 .44254 .51846 .45262 .51527 .4468 .50942 Mtetra
.658 .753 .92 r
.4468 .50942 .45262 .51527 .46273 .51203 .45695 .50618 Mtetra
.659 .753 .92 r
.45695 .50618 .46273 .51203 .47289 .50877 .46713 .5029 Mtetra
.659 .754 .92 r
.46713 .5029 .47289 .50877 .48308 .50549 .47735 .4996 Mtetra
.47735 .4996 .48308 .50549 .49332 .5022 .4876 .49628 Mtetra
.4876 .49628 .49332 .5022 .50359 .49891 .4979 .49296 Mtetra
.658 .753 .92 r
.4979 .49296 .50359 .49891 .51389 .49561 .50823 .48964 Mtetra
.50823 .48964 .51389 .49561 .52424 .4923 .5186 .48631 Mtetra
.5186 .48631 .52424 .4923 .53462 .48899 .52901 .48297 Mtetra
.52901 .48297 .53462 .48899 .54505 .48567 .53946 .47962 Mtetra
.53946 .47962 .54505 .48567 .55551 .48234 .54995 .47627 Mtetra
.54995 .47627 .55551 .48234 .56601 .479 .56048 .4729 Mtetra
.56048 .4729 .56601 .479 .57655 .47565 .57105 .46953 Mtetra
.657 .753 .92 r
.57105 .46953 .57655 .47565 .58714 .47228 .58166 .46614 Mtetra
.58166 .46614 .58714 .47228 .59776 .46891 .59231 .46274 Mtetra
.59231 .46274 .59776 .46891 .60842 .46552 .603 .45933 Mtetra
.657 .752 .92 r
.603 .45933 .60842 .46552 .61912 .46213 .61373 .45591 Mtetra
.61373 .45591 .61912 .46213 .62987 .45872 .6245 .45248 Mtetra
.6245 .45248 .62987 .45872 .64065 .4553 .63531 .44903 Mtetra
.63531 .44903 .64065 .4553 .65148 .45187 .64617 .44557 Mtetra
.64617 .44557 .65148 .45187 .66235 .44842 .65707 .4421 Mtetra
.65707 .4421 .66235 .44842 .67326 .44496 .66801 .43862 Mtetra
.66801 .43862 .67326 .44496 .68421 .44149 .67899 .43513 Mtetra
.67899 .43513 .68421 .44149 .69521 .43801 .69001 .43162 Mtetra
.69001 .43162 .69521 .43801 .70624 .43451 .70108 .4281 Mtetra
.70108 .4281 .70624 .43451 .71732 .43101 .71219 .42456 Mtetra
.71219 .42456 .71732 .43101 .72845 .42748 .72334 .42102 Mtetra
.72334 .42102 .72845 .42748 .73961 .42395 .73454 .41745 Mtetra
.73454 .41745 .73961 .42395 .75083 .4204 .74578 .41388 Mtetra
.74578 .41388 .75083 .4204 .76208 .41684 .75707 .41029 Mtetra
.75707 .41029 .76208 .41684 .77338 .41326 .7684 .40669 Mtetra
.7684 .40669 .77338 .41326 .78472 .40968 .77977 .40308 Mtetra
.77977 .40308 .78472 .40968 .79611 .40607 .79119 .39945 Mtetra
.79119 .39945 .79611 .40607 .80754 .40246 .80266 .39581 Mtetra
.80266 .39581 .80754 .40246 .81902 .39883 .81417 .39215 Mtetra
.81417 .39215 .81902 .39883 .83054 .39518 .82572 .38848 Mtetra
.82572 .38848 .83054 .39518 .84211 .39152 .83733 .38479 Mtetra
.83733 .38479 .84211 .39152 .85373 .38785 .84897 .38109 Mtetra
.84897 .38109 .85373 .38785 .86539 .38416 .86067 .37738 Mtetra
.86067 .37738 .86539 .38416 .8771 .38046 .87241 .37365 Mtetra
.614 .723 .923 r
.24536 .56527 .25161 .57124 .26096 .56933 .25473 .56323 Mtetra
.576 .706 .931 r
.25473 .56323 .26096 .56933 .26996 .57243 .26408 .56192 Mtetra
.783 .67 .74 r
.26408 .56192 .26996 .57243 .28014 .56022 .27426 .55008 Mtetra
.412 .51 .849 r
.27426 .55008 .28014 .56022 .28955 .5588 .28338 .55269 Mtetra
.617 .721 .921 r
.28338 .55269 .28955 .5588 .29907 .55651 .2929 .55058 Mtetra
.626 .731 .923 r
.2929 .55058 .29907 .55651 .30861 .55434 .30247 .54824 Mtetra
.592 .715 .929 r
.30247 .54824 .30861 .55434 .31798 .55566 .31204 .5466 Mtetra
.822 .702 .733 r
.31204 .5466 .31798 .55566 .32812 .54476 .32243 .53189 Mtetra
.325 .404 .79 r
.32243 .53189 .32812 .54476 .33772 .54339 .33165 .53719 Mtetra
.62 .722 .919 r
.33165 .53719 .33772 .54339 .34743 .54088 .34136 .53495 Mtetra
.638 .738 .921 r
.34136 .53495 .34743 .54088 .35718 .53819 .35113 .53229 Mtetra
.64 .74 .921 r
.35113 .53229 .35718 .53819 .36697 .53552 .36094 .52956 Mtetra
.633 .737 .923 r
.36094 .52956 .36697 .53552 .37678 .53325 .37079 .52698 Mtetra
.577 .707 .931 r
.37079 .52698 .37678 .53325 .38624 .54063 .38062 .5256 Mtetra
.737 .61 .716 r
.38062 .5256 .38624 .54063 .39672 .52356 .39088 .5148 Mtetra
.504 .598 .881 r
.39088 .5148 .39672 .52356 .40663 .52157 .4007 .51538 Mtetra
.633 .731 .919 r
.4007 .51538 .40663 .52157 .41661 .51876 .41069 .51278 Mtetra
.647 .744 .92 r
.41069 .51278 .41661 .51876 .42664 .51574 .42074 .50982 Mtetra
.652 .748 .92 r
.42074 .50982 .42664 .51574 .4367 .51262 .43083 .50671 Mtetra
.655 .751 .92 r
.43083 .50671 .4367 .51262 .4468 .50942 .44095 .50352 Mtetra
.657 .752 .92 r
.44095 .50352 .4468 .50942 .45695 .50618 .45112 .50027 Mtetra
.658 .753 .92 r
.45112 .50027 .45695 .50618 .46713 .5029 .46132 .49698 Mtetra
.659 .754 .92 r
.46132 .49698 .46713 .5029 .47735 .4996 .47157 .49366 Mtetra
.47157 .49366 .47735 .4996 .4876 .49628 .48185 .49033 Mtetra
.48185 .49033 .4876 .49628 .4979 .49296 .49217 .48698 Mtetra
.49217 .48698 .4979 .49296 .50823 .48964 .50253 .48363 Mtetra
.658 .753 .92 r
.50253 .48363 .50823 .48964 .5186 .48631 .51293 .48027 Mtetra
.51293 .48027 .5186 .48631 .52901 .48297 .52336 .47691 Mtetra
.52336 .47691 .52901 .48297 .53946 .47962 .53384 .47354 Mtetra
.53384 .47354 .53946 .47962 .54995 .47627 .54435 .47015 Mtetra
.54435 .47015 .54995 .47627 .56048 .4729 .55491 .46676 Mtetra
.55491 .46676 .56048 .4729 .57105 .46953 .5655 .46336 Mtetra
.657 .753 .92 r
.5655 .46336 .57105 .46953 .58166 .46614 .57614 .45995 Mtetra
.57614 .45995 .58166 .46614 .59231 .46274 .58682 .45653 Mtetra
.58682 .45653 .59231 .46274 .603 .45933 .59753 .45309 Mtetra
.59753 .45309 .603 .45933 .61373 .45591 .60829 .44965 Mtetra
.657 .752 .92 r
.60829 .44965 .61373 .45591 .6245 .45248 .61909 .44619 Mtetra
.61909 .44619 .6245 .45248 .63531 .44903 .62994 .44272 Mtetra
.62994 .44272 .63531 .44903 .64617 .44557 .64082 .43924 Mtetra
.64082 .43924 .64617 .44557 .65707 .4421 .65175 .43574 Mtetra
.65175 .43574 .65707 .4421 .66801 .43862 .66271 .43223 Mtetra
.66271 .43223 .66801 .43862 .67899 .43513 .67372 .42871 Mtetra
.67372 .42871 .67899 .43513 .69001 .43162 .68478 .42518 Mtetra
.68478 .42518 .69001 .43162 .70108 .4281 .69588 .42163 Mtetra
.69588 .42163 .70108 .4281 .71219 .42456 .70702 .41807 Mtetra
.70702 .41807 .71219 .42456 .72334 .42102 .7182 .4145 Mtetra
.7182 .4145 .72334 .42102 .73454 .41745 .72943 .41091 Mtetra
.72943 .41091 .73454 .41745 .74578 .41388 .7407 .40731 Mtetra
.7407 .40731 .74578 .41388 .75707 .41029 .75202 .4037 Mtetra
.75202 .4037 .75707 .41029 .7684 .40669 .76338 .40007 Mtetra
.76338 .40007 .7684 .40669 .77977 .40308 .77479 .39643 Mtetra
.77479 .39643 .77977 .40308 .79119 .39945 .78624 .39277 Mtetra
.78624 .39277 .79119 .39945 .80266 .39581 .79773 .3891 Mtetra
.79773 .3891 .80266 .39581 .81417 .39215 .80928 .38542 Mtetra
.80928 .38542 .81417 .39215 .82572 .38848 .82087 .38172 Mtetra
.82087 .38172 .82572 .38848 .83733 .38479 .8325 .37801 Mtetra
.8325 .37801 .83733 .38479 .84897 .38109 .84419 .37428 Mtetra
.84419 .37428 .84897 .38109 .86067 .37738 .85591 .37054 Mtetra
.85591 .37054 .86067 .37738 .87241 .37365 .86769 .36678 Mtetra
.605 .713 .921 r
.23909 .55907 .24536 .56527 .25473 .56323 .24845 .55722 Mtetra
.609 .722 .925 r
.24845 .55722 .25473 .56323 .26408 .56192 .25787 .55526 Mtetra
.231 .523 .916 r
.25787 .55526 .26408 .56192 .27426 .55008 .26694 .55833 Mtetra
.593 .852 .501 r
.26694 .55833 .27426 .55008 .28338 .55269 .27721 .54604 Mtetra
.587 .694 .916 r
.27721 .54604 .28338 .55269 .2929 .55058 .2867 .54457 Mtetra
.625 .729 .922 r
.2867 .54457 .2929 .55058 .30247 .54824 .29629 .54222 Mtetra
.618 .728 .924 r
.29629 .54222 .30247 .54824 .31204 .5466 .3059 .54001 Mtetra
.404 .62 .939 r
.3059 .54001 .31204 .5466 .32243 .53189 .31534 .5413 Mtetra
0 0 0 r
.31534 .5413 .32243 .53189 .33165 .53719 .32558 .53031 Mtetra
.584 .688 .913 r
.32558 .53031 .33165 .53719 .34136 .53495 .33525 .5289 Mtetra
.632 .733 .921 r
.33525 .5289 .34136 .53495 .35113 .53229 .34504 .52634 Mtetra
.64 .74 .921 r
.34504 .52634 .35113 .53229 .36094 .52956 .35487 .52359 Mtetra
.638 .739 .922 r
.35487 .52359 .36094 .52956 .37079 .52698 .36474 .52087 Mtetra
.62 .73 .925 r
.36474 .52087 .37079 .52698 .38062 .5256 .37464 .51855 Mtetra
0 .225 .734 r
.37464 .51855 .38062 .5256 .39088 .5148 .38416 .52592 Mtetra
0 0 0 r
.38416 .52592 .39088 .5148 .4007 .51538 .39475 .50873 Mtetra
.609 .709 .916 r
.39475 .50873 .4007 .51538 .41069 .51278 .40474 .50669 Mtetra
.642 .74 .92 r
.40474 .50669 .41069 .51278 .42074 .50982 .4148 .50383 Mtetra
.65 .747 .92 r
.4148 .50383 .42074 .50982 .43083 .50671 .42491 .50075 Mtetra
.654 .75 .92 r
.42491 .50075 .43083 .50671 .44095 .50352 .43506 .49757 Mtetra
.656 .751 .92 r
.43506 .49757 .44095 .50352 .45112 .50027 .44525 .49432 Mtetra
.658 .753 .92 r
.44525 .49432 .45112 .50027 .46132 .49698 .45548 .49102 Mtetra
.659 .753 .92 r
.45548 .49102 .46132 .49698 .47157 .49366 .46575 .48769 Mtetra
.659 .754 .92 r
.46575 .48769 .47157 .49366 .48185 .49033 .47606 .48433 Mtetra
.47606 .48433 .48185 .49033 .49217 .48698 .4864 .48096 Mtetra
.4864 .48096 .49217 .48698 .50253 .48363 .49679 .47758 Mtetra
.658 .753 .92 r
.49679 .47758 .50253 .48363 .51293 .48027 .50721 .47419 Mtetra
.50721 .47419 .51293 .48027 .52336 .47691 .51767 .4708 Mtetra
.51767 .4708 .52336 .47691 .53384 .47354 .52817 .46741 Mtetra
.52817 .46741 .53384 .47354 .54435 .47015 .53872 .464 Mtetra
.53872 .464 .54435 .47015 .55491 .46676 .5493 .46058 Mtetra
.5493 .46058 .55491 .46676 .5655 .46336 .55992 .45716 Mtetra
.55992 .45716 .5655 .46336 .57614 .45995 .57058 .45372 Mtetra
.657 .753 .92 r
.57058 .45372 .57614 .45995 .58682 .45653 .58129 .45027 Mtetra
.58129 .45027 .58682 .45653 .59753 .45309 .59203 .44681 Mtetra
.59203 .44681 .59753 .45309 .60829 .44965 .60282 .44334 Mtetra
.657 .752 .92 r
.60282 .44334 .60829 .44965 .61909 .44619 .61365 .43986 Mtetra
.61365 .43986 .61909 .44619 .62994 .44272 .62452 .43636 Mtetra
.62452 .43636 .62994 .44272 .64082 .43924 .63543 .43286 Mtetra
.63543 .43286 .64082 .43924 .65175 .43574 .64639 .42934 Mtetra
.64639 .42934 .65175 .43574 .66271 .43223 .65738 .4258 Mtetra
.65738 .4258 .66271 .43223 .67372 .42871 .66842 .42226 Mtetra
.66842 .42226 .67372 .42871 .68478 .42518 .67951 .4187 Mtetra
.67951 .4187 .68478 .42518 .69588 .42163 .69063 .41512 Mtetra
.69063 .41512 .69588 .42163 .70702 .41807 .70181 .41154 Mtetra
.70181 .41154 .70702 .41807 .7182 .4145 .71302 .40794 Mtetra
.71302 .40794 .7182 .4145 .72943 .41091 .72428 .40432 Mtetra
.72428 .40432 .72943 .41091 .7407 .40731 .73558 .4007 Mtetra
.73558 .4007 .7407 .40731 .75202 .4037 .74693 .39706 Mtetra
.74693 .39706 .75202 .4037 .76338 .40007 .75832 .3934 Mtetra
.75832 .3934 .76338 .40007 .77479 .39643 .76976 .38973 Mtetra
.76976 .38973 .77479 .39643 .78624 .39277 .78125 .38605 Mtetra
.78125 .38605 .78624 .39277 .79773 .3891 .79278 .38235 Mtetra
.79278 .38235 .79773 .3891 .80928 .38542 .80435 .37864 Mtetra
.80435 .37864 .80928 .38542 .82087 .38172 .81598 .37492 Mtetra
.81598 .37492 .82087 .38172 .8325 .37801 .82764 .37118 Mtetra
.82764 .37118 .8325 .37801 .84419 .37428 .83936 .36742 Mtetra
.83936 .36742 .84419 .37428 .85591 .37054 .85112 .36365 Mtetra
.85112 .36365 .85591 .37054 .86769 .36678 .86294 .35987 Mtetra
.562 .672 .912 r
.23284 .55206 .23909 .55907 .24845 .55722 .24214 .55115 Mtetra
.614 .723 .923 r
.24214 .55115 .24845 .55722 .25787 .55526 .25158 .54906 Mtetra
.576 .706 .931 r
.25158 .54906 .25787 .55526 .26694 .55833 .261 .54771 Mtetra
.783 .671 .74 r
.261 .54771 .26694 .55833 .27721 .54604 .27127 .53578 Mtetra
.411 .51 .849 r
.27127 .53578 .27721 .54604 .2867 .54457 .28046 .53836 Mtetra
.617 .721 .921 r
.28046 .53836 .2867 .54457 .29629 .54222 .29006 .5362 Mtetra
.626 .731 .923 r
.29006 .5362 .29629 .54222 .3059 .54001 .2997 .53381 Mtetra
.592 .714 .929 r
.2997 .53381 .3059 .54001 .31534 .5413 .30935 .53212 Mtetra
.823 .703 .733 r
.30935 .53212 .31534 .5413 .32558 .53031 .31984 .51731 Mtetra
.323 .403 .79 r
.31984 .51731 .32558 .53031 .33525 .5289 .32912 .5226 Mtetra
.62 .722 .919 r
.32912 .5226 .33525 .5289 .34504 .52634 .33891 .52031 Mtetra
.638 .738 .921 r
.33891 .52031 .34504 .52634 .35487 .52359 .34876 .51759 Mtetra
.64 .74 .921 r
.34876 .51759 .35487 .52359 .36474 .52087 .35866 .51481 Mtetra
.633 .737 .923 r
.35866 .51481 .36474 .52087 .37464 .51855 .36858 .51217 Mtetra
.577 .707 .931 r
.36858 .51217 .37464 .51855 .38416 .52592 .3785 .51074 Mtetra
.737 .61 .716 r
.3785 .51074 .38416 .52592 .39475 .50873 .38884 .49986 Mtetra
.503 .598 .881 r
.38884 .49986 .39475 .50873 .40474 .50669 .39875 .5004 Mtetra
.633 .731 .919 r
.39875 .5004 .40474 .50669 .4148 .50383 .40883 .49775 Mtetra
.647 .744 .92 r
.40883 .49775 .4148 .50383 .42491 .50075 .41896 .49473 Mtetra
.652 .748 .92 r
.41896 .49473 .42491 .50075 .43506 .49757 .42913 .49157 Mtetra
.655 .751 .92 r
.42913 .49157 .43506 .49757 .44525 .49432 .43934 .48832 Mtetra
.657 .752 .92 r
.43934 .48832 .44525 .49432 .45548 .49102 .4496 .48501 Mtetra
.658 .753 .92 r
.4496 .48501 .45548 .49102 .46575 .48769 .45989 .48166 Mtetra
.659 .754 .92 r
.45989 .48166 .46575 .48769 .47606 .48433 .47022 .47829 Mtetra
.47022 .47829 .47606 .48433 .4864 .48096 .48059 .47489 Mtetra
.48059 .47489 .4864 .48096 .49679 .47758 .491 .47149 Mtetra
.491 .47149 .49679 .47758 .50721 .47419 .50145 .46807 Mtetra
.658 .753 .92 r
.50145 .46807 .50721 .47419 .51767 .4708 .51194 .46466 Mtetra
.51194 .46466 .51767 .4708 .52817 .46741 .52247 .46123 Mtetra
.52247 .46123 .52817 .46741 .53872 .464 .53304 .4578 Mtetra
.53304 .4578 .53872 .464 .5493 .46058 .54365 .45436 Mtetra
.54365 .45436 .5493 .46058 .55992 .45716 .5543 .45091 Mtetra
.5543 .45091 .55992 .45716 .57058 .45372 .56499 .44745 Mtetra
.657 .753 .92 r
.56499 .44745 .57058 .45372 .58129 .45027 .57572 .44397 Mtetra
.57572 .44397 .58129 .45027 .59203 .44681 .58649 .44049 Mtetra
.58649 .44049 .59203 .44681 .60282 .44334 .59731 .43699 Mtetra
.59731 .43699 .60282 .44334 .61365 .43986 .60816 .43348 Mtetra
.657 .752 .92 r
.60816 .43348 .61365 .43986 .62452 .43636 .61906 .42996 Mtetra
.61906 .42996 .62452 .43636 .63543 .43286 .63 .42643 Mtetra
.63 .42643 .63543 .43286 .64639 .42934 .64099 .42288 Mtetra
.64099 .42288 .64639 .42934 .65738 .4258 .65201 .41932 Mtetra
.65201 .41932 .65738 .4258 .66842 .42226 .66308 .41575 Mtetra
.66308 .41575 .66842 .42226 .67951 .4187 .6742 .41216 Mtetra
.6742 .41216 .67951 .4187 .69063 .41512 .68535 .40857 Mtetra
.68535 .40857 .69063 .41512 .70181 .41154 .69656 .40495 Mtetra
.69656 .40495 .70181 .41154 .71302 .40794 .7078 .40133 Mtetra
.7078 .40133 .71302 .40794 .72428 .40432 .71909 .39769 Mtetra
.71909 .39769 .72428 .40432 .73558 .4007 .73043 .39403 Mtetra
.73043 .39403 .73558 .4007 .74693 .39706 .74181 .39037 Mtetra
.74181 .39037 .74693 .39706 .75832 .3934 .75323 .38668 Mtetra
.75323 .38668 .75832 .3934 .76976 .38973 .7647 .38299 Mtetra
.7647 .38299 .76976 .38973 .78125 .38605 .77622 .37928 Mtetra
.77622 .37928 .78125 .38605 .79278 .38235 .78778 .37555 Mtetra
.78778 .37555 .79278 .38235 .80435 .37864 .79939 .37182 Mtetra
.79939 .37182 .80435 .37864 .81598 .37492 .81105 .36806 Mtetra
.81105 .36806 .81598 .37492 .82764 .37118 .82275 .36429 Mtetra
.82275 .36429 .82764 .37118 .83936 .36742 .8345 .36051 Mtetra
.8345 .36051 .83936 .36742 .85112 .36365 .8463 .35671 Mtetra
.8463 .35671 .85112 .36365 .86294 .35987 .85814 .3529 Mtetra
.138 .21 .676 r
.22751 .5342 .23284 .55206 .24214 .55115 .2358 .54485 Mtetra
.605 .713 .921 r
.2358 .54485 .24214 .55115 .25158 .54906 .24524 .54295 Mtetra
.609 .722 .925 r
.24524 .54295 .25158 .54906 .261 .54771 .25473 .54094 Mtetra
.233 .524 .916 r
.25473 .54094 .261 .54771 .27127 .53578 .26387 .54399 Mtetra
.603 .86 .511 r
.26387 .54399 .27127 .53578 .28046 .53836 .27423 .5316 Mtetra
.587 .694 .916 r
.27423 .5316 .28046 .53836 .29006 .5362 .28379 .53009 Mtetra
.625 .729 .922 r
.28379 .53009 .29006 .5362 .2997 .53381 .29346 .5277 Mtetra
.618 .728 .924 r
.29346 .5277 .2997 .53381 .30935 .53212 .30315 .52543 Mtetra
.405 .62 .939 r
.30315 .52543 .30935 .53212 .31984 .51731 .31267 .52669 Mtetra
0 0 0 r
.31267 .52669 .31984 .51731 .32912 .5226 .32299 .5156 Mtetra
.584 .688 .913 r
.32299 .5156 .32912 .5226 .33891 .52031 .33274 .51415 Mtetra
.632 .733 .921 r
.33274 .51415 .33891 .52031 .34876 .51759 .34261 .51154 Mtetra
.64 .74 .921 r
.34261 .51154 .34876 .51759 .35866 .51481 .35253 .50874 Mtetra
.638 .739 .922 r
.35253 .50874 .35866 .51481 .36858 .51217 .36248 .50597 Mtetra
.621 .73 .925 r
.36248 .50597 .36858 .51217 .3785 .51074 .37245 .50359 Mtetra
0 .229 .737 r
.37245 .50359 .3785 .51074 .38884 .49986 .38205 .51095 Mtetra
0 0 0 r
.38205 .51095 .38884 .49986 .39875 .5004 .39274 .49364 Mtetra
.609 .709 .916 r
.39274 .49364 .39875 .5004 .40883 .49775 .40281 .49155 Mtetra
.642 .74 .92 r
.40281 .49155 .40883 .49775 .41896 .49473 .41296 .48863 Mtetra
.65 .747 .92 r
.41296 .48863 .41896 .49473 .42913 .49157 .42316 .4855 Mtetra
.654 .75 .92 r
.42316 .4855 .42913 .49157 .43934 .48832 .43339 .48226 Mtetra
.656 .752 .92 r
.43339 .48226 .43934 .48832 .4496 .48501 .44367 .47896 Mtetra
.658 .753 .92 r
.44367 .47896 .4496 .48501 .45989 .48166 .45399 .4756 Mtetra
.659 .753 .92 r
.45399 .4756 .45989 .48166 .47022 .47829 .46435 .4722 Mtetra
.659 .754 .92 r
.46435 .4722 .47022 .47829 .48059 .47489 .47474 .46878 Mtetra
.47474 .46878 .48059 .47489 .491 .47149 .48518 .46535 Mtetra
.48518 .46535 .491 .47149 .50145 .46807 .49565 .46191 Mtetra
.658 .753 .92 r
.49565 .46191 .50145 .46807 .51194 .46466 .50617 .45847 Mtetra
.50617 .45847 .51194 .46466 .52247 .46123 .51672 .45502 Mtetra
.51672 .45502 .52247 .46123 .53304 .4578 .52732 .45156 Mtetra
.52732 .45156 .53304 .4578 .54365 .45436 .53795 .44809 Mtetra
.53795 .44809 .54365 .45436 .5543 .45091 .54863 .44462 Mtetra
.54863 .44462 .5543 .45091 .56499 .44745 .55935 .44113 Mtetra
.55935 .44113 .56499 .44745 .57572 .44397 .57011 .43763 Mtetra
.657 .753 .92 r
.57011 .43763 .57572 .44397 .58649 .44049 .58091 .43412 Mtetra
.58091 .43412 .58649 .44049 .59731 .43699 .59175 .4306 Mtetra
.59175 .4306 .59731 .43699 .60816 .43348 .60264 .42706 Mtetra
.657 .752 .92 r
.60264 .42706 .60816 .43348 .61906 .42996 .61357 .42351 Mtetra
.61357 .42351 .61906 .42996 .63 .42643 .62454 .41995 Mtetra
.62454 .41995 .63 .42643 .64099 .42288 .63555 .41638 Mtetra
.63555 .41638 .64099 .42288 .65201 .41932 .64661 .4128 Mtetra
.64661 .4128 .65201 .41932 .66308 .41575 .65771 .4092 Mtetra
.65771 .4092 .66308 .41575 .6742 .41216 .66885 .40559 Mtetra
.66885 .40559 .6742 .41216 .68535 .40857 .68004 .40196 Mtetra
.68004 .40196 .68535 .40857 .69656 .40495 .69127 .39832 Mtetra
.69127 .39832 .69656 .40495 .7078 .40133 .70255 .39467 Mtetra
.70255 .39467 .7078 .40133 .71909 .39769 .71387 .391 Mtetra
.71387 .391 .71909 .39769 .73043 .39403 .72523 .38732 Mtetra
.72523 .38732 .73043 .39403 .74181 .39037 .73664 .38363 Mtetra
.73664 .38363 .74181 .39037 .75323 .38668 .7481 .37992 Mtetra
.7481 .37992 .75323 .38668 .7647 .38299 .7596 .37619 Mtetra
.7596 .37619 .7647 .38299 .77622 .37928 .77115 .37246 Mtetra
.77115 .37246 .77622 .37928 .78778 .37555 .78275 .3687 Mtetra
.78275 .3687 .78778 .37555 .79939 .37182 .79439 .36494 Mtetra
.79439 .36494 .79939 .37182 .81105 .36806 .80608 .36116 Mtetra
.80608 .36116 .81105 .36806 .82275 .36429 .81782 .35736 Mtetra
.81782 .35736 .82275 .36429 .8345 .36051 .8296 .35355 Mtetra
.8296 .35355 .8345 .36051 .8463 .35671 .84143 .34972 Mtetra
.84143 .34972 .8463 .35671 .85814 .3529 .85332 .34588 Mtetra
0 0 0 r
.21933 .54788 .22751 .5342 .2358 .54485 .22949 .53774 Mtetra
.562 .672 .912 r
.22949 .53774 .2358 .54485 .24524 .54295 .23886 .53678 Mtetra
.614 .723 .923 r
.23886 .53678 .24524 .54295 .25473 .54094 .24838 .53465 Mtetra
.576 .706 .931 r
.24838 .53465 .25473 .54094 .26387 .54399 .25787 .53325 Mtetra
.784 .671 .74 r
.25787 .53325 .26387 .54399 .27423 .5316 .26823 .52123 Mtetra
.41 .51 .849 r
.26823 .52123 .27423 .5316 .28379 .53009 .27749 .52378 Mtetra
.617 .721 .921 r
.27749 .52378 .28379 .53009 .29346 .5277 .28716 .52157 Mtetra
.626 .731 .923 r
.28716 .52157 .29346 .5277 .30315 .52543 .29689 .51913 Mtetra
.592 .714 .929 r
.29689 .51913 .30315 .52543 .31267 .52669 .30661 .51739 Mtetra
.823 .704 .733 r
.30661 .51739 .31267 .52669 .32299 .5156 .3172 .50248 Mtetra
.322 .403 .79 r
.3172 .50248 .32299 .5156 .33274 .51415 .32655 .50775 Mtetra
.62 .722 .919 r
.32655 .50775 .33274 .51415 .34261 .51154 .33642 .5054 Mtetra
.638 .738 .921 r
.33642 .5054 .34261 .51154 .35253 .50874 .34635 .50263 Mtetra
.64 .74 .921 r
.34635 .50263 .35253 .50874 .36248 .50597 .35633 .4998 Mtetra
.633 .737 .923 r
.35633 .4998 .36248 .50597 .37245 .50359 .36634 .49711 Mtetra
.577 .707 .931 r
.36634 .49711 .37245 .50359 .38205 .51095 .37633 .49563 Mtetra
.738 .61 .716 r
.37633 .49563 .38205 .51095 .39274 .49364 .38678 .48466 Mtetra
.503 .598 .881 r
.38678 .48466 .39274 .49364 .40281 .49155 .39676 .48515 Mtetra
.633 .731 .919 r
.39676 .48515 .40281 .49155 .41296 .48863 .40692 .48245 Mtetra
.647 .744 .92 r
.40692 .48245 .41296 .48863 .42316 .4855 .41714 .47937 Mtetra
.652 .748 .92 r
.41714 .47937 .42316 .4855 .43339 .48226 .4274 .47615 Mtetra
.655 .751 .92 r
.4274 .47615 .43339 .48226 .44367 .47896 .4377 .47285 Mtetra
.657 .752 .92 r
.4377 .47285 .44367 .47896 .45399 .4756 .44805 .46948 Mtetra
.658 .753 .92 r
.44805 .46948 .45399 .4756 .46435 .4722 .45843 .46607 Mtetra
.659 .754 .92 r
.45843 .46607 .46435 .4722 .47474 .46878 .46885 .46263 Mtetra
.46885 .46263 .47474 .46878 .48518 .46535 .47931 .45918 Mtetra
.47931 .45918 .48518 .46535 .49565 .46191 .48981 .45571 Mtetra
.48981 .45571 .49565 .46191 .50617 .45847 .50036 .45224 Mtetra
.658 .753 .92 r
.50036 .45224 .50617 .45847 .51672 .45502 .51094 .44876 Mtetra
.51094 .44876 .51672 .45502 .52732 .45156 .52156 .44527 Mtetra
.52156 .44527 .52732 .45156 .53795 .44809 .53222 .44178 Mtetra
.53222 .44178 .53795 .44809 .54863 .44462 .54293 .43828 Mtetra
.54293 .43828 .54863 .44462 .55935 .44113 .55367 .43476 Mtetra
.55367 .43476 .55935 .44113 .57011 .43763 .56446 .43124 Mtetra
.657 .753 .92 r
.56446 .43124 .57011 .43763 .58091 .43412 .57529 .4277 Mtetra
.57529 .4277 .58091 .43412 .59175 .4306 .58616 .42415 Mtetra
.58616 .42415 .59175 .4306 .60264 .42706 .59707 .42059 Mtetra
.59707 .42059 .60264 .42706 .61357 .42351 .60803 .41702 Mtetra
.657 .752 .92 r
.60803 .41702 .61357 .42351 .62454 .41995 .61903 .41343 Mtetra
.61903 .41343 .62454 .41995 .63555 .41638 .63007 .40983 Mtetra
.63007 .40983 .63555 .41638 .64661 .4128 .64116 .40622 Mtetra
.64116 .40622 .64661 .4128 .65771 .4092 .65229 .4026 Mtetra
.65229 .4026 .65771 .4092 .66885 .40559 .66346 .39896 Mtetra
.66346 .39896 .66885 .40559 .68004 .40196 .67468 .39531 Mtetra
.67468 .39531 .68004 .40196 .69127 .39832 .68594 .39164 Mtetra
.68594 .39164 .69127 .39832 .70255 .39467 .69725 .38796 Mtetra
.69725 .38796 .70255 .39467 .71387 .391 .7086 .38427 Mtetra
.7086 .38427 .71387 .391 .72523 .38732 .72 .38056 Mtetra
.72 .38056 .72523 .38732 .73664 .38363 .73144 .37684 Mtetra
.73144 .37684 .73664 .38363 .7481 .37992 .74293 .3731 Mtetra
.74293 .3731 .7481 .37992 .7596 .37619 .75447 .36935 Mtetra
.75447 .36935 .7596 .37619 .77115 .37246 .76605 .36558 Mtetra
.76605 .36558 .77115 .37246 .78275 .3687 .77768 .3618 Mtetra
.77768 .3618 .78275 .3687 .79439 .36494 .78936 .35801 Mtetra
.78936 .35801 .79439 .36494 .80608 .36116 .80108 .3542 Mtetra
.80108 .3542 .80608 .36116 .81782 .35736 .81285 .35037 Mtetra
.81285 .35037 .81782 .35736 .8296 .35355 .82467 .34653 Mtetra
.82467 .34653 .8296 .35355 .84143 .34972 .83654 .34268 Mtetra
.83654 .34268 .84143 .34972 .85332 .34588 .84845 .3388 Mtetra
.852 .711 .706 r
.21307 .53943 .21933 .54788 .22949 .53774 .22412 .51973 Mtetra
.134 .207 .675 r
.22412 .51973 .22949 .53774 .23886 .53678 .23246 .53038 Mtetra
.605 .713 .921 r
.23246 .53038 .23886 .53678 .24838 .53465 .24197 .52844 Mtetra
.609 .722 .925 r
.24197 .52844 .24838 .53465 .25787 .53325 .25154 .52638 Mtetra
.235 .525 .917 r
.25154 .52638 .25787 .53325 .26823 .52123 .26074 .5294 Mtetra
.614 .868 .522 r
.26074 .5294 .26823 .52123 .27749 .52378 .2712 .51692 Mtetra
.587 .694 .916 r
.2712 .51692 .27749 .52378 .28716 .52157 .28083 .51536 Mtetra
.625 .729 .922 r
.28083 .51536 .28716 .52157 .29689 .51913 .29058 .51291 Mtetra
.619 .728 .924 r
.29058 .51291 .29689 .51913 .30661 .51739 .30035 .5106 Mtetra
.406 .62 .939 r
.30035 .5106 .30661 .51739 .3172 .50248 .30994 .51182 Mtetra
0 0 0 r
.30994 .51182 .3172 .50248 .32655 .50775 .32035 .50064 Mtetra
.584 .688 .913 r
.32035 .50064 .32655 .50775 .33642 .5054 .33019 .49914 Mtetra
.632 .733 .921 r
.33019 .49914 .33642 .5054 .34635 .50263 .34014 .49647 Mtetra
.64 .74 .921 r
.34014 .49647 .34635 .50263 .35633 .4998 .35014 .49362 Mtetra
.638 .739 .922 r
.35014 .49362 .35633 .4998 .36634 .49711 .36017 .49079 Mtetra
.621 .73 .925 r
.36017 .49079 .36634 .49711 .37633 .49563 .37023 .48836 Mtetra
0 .233 .741 r
.37023 .48836 .37633 .49563 .38678 .48466 .37991 .49571 Mtetra
.605 .797 .375 r
.37991 .49571 .38678 .48466 .39676 .48515 .39069 .47829 Mtetra
.609 .709 .916 r
.39069 .47829 .39676 .48515 .40692 .48245 .40085 .47614 Mtetra
.642 .74 .92 r
.40085 .47614 .40692 .48245 .41714 .47937 .41109 .47317 Mtetra
.65 .747 .92 r
.41109 .47317 .41714 .47937 .4274 .47615 .42137 .46998 Mtetra
.654 .75 .92 r
.42137 .46998 .4274 .47615 .4377 .47285 .43169 .46668 Mtetra
.656 .752 .92 r
.43169 .46668 .4377 .47285 .44805 .46948 .44206 .46331 Mtetra
.658 .753 .92 r
.44206 .46331 .44805 .46948 .45843 .46607 .45247 .45989 Mtetra
.659 .753 .92 r
.45247 .45989 .45843 .46607 .46885 .46263 .46292 .45644 Mtetra
.659 .754 .92 r
.46292 .45644 .46885 .46263 .47931 .45918 .4734 .45296 Mtetra
.4734 .45296 .47931 .45918 .48981 .45571 .48393 .44947 Mtetra
.48393 .44947 .48981 .45571 .50036 .45224 .4945 .44597 Mtetra
.658 .753 .92 r
.4945 .44597 .50036 .45224 .51094 .44876 .50511 .44246 Mtetra
.50511 .44246 .51094 .44876 .52156 .44527 .51576 .43895 Mtetra
.51576 .43895 .52156 .44527 .53222 .44178 .52645 .43542 Mtetra
.52645 .43542 .53222 .44178 .54293 .43828 .53718 .43189 Mtetra
.53718 .43189 .54293 .43828 .55367 .43476 .54795 .42835 Mtetra
.54795 .42835 .55367 .43476 .56446 .43124 .55877 .4248 Mtetra
.55877 .4248 .56446 .43124 .57529 .4277 .56963 .42124 Mtetra
.657 .753 .92 r
.56963 .42124 .57529 .4277 .58616 .42415 .58053 .41766 Mtetra
.58053 .41766 .58616 .42415 .59707 .42059 .59147 .41408 Mtetra
.59147 .41408 .59707 .42059 .60803 .41702 .60245 .41048 Mtetra
.657 .752 .92 r
.60245 .41048 .60803 .41702 .61903 .41343 .61348 .40686 Mtetra
.61348 .40686 .61903 .41343 .63007 .40983 .62455 .40324 Mtetra
.62455 .40324 .63007 .40983 .64116 .40622 .63567 .3996 Mtetra
.63567 .3996 .64116 .40622 .65229 .4026 .64683 .39595 Mtetra
.64683 .39595 .65229 .4026 .66346 .39896 .65803 .39228 Mtetra
.65803 .39228 .66346 .39896 .67468 .39531 .66928 .3886 Mtetra
.66928 .3886 .67468 .39531 .68594 .39164 .68058 .38491 Mtetra
.68058 .38491 .68594 .39164 .69725 .38796 .69192 .3812 Mtetra
.69192 .3812 .69725 .38796 .7086 .38427 .7033 .37748 Mtetra
.7033 .37748 .7086 .38427 .72 .38056 .71473 .37375 Mtetra
.71473 .37375 .72 .38056 .73144 .37684 .7262 .37 Mtetra
.7262 .37 .73144 .37684 .74293 .3731 .73773 .36623 Mtetra
.73773 .36623 .74293 .3731 .75447 .36935 .74929 .36245 Mtetra
.74929 .36245 .75447 .36935 .76605 .36558 .76091 .35866 Mtetra
.76091 .35866 .76605 .36558 .77768 .3618 .77257 .35485 Mtetra
.77257 .35485 .77768 .3618 .78936 .35801 .78428 .35102 Mtetra
.78428 .35102 .78936 .35801 .80108 .3542 .79604 .34719 Mtetra
.79604 .34719 .80108 .3542 .81285 .35037 .80784 .34333 Mtetra
.80784 .34333 .81285 .35037 .82467 .34653 .8197 .33946 Mtetra
.8197 .33946 .82467 .34653 .83654 .34268 .8316 .33558 Mtetra
.8316 .33558 .83654 .34268 .84845 .3388 .84355 .33168 Mtetra
.447 .643 .941 r
.2066 .53278 .21307 .53943 .22412 .51973 .21583 .5334 Mtetra
0 0 0 r
.21583 .5334 .22412 .51973 .23246 .53038 .22608 .52317 Mtetra
.562 .672 .913 r
.22608 .52317 .23246 .53038 .24197 .52844 .23552 .52217 Mtetra
.614 .723 .923 r
.23552 .52217 .24197 .52844 .25154 .52638 .24512 .51998 Mtetra
.576 .706 .931 r
.24512 .51998 .25154 .52638 .26074 .5294 .25469 .51854 Mtetra
.784 .672 .74 r
.25469 .51854 .26074 .5294 .2712 .51692 .26514 .50642 Mtetra
.409 .509 .849 r
.26514 .50642 .2712 .51692 .28083 .51536 .27447 .50895 Mtetra
.616 .721 .921 r
.27447 .50895 .28083 .51536 .29058 .51291 .28422 .50668 Mtetra
.626 .731 .923 r
.28422 .50668 .29058 .51291 .30035 .5106 .29403 .50419 Mtetra
.592 .714 .929 r
.29403 .50419 .30035 .5106 .30994 .51182 .30382 .50241 Mtetra
.824 .705 .733 r
.30382 .50241 .30994 .51182 .32035 .50064 .31451 .48738 Mtetra
.32 .402 .79 r
.31451 .48738 .32035 .50064 .33019 .49914 .32393 .49263 Mtetra
.62 .722 .919 r
.32393 .49263 .33019 .49914 .34014 .49647 .33388 .49023 Mtetra
.638 .738 .921 r
.33388 .49023 .34014 .49647 .35014 .49362 .3439 .48741 Mtetra
.64 .74 .921 r
.3439 .48741 .35014 .49362 .36017 .49079 .35396 .48452 Mtetra
.633 .737 .923 r
.35396 .48452 .36017 .49079 .37023 .48836 .36406 .48177 Mtetra
.577 .707 .931 r
.36406 .48177 .37023 .48836 .37991 .49571 .37414 .48024 Mtetra
.738 .611 .716 r
.37414 .48024 .37991 .49571 .39069 .47829 .38467 .46918 Mtetra
.502 .598 .881 r
.38467 .46918 .39069 .47829 .40085 .47614 .39474 .46963 Mtetra
.633 .731 .919 r
.39474 .46963 .40085 .47614 .41109 .47317 .40499 .46687 Mtetra
.647 .744 .92 r
.40499 .46687 .41109 .47317 .42137 .46998 .41529 .46374 Mtetra
.652 .748 .92 r
.41529 .46374 .42137 .46998 .43169 .46668 .42564 .46046 Mtetra
.655 .751 .92 r
.42564 .46046 .43169 .46668 .44206 .46331 .43603 .45709 Mtetra
.657 .752 .92 r
.43603 .45709 .44206 .46331 .45247 .45989 .44647 .45366 Mtetra
.658 .753 .92 r
.44647 .45366 .45247 .45989 .46292 .45644 .45694 .45019 Mtetra
.659 .754 .92 r
.45694 .45019 .46292 .45644 .4734 .45296 .46745 .44669 Mtetra
.46745 .44669 .4734 .45296 .48393 .44947 .47801 .44318 Mtetra
.47801 .44318 .48393 .44947 .4945 .44597 .4886 .43965 Mtetra
.4886 .43965 .4945 .44597 .50511 .44246 .49924 .43611 Mtetra
.658 .753 .92 r
.49924 .43611 .50511 .44246 .51576 .43895 .50992 .43257 Mtetra
.50992 .43257 .51576 .43895 .52645 .43542 .52063 .42902 Mtetra
.52063 .42902 .52645 .43542 .53718 .43189 .53139 .42547 Mtetra
.53139 .42547 .53718 .43189 .54795 .42835 .54219 .4219 Mtetra
.54219 .4219 .54795 .42835 .55877 .4248 .55304 .41832 Mtetra
.55304 .41832 .55877 .4248 .56963 .42124 .56392 .41473 Mtetra
.657 .753 .92 r
.56392 .41473 .56963 .42124 .58053 .41766 .57485 .41113 Mtetra
.57485 .41113 .58053 .41766 .59147 .41408 .58582 .40751 Mtetra
.58582 .40751 .59147 .41408 .60245 .41048 .59684 .40389 Mtetra
.59684 .40389 .60245 .41048 .61348 .40686 .60789 .40025 Mtetra
.657 .752 .92 r
.60789 .40025 .61348 .40686 .62455 .40324 .619 .3966 Mtetra
.619 .3966 .62455 .40324 .63567 .3996 .63014 .39293 Mtetra
.63014 .39293 .63567 .3996 .64683 .39595 .64133 .38925 Mtetra
.64133 .38925 .64683 .39595 .65803 .39228 .65257 .38556 Mtetra
.65257 .38556 .65803 .39228 .66928 .3886 .66385 .38185 Mtetra
.66385 .38185 .66928 .3886 .68058 .38491 .67517 .37813 Mtetra
.67517 .37813 .68058 .38491 .69192 .3812 .68654 .37439 Mtetra
.68654 .37439 .69192 .3812 .7033 .37748 .69796 .37065 Mtetra
.69796 .37065 .7033 .37748 .71473 .37375 .70942 .36688 Mtetra
.70942 .36688 .71473 .37375 .7262 .37 .72093 .3631 Mtetra
.72093 .3631 .7262 .37 .73773 .36623 .73248 .35931 Mtetra
.73248 .35931 .73773 .36623 .74929 .36245 .74408 .3555 Mtetra
.74408 .3555 .74929 .36245 .76091 .35866 .75573 .35168 Mtetra
.75573 .35168 .76091 .35866 .77257 .35485 .76743 .34784 Mtetra
.76743 .34784 .77257 .35485 .78428 .35102 .77917 .34399 Mtetra
.77917 .34399 .78428 .35102 .79604 .34719 .79096 .34012 Mtetra
.79096 .34012 .79604 .34719 .80784 .34333 .8028 .33624 Mtetra
.8028 .33624 .80784 .34333 .8197 .33946 .81469 .33234 Mtetra
.81469 .33234 .8197 .33946 .8316 .33558 .82662 .32842 Mtetra
.82662 .32842 .8316 .33558 .84355 .33168 .83861 .32449 Mtetra
.584 .709 .929 r
.20007 .52642 .2066 .53278 .21583 .5334 .20951 .52484 Mtetra
.853 .712 .706 r
.20951 .52484 .21583 .5334 .22608 .52317 .22066 .50501 Mtetra
.13 .204 .674 r
.22066 .50501 .22608 .52317 .23552 .52217 .22905 .51567 Mtetra
.605 .713 .921 r
.22905 .51567 .23552 .52217 .24512 .51998 .23864 .51367 Mtetra
.609 .722 .925 r
.23864 .51367 .24512 .51998 .25469 .51854 .24829 .51156 Mtetra
.238 .526 .917 r
.24829 .51156 .25469 .51854 .26514 .50642 .25756 .51456 Mtetra
.624 .876 .533 r
.25756 .51456 .26514 .50642 .27447 .50895 .26811 .50198 Mtetra
.587 .694 .916 r
.26811 .50198 .27447 .50895 .28422 .50668 .27782 .50037 Mtetra
.625 .729 .922 r
.27782 .50037 .28422 .50668 .29403 .50419 .28765 .49787 Mtetra
.619 .728 .924 r
.28765 .49787 .29403 .50419 .30382 .50241 .2975 .4955 Mtetra
.407 .62 .939 r
.2975 .4955 .30382 .50241 .31451 .48738 .30717 .49668 Mtetra
0 0 0 r
.30717 .49668 .31451 .48738 .32393 .49263 .31767 .48542 Mtetra
.584 .688 .913 r
.31767 .48542 .32393 .49263 .33388 .49023 .32759 .48386 Mtetra
.632 .733 .921 r
.32759 .48386 .33388 .49023 .3439 .48741 .33762 .48114 Mtetra
.64 .74 .921 r
.33762 .48114 .3439 .48741 .35396 .48452 .34771 .47823 Mtetra
.638 .739 .922 r
.34771 .47823 .35396 .48452 .36406 .48177 .35783 .47535 Mtetra
.621 .73 .925 r
.35783 .47535 .36406 .48177 .37414 .48024 .36797 .47286 Mtetra
0 .238 .745 r
.36797 .47286 .37414 .48024 .38467 .46918 .37772 .4802 Mtetra
.614 .805 .385 r
.37772 .4802 .38467 .46918 .39474 .46963 .3886 .46265 Mtetra
.609 .709 .916 r
.3886 .46265 .39474 .46963 .40499 .46687 .39885 .46045 Mtetra
.642 .74 .92 r
.39885 .46045 .40499 .46687 .41529 .46374 .40918 .45742 Mtetra
.65 .747 .92 r
.40918 .45742 .41529 .46374 .42564 .46046 .41955 .45417 Mtetra
.654 .75 .92 r
.41955 .45417 .42564 .46046 .43603 .45709 .42996 .45081 Mtetra
.656 .752 .92 r
.42996 .45081 .43603 .45709 .44647 .45366 .44042 .44738 Mtetra
.658 .753 .92 r
.44042 .44738 .44647 .45366 .45694 .45019 .45092 .4439 Mtetra
.659 .753 .92 r
.45092 .4439 .45694 .45019 .46745 .44669 .46146 .44038 Mtetra
.659 .754 .92 r
.46146 .44038 .46745 .44669 .47801 .44318 .47204 .43684 Mtetra
.47204 .43684 .47801 .44318 .4886 .43965 .48266 .43329 Mtetra
.48266 .43329 .4886 .43965 .49924 .43611 .49333 .42972 Mtetra
.658 .753 .92 r
.49333 .42972 .49924 .43611 .50992 .43257 .50403 .42615 Mtetra
.50403 .42615 .50992 .43257 .52063 .42902 .51478 .42258 Mtetra
.51478 .42258 .52063 .42902 .53139 .42547 .52556 .41899 Mtetra
.52556 .41899 .53139 .42547 .54219 .4219 .53639 .4154 Mtetra
.53639 .4154 .54219 .4219 .55304 .41832 .54726 .41179 Mtetra
.54726 .41179 .55304 .41832 .56392 .41473 .55818 .40817 Mtetra
.55818 .40817 .56392 .41473 .57485 .41113 .56913 .40455 Mtetra
.657 .753 .92 r
.56913 .40455 .57485 .41113 .58582 .40751 .58013 .4009 Mtetra
.58013 .4009 .58582 .40751 .59684 .40389 .59118 .39725 Mtetra
.59118 .39725 .59684 .40389 .60789 .40025 .60227 .39358 Mtetra
.657 .752 .92 r
.60227 .39358 .60789 .40025 .619 .3966 .6134 .3899 Mtetra
.6134 .3899 .619 .3966 .63014 .39293 .62457 .38621 Mtetra
.62457 .38621 .63014 .39293 .64133 .38925 .63579 .3825 Mtetra
.63579 .3825 .64133 .38925 .65257 .38556 .64706 .37878 Mtetra
.64706 .37878 .65257 .38556 .66385 .38185 .65837 .37505 Mtetra
.65837 .37505 .66385 .38185 .67517 .37813 .66973 .3713 Mtetra
.66973 .3713 .67517 .37813 .68654 .37439 .68113 .36754 Mtetra
.68113 .36754 .68654 .37439 .69796 .37065 .69257 .36376 Mtetra
.69257 .36376 .69796 .37065 .70942 .36688 .70407 .35997 Mtetra
.70407 .35997 .70942 .36688 .72093 .3631 .71561 .35616 Mtetra
.71561 .35616 .72093 .3631 .73248 .35931 .72719 .35234 Mtetra
.72719 .35234 .73248 .35931 .74408 .3555 .73883 .3485 Mtetra
.73883 .3485 .74408 .3555 .75573 .35168 .75051 .34465 Mtetra
.75051 .34465 .75573 .35168 .76743 .34784 .76224 .34078 Mtetra
.76224 .34078 .76743 .34784 .77917 .34399 .77402 .3369 Mtetra
.77402 .3369 .77917 .34399 .79096 .34012 .78584 .333 Mtetra
.78584 .333 .79096 .34012 .8028 .33624 .79772 .32909 Mtetra
.79772 .32909 .8028 .33624 .81469 .33234 .80964 .32516 Mtetra
.80964 .32516 .81469 .33234 .82662 .32842 .82161 .32122 Mtetra
.82161 .32122 .82662 .32842 .83861 .32449 .83363 .31726 Mtetra
.603 .716 .925 r
.19348 .52004 .20007 .52642 .20951 .52484 .20298 .51808 Mtetra
.447 .643 .941 r
.20298 .51808 .20951 .52484 .22066 .50501 .21227 .51866 Mtetra
0 0 0 r
.21227 .51866 .22066 .50501 .22905 .51567 .22261 .50835 Mtetra
.561 .672 .913 r
.22261 .50835 .22905 .51567 .23864 .51367 .23213 .5073 Mtetra
.614 .723 .923 r
.23213 .5073 .23864 .51367 .24829 .51156 .2418 .50506 Mtetra
.576 .706 .931 r
.2418 .50506 .24829 .51156 .25756 .51456 .25145 .50357 Mtetra
.785 .673 .74 r
.25145 .50357 .25756 .51456 .26811 .50198 .26199 .49136 Mtetra
.409 .509 .85 r
.26199 .49136 .26811 .50198 .27782 .50037 .2714 .49385 Mtetra
.616 .721 .921 r
.2714 .49385 .27782 .50037 .28765 .49787 .28122 .49153 Mtetra
.626 .731 .923 r
.28122 .49153 .28765 .49787 .2975 .4955 .29111 .48899 Mtetra
.592 .714 .929 r
.29111 .48899 .2975 .4955 .30717 .49668 .30099 .48715 Mtetra
.825 .705 .733 r
.30099 .48715 .30717 .49668 .31767 .48542 .31177 .47202 Mtetra
.318 .401 .79 r
.31177 .47202 .31767 .48542 .32759 .48386 .32127 .47725 Mtetra
.62 .722 .919 r
.32127 .47725 .32759 .48386 .33762 .48114 .3313 .47479 Mtetra
.638 .738 .921 r
.3313 .47479 .33762 .48114 .34771 .47823 .34141 .47191 Mtetra
.64 .74 .921 r
.34141 .47191 .34771 .47823 .35783 .47535 .35155 .46896 Mtetra
.633 .737 .923 r
.35155 .46896 .35783 .47535 .36797 .47286 .36173 .46616 Mtetra
.577 .707 .931 r
.36173 .46616 .36797 .47286 .37772 .4802 .3719 .46458 Mtetra
.738 .611 .716 r
.3719 .46458 .37772 .4802 .3886 .46265 .38253 .45342 Mtetra
.502 .597 .882 r
.38253 .45342 .3886 .46265 .39885 .46045 .39268 .45383 Mtetra
.633 .731 .919 r
.39268 .45383 .39885 .46045 .40918 .45742 .40302 .45101 Mtetra
.647 .744 .92 r
.40302 .45101 .40918 .45742 .41955 .45417 .41341 .44782 Mtetra
.652 .748 .92 r
.41341 .44782 .41955 .45417 .42996 .45081 .42385 .44448 Mtetra
.655 .751 .92 r
.42385 .44448 .42996 .45081 .44042 .44738 .43433 .44105 Mtetra
.657 .752 .92 r
.43433 .44105 .44042 .44738 .45092 .4439 .44486 .43756 Mtetra
.658 .753 .92 r
.44486 .43756 .45092 .4439 .46146 .44038 .45543 .43403 Mtetra
.659 .754 .92 r
.45543 .43403 .46146 .44038 .47204 .43684 .46603 .43046 Mtetra
.46603 .43046 .47204 .43684 .48266 .43329 .47668 .42688 Mtetra
.47668 .42688 .48266 .43329 .49333 .42972 .48737 .42329 Mtetra
.48737 .42329 .49333 .42972 .50403 .42615 .4981 .41969 Mtetra
.658 .753 .92 r
.4981 .41969 .50403 .42615 .51478 .42258 .50887 .41609 Mtetra
.50887 .41609 .51478 .42258 .52556 .41899 .51969 .41247 Mtetra
.51969 .41247 .52556 .41899 .53639 .4154 .53055 .40885 Mtetra
.53055 .40885 .53639 .4154 .54726 .41179 .54145 .40522 Mtetra
.54145 .40522 .54726 .41179 .55818 .40817 .55239 .40157 Mtetra
.55239 .40157 .55818 .40817 .56913 .40455 .56338 .39791 Mtetra
.657 .753 .92 r
.56338 .39791 .56913 .40455 .58013 .4009 .5744 .39425 Mtetra
.5744 .39425 .58013 .4009 .59118 .39725 .58548 .39056 Mtetra
.58548 .39056 .59118 .39725 .60227 .39358 .5966 .38687 Mtetra
.5966 .38687 .60227 .39358 .6134 .3899 .60776 .38316 Mtetra
.657 .752 .92 r
.60776 .38316 .6134 .3899 .62457 .38621 .61896 .37944 Mtetra
.61896 .37944 .62457 .38621 .63579 .3825 .63021 .37571 Mtetra
.63021 .37571 .63579 .3825 .64706 .37878 .64151 .37196 Mtetra
.64151 .37196 .64706 .37878 .65837 .37505 .65285 .3682 Mtetra
.65285 .3682 .65837 .37505 .66973 .3713 .66424 .36442 Mtetra
.66424 .36442 .66973 .3713 .68113 .36754 .67567 .36063 Mtetra
.67567 .36063 .68113 .36754 .69257 .36376 .68715 .35682 Mtetra
.68715 .35682 .69257 .36376 .70407 .35997 .69868 .353 Mtetra
.69868 .353 .70407 .35997 .71561 .35616 .71025 .34916 Mtetra
.71025 .34916 .71561 .35616 .72719 .35234 .72187 .34531 Mtetra
.72187 .34531 .72719 .35234 .73883 .3485 .73354 .34145 Mtetra
.73354 .34145 .73883 .3485 .75051 .34465 .74525 .33757 Mtetra
.74525 .33757 .75051 .34465 .76224 .34078 .75701 .33367 Mtetra
.75701 .33367 .76224 .34078 .77402 .3369 .76883 .32976 Mtetra
.76883 .32976 .77402 .3369 .78584 .333 .78069 .32583 Mtetra
.78069 .32583 .78584 .333 .79772 .32909 .79259 .32189 Mtetra
.79259 .32189 .79772 .32909 .80964 .32516 .80455 .31793 Mtetra
.80455 .31793 .80964 .32516 .82161 .32122 .81656 .31396 Mtetra
.81656 .31396 .82161 .32122 .83363 .31726 .82862 .30996 Mtetra
.595 .707 .922 r
.18688 .51342 .19348 .52004 .20298 .51808 .19637 .51161 Mtetra
.584 .709 .929 r
.19637 .51161 .20298 .51808 .21227 .51866 .20588 .50998 Mtetra
.854 .713 .706 r
.20588 .50998 .21227 .51866 .22261 .50835 .21715 .49003 Mtetra
.126 .202 .673 r
.21715 .49003 .22261 .50835 .23213 .5073 .22559 .50069 Mtetra
.605 .713 .921 r
.22559 .50069 .23213 .5073 .2418 .50506 .23526 .49864 Mtetra
.609 .722 .925 r
.23526 .49864 .2418 .50506 .25145 .50357 .24498 .49648 Mtetra
.24 .527 .917 r
.24498 .49648 .25145 .50357 .26199 .49136 .25432 .49945 Mtetra
.634 .883 .543 r
.25432 .49945 .26199 .49136 .2714 .49385 .26497 .48677 Mtetra
.587 .694 .916 r
.26497 .48677 .2714 .49385 .28122 .49153 .27476 .48511 Mtetra
.625 .729 .922 r
.27476 .48511 .28122 .49153 .29111 .48899 .28467 .48256 Mtetra
.619 .728 .924 r
.28467 .48256 .29111 .48899 .30099 .48715 .2946 .48014 Mtetra
.408 .62 .938 r
.2946 .48014 .30099 .48715 .31177 .47202 .30434 .48128 Mtetra
0 0 0 r
.30434 .48128 .31177 .47202 .32127 .47725 .31495 .46992 Mtetra
.584 .688 .913 r
.31495 .46992 .32127 .47725 .3313 .47479 .32495 .46831 Mtetra
.632 .733 .921 r
.32495 .46831 .3313 .47479 .34141 .47191 .33506 .46554 Mtetra
.64 .74 .921 r
.33506 .46554 .34141 .47191 .35155 .46896 .34523 .46257 Mtetra
.638 .739 .922 r
.34523 .46257 .35155 .46896 .36173 .46616 .35544 .45963 Mtetra
.621 .73 .925 r
.35544 .45963 .36173 .46616 .3719 .46458 .36567 .45708 Mtetra
0 .242 .748 r
.36567 .45708 .3719 .46458 .38253 .45342 .37549 .46441 Mtetra
.624 .813 .395 r
.37549 .46441 .38253 .45342 .39268 .45383 .38648 .44674 Mtetra
.609 .709 .916 r
.38648 .44674 .39268 .45383 .40302 .45101 .39682 .44448 Mtetra
.642 .74 .92 r
.39682 .44448 .40302 .45101 .41341 .44782 .40723 .44139 Mtetra
.65 .747 .92 r
.40723 .44139 .41341 .44782 .42385 .44448 .4177 .43808 Mtetra
.654 .75 .92 r
.4177 .43808 .42385 .44448 .43433 .44105 .4282 .43466 Mtetra
.656 .752 .92 r
.4282 .43466 .43433 .44105 .44486 .43756 .43875 .43116 Mtetra
.658 .753 .92 r
.43875 .43116 .44486 .43756 .45543 .43403 .44935 .42762 Mtetra
.659 .753 .92 r
.44935 .42762 .45543 .43403 .46603 .43046 .45998 .42404 Mtetra
.659 .754 .92 r
.45998 .42404 .46603 .43046 .47668 .42688 .47066 .42043 Mtetra
.47066 .42043 .47668 .42688 .48737 .42329 .48137 .41681 Mtetra
.48137 .41681 .48737 .42329 .4981 .41969 .49213 .41318 Mtetra
.658 .753 .92 r
.49213 .41318 .4981 .41969 .50887 .41609 .50293 .40955 Mtetra
.50293 .40955 .50887 .41609 .51969 .41247 .51377 .40591 Mtetra
.51377 .40591 .51969 .41247 .53055 .40885 .52466 .40225 Mtetra
.52466 .40225 .53055 .40885 .54145 .40522 .53559 .39859 Mtetra
.53559 .39859 .54145 .40522 .55239 .40157 .54656 .39492 Mtetra
.54656 .39492 .55239 .40157 .56338 .39791 .55757 .39124 Mtetra
.55757 .39124 .56338 .39791 .5744 .39425 .56863 .38754 Mtetra
.657 .753 .92 r
.56863 .38754 .5744 .39425 .58548 .39056 .57974 .38383 Mtetra
.57974 .38383 .58548 .39056 .5966 .38687 .59088 .38011 Mtetra
.59088 .38011 .5966 .38687 .60776 .38316 .60207 .37637 Mtetra
.657 .752 .92 r
.60207 .37637 .60776 .38316 .61896 .37944 .61331 .37262 Mtetra
.61331 .37262 .61896 .37944 .63021 .37571 .62459 .36886 Mtetra
.62459 .36886 .63021 .37571 .64151 .37196 .63592 .36508 Mtetra
.63592 .36508 .64151 .37196 .65285 .3682 .64729 .36129 Mtetra
.64729 .36129 .65285 .3682 .66424 .36442 .65871 .35749 Mtetra
.65871 .35749 .66424 .36442 .67567 .36063 .67018 .35367 Mtetra
.67018 .35367 .67567 .36063 .68715 .35682 .68169 .34983 Mtetra
.68169 .34983 .68715 .35682 .69868 .353 .69325 .34598 Mtetra
.69325 .34598 .69868 .353 .71025 .34916 .70485 .34212 Mtetra
.70485 .34212 .71025 .34916 .72187 .34531 .7165 .33824 Mtetra
.7165 .33824 .72187 .34531 .73354 .34145 .7282 .33434 Mtetra
.7282 .33434 .73354 .34145 .74525 .33757 .73995 .33043 Mtetra
.73995 .33043 .74525 .33757 .75701 .33367 .75175 .3265 Mtetra
.75175 .3265 .75701 .33367 .76883 .32976 .7636 .32256 Mtetra
.7636 .32256 .76883 .32976 .78069 .32583 .77549 .31861 Mtetra
.77549 .31861 .78069 .32583 .79259 .32189 .78743 .31463 Mtetra
.78743 .31463 .79259 .32189 .80455 .31793 .79943 .31064 Mtetra
.79943 .31064 .80455 .31793 .81656 .31396 .81147 .30664 Mtetra
.81147 .30664 .81656 .31396 .82862 .30996 .82356 .30262 Mtetra
.54 .655 .91 r
.18033 .50578 .18688 .51342 .19637 .51161 .18972 .50513 Mtetra
.603 .716 .925 r
.18972 .50513 .19637 .51161 .20588 .50998 .19928 .50312 Mtetra
.448 .643 .941 r
.19928 .50312 .20588 .50998 .21715 .49003 .20865 .50366 Mtetra
0 0 0 r
.20865 .50366 .21715 .49003 .22559 .50069 .21908 .49326 Mtetra
.561 .672 .913 r
.21908 .49326 .22559 .50069 .23526 .49864 .22868 .49217 Mtetra
.614 .723 .923 r
.22868 .49217 .23526 .49864 .24498 .49648 .23842 .48987 Mtetra
.577 .706 .931 r
.23842 .48987 .24498 .49648 .25432 .49945 .24815 .48834 Mtetra
.785 .673 .74 r
.24815 .48834 .25432 .49945 .26497 .48677 .25879 .47603 Mtetra
.408 .509 .85 r
.25879 .47603 .26497 .48677 .27476 .48511 .26827 .47849 Mtetra
.616 .721 .921 r
.26827 .47849 .27476 .48511 .28467 .48256 .27818 .47611 Mtetra
.626 .731 .923 r
.27818 .47611 .28467 .48256 .2946 .48014 .28814 .47351 Mtetra
.592 .714 .929 r
.28814 .47351 .2946 .48014 .30434 .48128 .2981 .47162 Mtetra
.825 .706 .733 r
.2981 .47162 .30434 .48128 .31495 .46992 .30899 .45638 Mtetra
.317 .4 .79 r
.30899 .45638 .31495 .46992 .32495 .46831 .31856 .46158 Mtetra
.62 .723 .919 r
.31856 .46158 .32495 .46831 .33506 .46554 .32868 .45908 Mtetra
.638 .738 .921 r
.32868 .45908 .33506 .46554 .34523 .46257 .33887 .45614 Mtetra
.64 .74 .921 r
.33887 .45614 .34523 .46257 .35544 .45963 .3491 .45313 Mtetra
.633 .737 .923 r
.3491 .45313 .35544 .45963 .36567 .45708 .35936 .45027 Mtetra
.577 .707 .931 r
.35936 .45027 .36567 .45708 .37549 .46441 .36962 .44863 Mtetra
.738 .611 .716 r
.36962 .44863 .37549 .46441 .38648 .44674 .38034 .43738 Mtetra
.502 .597 .882 r
.38034 .43738 .38648 .44674 .39682 .44448 .39058 .43774 Mtetra
.633 .731 .919 r
.39058 .43774 .39682 .44448 .40723 .44139 .40101 .43486 Mtetra
.647 .744 .92 r
.40101 .43486 .40723 .44139 .4177 .43808 .4115 .43161 Mtetra
.652 .748 .92 r
.4115 .43161 .4177 .43808 .4282 .43466 .42203 .4282 Mtetra
.655 .751 .92 r
.42203 .4282 .4282 .43466 .43875 .43116 .4326 .42471 Mtetra
.657 .752 .92 r
.4326 .42471 .43875 .43116 .44935 .42762 .44322 .42116 Mtetra
.658 .753 .92 r
.44322 .42116 .44935 .42762 .45998 .42404 .45388 .41756 Mtetra
.659 .754 .92 r
.45388 .41756 .45998 .42404 .47066 .42043 .46459 .41393 Mtetra
.46459 .41393 .47066 .42043 .48137 .41681 .47533 .41029 Mtetra
.47533 .41029 .48137 .41681 .49213 .41318 .48612 .40663 Mtetra
.48612 .40663 .49213 .41318 .50293 .40955 .49694 .40296 Mtetra
.658 .753 .92 r
.49694 .40296 .50293 .40955 .51377 .40591 .50782 .39929 Mtetra
.50782 .39929 .51377 .40591 .52466 .40225 .51873 .39561 Mtetra
.51873 .39561 .52466 .40225 .53559 .39859 .52969 .39192 Mtetra
.52969 .39192 .53559 .39859 .54656 .39492 .54069 .38822 Mtetra
.54069 .38822 .54656 .39492 .55757 .39124 .55173 .38451 Mtetra
.55173 .38451 .55757 .39124 .56863 .38754 .56282 .38078 Mtetra
.657 .753 .92 r
.56282 .38078 .56863 .38754 .57974 .38383 .57395 .37704 Mtetra
.57395 .37704 .57974 .38383 .59088 .38011 .58513 .37329 Mtetra
.58513 .37329 .59088 .38011 .60207 .37637 .59635 .36953 Mtetra
.59635 .36953 .60207 .37637 .61331 .37262 .60762 .36575 Mtetra
.657 .752 .92 r
.60762 .36575 .61331 .37262 .62459 .36886 .61893 .36196 Mtetra
.61893 .36196 .62459 .36886 .63592 .36508 .63029 .35816 Mtetra
.63029 .35816 .63592 .36508 .64729 .36129 .64169 .35434 Mtetra
.64169 .35434 .64729 .36129 .65871 .35749 .65314 .3505 Mtetra
.65314 .3505 .65871 .35749 .67018 .35367 .66464 .34665 Mtetra
.66464 .34665 .67018 .35367 .68169 .34983 .67618 .34279 Mtetra
.67618 .34279 .68169 .34983 .69325 .34598 .68777 .33891 Mtetra
.68777 .33891 .69325 .34598 .70485 .34212 .69941 .33501 Mtetra
.69941 .33501 .70485 .34212 .7165 .33824 .7111 .3311 Mtetra
.7111 .3311 .7165 .33824 .7282 .33434 .72283 .32718 Mtetra
.72283 .32718 .7282 .33434 .73995 .33043 .73461 .32324 Mtetra
.73461 .32324 .73995 .33043 .75175 .3265 .74644 .31928 Mtetra
.74644 .31928 .75175 .3265 .7636 .32256 .75832 .31531 Mtetra
.75832 .31531 .7636 .32256 .77549 .31861 .77025 .31132 Mtetra
.77025 .31132 .77549 .31861 .78743 .31463 .78223 .30732 Mtetra
.78223 .30732 .78743 .31463 .79943 .31064 .79426 .3033 Mtetra
.79426 .3033 .79943 .31064 .81147 .30664 .80634 .29926 Mtetra
.80634 .29926 .81147 .30664 .82356 .30262 .81847 .29521 Mtetra
0 0 .385 r
.1773 .46447 .18033 .50578 .18972 .50513 .18304 .4984 Mtetra
.595 .707 .922 r
.18304 .4984 .18972 .50513 .19928 .50312 .19261 .49655 Mtetra
.584 .709 .929 r
.19261 .49655 .19928 .50312 .20865 .50366 .2022 .49487 Mtetra
.855 .714 .706 r
.2022 .49487 .20865 .50366 .21908 .49326 .21357 .47479 Mtetra
.123 .199 .671 r
.21357 .47479 .21908 .49326 .22868 .49217 .22207 .48545 Mtetra
.605 .713 .921 r
.22207 .48545 .22868 .49217 .23842 .48987 .23181 .48335 Mtetra
.609 .722 .925 r
.23181 .48335 .23842 .48987 .24815 .48834 .24161 .48114 Mtetra
.242 .528 .917 r
.24161 .48114 .24815 .48834 .25879 .47603 .25103 .48407 Mtetra
.644 .891 .553 r
.25103 .48407 .25879 .47603 .26827 .47849 .26177 .47129 Mtetra
.587 .694 .916 r
.26177 .47129 .26827 .47849 .27818 .47611 .27164 .46958 Mtetra
.625 .729 .922 r
.27164 .46958 .27818 .47611 .28814 .47351 .28163 .46697 Mtetra
.619 .728 .924 r
.28163 .46697 .28814 .47351 .2981 .47162 .29165 .46449 Mtetra
.409 .62 .938 r
.29165 .46449 .2981 .47162 .30899 .45638 .30147 .46559 Mtetra
0 0 0 r
.30147 .46559 .30899 .45638 .31856 .46158 .31217 .45414 Mtetra
.584 .688 .913 r
.31217 .45414 .31856 .46158 .32868 .45908 .32225 .45248 Mtetra
.632 .733 .921 r
.32225 .45248 .32868 .45908 .33887 .45614 .33246 .44965 Mtetra
.64 .74 .921 r
.33246 .44965 .33887 .45614 .3491 .45313 .34271 .44662 Mtetra
.638 .739 .922 r
.34271 .44662 .3491 .45313 .35936 .45027 .35301 .44362 Mtetra
.621 .73 .925 r
.35301 .44362 .35936 .45027 .36962 .44863 .36332 .44102 Mtetra
0 .246 .752 r
.36332 .44102 .36962 .44863 .38034 .43738 .37323 .44832 Mtetra
.634 .821 .405 r
.37323 .44832 .38034 .43738 .39058 .43774 .38432 .43053 Mtetra
.609 .709 .916 r
.38432 .43053 .39058 .43774 .40101 .43486 .39475 .42821 Mtetra
.642 .74 .92 r
.39475 .42821 .40101 .43486 .4115 .43161 .40525 .42506 Mtetra
.65 .747 .92 r
.40525 .42506 .4115 .43161 .42203 .4282 .41581 .42168 Mtetra
.654 .75 .92 r
.41581 .42168 .42203 .4282 .4326 .42471 .42641 .4182 Mtetra
.656 .752 .92 r
.42641 .4182 .4326 .42471 .44322 .42116 .43705 .41464 Mtetra
.658 .753 .92 r
.43705 .41464 .44322 .42116 .45388 .41756 .44774 .41103 Mtetra
.659 .753 .92 r
.44774 .41103 .45388 .41756 .46459 .41393 .45847 .40739 Mtetra
.659 .754 .92 r
.45847 .40739 .46459 .41393 .47533 .41029 .46924 .40371 Mtetra
.46924 .40371 .47533 .41029 .48612 .40663 .48006 .40003 Mtetra
.48006 .40003 .48612 .40663 .49694 .40296 .49091 .39633 Mtetra
.658 .753 .92 r
.49091 .39633 .49694 .40296 .50782 .39929 .50181 .39263 Mtetra
.50181 .39263 .50782 .39929 .51873 .39561 .51275 .38892 Mtetra
.51275 .38892 .51873 .39561 .52969 .39192 .52374 .3852 Mtetra
.52374 .3852 .52969 .39192 .54069 .38822 .53477 .38147 Mtetra
.53477 .38147 .54069 .38822 .55173 .38451 .54584 .37773 Mtetra
.54584 .37773 .55173 .38451 .56282 .38078 .55696 .37398 Mtetra
.55696 .37398 .56282 .38078 .57395 .37704 .56812 .37021 Mtetra
.657 .753 .92 r
.56812 .37021 .57395 .37704 .58513 .37329 .57933 .36643 Mtetra
.57933 .36643 .58513 .37329 .59635 .36953 .59058 .36264 Mtetra
.59058 .36264 .59635 .36953 .60762 .36575 .60188 .35883 Mtetra
.657 .752 .92 r
.60188 .35883 .60762 .36575 .61893 .36196 .61322 .35501 Mtetra
.61322 .35501 .61893 .36196 .63029 .35816 .62461 .35118 Mtetra
.62461 .35118 .63029 .35816 .64169 .35434 .63605 .34733 Mtetra
.63605 .34733 .64169 .35434 .65314 .3505 .64753 .34346 Mtetra
.64753 .34346 .65314 .3505 .66464 .34665 .65906 .33958 Mtetra
.65906 .33958 .66464 .34665 .67618 .34279 .67063 .33569 Mtetra
.67063 .33569 .67618 .34279 .68777 .33891 .68226 .33178 Mtetra
.68226 .33178 .68777 .33891 .69941 .33501 .69393 .32786 Mtetra
.69393 .32786 .69941 .33501 .7111 .3311 .70565 .32392 Mtetra
.70565 .32392 .7111 .3311 .72283 .32718 .71742 .31996 Mtetra
.71742 .31996 .72283 .32718 .73461 .32324 .72923 .31599 Mtetra
.72923 .31599 .73461 .32324 .74644 .31928 .7411 .31201 Mtetra
.7411 .31201 .74644 .31928 .75832 .31531 .75301 .308 Mtetra
.75301 .308 .75832 .31531 .77025 .31132 .76498 .30398 Mtetra
.76498 .30398 .77025 .31132 .78223 .30732 .77699 .29995 Mtetra
.77699 .29995 .78223 .30732 .79426 .3033 .78906 .2959 Mtetra
.78906 .2959 .79426 .3033 .80634 .29926 .80117 .29183 Mtetra
.80117 .29183 .80634 .29926 .81847 .29521 .81334 .28775 Mtetra
.359 .077 .342 r
.16601 .50064 .1773 .46447 .18304 .4984 .17642 .49065 Mtetra
.54 .655 .91 r
.17642 .49065 .18304 .4984 .19261 .49655 .18588 .48996 Mtetra
.603 .716 .925 r
.18588 .48996 .19261 .49655 .2022 .49487 .19552 .4879 Mtetra
.448 .643 .94 r
.19552 .4879 .2022 .49487 .21357 .47479 .20496 .48839 Mtetra
0 0 0 r
.20496 .48839 .21357 .47479 .22207 .48545 .21549 .47791 Mtetra
.561 .672 .913 r
.21549 .47791 .22207 .48545 .23181 .48335 .22516 .47676 Mtetra
.614 .723 .923 r
.22516 .47676 .23181 .48335 .24161 .48114 .23499 .47442 Mtetra
.577 .706 .931 r
.23499 .47442 .24161 .48114 .25103 .48407 .24479 .47283 Mtetra
.786 .674 .741 r
.24479 .47283 .25103 .48407 .26177 .47129 .25553 .46042 Mtetra
.407 .509 .85 r
.25553 .46042 .26177 .47129 .27164 .46958 .26508 .46284 Mtetra
.616 .721 .921 r
.26508 .46284 .27164 .46958 .28163 .46697 .27507 .46042 Mtetra
.626 .731 .923 r
.27507 .46042 .28163 .46697 .29165 .46449 .28512 .45776 Mtetra
.592 .714 .929 r
.28512 .45776 .29165 .46449 .30147 .46559 .29517 .45581 Mtetra
.826 .707 .733 r
.29517 .45581 .30147 .46559 .31217 .45414 .30616 .44046 Mtetra
.315 .399 .789 r
.30616 .44046 .31217 .45414 .32225 .45248 .3158 .44564 Mtetra
.62 .723 .919 r
.3158 .44564 .32225 .45248 .33246 .44965 .326 .44307 Mtetra
.638 .738 .921 r
.326 .44307 .33246 .44965 .34271 .44662 .33628 .44007 Mtetra
.64 .74 .921 r
.33628 .44007 .34271 .44662 .35301 .44362 .3466 .437 Mtetra
.633 .737 .923 r
.3466 .437 .35301 .44362 .36332 .44102 .35695 .43408 Mtetra
.577 .707 .931 r
.35695 .43408 .36332 .44102 .37323 .44832 .36729 .43239 Mtetra
.739 .611 .717 r
.36729 .43239 .37323 .44832 .38432 .43053 .37812 .42104 Mtetra
.501 .597 .882 r
.37812 .42104 .38432 .43053 .39475 .42821 .38845 .42136 Mtetra
.633 .732 .919 r
.38845 .42136 .39475 .42821 .40525 .42506 .39897 .41842 Mtetra
.647 .744 .92 r
.39897 .41842 .40525 .42506 .41581 .42168 .40955 .4151 Mtetra
.652 .748 .92 r
.40955 .4151 .41581 .42168 .42641 .4182 .42017 .41163 Mtetra
.655 .751 .92 r
.42017 .41163 .42641 .4182 .43705 .41464 .43084 .40807 Mtetra
.657 .752 .92 r
.43084 .40807 .43705 .41464 .44774 .41103 .44155 .40445 Mtetra
.658 .753 .92 r
.44155 .40445 .44774 .41103 .45847 .40739 .45231 .40079 Mtetra
.659 .754 .92 r
.45231 .40079 .45847 .40739 .46924 .40371 .46311 .39709 Mtetra
.46311 .39709 .46924 .40371 .48006 .40003 .47395 .39338 Mtetra
.47395 .39338 .48006 .40003 .49091 .39633 .48484 .38966 Mtetra
.48484 .38966 .49091 .39633 .50181 .39263 .49576 .38592 Mtetra
.658 .753 .92 r
.49576 .38592 .50181 .39263 .51275 .38892 .50674 .38218 Mtetra
.50674 .38218 .51275 .38892 .52374 .3852 .51775 .37843 Mtetra
.51775 .37843 .52374 .3852 .53477 .38147 .52881 .37467 Mtetra
.52881 .37467 .53477 .38147 .54584 .37773 .53991 .3709 Mtetra
.53991 .3709 .54584 .37773 .55696 .37398 .55106 .36712 Mtetra
.55106 .36712 .55696 .37398 .56812 .37021 .56225 .36332 Mtetra
.657 .753 .92 r
.56225 .36332 .56812 .37021 .57933 .36643 .57349 .35952 Mtetra
.57349 .35952 .57933 .36643 .59058 .36264 .58477 .35569 Mtetra
.58477 .35569 .59058 .36264 .60188 .35883 .5961 .35186 Mtetra
.5961 .35186 .60188 .35883 .61322 .35501 .60747 .34801 Mtetra
.657 .752 .92 r
.60747 .34801 .61322 .35501 .62461 .35118 .61889 .34414 Mtetra
.61889 .34414 .62461 .35118 .63605 .34733 .63036 .34027 Mtetra
.63036 .34027 .63605 .34733 .64753 .34346 .64188 .33637 Mtetra
.64188 .33637 .64753 .34346 .65906 .33958 .65344 .33246 Mtetra
.65344 .33246 .65906 .33958 .67063 .33569 .66505 .32854 Mtetra
.66505 .32854 .67063 .33569 .68226 .33178 .6767 .3246 Mtetra
.6767 .3246 .68226 .33178 .69393 .32786 .68841 .32065 Mtetra
.68841 .32065 .69393 .32786 .70565 .32392 .70016 .31668 Mtetra
.70016 .31668 .70565 .32392 .71742 .31996 .71196 .31269 Mtetra
.71196 .31269 .71742 .31996 .72923 .31599 .72381 .30869 Mtetra
.72381 .30869 .72923 .31599 .7411 .31201 .73571 .30467 Mtetra
.73571 .30467 .7411 .31201 .75301 .308 .74766 .30064 Mtetra
.74766 .30064 .75301 .308 .76498 .30398 .75966 .29659 Mtetra
.75966 .29659 .76498 .30398 .77699 .29995 .77171 .29252 Mtetra
.77171 .29252 .77699 .29995 .78906 .2959 .78381 .28844 Mtetra
.78381 .28844 .78906 .2959 .80117 .29183 .79596 .28434 Mtetra
.79596 .28434 .80117 .29183 .81334 .28775 .80816 .28022 Mtetra
.902 .71 .633 r
.15938 .49237 .16601 .50064 .17642 .49065 .1734 .44909 Mtetra
0 0 .38 r
.1734 .44909 .17642 .49065 .18588 .48996 .17913 .48312 Mtetra
.595 .707 .922 r
.17913 .48312 .18588 .48996 .19552 .4879 .18877 .48121 Mtetra
.584 .709 .929 r
.18877 .48121 .19552 .4879 .20496 .48839 .19844 .47948 Mtetra
.856 .714 .706 r
.19844 .47948 .20496 .48839 .21549 .47791 .20993 .45927 Mtetra
.119 .197 .67 r
.20993 .45927 .21549 .47791 .22516 .47676 .21848 .46993 Mtetra
.605 .713 .921 r
.21848 .46993 .22516 .47676 .23499 .47442 .2283 .46778 Mtetra
.609 .722 .925 r
.2283 .46778 .23499 .47442 .24479 .47283 .23818 .46551 Mtetra
.244 .528 .917 r
.23818 .46551 .24479 .47283 .25553 .46042 .24767 .46841 Mtetra
.654 .898 .563 r
.24767 .46841 .25553 .46042 .26508 .46284 .25851 .45554 Mtetra
.587 .694 .916 r
.25851 .45554 .26508 .46284 .27507 .46042 .26847 .45377 Mtetra
.625 .729 .922 r
.26847 .45377 .27507 .46042 .28512 .45776 .27854 .4511 Mtetra
.619 .728 .924 r
.27854 .4511 .28512 .45776 .29517 .45581 .28864 .44857 Mtetra
.41 .621 .938 r
.28864 .44857 .29517 .45581 .30616 .44046 .29854 .44962 Mtetra
0 0 0 r
.29854 .44962 .30616 .44046 .3158 .44564 .30934 .43808 Mtetra
.583 .688 .913 r
.30934 .43808 .3158 .44564 .326 .44307 .31951 .43636 Mtetra
.632 .733 .921 r
.31951 .43636 .326 .44307 .33628 .44007 .3298 .43347 Mtetra
.64 .74 .921 r
.3298 .43347 .33628 .44007 .3466 .437 .34014 .43038 Mtetra
.638 .739 .922 r
.34014 .43038 .3466 .437 .35695 .43408 .35053 .42731 Mtetra
.621 .73 .925 r
.35053 .42731 .35695 .43408 .36729 .43239 .36094 .42465 Mtetra
0 .25 .755 r
.36094 .42465 .36729 .43239 .37812 .42104 .37092 .43194 Mtetra
.643 .828 .414 r
.37092 .43194 .37812 .42104 .38845 .42136 .38212 .41402 Mtetra
.609 .709 .916 r
.38212 .41402 .38845 .42136 .39897 .41842 .39264 .41165 Mtetra
.642 .74 .92 r
.39264 .41165 .39897 .41842 .40955 .4151 .40324 .40843 Mtetra
.65 .747 .92 r
.40324 .40843 .40955 .4151 .42017 .41163 .41389 .40499 Mtetra
.654 .75 .92 r
.41389 .40499 .42017 .41163 .43084 .40807 .42458 .40144 Mtetra
.656 .752 .92 r
.42458 .40144 .43084 .40807 .44155 .40445 .43532 .39782 Mtetra
.658 .753 .92 r
.43532 .39782 .44155 .40445 .45231 .40079 .44611 .39414 Mtetra
.659 .753 .92 r
.44611 .39414 .45231 .40079 .46311 .39709 .45693 .39042 Mtetra
.659 .754 .92 r
.45693 .39042 .46311 .39709 .47395 .39338 .4678 .38668 Mtetra
.4678 .38668 .47395 .39338 .48484 .38966 .47872 .38293 Mtetra
.47872 .38293 .48484 .38966 .49576 .38592 .48967 .37917 Mtetra
.658 .753 .92 r
.48967 .37917 .49576 .38592 .50674 .38218 .50067 .37539 Mtetra
.50067 .37539 .50674 .38218 .51775 .37843 .51172 .37161 Mtetra
.51172 .37161 .51775 .37843 .52881 .37467 .5228 .36782 Mtetra
.5228 .36782 .52881 .37467 .53991 .3709 .53394 .36402 Mtetra
.53394 .36402 .53991 .3709 .55106 .36712 .54511 .36021 Mtetra
.54511 .36021 .55106 .36712 .56225 .36332 .55633 .35639 Mtetra
.55633 .35639 .56225 .36332 .57349 .35952 .5676 .35255 Mtetra
.657 .753 .92 r
.5676 .35255 .57349 .35952 .58477 .35569 .57892 .3487 Mtetra
.57892 .3487 .58477 .35569 .5961 .35186 .59027 .34483 Mtetra
.59027 .34483 .5961 .35186 .60747 .34801 .60168 .34095 Mtetra
.657 .752 .92 r
.60168 .34095 .60747 .34801 .61889 .34414 .61313 .33706 Mtetra
.61313 .33706 .61889 .34414 .63036 .34027 .62463 .33315 Mtetra
.62463 .33315 .63036 .34027 .64188 .33637 .63618 .32923 Mtetra
.63618 .32923 .64188 .33637 .65344 .33246 .64777 .32529 Mtetra
.64777 .32529 .65344 .33246 .66505 .32854 .65941 .32134 Mtetra
.65941 .32134 .66505 .32854 .6767 .3246 .6711 .31737 Mtetra
.6711 .31737 .6767 .3246 .68841 .32065 .68284 .31338 Mtetra
.68284 .31338 .68841 .32065 .70016 .31668 .69463 .30938 Mtetra
.69463 .30938 .70016 .31668 .71196 .31269 .70646 .30537 Mtetra
.70646 .30537 .71196 .31269 .72381 .30869 .71835 .30133 Mtetra
.71835 .30133 .72381 .30869 .73571 .30467 .73028 .29728 Mtetra
.73028 .29728 .73571 .30467 .74766 .30064 .74227 .29322 Mtetra
.74227 .29322 .74766 .30064 .75966 .29659 .7543 .28914 Mtetra
.7543 .28914 .75966 .29659 .77171 .29252 .76639 .28504 Mtetra
.76639 .28504 .77171 .29252 .78381 .28844 .77852 .28092 Mtetra
.77852 .28092 .78381 .28844 .79596 .28434 .79071 .27679 Mtetra
.79071 .27679 .79596 .28434 .80816 .28022 .80295 .27264 Mtetra
.486 .662 .939 r
.15256 .48541 .15938 .49237 .1734 .44909 .16194 .48533 Mtetra
.352 .067 .335 r
.16194 .48533 .1734 .44909 .17913 .48312 .17245 .47526 Mtetra
.54 .655 .91 r
.17245 .47526 .17913 .48312 .18877 .48121 .18198 .47452 Mtetra
.603 .716 .925 r
.18198 .47452 .18877 .48121 .19844 .47948 .1917 .4724 Mtetra
.449 .643 .94 r
.1917 .4724 .19844 .47948 .20993 .45927 .20121 .47285 Mtetra
0 0 0 r
.20121 .47285 .20993 .45927 .21848 .46993 .21183 .46228 Mtetra
.561 .672 .913 r
.21183 .46228 .21848 .46993 .2283 .46778 .22158 .46108 Mtetra
.614 .723 .923 r
.22158 .46108 .2283 .46778 .23818 .46551 .23149 .45868 Mtetra
.577 .706 .931 r
.23149 .45868 .23818 .46551 .24767 .46841 .24137 .45704 Mtetra
.786 .675 .741 r
.24137 .45704 .24767 .46841 .25851 .45554 .25221 .44453 Mtetra
.406 .508 .85 r
.25221 .44453 .25851 .45554 .26847 .45377 .26184 .44692 Mtetra
.616 .721 .921 r
.26184 .44692 .26847 .45377 .27854 .4511 .27191 .44443 Mtetra
.626 .731 .923 r
.27191 .44443 .27854 .4511 .28864 .44857 .28205 .44171 Mtetra
.592 .714 .929 r
.28205 .44171 .28864 .44857 .29854 .44962 .29218 .43971 Mtetra
.827 .708 .733 r
.29218 .43971 .29854 .44962 .30934 .43808 .30327 .42425 Mtetra
.313 .398 .789 r
.30327 .42425 .30934 .43808 .31951 .43636 .31299 .4294 Mtetra
.62 .723 .919 r
.31299 .4294 .31951 .43636 .3298 .43347 .32328 .42677 Mtetra
.638 .738 .921 r
.32328 .42677 .3298 .43347 .34014 .43038 .33364 .42371 Mtetra
.64 .74 .921 r
.33364 .42371 .34014 .43038 .35053 .42731 .34405 .42058 Mtetra
.633 .737 .923 r
.34405 .42058 .35053 .42731 .36094 .42465 .3545 .4176 Mtetra
.577 .707 .931 r
.3545 .4176 .36094 .42465 .37092 .43194 .36493 .41585 Mtetra
.739 .612 .717 r
.36493 .41585 .37092 .43194 .38212 .41402 .37586 .4044 Mtetra
.501 .597 .882 r
.37586 .4044 .38212 .41402 .39264 .41165 .38627 .40467 Mtetra
.633 .732 .919 r
.38627 .40467 .39264 .41165 .40324 .40843 .39689 .40166 Mtetra
.647 .744 .92 r
.39689 .40166 .40324 .40843 .41389 .40499 .40756 .39828 Mtetra
.652 .748 .92 r
.40756 .39828 .41389 .40499 .42458 .40144 .41828 .39474 Mtetra
.655 .751 .92 r
.41828 .39474 .42458 .40144 .43532 .39782 .42904 .39112 Mtetra
.657 .752 .92 r
.42904 .39112 .43532 .39782 .44611 .39414 .43986 .38743 Mtetra
.658 .753 .92 r
.43986 .38743 .44611 .39414 .45693 .39042 .45071 .3837 Mtetra
.659 .754 .92 r
.45071 .3837 .45693 .39042 .4678 .38668 .46161 .37994 Mtetra
.46161 .37994 .4678 .38668 .47872 .38293 .47255 .37615 Mtetra
.47255 .37615 .47872 .38293 .48967 .37917 .48353 .37236 Mtetra
.48353 .37236 .48967 .37917 .50067 .37539 .49456 .36856 Mtetra
.658 .753 .92 r
.49456 .36856 .50067 .37539 .51172 .37161 .50564 .36475 Mtetra
.50564 .36475 .51172 .37161 .5228 .36782 .51675 .36093 Mtetra
.51675 .36093 .5228 .36782 .53394 .36402 .52791 .35709 Mtetra
.52791 .35709 .53394 .36402 .54511 .36021 .53912 .35325 Mtetra
.53912 .35325 .54511 .36021 .55633 .35639 .55037 .3494 Mtetra
.55037 .3494 .55633 .35639 .5676 .35255 .56167 .34553 Mtetra
.657 .753 .92 r
.56167 .34553 .5676 .35255 .57892 .3487 .57302 .34165 Mtetra
.57302 .34165 .57892 .3487 .59027 .34483 .58441 .33776 Mtetra
.58441 .33776 .59027 .34483 .60168 .34095 .59584 .33385 Mtetra
.59584 .33385 .60168 .34095 .61313 .33706 .60733 .32992 Mtetra
.657 .752 .92 r
.60733 .32992 .61313 .33706 .62463 .33315 .61886 .32598 Mtetra
.61886 .32598 .62463 .33315 .63618 .32923 .63044 .32203 Mtetra
.63044 .32203 .63618 .32923 .64777 .32529 .64206 .31806 Mtetra
.64206 .31806 .64777 .32529 .65941 .32134 .65374 .31408 Mtetra
.65374 .31408 .65941 .32134 .6711 .31737 .66546 .31008 Mtetra
.66546 .31008 .6711 .31737 .68284 .31338 .67723 .30606 Mtetra
.67723 .30606 .68284 .31338 .69463 .30938 .68905 .30203 Mtetra
.68905 .30203 .69463 .30938 .70646 .30537 .70092 .29798 Mtetra
.70092 .29798 .70646 .30537 .71835 .30133 .71284 .29392 Mtetra
.71284 .29392 .71835 .30133 .73028 .29728 .72481 .28984 Mtetra
.72481 .28984 .73028 .29728 .74227 .29322 .73683 .28574 Mtetra
.73683 .28574 .74227 .29322 .7543 .28914 .7489 .28163 Mtetra
.7489 .28163 .7543 .28914 .76639 .28504 .76102 .2775 Mtetra
.76102 .2775 .76639 .28504 .77852 .28092 .7732 .27335 Mtetra
.7732 .27335 .77852 .28092 .79071 .27679 .78542 .26918 Mtetra
.78542 .26918 .79071 .27679 .80295 .27264 .7977 .265 Mtetra
.582 .707 .928 r
.14567 .47864 .15256 .48541 .16194 .48533 .15524 .47694 Mtetra
.903 .71 .632 r
.15524 .47694 .16194 .48533 .17245 .47526 .16942 .43344 Mtetra
0 0 .376 r
.16942 .43344 .17245 .47526 .18198 .47452 .17516 .46756 Mtetra
.595 .707 .922 r
.17516 .46756 .18198 .47452 .1917 .4724 .18488 .4656 Mtetra
.584 .709 .929 r
.18488 .4656 .1917 .4724 .20121 .47285 .19462 .46382 Mtetra
.856 .715 .705 r
.19462 .46382 .20121 .47285 .21183 .46228 .20622 .44348 Mtetra
.115 .194 .669 r
.20622 .44348 .21183 .46228 .22158 .46108 .21483 .45414 Mtetra
.605 .713 .921 r
.21483 .45414 .22158 .46108 .23149 .45868 .22473 .45193 Mtetra
.609 .722 .925 r
.22473 .45193 .23149 .45868 .24137 .45704 .23469 .4496 Mtetra
.247 .529 .917 r
.23469 .4496 .24137 .45704 .25221 .44453 .24425 .45247 Mtetra
.664 .905 .573 r
.24425 .45247 .25221 .44453 .26184 .44692 .2552 .43949 Mtetra
.587 .694 .916 r
.2552 .43949 .26184 .44692 .27191 .44443 .26524 .43767 Mtetra
.625 .729 .922 r
.26524 .43767 .27191 .44443 .28205 .44171 .27539 .43494 Mtetra
.619 .728 .924 r
.27539 .43494 .28205 .44171 .29218 .43971 .28558 .43235 Mtetra
.411 .621 .938 r
.28558 .43235 .29218 .43971 .30327 .42425 .29556 .43336 Mtetra
0 0 0 r
.29556 .43336 .30327 .42425 .31299 .4294 .30646 .42172 Mtetra
.583 .688 .913 r
.30646 .42172 .31299 .4294 .32328 .42677 .31672 .41994 Mtetra
.632 .733 .921 r
.31672 .41994 .32328 .42677 .33364 .42371 .3271 .41699 Mtetra
.64 .74 .921 r
.3271 .41699 .33364 .42371 .34405 .42058 .33753 .41383 Mtetra
.638 .739 .922 r
.33753 .41383 .34405 .42058 .3545 .4176 .34801 .41071 Mtetra
.621 .73 .925 r
.34801 .41071 .3545 .4176 .36493 .41585 .3585 .40798 Mtetra
0 .254 .759 r
.3585 .40798 .36493 .41585 .37586 .4044 .36857 .41525 Mtetra
.653 .836 .424 r
.36857 .41525 .37586 .4044 .38627 .40467 .37988 .39721 Mtetra
.609 .709 .916 r
.37988 .39721 .38627 .40467 .39689 .40166 .39049 .39477 Mtetra
.642 .74 .92 r
.39049 .39477 .39689 .40166 .40756 .39828 .40118 .39149 Mtetra
.65 .747 .92 r
.40118 .39149 .40756 .39828 .41828 .39474 .41193 .38798 Mtetra
.654 .75 .92 r
.41193 .38798 .41828 .39474 .42904 .39112 .42272 .38436 Mtetra
.656 .752 .92 r
.42272 .38436 .42904 .39112 .43986 .38743 .43356 .38067 Mtetra
.658 .753 .92 r
.43356 .38067 .43986 .38743 .45071 .3837 .44444 .37692 Mtetra
.659 .753 .92 r
.44444 .37692 .45071 .3837 .46161 .37994 .45537 .37314 Mtetra
.659 .754 .92 r
.45537 .37314 .46161 .37994 .47255 .37615 .46634 .36933 Mtetra
.46634 .36933 .47255 .37615 .48353 .37236 .47735 .36551 Mtetra
.47735 .36551 .48353 .37236 .49456 .36856 .48841 .36167 Mtetra
.658 .753 .92 r
.48841 .36167 .49456 .36856 .50564 .36475 .49951 .35783 Mtetra
.49951 .35783 .50564 .36475 .51675 .36093 .51066 .35398 Mtetra
.51066 .35398 .51675 .36093 .52791 .35709 .52185 .35011 Mtetra
.52185 .35011 .52791 .35709 .53912 .35325 .53309 .34624 Mtetra
.53309 .34624 .53912 .35325 .55037 .3494 .54437 .34236 Mtetra
.54437 .34236 .55037 .3494 .56167 .34553 .5557 .33846 Mtetra
.5557 .33846 .56167 .34553 .57302 .34165 .56707 .33455 Mtetra
.657 .753 .92 r
.56707 .33455 .57302 .34165 .58441 .33776 .57849 .33062 Mtetra
.57849 .33062 .58441 .33776 .59584 .33385 .58996 .32668 Mtetra
.58996 .32668 .59584 .33385 .60733 .32992 .60148 .32273 Mtetra
.657 .752 .92 r
.60148 .32273 .60733 .32992 .61886 .32598 .61304 .31876 Mtetra
.61304 .31876 .61886 .32598 .63044 .32203 .62465 .31478 Mtetra
.62465 .31478 .63044 .32203 .64206 .31806 .63631 .31078 Mtetra
.63631 .31078 .64206 .31806 .65374 .31408 .64802 .30676 Mtetra
.64802 .30676 .65374 .31408 .66546 .31008 .65977 .30273 Mtetra
.65977 .30273 .66546 .31008 .67723 .30606 .67158 .29868 Mtetra
.67158 .29868 .67723 .30606 .68905 .30203 .68343 .29462 Mtetra
.68343 .29462 .68905 .30203 .70092 .29798 .69534 .29054 Mtetra
.69534 .29054 .70092 .29798 .71284 .29392 .70729 .28644 Mtetra
.70729 .28644 .71284 .29392 .72481 .28984 .7193 .28233 Mtetra
.7193 .28233 .72481 .28984 .73683 .28574 .73135 .2782 Mtetra
.73135 .2782 .73683 .28574 .7489 .28163 .74346 .27406 Mtetra
.74346 .27406 .7489 .28163 .76102 .2775 .75562 .26989 Mtetra
.75562 .26989 .76102 .2775 .7732 .27335 .76783 .26571 Mtetra
.76783 .26571 .7732 .27335 .78542 .26918 .78009 .26152 Mtetra
.78009 .26152 .78542 .26918 .7977 .265 .7924 .2573 Mtetra
.591 .707 .924 r
.13874 .47175 .14567 .47864 .15524 .47694 .14835 .46987 Mtetra
.486 .662 .939 r
.14835 .46987 .15524 .47694 .16942 .43344 .1578 .46975 Mtetra
.344 .058 .327 r
.1578 .46975 .16942 .43344 .17516 .46756 .1684 .45958 Mtetra
.54 .655 .91 r
.1684 .45958 .17516 .46756 .18488 .4656 .178 .45879 Mtetra
.603 .716 .925 r
.178 .45879 .18488 .4656 .19462 .46382 .1878 .45662 Mtetra
.45 .643 .94 r
.1878 .45662 .19462 .46382 .20622 .44348 .19739 .45703 Mtetra
0 0 0 r
.19739 .45703 .20622 .44348 .21483 .45414 .20811 .44636 Mtetra
.561 .672 .913 r
.20811 .44636 .21483 .45414 .22473 .45193 .21794 .44511 Mtetra
.614 .723 .923 r
.21794 .44511 .22473 .45193 .23469 .4496 .22792 .44265 Mtetra
.577 .706 .931 r
.22792 .44265 .23469 .4496 .24425 .45247 .23789 .44096 Mtetra
.787 .675 .741 r
.23789 .44096 .24425 .45247 .2552 .43949 .24883 .42835 Mtetra
.405 .508 .85 r
.24883 .42835 .2552 .43949 .26524 .43767 .25853 .4307 Mtetra
.616 .721 .921 r
.25853 .4307 .26524 .43767 .27539 .43494 .26869 .42815 Mtetra
.626 .731 .923 r
.26869 .42815 .27539 .43494 .28558 .43235 .27891 .42537 Mtetra
.592 .714 .929 r
.27891 .42537 .28558 .43235 .29556 .43336 .28913 .42332 Mtetra
.828 .709 .733 r
.28913 .42332 .29556 .43336 .30646 .42172 .30033 .40774 Mtetra
.311 .397 .789 r
.30033 .40774 .30646 .42172 .31672 .41994 .31012 .41286 Mtetra
.62 .723 .919 r
.31012 .41286 .31672 .41994 .3271 .41699 .32051 .41017 Mtetra
.638 .738 .921 r
.32051 .41017 .3271 .41699 .33753 .41383 .33096 .40705 Mtetra
.64 .74 .921 r
.33096 .40705 .33753 .41383 .34801 .41071 .34146 .40385 Mtetra
.633 .737 .923 r
.34146 .40385 .34801 .41071 .3585 .40798 .352 .40081 Mtetra
.578 .707 .931 r
.352 .40081 .3585 .40798 .36857 .41525 .36252 .399 Mtetra
.739 .612 .717 r
.36252 .399 .36857 .41525 .37988 .39721 .37355 .38745 Mtetra
.5 .597 .882 r
.37355 .38745 .37988 .39721 .39049 .39477 .38406 .38767 Mtetra
.633 .732 .919 r
.38406 .38767 .39049 .39477 .40118 .39149 .39476 .3846 Mtetra
.647 .744 .92 r
.39476 .3846 .40118 .39149 .41193 .38798 .40553 .38114 Mtetra
.652 .748 .92 r
.40553 .38114 .41193 .38798 .42272 .38436 .41635 .37754 Mtetra
.655 .751 .92 r
.41635 .37754 .42272 .38436 .43356 .38067 .42721 .37385 Mtetra
.657 .752 .92 r
.42721 .37385 .43356 .38067 .44444 .37692 .43812 .37009 Mtetra
.658 .753 .92 r
.43812 .37009 .44444 .37692 .45537 .37314 .44908 .36629 Mtetra
.659 .754 .92 r
.44908 .36629 .45537 .37314 .46634 .36933 .46008 .36245 Mtetra
.46008 .36245 .46634 .36933 .47735 .36551 .47112 .3586 Mtetra
.47112 .3586 .47735 .36551 .48841 .36167 .48221 .35473 Mtetra
.48221 .35473 .48841 .36167 .49951 .35783 .49334 .35086 Mtetra
.658 .753 .92 r
.49334 .35086 .49951 .35783 .51066 .35398 .50451 .34698 Mtetra
.50451 .34698 .51066 .35398 .52185 .35011 .51574 .34308 Mtetra
.51574 .34308 .52185 .35011 .53309 .34624 .527 .33918 Mtetra
.527 .33918 .53309 .34624 .54437 .34236 .53832 .33526 Mtetra
.53832 .33526 .54437 .34236 .5557 .33846 .54968 .33134 Mtetra
.54968 .33134 .5557 .33846 .56707 .33455 .56108 .32739 Mtetra
.657 .753 .92 r
.56108 .32739 .56707 .33455 .57849 .33062 .57253 .32344 Mtetra
.57253 .32344 .57849 .33062 .58996 .32668 .58404 .31947 Mtetra
.58404 .31947 .58996 .32668 .60148 .32273 .59558 .31548 Mtetra
.59558 .31548 .60148 .32273 .61304 .31876 .60718 .31148 Mtetra
.657 .752 .92 r
.60718 .31148 .61304 .31876 .62465 .31478 .61882 .30747 Mtetra
.61882 .30747 .62465 .31478 .63631 .31078 .63051 .30344 Mtetra
.63051 .30344 .63631 .31078 .64802 .30676 .64225 .29939 Mtetra
.64225 .29939 .64802 .30676 .65977 .30273 .65404 .29533 Mtetra
.65404 .29533 .65977 .30273 .67158 .29868 .66588 .29125 Mtetra
.66588 .29125 .67158 .29868 .68343 .29462 .67777 .28715 Mtetra
.67777 .28715 .68343 .29462 .69534 .29054 .68971 .28304 Mtetra
.68971 .28304 .69534 .29054 .70729 .28644 .7017 .27891 Mtetra
.7017 .27891 .70729 .28644 .7193 .28233 .71374 .27477 Mtetra
.71374 .27477 .7193 .28233 .73135 .2782 .72583 .27061 Mtetra
.72583 .27061 .73135 .2782 .74346 .27406 .73797 .26643 Mtetra
.73797 .26643 .74346 .27406 .75562 .26989 .75017 .26223 Mtetra
.75017 .26223 .75562 .26989 .76783 .26571 .76241 .25802 Mtetra
.76241 .25802 .76783 .26571 .78009 .26152 .77471 .25379 Mtetra
.77471 .25379 .78009 .26152 .7924 .2573 .78706 .24954 Mtetra
.558 .676 .917 r
.13184 .46419 .13874 .47175 .14835 .46987 .14138 .46299 Mtetra
.582 .707 .928 r
.14138 .46299 .14835 .46987 .1578 .46975 .15103 .46123 Mtetra
.904 .711 .631 r
.15103 .46123 .1578 .46975 .1684 .45958 .16538 .41751 Mtetra
0 0 .371 r
.16538 .41751 .1684 .45958 .178 .45879 .17111 .45173 Mtetra
.595 .707 .922 r
.17111 .45173 .178 .45879 .1878 .45662 .18091 .44971 Mtetra
.584 .709 .929 r
.18091 .44971 .1878 .45662 .19739 .45703 .19073 .44787 Mtetra
.857 .716 .705 r
.19073 .44787 .19739 .45703 .20811 .44636 .20245 .4274 Mtetra
.111 .191 .668 r
.20245 .4274 .20811 .44636 .21794 .44511 .21111 .43805 Mtetra
.605 .713 .921 r
.21111 .43805 .21794 .44511 .22792 .44265 .2211 .43579 Mtetra
.609 .722 .925 r
.2211 .43579 .22792 .44265 .23789 .44096 .23114 .4334 Mtetra
.249 .53 .918 r
.23114 .4334 .23789 .44096 .24883 .42835 .24077 .43623 Mtetra
.673 .911 .583 r
.24077 .43623 .24883 .42835 .25853 .4307 .25182 .42315 Mtetra
.587 .694 .916 r
.25182 .42315 .25853 .4307 .26869 .42815 .26195 .42127 Mtetra
.625 .729 .922 r
.26195 .42127 .26869 .42815 .27891 .42537 .27219 .41849 Mtetra
.619 .728 .924 r
.27219 .41849 .27891 .42537 .28913 .42332 .28247 .41583 Mtetra
.412 .621 .938 r
.28247 .41583 .28913 .42332 .30033 .40774 .29253 .41679 Mtetra
0 0 0 r
.29253 .41679 .30033 .40774 .31012 .41286 .30353 .40505 Mtetra
.583 .688 .913 r
.30353 .40505 .31012 .41286 .32051 .41017 .31387 .40322 Mtetra
.632 .733 .921 r
.31387 .40322 .32051 .41017 .33096 .40705 .32434 .4002 Mtetra
.64 .74 .921 r
.32434 .4002 .33096 .40705 .34146 .40385 .33487 .39698 Mtetra
.638 .739 .922 r
.33487 .39698 .34146 .40385 .352 .40081 .34544 .39379 Mtetra
.621 .73 .925 r
.34544 .39379 .352 .40081 .36252 .399 .35603 .391 Mtetra
0 .259 .762 r
.35603 .391 .36252 .399 .37355 .38745 .36617 .39824 Mtetra
.662 .843 .433 r
.36617 .39824 .37355 .38745 .38406 .38767 .3776 .38008 Mtetra
.609 .709 .916 r
.3776 .38008 .38406 .38767 .39476 .3846 .3883 .37758 Mtetra
.642 .74 .92 r
.3883 .37758 .39476 .3846 .40553 .38114 .39909 .37422 Mtetra
.65 .747 .92 r
.39909 .37422 .40553 .38114 .41635 .37754 .40993 .37065 Mtetra
.654 .75 .92 r
.40993 .37065 .41635 .37754 .42721 .37385 .42082 .36696 Mtetra
.656 .752 .92 r
.42082 .36696 .42721 .37385 .43812 .37009 .43176 .3632 Mtetra
.658 .753 .92 r
.43176 .3632 .43812 .37009 .44908 .36629 .44274 .35938 Mtetra
.659 .753 .92 r
.44274 .35938 .44908 .36629 .46008 .36245 .45377 .35553 Mtetra
.659 .754 .92 r
.45377 .35553 .46008 .36245 .47112 .3586 .46484 .35164 Mtetra
.46484 .35164 .47112 .3586 .48221 .35473 .47596 .34775 Mtetra
.47596 .34775 .48221 .35473 .49334 .35086 .48712 .34384 Mtetra
.658 .753 .92 r
.48712 .34384 .49334 .35086 .50451 .34698 .49833 .33992 Mtetra
.49833 .33992 .50451 .34698 .51574 .34308 .50958 .336 Mtetra
.50958 .336 .51574 .34308 .527 .33918 .52087 .33206 Mtetra
.52087 .33206 .527 .33918 .53832 .33526 .53222 .32812 Mtetra
.53222 .32812 .53832 .33526 .54968 .33134 .54361 .32416 Mtetra
.54361 .32416 .54968 .33134 .56108 .32739 .55505 .32018 Mtetra
.55505 .32018 .56108 .32739 .57253 .32344 .56653 .3162 Mtetra
.657 .753 .92 r
.56653 .3162 .57253 .32344 .58404 .31947 .57806 .31219 Mtetra
.57806 .31219 .58404 .31947 .59558 .31548 .58964 .30818 Mtetra
.58964 .30818 .59558 .31548 .60718 .31148 .60127 .30415 Mtetra
.657 .752 .92 r
.60127 .30415 .60718 .31148 .61882 .30747 .61295 .3001 Mtetra
.61295 .3001 .61882 .30747 .63051 .30344 .62467 .29604 Mtetra
.62467 .29604 .63051 .30344 .64225 .29939 .63645 .29196 Mtetra
.63645 .29196 .64225 .29939 .65404 .29533 .64827 .28786 Mtetra
.64827 .28786 .65404 .29533 .66588 .29125 .66014 .28375 Mtetra
.66014 .28375 .66588 .29125 .67777 .28715 .67207 .27963 Mtetra
.67207 .27963 .67777 .28715 .68971 .28304 .68404 .27548 Mtetra
.68404 .27548 .68971 .28304 .7017 .27891 .69606 .27132 Mtetra
.69606 .27132 .7017 .27891 .71374 .27477 .70814 .26715 Mtetra
.70814 .26715 .71374 .27477 .72583 .27061 .72027 .26295 Mtetra
.72027 .26295 .72583 .27061 .73797 .26643 .73244 .25874 Mtetra
.73244 .25874 .73797 .26643 .75017 .26223 .74468 .25451 Mtetra
.74468 .25451 .75017 .26223 .76241 .25802 .75696 .25026 Mtetra
.75696 .25026 .76241 .25802 .77471 .25379 .76929 .246 Mtetra
.76929 .246 .77471 .25379 .78706 .24954 .78168 .24172 Mtetra
.235 .347 .774 r
.12567 .45023 .13184 .46419 .14138 .46299 .13437 .45598 Mtetra
.591 .707 .924 r
.13437 .45598 .14138 .46299 .15103 .46123 .14405 .45405 Mtetra
.487 .662 .939 r
.14405 .45405 .15103 .46123 .16538 .41751 .15358 .45388 Mtetra
.336 .048 .319 r
.15358 .45388 .16538 .41751 .17111 .45173 .16428 .44362 Mtetra
.54 .655 .91 r
.16428 .44362 .17111 .45173 .18091 .44971 .17396 .44278 Mtetra
.603 .716 .925 r
.17396 .44278 .18091 .44971 .19073 .44787 .18384 .44056 Mtetra
.45 .643 .94 r
.18384 .44056 .19073 .44787 .20245 .4274 .1935 .44092 Mtetra
0 0 0 r
.1935 .44092 .20245 .4274 .21111 .43805 .20432 .43016 Mtetra
.561 .672 .913 r
.20432 .43016 .21111 .43805 .2211 .43579 .21422 .42885 Mtetra
.614 .723 .923 r
.21422 .42885 .2211 .43579 .23114 .4334 .2243 .42634 Mtetra
.577 .706 .93 r
.2243 .42634 .23114 .4334 .24077 .43623 .23435 .42458 Mtetra
.787 .676 .741 r
.23435 .42458 .24077 .43623 .25182 .42315 .24539 .41187 Mtetra
.404 .508 .85 r
.24539 .41187 .25182 .42315 .26195 .42127 .25517 .41418 Mtetra
.616 .721 .921 r
.25517 .41418 .26195 .42127 .27219 .41849 .26541 .41158 Mtetra
.626 .731 .923 r
.26541 .41158 .27219 .41849 .28247 .41583 .27572 .40873 Mtetra
.592 .714 .928 r
.27572 .40873 .28247 .41583 .29253 .41679 .28603 .40662 Mtetra
.828 .709 .733 r
.28603 .40662 .29253 .41679 .30353 .40505 .29734 .39092 Mtetra
.31 .396 .789 r
.29734 .39092 .30353 .40505 .31387 .40322 .30721 .39601 Mtetra
.62 .723 .92 r
.30721 .39601 .31387 .40322 .32434 .4002 .31768 .39326 Mtetra
.638 .738 .921 r
.31768 .39326 .32434 .4002 .33487 .39698 .32823 .39007 Mtetra
.64 .74 .921 r
.32823 .39007 .33487 .39698 .34544 .39379 .33882 .38681 Mtetra
.633 .737 .923 r
.33882 .38681 .34544 .39379 .35603 .391 .34945 .3837 Mtetra
.578 .707 .93 r
.34945 .3837 .35603 .391 .36617 .39824 .36006 .38183 Mtetra
.739 .612 .717 r
.36006 .38183 .36617 .39824 .3776 .38008 .3712 .37018 Mtetra
.5 .597 .882 r
.3712 .37018 .3776 .38008 .3883 .37758 .3818 .37034 Mtetra
.632 .732 .919 r
.3818 .37034 .3883 .37758 .39909 .37422 .3926 .3672 Mtetra
.647 .744 .92 r
.3926 .3672 .39909 .37422 .40993 .37065 .40347 .36368 Mtetra
.652 .748 .92 r
.40347 .36368 .40993 .37065 .42082 .36696 .41439 .36001 Mtetra
.655 .751 .92 r
.41439 .36001 .42082 .36696 .43176 .3632 .42535 .35625 Mtetra
.657 .752 .92 r
.42535 .35625 .43176 .3632 .44274 .35938 .43636 .35242 Mtetra
.658 .753 .92 r
.43636 .35242 .44274 .35938 .45377 .35553 .44742 .34854 Mtetra
.659 .754 .92 r
.44742 .34854 .45377 .35553 .46484 .35164 .45852 .34464 Mtetra
.45852 .34464 .46484 .35164 .47596 .34775 .46966 .34071 Mtetra
.46966 .34071 .47596 .34775 .48712 .34384 .48085 .33677 Mtetra
.48085 .33677 .48712 .34384 .49833 .33992 .49209 .33282 Mtetra
.658 .753 .92 r
.49209 .33282 .49833 .33992 .50958 .336 .50337 .32886 Mtetra
.50337 .32886 .50958 .336 .52087 .33206 .5147 .32489 Mtetra
.5147 .32489 .52087 .33206 .53222 .32812 .52607 .32092 Mtetra
.52607 .32092 .53222 .32812 .54361 .32416 .5375 .31692 Mtetra
.5375 .31692 .54361 .32416 .55505 .32018 .54896 .31292 Mtetra
.54896 .31292 .55505 .32018 .56653 .3162 .56048 .3089 Mtetra
.657 .753 .92 r
.56048 .3089 .56653 .3162 .57806 .31219 .57204 .30487 Mtetra
.57204 .30487 .57806 .31219 .58964 .30818 .58366 .30082 Mtetra
.58366 .30082 .58964 .30818 .60127 .30415 .59532 .29676 Mtetra
.59532 .29676 .60127 .30415 .61295 .3001 .60703 .29268 Mtetra
.657 .752 .92 r
.60703 .29268 .61295 .3001 .62467 .29604 .61878 .28858 Mtetra
.61878 .28858 .62467 .29604 .63645 .29196 .63059 .28447 Mtetra
.63059 .28447 .63645 .29196 .64827 .28786 .64245 .28035 Mtetra
.64245 .28035 .64827 .28786 .66014 .28375 .65436 .2762 Mtetra
.65436 .2762 .66014 .28375 .67207 .27963 .66632 .27204 Mtetra
.66632 .27204 .67207 .27963 .68404 .27548 .67832 .26787 Mtetra
.67832 .26787 .68404 .27548 .69606 .27132 .69038 .26367 Mtetra
.69038 .26367 .69606 .27132 .70814 .26715 .70249 .25946 Mtetra
.70249 .25946 .70814 .26715 .72027 .26295 .71466 .25523 Mtetra
.71466 .25523 .72027 .26295 .73244 .25874 .72687 .25099 Mtetra
.72687 .25099 .73244 .25874 .74468 .25451 .73914 .24673 Mtetra
.73914 .24673 .74468 .25451 .75696 .25026 .75146 .24245 Mtetra
.75146 .24245 .75696 .25026 .76929 .246 .76383 .23815 Mtetra
.76383 .23815 .76929 .246 .78168 .24172 .77626 .23383 Mtetra
.52 .827 .505 r
.1166 .45944 .12567 .45023 .13437 .45598 .1274 .44831 Mtetra
.558 .676 .917 r
.1274 .44831 .13437 .45598 .14405 .45405 .13701 .44706 Mtetra
.582 .707 .928 r
.13701 .44706 .14405 .45405 .15358 .45388 .14673 .44524 Mtetra
.905 .712 .63 r
.14673 .44524 .15358 .45388 .16428 .44362 .16126 .40129 Mtetra
0 0 .366 r
.16126 .40129 .16428 .44362 .17396 .44278 .16699 .4356 Mtetra
.595 .707 .922 r
.16699 .4356 .17396 .44278 .18384 .44056 .17686 .43353 Mtetra
.585 .709 .929 r
.17686 .43353 .18384 .44056 .1935 .44092 .18677 .43163 Mtetra
.858 .717 .705 r
.18677 .43163 .1935 .44092 .20432 .43016 .19861 .41103 Mtetra
.107 .189 .667 r
.19861 .41103 .20432 .43016 .21422 .42885 .20732 .42167 Mtetra
.605 .713 .921 r
.20732 .42167 .21422 .42885 .2243 .42634 .21739 .41935 Mtetra
.609 .722 .925 r
.21739 .41935 .2243 .42634 .23435 .42458 .22752 .41691 Mtetra
.251 .531 .918 r
.22752 .41691 .23435 .42458 .24539 .41187 .23723 .4197 Mtetra
.682 .917 .592 r
.23723 .4197 .24539 .41187 .25517 .41418 .24839 .40651 Mtetra
.587 .694 .916 r
.24839 .40651 .25517 .41418 .26541 .41158 .25859 .40457 Mtetra
.625 .729 .922 r
.25859 .40457 .26541 .41158 .27572 .40873 .26892 .40172 Mtetra
.619 .728 .924 r
.26892 .40172 .27572 .40873 .28603 .40662 .27929 .399 Mtetra
.413 .621 .938 r
.27929 .399 .28603 .40662 .29734 .39092 .28944 .39992 Mtetra
0 0 0 r
.28944 .39992 .29734 .39092 .30721 .39601 .30054 .38808 Mtetra
.583 .688 .913 r
.30054 .38808 .30721 .39601 .31768 .39326 .31098 .38619 Mtetra
.632 .733 .921 r
.31098 .38619 .31768 .39326 .32823 .39007 .32154 .3831 Mtetra
.64 .74 .921 r
.32154 .3831 .32823 .39007 .33882 .38681 .33215 .37981 Mtetra
.638 .739 .922 r
.33215 .37981 .33882 .38681 .34945 .3837 .34282 .37655 Mtetra
.621 .73 .925 r
.34282 .37655 .34945 .3837 .36006 .38183 .3535 .3737 Mtetra
0 .263 .765 r
.3535 .3737 .36006 .38183 .3712 .37018 .36373 .38092 Mtetra
.671 .85 .442 r
.36373 .38092 .3712 .37018 .3818 .37034 .37527 .36262 Mtetra
.609 .709 .916 r
.37527 .36262 .3818 .37034 .3926 .3672 .38607 .36005 Mtetra
.642 .74 .92 r
.38607 .36005 .3926 .3672 .40347 .36368 .39696 .35663 Mtetra
.65 .747 .92 r
.39696 .35663 .40347 .36368 .41439 .36001 .4079 .35299 Mtetra
.654 .75 .92 r
.4079 .35299 .41439 .36001 .42535 .35625 .41889 .34923 Mtetra
.656 .752 .92 r
.41889 .34923 .42535 .35625 .43636 .35242 .42993 .34539 Mtetra
.658 .753 .92 r
.42993 .34539 .43636 .35242 .44742 .34854 .44101 .3415 Mtetra
.659 .753 .92 r
.44101 .3415 .44742 .34854 .45852 .34464 .45214 .33757 Mtetra
.659 .754 .92 r
.45214 .33757 .45852 .34464 .46966 .34071 .46332 .33362 Mtetra
.46332 .33362 .46966 .34071 .48085 .33677 .47454 .32965 Mtetra
.47454 .32965 .48085 .33677 .49209 .33282 .4858 .32566 Mtetra
.658 .753 .92 r
.4858 .32566 .49209 .33282 .50337 .32886 .49712 .32167 Mtetra
.49712 .32167 .50337 .32886 .5147 .32489 .50848 .31767 Mtetra
.50848 .31767 .5147 .32489 .52607 .32092 .51988 .31366 Mtetra
.51988 .31366 .52607 .32092 .5375 .31692 .53133 .30964 Mtetra
.53133 .30964 .5375 .31692 .54896 .31292 .54284 .3056 Mtetra
.54284 .3056 .54896 .31292 .56048 .3089 .55438 .30155 Mtetra
.55438 .30155 .56048 .3089 .57204 .30487 .56598 .29748 Mtetra
.657 .753 .92 r
.56598 .29748 .57204 .30487 .58366 .30082 .57762 .2934 Mtetra
.57762 .2934 .58366 .30082 .59532 .29676 .58932 .28931 Mtetra
.58932 .28931 .59532 .29676 .60703 .29268 .60106 .2852 Mtetra
.657 .752 .92 r
.60106 .2852 .60703 .29268 .61878 .28858 .61285 .28107 Mtetra
.61285 .28107 .61878 .28858 .63059 .28447 .62469 .27693 Mtetra
.62469 .27693 .63059 .28447 .64245 .28035 .63658 .27277 Mtetra
.63658 .27277 .64245 .28035 .65436 .2762 .64853 .26859 Mtetra
.64853 .26859 .65436 .2762 .66632 .27204 .66052 .2644 Mtetra
.66052 .2644 .66632 .27204 .67832 .26787 .67256 .26019 Mtetra
.67256 .26019 .67832 .26787 .69038 .26367 .68466 .25596 Mtetra
.68466 .25596 .69038 .26367 .70249 .25946 .6968 .25172 Mtetra
.6968 .25172 .70249 .25946 .71466 .25523 .709 .24746 Mtetra
.709 .24746 .71466 .25523 .72687 .25099 .72125 .24318 Mtetra
.72125 .24318 .72687 .25099 .73914 .24673 .73356 .23888 Mtetra
.73356 .23888 .73914 .24673 .75146 .24245 .74592 .23457 Mtetra
.74592 .23457 .75146 .24245 .76383 .23815 .75833 .23023 Mtetra
.75833 .23023 .76383 .23815 .77626 .23383 .77079 .22588 Mtetra
.82 .7 .732 r
.10983 .44951 .1166 .45944 .1274 .44831 .12117 .4342 Mtetra
.233 .345 .774 r
.12117 .4342 .1274 .44831 .13701 .44706 .12992 .43993 Mtetra
.591 .707 .924 r
.12992 .43993 .13701 .44706 .14673 .44524 .13968 .43794 Mtetra
.487 .662 .939 r
.13968 .43794 .14673 .44524 .16126 .40129 .14928 .43772 Mtetra
.328 .038 .31 r
.14928 .43772 .16126 .40129 .16699 .4356 .16008 .42737 Mtetra
.54 .655 .91 r
.16008 .42737 .16699 .4356 .17686 .43353 .16984 .42648 Mtetra
.603 .716 .925 r
.16984 .42648 .17686 .43353 .18677 .43163 .1798 .42419 Mtetra
.451 .643 .94 r
.1798 .42419 .18677 .43163 .19861 .41103 .18954 .42451 Mtetra
0 0 0 r
.18954 .42451 .19861 .41103 .20732 .42167 .20045 .41365 Mtetra
.561 .672 .913 r
.20045 .41365 .20732 .42167 .21739 .41935 .21044 .41229 Mtetra
.614 .723 .923 r
.21044 .41229 .21739 .41935 .22752 .41691 .2206 .40971 Mtetra
.577 .706 .93 r
.2206 .40971 .22752 .41691 .23723 .4197 .23073 .4079 Mtetra
.788 .677 .741 r
.23073 .4079 .23723 .4197 .24839 .40651 .24189 .39509 Mtetra
.403 .507 .85 r
.24189 .39509 .24839 .40651 .25859 .40457 .25174 .39736 Mtetra
.616 .721 .921 r
.25174 .39736 .25859 .40457 .26892 .40172 .26207 .39469 Mtetra
.626 .731 .923 r
.26207 .39469 .26892 .40172 .27929 .399 .27247 .39178 Mtetra
.592 .714 .928 r
.27247 .39178 .27929 .399 .28944 .39992 .28286 .3896 Mtetra
.829 .71 .733 r
.28286 .3896 .28944 .39992 .30054 .38808 .29429 .37379 Mtetra
.308 .395 .789 r
.29429 .37379 .30054 .38808 .31098 .38619 .30424 .37885 Mtetra
.62 .723 .92 r
.30424 .37885 .31098 .38619 .32154 .3831 .3148 .37603 Mtetra
.638 .738 .921 r
.3148 .37603 .32154 .3831 .33215 .37981 .32544 .37277 Mtetra
.64 .74 .921 r
.32544 .37277 .33215 .37981 .34282 .37655 .33613 .36944 Mtetra
.633 .737 .923 r
.33613 .36944 .34282 .37655 .3535 .3737 .34685 .36626 Mtetra
.578 .707 .93 r
.34685 .36626 .3535 .3737 .36373 .38092 .35756 .36433 Mtetra
.74 .613 .717 r
.35756 .36433 .36373 .38092 .37527 .36262 .36881 .35258 Mtetra
.5 .597 .883 r
.36881 .35258 .37527 .36262 .38607 .36005 .3795 .35269 Mtetra
.632 .732 .919 r
.3795 .35269 .38607 .36005 .39696 .35663 .3904 .34948 Mtetra
.647 .744 .92 r
.3904 .34948 .39696 .35663 .4079 .35299 .40137 .34589 Mtetra
.652 .748 .92 r
.40137 .34589 .4079 .35299 .41889 .34923 .41238 .34214 Mtetra
.655 .751 .92 r
.41238 .34214 .41889 .34923 .42993 .34539 .42345 .3383 Mtetra
.657 .752 .92 r
.42345 .3383 .42993 .34539 .44101 .3415 .43456 .3344 Mtetra
.658 .753 .92 r
.43456 .3344 .44101 .3415 .45214 .33757 .44572 .33045 Mtetra
.659 .754 .92 r
.44572 .33045 .45214 .33757 .46332 .33362 .45693 .32647 Mtetra
.45693 .32647 .46332 .33362 .47454 .32965 .46818 .32247 Mtetra
.46818 .32247 .47454 .32965 .4858 .32566 .47947 .31845 Mtetra
.47947 .31845 .4858 .32566 .49712 .32167 .49082 .31443 Mtetra
.658 .753 .92 r
.49082 .31443 .49712 .32167 .50848 .31767 .50221 .31039 Mtetra
.50221 .31039 .50848 .31767 .51988 .31366 .51364 .30635 Mtetra
.51364 .30635 .51988 .31366 .53133 .30964 .52513 .30229 Mtetra
.52513 .30229 .53133 .30964 .54284 .3056 .53666 .29822 Mtetra
.53666 .29822 .54284 .3056 .55438 .30155 .54824 .29414 Mtetra
.54824 .29414 .55438 .30155 .56598 .29748 .55987 .29004 Mtetra
.657 .753 .92 r
.55987 .29004 .56598 .29748 .57762 .2934 .57154 .28593 Mtetra
.57154 .28593 .57762 .2934 .58932 .28931 .58327 .2818 Mtetra
.58327 .2818 .58932 .28931 .60106 .2852 .59505 .27766 Mtetra
.59505 .27766 .60106 .2852 .61285 .28107 .60687 .2735 Mtetra
.657 .752 .92 r
.60687 .2735 .61285 .28107 .62469 .27693 .61875 .26932 Mtetra
.61875 .26932 .62469 .27693 .63658 .27277 .63067 .26513 Mtetra
.63067 .26513 .63658 .27277 .64853 .26859 .64265 .26092 Mtetra
.64265 .26092 .64853 .26859 .66052 .2644 .65468 .25669 Mtetra
.65468 .25669 .66052 .2644 .67256 .26019 .66676 .25245 Mtetra
.66676 .25245 .67256 .26019 .68466 .25596 .67889 .24819 Mtetra
.67889 .24819 .68466 .25596 .6968 .25172 .69107 .24391 Mtetra
.69107 .24391 .6968 .25172 .709 .24746 .7033 .23962 Mtetra
.7033 .23962 .709 .24746 .72125 .24318 .71559 .2353 Mtetra
.71559 .2353 .72125 .24318 .73356 .23888 .72793 .23097 Mtetra
.72793 .23097 .73356 .23888 .74592 .23457 .74033 .22662 Mtetra
.74033 .22662 .74592 .23457 .75833 .23023 .75278 .22225 Mtetra
.75278 .22225 .75833 .23023 .77079 .22588 .76528 .21787 Mtetra
.365 .6 .937 r
.1027 .44203 .10983 .44951 .12117 .4342 .11198 .44336 Mtetra
.534 .838 .519 r
.11198 .44336 .12117 .4342 .12992 .43993 .12287 .43213 Mtetra
.558 .676 .917 r
.12287 .43213 .12992 .43993 .13968 .43794 .13256 .43083 Mtetra
.582 .707 .928 r
.13256 .43083 .13968 .43794 .14928 .43772 .14236 .42896 Mtetra
.906 .712 .629 r
.14236 .42896 .14928 .43772 .16008 .42737 .15706 .38478 Mtetra
0 0 .36 r
.15706 .38478 .16008 .42737 .16984 .42648 .16279 .41918 Mtetra
.595 .707 .922 r
.16279 .41918 .16984 .42648 .1798 .42419 .17275 .41704 Mtetra
.585 .709 .929 r
.17275 .41704 .1798 .42419 .18954 .42451 .18273 .41509 Mtetra
.859 .718 .705 r
.18273 .41509 .18954 .42451 .20045 .41365 .19469 .39435 Mtetra
.103 .186 .665 r
.19469 .39435 .20045 .41365 .21044 .41229 .20347 .40499 Mtetra
.605 .713 .921 r
.20347 .40499 .21044 .41229 .2206 .40971 .21362 .4026 Mtetra
.609 .722 .925 r
.21362 .4026 .2206 .40971 .23073 .4079 .22383 .4001 Mtetra
.253 .532 .918 r
.22383 .4001 .23073 .4079 .24189 .39509 .23362 .40285 Mtetra
.691 .923 .601 r
.23362 .40285 .24189 .39509 .25174 .39736 .24488 .38956 Mtetra
.587 .694 .916 r
.24488 .38956 .25174 .39736 .26207 .39469 .25518 .38756 Mtetra
.625 .729 .922 r
.25518 .38756 .26207 .39469 .27247 .39178 .2656 .38464 Mtetra
.619 .728 .924 r
.2656 .38464 .27247 .39178 .28286 .3896 .27605 .38186 Mtetra
.414 .621 .937 r
.27605 .38186 .28286 .3896 .29429 .37379 .28628 .38272 Mtetra
0 0 0 r
.28628 .38272 .29429 .37379 .30424 .37885 .2975 .37078 Mtetra
.583 .688 .913 r
.2975 .37078 .30424 .37885 .3148 .37603 .30802 .36883 Mtetra
.632 .733 .921 r
.30802 .36883 .3148 .37603 .32544 .37277 .31868 .36567 Mtetra
.64 .74 .921 r
.31868 .36567 .32544 .37277 .33613 .36944 .32939 .36232 Mtetra
.638 .739 .922 r
.32939 .36232 .33613 .36944 .34685 .36626 .34015 .35899 Mtetra
.621 .73 .925 r
.34015 .35899 .34685 .36626 .35756 .36433 .35093 .35607 Mtetra
0 .267 .769 r
.35093 .35607 .35756 .36433 .36881 .35258 .36124 .36326 Mtetra
.68 .857 .452 r
.36124 .36326 .36881 .35258 .3795 .35269 .3729 .34483 Mtetra
.609 .709 .916 r
.3729 .34483 .3795 .35269 .3904 .34948 .3838 .34219 Mtetra
.642 .74 .92 r
.3838 .34219 .3904 .34948 .40137 .34589 .39479 .3387 Mtetra
.65 .747 .92 r
.39479 .3387 .40137 .34589 .41238 .34214 .40583 .33498 Mtetra
.654 .75 .92 r
.40583 .33498 .41238 .34214 .42345 .3383 .41692 .33115 Mtetra
.656 .752 .92 r
.41692 .33115 .42345 .3383 .43456 .3344 .42806 .32724 Mtetra
.658 .753 .92 r
.42806 .32724 .43456 .3344 .44572 .33045 .43925 .32328 Mtetra
.659 .753 .92 r
.43925 .32328 .44572 .33045 .45693 .32647 .45048 .31927 Mtetra
.659 .754 .92 r
.45048 .31927 .45693 .32647 .46818 .32247 .46176 .31524 Mtetra
.46176 .31524 .46818 .32247 .47947 .31845 .47309 .31119 Mtetra
.47309 .31119 .47947 .31845 .49082 .31443 .48447 .30713 Mtetra
.658 .753 .92 r
.48447 .30713 .49082 .31443 .50221 .31039 .49589 .30306 Mtetra
.49589 .30306 .50221 .31039 .51364 .30635 .50735 .29898 Mtetra
.50735 .29898 .51364 .30635 .52513 .30229 .51887 .29489 Mtetra
.51887 .29489 .52513 .30229 .53666 .29822 .53043 .29079 Mtetra
.53043 .29079 .53666 .29822 .54824 .29414 .54205 .28667 Mtetra
.54205 .28667 .54824 .29414 .55987 .29004 .55371 .28254 Mtetra
.55371 .28254 .55987 .29004 .57154 .28593 .56542 .2784 Mtetra
.657 .753 .92 r
.56542 .2784 .57154 .28593 .58327 .2818 .57718 .27424 Mtetra
.57718 .27424 .58327 .2818 .59505 .27766 .58899 .27006 Mtetra
.58899 .27006 .59505 .27766 .60687 .2735 .60084 .26587 Mtetra
.657 .752 .92 r
.60084 .26587 .60687 .2735 .61875 .26932 .61275 .26166 Mtetra
.61275 .26166 .61875 .26932 .63067 .26513 .62471 .25743 Mtetra
.62471 .25743 .63067 .26513 .64265 .26092 .63673 .25319 Mtetra
.63673 .25319 .64265 .26092 .65468 .25669 .64879 .24893 Mtetra
.64879 .24893 .65468 .25669 .66676 .25245 .6609 .24465 Mtetra
.6609 .24465 .66676 .25245 .67889 .24819 .67307 .24036 Mtetra
.67307 .24036 .67889 .24819 .69107 .24391 .68529 .23605 Mtetra
.68529 .23605 .69107 .24391 .7033 .23962 .69756 .23172 Mtetra
.69756 .23172 .7033 .23962 .71559 .2353 .70989 .22737 Mtetra
.70989 .22737 .71559 .2353 .72793 .23097 .72226 .223 Mtetra
.72226 .223 .72793 .23097 .74033 .22662 .7347 .21862 Mtetra
.7347 .21862 .74033 .22662 .75278 .22225 .74718 .21421 Mtetra
.74718 .21421 .75278 .22225 .76528 .21787 .75972 .20979 Mtetra
.565 .698 .931 r
.09548 .43484 .1027 .44203 .11198 .44336 .10513 .4333 Mtetra
.821 .701 .733 r
.10513 .4333 .11198 .44336 .12287 .43213 .11658 .41788 Mtetra
.231 .344 .773 r
.11658 .41788 .12287 .43213 .13256 .43083 .12539 .42358 Mtetra
.591 .707 .924 r
.12539 .42358 .13256 .43083 .14236 .42896 .13523 .42153 Mtetra
.487 .662 .939 r
.13523 .42153 .14236 .42896 .15706 .38478 .14491 .42126 Mtetra
.32 .027 .302 r
.14491 .42126 .15706 .38478 .16279 .41918 .1558 .41082 Mtetra
.539 .655 .911 r
.1558 .41082 .16279 .41918 .17275 .41704 .16564 .40987 Mtetra
.603 .716 .925 r
.16564 .40987 .17275 .41704 .18273 .41509 .17568 .40753 Mtetra
.451 .643 .94 r
.17568 .40753 .18273 .41509 .19469 .39435 .1855 .40779 Mtetra
0 0 0 r
.1855 .40779 .19469 .39435 .20347 .40499 .19652 .39684 Mtetra
.561 .672 .913 r
.19652 .39684 .20347 .40499 .21362 .4026 .20659 .39542 Mtetra
.614 .723 .923 r
.20659 .39542 .21362 .4026 .22383 .4001 .21684 .39278 Mtetra
.577 .706 .93 r
.21684 .39278 .22383 .4001 .23362 .40285 .22706 .39091 Mtetra
.788 .677 .742 r
.22706 .39091 .23362 .40285 .24488 .38956 .23831 .37799 Mtetra
.402 .507 .851 r
.23831 .37799 .24488 .38956 .25518 .38756 .24825 .38021 Mtetra
.616 .721 .921 r
.24825 .38021 .25518 .38756 .2656 .38464 .25867 .37748 Mtetra
.626 .731 .923 r
.25867 .37748 .2656 .38464 .27605 .38186 .26916 .37451 Mtetra
.592 .714 .928 r
.26916 .37451 .27605 .38186 .28628 .38272 .27964 .37226 Mtetra
.83 .711 .733 r
.27964 .37226 .28628 .38272 .2975 .37078 .29118 .35634 Mtetra
.306 .394 .789 r
.29118 .35634 .2975 .37078 .30802 .36883 .30121 .36136 Mtetra
.62 .723 .92 r
.30121 .36136 .30802 .36883 .31868 .36567 .31187 .35847 Mtetra
.638 .738 .921 r
.31187 .35847 .31868 .36567 .32939 .36232 .3226 .35515 Mtetra
.64 .74 .921 r
.3226 .35515 .32939 .36232 .34015 .35899 .33339 .35175 Mtetra
.633 .737 .923 r
.33339 .35175 .34015 .35899 .35093 .35607 .34421 .3485 Mtetra
.578 .707 .93 r
.34421 .3485 .35093 .35607 .36124 .36326 .35501 .3465 Mtetra
.74 .613 .717 r
.35501 .3465 .36124 .36326 .3729 .34483 .36637 .33465 Mtetra
.499 .597 .883 r
.36637 .33465 .3729 .34483 .3838 .34219 .37715 .33469 Mtetra
.632 .732 .919 r
.37715 .33469 .3838 .34219 .39479 .3387 .38816 .33141 Mtetra
.647 .744 .92 r
.38816 .33141 .39479 .3387 .40583 .33498 .39922 .32774 Mtetra
.652 .748 .92 r
.39922 .32774 .40583 .33498 .41692 .33115 .41034 .32392 Mtetra
.655 .751 .92 r
.41034 .32392 .41692 .33115 .42806 .32724 .42151 .32001 Mtetra
.657 .752 .92 r
.42151 .32001 .42806 .32724 .43925 .32328 .43273 .31604 Mtetra
.658 .753 .92 r
.43273 .31604 .43925 .32328 .45048 .31927 .44399 .31201 Mtetra
.659 .754 .92 r
.44399 .31201 .45048 .31927 .46176 .31524 .4553 .30795 Mtetra
.4553 .30795 .46176 .31524 .47309 .31119 .46666 .30387 Mtetra
.46666 .30387 .47309 .31119 .48447 .30713 .47807 .29978 Mtetra
.47807 .29978 .48447 .30713 .49589 .30306 .48952 .29567 Mtetra
.658 .753 .92 r
.48952 .29567 .49589 .30306 .50735 .29898 .50102 .29156 Mtetra
.50102 .29156 .50735 .29898 .51887 .29489 .51256 .28744 Mtetra
.51256 .28744 .51887 .29489 .53043 .29079 .52416 .2833 Mtetra
.52416 .2833 .53043 .29079 .54205 .28667 .53581 .27915 Mtetra
.53581 .27915 .54205 .28667 .55371 .28254 .5475 .27499 Mtetra
.5475 .27499 .55371 .28254 .56542 .2784 .55924 .27081 Mtetra
.657 .753 .92 r
.55924 .27081 .56542 .2784 .57718 .27424 .57103 .26661 Mtetra
.57103 .26661 .57718 .27424 .58899 .27006 .58288 .2624 Mtetra
.58288 .2624 .58899 .27006 .60084 .26587 .59477 .25818 Mtetra
.59477 .25818 .60084 .26587 .61275 .26166 .60671 .25393 Mtetra
.657 .752 .92 r
.60671 .25393 .61275 .26166 .62471 .25743 .61871 .24967 Mtetra
.61871 .24967 .62471 .25743 .63673 .25319 .63076 .2454 Mtetra
.63076 .2454 .63673 .25319 .64879 .24893 .64285 .2411 Mtetra
.64285 .2411 .64879 .24893 .6609 .24465 .655 .23679 Mtetra
.655 .23679 .6609 .24465 .67307 .24036 .66721 .23246 Mtetra
.66721 .23246 .67307 .24036 .68529 .23605 .67946 .22811 Mtetra
.67946 .22811 .68529 .23605 .69756 .23172 .69177 .22375 Mtetra
.69177 .22375 .69756 .23172 .70989 .22737 .70413 .21937 Mtetra
.70413 .21937 .70989 .22737 .72226 .223 .71655 .21496 Mtetra
.71655 .21496 .72226 .223 .7347 .21862 .72902 .21054 Mtetra
.72902 .21054 .7347 .21862 .74718 .21421 .74154 .2061 Mtetra
.74154 .2061 .74718 .21421 .75972 .20979 .75412 .20165 Mtetra
.58 .7 .925 r
.08822 .42752 .09548 .43484 .10513 .4333 .09792 .42569 Mtetra
.366 .6 .937 r
.09792 .42569 .10513 .4333 .11658 .41788 .10726 .42698 Mtetra
.548 .848 .532 r
.10726 .42698 .11658 .41788 .12539 .42358 .11826 .41566 Mtetra
.558 .676 .917 r
.11826 .41566 .12539 .42358 .13523 .42153 .12802 .4143 Mtetra
.582 .707 .928 r
.12802 .4143 .13523 .42153 .14491 .42126 .13791 .41237 Mtetra
.907 .713 .628 r
.13791 .41237 .14491 .42126 .1558 .41082 .15279 .36797 Mtetra
0 0 .355 r
.15279 .36797 .1558 .41082 .16564 .40987 .15851 .40245 Mtetra
.595 .707 .922 r
.15851 .40245 .16564 .40987 .17568 .40753 .16855 .40025 Mtetra
.585 .709 .929 r
.16855 .40025 .17568 .40753 .1855 .40779 .17862 .39824 Mtetra
.86 .719 .705 r
.17862 .39824 .1855 .40779 .19652 .39684 .19071 .37736 Mtetra
.099 .183 .664 r
.19071 .37736 .19652 .39684 .20659 .39542 .19954 .38799 Mtetra
.605 .713 .921 r
.19954 .38799 .20659 .39542 .21684 .39278 .20978 .38554 Mtetra
.609 .722 .925 r
.20978 .38554 .21684 .39278 .22706 .39091 .22008 .38298 Mtetra
.256 .532 .918 r
.22008 .38298 .22706 .39091 .23831 .37799 .22994 .38568 Mtetra
.7 .929 .61 r
.22994 .38568 .23831 .37799 .24825 .38021 .24131 .37228 Mtetra
.586 .694 .916 r
.24131 .37228 .24825 .38021 .25867 .37748 .2517 .37022 Mtetra
.625 .729 .922 r
.2517 .37022 .25867 .37748 .26916 .37451 .26221 .36724 Mtetra
.619 .728 .924 r
.26221 .36724 .26916 .37451 .27964 .37226 .27276 .36439 Mtetra
.414 .621 .937 r
.27276 .36439 .27964 .37226 .29118 .35634 .28307 .3652 Mtetra
0 0 0 r
.28307 .3652 .29118 .35634 .30121 .36136 .2944 .35315 Mtetra
.583 .688 .914 r
.2944 .35315 .30121 .36136 .31187 .35847 .30501 .35113 Mtetra
.632 .733 .921 r
.30501 .35113 .31187 .35847 .3226 .35515 .31576 .34791 Mtetra
.64 .74 .921 r
.31576 .34791 .3226 .35515 .33339 .35175 .32657 .34449 Mtetra
.638 .739 .922 r
.32657 .34449 .33339 .35175 .34421 .3485 .33743 .34108 Mtetra
.621 .73 .924 r
.33743 .34108 .34421 .3485 .35501 .3465 .34831 .3381 Mtetra
0 .27 .772 r
.34831 .3381 .35501 .3465 .36637 .33465 .3587 .34525 Mtetra
.688 .863 .461 r
.3587 .34525 .36637 .33465 .37715 .33469 .37048 .32669 Mtetra
.608 .709 .916 r
.37048 .32669 .37715 .33469 .38816 .33141 .38148 .32399 Mtetra
.642 .74 .92 r
.38148 .32399 .38816 .33141 .39922 .32774 .39257 .32042 Mtetra
.65 .747 .92 r
.39257 .32042 .39922 .32774 .41034 .32392 .40371 .31663 Mtetra
.654 .75 .92 r
.40371 .31663 .41034 .32392 .42151 .32001 .41491 .31272 Mtetra
.656 .752 .92 r
.41491 .31272 .42151 .32001 .43273 .31604 .42616 .30873 Mtetra
.658 .753 .92 r
.42616 .30873 .43273 .31604 .44399 .31201 .43745 .30469 Mtetra
.659 .753 .92 r
.43745 .30469 .44399 .31201 .4553 .30795 .44879 .30061 Mtetra
.659 .754 .92 r
.44879 .30061 .4553 .30795 .46666 .30387 .46018 .2965 Mtetra
.46018 .2965 .46666 .30387 .47807 .29978 .47162 .29237 Mtetra
.47162 .29237 .47807 .29978 .48952 .29567 .4831 .28823 Mtetra
.658 .753 .92 r
.4831 .28823 .48952 .29567 .50102 .29156 .49463 .28408 Mtetra
.49463 .28408 .50102 .29156 .51256 .28744 .50621 .27992 Mtetra
.50621 .27992 .51256 .28744 .52416 .2833 .51784 .27575 Mtetra
.51784 .27575 .52416 .2833 .53581 .27915 .52951 .27157 Mtetra
.52951 .27157 .53581 .27915 .5475 .27499 .54124 .26737 Mtetra
.54124 .26737 .5475 .27499 .55924 .27081 .55302 .26316 Mtetra
.55302 .26316 .55924 .27081 .57103 .26661 .56484 .25893 Mtetra
.657 .753 .92 r
.56484 .25893 .57103 .26661 .58288 .2624 .57672 .25469 Mtetra
.57672 .25469 .58288 .2624 .59477 .25818 .58865 .25043 Mtetra
.58865 .25043 .59477 .25818 .60671 .25393 .60063 .24615 Mtetra
.657 .752 .92 r
.60063 .24615 .60671 .25393 .61871 .24967 .61266 .24185 Mtetra
.61266 .24185 .61871 .24967 .63076 .2454 .62474 .23754 Mtetra
.62474 .23754 .63076 .2454 .64285 .2411 .63687 .23321 Mtetra
.63687 .23321 .64285 .2411 .655 .23679 .64906 .22887 Mtetra
.64906 .22887 .655 .23679 .66721 .23246 .66129 .2245 Mtetra
.66129 .2245 .66721 .23246 .67946 .22811 .67359 .22012 Mtetra
.67359 .22012 .67946 .22811 .69177 .22375 .68593 .21572 Mtetra
.68593 .21572 .69177 .22375 .70413 .21937 .69833 .2113 Mtetra
.69833 .2113 .70413 .21937 .71655 .21496 .71078 .20686 Mtetra
.71078 .20686 .71655 .21496 .72902 .21054 .72329 .20241 Mtetra
.72329 .20241 .72902 .21054 .74154 .2061 .73586 .19793 Mtetra
.73586 .19793 .74154 .2061 .75412 .20165 .74847 .19344 Mtetra
.535 .657 .915 r
.08103 .4193 .08822 .42752 .09792 .42569 .09061 .41839 Mtetra
.565 .698 .93 r
.09061 .41839 .09792 .42569 .10726 .42698 .10034 .41679 Mtetra
.821 .702 .733 r
.10034 .41679 .10726 .42698 .11826 .41566 .1119 .40125 Mtetra
.228 .343 .773 r
.1119 .40125 .11826 .41566 .12802 .4143 .12078 .40693 Mtetra
.591 .707 .924 r
.12078 .40693 .12802 .4143 .13791 .41237 .1307 .40482 Mtetra
.488 .662 .939 r
.1307 .40482 .13791 .41237 .15279 .36797 .14045 .4045 Mtetra
.311 .017 .293 r
.14045 .4045 .15279 .36797 .15851 .40245 .15145 .39396 Mtetra
.539 .655 .911 r
.15145 .39396 .15851 .40245 .16855 .40025 .16137 .39296 Mtetra
.603 .716 .925 r
.16137 .39296 .16855 .40025 .17862 .39824 .17149 .39055 Mtetra
.452 .643 .939 r
.17149 .39055 .17862 .39824 .19071 .37736 .18139 .39076 Mtetra
0 0 0 r
.18139 .39076 .19071 .37736 .19954 .38799 .19251 .37971 Mtetra
.56 .672 .913 r
.19251 .37971 .19954 .38799 .20978 .38554 .20267 .37824 Mtetra
.614 .723 .923 r
.20267 .37824 .20978 .38554 .22008 .38298 .213 .37553 Mtetra
.577 .706 .93 r
.213 .37553 .22008 .38298 .22994 .38568 .22331 .37359 Mtetra
.789 .678 .742 r
.22331 .37359 .22994 .38568 .24131 .37228 .23468 .36057 Mtetra
.401 .507 .851 r
.23468 .36057 .24131 .37228 .2517 .37022 .24469 .36274 Mtetra
.616 .721 .921 r
.24469 .36274 .2517 .37022 .26221 .36724 .2552 .35994 Mtetra
.626 .731 .923 r
.2552 .35994 .26221 .36724 .27276 .36439 .26579 .3569 Mtetra
.593 .714 .928 r
.26579 .3569 .27276 .36439 .28307 .3652 .27636 .3546 Mtetra
.831 .712 .734 r
.27636 .3546 .28307 .3652 .2944 .35315 .28801 .33855 Mtetra
.304 .393 .789 r
.28801 .33855 .2944 .35315 .30501 .35113 .29812 .34353 Mtetra
.62 .723 .92 r
.29812 .34353 .30501 .35113 .31576 .34791 .30888 .34058 Mtetra
.638 .738 .921 r
.30888 .34058 .31576 .34791 .32657 .34449 .31971 .33718 Mtetra
.64 .74 .921 r
.31971 .33718 .32657 .34449 .33743 .34108 .33059 .33371 Mtetra
.633 .737 .923 r
.33059 .33371 .33743 .34108 .34831 .3381 .34151 .33038 Mtetra
.578 .707 .93 r
.34151 .33038 .34831 .3381 .3587 .34525 .35241 .32832 Mtetra
.74 .613 .717 r
.35241 .32832 .3587 .34525 .37048 .32669 .36388 .31636 Mtetra
.499 .597 .883 r
.36388 .31636 .37048 .32669 .38148 .32399 .37476 .31634 Mtetra
.632 .732 .919 r
.37476 .31634 .38148 .32399 .39257 .32042 .38587 .31299 Mtetra
.647 .744 .92 r
.38587 .31299 .39257 .32042 .40371 .31663 .39704 .30925 Mtetra
.652 .748 .92 r
.39704 .30925 .40371 .31663 .41491 .31272 .40826 .30535 Mtetra
.655 .751 .92 r
.40826 .30535 .41491 .31272 .42616 .30873 .41954 .30136 Mtetra
.657 .752 .92 r
.41954 .30136 .42616 .30873 .43745 .30469 .43086 .29731 Mtetra
.658 .753 .92 r
.43086 .29731 .43745 .30469 .44879 .30061 .44223 .2932 Mtetra
.659 .754 .92 r
.44223 .2932 .44879 .30061 .46018 .2965 .45365 .28906 Mtetra
.45365 .28906 .46018 .2965 .47162 .29237 .46512 .28491 Mtetra
.46512 .28491 .47162 .29237 .4831 .28823 .47663 .28073 Mtetra
.47663 .28073 .4831 .28823 .49463 .28408 .48819 .27655 Mtetra
.658 .753 .92 r
.48819 .27655 .49463 .28408 .50621 .27992 .49981 .27235 Mtetra
.49981 .27235 .50621 .27992 .51784 .27575 .51147 .26815 Mtetra
.51147 .26815 .51784 .27575 .52951 .27157 .52318 .26393 Mtetra
.52318 .26393 .52951 .27157 .54124 .26737 .53493 .2597 Mtetra
.53493 .2597 .54124 .26737 .55302 .26316 .54674 .25545 Mtetra
.54674 .25545 .55302 .26316 .56484 .25893 .5586 .25119 Mtetra
.657 .753 .92 r
.5586 .25119 .56484 .25893 .57672 .25469 .57051 .24691 Mtetra
.57051 .24691 .57672 .25469 .58865 .25043 .58248 .24261 Mtetra
.58248 .24261 .58865 .25043 .60063 .24615 .59449 .2383 Mtetra
.59449 .2383 .60063 .24615 .61266 .24185 .60655 .23397 Mtetra
.657 .752 .92 r
.60655 .23397 .61266 .24185 .62474 .23754 .61867 .22962 Mtetra
.61867 .22962 .62474 .23754 .63687 .23321 .63084 .22526 Mtetra
.63084 .22526 .63687 .23321 .64906 .22887 .64306 .22088 Mtetra
.64306 .22088 .64906 .22887 .66129 .2245 .65534 .21648 Mtetra
.65534 .21648 .66129 .2245 .67359 .22012 .66766 .21206 Mtetra
.66766 .21206 .67359 .22012 .68593 .21572 .68005 .20762 Mtetra
.68005 .20762 .68593 .21572 .69833 .2113 .69248 .20317 Mtetra
.69248 .20317 .69833 .2113 .71078 .20686 .70498 .1987 Mtetra
.70498 .1987 .71078 .20686 .72329 .20241 .71752 .1942 Mtetra
.71752 .1942 .72329 .20241 .73586 .19793 .73012 .18969 Mtetra
.73012 .18969 .73586 .19793 .74847 .19344 .74278 .18516 Mtetra
0 0 .503 r
.07622 .3936 .08103 .4193 .09061 .41839 .08327 .41094 Mtetra
.58 .7 .925 r
.08327 .41094 .09061 .41839 .10034 .41679 .09305 .40906 Mtetra
.367 .6 .937 r
.09305 .40906 .10034 .41679 .1119 .40125 .10246 .4103 Mtetra
.561 .859 .546 r
.10246 .4103 .1119 .40125 .12078 .40693 .11356 .39888 Mtetra
.558 .676 .917 r
.11356 .39888 .12078 .40693 .1307 .40482 .12341 .39746 Mtetra
.582 .707 .928 r
.12341 .39746 .1307 .40482 .14045 .4045 .13337 .39547 Mtetra
.908 .714 .627 r
.13337 .39547 .14045 .4045 .15145 .39396 .14844 .35084 Mtetra
0 0 .35 r
.14844 .35084 .15145 .39396 .16137 .39296 .15415 .3854 Mtetra
.595 .707 .922 r
.15415 .3854 .16137 .39296 .17149 .39055 .16428 .38315 Mtetra
.585 .709 .929 r
.16428 .38315 .17149 .39055 .18139 .39076 .17443 .38107 Mtetra
.861 .719 .705 r
.17443 .38107 .18139 .39076 .19251 .37971 .18665 .36006 Mtetra
.095 .18 .663 r
.18665 .36006 .19251 .37971 .20267 .37824 .19553 .37068 Mtetra
.605 .713 .921 r
.19553 .37068 .20267 .37824 .213 .37553 .20586 .36816 Mtetra
.609 .722 .925 r
.20586 .36816 .213 .37553 .22331 .37359 .21625 .36553 Mtetra
.258 .533 .918 r
.21625 .36553 .22331 .37359 .23468 .36057 .22619 .36819 Mtetra
.708 .934 .619 r
.22619 .36819 .23468 .36057 .24469 .36274 .23768 .35468 Mtetra
.586 .694 .916 r
.23768 .35468 .24469 .36274 .2552 .35994 .24815 .35255 Mtetra
.625 .729 .922 r
.24815 .35255 .2552 .35994 .26579 .3569 .25875 .3495 Mtetra
.619 .728 .924 r
.25875 .3495 .26579 .3569 .27636 .3546 .2694 .34658 Mtetra
.415 .621 .937 r
.2694 .34658 .27636 .3546 .28801 .33855 .2798 .34734 Mtetra
0 0 0 r
.2798 .34734 .28801 .33855 .29812 .34353 .29123 .33519 Mtetra
.583 .688 .914 r
.29123 .33519 .29812 .34353 .30888 .34058 .30194 .3331 Mtetra
.632 .733 .921 r
.30194 .3331 .30888 .34058 .31971 .33718 .31279 .3298 Mtetra
.64 .74 .921 r
.31279 .3298 .31971 .33718 .33059 .33371 .3237 .32631 Mtetra
.638 .739 .922 r
.3237 .32631 .33059 .33371 .34151 .33038 .33465 .32283 Mtetra
.621 .73 .924 r
.33465 .32283 .34151 .33038 .35241 .32832 .34563 .31977 Mtetra
0 .274 .775 r
.34563 .31977 .35241 .32832 .36388 .31636 .35612 .32689 Mtetra
.697 .87 .47 r
.35612 .32689 .36388 .31636 .37476 .31634 .36802 .3082 Mtetra
.608 .709 .916 r
.36802 .3082 .37476 .31634 .38587 .31299 .37912 .30543 Mtetra
.642 .74 .92 r
.37912 .30543 .38587 .31299 .39704 .30925 .39031 .30178 Mtetra
.65 .747 .92 r
.39031 .30178 .39704 .30925 .40826 .30535 .40156 .29791 Mtetra
.654 .75 .92 r
.40156 .29791 .40826 .30535 .41954 .30136 .41286 .29392 Mtetra
.656 .752 .92 r
.41286 .29392 .41954 .30136 .43086 .29731 .42422 .28986 Mtetra
.658 .753 .92 r
.42422 .28986 .43086 .29731 .44223 .2932 .43562 .28574 Mtetra
.659 .753 .92 r
.43562 .28574 .44223 .2932 .45365 .28906 .44707 .28157 Mtetra
.659 .754 .92 r
.44707 .28157 .45365 .28906 .46512 .28491 .45856 .27738 Mtetra
.45856 .27738 .46512 .28491 .47663 .28073 .47011 .27317 Mtetra
.47011 .27317 .47663 .28073 .48819 .27655 .48171 .26895 Mtetra
.658 .753 .92 r
.48171 .26895 .48819 .27655 .49981 .27235 .49335 .26472 Mtetra
.49335 .26472 .49981 .27235 .51147 .26815 .50504 .26048 Mtetra
.50504 .26048 .51147 .26815 .52318 .26393 .51678 .25623 Mtetra
.51678 .25623 .52318 .26393 .53493 .2597 .52858 .25196 Mtetra
.52858 .25196 .53493 .2597 .54674 .25545 .54042 .24768 Mtetra
.54042 .24768 .54674 .25545 .5586 .25119 .55231 .24338 Mtetra
.55231 .24338 .5586 .25119 .57051 .24691 .56426 .23907 Mtetra
.657 .753 .92 r
.56426 .23907 .57051 .24691 .58248 .24261 .57625 .23474 Mtetra
.57625 .23474 .58248 .24261 .59449 .2383 .5883 .23039 Mtetra
.5883 .23039 .59449 .2383 .60655 .23397 .6004 .22603 Mtetra
.657 .752 .92 r
.6004 .22603 .60655 .23397 .61867 .22962 .61255 .22164 Mtetra
.61255 .22164 .61867 .22962 .63084 .22526 .62476 .21724 Mtetra
.62476 .21724 .63084 .22526 .64306 .22088 .63702 .21283 Mtetra
.63702 .21283 .64306 .22088 .65534 .21648 .64933 .20839 Mtetra
.64933 .20839 .65534 .21648 .66766 .21206 .66169 .20394 Mtetra
.66169 .20394 .66766 .21206 .68005 .20762 .67411 .19946 Mtetra
.67411 .19946 .68005 .20762 .69248 .20317 .68659 .19497 Mtetra
.68659 .19497 .69248 .20317 .70498 .1987 .69912 .19046 Mtetra
.69912 .19046 .70498 .1987 .71752 .1942 .7117 .18593 Mtetra
.7117 .18593 .71752 .1942 .73012 .18969 .72434 .18138 Mtetra
.72434 .18138 .73012 .18969 .74278 .18516 .73704 .17681 Mtetra
.04 0 .018 r
.06504 .41309 .07622 .3936 .08327 .41094 .076 .40259 Mtetra
.534 .657 .915 r
.076 .40259 .08327 .41094 .09305 .40906 .08566 .40163 Mtetra
.566 .698 .93 r
.08566 .40163 .09305 .40906 .10246 .4103 .09546 .39997 Mtetra
.822 .702 .733 r
.09546 .39997 .10246 .4103 .11356 .39888 .10714 .38432 Mtetra
.226 .341 .773 r
.10714 .38432 .11356 .39888 .12341 .39746 .11608 .38996 Mtetra
.591 .707 .924 r
.11608 .38996 .12341 .39746 .13337 .39547 .12608 .38779 Mtetra
.488 .662 .939 r
.12608 .38779 .13337 .39547 .14844 .35084 .13591 .38741 Mtetra
.302 .005 .284 r
.13591 .38741 .14844 .35084 .15415 .3854 .14701 .37679 Mtetra
.539 .655 .911 r
.14701 .37679 .15415 .3854 .16428 .38315 .15701 .37572 Mtetra
.603 .716 .925 r
.15701 .37572 .16428 .38315 .17443 .38107 .16722 .37325 Mtetra
.452 .643 .939 r
.16722 .37325 .17443 .38107 .18665 .36006 .1772 .37341 Mtetra
0 0 0 r
.1772 .37341 .18665 .36006 .19553 .37068 .18843 .36226 Mtetra
.56 .672 .913 r
.18843 .36226 .19553 .37068 .20586 .36816 .19867 .36072 Mtetra
.614 .723 .923 r
.19867 .36072 .20586 .36816 .21625 .36553 .20909 .35795 Mtetra
.577 .706 .93 r
.20909 .35795 .21625 .36553 .22619 .36819 .21949 .35595 Mtetra
.789 .679 .742 r
.21949 .35595 .22619 .36819 .23768 .35468 .23097 .34281 Mtetra
.4 .506 .851 r
.23097 .34281 .23768 .35468 .24815 .35255 .24106 .34494 Mtetra
.616 .721 .921 r
.24106 .34494 .24815 .35255 .25875 .3495 .25167 .34207 Mtetra
.626 .731 .923 r
.25167 .34207 .25875 .3495 .2694 .34658 .26235 .33896 Mtetra
.593 .714 .928 r
.26235 .33896 .2694 .34658 .2798 .34734 .27301 .33658 Mtetra
.831 .713 .734 r
.27301 .33658 .2798 .34734 .29123 .33519 .28478 .32041 Mtetra
.302 .392 .789 r
.28478 .32041 .29123 .33519 .30194 .3331 .29498 .32536 Mtetra
.62 .723 .92 r
.29498 .32536 .30194 .3331 .31279 .3298 .30583 .32233 Mtetra
.638 .738 .921 r
.30583 .32233 .31279 .3298 .3237 .32631 .31676 .31886 Mtetra
.64 .74 .921 r
.31676 .31886 .3237 .32631 .33465 .32283 .32774 .31531 Mtetra
.633 .737 .923 r
.32774 .31531 .33465 .32283 .34563 .31977 .33876 .31192 Mtetra
.578 .707 .93 r
.33876 .31192 .34563 .31977 .35612 .32689 .34976 .30978 Mtetra
.741 .614 .717 r
.34976 .30978 .35612 .32689 .36802 .3082 .36134 .29771 Mtetra
.498 .597 .883 r
.36134 .29771 .36802 .3082 .37912 .30543 .37232 .29764 Mtetra
.632 .732 .919 r
.37232 .29764 .37912 .30543 .39031 .30178 .38353 .29421 Mtetra
.647 .744 .92 r
.38353 .29421 .39031 .30178 .40156 .29791 .39481 .29039 Mtetra
.652 .748 .92 r
.39481 .29039 .40156 .29791 .41286 .29392 .40614 .28641 Mtetra
.655 .751 .92 r
.40614 .28641 .41286 .29392 .42422 .28986 .41752 .28234 Mtetra
.657 .752 .92 r
.41752 .28234 .42422 .28986 .43562 .28574 .42895 .27821 Mtetra
.658 .753 .92 r
.42895 .27821 .43562 .28574 .44707 .28157 .44043 .27402 Mtetra
.659 .754 .92 r
.44043 .27402 .44707 .28157 .45856 .27738 .45196 .2698 Mtetra
.45196 .2698 .45856 .27738 .47011 .27317 .46354 .26556 Mtetra
.46354 .26556 .47011 .27317 .48171 .26895 .47517 .2613 Mtetra
.47517 .2613 .48171 .26895 .49335 .26472 .48684 .25704 Mtetra
.658 .753 .92 r
.48684 .25704 .49335 .26472 .50504 .26048 .49857 .25276 Mtetra
.49857 .25276 .50504 .26048 .51678 .25623 .51034 .24847 Mtetra
.51034 .24847 .51678 .25623 .52858 .25196 .52217 .24416 Mtetra
.52217 .24416 .52858 .25196 .54042 .24768 .53405 .23985 Mtetra
.53405 .23985 .54042 .24768 .55231 .24338 .54597 .23551 Mtetra
.54597 .23551 .55231 .24338 .56426 .23907 .55795 .23116 Mtetra
.657 .753 .92 r
.55795 .23116 .56426 .23907 .57625 .23474 .56998 .2268 Mtetra
.56998 .2268 .57625 .23474 .5883 .23039 .58207 .22242 Mtetra
.58207 .22242 .5883 .23039 .6004 .22603 .5942 .21802 Mtetra
.5942 .21802 .6004 .22603 .61255 .22164 .60639 .2136 Mtetra
.657 .752 .92 r
.60639 .2136 .61255 .22164 .62476 .21724 .61863 .20916 Mtetra
.61863 .20916 .62476 .21724 .63702 .21283 .63092 .20471 Mtetra
.63092 .20471 .63702 .21283 .64933 .20839 .64327 .20024 Mtetra
.64327 .20024 .64933 .20839 .66169 .20394 .65568 .19575 Mtetra
.65568 .19575 .66169 .20394 .67411 .19946 .66813 .19124 Mtetra
.66813 .19124 .67411 .19946 .68659 .19497 .68065 .18671 Mtetra
.68065 .18671 .68659 .19497 .69912 .19046 .69321 .18216 Mtetra
.69321 .18216 .69912 .19046 .7117 .18593 .70584 .17759 Mtetra
.70584 .17759 .7117 .18593 .72434 .18138 .71852 .17301 Mtetra
.71852 .17301 .72434 .18138 .73704 .17681 .73125 .1684 Mtetra
.876 .714 .678 r
.05782 .40379 .06504 .41309 .076 .40259 .07116 .3767 Mtetra
0 0 .499 r
.07116 .3767 .076 .40259 .08566 .40163 .07823 .39405 Mtetra
.58 .7 .925 r
.07823 .39405 .08566 .40163 .09546 .39997 .08809 .39211 Mtetra
.368 .6 .937 r
.08809 .39211 .09546 .39997 .10714 .38432 .09757 .3933 Mtetra
.574 .869 .559 r
.09757 .3933 .10714 .38432 .11608 .38996 .10878 .38179 Mtetra
.558 .676 .917 r
.10878 .38179 .11608 .38996 .12608 .38779 .1187 .38031 Mtetra
.582 .707 .928 r
.1187 .38031 .12608 .38779 .13591 .38741 .12875 .37825 Mtetra
.91 .714 .627 r
.12875 .37825 .13591 .38741 .14701 .37679 .14401 .33339 Mtetra
0 0 .345 r
.14401 .33339 .14701 .37679 .15701 .37572 .14971 .36803 Mtetra
.595 .707 .922 r
.14971 .36803 .15701 .37572 .16722 .37325 .15992 .36572 Mtetra
.585 .709 .929 r
.15992 .36572 .16722 .37325 .1772 .37341 .17016 .36358 Mtetra
.862 .72 .704 r
.17016 .36358 .1772 .37341 .18843 .36226 .18251 .34242 Mtetra
.091 .177 .662 r
.18251 .34242 .18843 .36226 .19867 .36072 .19145 .35303 Mtetra
.605 .713 .921 r
.19145 .35303 .19867 .36072 .20909 .35795 .20187 .35044 Mtetra
.609 .722 .925 r
.20187 .35044 .20909 .35795 .21949 .35595 .21235 .34774 Mtetra
.26 .534 .918 r
.21235 .34774 .21949 .35595 .23097 .34281 .22237 .35036 Mtetra
.716 .94 .627 r
.22237 .35036 .23097 .34281 .24106 .34494 .23397 .33673 Mtetra
.586 .694 .916 r
.23397 .33673 .24106 .34494 .25167 .34207 .24454 .33454 Mtetra
.625 .729 .922 r
.24454 .33454 .25167 .34207 .26235 .33896 .25523 .33142 Mtetra
.619 .728 .924 r
.25523 .33142 .26235 .33896 .27301 .33658 .26597 .32843 Mtetra
.416 .622 .937 r
.26597 .32843 .27301 .33658 .28478 .32041 .27646 .32913 Mtetra
.524 .823 .494 r
.27646 .32913 .28478 .32041 .29498 .32536 .28801 .31687 Mtetra
.583 .688 .914 r
.28801 .31687 .29498 .32536 .30583 .32233 .29882 .31471 Mtetra
.632 .733 .921 r
.29882 .31471 .30583 .32233 .31676 .31886 .30976 .31134 Mtetra
.64 .74 .921 r
.30976 .31134 .31676 .31886 .32774 .31531 .32077 .30777 Mtetra
.638 .739 .922 r
.32077 .30777 .32774 .31531 .33876 .31192 .33183 .30422 Mtetra
.621 .73 .924 r
.33183 .30422 .33876 .31192 .34976 .30978 .34291 .30109 Mtetra
0 .278 .778 r
.34291 .30109 .34976 .30978 .36134 .29771 .35348 .30817 Mtetra
.705 .876 .479 r
.35348 .30817 .36134 .29771 .37232 .29764 .3655 .28935 Mtetra
.608 .709 .916 r
.3655 .28935 .37232 .29764 .38353 .29421 .37671 .28649 Mtetra
.642 .74 .92 r
.37671 .28649 .38353 .29421 .39481 .29039 .38801 .28277 Mtetra
.65 .747 .92 r
.38801 .28277 .39481 .29039 .40614 .28641 .39936 .27882 Mtetra
.654 .75 .92 r
.39936 .27882 .40614 .28641 .41752 .28234 .41077 .27475 Mtetra
.656 .752 .92 r
.41077 .27475 .41752 .28234 .42895 .27821 .42223 .27061 Mtetra
.658 .753 .92 r
.42223 .27061 .42895 .27821 .44043 .27402 .43375 .2664 Mtetra
.659 .753 .92 r
.43375 .2664 .44043 .27402 .45196 .2698 .44531 .26216 Mtetra
.659 .754 .92 r
.44531 .26216 .45196 .2698 .46354 .26556 .45692 .25788 Mtetra
.45692 .25788 .46354 .26556 .47517 .2613 .46858 .25359 Mtetra
.46858 .25359 .47517 .2613 .48684 .25704 .48028 .24929 Mtetra
.658 .753 .92 r
.48028 .24929 .48684 .25704 .49857 .25276 .49204 .24497 Mtetra
.49204 .24497 .49857 .25276 .51034 .24847 .50385 .24065 Mtetra
.50385 .24065 .51034 .24847 .52217 .24416 .51571 .23631 Mtetra
.51571 .23631 .52217 .24416 .53405 .23985 .52762 .23195 Mtetra
.52762 .23195 .53405 .23985 .54597 .23551 .53958 .22758 Mtetra
.53958 .22758 .54597 .23551 .55795 .23116 .5516 .2232 Mtetra
.5516 .2232 .55795 .23116 .56998 .2268 .56366 .2188 Mtetra
.657 .753 .92 r
.56366 .2188 .56998 .2268 .58207 .22242 .57578 .21438 Mtetra
.57578 .21438 .58207 .22242 .5942 .21802 .58795 .20994 Mtetra
.58795 .20994 .5942 .21802 .60639 .2136 .60017 .20549 Mtetra
.657 .752 .92 r
.60017 .20549 .60639 .2136 .61863 .20916 .61245 .20102 Mtetra
.61245 .20102 .61863 .20916 .63092 .20471 .62478 .19653 Mtetra
.62478 .19653 .63092 .20471 .64327 .20024 .63717 .19202 Mtetra
.63717 .19202 .64327 .20024 .65568 .19575 .64961 .18749 Mtetra
.64961 .18749 .65568 .19575 .66813 .19124 .6621 .18294 Mtetra
.6621 .18294 .66813 .19124 .68065 .18671 .67465 .17838 Mtetra
.67465 .17838 .68065 .18671 .69321 .18216 .68726 .17379 Mtetra
.68726 .17379 .69321 .18216 .70584 .17759 .69992 .16919 Mtetra
.69992 .16919 .70584 .17759 .71852 .17301 .71264 .16456 Mtetra
.71264 .16456 .71852 .17301 .73125 .1684 .72542 .15992 Mtetra
.45 .643 .94 r
.05032 .39604 .05782 .40379 .07116 .3767 .05981 .39617 Mtetra
.025 0 .002 r
.05981 .39617 .07116 .3767 .07823 .39405 .07087 .38557 Mtetra
.534 .657 .915 r
.07087 .38557 .07823 .39405 .08809 .39211 .08061 .38455 Mtetra
.566 .698 .93 r
.08061 .38455 .08809 .39211 .09757 .3933 .0905 .38283 Mtetra
.823 .703 .733 r
.0905 .38283 .09757 .3933 .10878 .38179 .10229 .36706 Mtetra
.224 .34 .772 r
.10229 .36706 .10878 .38179 .1187 .38031 .11129 .37268 Mtetra
.591 .707 .924 r
.11129 .37268 .1187 .38031 .12875 .37825 .12137 .37044 Mtetra
.488 .662 .938 r
.12137 .37044 .12875 .37825 .14401 .33339 .13128 .37001 Mtetra
.293 0 .274 r
.13128 .37001 .14401 .33339 .14971 .36803 .14249 .35928 Mtetra
.539 .655 .911 r
.14249 .35928 .14971 .36803 .15992 .36572 .15257 .35816 Mtetra
.603 .716 .925 r
.15257 .35816 .15992 .36572 .17016 .36358 .16287 .35562 Mtetra
.453 .643 .939 r
.16287 .35562 .17016 .36358 .18251 .34242 .17292 .35572 Mtetra
0 0 0 r
.17292 .35572 .18251 .34242 .19145 .35303 .18427 .34447 Mtetra
.56 .672 .913 r
.18427 .34447 .19145 .35303 .20187 .35044 .1946 .34287 Mtetra
.614 .723 .923 r
.1946 .34287 .20187 .35044 .21235 .34774 .20511 .34002 Mtetra
.577 .706 .93 r
.20511 .34002 .21235 .34774 .22237 .35036 .21559 .33796 Mtetra
.79 .679 .742 r
.21559 .33796 .22237 .35036 .23397 .33673 .22719 .32472 Mtetra
.399 .506 .851 r
.22719 .32472 .23397 .33673 .24454 .33454 .23736 .32679 Mtetra
.616 .721 .921 r
.23736 .32679 .24454 .33454 .25523 .33142 .24807 .32385 Mtetra
.626 .731 .923 r
.24807 .32385 .25523 .33142 .26597 .32843 .25884 .32067 Mtetra
.593 .714 .928 r
.25884 .32067 .26597 .32843 .27646 .32913 .2696 .31822 Mtetra
.832 .714 .734 r
.2696 .31822 .27646 .32913 .28801 .31687 .28149 .30193 Mtetra
.3 .391 .789 r
.28149 .30193 .28801 .31687 .29882 .31471 .29177 .30683 Mtetra
.62 .723 .92 r
.29177 .30683 .29882 .31471 .30976 .31134 .30272 .30373 Mtetra
.638 .738 .921 r
.30272 .30373 .30976 .31134 .32077 .30777 .31375 .30018 Mtetra
.64 .74 .921 r
.31375 .30018 .32077 .30777 .33183 .30422 .32483 .29656 Mtetra
.633 .737 .923 r
.32483 .29656 .33183 .30422 .34291 .30109 .33596 .29308 Mtetra
.578 .707 .93 r
.33596 .29308 .34291 .30109 .35348 .30817 .34706 .29088 Mtetra
.741 .614 .717 r
.34706 .29088 .35348 .30817 .3655 .28935 .35875 .2787 Mtetra
.498 .597 .883 r
.35875 .2787 .3655 .28935 .37671 .28649 .36984 .27856 Mtetra
.632 .732 .919 r
.36984 .27856 .37671 .28649 .38801 .28277 .38115 .27505 Mtetra
.647 .744 .92 r
.38115 .27505 .38801 .28277 .39936 .27882 .39253 .27115 Mtetra
.652 .748 .92 r
.39253 .27115 .39936 .27882 .41077 .27475 .40397 .26709 Mtetra
.655 .751 .92 r
.40397 .26709 .41077 .27475 .42223 .27061 .41546 .26294 Mtetra
.657 .752 .92 r
.41546 .26294 .42223 .27061 .43375 .2664 .42701 .25872 Mtetra
.658 .753 .92 r
.42701 .25872 .43375 .2664 .44531 .26216 .4386 .25445 Mtetra
.659 .754 .92 r
.4386 .25445 .44531 .26216 .45692 .25788 .45024 .25015 Mtetra
.45024 .25015 .45692 .25788 .46858 .25359 .46193 .24582 Mtetra
.46193 .24582 .46858 .25359 .48028 .24929 .47367 .24148 Mtetra
.47367 .24148 .48028 .24929 .49204 .24497 .48547 .23713 Mtetra
.658 .753 .92 r
.48547 .23713 .49204 .24497 .50385 .24065 .49731 .23276 Mtetra
.49731 .23276 .50385 .24065 .51571 .23631 .5092 .22839 Mtetra
.5092 .22839 .51571 .23631 .52762 .23195 .52114 .224 Mtetra
.52114 .224 .52762 .23195 .53958 .22758 .53314 .21959 Mtetra
.53314 .21959 .53958 .22758 .5516 .2232 .54519 .21517 Mtetra
.54519 .21517 .5516 .2232 .56366 .2188 .55729 .21073 Mtetra
.657 .753 .92 r
.55729 .21073 .56366 .2188 .57578 .21438 .56944 .20628 Mtetra
.56944 .20628 .57578 .21438 .58795 .20994 .58165 .2018 Mtetra
.58165 .2018 .58795 .20994 .60017 .20549 .59391 .19731 Mtetra
.59391 .19731 .60017 .20549 .61245 .20102 .60622 .1928 Mtetra
.657 .752 .92 r
.60622 .1928 .61245 .20102 .62478 .19653 .61859 .18828 Mtetra
.61859 .18828 .62478 .19653 .63717 .19202 .63101 .18373 Mtetra
.63101 .18373 .63717 .19202 .64961 .18749 .64349 .17916 Mtetra
.64349 .17916 .64961 .18749 .6621 .18294 .65602 .17458 Mtetra
.65602 .17458 .6621 .18294 .67465 .17838 .66861 .16998 Mtetra
.66861 .16998 .67465 .17838 .68726 .17379 .68126 .16535 Mtetra
.68126 .16535 .68726 .17379 .69992 .16919 .69396 .16071 Mtetra
.69396 .16071 .69992 .16919 .71264 .16456 .70672 .15605 Mtetra
.70672 .15605 .71264 .16456 .72542 .15992 .71953 .15136 Mtetra
.564 .696 .929 r
.04275 .38843 .05032 .39604 .05981 .39617 .05251 .38673 Mtetra
.876 .715 .678 r
.05251 .38673 .05981 .39617 .07087 .38557 .066 .35948 Mtetra
0 0 .496 r
.066 .35948 .07087 .38557 .08061 .38455 .0731 .37684 Mtetra
.58 .7 .925 r
.0731 .37684 .08061 .38455 .0905 .38283 .08303 .37484 Mtetra
.369 .6 .937 r
.08303 .37484 .0905 .38283 .10229 .36706 .09259 .37598 Mtetra
.587 .878 .572 r
.09259 .37598 .10229 .36706 .11129 .37268 .1039 .36437 Mtetra
.557 .676 .917 r
.1039 .36437 .11129 .37268 .12137 .37044 .11391 .36282 Mtetra
.582 .707 .928 r
.11391 .36282 .12137 .37044 .13128 .37001 .12404 .36071 Mtetra
.911 .715 .626 r
.12404 .36071 .13128 .37001 .14249 .35928 .1395 .31562 Mtetra
0 0 .339 r
.1395 .31562 .14249 .35928 .15257 .35816 .14519 .35033 Mtetra
.595 .707 .922 r
.14519 .35033 .15257 .35816 .16287 .35562 .15549 .34795 Mtetra
.585 .709 .929 r
.15549 .34795 .16287 .35562 .17292 .35572 .16581 .34574 Mtetra
.863 .721 .704 r
.16581 .34574 .17292 .35572 .18427 .34447 .17829 .32445 Mtetra
.087 .175 .66 r
.17829 .32445 .18427 .34447 .1946 .34287 .18729 .33504 Mtetra
.605 .713 .921 r
.18729 .33504 .1946 .34287 .20511 .34002 .1978 .33238 Mtetra
.609 .722 .925 r
.1978 .33238 .20511 .34002 .21559 .33796 .20837 .32961 Mtetra
.262 .535 .918 r
.20837 .32961 .21559 .33796 .22719 .32472 .21847 .33218 Mtetra
.724 .945 .636 r
.21847 .33218 .22719 .32472 .23736 .32679 .23019 .31844 Mtetra
.586 .694 .917 r
.23019 .31844 .23736 .32679 .24807 .32385 .24085 .31618 Mtetra
.625 .729 .922 r
.24085 .31618 .24807 .32385 .25884 .32067 .25164 .31298 Mtetra
.619 .728 .924 r
.25164 .31298 .25884 .32067 .2696 .31822 .26248 .30992 Mtetra
.417 .622 .937 r
.26248 .30992 .2696 .31822 .28149 .30193 .27306 .31056 Mtetra
.538 .834 .507 r
.27306 .31056 .28149 .30193 .29177 .30683 .28472 .29819 Mtetra
.583 .688 .914 r
.28472 .29819 .29177 .30683 .30272 .30373 .29563 .29597 Mtetra
.632 .733 .921 r
.29563 .29597 .30272 .30373 .31375 .30018 .30667 .29252 Mtetra
.64 .74 .921 r
.30667 .29252 .31375 .30018 .32483 .29656 .31778 .28887 Mtetra
.638 .739 .922 r
.31778 .28887 .32483 .29656 .33596 .29308 .32894 .28524 Mtetra
.621 .73 .924 r
.32894 .28524 .33596 .29308 .34706 .29088 .34013 .28203 Mtetra
0 .282 .781 r
.34013 .28203 .34706 .29088 .35875 .2787 .35079 .28908 Mtetra
.714 .882 .487 r
.35079 .28908 .35875 .2787 .36984 .27856 .36294 .27012 Mtetra
.608 .709 .916 r
.36294 .27012 .36984 .27856 .38115 .27505 .37425 .26719 Mtetra
.642 .74 .92 r
.37425 .26719 .38115 .27505 .39253 .27115 .38565 .26338 Mtetra
.65 .747 .92 r
.38565 .26338 .39253 .27115 .40397 .26709 .39712 .25935 Mtetra
.654 .75 .92 r
.39712 .25935 .40397 .26709 .41546 .26294 .40864 .2552 Mtetra
.656 .752 .92 r
.40864 .2552 .41546 .26294 .42701 .25872 .42021 .25097 Mtetra
.658 .753 .92 r
.42021 .25097 .42701 .25872 .4386 .25445 .43184 .24668 Mtetra
.659 .753 .92 r
.43184 .24668 .4386 .25445 .45024 .25015 .44351 .24235 Mtetra
.659 .754 .92 r
.44351 .24235 .45024 .25015 .46193 .24582 .45524 .23799 Mtetra
.45524 .23799 .46193 .24582 .47367 .24148 .46701 .23361 Mtetra
.46701 .23361 .47367 .24148 .48547 .23713 .47883 .22922 Mtetra
.658 .753 .92 r
.47883 .22922 .48547 .23713 .49731 .23276 .49071 .22482 Mtetra
.49071 .22482 .49731 .23276 .5092 .22839 .50264 .2204 Mtetra
.50264 .2204 .5092 .22839 .52114 .224 .51461 .21598 Mtetra
.51461 .21598 .52114 .224 .53314 .21959 .52664 .21153 Mtetra
.52664 .21153 .53314 .21959 .54519 .21517 .53873 .20707 Mtetra
.53873 .20707 .54519 .21517 .55729 .21073 .55086 .2026 Mtetra
.55086 .2026 .55729 .21073 .56944 .20628 .56305 .19811 Mtetra
.657 .753 .92 r
.56305 .19811 .56944 .20628 .58165 .2018 .57529 .1936 Mtetra
.57529 .1936 .58165 .2018 .59391 .19731 .58759 .18907 Mtetra
.58759 .18907 .59391 .19731 .60622 .1928 .59994 .18452 Mtetra
.657 .752 .92 r
.59994 .18452 .60622 .1928 .61859 .18828 .61234 .17996 Mtetra
.61234 .17996 .61859 .18828 .63101 .18373 .6248 .17537 Mtetra
.6248 .17537 .63101 .18373 .64349 .17916 .63732 .17077 Mtetra
.63732 .17077 .64349 .17916 .65602 .17458 .64989 .16615 Mtetra
.64989 .16615 .65602 .17458 .66861 .16998 .66252 .16151 Mtetra
.66252 .16151 .66861 .16998 .68126 .16535 .6752 .15684 Mtetra
.6752 .15684 .68126 .16535 .69396 .16071 .68794 .15216 Mtetra
.68794 .15216 .69396 .16071 .70672 .15605 .70074 .14746 Mtetra
.70074 .14746 .70672 .15605 .71953 .15136 .7136 .14274 Mtetra
.559 .683 .923 r
.03517 .38042 .04275 .38843 .05251 .38673 .04492 .37885 Mtetra
.45 .643 .94 r
.04492 .37885 .05251 .38673 .066 .35948 .05448 .37892 Mtetra
.008 0 0 r
.05448 .37892 .066 .35948 .0731 .37684 .06565 .36823 Mtetra
.534 .657 .915 r
.06565 .36823 .0731 .37684 .08303 .37484 .07547 .36715 Mtetra
.566 .698 .93 r
.07547 .36715 .08303 .37484 .09259 .37598 .08543 .36537 Mtetra
.823 .704 .733 r
.08543 .36537 .09259 .37598 .1039 .36437 .09735 .34948 Mtetra
.221 .339 .772 r
.09735 .34948 .1039 .36437 .11391 .36282 .10641 .35506 Mtetra
.591 .707 .924 r
.10641 .35506 .11391 .36282 .12404 .36071 .11657 .35276 Mtetra
.489 .662 .938 r
.11657 .35276 .12404 .36071 .1395 .31562 .12656 .35227 Mtetra
.283 0 .264 r
.12656 .35227 .1395 .31562 .14519 .35033 .13788 .34144 Mtetra
.539 .655 .911 r
.13788 .34144 .14519 .35033 .15549 .34795 .14805 .34026 Mtetra
.603 .716 .925 r
.14805 .34026 .15549 .34795 .16581 .34574 .15843 .33765 Mtetra
.454 .643 .939 r
.15843 .33765 .16581 .34574 .17829 .32445 .16857 .33769 Mtetra
0 0 0 r
.16857 .33769 .17829 .32445 .18729 .33504 .18002 .32634 Mtetra
.56 .673 .914 r
.18002 .32634 .18729 .33504 .1978 .33238 .19044 .32467 Mtetra
.614 .723 .923 r
.19044 .32467 .1978 .33238 .20837 .32961 .20105 .32175 Mtetra
.577 .706 .93 r
.20105 .32175 .20837 .32961 .21847 .33218 .21162 .31962 Mtetra
.791 .68 .742 r
.21162 .31962 .21847 .33218 .23019 .31844 .22333 .30626 Mtetra
.398 .505 .851 r
.22333 .30626 .23019 .31844 .24085 .31618 .2336 .30829 Mtetra
.616 .721 .921 r
.2336 .30829 .24085 .31618 .25164 .31298 .24439 .30527 Mtetra
.626 .731 .923 r
.24439 .30527 .25164 .31298 .26248 .30992 .25526 .30201 Mtetra
.593 .714 .928 r
.25526 .30201 .26248 .30992 .27306 .31056 .26612 .2995 Mtetra
.833 .714 .734 r
.26612 .2995 .27306 .31056 .28472 .29819 .27814 .28308 Mtetra
.299 .39 .789 r
.27814 .28308 .28472 .29819 .29563 .29597 .2885 .28793 Mtetra
.62 .723 .92 r
.2885 .28793 .29563 .29597 .30667 .29252 .29955 .28476 Mtetra
.638 .738 .921 r
.29955 .28476 .30667 .29252 .31778 .28887 .31068 .28113 Mtetra
.64 .74 .921 r
.31068 .28113 .31778 .28887 .32894 .28524 .32187 .27743 Mtetra
.633 .737 .923 r
.32187 .27743 .32894 .28524 .34013 .28203 .3331 .27388 Mtetra
.578 .707 .93 r
.3331 .27388 .34013 .28203 .35079 .28908 .3443 .27159 Mtetra
.741 .614 .717 r
.3443 .27159 .35079 .28908 .36294 .27012 .35612 .25931 Mtetra
.497 .597 .883 r
.35612 .25931 .36294 .27012 .37425 .26719 .3673 .25909 Mtetra
.632 .732 .919 r
.3673 .25909 .37425 .26719 .38565 .26338 .37872 .25551 Mtetra
.647 .744 .92 r
.37872 .25551 .38565 .26338 .39712 .25935 .39022 .25152 Mtetra
.652 .748 .92 r
.39022 .25152 .39712 .25935 .40864 .2552 .40177 .24738 Mtetra
.655 .751 .92 r
.40177 .24738 .40864 .2552 .42021 .25097 .41337 .24315 Mtetra
.657 .752 .92 r
.41337 .24315 .42021 .25097 .43184 .24668 .42502 .23884 Mtetra
.658 .753 .92 r
.42502 .23884 .43184 .24668 .44351 .24235 .43673 .23449 Mtetra
.659 .754 .92 r
.43673 .23449 .44351 .24235 .45524 .23799 .44848 .2301 Mtetra
.44848 .2301 .45524 .23799 .46701 .23361 .46029 .22568 Mtetra
.46029 .22568 .46701 .23361 .47883 .22922 .47215 .22125 Mtetra
.47215 .22125 .47883 .22922 .49071 .22482 .48406 .21681 Mtetra
.658 .753 .92 r
.48406 .21681 .49071 .22482 .50264 .2204 .49602 .21236 Mtetra
.49602 .21236 .50264 .2204 .51461 .21598 .50803 .20789 Mtetra
.50803 .20789 .51461 .21598 .52664 .21153 .5201 .20341 Mtetra
.5201 .20341 .52664 .21153 .53873 .20707 .53221 .19891 Mtetra
.53221 .19891 .53873 .20707 .55086 .2026 .54438 .1944 Mtetra
.54438 .1944 .55086 .2026 .56305 .19811 .55661 .18987 Mtetra
.657 .753 .92 r
.55661 .18987 .56305 .19811 .57529 .1936 .56889 .18532 Mtetra
.56889 .18532 .57529 .1936 .58759 .18907 .58122 .18076 Mtetra
.58122 .18076 .58759 .18907 .59994 .18452 .59361 .17617 Mtetra
.59361 .17617 .59994 .18452 .61234 .17996 .60605 .17157 Mtetra
.657 .752 .92 r
.60605 .17157 .61234 .17996 .6248 .17537 .61855 .16695 Mtetra
.61855 .16695 .6248 .17537 .63732 .17077 .6311 .16231 Mtetra
.6311 .16231 .63732 .17077 .64989 .16615 .64371 .15765 Mtetra
.64371 .15765 .64989 .16615 .66252 .16151 .65638 .15296 Mtetra
.65638 .15296 .66252 .16151 .6752 .15684 .6691 .14826 Mtetra
.6691 .14826 .6752 .15684 .68794 .15216 .68188 .14354 Mtetra
.68188 .14354 .68794 .15216 .70074 .14746 .69472 .1388 Mtetra
.69472 .1388 .70074 .14746 .7136 .14274 .70761 .13404 Mtetra
.401 .535 .876 r
.02797 .36965 .03517 .38042 .04492 .37885 .03726 .37111 Mtetra
.564 .696 .929 r
.03726 .37111 .04492 .37885 .05448 .37892 .0471 .36935 Mtetra
.877 .716 .678 r
.0471 .36935 .05448 .37892 .06565 .36823 .06075 .34193 Mtetra
0 0 .492 r
.06075 .34193 .06565 .36823 .07547 .36715 .06786 .35931 Mtetra
.58 .7 .925 r
.06786 .35931 .07547 .36715 .08543 .36537 .07788 .35724 Mtetra
.371 .601 .936 r
.07788 .35724 .08543 .36537 .09735 .34948 .08751 .35833 Mtetra
.6 .888 .584 r
.08751 .35833 .09735 .34948 .10641 .35506 .09894 .34661 Mtetra
.557 .676 .917 r
.09894 .34661 .10641 .35506 .11657 .35276 .10902 .34501 Mtetra
.582 .707 .928 r
.10902 .34501 .11657 .35276 .12656 .35227 .11924 .34283 Mtetra
.912 .716 .625 r
.11924 .34283 .12656 .35227 .13788 .34144 .1349 .2975 Mtetra
0 0 .334 r
.1349 .2975 .13788 .34144 .14805 .34026 .14058 .33229 Mtetra
.595 .707 .922 r
.14058 .33229 .14805 .34026 .15843 .33765 .15096 .32984 Mtetra
.585 .709 .929 r
.15096 .32984 .15843 .33765 .16857 .33769 .16138 .32757 Mtetra
.864 .722 .704 r
.16138 .32757 .16857 .33769 .18002 .32634 .17399 .30613 Mtetra
.083 .172 .659 r
.17399 .30613 .18002 .32634 .19044 .32467 .18305 .31669 Mtetra
.605 .713 .921 r
.18305 .31669 .19044 .32467 .20105 .32175 .19365 .31397 Mtetra
.609 .722 .925 r
.19365 .31397 .20105 .32175 .21162 .31962 .20432 .31113 Mtetra
.264 .535 .918 r
.20432 .31113 .21162 .31962 .22333 .30626 .2145 .31364 Mtetra
.732 .949 .644 r
.2145 .31364 .22333 .30626 .2336 .30829 .22634 .29979 Mtetra
.586 .694 .917 r
.22634 .29979 .2336 .30829 .24439 .30527 .23709 .29746 Mtetra
.625 .729 .922 r
.23709 .29746 .24439 .30527 .25526 .30201 .24798 .29418 Mtetra
.619 .728 .924 r
.24798 .29418 .25526 .30201 .26612 .2995 .25891 .29105 Mtetra
.418 .622 .936 r
.25891 .29105 .26612 .2995 .27814 .28308 .26959 .29163 Mtetra
.551 .845 .521 r
.26959 .29163 .27814 .28308 .2885 .28793 .28137 .27914 Mtetra
.583 .688 .914 r
.28137 .27914 .2885 .28793 .29955 .28476 .29237 .27684 Mtetra
.632 .733 .921 r
.29237 .27684 .29955 .28476 .31068 .28113 .30352 .27332 Mtetra
.64 .74 .921 r
.30352 .27332 .31068 .28113 .32187 .27743 .31474 .26959 Mtetra
.638 .739 .922 r
.31474 .26959 .32187 .27743 .3331 .27388 .326 .26588 Mtetra
.621 .73 .924 r
.326 .26588 .3331 .27388 .3443 .27159 .33729 .26259 Mtetra
0 .286 .783 r
.33729 .26259 .3443 .27159 .35612 .25931 .34804 .2696 Mtetra
.722 .888 .496 r
.34804 .2696 .35612 .25931 .3673 .25909 .36032 .2505 Mtetra
.608 .709 .916 r
.36032 .2505 .3673 .25909 .37872 .25551 .37174 .24749 Mtetra
.642 .74 .92 r
.37174 .24749 .37872 .25551 .39022 .25152 .38326 .2436 Mtetra
.65 .747 .92 r
.38326 .2436 .39022 .25152 .40177 .24738 .39483 .23948 Mtetra
.654 .75 .92 r
.39483 .23948 .40177 .24738 .41337 .24315 .40647 .23525 Mtetra
.656 .752 .92 r
.40647 .23525 .41337 .24315 .42502 .23884 .41815 .23093 Mtetra
.658 .753 .92 r
.41815 .23093 .42502 .23884 .43673 .23449 .42989 .22656 Mtetra
.659 .753 .92 r
.42989 .22656 .43673 .23449 .44848 .2301 .44168 .22214 Mtetra
.659 .754 .92 r
.44168 .22214 .44848 .2301 .46029 .22568 .45352 .21769 Mtetra
.45352 .21769 .46029 .22568 .47215 .22125 .46541 .21322 Mtetra
.46541 .21322 .47215 .22125 .48406 .21681 .47735 .20874 Mtetra
.658 .753 .92 r
.47735 .20874 .48406 .21681 .49602 .21236 .48935 .20425 Mtetra
.48935 .20425 .49602 .21236 .50803 .20789 .5014 .19974 Mtetra
.5014 .19974 .50803 .20789 .5201 .20341 .5135 .19522 Mtetra
.5135 .19522 .5201 .20341 .53221 .19891 .52565 .19069 Mtetra
.52565 .19069 .53221 .19891 .54438 .1944 .53785 .18614 Mtetra
.53785 .18614 .54438 .1944 .55661 .18987 .55011 .18157 Mtetra
.55011 .18157 .55661 .18987 .56889 .18532 .56243 .17698 Mtetra
.657 .753 .92 r
.56243 .17698 .56889 .18532 .58122 .18076 .5748 .17238 Mtetra
.5748 .17238 .58122 .18076 .59361 .17617 .58722 .16776 Mtetra
.58722 .16776 .59361 .17617 .60605 .17157 .5997 .16312 Mtetra
.657 .752 .92 r
.5997 .16312 .60605 .17157 .61855 .16695 .61224 .15845 Mtetra
.61224 .15845 .61855 .16695 .6311 .16231 .62483 .15377 Mtetra
.62483 .15377 .6311 .16231 .64371 .15765 .63748 .14907 Mtetra
.63748 .14907 .64371 .15765 .65638 .15296 .65018 .14435 Mtetra
.65018 .14435 .65638 .15296 .6691 .14826 .66294 .13961 Mtetra
.66294 .13961 .6691 .14826 .68188 .14354 .67576 .13485 Mtetra
.67576 .13485 .68188 .14354 .69472 .1388 .68864 .13007 Mtetra
.68864 .13007 .69472 .1388 .70761 .13404 .70158 .12527 Mtetra
.829 .982 .698 r
.01768 .37804 .02797 .36965 .03726 .37111 .02959 .36297 Mtetra
.559 .683 .923 r
.02959 .36297 .03726 .37111 .0471 .36935 .03942 .36133 Mtetra
.451 .643 .94 r
.03942 .36133 .0471 .36935 .06075 .34193 .04905 .36135 Mtetra
0 0 0 r
.04905 .36135 .06075 .34193 .06786 .35931 .06033 .35056 Mtetra
.534 .657 .915 r
.06033 .35056 .06786 .35931 .07788 .35724 .07022 .34942 Mtetra
.566 .698 .93 r
.07022 .34942 .07788 .35724 .08751 .35833 .08027 .34757 Mtetra
.824 .705 .733 r
.08027 .34757 .08751 .35833 .09894 .34661 .09231 .33156 Mtetra
.219 .337 .772 r
.09231 .33156 .09894 .34661 .10902 .34501 .10143 .33711 Mtetra
.591 .707 .924 r
.10143 .33711 .10902 .34501 .11924 .34283 .11168 .33474 Mtetra
.489 .662 .938 r
.11168 .33474 .11924 .34283 .1349 .2975 .12176 .33419 Mtetra
.273 0 .254 r
.12176 .33419 .1349 .2975 .14058 .33229 .13318 .32326 Mtetra
.539 .655 .911 r
.13318 .32326 .14058 .33229 .15096 .32984 .14343 .32201 Mtetra
.603 .716 .925 r
.14343 .32201 .15096 .32984 .16138 .32757 .15391 .31933 Mtetra
.454 .643 .939 r
.15391 .31933 .16138 .32757 .17399 .30613 .16413 .31931 Mtetra
0 0 0 r
.16413 .31931 .17399 .30613 .18305 .31669 .1757 .30785 Mtetra
.56 .673 .914 r
.1757 .30785 .18305 .31669 .19365 .31397 .18621 .30611 Mtetra
.614 .723 .923 r
.18621 .30611 .19365 .31397 .20432 .31113 .1969 .30312 Mtetra
.577 .706 .93 r
.1969 .30312 .20432 .31113 .2145 .31364 .20757 .30092 Mtetra
.791 .681 .743 r
.20757 .30092 .2145 .31364 .22634 .29979 .2194 .28745 Mtetra
.397 .505 .851 r
.2194 .28745 .22634 .29979 .23709 .29746 .22975 .28942 Mtetra
.616 .721 .921 r
.22975 .28942 .23709 .29746 .24798 .29418 .24065 .28633 Mtetra
.626 .731 .923 r
.24065 .28633 .24798 .29418 .25891 .29105 .25162 .28299 Mtetra
.593 .714 .928 r
.25162 .28299 .25891 .29105 .26959 .29163 .26257 .2804 Mtetra
.834 .715 .734 r
.26257 .2804 .26959 .29163 .28137 .27914 .27472 .26385 Mtetra
.297 .389 .789 r
.27472 .26385 .28137 .27914 .29237 .27684 .28516 .26866 Mtetra
.62 .723 .92 r
.28516 .26866 .29237 .27684 .30352 .27332 .29631 .2654 Mtetra
.638 .738 .921 r
.29631 .2654 .30352 .27332 .31474 .26959 .30755 .2617 Mtetra
.64 .74 .921 r
.30755 .2617 .31474 .26959 .326 .26588 .31885 .25791 Mtetra
.633 .737 .923 r
.31885 .25791 .326 .26588 .33729 .26259 .33018 .25428 Mtetra
.578 .706 .93 r
.33018 .25428 .33729 .26259 .34804 .2696 .34149 .25192 Mtetra
.741 .615 .717 r
.34149 .25192 .34804 .2696 .36032 .2505 .35342 .23952 Mtetra
.497 .597 .884 r
.35342 .23952 .36032 .2505 .37174 .24749 .36471 .23924 Mtetra
.632 .732 .919 r
.36471 .23924 .37174 .24749 .38326 .2436 .37625 .23557 Mtetra
.647 .744 .92 r
.37625 .23557 .38326 .2436 .39483 .23948 .38785 .2315 Mtetra
.652 .748 .92 r
.38785 .2315 .39483 .23948 .40647 .23525 .39951 .22727 Mtetra
.655 .751 .92 r
.39951 .22727 .40647 .23525 .41815 .23093 .41123 .22295 Mtetra
.657 .752 .92 r
.41123 .22295 .41815 .23093 .42989 .22656 .423 .21855 Mtetra
.658 .753 .92 r
.423 .21855 .42989 .22656 .44168 .22214 .43482 .21411 Mtetra
.659 .754 .92 r
.43482 .21411 .44168 .22214 .45352 .21769 .44669 .20963 Mtetra
.44669 .20963 .45352 .21769 .46541 .21322 .45862 .20513 Mtetra
.45862 .20513 .46541 .21322 .47735 .20874 .47059 .20061 Mtetra
.47059 .20061 .47735 .20874 .48935 .20425 .48262 .19607 Mtetra
.658 .753 .92 r
.48262 .19607 .48935 .20425 .5014 .19974 .4947 .19153 Mtetra
.4947 .19153 .5014 .19974 .5135 .19522 .50684 .18697 Mtetra
.50684 .18697 .5135 .19522 .52565 .19069 .51903 .1824 Mtetra
.51903 .1824 .52565 .19069 .53785 .18614 .53127 .17781 Mtetra
.53127 .17781 .53785 .18614 .55011 .18157 .54357 .1732 Mtetra
.54357 .1732 .55011 .18157 .56243 .17698 .55592 .16858 Mtetra
.657 .753 .92 r
.55592 .16858 .56243 .17698 .5748 .17238 .56832 .16393 Mtetra
.56832 .16393 .5748 .17238 .58722 .16776 .58078 .15927 Mtetra
.58078 .15927 .58722 .16776 .5997 .16312 .5933 .15459 Mtetra
.5933 .15459 .5997 .16312 .61224 .15845 .60587 .14989 Mtetra
.657 .752 .92 r
.60587 .14989 .61224 .15845 .62483 .15377 .6185 .14517 Mtetra
.6185 .14517 .62483 .15377 .63748 .14907 .63119 .14043 Mtetra
.63119 .14043 .63748 .14907 .65018 .14435 .64394 .13567 Mtetra
.64394 .13567 .65018 .14435 .66294 .13961 .65674 .13089 Mtetra
.65674 .13089 .66294 .13961 .67576 .13485 .6696 .12609 Mtetra
.6696 .12609 .67576 .13485 .68864 .13007 .68252 .12126 Mtetra
.68252 .12126 .68864 .13007 .70158 .12527 .69549 .11642 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05eoo`0GD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBo@0GOol00`00
Oomoo`17Ool008Moo`<006=oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aB
o5;mD_`005;lD_d00U;l5goo00<007ooOol0AWoo0025Ool2001ROol085;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_dFOol00`00Oomoo`16
Ool0089oo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`00e;mD_aoo`0FOol00`00Oomoo`15Ool0081oo`8006=oo`0UD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_`05goo00<007ooOol0A7oo001mOol3001QOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo003D_eB
o7oo01Eoo`03001oogoo04Aoo`00Ngoo0P000Woo00<007ooOol0GGoo02aBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;m5goo00<007ooOol0@goo001hOol3001ROol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@0GOol00`00Oomoo`12Ool007Ioo`80065oo`0dD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`12Ool007=oo`<0065oo`9Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo004D_eBo5;lD_`GOol00`00Oomoo`11Ool0075o
o`80069oo`0iD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;l01Eoo`03001oo`00049oo`00KWoo0`00H7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomoo`10Ool006]oo`<0065o
o`11D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0oOol006Uoo`8000=oo`03001oogoo05]oo`03D_aBoE;l
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;m
D_aBo5;lD_d00e;l5Goo00<007ooOol0?goo001VOol3001OOol0BE;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m01Ioo`03001oogoo03ioo`00I7oo0P00H7oo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aB
o5;lD_d00U;l5Woo00<007ooOol0?Goo001QOol3001POol0Ce;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m01Eoo`03001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P00Ggoo00=Bo5;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007oo
Ool09Woo00<007ooOol04goo000dOol00`00Oomoo`02Ool00`00Oomoo`0POol3001POol0EE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo02Eo
o`03001oogoo01=oo`00>Goo00<007ooOol07Woo0P000Woo00<007ooOol0G7oo0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Eoo`03001oogoo02Ao
o`03001oo`0001Aoo`00;7oo1P001goo00<007ooOol06goo0`00Ggoo05aBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Woo00<007ooOol0
8goo00<007oo000057oo000eOol4000LOol2001POol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0FOol00`00Oomoo`0QOol0
1@00Oomoogoo00004goo000eOol00`00Oomoo`0JOol3001POol0HU;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol2
000SOol01@00Oomoogoo00004goo000eOol00`00Oomoo`0GOol3001OOol2D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d05Goo00<007ooOol07goo0`0000Aoo`000000019oo`00=Goo1@004goo0P00H7oo
06UBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol0=goo001:Ool300000goo
001oo`1MOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol0
27oo1000:goo0018Ool2001OOol0L5;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m5Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0:7oo0015Ool3001OOol01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;l
D_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol0:7oo0013Ool2001POol0ME;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`0XOol0041oo`<005ioo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Eoo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo02Qoo`00?Woo0P00GGoo07m>o5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`0XOol003]oo`@005eoo`04C_aBo5;lD_d3D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0DOol00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003Uoo`8000Aoo`03001oogoo05Qoo`24D_e>
g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol00goo1000:goo000fOol3001MOol3C]`01Tkm
C]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0COol200000goo001oo`0bOol003=oo`<005]oo`2>FUIN
MSYK?U`nFciLC]aBoDkLC_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0aOol0035o
o`8005eoo`03FUINMUif00@nF`06C_e>g4kLC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00800003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
01Eoo`03001oogoo031oo`00;Woo0`00GWoo079JEUifFUENMUYF?U`jFciL?U]BoDkLD_e>g5;mC]aB
oDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d300007E;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d05Goo00<007ooOol0;goo000/Ool4001NOol02EYFGWINMUifFUIN
MT[LC]a:_002B]`01E;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00`0000IBoE;lD_aBo5;m0002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`0_Ool0
02Yoo`8005ioo`1aB]e6_4[MA[aNMUYEGWIJEUifFfiKSdZlC]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkl
D_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@03
000095;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02ioo`00:Woo0P00Fgoo00Y>oDkLC_e>g4[MA[e6gDJm
GWIJEP9NMP06FhmKKe]_B]a>g4Zl0TkL00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0800005D_eBo5;lD_aBo@03D_`01U;mD_aB
o5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Eo
o`03001oogoo02ioo`0047oo1@000goo100017oo10001Woo00<007oo0000EWoo07=>g5;mC]aBoDkL
D_e>g5;mC]a:gDJlB]eJEUifFUEKSe]^FhmKKU^?C]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0030000:U;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoAEoo`03001oogoo02eoo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo00=oo`800003Ool007oo059oo`0>D_e>g4klC_aBoDkLC_a>g4kmC]a>oDkL
B]e6_@9NMP03FhmJEUif00@nF`03C]a>oDkL009>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0
5Goo00<007ooOol0;7oo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol00Woo0P000goo00<007ooOol0AWoo00=V]RFI8GP01Goo075>g5;mC]aBoDkLD_e>g5;mC]aB
oD[LC_e:g4kmB]a:gDJlGWIJEUifFUDnG3iK?U`jFciLC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00<0000bD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoAAoo`03001oogoo02aoo`001goo1P001Goo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo04Eoo`05J]MVeREh
8GPUV003C]`03dkMC]a>o4kLD_e>g4kmC_aBoDkLC_e>g4kMC]a>g@020AP01EYFGWINMUifFUH00T[L
00U>g4ZlB]a>o5;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l00000P00
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol057oo00<007ooOol0
:goo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol0@goo07AZefKFJ]LQN2FI8GPUV4[LC_e:g4kMB]aBoDkLD_e>g5;mC]aB
oDkLD_e:g4kmB]a>oEYFGWIJEEifFUIKKeM^C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e>o5;mC_aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l0`0003UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`04goo00<007oo0000;7oo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol00Woo0P001Woo0P00@Woo00UZefKFJ]IZeV[G8GPUN25h9IP00dkL
00i>oDkLC_a>o5;mC]a>oDklD_e>g4kmA[e:gDJm0eif00EJEUifFfiKKdZl009:g006C]a:_5;lD_aB
oDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol0:Woo000@Ool30004
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0
?goo06mVeV[GI[IZefKFB[a6_4ZmA[a:_4kLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[aN
MUYFGWIGKU^?EfiKKdkLD_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`00041Bo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oAEoo`03001oogoo02Uoo`004Woo00<007ooOol00goo100017oo10001Goo00<007ooOol027oo00<0
07ooOol0?Goo00EVeV[FJ]IZefKF0097D005B[a6_4ZlB[a>o@03C]`04TkmC]a>o4klD_e>g4kmC]a>
oDkLC_e6_D[MFUINMU]^GWIJEP<nF`=>g005C_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`30003D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m01Eoo`03001oogoo02Qoo`00:7oo00<007ooOol02Woo00<007ooOol0=Goo079>g4km
C]a>oDkLB]e:_4[MI[IZefKFJ]LQN2FI@dm:_4JlB[e6_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4km
B]a>oDJlB]eJEEifFUINMSYK?U`nFciLC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d20000Ae;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`05Goo00<007ooOol0:7oo000XOol3000;Ool00`00Oomoo`0`Ool02TkMB]a>g4kL
C]e>g4kMC]a>oD[L0d[M00QVeV[FJ]IZeb5h9GPQN4kM0dkL00iBoDkLC_a>g5;mC]a>oDklD_e>g4kM
C]a>gDkL0P4H00=NMUYFGWH00Uif13iK00E>g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo0030002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00ABoE;lD_aBo1Eoo`03001oogoo02Moo`00:7oo00<007ooOol037oo00<007ooOol0:goo07AR
UVJg;OXb6bgjC]e:g4kMB]a>oDkLC_e>g4kmA[a:gDZlB]eV]V[GI[HUV25h9ITQN4kMB]a>oD[LD_e>
g5;mC]aBoDkLD_e>g5;mB]a>oD[LC_e:g5ifFUINMUYEGWIGKU]_B[a>gDZlC]e>g5;mC]aBoDkLD_e>
o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0`0004iBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0VOol002Qoo`03001oogoo
00eoo`03001oogoo02Uoo`=R]`06<OX]nS7j<OY>gD[L0TkL00E>gDkLC]e>g4kM008bO@03J]IZefKF
009ZeP059IPQN2EhC]a>g@03C]`03U;mC]a>o4klD_e>g4kmC_aBoDJmA]e6_D[MFUH3GWH01EYFFfiG
KTkLB[`00T[L00I>g4klD_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_aBo0030002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aB
o5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`D
Ool00`00Oomoo`0VOol002Qoo`8000moo`03001oogoo02Moo`1`HYIV]f:FI[MRUS7j;OXb6bgjC_e:
g4kmC]a>oD[LC_e:g3Im<UaZefJfJ]MV]V[G8GPUV25h9IU>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>
g5;mA[a:gDJlB]eJEEifFUIKKeM^FfmGKTkmC]aBoDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d30000EU;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`0UOol002Qoo`03001oogoo00moo`03001oogoo
02Eoo`IR]`E:_00:C]e>g4kMC]a>gDkLC]e>g6[GI]H2J]H00f[G@bm3C`02B[`014JlB[a>g4km0dkL
00iBoDkLC_a>o5;mC]a>oDkLC_e>g4KMA[eNMUYF0eif0ciK00I>oDkLC]a>g5;mC_`2D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`EOol00`00Oomoo`0TOol002Qoo`03001oogoo
011oo`03001oogoo00]oo`0370Moogoo01=oo`1^A[a:gDJlB]eRUVJgHYIV]e^cGmA6_4ZmA[a:gDkL
C_e:g4kmC]a:gDJlB]e:_6[GI[IZefJf@dm3;dM@A[a:_4JlB[e>g5;mC]aBoDkLD_e>g5;mC]aBoD[L
C_e:g4kmB]a:gEYFGWIGKUifFUHnG3YK?Ua>g4kmC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@<0001MD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m01=oo`8002Ioo`009goo00<007ooOol04Woo00<007ooOol02Woo
0R0747oo00Q>gD[LC]e>g4kMA[e6gDJm0f:g00AK/endFk=K]0A:_007C]a>oDkLC]e>g4[MB]`00T[M
00UZefKFJ]IVeRFH8GPUV4kLC]d00dkL00mBoDkLC_a>o5;mC]a>oDklD_e>g4kMC]a>g@4HA]d00Uif
00=JEUifGWH00ciK00I>o5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo0<0009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@02D_`DOol00`00Oomoo`0SOol002Moo`<001=oo`03001oogoo00Uoo`0370LP27oo00Yoo`80
001_A[a2W4JmAYa>gD[LC_e:g4[MA[a:gDJlI[MK/fJgHYHanRgj<Q]:g4kMB]a>gDkLC_e>g4kmC]a:
gDJlB]e:_3ImI[IZeb5h9IPQN2FIB]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e:g4kmFUEN
MUYFGWIJEEifB[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00<0001TD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`EOol00`00Oomoo`0ROol002Moo`03001oogoo01Aoo`03001oogoo00Moo`8P1`03
70Moogoo00Uoo`0A001^ePRDA[a6W4JlAYa>gD[LC]e>g4[MA[e6gAhLH[MR]P02H[L01S7j;OXanTkL
C]e:g09>g004C]e>g4kMC]`3<Wd01fKFJ]MVeV[F8GPUV25h009>g006C]e>g4kLC_aBoDkL0Tkl00YB
oDkLC_e>o4[MA[e6gDJmGWIJEP=NMP9GKP03B]a>g4Zl009:g005D_e>o5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0P00
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`DOol00`00Oomoo`0ROol001Eoo`@000Aoo`@000Io
o`03001oogoo01Eoo`03001oogoo00Ioo`0380PL1b0700Yoo`1]J]E^eV[E2;@4U4Jl@Ya6_DJLC]e:
g4kMB]`R7AhLI[MRUVJgHYIV]bgj<OX]nS8KC]a>oD[LC_e>g4kmB]a>oD[L=WdbG6[GI[IZefJf9ITQ
N2FH8GQBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MA[aNMUYEGWIJEU]^EdiKKTkLC_e>
g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_`00`0006YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03
001oogoo025oo`0057oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo
01Ioo`8000Ioo`0370LP1b0700Uoo`08=We^eVkEK]H4U0Rd29A:g@=:g006C]e:g4[MB]aR]f:f0f:g
00=R]V:gB[`00dZl00m>g4kMC]a>gDkLC]e>g4kMC]aZefKFJ]IVeV[GI]H00dZl00A6_4kLC]a>o@9>
g003C_aBoDkL009>o007C_e>g4kmC]a:gDJmA]d00Uif00=JEUif?U/00ciK00M>g4kmC]a>g5;lD_e>
o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aB
o5;l0`0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo01=oo`03
001oogoo021oo`006Goo00@007ooOol000Aoo`03001oogoo00=oo`8001Uoo`03001oogoo009oo`1e
70LP1a`780PP1gooB[a>gD[LC]e:_3ZM=We^eV[EK]IZe@Rd19@8]0BDC]e:_4kMB[a:gDJlB]e6_6Jg
HYIV]f:FI[MK/eoDA[a:_DJlC_e>g4kmB]a>oDZlB]e6_4[MB[aZefJfJ]MV]T=??bi:_DJlB[a6_5;m
C]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmB]a:gDJlGWIJEUifFUENMSiK?U`jFe;mC]a>oDkLD_e>o5;m
C]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l00<0001b
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol0
87oo000<Ool60007Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol06Woo00@007ooOomo
o`<P1`A2W00FB]a:gD[LB]dfOCZMK]E^eV[EK]I^e@Rd19@8]0RDC]e:g4kMC]a:gDJmA]d2H[L00f:f
H[MK/`02Fk<4B[`01DkMC]a>oDkLC]d00T[M00U:g4[MI]IZefKFJ]HUN2FH8GP00TkL00I>gDkLC_a>
g5;mC]`2C_`03U;mC]a>oDklC]e>g4kMC]`164JmGWINEUifFUH4?U/015;lC_aBoDkL0U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0`0000=Bo5;mD_`00U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eB
o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`EOol00`00Oomoo`0O
Ool001Eoo`@000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo01]oo`05001oogoo70LP
2002L]<0Jd9lAYe2W4:LB[a>gD[LC]eZeFkFJ]E^eV[EK]I6W4Jl@Ya6_DJLC]e:g4kmA[a:gDJlB]eR
UVJgHYIV]f:F<OX]nTkMB]a>gD[LC_e>g4kmC]a>oDZlB]e6_4[MI[IZefJfJ]LQN2FH8GQ>oD[LC]e:
g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4kmB]aNMUYEGWIJEUifFUE>gDZlC]e:_5;mC]aBoDkLD_e>
o5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_`00`0007UBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomo
o`0OOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`8001eoo`03000P1g;C
00=bd`E2W00EA[a:gD[MB]eZeFkFK]E^eV[E2;A6W4JlAYa6_4kLC]e:g4kMA[e:gDJm00=R]`03HYIR
]c7j008anP9>g007C]e:g4kLC]a>gDkLC]d0139m00IVeV[GI]HUV2Eh9IP3C]`05TkMC]a>o4klD_e>
g4kmC_aBoDkLC_e6_D[MA[e6gEiFGWIJEUifGUIGKUM>0T[L00I>g4ZlD_aBo5;mC_`2D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0<00003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l57oo00<007ooOol07Woo000E
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00fJf6EQoo`08
Ool0JWKCL]=bdg:bM]<02D[MB[a:gDZlB]e6_4[MA[a^eV[E>YeZeFkF19@8]4JLA[a2W4JmB]a>gD[L
C]dN728M7QaV]f:FI[MRUVJg;OXanRgjC_e>g4kmB]a>oD[LC_e:g4km<WdfOFJfJ]MV]V[GI[HUVB5h
9IQ>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlB]eJEUifFUENMUM=EfiGCE;mC]a>oDkL
D_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l0`00085Bo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
57oo00<007ooOol07Goo000EOol50003Ool40005Ool00`00Oomoo`0BOol02FKFI[HIF1UGB]e:_4[M
B[a:g@02?Yd5L]<200X01T[MB[a:gDZlB]e6_09:g@09>YeZeFkFJ]E^ePRD2;A:g4[M00=:g006C]e:
g4[MB]aR]f:F0f:g00=RUTZlB[`00TZl011>gDkLC]e>g4kMC]a>gDkLC]eVeV[GI]IZeVKFJ]M6_0=:
_0=>g00BC_e>g4klC_aBoDkLC_a>g4kmC]a>oDJmB]e6_EifGUINMUYF13iK0TkL00E>oDkLD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eB
o000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01=oo`8001mo
o`009Woo00<007ooOol04Goo00]ZefJfJ]LI=aUH6CM:gDZlB]e6_3jm009bd`0fL[9fdg;CL]<02@0:
00T02TZlC]e:g4kM=WdjWF[EK]IZeFkFJ]D8]0BD2;A:_4kMB[a>gDJlB]e6_4[MHYIV]f:FI[MRUU^c
Ek=:gDJlB[e6_4kmC]a>oD[LB]e:_4[MA[a:gFJfJ]MV]V[G0P0002a6_4ZmA[a:_4kLD_e>g5;mC]aB
oDkLD_e>g5;mB]a>oD[LC_e6_4[MFUENMUYFGWHjFciL?U/nG4kLD_e>g4kmC]aBoDklD_e>g5;mD_aB
oDkLD_eBo5;m0P0008QBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03001oogoo01ao
o`009Goo00<007oo00004Goo00EVeVJfI]MV]VKF008IF0056EM:gDZlB]e:_006L]<5@Y`05T[LB]e:
g3ZM=We^eV[EK]IZeFkF29@8]0RD2;A>g4kMB]a>gDJmB]e6_DKM0V:g00ARUU^cFk=K/`E:_004C]e>
g4kmC]`3B]d024[LJ]IVeV[GI]IZeREh9IP3C]`01TkMC]a>o4kLD_e>g09>o00=D_e>g4kmC]a>gDkL
C]d164[MFUINMUiFGWH013iK00E>g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@0300001E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Aoo`03001oogoo00Moo`D000moo`009Goo0P00
2Woo00<007ooOol01Goo00iV]V[GI[IZefJf6EPI=aUH6CM:gDJlB]e6_7KC0W;C05ab/WKCL]=2W49l
AYe2W4kMB[a>gD[LK]IZeFkFJ]E^eV[EA[e6W4Jl@Ya6_D[LC]e:g4kmA[a:gDJlI[MRUVJgHYIV]bgj
<OY:g4kMB]a>gD[LC_e>g4kmC]a:gDZlB]e6_6[GI[IZefJf9ITQN2FHB]a>oD[LC]e>g5;mC]aBoDkL
D_e>g5;mC]a>oD[LC_e:g4kmFUINMUYEGWIJETkMB[a>gDZlC]e>g5;mC]aBoDkLD_e>o5;m0`0008iB
oDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00Moo`05
001oogooOol0000?Ool002Eoo`03001oogoo00Uoo`8000Eoo`07I[IVefJfI]IV]T^BBg400dJl00E6
W4[MA[e:gDJl00Ibd`0600Y2W4:L@Ya:gDJl0T[M019^eV[EK]IZeFkFJ]E6_4JLA[a6W4kMC]a>gD[L
C]e6_D[MA[d3H[L01F:F<OXanS7jB]`00TkL00I>gD[LC]e>g4kMC]`4<Wd01f[FI]IZefKF9IPUN4kM
00=>g00FC]e>g4klC_aBoDkLC_e>o5;mC]a6gDJmB]e6_EifGUINMUYFGWIGCDkLB[`2B]`01DkLC_aB
o5;lD_d00`0000EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oE;lOol04goo00<007ooOol01goo00<007ooOol047oo000UOol00`00Oomoo`08Ool200005d:M@Ya2
WD:LA]e6_4KMI[IZefJfJ]MV]QUHBg56_D:LA[e2W4[MA[a:gDJlM]<00W;C05Ab/gKC00T02TZlB]e:
_4[MA[a:gDJlK]IZeFkFJ]E^ePBD2;E6W4Jl@Ya>gD[LC]e:g4kM7Q`R7F:FI[MRUV:gHYHb6bgj<OY:
g4kmC]a>oD[LC_e:g4kmB]`fOC9MJ]MV]V[GI[IZeb5h9ITQN4kmC]aBoDkLC_e>g5;mC]aBoDkLD_e>
g5;mC]a:gDJlB]e6_5ifFUINMU==EfiCCEM^C]aBoDkLC_d30000UU;mC]aBoE;lD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00Moo`03001o
ogoo00moo`009Goo0P0027oo0P000VkE14:L0dJm00]V]VKGI[IVeVJf6EPIEd[MB[a:gDZl00<nW@Eb
d`802P06B]e:_4[MB[a:gDJl0T[M00ljWF[EK]IZe@Rd29@8]4[LB]e:g4[MB]a>gD[LB]d00V:g00AR
UV:gH[MR]`A:_00>C]a>gDkLC]e>g4kMC]a>gDkLJ]IVeV[GI]IZeP800004A[a:_4ZlC_d3C]`04Dkm
C]a>o4klD_e>g4kmC]a>oDkLA]e6_D[MFUINMUiFGWH013iK0`0000EBoDklD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001B
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo019oo`03001o
ogoo00Qoo`03001oogoo00ioo`009Goo00<007ooOol01goo01Q^e6kEK[A^e@0>@Ye2W4:M@Ya6gDJl
A]dZGF[GI[IZeaTg6EPI=d[MB[a:gDJl?[d2L]<0D7:cM]=bdg;C00T02P09C]e:_4kMB]`jWCIm>YeZ
eFkFJ]E^eV[E2;@4U4kMB[a>gDZlC]e6_4[MA[a:gF:FH[MRUVJgEk9K/dJlB]e6_4ZmB]a>oDkLC_e6
_4[MB[a:gDJlJ]MV]V[GI[HUV@00B[a6_4ZmA[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oD[LB]e6
_5ifFUENMUYF?U`30000WDkmC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Aoo`03001oogoo00Qoo`03001oogoo00eoo`00
9Goo00<007ooOol01Woo00/fOFkEK]E^eFkDK]D03d[MA[a:_DJl008^G@05I]IV]VKGI[IVeP026EP0
1DZlB]e:_4[MB[`01g;C0d:L00]:gD[LB]e:g3ZM=We^eV[EK]IZeFkF0088]00929A>gDkLC]e:g4kM
A[e:gDJm00=R]`03Ek=K/e^c00E:_005C]a>gDkLC_e:g003B]d026KFJ]HbOF[GI]HUV2EhC]d3C]`0
4E;mC]a>o4kLD_e>g4kmC_aBoDkLC]e>g4kM0?L164JmGWH00`0013iK00EBoDkLD_a>o5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`EOol0
0`00Oomoo`03Ool01@00Oomoogoo00003goo000TOol09@00OomoogooA[e6W4Jm@Y`jWCImK]E^]6kE
K]A^eFjd00l03T[MA[a:gDJlJ]MV]V[GI[IZefJf6EPI=aUHA[a:gDJlB]e6_7KC009bd`18L[=bdg:c
@Ya2O4JMB]a>gDZlC]e:g6kFJ]E^eV[EK]H8U000AYa6_4:LC_e:g4kMB]a>oDJlB]e6_6JgEk9R]f:F
<Q/]nTkMB]a>gD[LC]e>g4kmC]a>oDkLB]e:_4[M<UaZefJfJ]LQN2FI8GQ>gD[LC_e:g5;mC]aBoDkL
D_e>g5;mC]aBoD[LC_e:g4km0`000:ANMUYEGWI:_4kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>o5;mC_aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007oo
Ool017oo0`0047oo000TOol300001f_eImE6_DJlA[dfOCJM009^e@05K]A^eFkEK]D03P0200l4A[d0
16KGI[IVeVJf0T]a14Jl00=:gDJmB]d01W;C00@02T:L@Ya2W09:g@0EA[a:gD[MK]IZeFkFJ]E^ePRd
A[a6W4JlAYa6_4[LC]e:g4[M7Q`N7AhL00=R]`<anP0:C]e:g4kLC]a>gDkLC]e>g4kMC]`2<Wd02F[G
I]IZeVKFJ]LUN2FHC]a>g@03C]`02U;mC]a>o4klD_e>g4kmC_aBoDJm0P0000ENMUYFGWINEUif009C
C@03B]a>g4Zl009:g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00Ool05goo000TOol0:P00Oom[mVOE
JoIWeDJmAYa6_FjdK]E^e6kEK[A^eFkD00m2W4:M@Ya6gDJlA]eV]V[GI[I;LVJf6EQ2W4Jm@Ya6_D:L
B]e6_4[ML[=bdg:cL]=b/`802P0nB]e:_4[MA[a:gDJlB]eZeFkFJ]E^eV[E2;@8U4kMB[a>gDZlC]e:
g4kMB]`R7AhLH[MRUVJgHYIR]bgj<Q/]nS7jB]a>oDkLC_e:g4kmB]a>oC9L=WeV]V[GI[IZefJf9IPQ
N2FIC]a>oDkLD_e>g5;mC]aBoDkLD_e>g0<0002[A[a:gDJlGWIJEEifFUIGCE==Efi>g4kmC]aBoDkL
D_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l01Aoo`03001oogoo01Eoo`006Woo10001Woo00@007ooOomoo`<b6`=6_@05K]A^
eFkEK]E^e002K]D3@Y`4A[d00fJf;UeV]P02I[H021UHB[a:gDZlB]e:_3jM>Yd5L]<300X02d[MB[a:
gDZlB]e6_4[M=We^eV[EK]H00`Rd0T[L00I:gD[LB]e:g4kMB]`3H[L00f:FH[MR]`05B[`03DkLC]e>
g4kMC]a>gDkLC]eVeV[FI]IZefKF00800005B[a6_4ZlC]a>o@03C]`00e;mC]`0000200002dkLC_e>
g4kmA[e6gEiFGWIJEUifGUH00ciK00=>g4kmC]`00TkL00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001B
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`COol00`00Oomoo`0E
Ool001Uoo`03001oogoo009oo`03001oogoo00=oo`0Z001oogooOolb6bhK<Q/^6dKMA[a6gFjdK]E^
e6kEK[A^e@0>@Ye2W4:MA[a6gDJl;WdZGF[GI[IZeaUG6EQ6_4[MB[a:gCZML]=b/g;CL[=bdg:c100:
03I>gDZlC]e:g3ZM=We^eV[EK]IZeFkF29@8]0RDC]e:_4kMB[a:gDJlB]e6_6JgHYIR]f:FFk=GTTZm
A[a:gDJlB[e>g4kmC]a>oDJlB]e:_4[MI[IZefJfJ]LQN000A[a:_4JlB[e>g5;mC]`300003TkLD_e>
g5;mB]a>oD[LC_e6_5ifFUIGCEYEGWH2?U/0XcYK?U`nFe;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03
001oogoo01Aoo`006Goo00<007ooOol00Woo00<007ooOol00goo0P000goo138K0dJm00E^e6kEK]E^
eFkD00803`03B]e6_4Zm00<^G@9V]P03I]MV]VJf008IF0046EM:gDZlB]d7L]<4@Y`02T[MB]a:gCIm
>YeZeFkFJ]E^eV[E10Rd00Q>gDkLC]e:g4KMA[e:gF:F0V:g00IK/eNBEk=G/U^cB]`2C]`01TkMC]a>
gDkLC_e:g09:g@0:J]MVeV[FI]IZebEh9IQ>g4kMC]`300005DkLC_a>g5;mC]a>oDklD_e>g4kMC]`1
64JmGWINEUifFUINMT[LC]a:_002B]`01E;mC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00DOol00`00Oomoo`0COol0
01Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`1HA[e6W4Jm@Y`jWCImK]E^]6kE
K]A^e@0>00m6_4[MA[a:gDJlJ]MV]V[GI[IZefJfA[e2W4Jm@Ya:gDJlB]eb/g;CL[=bdg:cL]=b/d:L
@Wa6WD:LC]e:_4kMJ]E^eV[EK]IZeFkFJ]E6_DJLA[a2W4kmB]a>gD[LB]e6_4[MHYIK/f:FH[L]nS8K
;OXanT[LC]e:g4kmC]a>oDkLC_e6_4[MB[`bOFJfJ]MV]RFH8GP30000^T[LC_e:g5;mC]aBoDkLD_e>
g5;mC]aBoD[LC_e:g5ifFUENMUYFGWIC;5M=B[a>gDZlC]e>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA=oo`03
001oogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00A6_DJlA[e6
_0=^e@03K]A^eFkE00<03`E6_@04I]MV]VJfI[H2Ag44A[`00d[MA[e:g@06L]<05`0:B]e:_4[MB[a:
gDJlB]eZeFkFJ]E^eV[EK]I6W4JlAYa6_4JLB]e:g4kMB]`00QhL00@N7AhLH[MR]`@anP09C]e:g4kL
C]a>gDkLC]e>g4kM008bO@03I]IZefJf00<000049GPUV4kLC_d3C]`045;mC]a>o4klC_e>g4kmC]a>
oDJmA]eNEUifFUINMUiF0U==0T[L00I>g4ZlB]aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04goo00<007oo
Ool04Woo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0D4KMA[a6gDJlK]E^
e6kEK[A^eFjd@Ye2W4:MA[a6gDJlA]eV]V[GI[IZefJfBg52W4Jm@Ya6_DJlB]e6_4[ML[=bdg:cL]=b
/`0;00Y:gDZlB]e6_4[MA[a:gF[EK]IZeFkFJ]D8]4ZlC]e:_4kMB[a>gD[LC]e:g28M7QaR]f:FI[MR
US7j;OXb6bgjC_e:g4kmC]a>oD[LC_e:g4kmI[H30000`FJfJ]M6_4ZlA[a:_DkLC_e>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLB]e6_4[MFUINMUYEEdeCC5==DbaBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
01Aoo`03001oogoo015oo`006Goo00<007ooOol00Woo00<007ooOol00Woo0P0027oo0dJm00M6_6kE
K]E^eFkDK]D03`04@Y`3A[d016JfI]MV]VJf0QUH00I:_4[MB[a:gCZM?Yd6L]<200X00dZlB]e:_003
B]d01TJlB]eZeFkFJ]E^eP88]0=:g006B]e:g4[MB]a>gD[L0f:g00=RUUNbEi8014Zl00I>gDkLC]e>
g4[MB]`3000016JfJ]IVeV[G0P000TZl00A6_4kLC]a>o@9>g00@C_aBoDkLC_a>g4kmC]a>oDkLB]e6
_EifGUICCEYFGWH3?U/2C]`01DkmC]a>g5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo019oo`03001oogoo015o
o`006Woo10001Goo00<007ooOol01goo00U6_4KMA[a6gFjdK]E^]6kEK[@00P0?01Q:gDJlB]e6_2iM
:U`^OFJfJ]MV]V[G6ELIF4JlB]e:_4[MA[abdg:cL]=b/g;CL[<200X09@0;B]a>gDZlC]dfOCZM=We^
eV[EK]IZeFkF29@8]0RDC_e:g4kMB]a:gDJlB]e6_6JgHYIR]eNBEk=GTTZmA[a:gDJlC_e>g4km0080
000RA[a:gDZlJ]MV]V[GI[IZe`00B[e6_4ZlA[aBoDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>oD[LB]e6
_5ifFUINMUYE?U`2?U/0Y3YKD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dBOol3000BOol000Eoo`80
0003Ool0000001Uoo`03001oogoo00Qoo`05A[a6_DJmA[e^e003K]D01VkD00l03d[MA[a:_@8^G@=V
]P03I]MV]QUH008IF005A[a:gDJmB]e6_006L]<3@Y`05d[LB]e:g4[MB]a^eV[EK]IZeFkFJ]E6_4JL
A[a6W4kMC]a>gDJmA]e6_D[MHYH00f:g0c7j00=>gD[LC]`00`0000A>gDkLC_e:g09:g@06J]MV]VKF
I]HUV2Eh0TkL00I>gDkLC_a>g5;mC]`2C_`03U;mC]a>oDkLC]e>g4kMC]aNMUYFGWINEUifFUH2B]`0
1TkLB[aBo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01=oo`03001oogoo011oo`0017oo00<007oo
Ool00P006Woo00<007ooOol02Goo00TfOCZMK[A^eFjdK]E^]6kE00h00P0?01M:gDJlB]eV]V[GI[IZ
efJfAg53D4Jm@Ya6_DJlB]e6_4[ML[=bdg:cL]=b/g;C0092W00N@Wa6WDJlB]e6_4[MA[a^eV[EK]IZ
eFkF29A6_DJLA[a:g4kmB]a>gDJlB]e6_4[MHYIV]f:FH[L]nS8K0`000<m>gD[LC_e:g4kmB]a>oC9M
=WdbGF[GI[IZefJf9IPQN4kmB]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eJEUifFUENMUYF
Dde?;4kMB[a>gDZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04goo00<007ooOol03goo0004Ool0
1@00Oomoogoo00006Goo0`0037oo0fkE00=^e6kEK]D014:L0dJm00=V]VKGI[H00VJf00<IF4M@A[`0
0TJl00A6W4[MA[e:g@Ebd`0400Y:_4[MB[`3B]d01dJlB]eZeFkFJ]EZeV[E0088]007A[a6W4JlB]a:
gD[LC]d00ahL00=R]f:FH[L00`000S7j00Q>gDkLC]e>g4kMC]a>gDkL0S9m0VKF00=ZefJfI]H00RFH
00@UN4kLC]a>o@9>g00CC_aBoDkLC_a>g4kmC]a>oDkLB]e6_DKMGUINMUYFGWICC5==Dd`00TkL00I>
oDkLD_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01=oo`03001oogoo00ioo`0017oo00D007ooOomo
o`0001Uoo`03001oogoo00eoo`04K]E^]6kEK[@2Ool0<d:M@Ya2WD:LA]e6_4KMI[IZefJfJ]MV]QeH
6CM:gDZlB]e6_3jm>Yebdg:cL]=b/g;C00X02dZlB]e:_4[MB[a:gDJlB]dfOFkFJ[E^ePRd3;D8U4kM
B[a>gD[LC]e:g4kMB]aV]`0300004fJgHYI:_DJlB]e6_4kmB]a>oDkLC_e:g4kmB]aZefJfJ]MV]V[G
0080000HA[a:_4JlD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[aNMUYFGWIJECiL0ciK0:IB
oDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1=oo`03001oogoo00ioo`0017oo00D007ooOomo
o`0001Uoo`03001oogoo00eoo`03K]A^eGoo00=oo`0300m2W4:L0092W0=6_@04;UeVefJfI[H26EP0
1AUGB]e:_4[M>Yd01W;C0`0:00a:g4[MB]a:gD[L>YdfOF[FJ]E^eV[EJ]H22;@3B]`00d[MA[e6g@03
0003H[L00f:FEi9GTP03B[`01dkLC]e>g4kMC]a:gD[L009:g@06J]MV]VKFI]HUV0000dZl00E6_4kl
C]aBoDkL009>o00=D_e>g4klC]a>gDkLC]e>g4[MFUINMUiFGWH013iK0dkL00E>oE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`015;mD_aBo5;l4goo00<007ooOol03Goo0003Ool20002Ool2000IOol00`00Oomoo`0DOol0
;00?B]e6_4[MA[`^GBYLJ]MV]V[GI[IZeaUG7EQ6_4[MB[a:gG:cL]=b/g;CL[=be7:c@Ya2O4JMB]a>
gDZlC]dfOCZMJ[E^eV[EK]IZ]@be2;@<]D[LC_d30000=D[MA[a:gF:FI[MRUUNbDi5G/U>BB[e6_4[M
C]a>oDkLC_e>g4[MA[a:gFJfJ]MV]V[GI[HUV25hC_e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e:g4km
B]a>o@3gB]eJEEifFUINMSiK?U`00SiK0:M>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
01=oo`03001oogoo00aoo`008Woo0P005Goo0P0?00E:gDJlB[e6_6KG00=V]P03I]MV]QUH008IF004
A[a:gDJmB]d6L]<5@Y`02d[MB]a:gF[EK]IZeF[FJ]E^ePRdA[`00`0000U>gDkLC]e:g4KMA[e:gF:F
Ei800V:g0c7j00m>gD[LC]a>g4kmC]a>gDkLB]e:g4[M<WeZefJfI]H00RFH00DUN4kLC]a>gDkL009>
o00BD_e>g4klC_aBoDkLC]e>g4kMC]a>gEiFGWIJEUifGUICC4Zl0T[L0TkL00=Bo4klD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo004D_eBo5;lD_`BOol00`00Oomoo`0<Ool0029oo`03001oogoo01Aoo`<03`0S
A]e6_4KMA[aZefJfJ]MV]TM@@e16_D:LA[e6_4[MA[a:gG:cL]=b/g;CK[=be4ZlB]e:_4[MB[a:gDJl
B]eZeFkFJ[E^eP030000iDJmAYa6_4[LC]e:g4kMB]`N7AhL7QeRUVJgHYHb6Rgj<Q]:g4kMB]a>gD[L
C_e:g4kmB]`bOC9MJ]MV]V[GI[IZebEh9IPQN5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gDJl
GWIJEUifFUECCDl/Dda:_4kMB[a>gDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01=oo`03
001oogoo00]oo`008Goo00<007ooOol05Woo0d:L0dJm00=V]VKGI[H00VJf00=7D4JLA[`00dJl00=:
gDJmB]d01G;C00@02dZlB]e:_0=:g@03A[aZeV[E00800003J]H8]0bd00=:g005B]e:g4[MB]a>g@02
7Q`2H[L00f:FH[MR]`03<OX02dkLC]e>g4kMC]a>gDkLC]e>g6[GI[H00VKF00=ZefJfB[`00TZl00E6
_4kLC]a>oDkL009>o00AD_e>g4kmC]a>oDkLA]e6_D[MA[eNMUiFGWI?;5</CbaCC003C]`01TkmC_aB
o5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l019oo`8000aoo`008Goo00<007oo00005Woo0212
WD:L@Ye2W4KMA[a6gFJfJ]MV]V[G6ELMF4JlB]e:_4[M>Ydn_G:cL]=^/g;DL[=bd`0:00]:_4[MB[a:
gDJl0`0002EZeFkFJ[D<]@Rd3;E:_4kMB[a>gDZlC]e:g4kMHYIV]f:FH[MRUUNbDi5:_DJlB]e>g4km
B]a>oDkLB]e6_4[MB[aZefJfJ]MV]P0200006DZmA[a:_4kLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkL
D_e6_4[MFUENMUYFGWHnFciL008nF`2YC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`04goo00<007ooOol02Woo000QOol2000HOol02D[MA[a:_DJl;UdZGBiMI[IVe`02I[H01aUH7EQ:
_4[MB[a:gDZl00Ibd`0400/02P0;B]`300001cIm>YeZeF[FJ]E^eV[E0088]00:3;A:g4kMC]a>gD[L
A]e6_D[MHYH2H[L00eNBDi5GTP04B[`02dkLC_e>g4kMC]a:gD[LB]eVeV[GI[H00VKF00<UV2EhB[`0
0TZl00E>g4klC]aBoDkL009>o00<D_e>g4kMC]a>gDkLC]e6_D[MFUINMUiF1CiK00A>g5;lC_aBo@=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04Goo0P002goo000?Ool40004Ool40006Ool00`00
Oomoo`0HOol064[MA[a:gBYM;UeV]V[GI[IZefJf7EPIEaeHA[a:gDJlB]e6_7;DL[=bdfjcL]Ab/`<0
003cB]a>gDZlC]eZeFkFJ[E^eV[EK]I2W4JmAYa6_4[LC_e:g4kMA[a:gDJlH[MRUVJgHYIR]bgj<Q]:
g4kMB]a>gDkLC_e>g4kmC]a:gDJlB]eV]V[GI[IZebEh9IPUN4kmB]a>gDkLD_e>g5;mC]aBoDkLD_e>
g4kmB]a>oD[LC_eJEUifFUENMUYFC]e:_4kMB[a>gDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l00ioo`<00003Ool007oo00Yoo`003Woo00<007ooOol00Woo00@007ooOol000Aoo`03
001oogoo00=oo`03001oogoo01Uoo`05B]e6_4ZmI[IVe`03I[H00d=@@dm6_003A[`00d[MA[e:g@03
L]<30004@Y`2B]d05dJlB]eZeFkFJ]EZeV[E3;E6W4JlAYa6_4[LC]e>g4kMA[e6gDJmH[MRUV:gHYL0
0c7j00=>g4kMB]`00TkL00A>gDkLC]e>g0<bO@04I]IZefJfI]H29IP3C]`05TkMC]a>o4klD_e>g4km
C_aBoDkLA]e6_D[MA[eNMUiFGWIJEUifCba>g4Zl0T[L00E>g4klD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoGooOol027oo100017oo00<007ooOol02Goo000COol01000Oomoo`0017oo00<0
07ooOol00goo0P006goo0116gDJlA]eV]V[GI[IZefJf7EQ3;dJm@Ya6_D:LB]e6_0<0003jL[=bdfjc
00]:_4[MB[a:gDJlB]e6_4[MJ]E^eVZeK]H8]0be@Ya6_DJLA[a:g4kMB]a>gAWl7QeRUV:gHYIV]f:F
<QX]nS8KC]a>oD[LC_e:g4kmB]a>oC9M<WeV]V[GI[IZefJf9ITUN2FHC]aBoDkLC_e>g5;mC]aBoDkL
D_e>g5;mC]a:gDJlB]e6_5ifFUINMTl[Dda?;5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d6Ool30008Ool00`00Oomoo`09Ool001=oo`04001oogoo0004Ool00`00Oomo
o`02Ool2000MOol3A[d00fJfI]MV]P02I[H011eH6EQ:gDZl0`0000<jWG;CL]<00g;C00D02P0;B[a:
gDZl00=:g@08A[a:gF[EK]IZe@bd2;@<]@=:g00;B]e:g4[MB]a>gF:FH[MRUf:gHYIR]`04B[`02dkL
C]e>g4kMC]a>gDkLC]eVeV[GI[H00VKF0P000dZl0dkL015>oDkLC_a>o5;mC]a>oDkLC_e>g4KMA[e:
gEYFGWINEUif00<nF`05C_e>g4kLC]a>o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l
0goo0`0037oo00<007ooOol027oo000?Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0MOol024KMA[a6gBYMI]MV]V[G6EL30000DDZlB]djWG;DL[=bdfjcL]Ab/`0;00X02d[LC]e:
_4kM=WdjWCImK]IZeFkFJ[D<]@Rd3;E:_4kMB[a>gDJlB]e6_4[MHYIV]f:FH[MCLENBA[a:_DJlB]e>
g4kmB]a>oDZlB]e6_4[MI[IZefJfJ]LUN000A[a:_DJlB[a>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e:
g4[MA[aNMUYEGWIJEP02?U/0[SiL?U]BoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo08000moo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol07Woo00@^GBYMI[IV]P<000066EPMF1UHB]e:_4[M1g;C0d:L01Y:g4[MB]a:
gCImK]IZeF[FJ]E^ePRd3;@8]0beB]a>gDkLC]e6_DKMA[eR]f:FH[MRUf:g0S7j00=>g4kMB]`00TkL
00=>oDkLC]d00T[M00I:g6KFI]IZefJfI]H29IP3C]`03DkMC]a>o4kLD_e>g4kmC_aBoDkLC]e>g4kM
0080m`07A[eNMUYFGWIJETkLB[`00T[L00EBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00ABoE;lD_aBo11oo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol07goo0?mVe`00001V]VKGI[I6_D:LA[e2W4[MA[a:gFjcL]Ab/g;CK[=be4:L
AYa2O4JLB]a>gDZlC]eZeFkFJ[E^eV[EK]I2W4JmAYa6_4[LC_e:g4kMA[a:gDJlH[MRUVJgHYHb6Rgj
<Q]:g4kMB]a>oDkLC_e>g4kmB[a:gDJl<WeV]V[GI[HUVBEh9IQ:g4kmB]a>gDkLD_e>g5;mC]aBoDkL
D_e>g4kmB]a>oEYEGWIJEUifFUE?;4l[C]e:_4kMC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoDkl
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_d000eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo00?Ool00`00Oomoo`08Ool000moo`D000=oo`@000Eoo`8001ioo`<0
0006I]MV]VJfI[HMF3l_14Jl00=:gDJmL]<01G;C00@02dZlB]e:_0=:g@0@A[a:gF[EK]IZeF[FJ]D<
]DJLA[a6W4JlB]a:gD[LC]d37Q`016:gHYIR]f:G0c7j00Q>g4kMB]a>gDkLC]e>g4kM0S9m00EV]VKF
I[IZefJf00<UV0=>g00JC_e>g4klC_aBoDkLC_e>g4kmC]a6gDJmGWIJEUifFUINMTl[Cba:g4kLB[a:
g5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo0moo`03001oogoo00Qo
o`0087oo00<007ooOol06Woo0`000goo00=V]VKGOol00Woo0?lMF1UGA[e2W4JmA[a:gDJl?Ye^/g;D
L[=bd`0:00]:_4[MB[a:gDZlB]e6_6kFJ]E^eVZeK]H8]0beB[a>gDZlC]e:g4kMB]`N7AWlI[MRUV:g
HYIV]dJlB[e6_4[MC]a>oD[LC_e:g4kmB]a>oFJfJ]MV]V[GI[IZedJlB[e6_4ZlC]aBoDkLC_e>g5;m
C]aBoDkLD_e>g5;mA[a:gDJlGWIJEEifFUINMSiK?Ua>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d000QBo5;mD_aBoE;lD_eBo5;m3Woo00<007ooOol027oo000POol00`00Oomoo`0GOol3
000;Ool021UH7EPIF4[MB[a:gCZM?Yd5L]<300/03T[LB]e:g4[MB]`jWCImJ]IZeFkFJ]EZePbd3;D3
B]`02d[MB]a:gD[LH[MRUV:gHYMR]e=aDi400dZl00E>gDkLC]e>g4kM009:g@09B]a:gFJfJ]MV]VKF
9IP004Jl00=:_005C]a>o4kLD_e>g002C_`035;mC]a>oDkLC_e6_DKMFUINMTl[GWIJEP<nF`06C]a>
oDkLC]aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l
00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00=Ool00`00
Oomoo`08Ool001moo`03001oogoo01Eoo`<000moo`1E6ELMF4JlB]e:_4[MA[abe7:cL]=^/g;DL[=6
W49lAYa:g4kMB[a>gCIm>YeZ]FkFJ]E^eVZe3=D8]0beB]a>oD[LC]e6_4[MA[aR]f:FI[MCLE>ACg5C
TDJlB[e6_4kmC]a>oDkLC_e:_4[MA[aZefJfJ]MV]RVI9GPUVD[LC_e:g4kMC]aBoDkLD_e>g5;mC]aB
oDkLC_e:g4kmA[a:gEYFGWIJEEifFUH00SiK0;4nG4kLD_e>g5;mC_aBoDkLD_e>o5;mC_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d03Goo00<007ooOol01goo000OOol2000COol3000BOol021eH
6EPMF4JlB]e6_D[MA[`3L]<00g:cL]=2W004@Y`064[MB]a:gF[EK]IZeF[FJ]E^ePbdA[a6W4JlB]a>
gDkLC]e6_DKMHYMR]e=aH[MRU`<anP08C]a>gD[LC]e>g4kmC]a>g@9:g@04B]aVeVJfJ]L49IP3C]`0
4TkMC]a>o4klD_e>g4kmC_aBoDkLC]e>g4kMFUINMUYFGWIJEP9?:`06C]a:_4[LC_aBoDkL0U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol037oo00<007ooOol01goo000O
Ool00`00Oomoo`0?Ool3000FOol0odJm@Ya6_DJlB]e6_4[MK[=be7:cL]=^/g;DB[a:gDZlB]e:_4[M
A[a:gF[EK]IZ]FkFJ[D<eD:LA[e6W4JlB]a>gD[LC]dIo1hM6QaR]f:FI[LanS8J<OY>gD[LC]e:g4km
B]a>oD[LC_dbGC9mI[IZefJfJ]LUN2VI9GPUVDkLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDJlB]e6_5if
FUENMUYFGWI;2dl/B[a>gDZlC]e>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@002E;lD_eB
o5;mD_aBoE;lD_eBo00<Ool00`00Oomoo`07Ool001moo`03001oogoo00aoo`<001]oo`96_005AYa:
gDJmB]eb/`03L]<01G:c00]:_4[MB[`00d[M00Q6_6[FJ]E^eV[EJ]H<]0be0d[L00A:gD[LB]e:g08N
7005H[MRUf:gHYIR]`03<OX044kMC]a>gDkLC]e>g4kMC]a>gFJfJ]MV]VKFI[I:_4Jl0dZl0dkL00m>
oDkLC_a>o5;mC]a>oDkLC_e6_DKMA[eNMUYFGWH00Tl[00A;:dl[C]a>o@9>g003D_aBoDkl009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Yoo`03001oogoo00Moo`00
7goo00<007ooOol02Goo0`007goo00Y:_4[MA[`n_G:cL]=^/g;DL[=bd`<02`13B]e:_4[MA[a:gDJl
K]IZ]FkFJ[E^ePRd3=E:_4kMB[a>gD[LC]e:g6:gHYIV]f:FH[M?L5>AA[a:_DJlC_e>g4kmB]a>oDZl
B]e6_4[MI[IZefJf:IT004ZlA[a:_DJlB[a>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MFUINMUYE
GWH00ciK0;@nO4kLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`:Ool00`00Oomoo`07Ool001moo`8000Qoo`80029oo`04B]e:_4[MB[`3L]<00g:cL]=b
d`04@Y`02T[MB]a:gCIm=YeZeF[FJ]E^eV[E0Pbd00h<]D[LC]e>g4kMA[e6gDJmH[MRUV:gCg5CTDm`
14Zl00E>gDkLC_e>g4kM009:g@05B]aVeVJfJ]MV]P029IP02TkMC]a>g4kLC]e>g4klC]aBoDkL0Tkl
00YBoDkLC]e>g4kMA[e6gEYFGWIJEPDnF`03C_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol027oo00<007ooOol01goo000NOol00`00Oomoo`05
Ool3000UOol0od[MA[a:gDJlL]Ab/g;CK[=be6jcAYa2O4JLB]a>gDZlC]eZ]FkFJ[E^eVZeK]H8]4Jm
AYa6_4[LC_e:g4kMA[a:gF:FH[M?L6:gHYHb6S7jC]e:g4kMB]a>oDkLC_e>g4kmB[a:gDJlJ]MV]V[G
9GPYVBEhC]e:g4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>oEYEGWIJEUifFUE>gDZlC]e:_4kM
C]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0025;lD_eBo5;mD_aBoE;lD_d:
Ool00`00Oomoo`06Ool001ioo`03001oogoo009oo`<002Uoo`04B]e6_D[ML[<3L]<00g:cL]<02`03
@Y`2B]d04DJlB]eZeFkFJ]EZeV[E3;E6W4JlAYa6_4[LB]e:g4kM6Q`00QhL00=R]f:FH[L00c7j0TkL
00M>gD[LC]e>g4kMC]a>g@02<Wd016JfI]IV]V[G12FH0dkL019>oDkLC_a>o5;mC]a>oDklD_e6_DKM
A[eNMUYFGWIJET/[B`/2B]`01TkLB[a:g5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`015;mD_aBo5;l2Woo00<007ooOol01Woo000NOol00`00Ool00002000]Ool0od[M
A[a:gFjcL]A^/g;DK[<0300;B]e:_4[MA[a:gDJlK]IZ]FkFJ[E^ePbd3=E:_4kMB[a>gD[LC]e:g1hM
6OaR]f:FH[MRUV:g<OXb6S7jC_e>g4kmB]a>oD[LC_e:g4kmI[IZefJfJ]MV]TZlA[a:_DJlB[a>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[aNMUYEGWI;2dl[B`YBoDkLD_e>g5;mC]aBoDkLD_eBo5;m
C]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@001e;lD_eBo5;mD_aBoE;l00Uoo`03001oogoo00Io
o`007Woo0`00<7oo00@nWG;CL]=b/`=bd`<02`03B]e:_4[M009:g@08A[aZeV[EJ]IZeF[F3;@<]@=:
g009B]e:g4[MB]aR]f:FH[MRUf:g009?L0=:_005C]e>g4kMC]a>g@02B]d01D[LB]eV]V[GI[H00P00
00=:_4JlB[`00TZl0dkL00mBoDkLC_a>o4kmC]a>oDkLC_e6_DKMFUINMUYFGWH00ciK0TkL00E>oDkL
C]aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006
D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l27oo
00<007ooOol01Woo0004Ool50003Ool40004Ool40007Ool00`00Oomoo`0`Ool0CG;DK[=be6jcL]A^
/dJL@Wa6W4:LC]e:_4kM=WdjWFZeK]IZ]FkFJ[D<e@bd3=E:g4kmB]a>gDJlB]e6_6:gHYIR]dm`Di5?
L4[MA[a:_DJlC_e>g4kmC]a>oDZlB]e6_6[GI[IZefJf:ITUN4kMB]a>gD[LC]e>g5;mC]aBoDkLD_e>
g4kmB]a>oD[LC_e6_4[MFUINMUYE?W`00ciK0;IBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l1goo00<007ooOol01Woo0006Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol01Goo0P00<Goo0g;C00=b/gooOol0
0d:L01U:g4[MB]a:gF[EJ]IZeF[FJ]EZePbdA[a6W4JlB]a>gDkLB]e6_DKMHYMR]dm`H[MRU`02<OX2
C]`01dkMB]a>gDkLC_e>g4kM009:g@04B]aVeVJfI]L39IP05TkMC]a>g4kLD_e>g4klC]aBoDkLC_e>
o4kMC]a>gDkLC]eJEUifFUINMUYF0T[L00I>g4ZlD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l1goo00<007ooOol01Woo0006Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol01goo00<007ooOol0;Woo00=^/g;D
Ool00goo04D02dJL@Wa6W4JlB]e6_4[MJ[E^eVZeK]IZ]@cE@Ya6_DJLA[a:g4kmB]a:gDJlB]dIo1hM
HYIR]c7j<QXanTkMB]a>gD[LC_e:g4kmB]a>oC9M<WeV]V[GI[IZebEh:ITUN4kMB]a>gD[LD_e>g5;m
C]aBoDkLD_e>g4[MA[a:gDJlGWIJEEifFUH00P000;U>gDZlC]e:_5;mC]aBoDkLD_e>o5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00Ioo`03001oogoo00Ioo`00
1Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Qoo`03001oogoo
03=oo`802`03B]e:_4[M009:g@08A[aZeV[EJ]IZeF[F3;@<e@=:g00;B]e:g4[MB]`N71XL7QaRUf:g
HYIR]`03<OX044kMC]a>gDkLC]e>g4kMC]a>gFJfI]MV]VKFI[I:_4Jl0TZl00I>oDkLC]a>g5;mC]`2
C_`02TkmC]a>oDkLB]e6_DKMFUINMUYF10000TkL00I>oDkLD_aBo5;mC_`2D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`06Ool00`00Oomoo`05Ool0
00Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`09Ool00`00Oomo
o`0bOol0AP0;00`02d[MB[a:gDJlB]e6_3ZMJ[E^eVZeK]H<]0cEB[a>gDZlC]e:g4kMB]a>gF:FH[MR
UV:gBg1?L4JlB[e6_4kmC]a>oD[LC_e:_4[MA[a:gFJfJ]MV]RVI001:_4JlB[e6_4kmC]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4[MA[a:gEYFGWIJEEif0ciK0;QBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Ioo`03001oogoo00Eoo`001Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Yoo`80039oo`A2W00H
B]e:g4[M=WdfWF[EJ]IZeF[FJ]D<]@bd3=E:g4kMC]a>gDJmA]e6_D[MHYIR]f:G0Tm`14Zl00E>gDkL
C_e>g4kM009:g@05B]aVeVJfI]MV]P029IP02TkMC]a>g4kLD_e>g4klC]aBoDkL0Tkl00Y>gDkLC]e>
g4[MA[eNMUYFGWIJEP@nF`04D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol017oo00<007ooOol01Goo0004Ool30004Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol037oo00<007ooOol0<7oo0?m6W49lAYa2W4kMB[a>
gD[LK]IZ]FkFJ[E^ePbdA[e6W4JlB]a>oD[LC]e:g4[MA[aR]f:FH[MRUS8J<OY>gD[LC]e:g4kmC]a>
oDkLC_e:_4[MA[aZefJfJ]LUN2VI9IQ>gD[LC]e:g4kMC]aBoDkLD_e>g5;mC]a>oD[LC_e:g5ifFUEN
MUYFGWIJEDkMB[a>gDZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d000=Bo5;mD_`017oo00<007ooOol01Goo0006Ool00`00Oomoo`03Ool4
0004Ool4000@Ool00`00Oomoo`0`Ool01T[MB[a:gDZlB]e6_09:g@0CJ]IZeF[FJ]D<eDJLA[a6W4Jl
B]a:gD[LC]e:g1hL6Q`N76:FH[L00c7j0TkL00M>gD[LC]e>g4kMC]a>g@02<Wd016JfI]IV]VKG0bFH
00I>oDkLC]a>g4kmC]`2C_`035;mC]a>oDklB]e6_DKMFUINMUYFGWIJEP80009:g006C]a:_5;lD_aB
oDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003
D_eoogoo009oo`03001oogoo00Eoo`00:Goo00<007ooOol0<7oo049:gDZlB]e:_4[MA[a:gFZeK]IZ
]FkF3;@<eDZlC]e:_4kMB]a>gD[LC]dIo1hMHYIR]f:FH[LanS8J<OY>oDkLC_e:g4kmB]a>oD[LC_eV
]V[GI[IZefJfB[a6_4ZmA[a>oDkLD_e>g4kmC]aBoDkLD_e>g5;mC]a:gDJlB]eJEUifFUD40000^e;m
C]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m00=oo`03001oogoo00Eoo`00:Woo00<007ooOol0<Goo00a:_4[MB[a:gDJlB]eZ
eF[FJ]EZePbd3=D3B]`02d[MB]a:gD[LC]eRUV:gHYMR]d]_Cg000dZl00A>gDkLC]e>g0=:g@09B]a:
gFJfI]MV]RFH001:_4Jl009:_006D_e>g4klC]aBoDkL0Tkl00Y>oDkLC_e>g4[MA[eNMUYFGWIJEP@n
F`9>g005C_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l0goo00<007ooOol01Goo000[Ool2000bOol0@TZlC]e:g3ZMJ[E^eVZeK]IZ]A3E
3;@<eD[LC_e:g4kMA[a:gDJlB]eRUV:gHYI?L4]?Cg16_4ZmA[a>oDkLC_e>g4[MB[a:gDJlJ]MV]V[G
I[HYVBFHC]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmB]a:gDJlGWIJEUifFUE2O0<nF`2jD_e>
g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l0goo00<007ooOol017oo000]Ool00`00Oomoo`0`Ool05D[LB]e:g6[FJ]EZeV[EJ]H<
]4JlAYa6_4[LC]e>g4kMB]a6gDJmH[MRUP02HYL3<OX024kLC]e:g4kMC]a>oDkLC]d2B]d014[LI[IV
]VKG0bFH00I>gDkLC]a>g5;mC]`2C_`03U;mC]a>oDklC]e>g4kMC]aNMUYFGWIJEUif0002B]`01TkL
B[aBo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00ABoE;lD_aBo09oo`03001oogoo00Aoo`00;Woo00<007ooOol0<7oo03i6_4[MA[a^eVZe
K]IZ]FkF@Ya6_DJLA[a:g4kMB]a>gD[L7QdIo1hMHYIR]c7j<QXanTkMB]a>gD[LC_e:g4kmB]a>oC9M
<WeV]V[GI[IZebEh:ITUV4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gEYFGWIJEEif0P000<5:
_4kMB[a>gDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lOol00006Ool002moo`03001oogoo031oo`08A[a:gF[EJ]IZeF[F
J]D<e@=:g00;B]e:g4[MB]a>gAXL7QaRUf:gHYIRU`03<OX02dkMC]a>gDkLC]e>g4kMC]a>gFJfI]L0
0fJf00E:_4JlB[a:_4km00=>g00?D_e>g4klC_aBoDkLC_e>g4[MA[e6gEYFGWIJEUiF008nF`=>g006
C_e>o5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo7oo00001Woo000`Ool2000aOol0?SIm>YeZ]FkFJ[E^ePbd4=E:_4kMB[a>
gDZlC]e:g4kMHYIR]f:FH[M;Cdm`A[a:_DJlC_e>g4kmB]a:gDZlB]e6_4[MI[IZefJfJ]L004ZlA[a:
_DJlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_5ifFUINMUYE@W`2?U/0_dkLD_e>g5;mC]aBoDkl
D_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m00001Woo000bOol00`00Oomoo`0^Ool04SJM=WeZeV[EJ]IZe@cE3;@<eD[LC]e>g4kMB]a6
gDJmB]eRUP9RU`03H[LanS7j00=:_004C]e>g4kmC]`3B]d01D[LI[IV]VKGI[H00RFH01I>gDkLC]a>
g5;mC]a>o4kLD_e>g4kmC_aBoDkLC]e>g4[MA[eNMUYFGWIJEP<nF`04C]aBo4klD_d3D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`00goo00<0
07ooOol017oo000cOol00`00Oomoo`0^Ool0mVkFJ[E^eVZeOol<]4JmAYa6_4[LC_e:g4kMB]a:gDJl
H[MRUV:gHYHb6S7j=Q]:g4kMB]a>oDkLC_e>g4[MB[a:gDJlJ]MV]V[GI[HYVBFHC]e:g4kMB]aBoDkL
D_e>g5;mC]aBoDkLC_e:g4kmB]aNMUYEGWIJEUif001>gDZlC]e>g5;mC]aBoDkLD_e>o5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Qoo`03001oogoo00=oo`00=7oo
00<007ooOol0;Woo00=ZeV[EOol00Woo00T<]4JlAYa6_4JLB]e:g4kMB]`00QXL00AR]f:FHYMRU`<a
nP07C]a>gD[LC]e>g4kMC]`00S9m00EVefJfI[IV]VKG00<UV006C_e>g4kLC]aBoDkL0Tkl00]>oDkL
C_e>g4[MA[e6gEYFGWIJEUiF00<0009:g006C]a>o5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01@00D_aBo5;lD_d00e;l00=BoGooOol02Woo00<007ooOol00goo000eOol2000cOol07a3E3;A>
gDZlC]e:_4kMB]a>gD[LH[MRUV:gHYIR]dJlB[e6_4[MC]a>oD[LC_e:g4kmB]aZefJfJ]MV]V[G0080
000FA[a:_DJlC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MFUINMUYEGWH3?U/0[e;mC]aBoDkL
D_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m00moo`03001oogoo00=oo`00
=goo00<007ooOol0<7oo00<<eA3E3;@00T[L00I:gD[LA]e6_D[MA[d2HYL00f:gBdm;C`04B[`00dkL
C]e>g003B]d014[LI[IV]VKG0VJf00<004ZlA[`00TZl00IBoDkLC_a>g5;mC]`2C_`02TkMC]a>gDkL
B]e6_EiFFUINMUYF13iK00ABo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_`005;m
D_`AOol00`00Oomoo`03Ool003Qoo`03001oogoo02moo`0aA[e6W4Jl@Ya>oD[LC]e:g4[MA[a:gF:F
H[MRUV:g<OXf6d[LC]e:g4kMC]a>oDkLB]e:g4[MI[IZefJfJ]MV]RVI9IQ>gD[LC]e:g5;mC]aBoDkL
D_e>g5;mC]a>oD[LC_d00P3F0;=6_5ifFUINMUYEC]e:_4kMB[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00019oo`03001oogoo00=oo`00>Goo00<007ooOol0;goo00a6_4JLA[a6
W4JlC]a>gD[LA]e6_D[MHYH2HYL3<OX00dkLC]e:g002C]`00dkmC]a:g@02B]d01C9mI[IV]VKGI[H0
0RFH00I>gDkLC]a>g5;mC]`2C_`035;mC]a>oDklC]e>g4kMFUINMUYFGUIJEP80009:g006C]a:_5;l
D_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`4Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003Yo
o`80031oo`0dC]e:_4kMB[a>gD[LC]e:g1hM6OaR]f:FH[MRUS8J<OXf6dkLC_e:g4kmB]a>oD[L<Wdb
GF[GI[IZefJfJ]LUN2VI9IQ>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eJEUifFUD30000YDkL
D_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo008Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003ao
o`03001oogoo02ioo`9:g006B]e:g4[LB]a>gD[L0V:G00AR]f:FBdm7C`=:_007C]a>gDkLC]e>g4kM
C]`00VJf00IVefJfI[HUV000A[`2B[`01TkmC]a>g4kLD_e>g09>o00:C_e>g4kmC]a:gDJmGUIJEUif
FUH3?U/3C]`01DkmC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoE;lOol03goo00<007ooOol03goo00<007ooOol00Woo000mOol00`00Oomo
o`0_Ool0=4[LC]e:g4kmA[a:gDJlH[MRUV:gAbi;CdJlB[e6_4[MC]a>oDkLC_e:g4[MA[aZefJfJ]MV
]RVI9IPYVDJlB[e6_5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e:g4[MA[aNMUYFGWHnFd9l0SiK09U>g5;m
C]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`057oo00<007ooOol03Woo00<007ooOol00Woo000nOol00`00Oomoo`0_Ool01dkLC]e:g4kMA[e:
gF:F009RU`06H[LanS7jC]a>gD[L0TkL00=>oDkLC]d00T[M0fJf00EVefJf9IPUV2VH00=>g00BC]e>
g4klC]aBoDkLC_e>o4kMC]a>gDkLGWIJEUiFFUINMTZl0T[L0TkL00=Bo4klD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d06Goo00<007ooOol03Goo00<007ooOol0
0Woo000oOol00`00Oomoo`0_Ool0<4[LC]e:g4kM6O`N7AWlH[MRUS8J<OXf6d[LC]e:g4kMB]a>oD[L
C_d^GC9mI[IZefJfJ]LUN2VI9IQBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eJEUifFUENMP80
002DB[a>gDZlC]e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dL
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool0041oo`80031oo`03B]a>gD[L008J7004H[MRUV:GHYL3
<OX02TkLC]e>g4kMC]a>gDkLC]eV]VKG0fJf00E:_4JlB[a:_4km00=>g00?C_e>g4klC_aBoDkLC_e>
g4[MA[e6gEYFGWIJEUiF008nF`=>g005C_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m021oo`03001oogoo00aoo`03001oogoo009oo`00@Woo00<007ooOol0;Woo031:g4kMB]aR
]f:FH[MRUT]?Abi:_DJlB]e>g4kmB]a>oD[LB]e6_4[MI[IZefJfJ]L004ZlA[a:_DJlD_e>g5;mC]aB
oDkLD_e>g5;mC]aBoDkLB]e6_5ifFUINMUYE@W`3?U/0RU;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo2Eoo`03001oogoo00]oo`03001oogoo009oo`00@goo00<007ooOol0;Woo00=6_D[M
A[d00V:G00AR]f:F<OXanP=:_004C]a>oDkLC]d2B]d024[LI[IV]VKGI[HYV2FHC]d3C]`04U;mC]a>
o4kLD_e>g4kmC_aBoDkLC]e>g4[MA[eNEUYFGWIJEP9:g006C]a:_5;lC_aBoDkL0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo2Qoo`03001oogoo00]oo`03001oogoo009oo`00A7oo00<007ooOol0;Woo02e6_4[MHYIR
]f:FH[LanSHK<OY>gD[LC]e:g4kmC]a>oD[LB]e6_6[GI[IVefJf:ITUV4kMB]a>gD[LD_e>g5;mC]aB
oDkLD_e>g5;mB]a>oD[LGWIJEEifFUH00P0008E>gDZlC]e:_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0]Ool0
0`00Oomoo`0;Ool00`00Oomoo`01Ool004Eoo`8002moo`8J7004HYIRUf:GH[L3<OX01dkMC]a>gDkL
C]e>g4kM008bO@=V]P05I]LUV2VH9IQ>o@03C]`03e;mC]a>o4klC_e>g4kmC]a>oDJmA]eJEUifFUIN
EP030002C]`01TkmC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo35oo`03001oogoo00Yoo`03001oogoo005oo`00Agoo00<0
07ooOol0;Goo01ARUV:gHYIR]f:FB[e6_4[MA[a>oD[LC_e>g4kmB]a>oFJfI]MV]V[G0P0001I6_4Zm
A[aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlGWIJEUifFUE2O0<nF`1mD_e>g5;mC]aBoDklD_e>
g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0eOol0
0`00Oomoo`09Ool00`00Oomoo`01Ool004Qoo`03001oogoo02eoo`03HYMR]f:F0097;PA:_009C_e>
g4kMC]a:gD[LB]eV]VKG009V]P039IPYV4Jl009:_006D_e>g4klC]aBoDkL0Tkl00Y>gDkLC]e>g4[M
A[eNEP00GWIJEP<nF`05C]aBo4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eBo7oo03Qoo`03001oogoo00Uoo`03001oogoo005oo`00BGoo00<007oo
Ool0;7oo0:AR]f:FH[MoocHK<OY>gD[LC]e:g4kmC]a>oDkLB]e6_6[GI[IVefJf:ITUV2VIB]a>gD[L
C]e>g5;mC]aBoDkLD_e>g4kmB]a>oD[LB]eJEEifFUINMTZlC]e:_4kMC]aBoDkLD_e>g5;mC_aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l?Goo00<007ooOol027oo00<007ooOol0
0Goo001:Ool2000]Ool00f:GOomoo`03<OX024kMB]a>g4kLC]e>g4kMC]`2<Wd2I[H01FJgI[HYV2FH
:IP00dkL00m>oDkLC_a>o5;mC]a>oDklB]e6_DKMFUINMUYFGUH00P0000E:_4[LB]a>g4kl009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo45oo`03001oogoo00Moo`03001o
ogoo005oo`00C7oo00<007ooOol0;Woo02HanSHK<OY>oD[LC_e>g4kmB]a>oD[LI]MV]V[GI[IVedJl
B[e6_4ZlC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gEYFGWIJEEif0SiK071>g5;mC]aBoDkLD_e>
g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoDIoo`03001oogoo00Ioo`03001oogoo005oo`00
CGoo00<007ooOol0;Woo14Zl00E>g4kMC]a:gD[L009:g@06I[MV]VJfI[H004Jl0dZl00E>g4klC]aB
oDkL009>o00:D_e>g4kmC]a:gDJmGUIJEUifFUH4?U/2C]`01DkmD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00=BoGooOol0Agoo00<007ooOol01goo0@000Goo0Goo001>Ool00`00Oomoo`0^Ool0T4[LC]e:
g4kMC]a>oDkLB]e6_4[MI[IVefJfJ]LUV2VIB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LB]e6
_5ifFUINMUYEC]e:_4kMB[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoDeoo`03001oogoo00Ioo`40
005oo`5oo`00Cgoo0P00;goo00a:g4kLC]a>gDkLC]e>g4[MB]a:gFJfI[L2I[H2:IP3C]`044kMC]a>
o4klD_e>g4kmC_aBoDkLC]e>g5ifFUINEUYF0P000T[L00I>g4ZlD_aBo5;mC_`2D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_aBOol0
0`00Oomoo`05Ool10001Ool1Ool0055oo`03001oogoo02eoo`0RB]a>oDkLC_e:g4kmB]`bOBiMJ]MV
]VKGI[HYVBFH:IU>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[aNMUYEGWH30000HU;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aEOol00`00Oomoo`05Ool10001Ool1Ool0059oo`03001oogoo02eoo`08C]a>gDkLC]e>
g4kMC]aV]`=V]P03:IP004Zl009:_005A[a>g4kLC_e>g002C_`02e;mC]a>oDkLC_e6_DKMFUINMUYF
GUH00ciK0TkL00E>oDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`015;mD_aBo5;lFGoo00<007ooOol017oo0@000Goo0Goo001COol00`00Oomoo`0]Ool08TkL
C_e>g4kmA[a:gD[LI]MV]V[GI[HYVBFHC]e:g4kMB]aBoDkLD_e>g5;mC]aBoD[LC_e:g4kmA[a:gEYF
GWIJEEif0ciK05YBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aMOol00`00Oomoo`03Ool10001Ool1Ool005Aoo`03001oogoo02eoo`05C]a>gDkL
C_e:g002B]d00fJgI[IV]P02:IP01BFHC]a>g4kMC]`00Tkl00eBoDkLC_e>o5;mC]a>gDkLC]eJEUiF
FUINMP0200001d[LC]a:_5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@02D_aROol00`00Oomoo`03Ool10001Ool005Eoo`8002ioo`0OB]a>oD[LC_d^GF[GI[IVefJf
:ITUV2VIC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlGWIJEEifFUH00P0005EBoDkLD_e>g5;m
C]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@1UOol00`00Oomoo`03Ool10001
Ool005Moo`03001oogoo02aoo`04C]a>gDkLI[L3I[H20003B[`3C]`03dkmC]a>o4klD_e>g4kmC]a>
oDJmA]eJEUifFUINEP03?U/2C]`01DkmC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;lK7oo00<0
07ooOol00Woo0@000Goo001HOol00`00Oomoo`0/Ool07TJlB]e:g6KGI[IZefJf:ITUV4ZmA[a:_4kL
D_e>g5;mC]aBoDkLD_e:g4kmB]a>oDJlB]eJEUifFUE2O0<nF`19D_e>g5;mC]aBoDklD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d0LGoo00D007ooOomoo`00005oo`00FGoo00<007ooOol0;7oo00A:g4[MI[IV]`9V]P<YV09>
g00BC]e>g4klC]aBoDkLC_e>o5;mC]a>gDkLC]e6_EiFFUINMUYF0T[L00I>g4ZlD_a>o5;mC]`2D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo7Eoo`04001oogoo0001Ool005Yoo`8002eoo`0K;UdbOFJfI]MV]V[G9IPYVBFHD_e>g5;m
C]aBoDkLD_e>g5;mC]aBoDJlB]e6_5ifFUENMUYF00<00014B[a>gDZlD_e>g5;mC]aBoDklD_e>g5;m
D_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoGQoo`04001o
ogoo0001Ool005aoo`03001oogoo02]oo`=V]P03I[L00000009:_005A[a>g4kLC_e>g002C_`035;m
C]a>oDkLC_e>g4KMA[eNMUYFGUIJEP<nF`07C]a>oDkLC]aBo5;mC_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo7aoo`03001oo`00005oo`00GGoo00<0
07ooOol0:goo01YV]V[GI[IoobFH:KU6_4ZlAYaBoDkLD_e>g5;mC]aBoDkLC_e:g4kmB]a:gEYFGWIJ
EEif0ciK03e2O4kLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@20Ool10001Ool1000005ioo`03001oogoo02Yoo`04I[MV]WooOol3:IP06dkLC]e>
g4klC]aBoDkLC_e>o5;mC]a>gDkLC]e>g4KMFUINMUYFGUI:g4kLB[a:g4klD_e>g002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo024Ool2000005moo`8002moo`0E:ITU
V2ViB]a>gD[LD_e>g5;mC]aBoDkLD_e>g4[MA[a:gEYEGWIJEUif0080000gB[a>gDZlD_e>g5;mC]aB
oDklD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0R7oo0P00001QOol00`00Oomoo`0/Ool2
B[`014JlB[a>g4km0TkL00e>o5;mC]a>oDkLC_e>g4KMA[eNMUYFGUIJEP02?U/2C]`01TkmC]aBo5;l
D_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0RWoo0P00001ROol00`00Oomoo`0/Ool0
A4JlB[a6W4ZmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[aNMUYEGWHnFd9K?U]2O4kLD_e>g5;mC_aB
oDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_f=Ool40002Ool006=oo`03001oogoo02aoo`03C]a>gDkL009>g00FD_e>
g4klC_aBoDkLC_e>g4kMC]a6gEYFGWIJEUiFB]a>g4ZlC]a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0S7oo
10001Woo001TOol2000^Ool04DkMB]a>gDkLD_e>g5;mC]aBoDkLC_e:g4kmFUENMUYFGWH00P0002Q:
_4kMB[a>gDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoH]oo`@000Yoo`00IWoo00<007ooOol0;7oo00Y>oDkLC]a>o5;mC]a>
oDkLC_e>g096g@05B]eJEUiFFUINMP02?U/01dkLC_e>g4kLD_aBoDkl009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Yoo`@000ioo`00Igoo00<0
07ooOol0:goo03A>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_5ifFUENMUYF@U/nFd9l?U]BoDkLD_e>
o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7HYoo`<0
019oo`00J7oo00<007ooOol0:goo00=>g5;mC]`00Tkl00IBoDkLC_e>g4kMC]`2A]d02UifFUINEUYF
C]a:_4kLB]aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0U;lRGoo10005Goo001YOol2000/Ool03dkLD_e>g5;mC]aBoDkLD_e:g4kmB]aNMUYFGWIJE@020000
6dkMB[a>gDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7@28Ool4
000IOol006]oo`03001oogoo02]oo`0=D_e>g4klC]a>oDkLC_e6gD[MA[eNEUYFGWH00SiK00M>g4km
C]a>g5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo8Moo`@001eoo`00K7oo
00<007ooOol0:goo021BoDkLD_e>g5;mC]aBoDJlB]eJEEifFUINMSiK@W`nFe;mC]aBoDklD_e>g5;m
C_aBoDkLD_eBo5;mD_aBoE;lRGoo10008Goo001]Ool00`00Oomoo`0[Ool02E;mC]a>oDklC]e>g4kM
A]e:g@03FUH02DkLB[a>g4[LD_e>g5;lC_aBo@03D_`015;mD_aBo5;lRGoo0`009Goo001^Ool00`00
Oomoo`0[Ool02U;mC]aBoDkLC_e:g4kmFUINMUYE0P0000a>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC_b8
Ool4000XOol006moo`8002aoo`06C_e>g4kmC]a:gDJm0UYF00ENMUYF?U/nFdkm00=>g004D_e>o5;l
D_b7Ool4000/Ool0075oo`03001oogoo02Yoo`0@D_e>g5;mA[a:gDJlGWIJEUif?U]2O3iK@U]>g5;m
C]b6Ool4000`Ool0079oo`03001oogoo02Yoo`05C]e>g4kMA]e:g@03FUH00eifOomoo`26Ool4000d
Ool007=oo`03001oogoo02Yoo`07C_e:g4kmFUINMUYEGWH0QGoo1000>7oo001dOol2000[Ool01T[M
A[e6gEYFGWIJEX9oo`<003aoo`00MWoo00<007ooOol0:Goo00A:gDJlGWIJEWmoo`@003moo`00Mgoo
00<007ooOol0:7oo00@004[MA[eJEW]oo`@004=oo`00N7oo00<007ooOol09goo00<007ooOol0N7oo
1000Agoo001iOol2000WOol00`00Oomoo`1dOol4001;Ool007]oo`03001oogoo02Aoo`03001oogoo
075oo`<004moo`00O7oo00<007ooOol08goo00<007ooOol0KGoo1000DWoo001mOol00`00Oomoo`0R
Ool00`00Oomoo`1YOol4001FOol007ioo`80029oo`03001oogoo06Eoo`@005Yoo`00P7oo00<007oo
Ool07goo00<007ooOol0HGoo1000GWoo0021Ool00`00Oomoo`0NOol00`00Oomoo`1NOol3001ROol0
089oo`03001oogoo01eoo`03001oogoo05Yoo`@006Eoo`00Pgoo00<007ooOol077oo00<007ooOol0
EWoo1000JGoo0024Ool2000LOol00`00Oomoo`1BOol4001]Ool008Ioo`03001oogoo01Uoo`03001o
ogoo04ioo`@0075oo`00Qgoo00<007ooOol067oo00<007ooOol0Bgoo0`00MGoo0028Ool00`00Oomo
o`0GOol00`00Oomoo`17Ool4001hOol008Uoo`8001Moo`03001oogoo04=oo`@007aoo`00Rgoo00<0
07ooOol057oo00<007ooOol0?goo1000P7oo002<Ool00`00Oomoo`0BOol00`00Oomoo`0lOol40024
Ool008eoo`03001oogoo015oo`03001oogoo03Uoo`<008Qoo`00SWoo0P004Goo00<007ooOol0=Goo
1000Rgoo002@Ool00`00Oomoo`0>Ool00`00Oomoo`0aOol4002?Ool0095oo`03001oogoo00eoo`03
001oogoo02eoo`@009=oo`00TWoo00<007ooOol037oo00<007ooOol0:Goo1000Ugoo002COol2000<
Ool00`00Oomoo`0UOol4002KOol009Eoo`03001oogoo00Uoo`03001oogoo029oo`<009moo`00UWoo
00<007ooOol027oo00<007ooOol07Woo1000XWoo002GOol00`00Oomoo`07Ool00`00Oomoo`0JOol4
002VOol009Qoo`03001oogoo00Ioo`03001oogoo01Ioo`@00:Yoo`00VGoo0P001Woo00<007ooOol0
4Woo1000[Woo002KOol00`00Oomoo`03Ool00`00Oomoo`0?Ool3002bOol009aoo`03001oogoo009o
o`03001oogoo00]oo`@00;Eoo`00WGoo00D007ooOomoo`0000Uoo`@00;Uoo`00WWoo0P0000=oo`00
Ool017oo1000_Goo002POol200000goo000000020031Ool00:5oo`800<Eoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.635 .738 .922 r
.39634 .69785 .40166 .7027 .41056 .70084 .40527 .69578 Mtetra
.599 .719 .929 r
.40527 .69578 .41056 .70084 .4194 .70232 .4142 .69445 Mtetra
.819 .698 .731 r
.4142 .69445 .4194 .70232 .4286 .69222 .42353 .68064 Mtetra
.364 .425 .79 r
.42353 .68064 .4286 .69222 .43757 .69117 .43233 .68602 Mtetra
.627 .726 .918 r
.43233 .68602 .43757 .69117 .4466 .689 .44137 .68413 Mtetra
.646 .743 .92 r
.44137 .68413 .4466 .689 .45567 .6866 .45046 .6818 Mtetra
.652 .748 .92 r
.45046 .6818 .45567 .6866 .46477 .68409 .45958 .67931 Mtetra
.655 .75 .92 r
.45958 .67931 .46477 .68409 .47391 .68152 .46873 .67675 Mtetra
.657 .752 .92 r
.46873 .67675 .47391 .68152 .48307 .67889 .47792 .67412 Mtetra
.658 .753 .92 r
.47792 .67412 .48307 .67889 .49227 .67623 .48713 .67146 Mtetra
.659 .754 .92 r
.48713 .67146 .49227 .67623 .50149 .67356 .49638 .66877 Mtetra
.49638 .66877 .50149 .67356 .51075 .67087 .50565 .66607 Mtetra
.50565 .66607 .51075 .67087 .52004 .66818 .51496 .66335 Mtetra
.51496 .66335 .52004 .66818 .52936 .66548 .5243 .66064 Mtetra
.658 .753 .92 r
.5243 .66064 .52936 .66548 .53871 .66279 .53367 .65792 Mtetra
.53367 .65792 .53871 .66279 .54809 .66009 .54308 .6552 Mtetra
.54308 .6552 .54809 .66009 .5575 .65738 .55251 .65248 Mtetra
.55251 .65248 .5575 .65738 .56695 .65467 .56198 .64975 Mtetra
.56198 .64975 .56695 .65467 .57642 .65195 .57148 .64701 Mtetra
.57148 .64701 .57642 .65195 .58593 .64923 .58101 .64427 Mtetra
.58101 .64427 .58593 .64923 .59548 .64649 .59057 .64152 Mtetra
.657 .753 .92 r
.59057 .64152 .59548 .64649 .60505 .64375 .60017 .63876 Mtetra
.60017 .63876 .60505 .64375 .61466 .64101 .6098 .636 Mtetra
.6098 .636 .61466 .64101 .6243 .63825 .61946 .63322 Mtetra
.657 .752 .92 r
.61946 .63322 .6243 .63825 .63397 .63549 .62916 .63044 Mtetra
.62916 .63044 .63397 .63549 .64368 .63271 .63889 .62765 Mtetra
.63889 .62765 .64368 .63271 .65342 .62993 .64865 .62485 Mtetra
.64865 .62485 .65342 .62993 .66319 .62714 .65845 .62204 Mtetra
.65845 .62204 .66319 .62714 .673 .62434 .66828 .61922 Mtetra
.66828 .61922 .673 .62434 .68284 .62153 .67814 .6164 Mtetra
.67814 .6164 .68284 .62153 .69272 .61872 .68804 .61356 Mtetra
.68804 .61356 .69272 .61872 .70263 .61589 .69798 .61072 Mtetra
.69798 .61072 .70263 .61589 .71257 .61306 .70795 .60786 Mtetra
.70795 .60786 .71257 .61306 .72255 .61021 .71795 .605 Mtetra
.71795 .605 .72255 .61021 .73257 .60736 .72799 .60213 Mtetra
.72799 .60213 .73257 .60736 .74262 .60449 .73807 .59925 Mtetra
.73807 .59925 .74262 .60449 .7527 .60162 .74818 .59635 Mtetra
.74818 .59635 .7527 .60162 .76283 .59874 .75832 .59345 Mtetra
.75832 .59345 .76283 .59874 .77298 .59585 .76851 .59054 Mtetra
.76851 .59054 .77298 .59585 .78317 .59294 .77872 .58762 Mtetra
.77872 .58762 .78317 .59294 .7934 .59003 .78898 .58469 Mtetra
.78898 .58469 .7934 .59003 .80367 .58711 .79927 .58175 Mtetra
.79927 .58175 .80367 .58711 .81397 .58418 .8096 .57879 Mtetra
.8096 .57879 .81397 .58418 .82431 .58123 .81996 .57583 Mtetra
.81996 .57583 .82431 .58123 .83468 .57828 .83036 .57286 Mtetra
.83036 .57286 .83468 .57828 .84509 .57532 .8408 .56988 Mtetra
.8408 .56988 .84509 .57532 .85554 .57235 .85128 .56689 Mtetra
.85128 .56689 .85554 .57235 .86603 .56936 .86179 .56388 Mtetra
.86179 .56388 .86603 .56936 .87656 .56637 .87234 .56087 Mtetra
.87234 .56087 .87656 .56637 .88712 .56337 .88293 .55784 Mtetra
.88293 .55784 .88712 .56337 .89772 .56035 .89356 .55481 Mtetra
.89356 .55481 .89772 .56035 .90836 .55733 .90423 .55176 Mtetra
.90423 .55176 .90836 .55733 .91903 .55429 .91493 .54871 Mtetra
.91493 .54871 .91903 .55429 .92975 .55124 .92568 .54564 Mtetra
.92568 .54564 .92975 .55124 .94051 .54818 .93646 .54256 Mtetra
.93646 .54256 .94051 .54818 .9513 .54512 .94729 .53947 Mtetra
.94729 .53947 .9513 .54512 .96213 .54204 .95815 .53637 Mtetra
.95815 .53637 .96213 .54204 .97301 .53895 .96905 .53326 Mtetra
.96905 .53326 .97301 .53895 .98392 .53584 .97999 .53014 Mtetra
.639 .74 .922 r
.39098 .69299 .39634 .69785 .40527 .69578 .39993 .69083 Mtetra
.626 .733 .924 r
.39993 .69083 .40527 .69578 .4142 .69445 .4089 .68893 Mtetra
.415 .627 .941 r
.4089 .68893 .4142 .69445 .42353 .68064 .4178 .69039 Mtetra
0 0 0 r
.4178 .69039 .42353 .68064 .43233 .68602 .42708 .68022 Mtetra
.592 .691 .91 r
.42708 .68022 .43233 .68602 .44137 .68413 .43611 .67913 Mtetra
.64 .737 .919 r
.43611 .67913 .44137 .68413 .45046 .6818 .44521 .67693 Mtetra
.649 .746 .92 r
.44521 .67693 .45046 .6818 .45958 .67931 .45435 .67448 Mtetra
.653 .749 .92 r
.45435 .67448 .45958 .67931 .46873 .67675 .46352 .67193 Mtetra
.656 .751 .92 r
.46352 .67193 .46873 .67675 .47792 .67412 .47273 .66932 Mtetra
.658 .753 .92 r
.47273 .66932 .47792 .67412 .48713 .67146 .48196 .66665 Mtetra
.48196 .66665 .48713 .67146 .49638 .66877 .49123 .66395 Mtetra
.659 .754 .92 r
.49123 .66395 .49638 .66877 .50565 .66607 .50053 .66123 Mtetra
.50053 .66123 .50565 .66607 .51496 .66335 .50986 .6585 Mtetra
.50986 .6585 .51496 .66335 .5243 .66064 .51922 .65577 Mtetra
.659 .753 .92 r
.51922 .65577 .5243 .66064 .53367 .65792 .52861 .65303 Mtetra
.658 .753 .92 r
.52861 .65303 .53367 .65792 .54308 .6552 .53803 .65029 Mtetra
.53803 .65029 .54308 .6552 .55251 .65248 .54749 .64755 Mtetra
.54749 .64755 .55251 .65248 .56198 .64975 .55698 .6448 Mtetra
.55698 .6448 .56198 .64975 .57148 .64701 .5665 .64205 Mtetra
.5665 .64205 .57148 .64701 .58101 .64427 .57605 .63928 Mtetra
.57605 .63928 .58101 .64427 .59057 .64152 .58564 .63652 Mtetra
.657 .753 .92 r
.58564 .63652 .59057 .64152 .60017 .63876 .59526 .63374 Mtetra
.59526 .63374 .60017 .63876 .6098 .636 .60491 .63095 Mtetra
.60491 .63095 .6098 .636 .61946 .63322 .61459 .62816 Mtetra
.657 .752 .92 r
.61459 .62816 .61946 .63322 .62916 .63044 .62431 .62536 Mtetra
.62431 .62536 .62916 .63044 .63889 .62765 .63406 .62255 Mtetra
.63406 .62255 .63889 .62765 .64865 .62485 .64385 .61973 Mtetra
.64385 .61973 .64865 .62485 .65845 .62204 .65367 .61691 Mtetra
.65367 .61691 .65845 .62204 .66828 .61922 .66353 .61407 Mtetra
.66353 .61407 .66828 .61922 .67814 .6164 .67342 .61123 Mtetra
.67342 .61123 .67814 .6164 .68804 .61356 .68334 .60837 Mtetra
.68334 .60837 .68804 .61356 .69798 .61072 .6933 .60551 Mtetra
.6933 .60551 .69798 .61072 .70795 .60786 .70329 .60264 Mtetra
.70329 .60264 .70795 .60786 .71795 .605 .71332 .59976 Mtetra
.71332 .59976 .71795 .605 .72799 .60213 .72338 .59686 Mtetra
.72338 .59686 .72799 .60213 .73807 .59925 .73348 .59396 Mtetra
.73348 .59396 .73807 .59925 .74818 .59635 .74362 .59105 Mtetra
.74362 .59105 .74818 .59635 .75832 .59345 .75379 .58813 Mtetra
.75379 .58813 .75832 .59345 .76851 .59054 .764 .5852 Mtetra
.764 .5852 .76851 .59054 .77872 .58762 .77424 .58226 Mtetra
.77424 .58226 .77872 .58762 .78898 .58469 .78452 .57931 Mtetra
.78452 .57931 .78898 .58469 .79927 .58175 .79484 .57635 Mtetra
.79484 .57635 .79927 .58175 .8096 .57879 .80519 .57338 Mtetra
.80519 .57338 .8096 .57879 .81996 .57583 .81558 .57039 Mtetra
.81558 .57039 .81996 .57583 .83036 .57286 .82601 .5674 Mtetra
.82601 .5674 .83036 .57286 .8408 .56988 .83648 .5644 Mtetra
.83648 .5644 .8408 .56988 .85128 .56689 .84698 .56139 Mtetra
.84698 .56139 .85128 .56689 .86179 .56388 .85752 .55836 Mtetra
.85752 .55836 .86179 .56388 .87234 .56087 .8681 .55533 Mtetra
.8681 .55533 .87234 .56087 .88293 .55784 .87872 .55229 Mtetra
.87872 .55229 .88293 .55784 .89356 .55481 .88938 .54923 Mtetra
.88938 .54923 .89356 .55481 .90423 .55176 .90007 .54616 Mtetra
.90007 .54616 .90423 .55176 .91493 .54871 .91081 .54309 Mtetra
.91081 .54309 .91493 .54871 .92568 .54564 .92158 .54 Mtetra
.92158 .54 .92568 .54564 .93646 .54256 .93239 .5369 Mtetra
.93239 .5369 .93646 .54256 .94729 .53947 .94325 .53379 Mtetra
.94325 .53379 .94729 .53947 .95815 .53637 .95414 .53067 Mtetra
.95414 .53067 .95815 .53637 .96905 .53326 .96507 .52754 Mtetra
.96507 .52754 .96905 .53326 .97999 .53014 .97604 .52439 Mtetra
.64 .74 .921 r
.3856 .68811 .39098 .69299 .39993 .69083 .39456 .6859 Mtetra
.635 .738 .922 r
.39456 .6859 .39993 .69083 .4089 .68893 .40355 .6838 Mtetra
.599 .719 .928 r
.40355 .6838 .4089 .68893 .4178 .69039 .41256 .68244 Mtetra
.82 .699 .731 r
.41256 .68244 .4178 .69039 .42708 .68022 .42197 .66853 Mtetra
.363 .424 .79 r
.42197 .66853 .42708 .68022 .43611 .67913 .43083 .67391 Mtetra
.627 .726 .918 r
.43083 .67391 .43611 .67913 .44521 .67693 .43994 .67198 Mtetra
.646 .743 .92 r
.43994 .67198 .44521 .67693 .45435 .67448 .44909 .6696 Mtetra
.652 .748 .92 r
.44909 .6696 .45435 .67448 .46352 .67193 .45828 .66708 Mtetra
.655 .75 .92 r
.45828 .66708 .46352 .67193 .47273 .66932 .46751 .66447 Mtetra
.657 .752 .92 r
.46751 .66447 .47273 .66932 .48196 .66665 .47676 .66181 Mtetra
.658 .753 .92 r
.47676 .66181 .48196 .66665 .49123 .66395 .48605 .6591 Mtetra
.659 .754 .92 r
.48605 .6591 .49123 .66395 .50053 .66123 .49537 .65637 Mtetra
.49537 .65637 .50053 .66123 .50986 .6585 .50472 .65362 Mtetra
.50472 .65362 .50986 .6585 .51922 .65577 .5141 .65087 Mtetra
.5141 .65087 .51922 .65577 .52861 .65303 .52351 .64811 Mtetra
.658 .753 .92 r
.52351 .64811 .52861 .65303 .53803 .65029 .53296 .64535 Mtetra
.53296 .64535 .53803 .65029 .54749 .64755 .54243 .64259 Mtetra
.54243 .64259 .54749 .64755 .55698 .6448 .55194 .63982 Mtetra
.55194 .63982 .55698 .6448 .5665 .64205 .56149 .63705 Mtetra
.56149 .63705 .5665 .64205 .57605 .63928 .57106 .63427 Mtetra
.57106 .63427 .57605 .63928 .58564 .63652 .58067 .63148 Mtetra
.58067 .63148 .58564 .63652 .59526 .63374 .59031 .62868 Mtetra
.657 .753 .92 r
.59031 .62868 .59526 .63374 .60491 .63095 .59999 .62588 Mtetra
.59999 .62588 .60491 .63095 .61459 .62816 .60969 .62307 Mtetra
.60969 .62307 .61459 .62816 .62431 .62536 .61944 .62025 Mtetra
.657 .752 .92 r
.61944 .62025 .62431 .62536 .63406 .62255 .62921 .61742 Mtetra
.62921 .61742 .63406 .62255 .64385 .61973 .63902 .61459 Mtetra
.63902 .61459 .64385 .61973 .65367 .61691 .64886 .61174 Mtetra
.64886 .61174 .65367 .61691 .66353 .61407 .65874 .60889 Mtetra
.65874 .60889 .66353 .61407 .67342 .61123 .66866 .60602 Mtetra
.66866 .60602 .67342 .61123 .68334 .60837 .6786 .60315 Mtetra
.6786 .60315 .68334 .60837 .6933 .60551 .68859 .60027 Mtetra
.68859 .60027 .6933 .60551 .70329 .60264 .6986 .59738 Mtetra
.6986 .59738 .70329 .60264 .71332 .59976 .70866 .59448 Mtetra
.70866 .59448 .71332 .59976 .72338 .59686 .71875 .59157 Mtetra
.71875 .59157 .72338 .59686 .73348 .59396 .72887 .58865 Mtetra
.72887 .58865 .73348 .59396 .74362 .59105 .73903 .58571 Mtetra
.73903 .58571 .74362 .59105 .75379 .58813 .74923 .58277 Mtetra
.74923 .58277 .75379 .58813 .764 .5852 .75946 .57982 Mtetra
.75946 .57982 .764 .5852 .77424 .58226 .76973 .57686 Mtetra
.76973 .57686 .77424 .58226 .78452 .57931 .78004 .57389 Mtetra
.78004 .57389 .78452 .57931 .79484 .57635 .79038 .57091 Mtetra
.79038 .57091 .79484 .57635 .80519 .57338 .80076 .56792 Mtetra
.80076 .56792 .80519 .57338 .81558 .57039 .81118 .56492 Mtetra
.81118 .56492 .81558 .57039 .82601 .5674 .82163 .56191 Mtetra
.82163 .56191 .82601 .5674 .83648 .5644 .83213 .55889 Mtetra
.83213 .55889 .83648 .5644 .84698 .56139 .84266 .55585 Mtetra
.84266 .55585 .84698 .56139 .85752 .55836 .85323 .55281 Mtetra
.85323 .55281 .85752 .55836 .8681 .55533 .86384 .54976 Mtetra
.86384 .54976 .8681 .55533 .87872 .55229 .87448 .54669 Mtetra
.87448 .54669 .87872 .55229 .88938 .54923 .88517 .54361 Mtetra
.88517 .54361 .88938 .54923 .90007 .54616 .89589 .54053 Mtetra
.89589 .54053 .90007 .54616 .91081 .54309 .90665 .53743 Mtetra
.90665 .53743 .91081 .54309 .92158 .54 .91746 .53432 Mtetra
.91746 .53432 .92158 .54 .93239 .5369 .9283 .5312 Mtetra
.9283 .5312 .93239 .5369 .94325 .53379 .93918 .52807 Mtetra
.93918 .52807 .94325 .53379 .95414 .53067 .9501 .52493 Mtetra
.9501 .52493 .95414 .53067 .96507 .52754 .96106 .52177 Mtetra
.96106 .52177 .96507 .52754 .97604 .52439 .97207 .51861 Mtetra
.639 .739 .921 r
.38018 .68317 .3856 .68811 .39456 .6859 .38916 .68097 Mtetra
.639 .74 .922 r
.38916 .68097 .39456 .6859 .40355 .6838 .39817 .67877 Mtetra
.626 .733 .924 r
.39817 .67877 .40355 .6838 .41256 .68244 .40721 .67684 Mtetra
.415 .627 .941 r
.40721 .67684 .41256 .68244 .42197 .66853 .41618 .67827 Mtetra
0 0 0 r
.41618 .67827 .42197 .66853 .43083 .67391 .42553 .66802 Mtetra
.592 .691 .91 r
.42553 .66802 .43083 .67391 .43994 .67198 .43463 .6669 Mtetra
.64 .738 .92 r
.43463 .6669 .43994 .67198 .44909 .6696 .4438 .66466 Mtetra
.649 .746 .92 r
.4438 .66466 .44909 .6696 .45828 .66708 .45301 .66217 Mtetra
.653 .749 .92 r
.45301 .66217 .45828 .66708 .46751 .66447 .46225 .65958 Mtetra
.656 .751 .92 r
.46225 .65958 .46751 .66447 .47676 .66181 .47153 .65692 Mtetra
.658 .753 .92 r
.47153 .65692 .47676 .66181 .48605 .6591 .48084 .65421 Mtetra
.48084 .65421 .48605 .6591 .49537 .65637 .49017 .65147 Mtetra
.659 .754 .92 r
.49017 .65147 .49537 .65637 .50472 .65362 .49954 .64871 Mtetra
.49954 .64871 .50472 .65362 .5141 .65087 .50895 .64594 Mtetra
.50895 .64594 .5141 .65087 .52351 .64811 .51838 .64316 Mtetra
.659 .753 .92 r
.51838 .64316 .52351 .64811 .53296 .64535 .52785 .64038 Mtetra
.658 .753 .92 r
.52785 .64038 .53296 .64535 .54243 .64259 .53735 .6376 Mtetra
.53735 .6376 .54243 .64259 .55194 .63982 .54688 .63481 Mtetra
.54688 .63481 .55194 .63982 .56149 .63705 .55644 .63202 Mtetra
.55644 .63202 .56149 .63705 .57106 .63427 .56604 .62922 Mtetra
.56604 .62922 .57106 .63427 .58067 .63148 .57567 .62641 Mtetra
.57567 .62641 .58067 .63148 .59031 .62868 .58533 .6236 Mtetra
.657 .753 .92 r
.58533 .6236 .59031 .62868 .59999 .62588 .59503 .62078 Mtetra
.59503 .62078 .59999 .62588 .60969 .62307 .60476 .61795 Mtetra
.60476 .61795 .60969 .62307 .61944 .62025 .61453 .61511 Mtetra
.657 .752 .92 r
.61453 .61511 .61944 .62025 .62921 .61742 .62433 .61226 Mtetra
.62433 .61226 .62921 .61742 .63902 .61459 .63416 .60941 Mtetra
.63416 .60941 .63902 .61459 .64886 .61174 .64403 .60654 Mtetra
.64403 .60654 .64886 .61174 .65874 .60889 .65393 .60367 Mtetra
.65393 .60367 .65874 .60889 .66866 .60602 .66387 .60079 Mtetra
.66387 .60079 .66866 .60602 .6786 .60315 .67384 .5979 Mtetra
.67384 .5979 .6786 .60315 .68859 .60027 .68384 .59499 Mtetra
.68384 .59499 .68859 .60027 .6986 .59738 .69389 .59208 Mtetra
.69389 .59208 .6986 .59738 .70866 .59448 .70397 .58916 Mtetra
.70397 .58916 .70866 .59448 .71875 .59157 .71408 .58623 Mtetra
.71408 .58623 .71875 .59157 .72887 .58865 .72423 .58329 Mtetra
.72423 .58329 .72887 .58865 .73903 .58571 .73441 .58034 Mtetra
.73441 .58034 .73903 .58571 .74923 .58277 .74464 .57738 Mtetra
.74464 .57738 .74923 .58277 .75946 .57982 .7549 .57441 Mtetra
.7549 .57441 .75946 .57982 .76973 .57686 .76519 .57143 Mtetra
.76519 .57143 .76973 .57686 .78004 .57389 .77552 .56844 Mtetra
.77552 .56844 .78004 .57389 .79038 .57091 .78589 .56544 Mtetra
.78589 .56544 .79038 .57091 .80076 .56792 .7963 .56243 Mtetra
.7963 .56243 .80076 .56792 .81118 .56492 .80674 .55941 Mtetra
.80674 .55941 .81118 .56492 .82163 .56191 .81723 .55638 Mtetra
.81723 .55638 .82163 .56191 .83213 .55889 .82775 .55333 Mtetra
.82775 .55333 .83213 .55889 .84266 .55585 .83831 .55028 Mtetra
.83831 .55028 .84266 .55585 .85323 .55281 .8489 .54722 Mtetra
.8489 .54722 .85323 .55281 .86384 .54976 .85954 .54414 Mtetra
.85954 .54414 .86384 .54976 .87448 .54669 .87021 .54106 Mtetra
.87021 .54106 .87448 .54669 .88517 .54361 .88093 .53796 Mtetra
.88093 .53796 .88517 .54361 .89589 .54053 .89168 .53485 Mtetra
.89168 .53485 .89589 .54053 .90665 .53743 .90247 .53173 Mtetra
.90247 .53173 .90665 .53743 .91746 .53432 .9133 .5286 Mtetra
.9133 .5286 .91746 .53432 .9283 .5312 .92417 .52546 Mtetra
.92417 .52546 .9283 .5312 .93918 .52807 .93508 .52231 Mtetra
.93508 .52231 .93918 .52807 .9501 .52493 .94604 .51914 Mtetra
.94604 .51914 .9501 .52493 .96106 .52177 .95703 .51597 Mtetra
.95703 .51597 .96106 .52177 .97207 .51861 .96806 .51278 Mtetra
.636 .736 .921 r
.37472 .67815 .38018 .68317 .38916 .68097 .38372 .67601 Mtetra
.64 .74 .921 r
.38372 .67601 .38916 .68097 .39817 .67877 .39275 .67377 Mtetra
.635 .738 .922 r
.39275 .67377 .39817 .67877 .40721 .67684 .40182 .67162 Mtetra
.599 .719 .928 r
.40182 .67162 .40721 .67684 .41618 .67827 .41089 .67022 Mtetra
.82 .7 .731 r
.41089 .67022 .41618 .67827 .42553 .66802 .42037 .65622 Mtetra
.362 .423 .79 r
.42037 .65622 .42553 .66802 .43463 .6669 .4293 .6616 Mtetra
.627 .726 .918 r
.4293 .6616 .43463 .6669 .4438 .66466 .43848 .65963 Mtetra
.646 .743 .92 r
.43848 .65963 .4438 .66466 .45301 .66217 .44771 .65721 Mtetra
.652 .748 .92 r
.44771 .65721 .45301 .66217 .46225 .65958 .45697 .65465 Mtetra
.655 .75 .92 r
.45697 .65465 .46225 .65958 .47153 .65692 .46626 .652 Mtetra
.657 .752 .92 r
.46626 .652 .47153 .65692 .48084 .65421 .47559 .64929 Mtetra
.658 .753 .92 r
.47559 .64929 .48084 .65421 .49017 .65147 .48495 .64654 Mtetra
.659 .754 .92 r
.48495 .64654 .49017 .65147 .49954 .64871 .49434 .64377 Mtetra
.49434 .64377 .49954 .64871 .50895 .64594 .50376 .64098 Mtetra
.50376 .64098 .50895 .64594 .51838 .64316 .51322 .63818 Mtetra
.51322 .63818 .51838 .64316 .52785 .64038 .52271 .63538 Mtetra
.658 .753 .92 r
.52271 .63538 .52785 .64038 .53735 .6376 .53223 .63257 Mtetra
.53223 .63257 .53735 .6376 .54688 .63481 .54178 .62977 Mtetra
.54178 .62977 .54688 .63481 .55644 .63202 .55137 .62695 Mtetra
.55137 .62695 .55644 .63202 .56604 .62922 .56099 .62414 Mtetra
.56099 .62414 .56604 .62922 .57567 .62641 .57064 .62131 Mtetra
.57064 .62131 .57567 .62641 .58533 .6236 .58033 .61848 Mtetra
.58033 .61848 .58533 .6236 .59503 .62078 .59005 .61564 Mtetra
.657 .753 .92 r
.59005 .61564 .59503 .62078 .60476 .61795 .5998 .61279 Mtetra
.5998 .61279 .60476 .61795 .61453 .61511 .60959 .60993 Mtetra
.60959 .60993 .61453 .61511 .62433 .61226 .61941 .60707 Mtetra
.657 .752 .92 r
.61941 .60707 .62433 .61226 .63416 .60941 .62927 .60419 Mtetra
.62927 .60419 .63416 .60941 .64403 .60654 .63916 .60131 Mtetra
.63916 .60131 .64403 .60654 .65393 .60367 .64908 .59842 Mtetra
.64908 .59842 .65393 .60367 .66387 .60079 .65904 .59552 Mtetra
.65904 .59552 .66387 .60079 .67384 .5979 .66904 .5926 Mtetra
.66904 .5926 .67384 .5979 .68384 .59499 .67907 .58968 Mtetra
.67907 .58968 .68384 .59499 .69389 .59208 .68914 .58675 Mtetra
.68914 .58675 .69389 .59208 .70397 .58916 .69924 .58381 Mtetra
.69924 .58381 .70397 .58916 .71408 .58623 .70938 .58086 Mtetra
.70938 .58086 .71408 .58623 .72423 .58329 .71956 .57791 Mtetra
.71956 .57791 .72423 .58329 .73441 .58034 .72977 .57494 Mtetra
.72977 .57494 .73441 .58034 .74464 .57738 .74001 .57196 Mtetra
.74001 .57196 .74464 .57738 .7549 .57441 .7503 .56897 Mtetra
.7503 .56897 .7549 .57441 .76519 .57143 .76062 .56597 Mtetra
.76062 .56597 .76519 .57143 .77552 .56844 .77098 .56296 Mtetra
.77098 .56296 .77552 .56844 .78589 .56544 .78138 .55994 Mtetra
.78138 .55994 .78589 .56544 .7963 .56243 .79181 .5569 Mtetra
.79181 .5569 .7963 .56243 .80674 .55941 .80228 .55386 Mtetra
.80228 .55386 .80674 .55941 .81723 .55638 .81279 .55081 Mtetra
.81279 .55081 .81723 .55638 .82775 .55333 .82334 .54775 Mtetra
.82334 .54775 .82775 .55333 .83831 .55028 .83392 .54467 Mtetra
.83392 .54467 .83831 .55028 .8489 .54722 .84455 .54159 Mtetra
.84455 .54159 .8489 .54722 .85954 .54414 .85521 .53849 Mtetra
.85521 .53849 .85954 .54414 .87021 .54106 .86591 .53538 Mtetra
.86591 .53538 .87021 .54106 .88093 .53796 .87666 .53227 Mtetra
.87666 .53227 .88093 .53796 .89168 .53485 .88744 .52914 Mtetra
.88744 .52914 .89168 .53485 .90247 .53173 .89826 .526 Mtetra
.89826 .526 .90247 .53173 .9133 .5286 .90912 .52285 Mtetra
.90912 .52285 .9133 .5286 .92417 .52546 .92002 .51968 Mtetra
.92002 .51968 .92417 .52546 .93508 .52231 .93096 .51651 Mtetra
.93096 .51651 .93508 .52231 .94604 .51914 .94194 .51332 Mtetra
.94194 .51332 .94604 .51914 .95703 .51597 .95297 .51012 Mtetra
.95297 .51012 .95703 .51597 .96806 .51278 .96403 .50691 Mtetra
.63 .73 .92 r
.36925 .673 .37472 .67815 .38372 .67601 .37825 .671 Mtetra
.639 .739 .921 r
.37825 .671 .38372 .67601 .39275 .67377 .3873 .66876 Mtetra
.639 .74 .922 r
.3873 .66876 .39275 .67377 .40182 .67162 .39639 .66652 Mtetra
.626 .733 .924 r
.39639 .66652 .40182 .67162 .41089 .67022 .40549 .66455 Mtetra
.416 .627 .941 r
.40549 .66455 .41089 .67022 .42037 .65622 .41453 .66596 Mtetra
0 0 0 r
.41453 .66596 .42037 .65622 .4293 .6616 .42395 .65563 Mtetra
.592 .691 .911 r
.42395 .65563 .4293 .6616 .43848 .65963 .43313 .65448 Mtetra
.64 .738 .92 r
.43313 .65448 .43848 .65963 .44771 .65721 .44237 .65219 Mtetra
.649 .746 .92 r
.44237 .65219 .44771 .65721 .45697 .65465 .45165 .64967 Mtetra
.653 .749 .92 r
.45165 .64967 .45697 .65465 .46626 .652 .46096 .64703 Mtetra
.656 .751 .92 r
.46096 .64703 .46626 .652 .47559 .64929 .47031 .64433 Mtetra
.658 .753 .92 r
.47031 .64433 .47559 .64929 .48495 .64654 .47969 .64158 Mtetra
.47969 .64158 .48495 .64654 .49434 .64377 .4891 .63879 Mtetra
.659 .754 .92 r
.4891 .63879 .49434 .64377 .50376 .64098 .49855 .63599 Mtetra
.49855 .63599 .50376 .64098 .51322 .63818 .50802 .63317 Mtetra
.50802 .63317 .51322 .63818 .52271 .63538 .51753 .63035 Mtetra
.659 .753 .92 r
.51753 .63035 .52271 .63538 .53223 .63257 .52708 .62752 Mtetra
.658 .753 .92 r
.52708 .62752 .53223 .63257 .54178 .62977 .53665 .62469 Mtetra
.53665 .62469 .54178 .62977 .55137 .62695 .54626 .62186 Mtetra
.54626 .62186 .55137 .62695 .56099 .62414 .5559 .61902 Mtetra
.5559 .61902 .56099 .62414 .57064 .62131 .56558 .61618 Mtetra
.56558 .61618 .57064 .62131 .58033 .61848 .57529 .61333 Mtetra
.57529 .61333 .58033 .61848 .59005 .61564 .58503 .61047 Mtetra
.657 .753 .92 r
.58503 .61047 .59005 .61564 .5998 .61279 .5948 .6076 Mtetra
.5948 .6076 .5998 .61279 .60959 .60993 .60462 .60472 Mtetra
.60462 .60472 .60959 .60993 .61941 .60707 .61446 .60184 Mtetra
.657 .752 .92 r
.61446 .60184 .61941 .60707 .62927 .60419 .62434 .59894 Mtetra
.62434 .59894 .62927 .60419 .63916 .60131 .63426 .59604 Mtetra
.63426 .59604 .63916 .60131 .64908 .59842 .64421 .59313 Mtetra
.64421 .59313 .64908 .59842 .65904 .59552 .65419 .59021 Mtetra
.65419 .59021 .65904 .59552 .66904 .5926 .66421 .58728 Mtetra
.66421 .58728 .66904 .5926 .67907 .58968 .67427 .58434 Mtetra
.67427 .58434 .67907 .58968 .68914 .58675 .68436 .58139 Mtetra
.68436 .58139 .68914 .58675 .69924 .58381 .69449 .57843 Mtetra
.69449 .57843 .69924 .58381 .70938 .58086 .70465 .57546 Mtetra
.70465 .57546 .70938 .58086 .71956 .57791 .71485 .57248 Mtetra
.71485 .57248 .71956 .57791 .72977 .57494 .72509 .56949 Mtetra
.72509 .56949 .72977 .57494 .74001 .57196 .73536 .56649 Mtetra
.73536 .56649 .74001 .57196 .7503 .56897 .74567 .56348 Mtetra
.74567 .56348 .7503 .56897 .76062 .56597 .75602 .56046 Mtetra
.75602 .56046 .76062 .56597 .77098 .56296 .7664 .55743 Mtetra
.7664 .55743 .77098 .56296 .78138 .55994 .77683 .55439 Mtetra
.77683 .55439 .78138 .55994 .79181 .5569 .78729 .55134 Mtetra
.78729 .55134 .79181 .5569 .80228 .55386 .79779 .54828 Mtetra
.79779 .54828 .80228 .55386 .81279 .55081 .80832 .5452 Mtetra
.80832 .5452 .81279 .55081 .82334 .54775 .8189 .54212 Mtetra
.8189 .54212 .82334 .54775 .83392 .54467 .82951 .53903 Mtetra
.82951 .53903 .83392 .54467 .84455 .54159 .84016 .53592 Mtetra
.84016 .53592 .84455 .54159 .85521 .53849 .85086 .5328 Mtetra
.85086 .5328 .85521 .53849 .86591 .53538 .86159 .52967 Mtetra
.86159 .52967 .86591 .53538 .87666 .53227 .87236 .52654 Mtetra
.87236 .52654 .87666 .53227 .88744 .52914 .88317 .52338 Mtetra
.88317 .52338 .88744 .52914 .89826 .526 .89402 .52022 Mtetra
.89402 .52022 .89826 .526 .90912 .52285 .90491 .51705 Mtetra
.90491 .51705 .90912 .52285 .92002 .51968 .91584 .51386 Mtetra
.91584 .51386 .92002 .51968 .93096 .51651 .92681 .51067 Mtetra
.92681 .51067 .93096 .51651 .94194 .51332 .93782 .50746 Mtetra
.93782 .50746 .94194 .51332 .95297 .51012 .94887 .50424 Mtetra
.94887 .50424 .95297 .51012 .96403 .50691 .95997 .50101 Mtetra
.613 .715 .918 r
.36375 .66754 .36925 .673 .37825 .671 .37275 .6659 Mtetra
.636 .737 .921 r
.37275 .6659 .37825 .671 .3873 .66876 .38182 .66372 Mtetra
.64 .74 .921 r
.38182 .66372 .3873 .66876 .39639 .66652 .39092 .66144 Mtetra
.635 .738 .922 r
.39092 .66144 .39639 .66652 .40549 .66455 .40005 .65925 Mtetra
.599 .719 .928 r
.40005 .65925 .40549 .66455 .41453 .66596 .40919 .65782 Mtetra
.821 .7 .731 r
.40919 .65782 .41453 .66596 .42395 .65563 .41875 .64373 Mtetra
.36 .422 .79 r
.41875 .64373 .42395 .65563 .43313 .65448 .42775 .64909 Mtetra
.627 .726 .918 r
.42775 .64909 .43313 .65448 .44237 .65219 .437 .64708 Mtetra
.646 .743 .92 r
.437 .64708 .44237 .65219 .45165 .64967 .44629 .64463 Mtetra
.652 .748 .92 r
.44629 .64463 .45165 .64967 .46096 .64703 .45563 .64202 Mtetra
.655 .75 .92 r
.45563 .64202 .46096 .64703 .47031 .64433 .465 .63933 Mtetra
.657 .752 .92 r
.465 .63933 .47031 .64433 .47969 .64158 .4744 .63657 Mtetra
.658 .753 .92 r
.4744 .63657 .47969 .64158 .4891 .63879 .48383 .63378 Mtetra
.659 .754 .92 r
.48383 .63378 .4891 .63879 .49855 .63599 .4933 .63096 Mtetra
.4933 .63096 .49855 .63599 .50802 .63317 .5028 .62813 Mtetra
.5028 .62813 .50802 .63317 .51753 .63035 .51233 .62528 Mtetra
.51233 .62528 .51753 .63035 .52708 .62752 .52189 .62244 Mtetra
.658 .753 .92 r
.52189 .62244 .52708 .62752 .53665 .62469 .53149 .61959 Mtetra
.53149 .61959 .53665 .62469 .54626 .62186 .54112 .61673 Mtetra
.54112 .61673 .54626 .62186 .5559 .61902 .55078 .61388 Mtetra
.55078 .61388 .5559 .61902 .56558 .61618 .56048 .61101 Mtetra
.56048 .61101 .56558 .61618 .57529 .61333 .57021 .60814 Mtetra
.57021 .60814 .57529 .61333 .58503 .61047 .57998 .60526 Mtetra
.57998 .60526 .58503 .61047 .5948 .6076 .58978 .60237 Mtetra
.657 .753 .92 r
.58978 .60237 .5948 .6076 .60462 .60472 .59961 .59948 Mtetra
.59961 .59948 .60462 .60472 .61446 .60184 .60948 .59658 Mtetra
.60948 .59658 .61446 .60184 .62434 .59894 .61938 .59366 Mtetra
.657 .752 .92 r
.61938 .59366 .62434 .59894 .63426 .59604 .62932 .59074 Mtetra
.62932 .59074 .63426 .59604 .64421 .59313 .6393 .58781 Mtetra
.6393 .58781 .64421 .59313 .65419 .59021 .6493 .58487 Mtetra
.6493 .58487 .65419 .59021 .66421 .58728 .65935 .58192 Mtetra
.65935 .58192 .66421 .58728 .67427 .58434 .66943 .57896 Mtetra
.66943 .57896 .67427 .58434 .68436 .58139 .67955 .57599 Mtetra
.67955 .57599 .68436 .58139 .69449 .57843 .6897 .57301 Mtetra
.6897 .57301 .69449 .57843 .70465 .57546 .69989 .57002 Mtetra
.69989 .57002 .70465 .57546 .71485 .57248 .71011 .56702 Mtetra
.71011 .56702 .71485 .57248 .72509 .56949 .72038 .56401 Mtetra
.72038 .56401 .72509 .56949 .73536 .56649 .73068 .56099 Mtetra
.73068 .56099 .73536 .56649 .74567 .56348 .74101 .55796 Mtetra
.74101 .55796 .74567 .56348 .75602 .56046 .75139 .55492 Mtetra
.75139 .55492 .75602 .56046 .7664 .55743 .7618 .55187 Mtetra
.7618 .55187 .7664 .55743 .77683 .55439 .77225 .54881 Mtetra
.77225 .54881 .77683 .55439 .78729 .55134 .78274 .54574 Mtetra
.78274 .54574 .78729 .55134 .79779 .54828 .79326 .54265 Mtetra
.79326 .54265 .79779 .54828 .80832 .5452 .80383 .53956 Mtetra
.80383 .53956 .80832 .5452 .8189 .54212 .81443 .53646 Mtetra
.81443 .53646 .8189 .54212 .82951 .53903 .82507 .53334 Mtetra
.82507 .53334 .82951 .53903 .84016 .53592 .83575 .53021 Mtetra
.83575 .53021 .84016 .53592 .85086 .5328 .84647 .52707 Mtetra
.84647 .52707 .85086 .5328 .86159 .52967 .85723 .52393 Mtetra
.85723 .52393 .86159 .52967 .87236 .52654 .86803 .52076 Mtetra
.86803 .52076 .87236 .52654 .88317 .52338 .87887 .51759 Mtetra
.87887 .51759 .88317 .52338 .89402 .52022 .88975 .51441 Mtetra
.88975 .51441 .89402 .52022 .90491 .51705 .90067 .51121 Mtetra
.90067 .51121 .90491 .51705 .91584 .51386 .91163 .50801 Mtetra
.91163 .50801 .91584 .51386 .92681 .51067 .92263 .50479 Mtetra
.92263 .50479 .92681 .51067 .93782 .50746 .93367 .50156 Mtetra
.93367 .50156 .93782 .50746 .94887 .50424 .94475 .49832 Mtetra
.94475 .49832 .94887 .50424 .95997 .50101 .95588 .49506 Mtetra
.553 .654 .902 r
.35827 .66095 .36375 .66754 .37275 .6659 .36722 .66067 Mtetra
.63 .73 .92 r
.36722 .66067 .37275 .6659 .38182 .66372 .3763 .65863 Mtetra
.639 .739 .921 r
.3763 .65863 .38182 .66372 .39092 .66144 .38542 .65635 Mtetra
.639 .74 .922 r
.38542 .65635 .39092 .66144 .40005 .65925 .39457 .65407 Mtetra
.626 .733 .924 r
.39457 .65407 .40005 .65925 .40919 .65782 .40375 .65206 Mtetra
.417 .627 .94 r
.40375 .65206 .40919 .65782 .41875 .64373 .41285 .65344 Mtetra
0 0 0 r
.41285 .65344 .41875 .64373 .42775 .64909 .42235 .64304 Mtetra
.592 .691 .911 r
.42235 .64304 .42775 .64909 .437 .64708 .4316 .64185 Mtetra
.64 .738 .92 r
.4316 .64185 .437 .64708 .44629 .64463 .44091 .63952 Mtetra
.649 .746 .92 r
.44091 .63952 .44629 .64463 .45563 .64202 .45026 .63695 Mtetra
.653 .749 .92 r
.45026 .63695 .45563 .64202 .465 .63933 .45965 .63428 Mtetra
.656 .751 .92 r
.45965 .63428 .465 .63933 .4744 .63657 .46907 .63153 Mtetra
.658 .753 .92 r
.46907 .63153 .4744 .63657 .48383 .63378 .47853 .62873 Mtetra
.47853 .62873 .48383 .63378 .4933 .63096 .48801 .6259 Mtetra
.659 .754 .92 r
.48801 .6259 .4933 .63096 .5028 .62813 .49753 .62305 Mtetra
.49753 .62305 .5028 .62813 .51233 .62528 .50709 .62019 Mtetra
.50709 .62019 .51233 .62528 .52189 .62244 .51667 .61732 Mtetra
.659 .753 .92 r
.51667 .61732 .52189 .62244 .53149 .61959 .52629 .61445 Mtetra
.658 .753 .92 r
.52629 .61445 .53149 .61959 .54112 .61673 .53594 .61158 Mtetra
.53594 .61158 .54112 .61673 .55078 .61388 .54563 .6087 Mtetra
.54563 .6087 .55078 .61388 .56048 .61101 .55535 .60581 Mtetra
.55535 .60581 .56048 .61101 .57021 .60814 .5651 .60292 Mtetra
.5651 .60292 .57021 .60814 .57998 .60526 .57489 .60002 Mtetra
.57489 .60002 .57998 .60526 .58978 .60237 .58472 .59712 Mtetra
.657 .753 .92 r
.58472 .59712 .58978 .60237 .59961 .59948 .59457 .5942 Mtetra
.59457 .5942 .59961 .59948 .60948 .59658 .60447 .59128 Mtetra
.60447 .59128 .60948 .59658 .61938 .59366 .61439 .58835 Mtetra
.657 .752 .92 r
.61439 .58835 .61938 .59366 .62932 .59074 .62436 .5854 Mtetra
.62436 .5854 .62932 .59074 .6393 .58781 .63435 .58245 Mtetra
.63435 .58245 .6393 .58781 .6493 .58487 .64439 .57949 Mtetra
.64439 .57949 .6493 .58487 .65935 .58192 .65446 .57652 Mtetra
.65446 .57652 .65935 .58192 .66943 .57896 .66456 .57354 Mtetra
.66456 .57354 .66943 .57896 .67955 .57599 .6747 .57055 Mtetra
.6747 .57055 .67955 .57599 .6897 .57301 .68488 .56756 Mtetra
.68488 .56756 .6897 .57301 .69989 .57002 .6951 .56455 Mtetra
.6951 .56455 .69989 .57002 .71011 .56702 .70535 .56153 Mtetra
.70535 .56153 .71011 .56702 .72038 .56401 .71563 .5585 Mtetra
.71563 .5585 .72038 .56401 .73068 .56099 .72596 .55546 Mtetra
.72596 .55546 .73068 .56099 .74101 .55796 .73632 .55241 Mtetra
.73632 .55241 .74101 .55796 .75139 .55492 .74672 .54935 Mtetra
.74672 .54935 .75139 .55492 .7618 .55187 .75716 .54627 Mtetra
.75716 .54627 .7618 .55187 .77225 .54881 .76764 .54319 Mtetra
.76764 .54319 .77225 .54881 .78274 .54574 .77815 .5401 Mtetra
.77815 .5401 .78274 .54574 .79326 .54265 .78871 .53699 Mtetra
.78871 .53699 .79326 .54265 .80383 .53956 .7993 .53388 Mtetra
.7993 .53388 .80383 .53956 .81443 .53646 .80993 .53075 Mtetra
.80993 .53075 .81443 .53646 .82507 .53334 .8206 .52762 Mtetra
.8206 .52762 .82507 .53334 .83575 .53021 .83131 .52447 Mtetra
.83131 .52447 .83575 .53021 .84647 .52707 .84205 .52131 Mtetra
.84205 .52131 .84647 .52707 .85723 .52393 .85284 .51814 Mtetra
.85284 .51814 .85723 .52393 .86803 .52076 .86367 .51495 Mtetra
.86367 .51495 .86803 .52076 .87887 .51759 .87454 .51176 Mtetra
.87454 .51176 .87887 .51759 .88975 .51441 .88545 .50855 Mtetra
.88545 .50855 .88975 .51441 .90067 .51121 .8964 .50534 Mtetra
.8964 .50534 .90067 .51121 .91163 .50801 .90739 .50211 Mtetra
.90739 .50211 .91163 .50801 .92263 .50479 .91842 .49887 Mtetra
.91842 .49887 .92263 .50479 .93367 .50156 .92949 .49561 Mtetra
.92949 .49561 .93367 .50156 .94475 .49832 .94061 .49235 Mtetra
.94061 .49235 .94475 .49832 .95588 .49506 .95176 .48907 Mtetra
0 0 .378 r
.3577 .5545 .35827 .66095 .36722 .66067 .36167 .65513 Mtetra
.613 .715 .918 r
.36167 .65513 .36722 .66067 .3763 .65863 .37075 .65346 Mtetra
.636 .737 .921 r
.37075 .65346 .3763 .65863 .38542 .65635 .37988 .65123 Mtetra
.64 .74 .921 r
.37988 .65123 .38542 .65635 .39457 .65407 .38905 .64891 Mtetra
.635 .738 .922 r
.38905 .64891 .39457 .65407 .40375 .65206 .39826 .64668 Mtetra
.599 .719 .928 r
.39826 .64668 .40375 .65206 .41285 .65344 .40747 .64521 Mtetra
.822 .701 .731 r
.40747 .64521 .41285 .65344 .42235 .64304 .41711 .63103 Mtetra
.359 .422 .79 r
.41711 .63103 .42235 .64304 .4316 .64185 .42617 .63638 Mtetra
.627 .726 .918 r
.42617 .63638 .4316 .64185 .44091 .63952 .43549 .63433 Mtetra
.646 .743 .92 r
.43549 .63433 .44091 .63952 .45026 .63695 .44486 .63183 Mtetra
.652 .748 .92 r
.44486 .63183 .45026 .63695 .45965 .63428 .45427 .62918 Mtetra
.655 .75 .92 r
.45427 .62918 .45965 .63428 .46907 .63153 .46371 .62644 Mtetra
.657 .752 .92 r
.46371 .62644 .46907 .63153 .47853 .62873 .47319 .62365 Mtetra
.658 .753 .92 r
.47319 .62365 .47853 .62873 .48801 .6259 .48269 .62081 Mtetra
.659 .754 .92 r
.48269 .62081 .48801 .6259 .49753 .62305 .49224 .61795 Mtetra
.49224 .61795 .49753 .62305 .50709 .62019 .50181 .61506 Mtetra
.50181 .61506 .50709 .62019 .51667 .61732 .51142 .61218 Mtetra
.51142 .61218 .51667 .61732 .52629 .61445 .52106 .60928 Mtetra
.658 .753 .92 r
.52106 .60928 .52629 .61445 .53594 .61158 .53074 .60639 Mtetra
.53074 .60639 .53594 .61158 .54563 .6087 .54045 .60349 Mtetra
.54045 .60349 .54563 .6087 .55535 .60581 .55019 .60058 Mtetra
.55019 .60058 .55535 .60581 .5651 .60292 .55996 .59767 Mtetra
.55996 .59767 .5651 .60292 .57489 .60002 .56978 .59475 Mtetra
.56978 .59475 .57489 .60002 .58472 .59712 .57962 .59182 Mtetra
.57962 .59182 .58472 .59712 .59457 .5942 .5895 .58889 Mtetra
.657 .753 .92 r
.5895 .58889 .59457 .5942 .60447 .59128 .59942 .58595 Mtetra
.59942 .58595 .60447 .59128 .61439 .58835 .60937 .58299 Mtetra
.60937 .58299 .61439 .58835 .62436 .5854 .61936 .58003 Mtetra
.657 .752 .92 r
.61936 .58003 .62436 .5854 .63435 .58245 .62938 .57706 Mtetra
.62938 .57706 .63435 .58245 .64439 .57949 .63944 .57408 Mtetra
.63944 .57408 .64439 .57949 .65446 .57652 .64953 .57109 Mtetra
.64953 .57109 .65446 .57652 .66456 .57354 .65966 .56809 Mtetra
.65966 .56809 .66456 .57354 .6747 .57055 .66983 .56508 Mtetra
.66983 .56508 .6747 .57055 .68488 .56756 .68003 .56206 Mtetra
.68003 .56206 .68488 .56756 .6951 .56455 .69027 .55903 Mtetra
.69027 .55903 .6951 .56455 .70535 .56153 .70055 .55599 Mtetra
.70055 .55599 .70535 .56153 .71563 .5585 .71086 .55294 Mtetra
.71086 .55294 .71563 .5585 .72596 .55546 .72121 .54988 Mtetra
.72121 .54988 .72596 .55546 .73632 .55241 .7316 .54681 Mtetra
.7316 .54681 .73632 .55241 .74672 .54935 .74203 .54373 Mtetra
.74203 .54373 .74672 .54935 .75716 .54627 .75249 .54064 Mtetra
.75249 .54064 .75716 .54627 .76764 .54319 .763 .53753 Mtetra
.763 .53753 .76764 .54319 .77815 .5401 .77354 .53442 Mtetra
.77354 .53442 .77815 .5401 .78871 .53699 .78412 .5313 Mtetra
.78412 .5313 .78871 .53699 .7993 .53388 .79474 .52816 Mtetra
.79474 .52816 .7993 .53388 .80993 .53075 .8054 .52501 Mtetra
.8054 .52501 .80993 .53075 .8206 .52762 .81609 .52185 Mtetra
.81609 .52185 .8206 .52762 .83131 .52447 .82683 .51868 Mtetra
.82683 .51868 .83131 .52447 .84205 .52131 .83761 .5155 Mtetra
.83761 .5155 .84205 .52131 .85284 .51814 .84843 .51231 Mtetra
.84843 .51231 .85284 .51814 .86367 .51495 .85928 .5091 Mtetra
.85928 .5091 .86367 .51495 .87454 .51176 .87018 .50589 Mtetra
.87018 .50589 .87454 .51176 .88545 .50855 .88112 .50266 Mtetra
.88112 .50266 .88545 .50855 .8964 .50534 .8921 .49942 Mtetra
.8921 .49942 .8964 .50534 .90739 .50211 .90312 .49617 Mtetra
.90312 .49617 .90739 .50211 .91842 .49887 .91418 .49291 Mtetra
.91418 .49291 .91842 .49887 .92949 .49561 .92528 .48963 Mtetra
.92528 .48963 .92949 .49561 .94061 .49235 .93643 .48634 Mtetra
.93643 .48634 .94061 .49235 .95176 .48907 .94762 .48304 Mtetra
.53 .305 .518 r
.3467 .65772 .3577 .5545 .36167 .65513 .35614 .64846 Mtetra
.553 .654 .902 r
.35614 .64846 .36167 .65513 .37075 .65346 .36517 .64815 Mtetra
.63 .73 .92 r
.36517 .64815 .37075 .65346 .37988 .65123 .37431 .64606 Mtetra
.639 .739 .921 r
.37431 .64606 .37988 .65123 .38905 .64891 .3835 .64374 Mtetra
.639 .74 .922 r
.3835 .64374 .38905 .64891 .39826 .64668 .39273 .64142 Mtetra
.626 .733 .924 r
.39273 .64142 .39826 .64668 .40747 .64521 .40197 .63937 Mtetra
.418 .628 .94 r
.40197 .63937 .40747 .64521 .41711 .63103 .41114 .64073 Mtetra
0 0 0 r
.41114 .64073 .41711 .63103 .42617 .63638 .42072 .63025 Mtetra
.592 .691 .911 r
.42072 .63025 .42617 .63638 .43549 .63433 .43004 .62902 Mtetra
.64 .738 .92 r
.43004 .62902 .43549 .63433 .44486 .63183 .43943 .62665 Mtetra
.649 .746 .92 r
.43943 .62665 .44486 .63183 .45427 .62918 .44885 .62404 Mtetra
.653 .749 .92 r
.44885 .62404 .45427 .62918 .46371 .62644 .45832 .62131 Mtetra
.656 .751 .92 r
.45832 .62131 .46371 .62644 .47319 .62365 .46781 .61852 Mtetra
.658 .753 .92 r
.46781 .61852 .47319 .62365 .48269 .62081 .47734 .61568 Mtetra
.47734 .61568 .48269 .62081 .49224 .61795 .48691 .6128 Mtetra
.659 .754 .92 r
.48691 .6128 .49224 .61795 .50181 .61506 .4965 .60991 Mtetra
.4965 .60991 .50181 .61506 .51142 .61218 .50613 .607 Mtetra
.50613 .607 .51142 .61218 .52106 .60928 .5158 .60408 Mtetra
.659 .753 .92 r
.5158 .60408 .52106 .60928 .53074 .60639 .52549 .60117 Mtetra
.658 .753 .92 r
.52549 .60117 .53074 .60639 .54045 .60349 .53523 .59824 Mtetra
.53523 .59824 .54045 .60349 .55019 .60058 .54499 .59532 Mtetra
.54499 .59532 .55019 .60058 .55996 .59767 .55479 .59238 Mtetra
.55479 .59238 .55996 .59767 .56978 .59475 .56463 .58945 Mtetra
.56463 .58945 .56978 .59475 .57962 .59182 .57449 .5865 Mtetra
.57449 .5865 .57962 .59182 .5895 .58889 .5844 .58354 Mtetra
.657 .753 .92 r
.5844 .58354 .5895 .58889 .59942 .58595 .59434 .58058 Mtetra
.59434 .58058 .59942 .58595 .60937 .58299 .60431 .57761 Mtetra
.60431 .57761 .60937 .58299 .61936 .58003 .61432 .57463 Mtetra
.657 .752 .92 r
.61432 .57463 .61936 .58003 .62938 .57706 .62437 .57164 Mtetra
.62437 .57164 .62938 .57706 .63944 .57408 .63445 .56864 Mtetra
.63445 .56864 .63944 .57408 .64953 .57109 .64457 .56563 Mtetra
.64457 .56563 .64953 .57109 .65966 .56809 .65473 .56261 Mtetra
.65473 .56261 .65966 .56809 .66983 .56508 .66492 .55958 Mtetra
.66492 .55958 .66983 .56508 .68003 .56206 .67515 .55654 Mtetra
.67515 .55654 .68003 .56206 .69027 .55903 .68541 .55349 Mtetra
.68541 .55349 .69027 .55903 .70055 .55599 .69571 .55043 Mtetra
.69571 .55043 .70055 .55599 .71086 .55294 .70606 .54735 Mtetra
.70606 .54735 .71086 .55294 .72121 .54988 .71643 .54427 Mtetra
.71643 .54427 .72121 .54988 .7316 .54681 .72685 .54118 Mtetra
.72685 .54118 .7316 .54681 .74203 .54373 .7373 .53808 Mtetra
.7373 .53808 .74203 .54373 .75249 .54064 .74779 .53496 Mtetra
.74779 .53496 .75249 .54064 .763 .53753 .75832 .53184 Mtetra
.75832 .53184 .763 .53753 .77354 .53442 .76889 .5287 Mtetra
.76889 .5287 .77354 .53442 .78412 .5313 .7795 .52556 Mtetra
.7795 .52556 .78412 .5313 .79474 .52816 .79015 .5224 Mtetra
.79015 .5224 .79474 .52816 .8054 .52501 .80083 .51923 Mtetra
.80083 .51923 .8054 .52501 .81609 .52185 .81156 .51605 Mtetra
.81156 .51605 .81609 .52185 .82683 .51868 .82233 .51286 Mtetra
.82233 .51286 .82683 .51868 .83761 .5155 .83313 .50965 Mtetra
.83313 .50965 .83761 .5155 .84843 .51231 .84398 .50644 Mtetra
.84398 .50644 .84843 .51231 .85928 .5091 .85486 .50321 Mtetra
.85486 .50321 .85928 .5091 .87018 .50589 .86579 .49997 Mtetra
.86579 .49997 .87018 .50589 .88112 .50266 .87676 .49672 Mtetra
.87676 .49672 .88112 .50266 .8921 .49942 .88777 .49346 Mtetra
.88777 .49346 .8921 .49942 .90312 .49617 .89882 .49019 Mtetra
.89882 .49019 .90312 .49617 .91418 .49291 .90991 .4869 Mtetra
.90991 .4869 .91418 .49291 .92528 .48963 .92105 .4836 Mtetra
.92105 .4836 .92528 .48963 .93643 .48634 .93222 .48029 Mtetra
.93222 .48029 .93643 .48634 .94762 .48304 .94344 .47697 Mtetra
.925 .697 .574 r
.34112 .65095 .3467 .65772 .35614 .64846 .35563 .54151 Mtetra
0 0 .373 r
.35563 .54151 .35614 .64846 .36517 .64815 .35957 .64252 Mtetra
.613 .715 .918 r
.35957 .64252 .36517 .64815 .37431 .64606 .36871 .64081 Mtetra
.636 .737 .921 r
.36871 .64081 .37431 .64606 .3835 .64374 .37792 .63854 Mtetra
.64 .74 .921 r
.37792 .63854 .3835 .64374 .39273 .64142 .38716 .63618 Mtetra
.635 .738 .922 r
.38716 .63618 .39273 .64142 .40197 .63937 .39643 .63391 Mtetra
.599 .719 .928 r
.39643 .63391 .40197 .63937 .41114 .64073 .40571 .6324 Mtetra
.822 .702 .732 r
.40571 .6324 .41114 .64073 .42072 .63025 .41544 .61812 Mtetra
.357 .421 .79 r
.41544 .61812 .42072 .63025 .43004 .62902 .42456 .62347 Mtetra
.627 .726 .918 r
.42456 .62347 .43004 .62902 .43943 .62665 .43396 .62138 Mtetra
.646 .743 .92 r
.43396 .62138 .43943 .62665 .44885 .62404 .4434 .61883 Mtetra
.652 .748 .92 r
.4434 .61883 .44885 .62404 .45832 .62131 .45289 .61613 Mtetra
.655 .75 .92 r
.45289 .61613 .45832 .62131 .46781 .61852 .4624 .61335 Mtetra
.657 .752 .92 r
.4624 .61335 .46781 .61852 .47734 .61568 .47195 .61051 Mtetra
.658 .753 .92 r
.47195 .61051 .47734 .61568 .48691 .6128 .48154 .60763 Mtetra
.659 .754 .92 r
.48154 .60763 .48691 .6128 .4965 .60991 .49116 .60471 Mtetra
.49116 .60471 .4965 .60991 .50613 .607 .50081 .60179 Mtetra
.50081 .60179 .50613 .607 .5158 .60408 .5105 .59885 Mtetra
.5105 .59885 .5158 .60408 .52549 .60117 .52022 .59591 Mtetra
.658 .753 .92 r
.52022 .59591 .52549 .60117 .53523 .59824 .52997 .59297 Mtetra
.52997 .59297 .53523 .59824 .54499 .59532 .53976 .59002 Mtetra
.53976 .59002 .54499 .59532 .55479 .59238 .54958 .58707 Mtetra
.54958 .58707 .55479 .59238 .56463 .58945 .55944 .58411 Mtetra
.55944 .58411 .56463 .58945 .57449 .5865 .56933 .58114 Mtetra
.56933 .58114 .57449 .5865 .5844 .58354 .57926 .57816 Mtetra
.57926 .57816 .5844 .58354 .59434 .58058 .58922 .57518 Mtetra
.657 .753 .92 r
.58922 .57518 .59434 .58058 .60431 .57761 .59922 .57219 Mtetra
.59922 .57219 .60431 .57761 .61432 .57463 .60926 .56918 Mtetra
.60926 .56918 .61432 .57463 .62437 .57164 .61933 .56617 Mtetra
.657 .752 .92 r
.61933 .56617 .62437 .57164 .63445 .56864 .62944 .56315 Mtetra
.62944 .56315 .63445 .56864 .64457 .56563 .63958 .56012 Mtetra
.63958 .56012 .64457 .56563 .65473 .56261 .64976 .55708 Mtetra
.64976 .55708 .65473 .56261 .66492 .55958 .65998 .55403 Mtetra
.65998 .55403 .66492 .55958 .67515 .55654 .67023 .55097 Mtetra
.67023 .55097 .67515 .55654 .68541 .55349 .68052 .5479 Mtetra
.68052 .5479 .68541 .55349 .69571 .55043 .69085 .54482 Mtetra
.69085 .54482 .69571 .55043 .70606 .54735 .70122 .54173 Mtetra
.70122 .54173 .70606 .54735 .71643 .54427 .71162 .53862 Mtetra
.71162 .53862 .71643 .54427 .72685 .54118 .72206 .53551 Mtetra
.72206 .53551 .72685 .54118 .7373 .53808 .73254 .53239 Mtetra
.73254 .53239 .7373 .53808 .74779 .53496 .74306 .52925 Mtetra
.74306 .52925 .74779 .53496 .75832 .53184 .75362 .52611 Mtetra
.75362 .52611 .75832 .53184 .76889 .5287 .76422 .52295 Mtetra
.76422 .52295 .76889 .5287 .7795 .52556 .77485 .51978 Mtetra
.77485 .51978 .7795 .52556 .79015 .5224 .78553 .5166 Mtetra
.78553 .5166 .79015 .5224 .80083 .51923 .79624 .51341 Mtetra
.79624 .51341 .80083 .51923 .81156 .51605 .807 .51021 Mtetra
.807 .51021 .81156 .51605 .82233 .51286 .81779 .50699 Mtetra
.81779 .50699 .82233 .51286 .83313 .50965 .82862 .50377 Mtetra
.82862 .50377 .83313 .50965 .84398 .50644 .8395 .50053 Mtetra
.8395 .50053 .84398 .50644 .85486 .50321 .85042 .49728 Mtetra
.85042 .49728 .85486 .50321 .86579 .49997 .86137 .49402 Mtetra
.86137 .49402 .86579 .49997 .87676 .49672 .87237 .49075 Mtetra
.87237 .49075 .87676 .49672 .88777 .49346 .88341 .48746 Mtetra
.88341 .48746 .88777 .49346 .89882 .49019 .89449 .48417 Mtetra
.89449 .48417 .89882 .49019 .90991 .4869 .90561 .48086 Mtetra
.90561 .48086 .90991 .4869 .92105 .4836 .91678 .47754 Mtetra
.91678 .47754 .92105 .4836 .93222 .48029 .92799 .4742 Mtetra
.92799 .4742 .93222 .48029 .94344 .47697 .93924 .47086 Mtetra
.526 .683 .938 r
.33545 .64529 .34112 .65095 .35563 .54151 .34447 .64509 Mtetra
.527 .301 .516 r
.34447 .64509 .35563 .54151 .35957 .64252 .35399 .63576 Mtetra
.553 .654 .902 r
.35399 .63576 .35957 .64252 .36871 .64081 .36308 .63542 Mtetra
.63 .73 .92 r
.36308 .63542 .36871 .64081 .37792 .63854 .3723 .63329 Mtetra
.639 .739 .921 r
.3723 .63329 .37792 .63854 .38716 .63618 .38156 .63093 Mtetra
.639 .74 .922 r
.38156 .63093 .38716 .63618 .39643 .63391 .39085 .62856 Mtetra
.626 .733 .924 r
.39085 .62856 .39643 .63391 .40571 .6324 .40017 .62647 Mtetra
.419 .628 .94 r
.40017 .62647 .40571 .6324 .41544 .61812 .40941 .6278 Mtetra
0 0 0 r
.40941 .6278 .41544 .61812 .42456 .62347 .41907 .61724 Mtetra
.592 .691 .911 r
.41907 .61724 .42456 .62347 .43396 .62138 .42846 .61598 Mtetra
.64 .738 .92 r
.42846 .61598 .43396 .62138 .4434 .61883 .43792 .61356 Mtetra
.649 .746 .92 r
.43792 .61356 .4434 .61883 .45289 .61613 .44742 .6109 Mtetra
.653 .749 .92 r
.44742 .6109 .45289 .61613 .4624 .61335 .45696 .60814 Mtetra
.656 .751 .92 r
.45696 .60814 .4624 .61335 .47195 .61051 .46653 .6053 Mtetra
.658 .753 .92 r
.46653 .6053 .47195 .61051 .48154 .60763 .47614 .60241 Mtetra
.47614 .60241 .48154 .60763 .49116 .60471 .48578 .59949 Mtetra
.659 .754 .92 r
.48578 .59949 .49116 .60471 .50081 .60179 .49545 .59654 Mtetra
.49545 .59654 .50081 .60179 .5105 .59885 .50516 .59358 Mtetra
.50516 .59358 .5105 .59885 .52022 .59591 .51491 .59062 Mtetra
.659 .753 .92 r
.51491 .59062 .52022 .59591 .52997 .59297 .52468 .58766 Mtetra
.658 .753 .92 r
.52468 .58766 .52997 .59297 .53976 .59002 .53449 .58469 Mtetra
.53449 .58469 .53976 .59002 .54958 .58707 .54434 .58171 Mtetra
.54434 .58171 .54958 .58707 .55944 .58411 .55422 .57873 Mtetra
.55422 .57873 .55944 .58411 .56933 .58114 .56414 .57574 Mtetra
.56414 .57574 .56933 .58114 .57926 .57816 .57409 .57275 Mtetra
.57409 .57275 .57926 .57816 .58922 .57518 .58408 .56974 Mtetra
.657 .753 .92 r
.58408 .56974 .58922 .57518 .59922 .57219 .5941 .56673 Mtetra
.5941 .56673 .59922 .57219 .60926 .56918 .60416 .56371 Mtetra
.60416 .56371 .60926 .56918 .61933 .56617 .61425 .56067 Mtetra
.657 .752 .92 r
.61425 .56067 .61933 .56617 .62944 .56315 .62439 .55763 Mtetra
.62439 .55763 .62944 .56315 .63958 .56012 .63455 .55458 Mtetra
.63455 .55458 .63958 .56012 .64976 .55708 .64476 .55152 Mtetra
.64476 .55152 .64976 .55708 .65998 .55403 .655 .54845 Mtetra
.655 .54845 .65998 .55403 .67023 .55097 .66528 .54537 Mtetra
.66528 .54537 .67023 .55097 .68052 .5479 .6756 .54228 Mtetra
.6756 .54228 .68052 .5479 .69085 .54482 .68595 .53917 Mtetra
.68595 .53917 .69085 .54482 .70122 .54173 .69635 .53606 Mtetra
.69635 .53606 .70122 .54173 .71162 .53862 .70678 .53294 Mtetra
.70678 .53294 .71162 .53862 .72206 .53551 .71724 .5298 Mtetra
.71724 .5298 .72206 .53551 .73254 .53239 .72775 .52666 Mtetra
.72775 .52666 .73254 .53239 .74306 .52925 .7383 .5235 Mtetra
.7383 .5235 .74306 .52925 .75362 .52611 .74888 .52033 Mtetra
.74888 .52033 .75362 .52611 .76422 .52295 .75951 .51715 Mtetra
.75951 .51715 .76422 .52295 .77485 .51978 .77017 .51396 Mtetra
.77017 .51396 .77485 .51978 .78553 .5166 .78087 .51076 Mtetra
.78087 .51076 .78553 .5166 .79624 .51341 .79162 .50755 Mtetra
.79162 .50755 .79624 .51341 .807 .51021 .8024 .50432 Mtetra
.8024 .50432 .807 .51021 .81779 .50699 .81322 .50109 Mtetra
.81322 .50109 .81779 .50699 .82862 .50377 .82409 .49784 Mtetra
.82409 .49784 .82862 .50377 .8395 .50053 .83499 .49458 Mtetra
.83499 .49458 .8395 .50053 .85042 .49728 .84594 .49131 Mtetra
.84594 .49131 .85042 .49728 .86137 .49402 .85692 .48803 Mtetra
.85692 .48803 .86137 .49402 .87237 .49075 .86795 .48473 Mtetra
.86795 .48473 .87237 .49075 .88341 .48746 .87902 .48142 Mtetra
.87902 .48142 .88341 .48746 .89449 .48417 .89013 .4781 Mtetra
.89013 .4781 .89449 .48417 .90561 .48086 .90129 .47477 Mtetra
.90129 .47477 .90561 .48086 .91678 .47754 .91248 .47142 Mtetra
.91248 .47142 .91678 .47754 .92799 .4742 .92372 .46807 Mtetra
.92372 .46807 .92799 .4742 .93924 .47086 .935 .4647 Mtetra
.605 .721 .927 r
.32973 .63986 .33545 .64529 .34447 .64509 .33884 .63824 Mtetra
.926 .697 .572 r
.33884 .63824 .34447 .64509 .35399 .63576 .35353 .5283 Mtetra
0 0 .369 r
.35353 .5283 .35399 .63576 .36308 .63542 .35743 .62971 Mtetra
.613 .715 .918 r
.35743 .62971 .36308 .63542 .3723 .63329 .36664 .62796 Mtetra
.636 .737 .921 r
.36664 .62796 .3723 .63329 .38156 .63093 .37592 .62565 Mtetra
.64 .74 .921 r
.37592 .62565 .38156 .63093 .39085 .62856 .38523 .62324 Mtetra
.635 .738 .922 r
.38523 .62324 .39085 .62856 .40017 .62647 .39458 .62093 Mtetra
.599 .719 .928 r
.39458 .62093 .40017 .62647 .40941 .6278 .40393 .61938 Mtetra
.823 .702 .732 r
.40393 .61938 .40941 .6278 .41907 .61724 .41374 .605 Mtetra
.356 .42 .79 r
.41374 .605 .41907 .61724 .42846 .61598 .42293 .61034 Mtetra
.627 .726 .918 r
.42293 .61034 .42846 .61598 .43792 .61356 .4324 .6082 Mtetra
.646 .743 .92 r
.4324 .6082 .43792 .61356 .44742 .6109 .44192 .60561 Mtetra
.652 .748 .92 r
.44192 .60561 .44742 .6109 .45696 .60814 .45148 .60287 Mtetra
.655 .75 .92 r
.45148 .60287 .45696 .60814 .46653 .6053 .46107 .60004 Mtetra
.657 .752 .92 r
.46107 .60004 .46653 .6053 .47614 .60241 .4707 .59715 Mtetra
.658 .753 .92 r
.4707 .59715 .47614 .60241 .48578 .59949 .48037 .59422 Mtetra
.659 .754 .92 r
.48037 .59422 .48578 .59949 .49545 .59654 .49006 .59126 Mtetra
.49006 .59126 .49545 .59654 .50516 .59358 .49979 .58829 Mtetra
.49979 .58829 .50516 .59358 .51491 .59062 .50956 .5853 Mtetra
.50956 .5853 .51491 .59062 .52468 .58766 .51936 .58231 Mtetra
.658 .753 .92 r
.51936 .58231 .52468 .58766 .53449 .58469 .52919 .57932 Mtetra
.52919 .57932 .53449 .58469 .54434 .58171 .53906 .57632 Mtetra
.53906 .57632 .54434 .58171 .55422 .57873 .54897 .57332 Mtetra
.54897 .57332 .55422 .57873 .56414 .57574 .55891 .57031 Mtetra
.55891 .57031 .56414 .57574 .57409 .57275 .56888 .56729 Mtetra
.56888 .56729 .57409 .57275 .58408 .56974 .57889 .56427 Mtetra
.57889 .56427 .58408 .56974 .5941 .56673 .58894 .56123 Mtetra
.657 .753 .92 r
.58894 .56123 .5941 .56673 .60416 .56371 .59903 .55819 Mtetra
.59903 .55819 .60416 .56371 .61425 .56067 .60915 .55514 Mtetra
.60915 .55514 .61425 .56067 .62439 .55763 .6193 .55208 Mtetra
.657 .752 .92 r
.6193 .55208 .62439 .55763 .63455 .55458 .6295 .549 Mtetra
.6295 .549 .63455 .55458 .64476 .55152 .63973 .54592 Mtetra
.63973 .54592 .64476 .55152 .655 .54845 .64999 .54283 Mtetra
.64999 .54283 .655 .54845 .66528 .54537 .6603 .53973 Mtetra
.6603 .53973 .66528 .54537 .6756 .54228 .67064 .53661 Mtetra
.67064 .53661 .6756 .54228 .68595 .53917 .68102 .53349 Mtetra
.68102 .53349 .68595 .53917 .69635 .53606 .69144 .53036 Mtetra
.69144 .53036 .69635 .53606 .70678 .53294 .7019 .52721 Mtetra
.7019 .52721 .70678 .53294 .71724 .5298 .71239 .52406 Mtetra
.71239 .52406 .71724 .5298 .72775 .52666 .72293 .52089 Mtetra
.72293 .52089 .72775 .52666 .7383 .5235 .7335 .51771 Mtetra
.7335 .51771 .7383 .5235 .74888 .52033 .74411 .51452 Mtetra
.74411 .51452 .74888 .52033 .75951 .51715 .75477 .51132 Mtetra
.75477 .51132 .75951 .51715 .77017 .51396 .76546 .50811 Mtetra
.76546 .50811 .77017 .51396 .78087 .51076 .77619 .50488 Mtetra
.77619 .50488 .78087 .51076 .79162 .50755 .78696 .50165 Mtetra
.78696 .50165 .79162 .50755 .8024 .50432 .79777 .4984 Mtetra
.79777 .4984 .8024 .50432 .81322 .50109 .80862 .49514 Mtetra
.80862 .49514 .81322 .50109 .82409 .49784 .81952 .49187 Mtetra
.81952 .49187 .82409 .49784 .83499 .49458 .83045 .48859 Mtetra
.83045 .48859 .83499 .49458 .84594 .49131 .84142 .48529 Mtetra
.84142 .48529 .84594 .49131 .85692 .48803 .85244 .48199 Mtetra
.85244 .48199 .85692 .48803 .86795 .48473 .8635 .47867 Mtetra
.8635 .47867 .86795 .48473 .87902 .48142 .8746 .47534 Mtetra
.8746 .47534 .87902 .48142 .89013 .4781 .88574 .47199 Mtetra
.88574 .47199 .89013 .4781 .90129 .47477 .89693 .46864 Mtetra
.89693 .46864 .90129 .47477 .91248 .47142 .90815 .46527 Mtetra
.90815 .46527 .91248 .47142 .92372 .46807 .91942 .46189 Mtetra
.91942 .46189 .92372 .46807 .935 .4647 .93074 .4585 Mtetra
.622 .73 .924 r
.32397 .63448 .32973 .63986 .33884 .63824 .33311 .63249 Mtetra
.526 .683 .938 r
.33311 .63249 .33884 .63824 .35353 .5283 .3422 .63226 Mtetra
.524 .298 .513 r
.3422 .63226 .35353 .5283 .35743 .62971 .3518 .62286 Mtetra
.553 .654 .903 r
.3518 .62286 .35743 .62971 .36664 .62796 .36096 .62248 Mtetra
.63 .73 .92 r
.36096 .62248 .36664 .62796 .37592 .62565 .37025 .62031 Mtetra
.639 .739 .921 r
.37025 .62031 .37592 .62565 .38523 .62324 .37958 .6179 Mtetra
.639 .74 .922 r
.37958 .6179 .38523 .62324 .39458 .62093 .38895 .61549 Mtetra
.626 .733 .924 r
.38895 .61549 .39458 .62093 .40393 .61938 .39834 .61336 Mtetra
.42 .628 .94 r
.39834 .61336 .40393 .61938 .41374 .605 .40765 .61466 Mtetra
0 0 0 r
.40765 .61466 .41374 .605 .42293 .61034 .41739 .60402 Mtetra
.592 .691 .911 r
.41739 .60402 .42293 .61034 .4324 .6082 .42685 .60272 Mtetra
.64 .738 .92 r
.42685 .60272 .4324 .6082 .44192 .60561 .43639 .60026 Mtetra
.649 .746 .92 r
.43639 .60026 .44192 .60561 .45148 .60287 .44597 .59755 Mtetra
.653 .749 .92 r
.44597 .59755 .45148 .60287 .46107 .60004 .45558 .59474 Mtetra
.656 .751 .92 r
.45558 .59474 .46107 .60004 .4707 .59715 .46523 .59185 Mtetra
.657 .753 .92 r
.46523 .59185 .4707 .59715 .48037 .59422 .47492 .58892 Mtetra
.658 .753 .92 r
.47492 .58892 .48037 .59422 .49006 .59126 .48464 .58595 Mtetra
.659 .754 .92 r
.48464 .58595 .49006 .59126 .49979 .58829 .49439 .58295 Mtetra
.49439 .58295 .49979 .58829 .50956 .5853 .50418 .57995 Mtetra
.50418 .57995 .50956 .5853 .51936 .58231 .514 .57694 Mtetra
.659 .753 .92 r
.514 .57694 .51936 .58231 .52919 .57932 .52386 .57392 Mtetra
.658 .753 .92 r
.52386 .57392 .52919 .57932 .53906 .57632 .53375 .5709 Mtetra
.53375 .5709 .53906 .57632 .54897 .57332 .54368 .56788 Mtetra
.54368 .56788 .54897 .57332 .55891 .57031 .55364 .56484 Mtetra
.55364 .56484 .55891 .57031 .56888 .56729 .56364 .56181 Mtetra
.56364 .56181 .56888 .56729 .57889 .56427 .57368 .55876 Mtetra
.57368 .55876 .57889 .56427 .58894 .56123 .58375 .5557 Mtetra
.657 .753 .92 r
.58375 .5557 .58894 .56123 .59903 .55819 .59386 .55264 Mtetra
.59386 .55264 .59903 .55819 .60915 .55514 .604 .54957 Mtetra
.604 .54957 .60915 .55514 .6193 .55208 .61418 .54648 Mtetra
.657 .752 .92 r
.61418 .54648 .6193 .55208 .6295 .549 .6244 .54339 Mtetra
.6244 .54339 .6295 .549 .63973 .54592 .63466 .54029 Mtetra
.63466 .54029 .63973 .54592 .64999 .54283 .64495 .53717 Mtetra
.64495 .53717 .64999 .54283 .6603 .53973 .65528 .53405 Mtetra
.65528 .53405 .6603 .53973 .67064 .53661 .66565 .53091 Mtetra
.66565 .53091 .67064 .53661 .68102 .53349 .67606 .52777 Mtetra
.67606 .52777 .68102 .53349 .69144 .53036 .6865 .52461 Mtetra
.6865 .52461 .69144 .53036 .7019 .52721 .69699 .52145 Mtetra
.69699 .52145 .7019 .52721 .71239 .52406 .70751 .51827 Mtetra
.70751 .51827 .71239 .52406 .72293 .52089 .71807 .51508 Mtetra
.71807 .51508 .72293 .52089 .7335 .51771 .72867 .51188 Mtetra
.72867 .51188 .7335 .51771 .74411 .51452 .73931 .50867 Mtetra
.73931 .50867 .74411 .51452 .75477 .51132 .74999 .50544 Mtetra
.74999 .50544 .75477 .51132 .76546 .50811 .76071 .50221 Mtetra
.76071 .50221 .76546 .50811 .77619 .50488 .77147 .49896 Mtetra
.77147 .49896 .77619 .50488 .78696 .50165 .78227 .49571 Mtetra
.78227 .49571 .78696 .50165 .79777 .4984 .79311 .49244 Mtetra
.79311 .49244 .79777 .4984 .80862 .49514 .80399 .48915 Mtetra
.80399 .48915 .80862 .49514 .81952 .49187 .81491 .48586 Mtetra
.81491 .48586 .81952 .49187 .83045 .48859 .82588 .48256 Mtetra
.82588 .48256 .83045 .48859 .84142 .48529 .83688 .47924 Mtetra
.83688 .47924 .84142 .48529 .85244 .48199 .84793 .47591 Mtetra
.84793 .47591 .85244 .48199 .8635 .47867 .85902 .47257 Mtetra
.85902 .47257 .8635 .47867 .8746 .47534 .87015 .46921 Mtetra
.87015 .46921 .8746 .47534 .88574 .47199 .88132 .46584 Mtetra
.88132 .46584 .88574 .47199 .89693 .46864 .89254 .46246 Mtetra
.89254 .46246 .89693 .46864 .90815 .46527 .9038 .45907 Mtetra
.9038 .45907 .90815 .46527 .91942 .46189 .9151 .45567 Mtetra
.9151 .45567 .91942 .46189 .93074 .4585 .92644 .45225 Mtetra
.626 .731 .922 r
.31817 .62907 .32397 .63448 .33311 .63249 .32734 .62698 Mtetra
.605 .721 .927 r
.32734 .62698 .33311 .63249 .3422 .63226 .33652 .62532 Mtetra
.927 .698 .571 r
.33652 .62532 .3422 .63226 .3518 .62286 .35139 .51489 Mtetra
0 0 .364 r
.35139 .51489 .3518 .62286 .36096 .62248 .35525 .61669 Mtetra
.613 .715 .918 r
.35525 .61669 .36096 .62248 .37025 .62031 .36454 .61489 Mtetra
.636 .737 .921 r
.36454 .61489 .37025 .62031 .37958 .6179 .37389 .61254 Mtetra
.64 .74 .921 r
.37389 .61254 .37958 .6179 .38895 .61549 .38328 .61008 Mtetra
.635 .738 .922 r
.38328 .61008 .38895 .61549 .39834 .61336 .39269 .60773 Mtetra
.6 .719 .928 r
.39269 .60773 .39834 .61336 .40765 .61466 .40212 .60614 Mtetra
.824 .703 .732 r
.40212 .60614 .40765 .61466 .41739 .60402 .41201 .59166 Mtetra
.354 .419 .79 r
.41201 .59166 .41739 .60402 .42685 .60272 .42127 .59699 Mtetra
.627 .726 .918 r
.42127 .59699 .42685 .60272 .43639 .60026 .43082 .59481 Mtetra
.646 .743 .92 r
.43082 .59481 .43639 .60026 .44597 .59755 .44042 .59218 Mtetra
.652 .748 .92 r
.44042 .59218 .44597 .59755 .45558 .59474 .45005 .58939 Mtetra
.655 .75 .92 r
.45005 .58939 .45558 .59474 .46523 .59185 .45972 .58651 Mtetra
.657 .752 .92 r
.45972 .58651 .46523 .59185 .47492 .58892 .46943 .58357 Mtetra
.658 .753 .92 r
.46943 .58357 .47492 .58892 .48464 .58595 .47917 .58059 Mtetra
.659 .754 .92 r
.47917 .58059 .48464 .58595 .49439 .58295 .48895 .57758 Mtetra
.48895 .57758 .49439 .58295 .50418 .57995 .49876 .57456 Mtetra
.49876 .57456 .50418 .57995 .514 .57694 .50861 .57152 Mtetra
.50861 .57152 .514 .57694 .52386 .57392 .51849 .56849 Mtetra
.658 .753 .92 r
.51849 .56849 .52386 .57392 .53375 .5709 .5284 .56544 Mtetra
.5284 .56544 .53375 .5709 .54368 .56788 .53835 .5624 Mtetra
.53835 .5624 .54368 .56788 .55364 .56484 .54834 .55934 Mtetra
.54834 .55934 .55364 .56484 .56364 .56181 .55837 .55628 Mtetra
.55837 .55628 .56364 .56181 .57368 .55876 .56843 .55321 Mtetra
.56843 .55321 .57368 .55876 .58375 .5557 .57852 .55014 Mtetra
.57852 .55014 .58375 .5557 .59386 .55264 .58865 .54705 Mtetra
.657 .753 .92 r
.58865 .54705 .59386 .55264 .604 .54957 .59882 .54396 Mtetra
.59882 .54396 .604 .54957 .61418 .54648 .60903 .54085 Mtetra
.60903 .54085 .61418 .54648 .6244 .54339 .61927 .53774 Mtetra
.657 .752 .92 r
.61927 .53774 .6244 .54339 .63466 .54029 .62956 .53461 Mtetra
.62956 .53461 .63466 .54029 .64495 .53717 .63987 .53148 Mtetra
.63987 .53148 .64495 .53717 .65528 .53405 .65023 .52833 Mtetra
.65023 .52833 .65528 .53405 .66565 .53091 .66063 .52518 Mtetra
.66063 .52518 .66565 .53091 .67606 .52777 .67106 .52201 Mtetra
.67106 .52201 .67606 .52777 .6865 .52461 .68153 .51883 Mtetra
.68153 .51883 .6865 .52461 .69699 .52145 .69204 .51564 Mtetra
.69204 .51564 .69699 .52145 .70751 .51827 .70259 .51244 Mtetra
.70259 .51244 .70751 .51827 .71807 .51508 .71318 .50923 Mtetra
.71318 .50923 .71807 .51508 .72867 .51188 .72381 .50601 Mtetra
.72381 .50601 .72867 .51188 .73931 .50867 .73448 .50277 Mtetra
.73448 .50277 .73931 .50867 .74999 .50544 .74518 .49953 Mtetra
.74518 .49953 .74999 .50544 .76071 .50221 .75593 .49627 Mtetra
.75593 .49627 .76071 .50221 .77147 .49896 .76672 .493 Mtetra
.76672 .493 .77147 .49896 .78227 .49571 .77755 .48972 Mtetra
.77755 .48972 .78227 .49571 .79311 .49244 .78842 .48643 Mtetra
.78842 .48643 .79311 .49244 .80399 .48915 .79933 .48313 Mtetra
.79933 .48313 .80399 .48915 .81491 .48586 .81028 .47981 Mtetra
.81028 .47981 .81491 .48586 .82588 .48256 .82127 .47648 Mtetra
.82127 .47648 .82588 .48256 .83688 .47924 .83231 .47314 Mtetra
.83231 .47314 .83688 .47924 .84793 .47591 .84338 .46979 Mtetra
.84338 .46979 .84793 .47591 .85902 .47257 .8545 .46642 Mtetra
.8545 .46642 .85902 .47257 .87015 .46921 .86566 .46304 Mtetra
.86566 .46304 .87015 .46921 .88132 .46584 .87687 .45965 Mtetra
.87687 .45965 .88132 .46584 .89254 .46246 .88812 .45625 Mtetra
.88812 .45625 .89254 .46246 .9038 .45907 .89941 .45283 Mtetra
.89941 .45283 .9038 .45907 .9151 .45567 .91074 .4494 Mtetra
.91074 .4494 .9151 .45567 .92644 .45225 .92212 .44596 Mtetra
.623 .727 .921 r
.31234 .62355 .31817 .62907 .32734 .62698 .32152 .62151 Mtetra
.622 .73 .924 r
.32152 .62151 .32734 .62698 .33652 .62532 .33074 .61948 Mtetra
.526 .683 .937 r
.33074 .61948 .33652 .62532 .35139 .51489 .3399 .61922 Mtetra
.522 .294 .51 r
.3399 .61922 .35139 .51489 .35525 .61669 .34957 .60974 Mtetra
.553 .654 .903 r
.34957 .60974 .35525 .61669 .36454 .61489 .3588 .60933 Mtetra
.63 .73 .92 r
.3588 .60933 .36454 .61489 .37389 .61254 .36816 .60711 Mtetra
.639 .739 .921 r
.36816 .60711 .37389 .61254 .38328 .61008 .37757 .60466 Mtetra
.639 .74 .922 r
.37757 .60466 .38328 .61008 .39269 .60773 .38701 .60221 Mtetra
.626 .733 .924 r
.38701 .60221 .39269 .60773 .40212 .60614 .39648 .60003 Mtetra
.421 .628 .94 r
.39648 .60003 .40212 .60614 .41201 .59166 .40586 .60131 Mtetra
0 0 0 r
.40586 .60131 .41201 .59166 .42127 .59699 .41568 .59058 Mtetra
.592 .691 .911 r
.41568 .59058 .42127 .59699 .43082 .59481 .42522 .58924 Mtetra
.64 .738 .92 r
.42522 .58924 .43082 .59481 .44042 .59218 .43483 .58673 Mtetra
.649 .746 .92 r
.43483 .58673 .44042 .59218 .45005 .58939 .44449 .58398 Mtetra
.653 .749 .92 r
.44449 .58398 .45005 .58939 .45972 .58651 .45418 .58112 Mtetra
.656 .751 .92 r
.45418 .58112 .45972 .58651 .46943 .58357 .46391 .57818 Mtetra
.657 .753 .92 r
.46391 .57818 .46943 .58357 .47917 .58059 .47367 .5752 Mtetra
.658 .753 .92 r
.47367 .5752 .47917 .58059 .48895 .57758 .48347 .57218 Mtetra
.659 .754 .92 r
.48347 .57218 .48895 .57758 .49876 .57456 .49331 .56913 Mtetra
.49331 .56913 .49876 .57456 .50861 .57152 .50317 .56608 Mtetra
.50317 .56608 .50861 .57152 .51849 .56849 .51308 .56302 Mtetra
.659 .753 .92 r
.51308 .56302 .51849 .56849 .5284 .56544 .52302 .55995 Mtetra
.658 .753 .92 r
.52302 .55995 .5284 .56544 .53835 .5624 .53299 .55688 Mtetra
.53299 .55688 .53835 .5624 .54834 .55934 .54301 .5538 Mtetra
.54301 .5538 .54834 .55934 .55837 .55628 .55305 .55072 Mtetra
.55305 .55072 .55837 .55628 .56843 .55321 .56314 .54763 Mtetra
.56314 .54763 .56843 .55321 .57852 .55014 .57326 .54453 Mtetra
.57326 .54453 .57852 .55014 .58865 .54705 .58342 .54143 Mtetra
.657 .753 .92 r
.58342 .54143 .58865 .54705 .59882 .54396 .59361 .53831 Mtetra
.59361 .53831 .59882 .54396 .60903 .54085 .60384 .53518 Mtetra
.60384 .53518 .60903 .54085 .61927 .53774 .61411 .53205 Mtetra
.657 .752 .92 r
.61411 .53205 .61927 .53774 .62956 .53461 .62442 .5289 Mtetra
.62442 .5289 .62956 .53461 .63987 .53148 .63476 .52574 Mtetra
.63476 .52574 .63987 .53148 .65023 .52833 .64515 .52258 Mtetra
.64515 .52258 .65023 .52833 .66063 .52518 .65557 .5194 Mtetra
.65557 .5194 .66063 .52518 .67106 .52201 .66603 .51621 Mtetra
.66603 .51621 .67106 .52201 .68153 .51883 .67652 .51301 Mtetra
.67652 .51301 .68153 .51883 .69204 .51564 .68706 .5098 Mtetra
.68706 .5098 .69204 .51564 .70259 .51244 .69764 .50658 Mtetra
.69764 .50658 .70259 .51244 .71318 .50923 .70825 .50334 Mtetra
.70825 .50334 .71318 .50923 .72381 .50601 .71891 .5001 Mtetra
.71891 .5001 .72381 .50601 .73448 .50277 .72961 .49684 Mtetra
.72961 .49684 .73448 .50277 .74518 .49953 .74034 .49357 Mtetra
.74034 .49357 .74518 .49953 .75593 .49627 .75112 .49029 Mtetra
.75112 .49029 .75593 .49627 .76672 .493 .76193 .487 Mtetra
.76193 .487 .76672 .493 .77755 .48972 .77279 .4837 Mtetra
.77279 .4837 .77755 .48972 .78842 .48643 .78369 .48038 Mtetra
.78369 .48038 .78842 .48643 .79933 .48313 .79463 .47705 Mtetra
.79463 .47705 .79933 .48313 .81028 .47981 .80561 .47371 Mtetra
.80561 .47371 .81028 .47981 .82127 .47648 .81663 .47036 Mtetra
.81663 .47036 .82127 .47648 .83231 .47314 .8277 .467 Mtetra
.8277 .467 .83231 .47314 .84338 .46979 .83881 .46362 Mtetra
.83881 .46362 .84338 .46979 .8545 .46642 .84996 .46023 Mtetra
.84996 .46023 .8545 .46642 .86566 .46304 .86115 .45683 Mtetra
.86115 .45683 .86566 .46304 .87687 .45965 .87238 .45341 Mtetra
.87238 .45341 .87687 .45965 .88812 .45625 .88366 .44998 Mtetra
.88366 .44998 .88812 .45625 .89941 .45283 .89499 .44654 Mtetra
.89499 .44654 .89941 .45283 .91074 .4494 .90635 .44309 Mtetra
.90635 .44309 .91074 .4494 .92212 .44596 .91776 .43962 Mtetra
.61 .715 .919 r
.30649 .61778 .31234 .62355 .32152 .62151 .31567 .61602 Mtetra
.626 .731 .922 r
.31567 .61602 .32152 .62151 .33074 .61948 .32491 .61389 Mtetra
.605 .721 .927 r
.32491 .61389 .33074 .61948 .3399 .61922 .33416 .61218 Mtetra
.928 .698 .569 r
.33416 .61218 .3399 .61922 .34957 .60974 .34922 .50127 Mtetra
0 0 .36 r
.34922 .50127 .34957 .60974 .3588 .60933 .35304 .60345 Mtetra
.613 .715 .918 r
.35304 .60345 .3588 .60933 .36816 .60711 .3624 .60161 Mtetra
.636 .737 .921 r
.3624 .60161 .36816 .60711 .37757 .60466 .37182 .59921 Mtetra
.64 .74 .921 r
.37182 .59921 .37757 .60466 .38701 .60221 .38129 .59671 Mtetra
.635 .738 .922 r
.38129 .59671 .38701 .60221 .39648 .60003 .39078 .59431 Mtetra
.6 .719 .928 r
.39078 .59431 .39648 .60003 .40586 .60131 .40028 .59268 Mtetra
.824 .704 .732 r
.40028 .59268 .40586 .60131 .41568 .59058 .41026 .57811 Mtetra
.353 .419 .79 r
.41026 .57811 .41568 .59058 .42522 .58924 .41959 .58342 Mtetra
.627 .726 .918 r
.41959 .58342 .42522 .58924 .43483 .58673 .42921 .5812 Mtetra
.646 .743 .92 r
.42921 .5812 .43483 .58673 .44449 .58398 .43889 .57851 Mtetra
.652 .748 .92 r
.43889 .57851 .44449 .58398 .45418 .58112 .4486 .57567 Mtetra
.655 .75 .92 r
.4486 .57567 .45418 .58112 .46391 .57818 .45835 .57275 Mtetra
.657 .752 .92 r
.45835 .57275 .46391 .57818 .47367 .5752 .46814 .56976 Mtetra
.658 .753 .92 r
.46814 .56976 .47367 .5752 .48347 .57218 .47796 .56673 Mtetra
.659 .754 .92 r
.47796 .56673 .48347 .57218 .49331 .56913 .48782 .56367 Mtetra
.48782 .56367 .49331 .56913 .50317 .56608 .49771 .5606 Mtetra
.49771 .5606 .50317 .56608 .51308 .56302 .50764 .55751 Mtetra
.50764 .55751 .51308 .56302 .52302 .55995 .5176 .55442 Mtetra
.658 .753 .92 r
.5176 .55442 .52302 .55995 .53299 .55688 .5276 .55133 Mtetra
.5276 .55133 .53299 .55688 .54301 .5538 .53763 .54823 Mtetra
.53763 .54823 .54301 .5538 .55305 .55072 .54771 .54512 Mtetra
.54771 .54512 .55305 .55072 .56314 .54763 .55781 .54201 Mtetra
.55781 .54201 .56314 .54763 .57326 .54453 .56796 .53889 Mtetra
.56796 .53889 .57326 .54453 .58342 .54143 .57814 .53576 Mtetra
.57814 .53576 .58342 .54143 .59361 .53831 .58836 .53262 Mtetra
.657 .753 .92 r
.58836 .53262 .59361 .53831 .60384 .53518 .59862 .52948 Mtetra
.59862 .52948 .60384 .53518 .61411 .53205 .60891 .52632 Mtetra
.60891 .52632 .61411 .53205 .62442 .5289 .61925 .52315 Mtetra
.657 .752 .92 r
.61925 .52315 .62442 .5289 .63476 .52574 .62962 .51997 Mtetra
.62962 .51997 .63476 .52574 .64515 .52258 .64002 .51678 Mtetra
.64002 .51678 .64515 .52258 .65557 .5194 .65047 .51358 Mtetra
.65047 .51358 .65557 .5194 .66603 .51621 .66096 .51037 Mtetra
.66096 .51037 .66603 .51621 .67652 .51301 .67148 .50715 Mtetra
.67148 .50715 .67652 .51301 .68706 .5098 .68205 .50391 Mtetra
.68205 .50391 .68706 .5098 .69764 .50658 .69265 .50067 Mtetra
.69265 .50067 .69764 .50658 .70825 .50334 .7033 .49741 Mtetra
.7033 .49741 .70825 .50334 .71891 .5001 .71398 .49415 Mtetra
.71398 .49415 .71891 .5001 .72961 .49684 .7247 .49087 Mtetra
.7247 .49087 .72961 .49684 .74034 .49357 .73547 .48757 Mtetra
.73547 .48757 .74034 .49357 .75112 .49029 .74627 .48427 Mtetra
.74627 .48427 .75112 .49029 .76193 .487 .75712 .48096 Mtetra
.75712 .48096 .76193 .487 .77279 .4837 .768 .47763 Mtetra
.768 .47763 .77279 .4837 .78369 .48038 .77893 .47429 Mtetra
.77893 .47429 .78369 .48038 .79463 .47705 .7899 .47094 Mtetra
.7899 .47094 .79463 .47705 .80561 .47371 .80091 .46758 Mtetra
.80091 .46758 .80561 .47371 .81663 .47036 .81196 .4642 Mtetra
.81196 .4642 .81663 .47036 .8277 .467 .82306 .46081 Mtetra
.82306 .46081 .8277 .467 .83881 .46362 .8342 .45741 Mtetra
.8342 .45741 .83881 .46362 .84996 .46023 .84538 .454 Mtetra
.84538 .454 .84996 .46023 .86115 .45683 .8566 .45057 Mtetra
.8566 .45057 .86115 .45683 .87238 .45341 .86787 .44713 Mtetra
.86787 .44713 .87238 .45341 .88366 .44998 .87918 .44368 Mtetra
.87918 .44368 .88366 .44998 .89499 .44654 .89053 .44021 Mtetra
.89053 .44021 .89499 .44654 .90635 .44309 .90193 .43673 Mtetra
.90193 .43673 .90635 .44309 .91776 .43962 .91337 .43324 Mtetra
.563 .669 .909 r
.30066 .61112 .30649 .61778 .31567 .61602 .30979 .61041 Mtetra
.623 .727 .921 r
.30979 .61041 .31567 .61602 .32491 .61389 .31904 .60833 Mtetra
.622 .73 .924 r
.31904 .60833 .32491 .61389 .33416 .61218 .32833 .60626 Mtetra
.526 .683 .937 r
.32833 .60626 .33416 .61218 .34922 .50127 .33755 .60597 Mtetra
.519 .29 .507 r
.33755 .60597 .34922 .50127 .35304 .60345 .34731 .59641 Mtetra
.553 .654 .903 r
.34731 .59641 .35304 .60345 .3624 .60161 .35661 .59596 Mtetra
.63 .73 .92 r
.35661 .59596 .3624 .60161 .37182 .59921 .36604 .5937 Mtetra
.639 .739 .921 r
.36604 .5937 .37182 .59921 .38129 .59671 .37552 .5912 Mtetra
.639 .74 .922 r
.37552 .5912 .38129 .59671 .39078 .59431 .38504 .5887 Mtetra
.626 .733 .924 r
.38504 .5887 .39078 .59431 .40028 .59268 .39458 .58648 Mtetra
.422 .628 .939 r
.39458 .58648 .40028 .59268 .41026 .57811 .40404 .58773 Mtetra
0 0 0 r
.40404 .58773 .41026 .57811 .41959 .58342 .41394 .57692 Mtetra
.592 .691 .911 r
.41394 .57692 .41959 .58342 .42921 .5812 .42356 .57553 Mtetra
.64 .738 .92 r
.42356 .57553 .42921 .5812 .43889 .57851 .43325 .57298 Mtetra
.649 .746 .92 r
.43325 .57298 .43889 .57851 .4486 .57567 .44298 .57018 Mtetra
.653 .749 .92 r
.44298 .57018 .4486 .57567 .45835 .57275 .45275 .56726 Mtetra
.656 .751 .92 r
.45275 .56726 .45835 .57275 .46814 .56976 .46256 .56428 Mtetra
.657 .753 .92 r
.46256 .56428 .46814 .56976 .47796 .56673 .47241 .56124 Mtetra
.658 .753 .92 r
.47241 .56124 .47796 .56673 .48782 .56367 .48229 .55817 Mtetra
.659 .754 .92 r
.48229 .55817 .48782 .56367 .49771 .5606 .4922 .55508 Mtetra
.4922 .55508 .49771 .5606 .50764 .55751 .50216 .55197 Mtetra
.50216 .55197 .50764 .55751 .5176 .55442 .51214 .54886 Mtetra
.659 .753 .92 r
.51214 .54886 .5176 .55442 .5276 .55133 .52217 .54574 Mtetra
.658 .753 .92 r
.52217 .54574 .5276 .55133 .53763 .54823 .53223 .54262 Mtetra
.53223 .54262 .53763 .54823 .54771 .54512 .54232 .53949 Mtetra
.54232 .53949 .54771 .54512 .55781 .54201 .55245 .53636 Mtetra
.55245 .53636 .55781 .54201 .56796 .53889 .56262 .53321 Mtetra
.56262 .53321 .56796 .53889 .57814 .53576 .57283 .53006 Mtetra
.57283 .53006 .57814 .53576 .58836 .53262 .58308 .5269 Mtetra
.657 .753 .92 r
.58308 .5269 .58836 .53262 .59862 .52948 .59336 .52373 Mtetra
.59336 .52373 .59862 .52948 .60891 .52632 .60368 .52055 Mtetra
.60368 .52055 .60891 .52632 .61925 .52315 .61404 .51736 Mtetra
.657 .752 .92 r
.61404 .51736 .61925 .52315 .62962 .51997 .62443 .51416 Mtetra
.62443 .51416 .62962 .51997 .64002 .51678 .63487 .51095 Mtetra
.63487 .51095 .64002 .51678 .65047 .51358 .64534 .50772 Mtetra
.64534 .50772 .65047 .51358 .66096 .51037 .65586 .50449 Mtetra
.65586 .50449 .66096 .51037 .67148 .50715 .66641 .50124 Mtetra
.66641 .50124 .67148 .50715 .68205 .50391 .677 .49799 Mtetra
.677 .49799 .68205 .50391 .69265 .50067 .68763 .49472 Mtetra
.68763 .49472 .69265 .50067 .7033 .49741 .6983 .49144 Mtetra
.6983 .49144 .7033 .49741 .71398 .49415 .70901 .48815 Mtetra
.70901 .48815 .71398 .49415 .7247 .49087 .71977 .48485 Mtetra
.71977 .48485 .7247 .49087 .73547 .48757 .73056 .48154 Mtetra
.73056 .48154 .73547 .48757 .74627 .48427 .74139 .47821 Mtetra
.74139 .47821 .74627 .48427 .75712 .48096 .75227 .47487 Mtetra
.75227 .47487 .75712 .48096 .768 .47763 .76318 .47152 Mtetra
.76318 .47152 .768 .47763 .77893 .47429 .77414 .46816 Mtetra
.77414 .46816 .77893 .47429 .7899 .47094 .78514 .46478 Mtetra
.78514 .46478 .7899 .47094 .80091 .46758 .79618 .4614 Mtetra
.79618 .4614 .80091 .46758 .81196 .4642 .80726 .458 Mtetra
.80726 .458 .81196 .4642 .82306 .46081 .81839 .45458 Mtetra
.81839 .45458 .82306 .46081 .8342 .45741 .82956 .45116 Mtetra
.82956 .45116 .8342 .45741 .84538 .454 .84077 .44772 Mtetra
.84077 .44772 .84538 .454 .8566 .45057 .85202 .44427 Mtetra
.85202 .44427 .8566 .45057 .86787 .44713 .86332 .4408 Mtetra
.86332 .4408 .86787 .44713 .87918 .44368 .87466 .43733 Mtetra
.87466 .43733 .87918 .44368 .89053 .44021 .88605 .43384 Mtetra
.88605 .43384 .89053 .44021 .90193 .43673 .89748 .43033 Mtetra
.89748 .43033 .90193 .43673 .91337 .43324 .90895 .42681 Mtetra
.084 .123 .604 r
.29588 .5883 .30066 .61112 .30979 .61041 .30388 .60455 Mtetra
.61 .715 .919 r
.30388 .60455 .30979 .61041 .31904 .60833 .31313 .60275 Mtetra
.626 .731 .922 r
.31313 .60275 .31904 .60833 .32833 .60626 .32244 .60057 Mtetra
.605 .721 .927 r
.32244 .60057 .32833 .60626 .33755 .60597 .33176 .59883 Mtetra
.93 .699 .568 r
.33176 .59883 .33755 .60597 .34731 .59641 .34702 .48742 Mtetra
0 0 .355 r
.34702 .48742 .34731 .59641 .35661 .59596 .3508 .58998 Mtetra
.613 .715 .918 r
.3508 .58998 .35661 .59596 .36604 .5937 .36023 .5881 Mtetra
.636 .737 .921 r
.36023 .5881 .36604 .5937 .37552 .5912 .36973 .58566 Mtetra
.64 .74 .921 r
.36973 .58566 .37552 .5912 .38504 .5887 .37926 .58312 Mtetra
.635 .738 .922 r
.37926 .58312 .38504 .5887 .39458 .58648 .38883 .58067 Mtetra
.6 .719 .928 r
.38883 .58067 .39458 .58648 .40404 .58773 .39841 .57899 Mtetra
.825 .705 .732 r
.39841 .57899 .40404 .58773 .41394 .57692 .40847 .56432 Mtetra
.351 .418 .79 r
.40847 .56432 .41394 .57692 .42356 .57553 .41788 .56962 Mtetra
.627 .726 .918 r
.41788 .56962 .42356 .57553 .43325 .57298 .42758 .56735 Mtetra
.646 .743 .92 r
.42758 .56735 .43325 .57298 .44298 .57018 .43733 .56462 Mtetra
.652 .748 .92 r
.43733 .56462 .44298 .57018 .45275 .56726 .44712 .56173 Mtetra
.655 .75 .92 r
.44712 .56173 .45275 .56726 .46256 .56428 .45695 .55875 Mtetra
.657 .752 .92 r
.45695 .55875 .46256 .56428 .47241 .56124 .46682 .55572 Mtetra
.658 .753 .92 r
.46682 .55572 .47241 .56124 .48229 .55817 .47672 .55263 Mtetra
.659 .754 .92 r
.47672 .55263 .48229 .55817 .4922 .55508 .48666 .54952 Mtetra
.48666 .54952 .4922 .55508 .50216 .55197 .49664 .5464 Mtetra
.49664 .5464 .50216 .55197 .51214 .54886 .50665 .54326 Mtetra
.50665 .54326 .51214 .54886 .52217 .54574 .5167 .54012 Mtetra
.658 .753 .92 r
.5167 .54012 .52217 .54574 .53223 .54262 .52678 .53697 Mtetra
.52678 .53697 .53223 .54262 .54232 .53949 .5369 .53382 Mtetra
.5369 .53382 .54232 .53949 .55245 .53636 .54706 .53066 Mtetra
.54706 .53066 .55245 .53636 .56262 .53321 .55725 .5275 Mtetra
.55725 .5275 .56262 .53321 .57283 .53006 .56749 .52432 Mtetra
.56749 .52432 .57283 .53006 .58308 .5269 .57776 .52114 Mtetra
.57776 .52114 .58308 .5269 .59336 .52373 .58806 .51794 Mtetra
.657 .753 .92 r
.58806 .51794 .59336 .52373 .60368 .52055 .59841 .51474 Mtetra
.59841 .51474 .60368 .52055 .61404 .51736 .60879 .51153 Mtetra
.60879 .51153 .61404 .51736 .62443 .51416 .61922 .50831 Mtetra
.657 .752 .92 r
.61922 .50831 .62443 .51416 .63487 .51095 .62968 .50507 Mtetra
.62968 .50507 .63487 .51095 .64534 .50772 .64018 .50183 Mtetra
.64018 .50183 .64534 .50772 .65586 .50449 .65072 .49857 Mtetra
.65072 .49857 .65586 .50449 .66641 .50124 .6613 .4953 Mtetra
.6613 .4953 .66641 .50124 .677 .49799 .67192 .49202 Mtetra
.67192 .49202 .677 .49799 .68763 .49472 .68258 .48873 Mtetra
.68258 .48873 .68763 .49472 .6983 .49144 .69327 .48543 Mtetra
.69327 .48543 .6983 .49144 .70901 .48815 .70401 .48212 Mtetra
.70401 .48212 .70901 .48815 .71977 .48485 .71479 .47879 Mtetra
.71479 .47879 .71977 .48485 .73056 .48154 .72562 .47545 Mtetra
.72562 .47545 .73056 .48154 .74139 .47821 .73648 .4721 Mtetra
.73648 .4721 .74139 .47821 .75227 .47487 .74738 .46874 Mtetra
.74738 .46874 .75227 .47487 .76318 .47152 .75833 .46537 Mtetra
.75833 .46537 .76318 .47152 .77414 .46816 .76931 .46198 Mtetra
.76931 .46198 .77414 .46816 .78514 .46478 .78034 .45858 Mtetra
.78034 .45858 .78514 .46478 .79618 .4614 .79141 .45517 Mtetra
.79141 .45517 .79618 .4614 .80726 .458 .80253 .45175 Mtetra
.80253 .45175 .80726 .458 .81839 .45458 .81368 .44831 Mtetra
.81368 .44831 .81839 .45458 .82956 .45116 .82488 .44486 Mtetra
.82488 .44486 .82956 .45116 .84077 .44772 .83612 .4414 Mtetra
.83612 .4414 .84077 .44772 .85202 .44427 .84741 .43792 Mtetra
.84741 .43792 .85202 .44427 .86332 .4408 .85874 .43443 Mtetra
.85874 .43443 .86332 .4408 .87466 .43733 .87011 .43093 Mtetra
.87011 .43093 .87466 .43733 .88605 .43384 .88153 .42741 Mtetra
.88153 .42741 .88605 .43384 .89748 .43033 .89299 .42388 Mtetra
.89299 .42388 .89748 .43033 .90895 .42681 .9045 .42034 Mtetra
.249 0 .237 r
.28822 .60747 .29588 .5883 .30388 .60455 .29799 .5978 Mtetra
.563 .669 .909 r
.29799 .5978 .30388 .60455 .31313 .60275 .30719 .59706 Mtetra
.623 .727 .921 r
.30719 .59706 .31313 .60275 .32244 .60057 .31651 .59494 Mtetra
.622 .73 .924 r
.31651 .59494 .32244 .60057 .33176 .59883 .32587 .59282 Mtetra
.527 .683 .937 r
.32587 .59282 .33176 .59883 .34702 .48742 .33517 .59249 Mtetra
.516 .286 .504 r
.33517 .59249 .34702 .48742 .3508 .58998 .34501 .58285 Mtetra
.552 .654 .903 r
.34501 .58285 .3508 .58998 .36023 .5881 .35438 .58236 Mtetra
.63 .73 .92 r
.35438 .58236 .36023 .5881 .36973 .58566 .36389 .58006 Mtetra
.639 .739 .921 r
.36389 .58006 .36973 .58566 .37926 .58312 .37345 .57752 Mtetra
.639 .74 .922 r
.37345 .57752 .37926 .58312 .38883 .58067 .38304 .57497 Mtetra
.626 .733 .924 r
.38304 .57497 .38883 .58067 .39841 .57899 .39266 .5727 Mtetra
.423 .628 .939 r
.39266 .5727 .39841 .57899 .40847 .56432 .40219 .57391 Mtetra
0 0 0 r
.40219 .57391 .40847 .56432 .41788 .56962 .41218 .56302 Mtetra
.592 .691 .911 r
.41218 .56302 .41788 .56962 .42758 .56735 .42187 .56159 Mtetra
.64 .738 .92 r
.42187 .56159 .42758 .56735 .43733 .56462 .43164 .55899 Mtetra
.649 .746 .92 r
.43164 .55899 .43733 .56462 .44712 .56173 .44145 .55614 Mtetra
.653 .749 .92 r
.44145 .55614 .44712 .56173 .45695 .55875 .45131 .55318 Mtetra
.656 .751 .92 r
.45131 .55318 .45695 .55875 .46682 .55572 .46119 .55014 Mtetra
.657 .753 .92 r
.46119 .55014 .46682 .55572 .47672 .55263 .47112 .54705 Mtetra
.658 .753 .92 r
.47112 .54705 .47672 .55263 .48666 .54952 .48108 .54393 Mtetra
.659 .754 .92 r
.48108 .54393 .48666 .54952 .49664 .5464 .49108 .54078 Mtetra
.49108 .54078 .49664 .5464 .50665 .54326 .50112 .53762 Mtetra
.50112 .53762 .50665 .54326 .5167 .54012 .51119 .53446 Mtetra
.659 .753 .92 r
.51119 .53446 .5167 .54012 .52678 .53697 .5213 .53129 Mtetra
.658 .753 .92 r
.5213 .53129 .52678 .53697 .5369 .53382 .53144 .52811 Mtetra
.53144 .52811 .5369 .53382 .54706 .53066 .54163 .52493 Mtetra
.54163 .52493 .54706 .53066 .55725 .5275 .55185 .52174 Mtetra
.55185 .52174 .55725 .5275 .56749 .52432 .5621 .51854 Mtetra
.5621 .51854 .56749 .52432 .57776 .52114 .5724 .51534 Mtetra
.5724 .51534 .57776 .52114 .58806 .51794 .58273 .51212 Mtetra
.657 .753 .92 r
.58273 .51212 .58806 .51794 .59841 .51474 .5931 .50889 Mtetra
.5931 .50889 .59841 .51474 .60879 .51153 .60351 .50566 Mtetra
.60351 .50566 .60879 .51153 .61922 .50831 .61396 .50241 Mtetra
.657 .752 .92 r
.61396 .50241 .61922 .50831 .62968 .50507 .62445 .49916 Mtetra
.62445 .49916 .62968 .50507 .64018 .50183 .63498 .49589 Mtetra
.63498 .49589 .64018 .50183 .65072 .49857 .64554 .49261 Mtetra
.64554 .49261 .65072 .49857 .6613 .4953 .65615 .48932 Mtetra
.65615 .48932 .6613 .4953 .67192 .49202 .6668 .48602 Mtetra
.6668 .48602 .67192 .49202 .68258 .48873 .67748 .4827 Mtetra
.67748 .4827 .68258 .48873 .69327 .48543 .68821 .47938 Mtetra
.68821 .47938 .69327 .48543 .70401 .48212 .69898 .47604 Mtetra
.69898 .47604 .70401 .48212 .71479 .47879 .70979 .47269 Mtetra
.70979 .47269 .71479 .47879 .72562 .47545 .72064 .46933 Mtetra
.72064 .46933 .72562 .47545 .73648 .4721 .73153 .46595 Mtetra
.73153 .46595 .73648 .4721 .74738 .46874 .74246 .46257 Mtetra
.74246 .46257 .74738 .46874 .75833 .46537 .75343 .45917 Mtetra
.75343 .45917 .75833 .46537 .76931 .46198 .76445 .45576 Mtetra
.76445 .45576 .76931 .46198 .78034 .45858 .77551 .45234 Mtetra
.77551 .45234 .78034 .45858 .79141 .45517 .78661 .4489 Mtetra
.78661 .4489 .79141 .45517 .80253 .45175 .79775 .44545 Mtetra
.79775 .44545 .80253 .45175 .81368 .44831 .80894 .44199 Mtetra
.80894 .44199 .81368 .44831 .82488 .44486 .82017 .43852 Mtetra
.82017 .43852 .82488 .44486 .83612 .4414 .83145 .43503 Mtetra
.83145 .43503 .83612 .4414 .84741 .43792 .84276 .43153 Mtetra
.84276 .43153 .84741 .43792 .85874 .43443 .85413 .42801 Mtetra
.85413 .42801 .85874 .43443 .87011 .43093 .86553 .42448 Mtetra
.86553 .42448 .87011 .43093 .88153 .42741 .87698 .42094 Mtetra
.87698 .42094 .88153 .42741 .89299 .42388 .88848 .41739 Mtetra
.88848 .41739 .89299 .42388 .9045 .42034 .90002 .41382 Mtetra
.873 .713 .68 r
.28234 .59979 .28822 .60747 .29799 .5978 .29317 .57482 Mtetra
.08 .119 .602 r
.29317 .57482 .29799 .5978 .30719 .59706 .30122 .59111 Mtetra
.61 .715 .919 r
.30122 .59111 .30719 .59706 .31651 .59494 .31054 .58926 Mtetra
.626 .731 .922 r
.31054 .58926 .31651 .59494 .32587 .59282 .31993 .58704 Mtetra
.605 .721 .927 r
.31993 .58704 .32587 .59282 .33517 .59249 .32932 .58525 Mtetra
.931 .699 .566 r
.32932 .58525 .33517 .59249 .34501 .58285 .34478 .47335 Mtetra
0 0 .35 r
.34478 .47335 .34501 .58285 .35438 .58236 .34851 .5763 Mtetra
.613 .715 .918 r
.34851 .5763 .35438 .58236 .36389 .58006 .35802 .57437 Mtetra
.636 .737 .921 r
.35802 .57437 .36389 .58006 .37345 .57752 .36759 .57188 Mtetra
.64 .74 .921 r
.36759 .57188 .37345 .57752 .38304 .57497 .3772 .56929 Mtetra
.635 .738 .922 r
.3772 .56929 .38304 .57497 .39266 .5727 .38685 .56679 Mtetra
.6 .719 .928 r
.38685 .56679 .39266 .5727 .40219 .57391 .3965 .56507 Mtetra
.826 .705 .732 r
.3965 .56507 .40219 .57391 .41218 .56302 .40666 .5503 Mtetra
.35 .417 .79 r
.40666 .5503 .41218 .56302 .42187 .56159 .41613 .55559 Mtetra
.627 .726 .918 r
.41613 .55559 .42187 .56159 .43164 .55899 .42591 .55327 Mtetra
.646 .743 .92 r
.42591 .55327 .43164 .55899 .44145 .55614 .43575 .55049 Mtetra
.652 .748 .92 r
.43575 .55049 .44145 .55614 .45131 .55318 .44562 .54755 Mtetra
.655 .75 .92 r
.44562 .54755 .45131 .55318 .46119 .55014 .45553 .54452 Mtetra
.657 .752 .92 r
.45553 .54452 .46119 .55014 .47112 .54705 .46548 .54143 Mtetra
.658 .753 .92 r
.46548 .54143 .47112 .54705 .48108 .54393 .47547 .53829 Mtetra
.659 .754 .92 r
.47547 .53829 .48108 .54393 .49108 .54078 .48549 .53513 Mtetra
.48549 .53513 .49108 .54078 .50112 .53762 .49555 .53195 Mtetra
.49555 .53195 .50112 .53762 .51119 .53446 .50565 .52876 Mtetra
.50565 .52876 .51119 .53446 .5213 .53129 .51578 .52556 Mtetra
.658 .753 .92 r
.51578 .52556 .5213 .53129 .53144 .52811 .52595 .52236 Mtetra
.52595 .52236 .53144 .52811 .54163 .52493 .53616 .51916 Mtetra
.53616 .51916 .54163 .52493 .55185 .52174 .5464 .51595 Mtetra
.5464 .51595 .55185 .52174 .5621 .51854 .55668 .51272 Mtetra
.55668 .51272 .5621 .51854 .5724 .51534 .567 .5095 Mtetra
.567 .5095 .5724 .51534 .58273 .51212 .57736 .50626 Mtetra
.57736 .50626 .58273 .51212 .5931 .50889 .58776 .50301 Mtetra
.657 .753 .92 r
.58776 .50301 .5931 .50889 .60351 .50566 .5982 .49975 Mtetra
.5982 .49975 .60351 .50566 .61396 .50241 .60867 .49648 Mtetra
.60867 .49648 .61396 .50241 .62445 .49916 .61919 .4932 Mtetra
.657 .752 .92 r
.61919 .4932 .62445 .49916 .63498 .49589 .62974 .48991 Mtetra
.62974 .48991 .63498 .49589 .64554 .49261 .64033 .48661 Mtetra
.64033 .48661 .64554 .49261 .65615 .48932 .65097 .48329 Mtetra
.65097 .48329 .65615 .48932 .6668 .48602 .66164 .47997 Mtetra
.66164 .47997 .6668 .48602 .67748 .4827 .67236 .47663 Mtetra
.67236 .47663 .67748 .4827 .68821 .47938 .68311 .47328 Mtetra
.68311 .47328 .68821 .47938 .69898 .47604 .69391 .46992 Mtetra
.69391 .46992 .69898 .47604 .70979 .47269 .70474 .46655 Mtetra
.70474 .46655 .70979 .47269 .72064 .46933 .71562 .46316 Mtetra
.71562 .46316 .72064 .46933 .73153 .46595 .72654 .45976 Mtetra
.72654 .45976 .73153 .46595 .74246 .46257 .7375 .45635 Mtetra
.7375 .45635 .74246 .46257 .75343 .45917 .74851 .45293 Mtetra
.74851 .45293 .75343 .45917 .76445 .45576 .75955 .4495 Mtetra
.75955 .4495 .76445 .45576 .77551 .45234 .77064 .44605 Mtetra
.77064 .44605 .77551 .45234 .78661 .4489 .78178 .44259 Mtetra
.78178 .44259 .78661 .4489 .79775 .44545 .79295 .43911 Mtetra
.79295 .43911 .79775 .44545 .80894 .44199 .80417 .43563 Mtetra
.80417 .43563 .80894 .44199 .82017 .43852 .81543 .43213 Mtetra
.81543 .43213 .82017 .43852 .83145 .43503 .82673 .42861 Mtetra
.82673 .42861 .83145 .43503 .84276 .43153 .83808 .42509 Mtetra
.83808 .42509 .84276 .43153 .85413 .42801 .84948 .42155 Mtetra
.84948 .42155 .85413 .42801 .86553 .42448 .86092 .41799 Mtetra
.86092 .41799 .86553 .42448 .87698 .42094 .8724 .41443 Mtetra
.8724 .41443 .87698 .42094 .88848 .41739 .88393 .41085 Mtetra
.88393 .41085 .88848 .41739 .90002 .41382 .8955 .40725 Mtetra
.479 .659 .94 r
.27631 .59366 .28234 .59979 .29317 .57482 .28543 .59401 Mtetra
.24 0 .228 r
.28543 .59401 .29317 .57482 .30122 .59111 .29528 .58426 Mtetra
.563 .669 .909 r
.29528 .58426 .30122 .59111 .31054 .58926 .30454 .58348 Mtetra
.623 .727 .921 r
.30454 .58348 .31054 .58926 .31993 .58704 .31394 .58131 Mtetra
.622 .73 .924 r
.31394 .58131 .31993 .58704 .32932 .58525 .32338 .57915 Mtetra
.527 .683 .937 r
.32338 .57915 .32932 .58525 .34478 .47335 .33275 .57878 Mtetra
.513 .281 .501 r
.33275 .57878 .34478 .47335 .34851 .5763 .34267 .56907 Mtetra
.552 .654 .903 r
.34267 .56907 .34851 .5763 .35802 .57437 .35211 .56854 Mtetra
.63 .73 .92 r
.35211 .56854 .35802 .57437 .36759 .57188 .3617 .56619 Mtetra
.639 .739 .921 r
.3617 .56619 .36759 .57188 .3772 .56929 .37133 .5636 Mtetra
.639 .74 .922 r
.37133 .5636 .3772 .56929 .38685 .56679 .381 .561 Mtetra
.626 .733 .924 r
.381 .561 .38685 .56679 .3965 .56507 .3907 .55868 Mtetra
.423 .628 .939 r
.3907 .55868 .3965 .56507 .40666 .5503 .4003 .55987 Mtetra
0 0 0 r
.4003 .55987 .40666 .5503 .41613 .55559 .41038 .54889 Mtetra
.592 .691 .911 r
.41038 .54889 .41613 .55559 .42591 .55327 .42015 .54741 Mtetra
.64 .738 .92 r
.42015 .54741 .42591 .55327 .43575 .55049 .43 .54476 Mtetra
.649 .746 .92 r
.43 .54476 .43575 .55049 .44562 .54755 .4399 .54186 Mtetra
.653 .749 .92 r
.4399 .54186 .44562 .54755 .45553 .54452 .44983 .53884 Mtetra
.656 .751 .92 r
.44983 .53884 .45553 .54452 .46548 .54143 .4598 .53576 Mtetra
.657 .753 .92 r
.4598 .53576 .46548 .54143 .47547 .53829 .46981 .53262 Mtetra
.658 .753 .92 r
.46981 .53262 .47547 .53829 .48549 .53513 .47986 .52944 Mtetra
.659 .754 .92 r
.47986 .52944 .48549 .53513 .49555 .53195 .48994 .52624 Mtetra
.48994 .52624 .49555 .53195 .50565 .52876 .50006 .52302 Mtetra
.50006 .52302 .50565 .52876 .51578 .52556 .51022 .5198 Mtetra
.659 .753 .92 r
.51022 .5198 .51578 .52556 .52595 .52236 .52041 .51658 Mtetra
.658 .753 .92 r
.52041 .51658 .52595 .52236 .53616 .51916 .53065 .51335 Mtetra
.53065 .51335 .53616 .51916 .5464 .51595 .54092 .51011 Mtetra
.54092 .51011 .5464 .51595 .55668 .51272 .55123 .50687 Mtetra
.55123 .50687 .55668 .51272 .567 .5095 .56157 .50361 Mtetra
.56157 .50361 .567 .5095 .57736 .50626 .57196 .50035 Mtetra
.57196 .50035 .57736 .50626 .58776 .50301 .58238 .49708 Mtetra
.657 .753 .92 r
.58238 .49708 .58776 .50301 .5982 .49975 .59284 .4938 Mtetra
.59284 .4938 .5982 .49975 .60867 .49648 .60334 .4905 Mtetra
.60334 .4905 .60867 .49648 .61919 .4932 .61389 .4872 Mtetra
.657 .752 .92 r
.61389 .4872 .61919 .4932 .62974 .48991 .62447 .48389 Mtetra
.62447 .48389 .62974 .48991 .64033 .48661 .63509 .48056 Mtetra
.63509 .48056 .64033 .48661 .65097 .48329 .64575 .47722 Mtetra
.64575 .47722 .65097 .48329 .66164 .47997 .65645 .47387 Mtetra
.65645 .47387 .66164 .47997 .67236 .47663 .66719 .47051 Mtetra
.66719 .47051 .67236 .47663 .68311 .47328 .67798 .46714 Mtetra
.67798 .46714 .68311 .47328 .69391 .46992 .6888 .46376 Mtetra
.6888 .46376 .69391 .46992 .70474 .46655 .69967 .46036 Mtetra
.69967 .46036 .70474 .46655 .71562 .46316 .71057 .45695 Mtetra
.71057 .45695 .71562 .46316 .72654 .45976 .72152 .45353 Mtetra
.72152 .45353 .72654 .45976 .7375 .45635 .73251 .45009 Mtetra
.73251 .45009 .7375 .45635 .74851 .45293 .74355 .44665 Mtetra
.74355 .44665 .74851 .45293 .75955 .4495 .75462 .44319 Mtetra
.75462 .44319 .75955 .4495 .77064 .44605 .76574 .43971 Mtetra
.76574 .43971 .77064 .44605 .78178 .44259 .77691 .43623 Mtetra
.77691 .43623 .78178 .44259 .79295 .43911 .78811 .43273 Mtetra
.78811 .43273 .79295 .43911 .80417 .43563 .79936 .42922 Mtetra
.79936 .42922 .80417 .43563 .81543 .43213 .81065 .42569 Mtetra
.81065 .42569 .81543 .43213 .82673 .42861 .82199 .42215 Mtetra
.82199 .42215 .82673 .42861 .83808 .42509 .83337 .4186 Mtetra
.83337 .4186 .83808 .42509 .84948 .42155 .8448 .41504 Mtetra
.8448 .41504 .84948 .42155 .86092 .41799 .85627 .41146 Mtetra
.85627 .41146 .86092 .41799 .8724 .41443 .86778 .40786 Mtetra
.86778 .40786 .8724 .41443 .88393 .41085 .87935 .40426 Mtetra
.87935 .40426 .88393 .41085 .8955 .40725 .89095 .40064 Mtetra
.594 .715 .928 r
.27022 .58779 .27631 .59366 .28543 .59401 .27949 .58623 Mtetra
.874 .714 .68 r
.27949 .58623 .28543 .59401 .29528 .58426 .29043 .56112 Mtetra
.075 .116 .601 r
.29043 .56112 .29528 .58426 .30454 .58348 .29852 .57744 Mtetra
.61 .715 .919 r
.29852 .57744 .30454 .58348 .31394 .58131 .30792 .57555 Mtetra
.626 .731 .922 r
.30792 .57555 .31394 .58131 .32338 .57915 .31737 .57328 Mtetra
.605 .721 .927 r
.31737 .57328 .32338 .57915 .33275 .57878 .32684 .57145 Mtetra
.932 .7 .565 r
.32684 .57145 .33275 .57878 .34267 .56907 .3425 .45905 Mtetra
0 0 .345 r
.3425 .45905 .34267 .56907 .35211 .56854 .34619 .56238 Mtetra
.613 .715 .918 r
.34619 .56238 .35211 .56854 .3617 .56619 .35577 .56041 Mtetra
.636 .737 .921 r
.35577 .56041 .3617 .56619 .37133 .5636 .36542 .55787 Mtetra
.64 .74 .921 r
.36542 .55787 .37133 .5636 .381 .561 .37511 .55523 Mtetra
.635 .738 .922 r
.37511 .55523 .381 .561 .3907 .55868 .38484 .55268 Mtetra
.6 .719 .928 r
.38484 .55268 .3907 .55868 .4003 .55987 .39457 .55092 Mtetra
.826 .706 .732 r
.39457 .55092 .4003 .55987 .41038 .54889 .40481 .53604 Mtetra
.348 .416 .79 r
.40481 .53604 .41038 .54889 .42015 .54741 .41436 .54131 Mtetra
.627 .726 .918 r
.41436 .54131 .42015 .54741 .43 .54476 .42422 .53894 Mtetra
.646 .743 .92 r
.42422 .53894 .43 .54476 .4399 .54186 .43414 .53611 Mtetra
.652 .748 .92 r
.43414 .53611 .4399 .54186 .44983 .53884 .44409 .53312 Mtetra
.655 .75 .92 r
.44409 .53312 .44983 .53884 .4598 .53576 .45409 .53004 Mtetra
.657 .752 .92 r
.45409 .53004 .4598 .53576 .46981 .53262 .46412 .52689 Mtetra
.658 .753 .92 r
.46412 .52689 .46981 .53262 .47986 .52944 .47419 .5237 Mtetra
.659 .754 .92 r
.47419 .5237 .47986 .52944 .48994 .52624 .4843 .52049 Mtetra
.4843 .52049 .48994 .52624 .50006 .52302 .49444 .51725 Mtetra
.49444 .51725 .50006 .52302 .51022 .5198 .50462 .51401 Mtetra
.50462 .51401 .51022 .5198 .52041 .51658 .51484 .51076 Mtetra
.658 .753 .92 r
.51484 .51076 .52041 .51658 .53065 .51335 .5251 .5075 Mtetra
.5251 .5075 .53065 .51335 .54092 .51011 .5354 .50424 Mtetra
.5354 .50424 .54092 .51011 .55123 .50687 .54573 .50097 Mtetra
.54573 .50097 .55123 .50687 .56157 .50361 .5561 .49769 Mtetra
.5561 .49769 .56157 .50361 .57196 .50035 .56651 .49441 Mtetra
.56651 .49441 .57196 .50035 .58238 .49708 .57696 .49111 Mtetra
.57696 .49111 .58238 .49708 .59284 .4938 .58745 .48781 Mtetra
.657 .753 .92 r
.58745 .48781 .59284 .4938 .60334 .4905 .59798 .48449 Mtetra
.59798 .48449 .60334 .4905 .61389 .4872 .60855 .48116 Mtetra
.60855 .48116 .61389 .4872 .62447 .48389 .61916 .47782 Mtetra
.657 .752 .92 r
.61916 .47782 .62447 .48389 .63509 .48056 .6298 .47447 Mtetra
.6298 .47447 .63509 .48056 .64575 .47722 .64049 .47111 Mtetra
.64049 .47111 .64575 .47722 .65645 .47387 .65122 .46774 Mtetra
.65122 .46774 .65645 .47387 .66719 .47051 .66199 .46435 Mtetra
.66199 .46435 .66719 .47051 .67798 .46714 .67281 .46096 Mtetra
.67281 .46096 .67798 .46714 .6888 .46376 .68366 .45755 Mtetra
.68366 .45755 .6888 .46376 .69967 .46036 .69455 .45413 Mtetra
.69455 .45413 .69967 .46036 .71057 .45695 .70549 .45069 Mtetra
.70549 .45069 .71057 .45695 .72152 .45353 .71647 .44725 Mtetra
.71647 .44725 .72152 .45353 .73251 .45009 .72749 .44379 Mtetra
.72749 .44379 .73251 .45009 .74355 .44665 .73855 .44032 Mtetra
.73855 .44032 .74355 .44665 .75462 .44319 .74966 .43683 Mtetra
.74966 .43683 .75462 .44319 .76574 .43971 .76081 .43333 Mtetra
.76081 .43333 .76574 .43971 .77691 .43623 .772 .42982 Mtetra
.772 .42982 .77691 .43623 .78811 .43273 .78324 .4263 Mtetra
.78324 .4263 .78811 .43273 .79936 .42922 .79452 .42276 Mtetra
.79452 .42276 .79936 .42922 .81065 .42569 .80584 .41921 Mtetra
.80584 .41921 .81065 .42569 .82199 .42215 .81721 .41565 Mtetra
.81721 .41565 .82199 .42215 .83337 .4186 .82862 .41207 Mtetra
.82862 .41207 .83337 .4186 .8448 .41504 .84008 .40848 Mtetra
.84008 .40848 .8448 .41504 .85627 .41146 .85158 .40487 Mtetra
.85158 .40487 .85627 .41146 .86778 .40786 .86313 .40125 Mtetra
.86313 .40125 .86778 .40786 .87935 .40426 .87473 .39762 Mtetra
.87473 .39762 .87935 .40426 .89095 .40064 .88637 .39397 Mtetra
.612 .723 .924 r
.26408 .58195 .27022 .58779 .27949 .58623 .2734 .58 Mtetra
.48 .659 .94 r
.2734 .58 .27949 .58623 .29043 .56112 .28259 .58032 Mtetra
.23 0 .219 r
.28259 .58032 .29043 .56112 .29852 .57744 .29252 .57049 Mtetra
.563 .669 .909 r
.29252 .57049 .29852 .57744 .30792 .57555 .30186 .56967 Mtetra
.623 .727 .921 r
.30186 .56967 .30792 .57555 .31737 .57328 .31133 .56746 Mtetra
.622 .73 .924 r
.31133 .56746 .31737 .57328 .32684 .57145 .32084 .56525 Mtetra
.527 .683 .937 r
.32084 .56525 .32684 .57145 .3425 .45905 .33028 .56484 Mtetra
.51 .277 .497 r
.33028 .56484 .3425 .45905 .34619 .56238 .34029 .55505 Mtetra
.552 .654 .903 r
.34029 .55505 .34619 .56238 .35577 .56041 .34981 .55448 Mtetra
.63 .73 .92 r
.34981 .55448 .35577 .56041 .36542 .55787 .35947 .55208 Mtetra
.639 .739 .921 r
.35947 .55208 .36542 .55787 .37511 .55523 .36918 .54944 Mtetra
.639 .74 .922 r
.36918 .54944 .37511 .55523 .38484 .55268 .37893 .54679 Mtetra
.626 .733 .924 r
.37893 .54679 .38484 .55268 .39457 .55092 .3887 .54442 Mtetra
.424 .628 .939 r
.3887 .54442 .39457 .55092 .40481 .53604 .39839 .54557 Mtetra
0 0 0 r
.39839 .54557 .40481 .53604 .41436 .54131 .40855 .53451 Mtetra
.591 .691 .911 r
.40855 .53451 .41436 .54131 .42422 .53894 .4184 .53299 Mtetra
.64 .738 .92 r
.4184 .53299 .42422 .53894 .43414 .53611 .42834 .53029 Mtetra
.649 .746 .92 r
.42834 .53029 .43414 .53611 .44409 .53312 .43831 .52733 Mtetra
.653 .749 .92 r
.43831 .52733 .44409 .53312 .45409 .53004 .44833 .52426 Mtetra
.656 .751 .92 r
.44833 .52426 .45409 .53004 .46412 .52689 .45839 .52112 Mtetra
.657 .753 .92 r
.45839 .52112 .46412 .52689 .47419 .5237 .46848 .51793 Mtetra
.658 .753 .92 r
.46848 .51793 .47419 .5237 .4843 .52049 .47861 .5147 Mtetra
.659 .754 .92 r
.47861 .5147 .4843 .52049 .49444 .51725 .48878 .51144 Mtetra
.48878 .51144 .49444 .51725 .50462 .51401 .49899 .50817 Mtetra
.49899 .50817 .50462 .51401 .51484 .51076 .50923 .50489 Mtetra
.659 .753 .92 r
.50923 .50489 .51484 .51076 .5251 .5075 .51952 .50161 Mtetra
.658 .753 .92 r
.51952 .50161 .5251 .5075 .5354 .50424 .52984 .49833 Mtetra
.52984 .49833 .5354 .50424 .54573 .50097 .5402 .49503 Mtetra
.5402 .49503 .54573 .50097 .5561 .49769 .55059 .49173 Mtetra
.55059 .49173 .5561 .49769 .56651 .49441 .56103 .48842 Mtetra
.56103 .48842 .56651 .49441 .57696 .49111 .57151 .4851 Mtetra
.57151 .4851 .57696 .49111 .58745 .48781 .58202 .48177 Mtetra
.657 .753 .92 r
.58202 .48177 .58745 .48781 .59798 .48449 .59258 .47843 Mtetra
.59258 .47843 .59798 .48449 .60855 .48116 .60317 .47508 Mtetra
.60317 .47508 .60855 .48116 .61916 .47782 .61381 .47172 Mtetra
.657 .752 .92 r
.61381 .47172 .61916 .47782 .6298 .47447 .62448 .46834 Mtetra
.62448 .46834 .6298 .47447 .64049 .47111 .6352 .46496 Mtetra
.6352 .46496 .64049 .47111 .65122 .46774 .64596 .46156 Mtetra
.64596 .46156 .65122 .46774 .66199 .46435 .65676 .45815 Mtetra
.65676 .45815 .66199 .46435 .67281 .46096 .6676 .45473 Mtetra
.6676 .45473 .67281 .46096 .68366 .45755 .67848 .4513 Mtetra
.67848 .4513 .68366 .45755 .69455 .45413 .6894 .44785 Mtetra
.6894 .44785 .69455 .45413 .70549 .45069 .70037 .44439 Mtetra
.70037 .44439 .70549 .45069 .71647 .44725 .71138 .44092 Mtetra
.71138 .44092 .71647 .44725 .72749 .44379 .72243 .43744 Mtetra
.72243 .43744 .72749 .44379 .73855 .44032 .73352 .43394 Mtetra
.73352 .43394 .73855 .44032 .74966 .43683 .74466 .43043 Mtetra
.74466 .43043 .74966 .43683 .76081 .43333 .75584 .42691 Mtetra
.75584 .42691 .76081 .43333 .772 .42982 .76706 .42337 Mtetra
.76706 .42337 .772 .42982 .78324 .4263 .77833 .41982 Mtetra
.77833 .41982 .78324 .4263 .79452 .42276 .78964 .41626 Mtetra
.78964 .41626 .79452 .42276 .80584 .41921 .80099 .41268 Mtetra
.80099 .41268 .80584 .41921 .81721 .41565 .81239 .40909 Mtetra
.81239 .40909 .81721 .41565 .82862 .41207 .82384 .40549 Mtetra
.82384 .40549 .82862 .41207 .84008 .40848 .83533 .40187 Mtetra
.83533 .40187 .84008 .40848 .85158 .40487 .84687 .39824 Mtetra
.84687 .39824 .85158 .40487 .86313 .40125 .85845 .39459 Mtetra
.85845 .39459 .86313 .40125 .87473 .39762 .87008 .39093 Mtetra
.87008 .39093 .87473 .39762 .88637 .39397 .88175 .38726 Mtetra
.613 .721 .922 r
.25792 .57602 .26408 .58195 .2734 .58 .26725 .57404 Mtetra
.594 .715 .928 r
.26725 .57404 .2734 .58 .28259 .58032 .27659 .57244 Mtetra
.875 .715 .68 r
.27659 .57244 .28259 .58032 .29252 .57049 .28763 .54718 Mtetra
.071 .112 .599 r
.28763 .54718 .29252 .57049 .30186 .56967 .29577 .56353 Mtetra
.61 .715 .92 r
.29577 .56353 .30186 .56967 .31133 .56746 .30524 .5616 Mtetra
.626 .731 .922 r
.30524 .5616 .31133 .56746 .32084 .56525 .31478 .55928 Mtetra
.605 .721 .927 r
.31478 .55928 .32084 .56525 .33028 .56484 .32432 .55741 Mtetra
.933 .7 .563 r
.32432 .55741 .33028 .56484 .34029 .55505 .34018 .44451 Mtetra
0 0 .34 r
.34018 .44451 .34029 .55505 .34981 .55448 .34382 .54822 Mtetra
.613 .715 .918 r
.34382 .54822 .34981 .55448 .35947 .55208 .35348 .5462 Mtetra
.636 .737 .921 r
.35348 .5462 .35947 .55208 .36918 .54944 .36321 .54361 Mtetra
.64 .74 .921 r
.36321 .54361 .36918 .54944 .37893 .54679 .37298 .54092 Mtetra
.636 .738 .922 r
.37298 .54092 .37893 .54679 .3887 .54442 .38279 .53833 Mtetra
.6 .719 .928 r
.38279 .53833 .3887 .54442 .39839 .54557 .3926 .53651 Mtetra
.827 .707 .732 r
.3926 .53651 .39839 .54557 .40855 .53451 .40293 .52153 Mtetra
.347 .416 .79 r
.40293 .52153 .40855 .53451 .4184 .53299 .41256 .52679 Mtetra
.627 .726 .918 r
.41256 .52679 .4184 .53299 .42834 .53029 .4225 .52437 Mtetra
.646 .743 .92 r
.4225 .52437 .42834 .53029 .43831 .52733 .4325 .52148 Mtetra
.652 .748 .92 r
.4325 .52148 .43831 .52733 .44833 .52426 .44254 .51844 Mtetra
.655 .75 .92 r
.44254 .51844 .44833 .52426 .45839 .52112 .45262 .5153 Mtetra
.657 .752 .92 r
.45262 .5153 .45839 .52112 .46848 .51793 .46273 .5121 Mtetra
.658 .753 .92 r
.46273 .5121 .46848 .51793 .47861 .5147 .47289 .50886 Mtetra
.659 .754 .92 r
.47289 .50886 .47861 .5147 .48878 .51144 .48308 .50559 Mtetra
.48308 .50559 .48878 .51144 .49899 .50817 .49332 .5023 Mtetra
.49332 .5023 .49899 .50817 .50923 .50489 .50358 .49899 Mtetra
.50358 .49899 .50923 .50489 .51952 .50161 .51389 .49569 Mtetra
.658 .753 .92 r
.51389 .49569 .51952 .50161 .52984 .49833 .52424 .49237 Mtetra
.52424 .49237 .52984 .49833 .5402 .49503 .53462 .48906 Mtetra
.53462 .48906 .5402 .49503 .55059 .49173 .54505 .48573 Mtetra
.54505 .48573 .55059 .49173 .56103 .48842 .55551 .48239 Mtetra
.55551 .48239 .56103 .48842 .57151 .4851 .56601 .47905 Mtetra
.56601 .47905 .57151 .4851 .58202 .48177 .57656 .4757 Mtetra
.57656 .4757 .58202 .48177 .59258 .47843 .58714 .47233 Mtetra
.657 .753 .92 r
.58714 .47233 .59258 .47843 .60317 .47508 .59776 .46896 Mtetra
.59776 .46896 .60317 .47508 .61381 .47172 .60842 .46557 Mtetra
.60842 .46557 .61381 .47172 .62448 .46834 .61913 .46217 Mtetra
.657 .752 .92 r
.61913 .46217 .62448 .46834 .6352 .46496 .62987 .45876 Mtetra
.62987 .45876 .6352 .46496 .64596 .46156 .64066 .45534 Mtetra
.64066 .45534 .64596 .46156 .65676 .45815 .65148 .45191 Mtetra
.65148 .45191 .65676 .45815 .6676 .45473 .66235 .44846 Mtetra
.66235 .44846 .6676 .45473 .67848 .4513 .67326 .445 Mtetra
.67326 .445 .67848 .4513 .6894 .44785 .68421 .44153 Mtetra
.68421 .44153 .6894 .44785 .70037 .44439 .69521 .43805 Mtetra
.69521 .43805 .70037 .44439 .71138 .44092 .70625 .43455 Mtetra
.70625 .43455 .71138 .44092 .72243 .43744 .71733 .43104 Mtetra
.71733 .43104 .72243 .43744 .73352 .43394 .72845 .42752 Mtetra
.72845 .42752 .73352 .43394 .74466 .43043 .73962 .42398 Mtetra
.73962 .42398 .74466 .43043 .75584 .42691 .75083 .42043 Mtetra
.75083 .42043 .75584 .42691 .76706 .42337 .76208 .41687 Mtetra
.76208 .41687 .76706 .42337 .77833 .41982 .77338 .4133 Mtetra
.77338 .4133 .77833 .41982 .78964 .41626 .78472 .40971 Mtetra
.78472 .40971 .78964 .41626 .80099 .41268 .79611 .4061 Mtetra
.79611 .4061 .80099 .41268 .81239 .40909 .80754 .40249 Mtetra
.80754 .40249 .81239 .40909 .82384 .40549 .81902 .39886 Mtetra
.81902 .39886 .82384 .40549 .83533 .40187 .83055 .39521 Mtetra
.83055 .39521 .83533 .40187 .84687 .39824 .84212 .39155 Mtetra
.84212 .39155 .84687 .39824 .85845 .39459 .85373 .38788 Mtetra
.85373 .38788 .85845 .39459 .87008 .39093 .86539 .38419 Mtetra
.86539 .38419 .87008 .39093 .88175 .38726 .8771 .38049 Mtetra
.597 .705 .919 r
.25174 .56974 .25792 .57602 .26725 .57404 .26105 .56811 Mtetra
.612 .723 .924 r
.26105 .56811 .26725 .57404 .27659 .57244 .27044 .56612 Mtetra
.48 .659 .94 r
.27044 .56612 .27659 .57244 .28763 .54718 .27969 .5664 Mtetra
.221 0 .209 r
.27969 .5664 .28763 .54718 .29577 .56353 .28971 .55649 Mtetra
.562 .669 .909 r
.28971 .55649 .29577 .56353 .30524 .5616 .29912 .55563 Mtetra
.623 .727 .921 r
.29912 .55563 .30524 .5616 .31478 .55928 .30867 .55337 Mtetra
.622 .73 .924 r
.30867 .55337 .31478 .55928 .32432 .55741 .31826 .55111 Mtetra
.527 .682 .937 r
.31826 .55111 .32432 .55741 .34018 .44451 .32777 .55066 Mtetra
.507 .273 .494 r
.32777 .55066 .34018 .44451 .34382 .54822 .33786 .54079 Mtetra
.552 .654 .903 r
.33786 .54079 .34382 .54822 .35348 .5462 .34746 .54018 Mtetra
.63 .73 .92 r
.34746 .54018 .35348 .5462 .36321 .54361 .3572 .53773 Mtetra
.639 .739 .921 r
.3572 .53773 .36321 .54361 .37298 .54092 .36699 .53504 Mtetra
.639 .74 .922 r
.36699 .53504 .37298 .54092 .38279 .53833 .37682 .53234 Mtetra
.626 .733 .924 r
.37682 .53234 .38279 .53833 .3926 .53651 .38668 .52992 Mtetra
.425 .629 .939 r
.38668 .52992 .3926 .53651 .40293 .52153 .39644 .53104 Mtetra
0 0 0 r
.39644 .53104 .40293 .52153 .41256 .52679 .40669 .51988 Mtetra
.591 .691 .911 r
.40669 .51988 .41256 .52679 .4225 .52437 .41663 .51832 Mtetra
.64 .738 .92 r
.41663 .51832 .4225 .52437 .4325 .52148 .42664 .51556 Mtetra
.649 .746 .92 r
.42664 .51556 .4325 .52148 .44254 .51844 .4367 .51255 Mtetra
.653 .749 .92 r
.4367 .51255 .44254 .51844 .45262 .5153 .4468 .50943 Mtetra
.656 .751 .92 r
.4468 .50943 .45262 .5153 .46273 .5121 .45695 .50623 Mtetra
.657 .753 .92 r
.45695 .50623 .46273 .5121 .47289 .50886 .46713 .50298 Mtetra
.658 .753 .92 r
.46713 .50298 .47289 .50886 .48308 .50559 .47734 .49969 Mtetra
.659 .754 .92 r
.47734 .49969 .48308 .50559 .49332 .5023 .4876 .49638 Mtetra
.4876 .49638 .49332 .5023 .50358 .49899 .4979 .49305 Mtetra
.4979 .49305 .50358 .49899 .51389 .49569 .50823 .48972 Mtetra
.659 .753 .92 r
.50823 .48972 .51389 .49569 .52424 .49237 .5186 .48638 Mtetra
.658 .753 .92 r
.5186 .48638 .52424 .49237 .53462 .48906 .52901 .48304 Mtetra
.52901 .48304 .53462 .48906 .54505 .48573 .53946 .47969 Mtetra
.53946 .47969 .54505 .48573 .55551 .48239 .54995 .47633 Mtetra
.54995 .47633 .55551 .48239 .56601 .47905 .56048 .47296 Mtetra
.56048 .47296 .56601 .47905 .57656 .4757 .57105 .46958 Mtetra
.57105 .46958 .57656 .4757 .58714 .47233 .58166 .46619 Mtetra
.657 .753 .92 r
.58166 .46619 .58714 .47233 .59776 .46896 .59231 .46279 Mtetra
.59231 .46279 .59776 .46896 .60842 .46557 .603 .45938 Mtetra
.603 .45938 .60842 .46557 .61913 .46217 .61373 .45595 Mtetra
.657 .752 .92 r
.61373 .45595 .61913 .46217 .62987 .45876 .6245 .45252 Mtetra
.6245 .45252 .62987 .45876 .64066 .45534 .63532 .44907 Mtetra
.63532 .44907 .64066 .45534 .65148 .45191 .64617 .44561 Mtetra
.64617 .44561 .65148 .45191 .66235 .44846 .65707 .44214 Mtetra
.65707 .44214 .66235 .44846 .67326 .445 .66801 .43866 Mtetra
.66801 .43866 .67326 .445 .68421 .44153 .67899 .43516 Mtetra
.67899 .43516 .68421 .44153 .69521 .43805 .69001 .43166 Mtetra
.69001 .43166 .69521 .43805 .70625 .43455 .70108 .42813 Mtetra
.70108 .42813 .70625 .43455 .71733 .43104 .71219 .4246 Mtetra
.71219 .4246 .71733 .43104 .72845 .42752 .72334 .42105 Mtetra
.72334 .42105 .72845 .42752 .73962 .42398 .73454 .41749 Mtetra
.73454 .41749 .73962 .42398 .75083 .42043 .74578 .41391 Mtetra
.74578 .41391 .75083 .42043 .76208 .41687 .75707 .41033 Mtetra
.75707 .41033 .76208 .41687 .77338 .4133 .7684 .40672 Mtetra
.7684 .40672 .77338 .4133 .78472 .40971 .77977 .40311 Mtetra
.77977 .40311 .78472 .40971 .79611 .4061 .79119 .39948 Mtetra
.79119 .39948 .79611 .4061 .80754 .40249 .80266 .39584 Mtetra
.80266 .39584 .80754 .40249 .81902 .39886 .81417 .39218 Mtetra
.81417 .39218 .81902 .39886 .83055 .39521 .82573 .38851 Mtetra
.82573 .38851 .83055 .39521 .84212 .39155 .83733 .38482 Mtetra
.83733 .38482 .84212 .39155 .85373 .38788 .84898 .38112 Mtetra
.84898 .38112 .85373 .38788 .86539 .38419 .86067 .37741 Mtetra
.86067 .37741 .86539 .38419 .8771 .38049 .87242 .37368 Mtetra
.518 .628 .899 r
.24563 .562 .25174 .56974 .26105 .56811 .25482 .56208 Mtetra
.613 .721 .922 r
.25482 .56208 .26105 .56811 .27044 .56612 .26422 .56006 Mtetra
.594 .715 .928 r
.26422 .56006 .27044 .56612 .27969 .5664 .27364 .55842 Mtetra
.876 .716 .679 r
.27364 .55842 .27969 .5664 .28971 .55649 .28479 .53301 Mtetra
.066 .109 .597 r
.28479 .53301 .28971 .55649 .29912 .55563 .29298 .54939 Mtetra
.61 .715 .92 r
.29298 .54939 .29912 .55563 .30867 .55337 .30253 .54741 Mtetra
.626 .731 .922 r
.30253 .54741 .30867 .55337 .31826 .55111 .31213 .54505 Mtetra
.605 .721 .927 r
.31213 .54505 .31826 .55111 .32777 .55066 .32176 .54312 Mtetra
.934 .701 .561 r
.32176 .54312 .32777 .55066 .33786 .54079 .33783 .42973 Mtetra
0 0 .335 r
.33783 .42973 .33786 .54079 .34746 .54018 .34142 .53382 Mtetra
.613 .715 .918 r
.34142 .53382 .34746 .54018 .3572 .53773 .35116 .53175 Mtetra
.636 .737 .921 r
.35116 .53175 .3572 .53773 .36699 .53504 .36096 .52911 Mtetra
.64 .74 .921 r
.36096 .52911 .36699 .53504 .37682 .53234 .37082 .52637 Mtetra
.636 .738 .922 r
.37082 .52637 .37682 .53234 .38668 .52992 .3807 .52372 Mtetra
.6 .719 .928 r
.3807 .52372 .38668 .52992 .39644 .53104 .39059 .52186 Mtetra
.828 .708 .732 r
.39059 .52186 .39644 .53104 .40669 .51988 .40102 .50678 Mtetra
.345 .415 .79 r
.40102 .50678 .40669 .51988 .41663 .51832 .41072 .51201 Mtetra
.627 .726 .918 r
.41072 .51201 .41663 .51832 .42664 .51556 .42075 .50954 Mtetra
.646 .743 .92 r
.42075 .50954 .42664 .51556 .4367 .51255 .43083 .5066 Mtetra
.652 .748 .92 r
.43083 .5066 .4367 .51255 .4468 .50943 .44095 .5035 Mtetra
.655 .75 .92 r
.44095 .5035 .4468 .50943 .45695 .50623 .45112 .50031 Mtetra
.657 .752 .92 r
.45112 .50031 .45695 .50623 .46713 .50298 .46132 .49705 Mtetra
.658 .753 .92 r
.46132 .49705 .46713 .50298 .47734 .49969 .47157 .49375 Mtetra
.659 .754 .92 r
.47157 .49375 .47734 .49969 .4876 .49638 .48185 .49042 Mtetra
.48185 .49042 .4876 .49638 .4979 .49305 .49217 .48707 Mtetra
.49217 .48707 .4979 .49305 .50823 .48972 .50253 .48371 Mtetra
.50253 .48371 .50823 .48972 .5186 .48638 .51292 .48035 Mtetra
.658 .753 .92 r
.51292 .48035 .5186 .48638 .52901 .48304 .52336 .47698 Mtetra
.52336 .47698 .52901 .48304 .53946 .47969 .53384 .4736 Mtetra
.53384 .4736 .53946 .47969 .54995 .47633 .54435 .47022 Mtetra
.54435 .47022 .54995 .47633 .56048 .47296 .55491 .46682 Mtetra
.55491 .46682 .56048 .47296 .57105 .46958 .5655 .46342 Mtetra
.5655 .46342 .57105 .46958 .58166 .46619 .57614 .46 Mtetra
.57614 .46 .58166 .46619 .59231 .46279 .58682 .45658 Mtetra
.657 .753 .92 r
.58682 .45658 .59231 .46279 .603 .45938 .59754 .45314 Mtetra
.59754 .45314 .603 .45938 .61373 .45595 .60829 .44969 Mtetra
.60829 .44969 .61373 .45595 .6245 .45252 .61909 .44623 Mtetra
.657 .752 .92 r
.61909 .44623 .6245 .45252 .63532 .44907 .62994 .44276 Mtetra
.62994 .44276 .63532 .44907 .64617 .44561 .64082 .43928 Mtetra
.64082 .43928 .64617 .44561 .65707 .44214 .65175 .43578 Mtetra
.65175 .43578 .65707 .44214 .66801 .43866 .66272 .43227 Mtetra
.66272 .43227 .66801 .43866 .67899 .43516 .67373 .42875 Mtetra
.67373 .42875 .67899 .43516 .69001 .43166 .68478 .42522 Mtetra
.68478 .42522 .69001 .43166 .70108 .42813 .69588 .42167 Mtetra
.69588 .42167 .70108 .42813 .71219 .4246 .70702 .41811 Mtetra
.70702 .41811 .71219 .4246 .72334 .42105 .7182 .41454 Mtetra
.7182 .41454 .72334 .42105 .73454 .41749 .72943 .41095 Mtetra
.72943 .41095 .73454 .41749 .74578 .41391 .7407 .40735 Mtetra
.7407 .40735 .74578 .41391 .75707 .41033 .75202 .40373 Mtetra
.75202 .40373 .75707 .41033 .7684 .40672 .76338 .4001 Mtetra
.76338 .4001 .7684 .40672 .77977 .40311 .77479 .39646 Mtetra
.77479 .39646 .77977 .40311 .79119 .39948 .78624 .39281 Mtetra
.78624 .39281 .79119 .39948 .80266 .39584 .79774 .38914 Mtetra
.79774 .38914 .80266 .39584 .81417 .39218 .80928 .38545 Mtetra
.80928 .38545 .81417 .39218 .82573 .38851 .82087 .38175 Mtetra
.82087 .38175 .82573 .38851 .83733 .38482 .83251 .37804 Mtetra
.83251 .37804 .83733 .38482 .84898 .38112 .84419 .37431 Mtetra
.84419 .37431 .84898 .38112 .86067 .37741 .85592 .37057 Mtetra
.85592 .37057 .86067 .37741 .87242 .37368 .86769 .36681 Mtetra
0 0 0 r
.23639 .59098 .24563 .562 .25482 .56208 .24858 .55571 Mtetra
.597 .705 .919 r
.24858 .55571 .25482 .56208 .26422 .56006 .25797 .55404 Mtetra
.612 .723 .924 r
.25797 .55404 .26422 .56006 .27364 .55842 .26743 .55199 Mtetra
.481 .659 .94 r
.26743 .55199 .27364 .55842 .28479 .53301 .27675 .55223 Mtetra
.211 0 .199 r
.27675 .55223 .28479 .53301 .29298 .54939 .28686 .54225 Mtetra
.562 .669 .91 r
.28686 .54225 .29298 .54939 .30253 .54741 .29634 .54134 Mtetra
.623 .727 .921 r
.29634 .54134 .30253 .54741 .31213 .54505 .30597 .53903 Mtetra
.622 .73 .924 r
.30597 .53903 .31213 .54505 .32176 .54312 .31563 .53673 Mtetra
.528 .682 .937 r
.31563 .53673 .32176 .54312 .33783 .42973 .32522 .53624 Mtetra
.503 .268 .491 r
.32522 .53624 .33783 .42973 .34142 .53382 .3354 .52628 Mtetra
.552 .654 .903 r
.3354 .52628 .34142 .53382 .35116 .53175 .34508 .52563 Mtetra
.63 .731 .92 r
.34508 .52563 .35116 .53175 .36096 .52911 .3549 .52313 Mtetra
.639 .739 .921 r
.3549 .52313 .36096 .52911 .37082 .52637 .36477 .52038 Mtetra
.639 .74 .922 r
.36477 .52038 .37082 .52637 .3807 .52372 .37468 .51763 Mtetra
.626 .733 .924 r
.37468 .51763 .3807 .52372 .39059 .52186 .38461 .51516 Mtetra
.426 .629 .938 r
.38461 .51516 .39059 .52186 .40102 .50678 .39445 .51624 Mtetra
0 0 0 r
.39445 .51624 .40102 .50678 .41072 .51201 .4048 .505 Mtetra
.591 .691 .911 r
.4048 .505 .41072 .51201 .42075 .50954 .41482 .50338 Mtetra
.64 .738 .92 r
.41482 .50338 .42075 .50954 .43083 .5066 .42492 .50057 Mtetra
.649 .746 .92 r
.42492 .50057 .43083 .5066 .44095 .5035 .43506 .49751 Mtetra
.653 .749 .92 r
.43506 .49751 .44095 .5035 .45112 .50031 .44525 .49433 Mtetra
.656 .751 .92 r
.44525 .49433 .45112 .50031 .46132 .49705 .45548 .49108 Mtetra
.657 .753 .92 r
.45548 .49108 .46132 .49705 .47157 .49375 .46575 .48777 Mtetra
.658 .753 .92 r
.46575 .48777 .47157 .49375 .48185 .49042 .47605 .48442 Mtetra
.659 .754 .92 r
.47605 .48442 .48185 .49042 .49217 .48707 .4864 .48105 Mtetra
.4864 .48105 .49217 .48707 .50253 .48371 .49678 .47767 Mtetra
.49678 .47767 .50253 .48371 .51292 .48035 .50721 .47428 Mtetra
.659 .753 .92 r
.50721 .47428 .51292 .48035 .52336 .47698 .51767 .47088 Mtetra
.658 .753 .92 r
.51767 .47088 .52336 .47698 .53384 .4736 .52817 .46747 Mtetra
.52817 .46747 .53384 .4736 .54435 .47022 .53872 .46406 Mtetra
.53872 .46406 .54435 .47022 .55491 .46682 .5493 .46064 Mtetra
.5493 .46064 .55491 .46682 .5655 .46342 .55992 .45721 Mtetra
.55992 .45721 .5655 .46342 .57614 .46 .57058 .45377 Mtetra
.57058 .45377 .57614 .46 .58682 .45658 .58129 .45032 Mtetra
.657 .753 .92 r
.58129 .45032 .58682 .45658 .59754 .45314 .59203 .44686 Mtetra
.59203 .44686 .59754 .45314 .60829 .44969 .60282 .44339 Mtetra
.60282 .44339 .60829 .44969 .61909 .44623 .61365 .4399 Mtetra
.657 .752 .92 r
.61365 .4399 .61909 .44623 .62994 .44276 .62452 .43641 Mtetra
.62452 .43641 .62994 .44276 .64082 .43928 .63543 .4329 Mtetra
.63543 .4329 .64082 .43928 .65175 .43578 .64639 .42938 Mtetra
.64639 .42938 .65175 .43578 .66272 .43227 .65738 .42584 Mtetra
.65738 .42584 .66272 .43227 .67373 .42875 .66843 .42229 Mtetra
.66843 .42229 .67373 .42875 .68478 .42522 .67951 .41873 Mtetra
.67951 .41873 .68478 .42522 .69588 .42167 .69064 .41516 Mtetra
.69064 .41516 .69588 .42167 .70702 .41811 .70181 .41157 Mtetra
.70181 .41157 .70702 .41811 .7182 .41454 .71302 .40797 Mtetra
.71302 .40797 .7182 .41454 .72943 .41095 .72428 .40436 Mtetra
.72428 .40436 .72943 .41095 .7407 .40735 .73558 .40073 Mtetra
.73558 .40073 .7407 .40735 .75202 .40373 .74693 .39709 Mtetra
.74693 .39709 .75202 .40373 .76338 .4001 .75833 .39344 Mtetra
.75833 .39344 .76338 .4001 .77479 .39646 .76976 .38977 Mtetra
.76976 .38977 .77479 .39646 .78624 .39281 .78125 .38608 Mtetra
.78125 .38608 .78624 .39281 .79774 .38914 .79278 .38239 Mtetra
.79278 .38239 .79774 .38914 .80928 .38545 .80436 .37868 Mtetra
.80436 .37868 .80928 .38545 .82087 .38175 .81598 .37495 Mtetra
.81598 .37495 .82087 .38175 .83251 .37804 .82765 .37121 Mtetra
.82765 .37121 .83251 .37804 .84419 .37431 .83936 .36745 Mtetra
.83936 .36745 .84419 .37431 .85592 .37057 .85113 .36368 Mtetra
.85113 .36368 .85592 .37057 .86769 .36681 .86294 .3599 Mtetra
.65 .48 .64 r
.23236 .55762 .23639 .59098 .24858 .55571 .24241 .54787 Mtetra
.518 .628 .899 r
.24241 .54787 .24858 .55571 .25797 .55404 .25167 .54791 Mtetra
.613 .721 .922 r
.25167 .54791 .25797 .55404 .26743 .55199 .26115 .54584 Mtetra
.594 .715 .928 r
.26115 .54584 .26743 .55199 .27675 .55223 .27064 .54415 Mtetra
.877 .716 .679 r
.27064 .54415 .27675 .55223 .28686 .54225 .2819 .5186 Mtetra
.061 .105 .595 r
.2819 .5186 .28686 .54225 .29634 .54134 .29014 .53501 Mtetra
.61 .715 .92 r
.29014 .53501 .29634 .54134 .30597 .53903 .29976 .53298 Mtetra
.626 .731 .922 r
.29976 .53298 .30597 .53903 .31563 .53673 .30945 .53057 Mtetra
.606 .721 .927 r
.30945 .53057 .31563 .53673 .32522 .53624 .31914 .52859 Mtetra
.935 .701 .56 r
.31914 .52859 .32522 .53624 .3354 .52628 .33544 .4147 Mtetra
0 0 .33 r
.33544 .4147 .3354 .52628 .34508 .52563 .33897 .51917 Mtetra
.613 .715 .918 r
.33897 .51917 .34508 .52563 .3549 .52313 .34879 .51705 Mtetra
.636 .737 .921 r
.34879 .51705 .3549 .52313 .36477 .52038 .35868 .51436 Mtetra
.64 .74 .921 r
.35868 .51436 .36477 .52038 .37468 .51763 .36861 .51156 Mtetra
.636 .738 .922 r
.36861 .51156 .37468 .51763 .38461 .51516 .37858 .50886 Mtetra
.6 .719 .928 r
.37858 .50886 .38461 .51516 .39445 .51624 .38855 .50695 Mtetra
.828 .709 .732 r
.38855 .50695 .39445 .51624 .4048 .505 .39908 .49176 Mtetra
.344 .414 .79 r
.39908 .49176 .4048 .505 .41482 .50338 .40885 .49697 Mtetra
.627 .726 .918 r
.40885 .49697 .41482 .50338 .42492 .50057 .41896 .49445 Mtetra
.646 .743 .92 r
.41896 .49445 .42492 .50057 .43506 .49751 .42913 .49145 Mtetra
.652 .748 .92 r
.42913 .49145 .43506 .49751 .44525 .49433 .43934 .4883 Mtetra
.655 .75 .92 r
.43934 .4883 .44525 .49433 .45548 .49108 .4496 .48505 Mtetra
.657 .752 .92 r
.4496 .48505 .45548 .49108 .46575 .48777 .45989 .48173 Mtetra
.658 .753 .92 r
.45989 .48173 .46575 .48777 .47605 .48442 .47022 .47838 Mtetra
.659 .754 .92 r
.47022 .47838 .47605 .48442 .4864 .48105 .48059 .47499 Mtetra
.48059 .47499 .4864 .48105 .49678 .47767 .491 .47158 Mtetra
.491 .47158 .49678 .47767 .50721 .47428 .50145 .46816 Mtetra
.50145 .46816 .50721 .47428 .51767 .47088 .51194 .46474 Mtetra
.658 .753 .92 r
.51194 .46474 .51767 .47088 .52817 .46747 .52247 .4613 Mtetra
.52247 .4613 .52817 .46747 .53872 .46406 .53304 .45787 Mtetra
.53304 .45787 .53872 .46406 .5493 .46064 .54365 .45442 Mtetra
.54365 .45442 .5493 .46064 .55992 .45721 .5543 .45097 Mtetra
.5543 .45097 .55992 .45721 .57058 .45377 .56499 .4475 Mtetra
.56499 .4475 .57058 .45377 .58129 .45032 .57572 .44402 Mtetra
.57572 .44402 .58129 .45032 .59203 .44686 .58649 .44054 Mtetra
.657 .753 .92 r
.58649 .44054 .59203 .44686 .60282 .44339 .59731 .43704 Mtetra
.59731 .43704 .60282 .44339 .61365 .4399 .60816 .43353 Mtetra
.60816 .43353 .61365 .4399 .62452 .43641 .61906 .43001 Mtetra
.657 .752 .92 r
.61906 .43001 .62452 .43641 .63543 .4329 .63 .42647 Mtetra
.63 .42647 .63543 .4329 .64639 .42938 .64099 .42292 Mtetra
.64099 .42292 .64639 .42938 .65738 .42584 .65202 .41936 Mtetra
.65202 .41936 .65738 .42584 .66843 .42229 .66309 .41579 Mtetra
.66309 .41579 .66843 .42229 .67951 .41873 .6742 .4122 Mtetra
.6742 .4122 .67951 .41873 .69064 .41516 .68536 .4086 Mtetra
.68536 .4086 .69064 .41516 .70181 .41157 .69656 .40499 Mtetra
.69656 .40499 .70181 .41157 .71302 .40797 .7078 .40136 Mtetra
.7078 .40136 .71302 .40797 .72428 .40436 .71909 .39772 Mtetra
.71909 .39772 .72428 .40436 .73558 .40073 .73043 .39407 Mtetra
.73043 .39407 .73558 .40073 .74693 .39709 .74181 .3904 Mtetra
.74181 .3904 .74693 .39709 .75833 .39344 .75323 .38672 Mtetra
.75323 .38672 .75833 .39344 .76976 .38977 .7647 .38302 Mtetra
.7647 .38302 .76976 .38977 .78125 .38608 .77622 .37931 Mtetra
.77622 .37931 .78125 .38608 .79278 .38239 .78778 .37559 Mtetra
.78778 .37559 .79278 .38239 .80436 .37868 .79939 .37185 Mtetra
.79939 .37185 .80436 .37868 .81598 .37495 .81105 .36809 Mtetra
.81105 .36809 .81598 .37495 .82765 .37121 .82275 .36432 Mtetra
.82275 .36432 .82765 .37121 .83936 .36745 .8345 .36054 Mtetra
.8345 .36054 .83936 .36745 .85113 .36368 .8463 .35674 Mtetra
.8463 .35674 .85113 .36368 .86294 .3599 .85815 .35293 Mtetra
.935 .56 .245 r
.22608 .55035 .23236 .55762 .24241 .54787 .23305 .5769 Mtetra
0 0 0 r
.23305 .5769 .24241 .54787 .25167 .54791 .24537 .54144 Mtetra
.597 .705 .919 r
.24537 .54144 .25167 .54791 .26115 .54584 .25483 .53972 Mtetra
.612 .723 .924 r
.25483 .53972 .26115 .54584 .27064 .54415 .26436 .53762 Mtetra
.481 .659 .94 r
.26436 .53762 .27064 .54415 .2819 .5186 .27376 .53783 Mtetra
.2 0 .188 r
.27376 .53783 .2819 .5186 .29014 .53501 .28396 .52776 Mtetra
.562 .669 .91 r
.28396 .52776 .29014 .53501 .29976 .53298 .29352 .52681 Mtetra
.623 .727 .921 r
.29352 .52681 .29976 .53298 .30945 .53057 .30322 .52445 Mtetra
.622 .73 .924 r
.30322 .52445 .30945 .53057 .31914 .52859 .31296 .52209 Mtetra
.528 .682 .936 r
.31296 .52209 .31914 .52859 .33544 .4147 .32263 .52156 Mtetra
.5 .263 .487 r
.32263 .52156 .33544 .4147 .33897 .51917 .3329 .51152 Mtetra
.551 .654 .904 r
.3329 .51152 .33897 .51917 .34879 .51705 .34265 .51082 Mtetra
.63 .731 .92 r
.34265 .51082 .34879 .51705 .35868 .51436 .35255 .50827 Mtetra
.639 .739 .921 r
.35255 .50827 .35868 .51436 .36861 .51156 .3625 .50547 Mtetra
.639 .74 .922 r
.3625 .50547 .36861 .51156 .37858 .50886 .3725 .50267 Mtetra
.627 .733 .924 r
.3725 .50267 .37858 .50886 .38855 .50695 .38252 .50015 Mtetra
.427 .629 .938 r
.38252 .50015 .38855 .50695 .39908 .49176 .39244 .50119 Mtetra
0 0 0 r
.39244 .50119 .39908 .49176 .40885 .49697 .40287 .48985 Mtetra
.591 .691 .911 r
.40287 .48985 .40885 .49697 .41896 .49445 .41298 .48819 Mtetra
.64 .738 .92 r
.41298 .48819 .41896 .49445 .42913 .49145 .42316 .48532 Mtetra
.649 .746 .92 r
.42316 .48532 .42913 .49145 .43934 .4883 .43339 .4822 Mtetra
.653 .749 .92 r
.43339 .4822 .43934 .4883 .4496 .48505 .44367 .47896 Mtetra
.656 .751 .92 r
.44367 .47896 .4496 .48505 .45989 .48173 .45399 .47565 Mtetra
.657 .753 .92 r
.45399 .47565 .45989 .48173 .47022 .47838 .46434 .47228 Mtetra
.658 .753 .92 r
.46434 .47228 .47022 .47838 .48059 .47499 .47474 .46888 Mtetra
.659 .754 .92 r
.47474 .46888 .48059 .47499 .491 .47158 .48518 .46545 Mtetra
.48518 .46545 .491 .47158 .50145 .46816 .49565 .462 Mtetra
.49565 .462 .50145 .46816 .51194 .46474 .50617 .45855 Mtetra
.659 .753 .92 r
.50617 .45855 .51194 .46474 .52247 .4613 .51672 .45509 Mtetra
.658 .753 .92 r
.51672 .45509 .52247 .4613 .53304 .45787 .52732 .45163 Mtetra
.52732 .45163 .53304 .45787 .54365 .45442 .53795 .44816 Mtetra
.53795 .44816 .54365 .45442 .5543 .45097 .54863 .44467 Mtetra
.54863 .44467 .5543 .45097 .56499 .4475 .55935 .44118 Mtetra
.55935 .44118 .56499 .4475 .57572 .44402 .57011 .43768 Mtetra
.57011 .43768 .57572 .44402 .58649 .44054 .58091 .43417 Mtetra
.657 .753 .92 r
.58091 .43417 .58649 .44054 .59731 .43704 .59175 .43064 Mtetra
.59175 .43064 .59731 .43704 .60816 .43353 .60264 .42711 Mtetra
.60264 .42711 .60816 .43353 .61906 .43001 .61357 .42356 Mtetra
.657 .752 .92 r
.61357 .42356 .61906 .43001 .63 .42647 .62454 .42 Mtetra
.62454 .42 .63 .42647 .64099 .42292 .63555 .41642 Mtetra
.63555 .41642 .64099 .42292 .65202 .41936 .64661 .41284 Mtetra
.64661 .41284 .65202 .41936 .66309 .41579 .65771 .40924 Mtetra
.65771 .40924 .66309 .41579 .6742 .4122 .66885 .40562 Mtetra
.66885 .40562 .6742 .4122 .68536 .4086 .68004 .402 Mtetra
.68004 .402 .68536 .4086 .69656 .40499 .69127 .39836 Mtetra
.69127 .39836 .69656 .40499 .7078 .40136 .70255 .39471 Mtetra
.70255 .39471 .7078 .40136 .71909 .39772 .71387 .39104 Mtetra
.71387 .39104 .71909 .39772 .73043 .39407 .72523 .38736 Mtetra
.72523 .38736 .73043 .39407 .74181 .3904 .73665 .38366 Mtetra
.73665 .38366 .74181 .3904 .75323 .38672 .7481 .37995 Mtetra
.7481 .37995 .75323 .38672 .7647 .38302 .75961 .37623 Mtetra
.75961 .37623 .7647 .38302 .77622 .37931 .77116 .37249 Mtetra
.77116 .37249 .77622 .37931 .78778 .37559 .78275 .36874 Mtetra
.78275 .36874 .78778 .37559 .79939 .37185 .79439 .36497 Mtetra
.79439 .36497 .79939 .37185 .81105 .36809 .80608 .36119 Mtetra
.80608 .36119 .81105 .36809 .82275 .36432 .81782 .35739 Mtetra
.81782 .35739 .82275 .36432 .8345 .36054 .82961 .35358 Mtetra
.82961 .35358 .8345 .36054 .8463 .35674 .84144 .34975 Mtetra
.84144 .34975 .8463 .35674 .85815 .35293 .85332 .34591 Mtetra
.533 .685 .936 r
.21969 .54395 .22608 .55035 .23305 .5769 .229 .54333 Mtetra
.65 .479 .64 r
.229 .54333 .23305 .5769 .24537 .54144 .23914 .53349 Mtetra
.518 .628 .899 r
.23914 .53349 .24537 .54144 .25483 .53972 .24847 .53349 Mtetra
.613 .721 .922 r
.24847 .53349 .25483 .53972 .26436 .53762 .25802 .53137 Mtetra
.594 .715 .928 r
.25802 .53137 .26436 .53762 .27376 .53783 .26758 .52964 Mtetra
.878 .717 .678 r
.26758 .52964 .27376 .53783 .28396 .52776 .27896 .50393 Mtetra
.056 .102 .593 r
.27896 .50393 .28396 .52776 .29352 .52681 .28725 .52037 Mtetra
.61 .715 .92 r
.28725 .52037 .29352 .52681 .30322 .52445 .29695 .51829 Mtetra
.626 .731 .922 r
.29695 .51829 .30322 .52445 .31296 .52209 .30671 .51583 Mtetra
.606 .721 .927 r
.30671 .51583 .31296 .52209 .32263 .52156 .31649 .51381 Mtetra
.936 .702 .558 r
.31649 .51381 .32263 .52156 .3329 .51152 .333 .39941 Mtetra
0 0 .325 r
.333 .39941 .3329 .51152 .34265 .51082 .33648 .50426 Mtetra
.613 .715 .918 r
.33648 .50426 .34265 .51082 .35255 .50827 .34638 .50209 Mtetra
.636 .737 .921 r
.34638 .50209 .35255 .50827 .3625 .50547 .35635 .49934 Mtetra
.64 .74 .921 r
.35635 .49934 .3625 .50547 .3725 .50267 .36637 .49649 Mtetra
.636 .738 .922 r
.36637 .49649 .3725 .50267 .38252 .50015 .37642 .49374 Mtetra
.6 .719 .928 r
.37642 .49374 .38252 .50015 .39244 .50119 .38648 .49178 Mtetra
.829 .709 .732 r
.38648 .49178 .39244 .50119 .40287 .48985 .3971 .47647 Mtetra
.342 .413 .79 r
.3971 .47647 .40287 .48985 .41298 .48819 .40695 .48167 Mtetra
.627 .726 .918 r
.40695 .48167 .41298 .48819 .42316 .48532 .41715 .47909 Mtetra
.646 .743 .92 r
.41715 .47909 .42316 .48532 .43339 .4822 .4274 .47604 Mtetra
.652 .748 .92 r
.4274 .47604 .43339 .4822 .44367 .47896 .4377 .47282 Mtetra
.655 .75 .92 r
.4377 .47282 .44367 .47896 .45399 .47565 .44804 .46951 Mtetra
.657 .752 .92 r
.44804 .46951 .45399 .47565 .46434 .47228 .45843 .46614 Mtetra
.658 .753 .92 r
.45843 .46614 .46434 .47228 .47474 .46888 .46885 .46272 Mtetra
.659 .754 .92 r
.46885 .46272 .47474 .46888 .48518 .46545 .47931 .45927 Mtetra
.47931 .45927 .48518 .46545 .49565 .462 .48981 .4558 Mtetra
.48981 .4558 .49565 .462 .50617 .45855 .50035 .45233 Mtetra
.50035 .45233 .50617 .45855 .51672 .45509 .51094 .44884 Mtetra
.658 .753 .92 r
.51094 .44884 .51672 .45509 .52732 .45163 .52156 .44535 Mtetra
.52156 .44535 .52732 .45163 .53795 .44816 .53222 .44185 Mtetra
.53222 .44185 .53795 .44816 .54863 .44467 .54293 .43834 Mtetra
.54293 .43834 .54863 .44467 .55935 .44118 .55367 .43482 Mtetra
.55367 .43482 .55935 .44118 .57011 .43768 .56446 .43129 Mtetra
.56446 .43129 .57011 .43768 .58091 .43417 .57529 .42775 Mtetra
.57529 .42775 .58091 .43417 .59175 .43064 .58616 .4242 Mtetra
.657 .753 .92 r
.58616 .4242 .59175 .43064 .60264 .42711 .59707 .42064 Mtetra
.59707 .42064 .60264 .42711 .61357 .42356 .60803 .41707 Mtetra
.60803 .41707 .61357 .42356 .62454 .42 .61903 .41348 Mtetra
.657 .752 .92 r
.61903 .41348 .62454 .42 .63555 .41642 .63007 .40988 Mtetra
.63007 .40988 .63555 .41642 .64661 .41284 .64116 .40626 Mtetra
.64116 .40626 .64661 .41284 .65771 .40924 .65229 .40264 Mtetra
.65229 .40264 .65771 .40924 .66885 .40562 .66346 .399 Mtetra
.66346 .399 .66885 .40562 .68004 .402 .67468 .39535 Mtetra
.67468 .39535 .68004 .402 .69127 .39836 .68594 .39168 Mtetra
.68594 .39168 .69127 .39836 .70255 .39471 .69725 .388 Mtetra
.69725 .388 .70255 .39471 .71387 .39104 .7086 .3843 Mtetra
.7086 .3843 .71387 .39104 .72523 .38736 .72 .38059 Mtetra
.72 .38059 .72523 .38736 .73665 .38366 .73145 .37687 Mtetra
.73145 .37687 .73665 .38366 .7481 .37995 .74294 .37313 Mtetra
.74294 .37313 .7481 .37995 .75961 .37623 .75447 .36938 Mtetra
.75447 .36938 .75961 .37623 .77116 .37249 .76605 .36562 Mtetra
.76605 .36562 .77116 .37249 .78275 .36874 .77768 .36184 Mtetra
.77768 .36184 .78275 .36874 .79439 .36497 .78936 .35804 Mtetra
.78936 .35804 .79439 .36497 .80608 .36119 .80108 .35423 Mtetra
.80108 .35423 .80608 .36119 .81782 .35739 .81285 .3504 Mtetra
.81285 .3504 .81782 .35739 .82961 .35358 .82467 .34656 Mtetra
.82467 .34656 .82961 .35358 .84144 .34975 .83654 .34271 Mtetra
.83654 .34271 .84144 .34975 .85332 .34591 .84845 .33883 Mtetra
.595 .714 .927 r
.21323 .53769 .21969 .54395 .229 .54333 .22266 .53595 Mtetra
.934 .558 .24 r
.22266 .53595 .229 .54333 .23914 .53349 .22965 .56257 Mtetra
0 0 0 r
.22965 .56257 .23914 .53349 .24847 .53349 .2421 .52692 Mtetra
.597 .705 .919 r
.2421 .52692 .24847 .53349 .25802 .53137 .25164 .52515 Mtetra
.613 .723 .924 r
.25164 .52515 .25802 .53137 .26758 .52964 .26125 .52301 Mtetra
.481 .659 .94 r
.26125 .52301 .26758 .52964 .27896 .50393 .27072 .52317 Mtetra
.19 0 .177 r
.27072 .52317 .27896 .50393 .28725 .52037 .281 .51302 Mtetra
.562 .669 .91 r
.281 .51302 .28725 .52037 .29695 .51829 .29064 .51203 Mtetra
.623 .727 .921 r
.29064 .51203 .29695 .51829 .30671 .51583 .30042 .50961 Mtetra
.622 .73 .924 r
.30042 .50961 .30671 .51583 .31649 .51381 .31024 .5072 Mtetra
.528 .682 .936 r
.31024 .5072 .31649 .51381 .333 .39941 .31999 .50663 Mtetra
.496 .258 .483 r
.31999 .50663 .333 .39941 .33648 .50426 .33035 .4965 Mtetra
.551 .654 .904 r
.33035 .4965 .33648 .50426 .34638 .50209 .34018 .49576 Mtetra
.629 .731 .92 r
.34018 .49576 .34638 .50209 .35635 .49934 .35016 .49315 Mtetra
.639 .739 .921 r
.35016 .49315 .35635 .49934 .36637 .49649 .3602 .4903 Mtetra
.639 .74 .922 r
.3602 .4903 .36637 .49649 .37642 .49374 .37028 .48744 Mtetra
.627 .733 .924 r
.37028 .48744 .37642 .49374 .38648 .49178 .38038 .48486 Mtetra
.428 .629 .938 r
.38038 .48486 .38648 .49178 .3971 .47647 .39038 .48586 Mtetra
0 0 0 r
.39038 .48586 .3971 .47647 .40695 .48167 .40091 .47444 Mtetra
.591 .691 .911 r
.40091 .47444 .40695 .48167 .41715 .47909 .4111 .47272 Mtetra
.64 .738 .92 r
.4111 .47272 .41715 .47909 .4274 .47604 .42137 .46979 Mtetra
.649 .746 .92 r
.42137 .46979 .4274 .47604 .4377 .47282 .4317 .46662 Mtetra
.653 .749 .92 r
.4317 .46662 .4377 .47282 .44804 .46951 .44206 .46332 Mtetra
.656 .751 .92 r
.44206 .46332 .44804 .46951 .45843 .46614 .45247 .45995 Mtetra
.657 .753 .92 r
.45247 .45995 .45843 .46614 .46885 .46272 .46291 .45652 Mtetra
.658 .753 .92 r
.46291 .45652 .46885 .46272 .47931 .45927 .4734 .45305 Mtetra
.659 .754 .92 r
.4734 .45305 .47931 .45927 .48981 .4558 .48393 .44956 Mtetra
.48393 .44956 .48981 .4558 .50035 .45233 .4945 .44606 Mtetra
.4945 .44606 .50035 .45233 .51094 .44884 .50511 .44254 Mtetra
.659 .753 .92 r
.50511 .44254 .51094 .44884 .52156 .44535 .51576 .43902 Mtetra
.658 .753 .92 r
.51576 .43902 .52156 .44535 .53222 .44185 .52645 .43549 Mtetra
.52645 .43549 .53222 .44185 .54293 .43834 .53718 .43196 Mtetra
.53718 .43196 .54293 .43834 .55367 .43482 .54795 .42841 Mtetra
.54795 .42841 .55367 .43482 .56446 .43129 .55877 .42486 Mtetra
.55877 .42486 .56446 .43129 .57529 .42775 .56963 .42129 Mtetra
.56963 .42129 .57529 .42775 .58616 .4242 .58053 .41772 Mtetra
.657 .753 .92 r
.58053 .41772 .58616 .4242 .59707 .42064 .59147 .41413 Mtetra
.59147 .41413 .59707 .42064 .60803 .41707 .60245 .41052 Mtetra
.60245 .41052 .60803 .41707 .61903 .41348 .61348 .40691 Mtetra
.657 .752 .92 r
.61348 .40691 .61903 .41348 .63007 .40988 .62456 .40328 Mtetra
.62456 .40328 .63007 .40988 .64116 .40626 .63567 .39964 Mtetra
.63567 .39964 .64116 .40626 .65229 .40264 .64683 .39599 Mtetra
.64683 .39599 .65229 .40264 .66346 .399 .65804 .39232 Mtetra
.65804 .39232 .66346 .399 .67468 .39535 .66928 .38864 Mtetra
.66928 .38864 .67468 .39535 .68594 .39168 .68058 .38495 Mtetra
.68058 .38495 .68594 .39168 .69725 .388 .69192 .38124 Mtetra
.69192 .38124 .69725 .388 .7086 .3843 .7033 .37752 Mtetra
.7033 .37752 .7086 .3843 .72 .38059 .71473 .37378 Mtetra
.71473 .37378 .72 .38059 .73145 .37687 .72621 .37003 Mtetra
.72621 .37003 .73145 .37687 .74294 .37313 .73773 .36627 Mtetra
.73773 .36627 .74294 .37313 .75447 .36938 .7493 .36249 Mtetra
.7493 .36249 .75447 .36938 .76605 .36562 .76091 .35869 Mtetra
.76091 .35869 .76605 .36562 .77768 .36184 .77257 .35488 Mtetra
.77257 .35488 .77768 .36184 .78936 .35804 .78428 .35106 Mtetra
.78428 .35106 .78936 .35804 .80108 .35423 .79604 .34722 Mtetra
.79604 .34722 .80108 .35423 .81285 .3504 .80785 .34336 Mtetra
.80785 .34336 .81285 .3504 .82467 .34656 .8197 .33949 Mtetra
.8197 .33949 .82467 .34656 .83654 .34271 .8316 .33561 Mtetra
.8316 .33561 .83654 .34271 .84845 .33883 .84355 .33171 Mtetra
.603 .715 .923 r
.20674 .53136 .21323 .53769 .22266 .53595 .21619 .52944 Mtetra
.533 .685 .936 r
.21619 .52944 .22266 .53595 .22965 .56257 .22558 .52878 Mtetra
.649 .478 .639 r
.22558 .52878 .22965 .56257 .2421 .52692 .23581 .51886 Mtetra
.518 .628 .899 r
.23581 .51886 .2421 .52692 .25164 .52515 .24521 .51882 Mtetra
.613 .721 .922 r
.24521 .51882 .25164 .52515 .26125 .52301 .25484 .51665 Mtetra
.594 .714 .928 r
.25484 .51665 .26125 .52301 .27072 .52317 .26448 .51487 Mtetra
.879 .718 .678 r
.26448 .51487 .27072 .52317 .281 .51302 .27597 .48901 Mtetra
.052 .098 .591 r
.27597 .48901 .281 .51302 .29064 .51203 .28431 .50548 Mtetra
.61 .715 .92 r
.28431 .50548 .29064 .51203 .30042 .50961 .29408 .50335 Mtetra
.626 .731 .922 r
.29408 .50335 .30042 .50961 .31024 .5072 .30393 .50084 Mtetra
.606 .721 .926 r
.30393 .50084 .31024 .5072 .31999 .50663 .31379 .49876 Mtetra
.938 .702 .556 r
.31379 .49876 .31999 .50663 .33035 .4965 .33053 .38387 Mtetra
0 0 .319 r
.33053 .38387 .33035 .4965 .34018 .49576 .33395 .48909 Mtetra
.613 .715 .918 r
.33395 .48909 .34018 .49576 .35016 .49315 .34393 .48686 Mtetra
.636 .737 .921 r
.34393 .48686 .35016 .49315 .3602 .4903 .35399 .48406 Mtetra
.64 .74 .921 r
.35399 .48406 .3602 .4903 .37028 .48744 .36409 .48115 Mtetra
.636 .738 .922 r
.36409 .48115 .37028 .48744 .38038 .48486 .37422 .47835 Mtetra
.6 .719 .928 r
.37422 .47835 .38038 .48486 .39038 .48586 .38436 .47633 Mtetra
.83 .71 .732 r
.38436 .47633 .39038 .48586 .40091 .47444 .39508 .46092 Mtetra
.341 .412 .79 r
.39508 .46092 .40091 .47444 .4111 .47272 .40502 .46609 Mtetra
.627 .726 .918 r
.40502 .46609 .4111 .47272 .42137 .46979 .4153 .46345 Mtetra
.646 .743 .92 r
.4153 .46345 .42137 .46979 .4317 .46662 .42565 .46034 Mtetra
.652 .748 .92 r
.42565 .46034 .4317 .46662 .44206 .46332 .43603 .45707 Mtetra
.655 .75 .92 r
.43603 .45707 .44206 .46332 .45247 .45995 .44647 .4537 Mtetra
.657 .752 .92 r
.44647 .4537 .45247 .45995 .46291 .45652 .45694 .45026 Mtetra
.658 .753 .92 r
.45694 .45026 .46291 .45652 .4734 .45305 .46745 .44679 Mtetra
.659 .754 .92 r
.46745 .44679 .4734 .45305 .48393 .44956 .47801 .44327 Mtetra
.47801 .44327 .48393 .44956 .4945 .44606 .4886 .43974 Mtetra
.4886 .43974 .4945 .44606 .50511 .44254 .49924 .4362 Mtetra
.49924 .4362 .50511 .44254 .51576 .43902 .50991 .43265 Mtetra
.658 .753 .92 r
.50991 .43265 .51576 .43902 .52645 .43549 .52063 .4291 Mtetra
.52063 .4291 .52645 .43549 .53718 .43196 .53139 .42553 Mtetra
.53139 .42553 .53718 .43196 .54795 .42841 .54219 .42196 Mtetra
.54219 .42196 .54795 .42841 .55877 .42486 .55304 .41838 Mtetra
.55304 .41838 .55877 .42486 .56963 .42129 .56392 .41478 Mtetra
.56392 .41478 .56963 .42129 .58053 .41772 .57485 .41118 Mtetra
.57485 .41118 .58053 .41772 .59147 .41413 .58582 .40756 Mtetra
.657 .753 .92 r
.58582 .40756 .59147 .41413 .60245 .41052 .59684 .40394 Mtetra
.59684 .40394 .60245 .41052 .61348 .40691 .6079 .40029 Mtetra
.6079 .40029 .61348 .40691 .62456 .40328 .619 .39664 Mtetra
.657 .752 .92 r
.619 .39664 .62456 .40328 .63567 .39964 .63014 .39297 Mtetra
.63014 .39297 .63567 .39964 .64683 .39599 .64133 .38929 Mtetra
.64133 .38929 .64683 .39599 .65804 .39232 .65257 .3856 Mtetra
.65257 .3856 .65804 .39232 .66928 .38864 .66385 .38189 Mtetra
.66385 .38189 .66928 .38864 .68058 .38495 .67517 .37817 Mtetra
.67517 .37817 .68058 .38495 .69192 .38124 .68654 .37443 Mtetra
.68654 .37443 .69192 .38124 .7033 .37752 .69796 .37068 Mtetra
.69796 .37068 .7033 .37752 .71473 .37378 .70942 .36692 Mtetra
.70942 .36692 .71473 .37378 .72621 .37003 .72093 .36314 Mtetra
.72093 .36314 .72621 .37003 .73773 .36627 .73248 .35935 Mtetra
.73248 .35935 .73773 .36627 .7493 .36249 .74408 .35554 Mtetra
.74408 .35554 .7493 .36249 .76091 .35869 .75573 .35171 Mtetra
.75573 .35171 .76091 .35869 .77257 .35488 .76743 .34788 Mtetra
.76743 .34788 .77257 .35488 .78428 .35106 .77917 .34402 Mtetra
.77917 .34402 .78428 .35106 .79604 .34722 .79096 .34015 Mtetra
.79096 .34015 .79604 .34722 .80785 .34336 .8028 .33627 Mtetra
.8028 .33627 .80785 .34336 .8197 .33949 .81469 .33237 Mtetra
.81469 .33237 .8197 .33949 .8316 .33561 .82663 .32846 Mtetra
.82663 .32846 .8316 .33561 .84355 .33171 .83861 .32453 Mtetra
.585 .698 .92 r
.20024 .52464 .20674 .53136 .21619 .52944 .20967 .52309 Mtetra
.595 .714 .927 r
.20967 .52309 .21619 .52944 .22558 .52878 .21917 .52129 Mtetra
.933 .556 .234 r
.21917 .52129 .22558 .52878 .23581 .51886 .22619 .548 Mtetra
0 0 0 r
.22619 .548 .23581 .51886 .24521 .51882 .23877 .51214 Mtetra
.597 .705 .919 r
.23877 .51214 .24521 .51882 .25484 .51665 .24839 .51033 Mtetra
.613 .723 .924 r
.24839 .51033 .25484 .51665 .26448 .51487 .25807 .50813 Mtetra
.482 .659 .939 r
.25807 .50813 .26448 .51487 .27597 .48901 .26762 .50826 Mtetra
.179 0 .166 r
.26762 .50826 .27597 .48901 .28431 .50548 .278 .49802 Mtetra
.562 .669 .91 r
.278 .49802 .28431 .50548 .29408 .50335 .28771 .49698 Mtetra
.623 .727 .921 r
.28771 .49698 .29408 .50335 .30393 .50084 .29757 .49451 Mtetra
.622 .73 .924 r
.29757 .49451 .30393 .50084 .31379 .49876 .30747 .49205 Mtetra
.528 .682 .936 r
.30747 .49205 .31379 .49876 .33053 .38387 .3173 .49143 Mtetra
.493 .253 .48 r
.3173 .49143 .33053 .38387 .33395 .48909 .32775 .48121 Mtetra
.551 .654 .904 r
.32775 .48121 .33395 .48909 .34393 .48686 .33766 .48042 Mtetra
.629 .731 .92 r
.33766 .48042 .34393 .48686 .35399 .48406 .34773 .47776 Mtetra
.639 .739 .921 r
.34773 .47776 .35399 .48406 .36409 .48115 .35785 .47485 Mtetra
.639 .74 .922 r
.35785 .47485 .36409 .48115 .37422 .47835 .36801 .47193 Mtetra
.627 .733 .924 r
.36801 .47193 .37422 .47835 .38436 .47633 .37821 .4693 Mtetra
.429 .629 .938 r
.37821 .4693 .38436 .47633 .39508 .46092 .38829 .47026 Mtetra
0 0 0 r
.38829 .47026 .39508 .46092 .40502 .46609 .39892 .45874 Mtetra
.591 .691 .912 r
.39892 .45874 .40502 .46609 .4153 .46345 .40919 .45697 Mtetra
.64 .738 .92 r
.40919 .45697 .4153 .46345 .42565 .46034 .41955 .45399 Mtetra
.649 .746 .92 r
.41955 .45399 .42565 .46034 .43603 .45707 .42997 .45075 Mtetra
.653 .749 .92 r
.42997 .45075 .43603 .45707 .44647 .4537 .44042 .44739 Mtetra
.656 .751 .92 r
.44042 .44739 .44647 .4537 .45694 .45026 .45092 .44396 Mtetra
.657 .753 .92 r
.45092 .44396 .45694 .45026 .46745 .44679 .46146 .44047 Mtetra
.658 .753 .92 r
.46146 .44047 .46745 .44679 .47801 .44327 .47204 .43694 Mtetra
.659 .754 .92 r
.47204 .43694 .47801 .44327 .4886 .43974 .48266 .43338 Mtetra
.48266 .43338 .4886 .43974 .49924 .4362 .49333 .42982 Mtetra
.49333 .42982 .49924 .4362 .50991 .43265 .50403 .42624 Mtetra
.659 .753 .92 r
.50403 .42624 .50991 .43265 .52063 .4291 .51478 .42265 Mtetra
.658 .753 .92 r
.51478 .42265 .52063 .4291 .53139 .42553 .52556 .41906 Mtetra
.52556 .41906 .53139 .42553 .54219 .42196 .53639 .41546 Mtetra
.53639 .41546 .54219 .42196 .55304 .41838 .54726 .41185 Mtetra
.54726 .41185 .55304 .41838 .56392 .41478 .55818 .40823 Mtetra
.55818 .40823 .56392 .41478 .57485 .41118 .56913 .4046 Mtetra
.56913 .4046 .57485 .41118 .58582 .40756 .58014 .40096 Mtetra
.657 .753 .92 r
.58014 .40096 .58582 .40756 .59684 .40394 .59118 .3973 Mtetra
.59118 .3973 .59684 .40394 .6079 .40029 .60227 .39363 Mtetra
.60227 .39363 .6079 .40029 .619 .39664 .6134 .38995 Mtetra
.657 .752 .92 r
.6134 .38995 .619 .39664 .63014 .39297 .62457 .38626 Mtetra
.62457 .38626 .63014 .39297 .64133 .38929 .6358 .38255 Mtetra
.6358 .38255 .64133 .38929 .65257 .3856 .64706 .37882 Mtetra
.64706 .37882 .65257 .3856 .66385 .38189 .65837 .37509 Mtetra
.65837 .37509 .66385 .38189 .67517 .37817 .66973 .37134 Mtetra
.66973 .37134 .67517 .37817 .68654 .37443 .68113 .36758 Mtetra
.68113 .36758 .68654 .37443 .69796 .37068 .69258 .3638 Mtetra
.69258 .3638 .69796 .37068 .70942 .36692 .70407 .36 Mtetra
.70407 .36 .70942 .36692 .72093 .36314 .71561 .3562 Mtetra
.71561 .3562 .72093 .36314 .73248 .35935 .7272 .35237 Mtetra
.7272 .35237 .73248 .35935 .74408 .35554 .73883 .34854 Mtetra
.73883 .34854 .74408 .35554 .75573 .35171 .75051 .34469 Mtetra
.75051 .34469 .75573 .35171 .76743 .34788 .76224 .34082 Mtetra
.76224 .34082 .76743 .34788 .77917 .34402 .77402 .33694 Mtetra
.77402 .33694 .77917 .34402 .79096 .34015 .78585 .33304 Mtetra
.78585 .33304 .79096 .34015 .8028 .33627 .79772 .32912 Mtetra
.79772 .32912 .8028 .33627 .81469 .33237 .80964 .32519 Mtetra
.80964 .32519 .81469 .33237 .82663 .32846 .82161 .32125 Mtetra
.82161 .32125 .82663 .32846 .83861 .32453 .83364 .31729 Mtetra
.478 .592 .889 r
.19389 .51592 .20024 .52464 .20967 .52309 .20311 .51665 Mtetra
.603 .715 .923 r
.20311 .51665 .20967 .52309 .21917 .52129 .21264 .51469 Mtetra
.534 .685 .936 r
.21264 .51469 .21917 .52129 .22619 .548 .2221 .51398 Mtetra
.648 .477 .638 r
.2221 .51398 .22619 .548 .23877 .51214 .23242 .50397 Mtetra
.517 .628 .9 r
.23242 .50397 .23877 .51214 .24839 .51033 .2419 .50389 Mtetra
.613 .721 .922 r
.2419 .50389 .24839 .51033 .25807 .50813 .2516 .50168 Mtetra
.594 .714 .928 r
.2516 .50168 .25807 .50813 .26762 .50826 .26132 .49984 Mtetra
.88 .719 .678 r
.26132 .49984 .26762 .50826 .278 .49802 .27293 .47383 Mtetra
.047 .094 .589 r
.27293 .47383 .278 .49802 .28771 .49698 .28131 .49033 Mtetra
.61 .715 .92 r
.28131 .49033 .28771 .49698 .29757 .49451 .29117 .48815 Mtetra
.626 .731 .922 r
.29117 .48815 .29757 .49451 .30747 .49205 .3011 .48557 Mtetra
.606 .721 .926 r
.3011 .48557 .30747 .49205 .3173 .49143 .31104 .48345 Mtetra
.939 .702 .554 r
.31104 .48345 .3173 .49143 .32775 .48121 .32801 .36805 Mtetra
0 0 .314 r
.32801 .36805 .32775 .48121 .33766 .48042 .33137 .47364 Mtetra
.613 .715 .918 r
.33137 .47364 .33766 .48042 .34773 .47776 .34144 .47137 Mtetra
.636 .737 .921 r
.34144 .47137 .34773 .47776 .35785 .47485 .35158 .46851 Mtetra
.64 .74 .921 r
.35158 .46851 .35785 .47485 .36801 .47193 .36176 .46554 Mtetra
.636 .738 .922 r
.36176 .46554 .36801 .47193 .37821 .4693 .37198 .46267 Mtetra
.6 .719 .928 r
.37198 .46267 .37821 .4693 .38829 .47026 .38221 .4606 Mtetra
.831 .711 .732 r
.38221 .4606 .38829 .47026 .39892 .45874 .39303 .44508 Mtetra
.339 .411 .79 r
.39303 .44508 .39892 .45874 .40919 .45697 .40305 .45023 Mtetra
.627 .726 .918 r
.40305 .45023 .40919 .45697 .41955 .45399 .41342 .44753 Mtetra
.646 .743 .92 r
.41342 .44753 .41955 .45399 .42997 .45075 .42386 .44436 Mtetra
.652 .748 .92 r
.42386 .44436 .42997 .45075 .44042 .44739 .43433 .44102 Mtetra
.655 .75 .92 r
.43433 .44102 .44042 .44739 .45092 .44396 .44486 .43759 Mtetra
.657 .752 .92 r
.44486 .43759 .45092 .44396 .46146 .44047 .45542 .4341 Mtetra
.658 .753 .92 r
.45542 .4341 .46146 .44047 .47204 .43694 .46603 .43056 Mtetra
.659 .754 .92 r
.46603 .43056 .47204 .43694 .48266 .43338 .47668 .42698 Mtetra
.47668 .42698 .48266 .43338 .49333 .42982 .48737 .42339 Mtetra
.48737 .42339 .49333 .42982 .50403 .42624 .4981 .41978 Mtetra
.4981 .41978 .50403 .42624 .51478 .42265 .50887 .41616 Mtetra
.658 .753 .92 r
.50887 .41616 .51478 .42265 .52556 .41906 .51969 .41254 Mtetra
.51969 .41254 .52556 .41906 .53639 .41546 .53055 .40891 Mtetra
.53055 .40891 .53639 .41546 .54726 .41185 .54145 .40528 Mtetra
.54145 .40528 .54726 .41185 .55818 .40823 .55239 .40163 Mtetra
.55239 .40163 .55818 .40823 .56913 .4046 .56338 .39797 Mtetra
.56338 .39797 .56913 .4046 .58014 .40096 .57441 .3943 Mtetra
.57441 .3943 .58014 .40096 .59118 .3973 .58548 .39061 Mtetra
.657 .753 .92 r
.58548 .39061 .59118 .3973 .60227 .39363 .5966 .38692 Mtetra
.5966 .38692 .60227 .39363 .6134 .38995 .60776 .38321 Mtetra
.60776 .38321 .6134 .38995 .62457 .38626 .61896 .37949 Mtetra
.657 .752 .92 r
.61896 .37949 .62457 .38626 .6358 .38255 .63022 .37575 Mtetra
.63022 .37575 .6358 .38255 .64706 .37882 .64151 .372 Mtetra
.64151 .372 .64706 .37882 .65837 .37509 .65285 .36824 Mtetra
.65285 .36824 .65837 .37509 .66973 .37134 .66424 .36446 Mtetra
.66424 .36446 .66973 .37134 .68113 .36758 .67567 .36067 Mtetra
.67567 .36067 .68113 .36758 .69258 .3638 .68715 .35686 Mtetra
.68715 .35686 .69258 .3638 .70407 .36 .69868 .35304 Mtetra
.69868 .35304 .70407 .36 .71561 .3562 .71025 .3492 Mtetra
.71025 .3492 .71561 .3562 .7272 .35237 .72187 .34535 Mtetra
.72187 .34535 .7272 .35237 .73883 .34854 .73354 .34148 Mtetra
.73354 .34148 .73883 .34854 .75051 .34469 .74525 .3376 Mtetra
.74525 .3376 .75051 .34469 .76224 .34082 .75702 .33371 Mtetra
.75702 .33371 .76224 .34082 .77402 .33694 .76883 .32979 Mtetra
.76883 .32979 .77402 .33694 .78585 .33304 .78069 .32587 Mtetra
.78069 .32587 .78585 .33304 .79772 .32912 .7926 .32192 Mtetra
.7926 .32192 .79772 .32912 .80964 .32519 .80456 .31796 Mtetra
.80456 .31796 .80964 .32519 .82161 .32125 .81656 .31399 Mtetra
.81656 .31399 .82161 .32125 .83364 .31729 .82862 .31 Mtetra
.727 .879 .474 r
.18536 .52844 .19389 .51592 .20311 .51665 .19654 .50983 Mtetra
.585 .698 .92 r
.19654 .50983 .20311 .51665 .21264 .51469 .20605 .50823 Mtetra
.595 .714 .927 r
.20605 .50823 .21264 .51469 .2221 .51398 .21563 .50638 Mtetra
.933 .554 .229 r
.21563 .50638 .2221 .51398 .23242 .50397 .22267 .53316 Mtetra
0 0 0 r
.22267 .53316 .23242 .50397 .2419 .50389 .23539 .49711 Mtetra
.597 .705 .919 r
.23539 .49711 .2419 .50389 .2516 .50168 .24508 .49524 Mtetra
.613 .723 .924 r
.24508 .49524 .2516 .50168 .26132 .49984 .25485 .493 Mtetra
.482 .659 .939 r
.25485 .493 .26132 .49984 .27293 .47383 .26447 .49308 Mtetra
.168 0 .155 r
.26447 .49308 .27293 .47383 .28131 .49033 .27494 .48275 Mtetra
.562 .669 .91 r
.27494 .48275 .28131 .49033 .29117 .48815 .28473 .48166 Mtetra
.623 .727 .921 r
.28473 .48166 .29117 .48815 .3011 .48557 .29467 .47914 Mtetra
.622 .73 .924 r
.29467 .47914 .3011 .48557 .31104 .48345 .30466 .47663 Mtetra
.529 .682 .936 r
.30466 .47663 .31104 .48345 .32801 .36805 .31456 .47595 Mtetra
.489 .248 .476 r
.31456 .47595 .32801 .36805 .33137 .47364 .32511 .46565 Mtetra
.551 .654 .904 r
.32511 .46565 .33137 .47364 .34144 .47137 .3351 .46481 Mtetra
.629 .731 .92 r
.3351 .46481 .34144 .47137 .35158 .46851 .34526 .4621 Mtetra
.639 .739 .921 r
.34526 .4621 .35158 .46851 .36176 .46554 .35546 .45913 Mtetra
.639 .74 .922 r
.35546 .45913 .36176 .46554 .37198 .46267 .36571 .45615 Mtetra
.627 .733 .924 r
.36571 .45615 .37198 .46267 .38221 .4606 .37599 .45346 Mtetra
.429 .629 .938 r
.37599 .45346 .38221 .4606 .39303 .44508 .38616 .45438 Mtetra
0 0 0 r
.38616 .45438 .39303 .44508 .40305 .45023 .39689 .44276 Mtetra
.591 .691 .912 r
.39689 .44276 .40305 .45023 .41342 .44753 .40725 .44093 Mtetra
.64 .738 .92 r
.40725 .44093 .41342 .44753 .42386 .44436 .4177 .43789 Mtetra
.649 .746 .92 r
.4177 .43789 .42386 .44436 .43433 .44102 .4282 .43459 Mtetra
.653 .749 .92 r
.4282 .43459 .43433 .44102 .44486 .43759 .43875 .43117 Mtetra
.656 .751 .92 r
.43875 .43117 .44486 .43759 .45542 .4341 .44934 .42767 Mtetra
.657 .753 .92 r
.44934 .42767 .45542 .4341 .46603 .43056 .45998 .42412 Mtetra
.658 .753 .92 r
.45998 .42412 .46603 .43056 .47668 .42698 .47065 .42053 Mtetra
.659 .754 .92 r
.47065 .42053 .47668 .42698 .48737 .42339 .48137 .41691 Mtetra
.48137 .41691 .48737 .42339 .4981 .41978 .49213 .41327 Mtetra
.49213 .41327 .4981 .41978 .50887 .41616 .50293 .40963 Mtetra
.659 .753 .92 r
.50293 .40963 .50887 .41616 .51969 .41254 .51377 .40598 Mtetra
.658 .753 .92 r
.51377 .40598 .51969 .41254 .53055 .40891 .52466 .40232 Mtetra
.52466 .40232 .53055 .40891 .54145 .40528 .53559 .39866 Mtetra
.53559 .39866 .54145 .40528 .55239 .40163 .54656 .39498 Mtetra
.54656 .39498 .55239 .40163 .56338 .39797 .55757 .39129 Mtetra
.55757 .39129 .56338 .39797 .57441 .3943 .56863 .38759 Mtetra
.56863 .38759 .57441 .3943 .58548 .39061 .57974 .38388 Mtetra
.657 .753 .92 r
.57974 .38388 .58548 .39061 .5966 .38692 .59088 .38016 Mtetra
.59088 .38016 .5966 .38692 .60776 .38321 .60208 .37642 Mtetra
.60208 .37642 .60776 .38321 .61896 .37949 .61331 .37267 Mtetra
.657 .752 .92 r
.61331 .37267 .61896 .37949 .63022 .37575 .62459 .3689 Mtetra
.62459 .3689 .63022 .37575 .64151 .372 .63592 .36513 Mtetra
.63592 .36513 .64151 .372 .65285 .36824 .64729 .36133 Mtetra
.64729 .36133 .65285 .36824 .66424 .36446 .65871 .35753 Mtetra
.65871 .35753 .66424 .36446 .67567 .36067 .67018 .35371 Mtetra
.67018 .35371 .67567 .36067 .68715 .35686 .68169 .34987 Mtetra
.68169 .34987 .68715 .35686 .69868 .35304 .69325 .34602 Mtetra
.69325 .34602 .69868 .35304 .71025 .3492 .70485 .34215 Mtetra
.70485 .34215 .71025 .3492 .72187 .34535 .71651 .33827 Mtetra
.71651 .33827 .72187 .34535 .73354 .34148 .72821 .33438 Mtetra
.72821 .33438 .73354 .34148 .74525 .3376 .73996 .33047 Mtetra
.73996 .33047 .74525 .3376 .75702 .33371 .75175 .32654 Mtetra
.75175 .32654 .75702 .33371 .76883 .32979 .7636 .3226 Mtetra
.7636 .3226 .76883 .32979 .78069 .32587 .77549 .31864 Mtetra
.77549 .31864 .78069 .32587 .7926 .32192 .78744 .31467 Mtetra
.78744 .31467 .7926 .32192 .80456 .31796 .79943 .31068 Mtetra
.79943 .31068 .80456 .31796 .81656 .31399 .81147 .30667 Mtetra
.81147 .30667 .81656 .31399 .82862 .31 .82357 .30265 Mtetra
.719 .586 .706 r
.17976 .51134 .18536 .52844 .19654 .50983 .19013 .50099 Mtetra
.478 .592 .889 r
.19013 .50099 .19654 .50983 .20605 .50823 .19942 .50169 Mtetra
.603 .715 .924 r
.19942 .50169 .20605 .50823 .21563 .50638 .20903 .49967 Mtetra
.534 .685 .936 r
.20903 .49967 .21563 .50638 .22267 .53316 .21856 .49892 Mtetra
.648 .476 .637 r
.21856 .49892 .22267 .53316 .23539 .49711 .22897 .48883 Mtetra
.517 .628 .9 r
.22897 .48883 .23539 .49711 .24508 .49524 .23852 .4887 Mtetra
.613 .721 .922 r
.23852 .4887 .24508 .49524 .25485 .493 .24831 .48643 Mtetra
.594 .714 .928 r
.24831 .48643 .25485 .493 .26447 .49308 .2581 .48454 Mtetra
.881 .72 .677 r
.2581 .48454 .26447 .49308 .27494 .48275 .26983 .45838 Mtetra
.042 .091 .587 r
.26983 .45838 .27494 .48275 .28473 .48166 .27827 .4749 Mtetra
.61 .715 .92 r
.27827 .4749 .28473 .48166 .29467 .47914 .2882 .47267 Mtetra
.626 .731 .922 r
.2882 .47267 .29467 .47914 .30466 .47663 .29821 .47004 Mtetra
.606 .721 .926 r
.29821 .47004 .30466 .47663 .31456 .47595 .30824 .46786 Mtetra
.94 .703 .552 r
.30824 .46786 .31456 .47595 .32511 .46565 .32545 .35197 Mtetra
0 0 .308 r
.32545 .35197 .32511 .46565 .3351 .46481 .32875 .45792 Mtetra
.613 .715 .918 r
.32875 .45792 .3351 .46481 .34526 .4621 .3389 .45559 Mtetra
.636 .737 .921 r
.3389 .45559 .34526 .4621 .35546 .45913 .34912 .45267 Mtetra
.64 .74 .921 r
.34912 .45267 .35546 .45913 .36571 .45615 .3594 .44964 Mtetra
.636 .738 .922 r
.3594 .44964 .36571 .45615 .37599 .45346 .36971 .44672 Mtetra
.6 .719 .928 r
.36971 .44672 .37599 .45346 .38616 .45438 .38002 .44459 Mtetra
.831 .712 .732 r
.38002 .44459 .38616 .45438 .39689 .44276 .39095 .42896 Mtetra
.337 .411 .79 r
.39095 .42896 .39689 .44276 .40725 .44093 .40104 .43407 Mtetra
.627 .726 .918 r
.40104 .43407 .40725 .44093 .4177 .43789 .41151 .43132 Mtetra
.646 .743 .92 r
.41151 .43132 .4177 .43789 .4282 .43459 .42203 .42809 Mtetra
.652 .748 .92 r
.42203 .42809 .4282 .43459 .43875 .43117 .4326 .42469 Mtetra
.655 .75 .92 r
.4326 .42469 .43875 .43117 .44934 .42767 .44322 .42119 Mtetra
.657 .752 .92 r
.44322 .42119 .44934 .42767 .45998 .42412 .45388 .41763 Mtetra
.658 .753 .92 r
.45388 .41763 .45998 .42412 .47065 .42053 .46458 .41403 Mtetra
.659 .754 .92 r
.46458 .41403 .47065 .42053 .48137 .41691 .47533 .41038 Mtetra
.47533 .41038 .48137 .41691 .49213 .41327 .48611 .40672 Mtetra
.48611 .40672 .49213 .41327 .50293 .40963 .49694 .40305 Mtetra
.49694 .40305 .50293 .40963 .51377 .40598 .50781 .39937 Mtetra
.658 .753 .92 r
.50781 .39937 .51377 .40598 .52466 .40232 .51873 .39568 Mtetra
.51873 .39568 .52466 .40232 .53559 .39866 .52969 .39199 Mtetra
.52969 .39199 .53559 .39866 .54656 .39498 .54069 .38828 Mtetra
.54069 .38828 .54656 .39498 .55757 .39129 .55173 .38456 Mtetra
.55173 .38456 .55757 .39129 .56863 .38759 .56282 .38084 Mtetra
.56282 .38084 .56863 .38759 .57974 .38388 .57395 .3771 Mtetra
.57395 .3771 .57974 .38388 .59088 .38016 .58513 .37334 Mtetra
.657 .753 .92 r
.58513 .37334 .59088 .38016 .60208 .37642 .59635 .36958 Mtetra
.59635 .36958 .60208 .37642 .61331 .37267 .60762 .3658 Mtetra
.60762 .3658 .61331 .37267 .62459 .3689 .61893 .36201 Mtetra
.657 .752 .92 r
.61893 .36201 .62459 .3689 .63592 .36513 .63029 .3582 Mtetra
.63029 .3582 .63592 .36513 .64729 .36133 .64169 .35438 Mtetra
.64169 .35438 .64729 .36133 .65871 .35753 .65314 .35054 Mtetra
.65314 .35054 .65871 .35753 .67018 .35371 .66464 .34669 Mtetra
.66464 .34669 .67018 .35371 .68169 .34987 .67618 .34283 Mtetra
.67618 .34283 .68169 .34987 .69325 .34602 .68777 .33895 Mtetra
.68777 .33895 .69325 .34602 .70485 .34215 .69941 .33505 Mtetra
.69941 .33505 .70485 .34215 .71651 .33827 .7111 .33114 Mtetra
.7111 .33114 .71651 .33827 .72821 .33438 .72283 .32722 Mtetra
.72283 .32722 .72821 .33438 .73996 .33047 .73462 .32328 Mtetra
.73462 .32328 .73996 .33047 .75175 .32654 .74645 .31932 Mtetra
.74645 .31932 .75175 .32654 .7636 .3226 .75833 .31535 Mtetra
.75833 .31535 .7636 .3226 .77549 .31864 .77026 .31136 Mtetra
.77026 .31136 .77549 .31864 .78744 .31467 .78224 .30735 Mtetra
.78224 .30735 .78744 .31467 .79943 .31068 .79426 .30333 Mtetra
.79426 .30333 .79943 .31068 .81147 .30667 .80634 .29929 Mtetra
.80634 .29929 .81147 .30667 .82357 .30265 .81847 .29524 Mtetra
.544 .061 0 r
.17313 .50394 .17976 .51134 .19013 .50099 .18149 .51349 Mtetra
.735 .885 .483 r
.18149 .51349 .19013 .50099 .19942 .50169 .19279 .49475 Mtetra
.585 .698 .92 r
.19279 .49475 .19942 .50169 .20903 .49967 .20237 .49311 Mtetra
.595 .714 .927 r
.20237 .49311 .20903 .49967 .21856 .49892 .21202 .49121 Mtetra
.932 .552 .223 r
.21202 .49121 .21856 .49892 .22897 .48883 .21908 .51806 Mtetra
0 0 0 r
.21908 .51806 .22897 .48883 .23852 .4887 .23195 .48181 Mtetra
.597 .705 .92 r
.23195 .48181 .23852 .4887 .24831 .48643 .24172 .47989 Mtetra
.613 .723 .924 r
.24172 .47989 .24831 .48643 .2581 .48454 .25156 .47759 Mtetra
.483 .659 .939 r
.25156 .47759 .2581 .48454 .26983 .45838 .26126 .47763 Mtetra
.156 0 .143 r
.26126 .47763 .26983 .45838 .27827 .4749 .27183 .46721 Mtetra
.562 .669 .91 r
.27183 .46721 .27827 .4749 .2882 .47267 .2817 .46607 Mtetra
.623 .727 .921 r
.2817 .46607 .2882 .47267 .29821 .47004 .29172 .46349 Mtetra
.622 .73 .924 r
.29172 .46349 .29821 .47004 .30824 .46786 .30179 .46092 Mtetra
.529 .682 .936 r
.30179 .46092 .30824 .46786 .32545 .35197 .31178 .4602 Mtetra
.485 .243 .472 r
.31178 .4602 .32545 .35197 .32875 .45792 .32242 .44981 Mtetra
.551 .655 .904 r
.32242 .44981 .32875 .45792 .3389 .45559 .3325 .44892 Mtetra
.629 .731 .92 r
.3325 .44892 .3389 .45559 .34912 .45267 .34274 .44614 Mtetra
.639 .739 .921 r
.34274 .44614 .34912 .45267 .3594 .44964 .35303 .44312 Mtetra
.639 .74 .922 r
.35303 .44312 .3594 .44964 .36971 .44672 .36337 .44008 Mtetra
.627 .733 .924 r
.36337 .44008 .36971 .44672 .38002 .44459 .37374 .43733 Mtetra
.43 .629 .937 r
.37374 .43733 .38002 .44459 .39095 .42896 .38399 .4382 Mtetra
0 0 0 r
.38399 .4382 .39095 .42896 .40104 .43407 .39482 .42649 Mtetra
.591 .691 .912 r
.39482 .42649 .40104 .43407 .41151 .43132 .40527 .4246 Mtetra
.64 .738 .92 r
.40527 .4246 .41151 .43132 .42203 .42809 .41581 .4215 Mtetra
.649 .746 .92 r
.41581 .4215 .42203 .42809 .4326 .42469 .42641 .41814 Mtetra
.653 .749 .92 r
.42641 .41814 .4326 .42469 .44322 .42119 .43705 .41465 Mtetra
.656 .751 .92 r
.43705 .41465 .44322 .42119 .45388 .41763 .44774 .41109 Mtetra
.657 .753 .92 r
.44774 .41109 .45388 .41763 .46458 .41403 .45847 .40747 Mtetra
.658 .753 .92 r
.45847 .40747 .46458 .41403 .47533 .41038 .46924 .40381 Mtetra
.659 .754 .92 r
.46924 .40381 .47533 .41038 .48611 .40672 .48006 .40013 Mtetra
.48006 .40013 .48611 .40672 .49694 .40305 .49091 .39643 Mtetra
.49091 .39643 .49694 .40305 .50781 .39937 .50181 .39271 Mtetra
.659 .753 .92 r
.50181 .39271 .50781 .39937 .51873 .39568 .51275 .389 Mtetra
.658 .753 .92 r
.51275 .389 .51873 .39568 .52969 .39199 .52374 .38527 Mtetra
.52374 .38527 .52969 .39199 .54069 .38828 .53477 .38153 Mtetra
.53477 .38153 .54069 .38828 .55173 .38456 .54584 .37779 Mtetra
.54584 .37779 .55173 .38456 .56282 .38084 .55696 .37403 Mtetra
.55696 .37403 .56282 .38084 .57395 .3771 .56812 .37026 Mtetra
.56812 .37026 .57395 .3771 .58513 .37334 .57933 .36648 Mtetra
.657 .753 .92 r
.57933 .36648 .58513 .37334 .59635 .36958 .59058 .36269 Mtetra
.59058 .36269 .59635 .36958 .60762 .3658 .60188 .35888 Mtetra
.60188 .35888 .60762 .3658 .61893 .36201 .61322 .35506 Mtetra
.657 .752 .92 r
.61322 .35506 .61893 .36201 .63029 .3582 .62461 .35122 Mtetra
.62461 .35122 .63029 .3582 .64169 .35438 .63605 .34737 Mtetra
.63605 .34737 .64169 .35438 .65314 .35054 .64753 .34351 Mtetra
.64753 .34351 .65314 .35054 .66464 .34669 .65906 .33963 Mtetra
.65906 .33963 .66464 .34669 .67618 .34283 .67064 .33573 Mtetra
.67064 .33573 .67618 .34283 .68777 .33895 .68226 .33182 Mtetra
.68226 .33182 .68777 .33895 .69941 .33505 .69393 .3279 Mtetra
.69393 .3279 .69941 .33505 .7111 .33114 .70565 .32396 Mtetra
.70565 .32396 .7111 .33114 .72283 .32722 .71742 .32 Mtetra
.71742 .32 .72283 .32722 .73462 .32328 .72924 .31603 Mtetra
.72924 .31603 .73462 .32328 .74645 .31932 .7411 .31204 Mtetra
.7411 .31204 .74645 .31932 .75833 .31535 .75302 .30804 Mtetra
.75302 .30804 .75833 .31535 .77026 .31136 .76498 .30402 Mtetra
.76498 .30402 .77026 .31136 .78224 .30735 .777 .29998 Mtetra
.777 .29998 .78224 .30735 .79426 .30333 .78906 .29593 Mtetra
.78906 .29593 .79426 .30333 .80634 .29929 .80117 .29186 Mtetra
.80117 .29186 .80634 .29929 .81847 .29524 .81334 .28778 Mtetra
.544 .69 .934 r
.16639 .4972 .17313 .50394 .18149 .51349 .17584 .49624 Mtetra
.719 .586 .706 r
.17584 .49624 .18149 .51349 .19279 .49475 .18631 .4858 Mtetra
.478 .592 .889 r
.18631 .4858 .19279 .49475 .20237 .49311 .19567 .48646 Mtetra
.603 .715 .924 r
.19567 .48646 .20237 .49311 .21202 .49121 .20535 .48439 Mtetra
.534 .685 .936 r
.20535 .48439 .21202 .49121 .21908 .51806 .21496 .48359 Mtetra
.647 .475 .636 r
.21496 .48359 .21908 .51806 .23195 .48181 .22546 .47341 Mtetra
.517 .628 .9 r
.22546 .47341 .23195 .48181 .24172 .47989 .23509 .47324 Mtetra
.613 .721 .922 r
.23509 .47324 .24172 .47989 .25156 .47759 .24495 .47091 Mtetra
.594 .714 .928 r
.24495 .47091 .25156 .47759 .26126 .47763 .25483 .46897 Mtetra
.882 .72 .677 r
.25483 .46897 .26126 .47763 .27183 .46721 .26668 .44266 Mtetra
.037 .087 .585 r
.26668 .44266 .27183 .46721 .2817 .46607 .27516 .4592 Mtetra
.61 .715 .92 r
.27516 .4592 .2817 .46607 .29172 .46349 .28518 .45691 Mtetra
.626 .731 .922 r
.28518 .45691 .29172 .46349 .30179 .46092 .29528 .45422 Mtetra
.606 .721 .926 r
.29528 .45422 .30179 .46092 .31178 .4602 .30538 .45198 Mtetra
.941 .703 .551 r
.30538 .45198 .31178 .4602 .32242 .44981 .32284 .33559 Mtetra
0 0 .303 r
.32284 .33559 .32242 .44981 .3325 .44892 .32607 .44191 Mtetra
.612 .715 .918 r
.32607 .44191 .3325 .44892 .34274 .44614 .33631 .43952 Mtetra
.636 .737 .921 r
.33631 .43952 .34274 .44614 .35303 .44312 .34662 .43654 Mtetra
.64 .74 .921 r
.34662 .43654 .35303 .44312 .36337 .44008 .35699 .43346 Mtetra
.636 .738 .922 r
.35699 .43346 .36337 .44008 .37374 .43733 .36739 .43047 Mtetra
.6 .719 .928 r
.36739 .43047 .37374 .43733 .38399 .4382 .37779 .42828 Mtetra
.832 .713 .733 r
.37779 .42828 .38399 .4382 .39482 .42649 .38882 .41254 Mtetra
.336 .41 .79 r
.38882 .41254 .39482 .42649 .40527 .4246 .399 .41762 Mtetra
.627 .726 .918 r
.399 .41762 .40527 .4246 .41581 .4215 .40956 .41481 Mtetra
.646 .743 .92 r
.40956 .41481 .41581 .4215 .42641 .41814 .42017 .41151 Mtetra
.652 .748 .92 r
.42017 .41151 .42641 .41814 .43705 .41465 .43084 .40805 Mtetra
.655 .75 .92 r
.43084 .40805 .43705 .41465 .44774 .41109 .44155 .40449 Mtetra
.657 .752 .92 r
.44155 .40449 .44774 .41109 .45847 .40747 .45231 .40086 Mtetra
.658 .753 .92 r
.45231 .40086 .45847 .40747 .46924 .40381 .46311 .39719 Mtetra
.659 .754 .92 r
.46311 .39719 .46924 .40381 .48006 .40013 .47395 .39348 Mtetra
.47395 .39348 .48006 .40013 .49091 .39643 .48484 .38975 Mtetra
.48484 .38975 .49091 .39643 .50181 .39271 .49576 .38601 Mtetra
.49576 .38601 .50181 .39271 .51275 .389 .50674 .38226 Mtetra
.658 .753 .92 r
.50674 .38226 .51275 .389 .52374 .38527 .51775 .3785 Mtetra
.51775 .3785 .52374 .38527 .53477 .38153 .52881 .37474 Mtetra
.52881 .37474 .53477 .38153 .54584 .37779 .53991 .37096 Mtetra
.53991 .37096 .54584 .37779 .55696 .37403 .55106 .36718 Mtetra
.55106 .36718 .55696 .37403 .56812 .37026 .56225 .36338 Mtetra
.56225 .36338 .56812 .37026 .57933 .36648 .57349 .35957 Mtetra
.57349 .35957 .57933 .36648 .59058 .36269 .58477 .35574 Mtetra
.657 .753 .92 r
.58477 .35574 .59058 .36269 .60188 .35888 .5961 .35191 Mtetra
.5961 .35191 .60188 .35888 .61322 .35506 .60747 .34806 Mtetra
.60747 .34806 .61322 .35506 .62461 .35122 .6189 .34419 Mtetra
.657 .752 .92 r
.6189 .34419 .62461 .35122 .63605 .34737 .63036 .34031 Mtetra
.63036 .34031 .63605 .34737 .64753 .34351 .64188 .33642 Mtetra
.64188 .33642 .64753 .34351 .65906 .33963 .65344 .33251 Mtetra
.65344 .33251 .65906 .33963 .67064 .33573 .66505 .32858 Mtetra
.66505 .32858 .67064 .33573 .68226 .33182 .6767 .32464 Mtetra
.6767 .32464 .68226 .33182 .69393 .3279 .68841 .32069 Mtetra
.68841 .32069 .69393 .3279 .70565 .32396 .70016 .31672 Mtetra
.70016 .31672 .70565 .32396 .71742 .32 .71196 .31273 Mtetra
.71196 .31273 .71742 .32 .72924 .31603 .72381 .30873 Mtetra
.72381 .30873 .72924 .31603 .7411 .31204 .73571 .30471 Mtetra
.73571 .30471 .7411 .31204 .75302 .30804 .74766 .30068 Mtetra
.74766 .30068 .75302 .30804 .76498 .30402 .75966 .29662 Mtetra
.75966 .29662 .76498 .30402 .777 .29998 .77171 .29256 Mtetra
.77171 .29256 .777 .29998 .78906 .29593 .78381 .28847 Mtetra
.78381 .28847 .78906 .29593 .80117 .29186 .79597 .28437 Mtetra
.79597 .28437 .80117 .29186 .81334 .28778 .80817 .28026 Mtetra
.59 .709 .926 r
.15959 .49052 .16639 .4972 .17584 .49624 .16914 .48872 Mtetra
.537 .055 0 r
.16914 .48872 .17584 .49624 .18631 .4858 .17755 .49828 Mtetra
.743 .89 .491 r
.17755 .49828 .18631 .4858 .19567 .48646 .18896 .47941 Mtetra
.585 .698 .92 r
.18896 .47941 .19567 .48646 .20535 .48439 .19862 .47771 Mtetra
.595 .714 .927 r
.19862 .47771 .20535 .48439 .21496 .48359 .20835 .47576 Mtetra
.931 .55 .217 r
.20835 .47576 .21496 .48359 .22546 .47341 .21543 .50269 Mtetra
0 0 0 r
.21543 .50269 .22546 .47341 .23509 .47324 .22844 .46623 Mtetra
.596 .705 .92 r
.22844 .46623 .23509 .47324 .24495 .47091 .23829 .46426 Mtetra
.613 .723 .924 r
.23829 .46426 .24495 .47091 .25483 .46897 .24822 .46191 Mtetra
.483 .659 .939 r
.24822 .46191 .25483 .46897 .26668 .44266 .258 .4619 Mtetra
.144 0 .131 r
.258 .4619 .26668 .44266 .27516 .4592 .26866 .45139 Mtetra
.561 .669 .91 r
.26866 .45139 .27516 .4592 .28518 .45691 .27861 .4502 Mtetra
.623 .727 .921 r
.27861 .4502 .28518 .45691 .29528 .45422 .28872 .44756 Mtetra
.622 .73 .924 r
.28872 .44756 .29528 .45422 .30538 .45198 .29887 .44493 Mtetra
.529 .682 .936 r
.29887 .44493 .30538 .45198 .32284 .33559 .30894 .44416 Mtetra
.481 .238 .467 r
.30894 .44416 .32284 .33559 .32607 .44191 .31968 .43368 Mtetra
.551 .655 .904 r
.31968 .43368 .32607 .44191 .33631 .43952 .32984 .43274 Mtetra
.629 .731 .92 r
.32984 .43274 .33631 .43952 .34662 .43654 .34017 .4299 Mtetra
.639 .739 .921 r
.34017 .4299 .34662 .43654 .35699 .43346 .35056 .42681 Mtetra
.639 .74 .922 r
.35056 .42681 .35699 .43346 .36739 .43047 .36098 .42371 Mtetra
.627 .733 .924 r
.36098 .42371 .36739 .43047 .37779 .42828 .37144 .4209 Mtetra
.431 .629 .937 r
.37144 .4209 .37779 .42828 .38882 .41254 .38178 .42173 Mtetra
0 0 0 r
.38178 .42173 .38882 .41254 .399 .41762 .39271 .40991 Mtetra
.591 .691 .912 r
.39271 .40991 .399 .41762 .40956 .41481 .40325 .40797 Mtetra
.64 .738 .92 r
.40325 .40797 .40956 .41481 .42017 .41151 .41389 .4048 Mtetra
.649 .746 .92 r
.41389 .4048 .42017 .41151 .43084 .40805 .42458 .40137 Mtetra
.653 .749 .92 r
.42458 .40137 .43084 .40805 .44155 .40449 .43532 .39782 Mtetra
.656 .751 .92 r
.43532 .39782 .44155 .40449 .45231 .40086 .4461 .39419 Mtetra
.657 .753 .92 r
.4461 .39419 .45231 .40086 .46311 .39719 .45693 .39051 Mtetra
.658 .753 .92 r
.45693 .39051 .46311 .39719 .47395 .39348 .4678 .38678 Mtetra
.659 .754 .92 r
.4678 .38678 .47395 .39348 .48484 .38975 .47871 .38303 Mtetra
.47871 .38303 .48484 .38975 .49576 .38601 .48967 .37926 Mtetra
.48967 .37926 .49576 .38601 .50674 .38226 .50067 .37548 Mtetra
.659 .753 .92 r
.50067 .37548 .50674 .38226 .51775 .3785 .51171 .37169 Mtetra
.658 .753 .92 r
.51171 .37169 .51775 .3785 .52881 .37474 .5228 .36789 Mtetra
.5228 .36789 .52881 .37474 .53991 .37096 .53394 .36409 Mtetra
.53394 .36409 .53991 .37096 .55106 .36718 .54511 .36027 Mtetra
.54511 .36027 .55106 .36718 .56225 .36338 .55633 .35644 Mtetra
.55633 .35644 .56225 .36338 .57349 .35957 .5676 .3526 Mtetra
.5676 .3526 .57349 .35957 .58477 .35574 .57892 .34875 Mtetra
.657 .753 .92 r
.57892 .34875 .58477 .35574 .5961 .35191 .59028 .34488 Mtetra
.59028 .34488 .5961 .35191 .60747 .34806 .60168 .341 Mtetra
.60168 .341 .60747 .34806 .6189 .34419 .61313 .33711 Mtetra
.657 .752 .92 r
.61313 .33711 .6189 .34419 .63036 .34031 .62463 .3332 Mtetra
.62463 .3332 .63036 .34031 .64188 .33642 .63618 .32927 Mtetra
.63618 .32927 .64188 .33642 .65344 .33251 .64777 .32533 Mtetra
.64777 .32533 .65344 .33251 .66505 .32858 .65941 .32138 Mtetra
.65941 .32138 .66505 .32858 .6767 .32464 .6711 .31741 Mtetra
.6711 .31741 .6767 .32464 .68841 .32069 .68284 .31342 Mtetra
.68284 .31342 .68841 .32069 .70016 .31672 .69463 .30942 Mtetra
.69463 .30942 .70016 .31672 .71196 .31273 .70647 .3054 Mtetra
.70647 .3054 .71196 .31273 .72381 .30873 .71835 .30137 Mtetra
.71835 .30137 .72381 .30873 .73571 .30471 .73029 .29732 Mtetra
.73029 .29732 .73571 .30471 .74766 .30068 .74227 .29325 Mtetra
.74227 .29325 .74766 .30068 .75966 .29662 .75431 .28917 Mtetra
.75431 .28917 .75966 .29662 .77171 .29256 .76639 .28507 Mtetra
.76639 .28507 .77171 .29256 .78381 .28847 .77853 .28096 Mtetra
.77853 .28096 .78381 .28847 .79597 .28437 .79072 .27683 Mtetra
.79072 .27683 .79597 .28437 .80817 .28026 .80295 .27268 Mtetra
.586 .701 .922 r
.15277 .4836 .15959 .49052 .16914 .48872 .16232 .48188 Mtetra
.545 .69 .934 r
.16232 .48188 .16914 .48872 .17755 .49828 .17185 .48087 Mtetra
.719 .586 .706 r
.17185 .48087 .17755 .49828 .18896 .47941 .18241 .47034 Mtetra
.477 .592 .89 r
.18241 .47034 .18896 .47941 .19862 .47771 .19184 .47095 Mtetra
.603 .715 .924 r
.19184 .47095 .19862 .47771 .20835 .47576 .2016 .46883 Mtetra
.534 .685 .935 r
.2016 .46883 .20835 .47576 .21543 .50269 .21129 .46798 Mtetra
.646 .473 .636 r
.21129 .46798 .21543 .50269 .22844 .46623 .22189 .45771 Mtetra
.517 .628 .9 r
.22189 .45771 .22844 .46623 .23829 .46426 .23159 .4575 Mtetra
.613 .721 .922 r
.23159 .4575 .23829 .46426 .24822 .46191 .24154 .45512 Mtetra
.594 .714 .928 r
.24154 .45512 .24822 .46191 .258 .4619 .25149 .45312 Mtetra
.883 .721 .676 r
.25149 .45312 .258 .4619 .26866 .45139 .26347 .42665 Mtetra
.032 .083 .583 r
.26347 .42665 .26866 .45139 .27861 .4502 .27201 .44321 Mtetra
.61 .715 .92 r
.27201 .44321 .27861 .4502 .28872 .44756 .28211 .44086 Mtetra
.626 .731 .922 r
.28211 .44086 .28872 .44756 .29887 .44493 .29229 .43812 Mtetra
.606 .721 .926 r
.29229 .43812 .29887 .44493 .30894 .44416 .30248 .43582 Mtetra
.942 .704 .549 r
.30248 .43582 .30894 .44416 .31968 .43368 .32019 .31893 Mtetra
0 0 .297 r
.32019 .31893 .31968 .43368 .32984 .43274 .32335 .42561 Mtetra
.612 .715 .918 r
.32335 .42561 .32984 .43274 .34017 .4299 .33368 .42316 Mtetra
.636 .737 .921 r
.33368 .42316 .34017 .4299 .35056 .42681 .34408 .42012 Mtetra
.64 .74 .921 r
.34408 .42012 .35056 .42681 .36098 .42371 .35453 .41697 Mtetra
.636 .738 .922 r
.35453 .41697 .36098 .42371 .37144 .4209 .36502 .41392 Mtetra
.6 .719 .927 r
.36502 .41392 .37144 .4209 .38178 .42173 .37552 .41167 Mtetra
.833 .714 .733 r
.37552 .41167 .38178 .42173 .39271 .40991 .38665 .39581 Mtetra
.334 .409 .79 r
.38665 .39581 .39271 .40991 .40325 .40797 .39692 .40087 Mtetra
.627 .726 .918 r
.39692 .40087 .40325 .40797 .41389 .4048 .40757 .39799 Mtetra
.646 .743 .92 r
.40757 .39799 .41389 .4048 .42458 .40137 .41828 .39463 Mtetra
.652 .748 .92 r
.41828 .39463 .42458 .40137 .43532 .39782 .42905 .39109 Mtetra
.655 .75 .92 r
.42905 .39109 .43532 .39782 .4461 .39419 .43985 .38747 Mtetra
.657 .752 .92 r
.43985 .38747 .4461 .39419 .45693 .39051 .45071 .38377 Mtetra
.658 .753 .92 r
.45071 .38377 .45693 .39051 .4678 .38678 .46161 .38003 Mtetra
.659 .754 .92 r
.46161 .38003 .4678 .38678 .47871 .38303 .47255 .37625 Mtetra
.47255 .37625 .47871 .38303 .48967 .37926 .48353 .37246 Mtetra
.48353 .37246 .48967 .37926 .50067 .37548 .49456 .36865 Mtetra
.49456 .36865 .50067 .37548 .51171 .37169 .50563 .36483 Mtetra
.658 .753 .92 r
.50563 .36483 .51171 .37169 .5228 .36789 .51675 .361 Mtetra
.51675 .361 .5228 .36789 .53394 .36409 .52791 .35716 Mtetra
.52791 .35716 .53394 .36409 .54511 .36027 .53912 .35332 Mtetra
.53912 .35332 .54511 .36027 .55633 .35644 .55037 .34946 Mtetra
.55037 .34946 .55633 .35644 .5676 .3526 .56167 .34559 Mtetra
.56167 .34559 .5676 .3526 .57892 .34875 .57302 .3417 Mtetra
.57302 .3417 .57892 .34875 .59028 .34488 .58441 .33781 Mtetra
.657 .753 .92 r
.58441 .33781 .59028 .34488 .60168 .341 .59584 .33389 Mtetra
.59584 .33389 .60168 .341 .61313 .33711 .60733 .32997 Mtetra
.60733 .32997 .61313 .33711 .62463 .3332 .61886 .32603 Mtetra
.657 .752 .92 r
.61886 .32603 .62463 .3332 .63618 .32927 .63044 .32207 Mtetra
.63044 .32207 .63618 .32927 .64777 .32533 .64206 .3181 Mtetra
.64206 .3181 .64777 .32533 .65941 .32138 .65374 .31412 Mtetra
.65374 .31412 .65941 .32138 .6711 .31741 .66546 .31012 Mtetra
.66546 .31012 .6711 .31741 .68284 .31342 .67723 .3061 Mtetra
.67723 .3061 .68284 .31342 .69463 .30942 .68905 .30207 Mtetra
.68905 .30207 .69463 .30942 .70647 .3054 .70092 .29802 Mtetra
.70092 .29802 .70647 .3054 .71835 .30137 .71284 .29395 Mtetra
.71284 .29395 .71835 .30137 .73029 .29732 .72481 .28987 Mtetra
.72481 .28987 .73029 .29732 .74227 .29325 .73683 .28578 Mtetra
.73683 .28578 .74227 .29325 .75431 .28917 .7489 .28166 Mtetra
.7489 .28166 .75431 .28917 .76639 .28507 .76103 .27753 Mtetra
.76103 .27753 .76639 .28507 .77853 .28096 .7732 .27338 Mtetra
.7732 .27338 .77853 .28096 .79072 .27683 .78542 .26922 Mtetra
.78542 .26922 .79072 .27683 .80295 .27268 .7977 .26504 Mtetra
.523 .641 .908 r
.14603 .4755 .15277 .4836 .16232 .48188 .15545 .47509 Mtetra
.59 .709 .926 r
.15545 .47509 .16232 .48188 .17185 .48087 .16508 .47324 Mtetra
.53 .049 0 r
.16508 .47324 .17185 .48087 .18241 .47034 .17354 .48278 Mtetra
.751 .895 .5 r
.17354 .48278 .18241 .47034 .19184 .47095 .18506 .46379 Mtetra
.585 .698 .92 r
.18506 .46379 .19184 .47095 .2016 .46883 .1948 .46204 Mtetra
.595 .714 .927 r
.1948 .46204 .2016 .46883 .21129 .46798 .20461 .46004 Mtetra
.93 .547 .211 r
.20461 .46004 .21129 .46798 .22189 .45771 .21172 .48703 Mtetra
0 0 0 r
.21172 .48703 .22189 .45771 .23159 .4575 .22488 .45038 Mtetra
.596 .705 .92 r
.22488 .45038 .23159 .4575 .24154 .45512 .23481 .44835 Mtetra
.613 .723 .924 r
.23481 .44835 .24154 .45512 .25149 .45312 .24481 .44594 Mtetra
.484 .659 .939 r
.24481 .44594 .25149 .45312 .26347 .42665 .25467 .44588 Mtetra
.132 0 .118 r
.25467 .44588 .26347 .42665 .27201 .44321 .26543 .43528 Mtetra
.561 .669 .91 r
.26543 .43528 .27201 .44321 .28211 .44086 .27546 .43404 Mtetra
.623 .727 .921 r
.27546 .43404 .28211 .44086 .29229 .43812 .28566 .43134 Mtetra
.622 .729 .923 r
.28566 .43134 .29229 .43812 .30248 .43582 .2959 .42865 Mtetra
.53 .682 .936 r
.2959 .42865 .30248 .43582 .32019 .31893 .30605 .42783 Mtetra
.477 .232 .463 r
.30605 .42783 .32019 .31893 .32335 .42561 .31689 .41725 Mtetra
.55 .655 .904 r
.31689 .41725 .32335 .42561 .33368 .42316 .32714 .41625 Mtetra
.629 .731 .92 r
.32714 .41625 .33368 .42316 .34408 .42012 .33756 .41336 Mtetra
.639 .739 .921 r
.33756 .41336 .34408 .42012 .35453 .41697 .34803 .4102 Mtetra
.639 .74 .922 r
.34803 .4102 .35453 .41697 .36502 .41392 .35855 .40704 Mtetra
.627 .733 .924 r
.35855 .40704 .36502 .41392 .37552 .41167 .3691 .40417 Mtetra
.432 .629 .937 r
.3691 .40417 .37552 .41167 .38665 .39581 .37953 .40494 Mtetra
0 0 0 r
.37953 .40494 .38665 .39581 .39692 .40087 .39056 .39303 Mtetra
.591 .691 .912 r
.39056 .39303 .39692 .40087 .40757 .39799 .4012 .39103 Mtetra
.64 .738 .92 r
.4012 .39103 .40757 .39799 .41828 .39463 .41194 .38779 Mtetra
.649 .746 .92 r
.41194 .38779 .41828 .39463 .42905 .39109 .42272 .3843 Mtetra
.653 .749 .92 r
.42272 .3843 .42905 .39109 .43985 .38747 .43356 .38068 Mtetra
.656 .751 .92 r
.43356 .38068 .43985 .38747 .45071 .38377 .44444 .37698 Mtetra
.657 .753 .92 r
.44444 .37698 .45071 .38377 .46161 .38003 .45536 .37322 Mtetra
.658 .753 .92 r
.45536 .37322 .46161 .38003 .47255 .37625 .46633 .36943 Mtetra
.659 .754 .92 r
.46633 .36943 .47255 .37625 .48353 .37246 .47735 .3656 Mtetra
.47735 .3656 .48353 .37246 .49456 .36865 .48841 .36176 Mtetra
.48841 .36176 .49456 .36865 .50563 .36483 .49951 .35791 Mtetra
.659 .753 .92 r
.49951 .35791 .50563 .36483 .51675 .361 .51066 .35405 Mtetra
.658 .753 .92 r
.51066 .35405 .51675 .361 .52791 .35716 .52185 .35018 Mtetra
.52185 .35018 .52791 .35716 .53912 .35332 .53309 .34631 Mtetra
.53309 .34631 .53912 .35332 .55037 .34946 .54437 .34242 Mtetra
.54437 .34242 .55037 .34946 .56167 .34559 .5557 .33852 Mtetra
.5557 .33852 .56167 .34559 .57302 .3417 .56707 .3346 Mtetra
.56707 .3346 .57302 .3417 .58441 .33781 .57849 .33067 Mtetra
.657 .753 .92 r
.57849 .33067 .58441 .33781 .59584 .33389 .58996 .32673 Mtetra
.58996 .32673 .59584 .33389 .60733 .32997 .60148 .32278 Mtetra
.60148 .32278 .60733 .32997 .61886 .32603 .61304 .31881 Mtetra
.657 .752 .92 r
.61304 .31881 .61886 .32603 .63044 .32207 .62465 .31482 Mtetra
.62465 .31482 .63044 .32207 .64206 .3181 .63631 .31082 Mtetra
.63631 .31082 .64206 .3181 .65374 .31412 .64802 .3068 Mtetra
.64802 .3068 .65374 .31412 .66546 .31012 .65978 .30277 Mtetra
.65978 .30277 .66546 .31012 .67723 .3061 .67158 .29872 Mtetra
.67158 .29872 .67723 .3061 .68905 .30207 .68344 .29466 Mtetra
.68344 .29466 .68905 .30207 .70092 .29802 .69534 .29058 Mtetra
.69534 .29058 .70092 .29802 .71284 .29395 .7073 .28648 Mtetra
.7073 .28648 .71284 .29395 .72481 .28987 .7193 .28237 Mtetra
.7193 .28237 .72481 .28987 .73683 .28578 .73136 .27824 Mtetra
.73136 .27824 .73683 .28578 .7489 .28166 .74346 .27409 Mtetra
.74346 .27409 .7489 .28166 .76103 .27753 .75562 .26993 Mtetra
.75562 .26993 .76103 .27753 .7732 .27338 .76783 .26575 Mtetra
.76783 .26575 .7732 .27338 .78542 .26922 .78009 .26155 Mtetra
.78009 .26155 .78542 .26922 .7977 .26504 .7924 .25734 Mtetra
0 0 .175 r
.1516 .36202 .14603 .4755 .15545 .47509 .14855 .46805 Mtetra
.586 .701 .922 r
.14855 .46805 .15545 .47509 .16508 .47324 .15819 .46628 Mtetra
.545 .69 .934 r
.15819 .46628 .16508 .47324 .17354 .48278 .16779 .46522 Mtetra
.719 .586 .706 r
.16779 .46522 .17354 .48278 .18506 .46379 .17845 .4546 Mtetra
.477 .592 .89 r
.17845 .4546 .18506 .46379 .1948 .46204 .18795 .45517 Mtetra
.603 .715 .924 r
.18795 .45517 .1948 .46204 .20461 .46004 .19779 .45299 Mtetra
.534 .685 .935 r
.19779 .45299 .20461 .46004 .21172 .48703 .20755 .45209 Mtetra
.645 .472 .635 r
.20755 .45209 .21172 .48703 .22488 .45038 .21825 .44173 Mtetra
.516 .628 .9 r
.21825 .44173 .22488 .45038 .23481 .44835 .22803 .44147 Mtetra
.613 .721 .922 r
.22803 .44147 .23481 .44835 .24481 .44594 .23806 .43903 Mtetra
.594 .714 .928 r
.23806 .43903 .24481 .44594 .25467 .44588 .2481 .43698 Mtetra
.884 .722 .676 r
.2481 .43698 .25467 .44588 .26543 .43528 .2602 .41035 Mtetra
.027 .079 .581 r
.2602 .41035 .26543 .43528 .27546 .43404 .26879 .42693 Mtetra
.61 .715 .92 r
.26879 .42693 .27546 .43404 .28566 .43134 .27898 .42452 Mtetra
.626 .731 .922 r
.27898 .42452 .28566 .43134 .2959 .42865 .28924 .42171 Mtetra
.606 .721 .926 r
.28924 .42171 .2959 .42865 .30605 .42783 .29952 .41936 Mtetra
.943 .704 .547 r
.29952 .41936 .30605 .42783 .31689 .41725 .31748 .30197 Mtetra
0 0 .291 r
.31748 .30197 .31689 .41725 .32714 .41625 .32058 .409 Mtetra
.612 .715 .918 r
.32058 .409 .32714 .41625 .33756 .41336 .33099 .40649 Mtetra
.636 .737 .921 r
.33099 .40649 .33756 .41336 .34803 .4102 .34149 .40339 Mtetra
.64 .74 .921 r
.34149 .40339 .34803 .4102 .35855 .40704 .35203 .40017 Mtetra
.636 .738 .922 r
.35203 .40017 .35855 .40704 .3691 .40417 .36262 .39706 Mtetra
.6 .719 .927 r
.36262 .39706 .3691 .40417 .37953 .40494 .37321 .39475 Mtetra
.834 .714 .733 r
.37321 .39475 .37953 .40494 .39056 .39303 .38445 .37877 Mtetra
.333 .408 .79 r
.38445 .37877 .39056 .39303 .4012 .39103 .3948 .3838 Mtetra
.627 .726 .919 r
.3948 .3838 .4012 .39103 .41194 .38779 .40554 .38085 Mtetra
.646 .743 .92 r
.40554 .38085 .41194 .38779 .42272 .3843 .41635 .37742 Mtetra
.652 .748 .92 r
.41635 .37742 .42272 .3843 .43356 .38068 .42722 .37382 Mtetra
.655 .75 .92 r
.42722 .37382 .43356 .38068 .44444 .37698 .43812 .37013 Mtetra
.657 .752 .92 r
.43812 .37013 .44444 .37698 .45536 .37322 .44908 .36636 Mtetra
.658 .753 .92 r
.44908 .36636 .45536 .37322 .46633 .36943 .46007 .36255 Mtetra
.659 .754 .92 r
.46007 .36255 .46633 .36943 .47735 .3656 .47112 .3587 Mtetra
.47112 .3587 .47735 .3656 .48841 .36176 .4822 .35483 Mtetra
.4822 .35483 .48841 .36176 .49951 .35791 .49334 .35095 Mtetra
.49334 .35095 .49951 .35791 .51066 .35405 .50451 .34706 Mtetra
.658 .753 .92 r
.50451 .34706 .51066 .35405 .52185 .35018 .51574 .34316 Mtetra
.51574 .34316 .52185 .35018 .53309 .34631 .527 .33925 Mtetra
.527 .33925 .53309 .34631 .54437 .34242 .53832 .33533 Mtetra
.53832 .33533 .54437 .34242 .5557 .33852 .54968 .33139 Mtetra
.54968 .33139 .5557 .33852 .56707 .3346 .56108 .32745 Mtetra
.56108 .32745 .56707 .3346 .57849 .33067 .57254 .32349 Mtetra
.57254 .32349 .57849 .33067 .58996 .32673 .58404 .31952 Mtetra
.657 .753 .92 r
.58404 .31952 .58996 .32673 .60148 .32278 .59558 .31553 Mtetra
.59558 .31553 .60148 .32278 .61304 .31881 .60718 .31153 Mtetra
.60718 .31153 .61304 .31881 .62465 .31482 .61882 .30751 Mtetra
.657 .752 .92 r
.61882 .30751 .62465 .31482 .63631 .31082 .63052 .30348 Mtetra
.63052 .30348 .63631 .31082 .64802 .3068 .64226 .29943 Mtetra
.64226 .29943 .64802 .3068 .65978 .30277 .65405 .29537 Mtetra
.65405 .29537 .65978 .30277 .67158 .29872 .66589 .29129 Mtetra
.66589 .29129 .67158 .29872 .68344 .29466 .67777 .28719 Mtetra
.67777 .28719 .68344 .29466 .69534 .29058 .68971 .28308 Mtetra
.68971 .28308 .69534 .29058 .7073 .28648 .7017 .27895 Mtetra
.7017 .27895 .7073 .28648 .7193 .28237 .71374 .27481 Mtetra
.71374 .27481 .7193 .28237 .73136 .27824 .72583 .27064 Mtetra
.72583 .27064 .73136 .27824 .74346 .27409 .73798 .26646 Mtetra
.73798 .26646 .74346 .27409 .75562 .26993 .75017 .26227 Mtetra
.75017 .26227 .75562 .26993 .76783 .26575 .76242 .25805 Mtetra
.76242 .25805 .76783 .26575 .78009 .26155 .77471 .25382 Mtetra
.77471 .25382 .78009 .26155 .7924 .25734 .78707 .24957 Mtetra
.472 .224 .457 r
.13116 .46987 .1516 .36202 .14855 .46805 .14175 .45983 Mtetra
.522 .641 .908 r
.14175 .45983 .14855 .46805 .15819 .46628 .15124 .45938 Mtetra
.59 .709 .926 r
.15124 .45938 .15819 .46628 .16779 .46522 .16094 .45747 Mtetra
0 0 .476 r
.16094 .45747 .16779 .46522 .17845 .4546 .16946 .46701 Mtetra
.758 .901 .508 r
.16946 .46701 .17845 .4546 .18795 .45517 .1811 .44789 Mtetra
.585 .698 .92 r
.1811 .44789 .18795 .45517 .19779 .45299 .19091 .44609 Mtetra
.595 .714 .927 r
.19091 .44609 .19779 .45299 .20755 .45209 .2008 .44403 Mtetra
.929 .545 .204 r
.2008 .44403 .20755 .45209 .21825 .44173 .20793 .47109 Mtetra
0 0 0 r
.20793 .47109 .21825 .44173 .22803 .44147 .22124 .43423 Mtetra
.596 .705 .92 r
.22124 .43423 .22803 .44147 .23806 .43903 .23125 .43214 Mtetra
.613 .723 .924 r
.23125 .43214 .23806 .43903 .2481 .43698 .24135 .42967 Mtetra
.484 .659 .939 r
.24135 .42967 .2481 .43698 .2602 .41035 .25128 .42956 Mtetra
.119 0 .105 r
.25128 .42956 .2602 .41035 .26879 .42693 .26214 .41887 Mtetra
.561 .669 .91 r
.26214 .41887 .26879 .42693 .27898 .42452 .27226 .41757 Mtetra
.623 .727 .921 r
.27226 .41757 .27898 .42452 .28924 .42171 .28254 .41482 Mtetra
.622 .729 .923 r
.28254 .41482 .28924 .42171 .29952 .41936 .29287 .41207 Mtetra
.53 .682 .935 r
.29287 .41207 .29952 .41936 .31748 .30197 .30311 .41119 Mtetra
.473 .226 .459 r
.30311 .41119 .31748 .30197 .32058 .409 .31405 .40052 Mtetra
.55 .655 .904 r
.31405 .40052 .32058 .409 .33099 .40649 .32439 .39946 Mtetra
.629 .731 .92 r
.32439 .39946 .33099 .40649 .34149 .40339 .3349 .3965 Mtetra
.639 .739 .921 r
.3349 .3965 .34149 .40339 .35203 .40017 .34546 .39328 Mtetra
.639 .74 .922 r
.34546 .39328 .35203 .40017 .36262 .39706 .35608 .39006 Mtetra
.627 .733 .924 r
.35608 .39006 .36262 .39706 .37321 .39475 .36672 .38712 Mtetra
.433 .63 .937 r
.36672 .38712 .37321 .39475 .38445 .37877 .37724 .38784 Mtetra
0 0 0 r
.37724 .38784 .38445 .37877 .3948 .3838 .38838 .37583 Mtetra
.591 .691 .912 r
.38838 .37583 .3948 .3838 .40554 .38085 .39911 .37376 Mtetra
.64 .738 .92 r
.39911 .37376 .40554 .38085 .41635 .37742 .40994 .37046 Mtetra
.649 .746 .92 r
.40994 .37046 .41635 .37742 .42722 .37382 .42083 .3669 Mtetra
.653 .749 .92 r
.42083 .3669 .42722 .37382 .43812 .37013 .43176 .36321 Mtetra
.656 .751 .92 r
.43176 .36321 .43812 .37013 .44908 .36636 .44274 .35944 Mtetra
.657 .753 .92 r
.44274 .35944 .44908 .36636 .46007 .36255 .45377 .35561 Mtetra
.658 .753 .92 r
.45377 .35561 .46007 .36255 .47112 .3587 .46484 .35174 Mtetra
.659 .754 .92 r
.46484 .35174 .47112 .3587 .4822 .35483 .47596 .34785 Mtetra
.47596 .34785 .4822 .35483 .49334 .35095 .48712 .34393 Mtetra
.48712 .34393 .49334 .35095 .50451 .34706 .49832 .34001 Mtetra
.659 .753 .92 r
.49832 .34001 .50451 .34706 .51574 .34316 .50958 .33608 Mtetra
.658 .753 .92 r
.50958 .33608 .51574 .34316 .527 .33925 .52087 .33213 Mtetra
.52087 .33213 .527 .33925 .53832 .33533 .53222 .32818 Mtetra
.53222 .32818 .53832 .33533 .54968 .33139 .54361 .32422 Mtetra
.54361 .32422 .54968 .33139 .56108 .32745 .55505 .32024 Mtetra
.55505 .32024 .56108 .32745 .57254 .32349 .56653 .31625 Mtetra
.56653 .31625 .57254 .32349 .58404 .31952 .57806 .31225 Mtetra
.657 .753 .92 r
.57806 .31225 .58404 .31952 .59558 .31553 .58964 .30823 Mtetra
.58964 .30823 .59558 .31553 .60718 .31153 .60127 .3042 Mtetra
.60127 .3042 .60718 .31153 .61882 .30751 .61295 .30015 Mtetra
.657 .752 .92 r
.61295 .30015 .61882 .30751 .63052 .30348 .62467 .29608 Mtetra
.62467 .29608 .63052 .30348 .64226 .29943 .63645 .292 Mtetra
.63645 .292 .64226 .29943 .65405 .29537 .64827 .28791 Mtetra
.64827 .28791 .65405 .29537 .66589 .29129 .66015 .2838 Mtetra
.66015 .2838 .66589 .29129 .67777 .28719 .67207 .27967 Mtetra
.67207 .27967 .67777 .28719 .68971 .28308 .68404 .27552 Mtetra
.68404 .27552 .68971 .28308 .7017 .27895 .69607 .27136 Mtetra
.69607 .27136 .7017 .27895 .71374 .27481 .70814 .26718 Mtetra
.70814 .26718 .71374 .27481 .72583 .27064 .72027 .26299 Mtetra
.72027 .26299 .72583 .27064 .73798 .26646 .73245 .25878 Mtetra
.73245 .25878 .73798 .26646 .75017 .26227 .74468 .25455 Mtetra
.74468 .25455 .75017 .26227 .76242 .25805 .75696 .2503 Mtetra
.75696 .2503 .76242 .25805 .77471 .25382 .7693 .24603 Mtetra
.7693 .24603 .77471 .25382 .78707 .24957 .78168 .24175 Mtetra
.925 .697 .573 r
.12429 .46158 .13116 .46987 .14175 .45983 .14749 .34583 Mtetra
0 0 .168 r
.14749 .34583 .14175 .45983 .15124 .45938 .14427 .45223 Mtetra
.586 .701 .922 r
.14427 .45223 .15124 .45938 .16094 .45747 .15398 .45039 Mtetra
.545 .69 .934 r
.15398 .45039 .16094 .45747 .16946 .46701 .16365 .44928 Mtetra
.719 .586 .706 r
.16365 .44928 .16946 .46701 .1811 .44789 .17441 .43858 Mtetra
.476 .592 .89 r
.17441 .43858 .1811 .44789 .19091 .44609 .18399 .4391 Mtetra
.603 .715 .924 r
.18399 .4391 .19091 .44609 .2008 .44403 .19391 .43686 Mtetra
.535 .685 .935 r
.19391 .43686 .2008 .44403 .20793 .47109 .20375 .43591 Mtetra
.645 .471 .634 r
.20375 .43591 .20793 .47109 .22124 .43423 .21455 .42546 Mtetra
.516 .628 .9 r
.21455 .42546 .22124 .43423 .23125 .43214 .22441 .42514 Mtetra
.613 .721 .922 r
.22441 .42514 .23125 .43214 .24135 .42967 .23452 .42264 Mtetra
.594 .714 .928 r
.23452 .42264 .24135 .42967 .25128 .42956 .24464 .42053 Mtetra
.885 .723 .676 r
.24464 .42053 .25128 .42956 .26214 .41887 .25687 .39375 Mtetra
.022 .075 .579 r
.25687 .39375 .26214 .41887 .27226 .41757 .26551 .41034 Mtetra
.61 .715 .92 r
.26551 .41034 .27226 .41757 .28254 .41482 .27579 .40787 Mtetra
.626 .731 .922 r
.27579 .40787 .28254 .41482 .29287 .41207 .28614 .40501 Mtetra
.606 .721 .926 r
.28614 .40501 .29287 .41207 .30311 .41119 .29651 .40259 Mtetra
.944 .705 .545 r
.29651 .40259 .30311 .41119 .31405 .40052 .31474 .28471 Mtetra
0 0 .286 r
.31474 .28471 .31405 .40052 .32439 .39946 .31776 .39209 Mtetra
.612 .715 .918 r
.31776 .39209 .32439 .39946 .3349 .3965 .32826 .38951 Mtetra
.636 .737 .921 r
.32826 .38951 .3349 .3965 .34546 .39328 .33885 .38634 Mtetra
.64 .74 .921 r
.33885 .38634 .34546 .39328 .35608 .39006 .34949 .38306 Mtetra
.636 .738 .922 r
.34949 .38306 .35608 .39006 .36672 .38712 .36016 .37988 Mtetra
.6 .719 .927 r
.36016 .37988 .36672 .38712 .37724 .38784 .37085 .37751 Mtetra
.834 .715 .733 r
.37085 .37751 .37724 .38784 .38838 .37583 .3822 .36141 Mtetra
.331 .407 .79 r
.3822 .36141 .38838 .37583 .39911 .37376 .39264 .3664 Mtetra
.627 .726 .919 r
.39264 .3664 .39911 .37376 .40994 .37046 .40348 .36339 Mtetra
.646 .743 .92 r
.40348 .36339 .40994 .37046 .42083 .3669 .41439 .35989 Mtetra
.652 .748 .92 r
.41439 .35989 .42083 .3669 .43176 .36321 .42535 .35622 Mtetra
.655 .75 .92 r
.42535 .35622 .43176 .36321 .44274 .35944 .43636 .35245 Mtetra
.657 .752 .92 r
.43636 .35245 .44274 .35944 .45377 .35561 .44741 .34862 Mtetra
.658 .753 .92 r
.44741 .34862 .45377 .35561 .46484 .35174 .45851 .34473 Mtetra
.659 .754 .92 r
.45851 .34473 .46484 .35174 .47596 .34785 .46966 .34081 Mtetra
.46966 .34081 .47596 .34785 .48712 .34393 .48085 .33687 Mtetra
.48085 .33687 .48712 .34393 .49832 .34001 .49209 .33291 Mtetra
.49209 .33291 .49832 .34001 .50958 .33608 .50337 .32894 Mtetra
.658 .753 .92 r
.50337 .32894 .50958 .33608 .52087 .33213 .5147 .32497 Mtetra
.5147 .32497 .52087 .33213 .53222 .32818 .52607 .32098 Mtetra
.52607 .32098 .53222 .32818 .54361 .32422 .5375 .31699 Mtetra
.5375 .31699 .54361 .32422 .55505 .32024 .54896 .31298 Mtetra
.54896 .31298 .55505 .32024 .56653 .31625 .56048 .30896 Mtetra
.56048 .30896 .56653 .31625 .57806 .31225 .57205 .30492 Mtetra
.57205 .30492 .57806 .31225 .58964 .30823 .58366 .30087 Mtetra
.657 .753 .92 r
.58366 .30087 .58964 .30823 .60127 .3042 .59532 .29681 Mtetra
.59532 .29681 .60127 .3042 .61295 .30015 .60703 .29272 Mtetra
.60703 .29272 .61295 .30015 .62467 .29608 .61879 .28863 Mtetra
.657 .752 .92 r
.61879 .28863 .62467 .29608 .63645 .292 .63059 .28452 Mtetra
.63059 .28452 .63645 .292 .64827 .28791 .64245 .28039 Mtetra
.64245 .28039 .64827 .28791 .66015 .2838 .65436 .27624 Mtetra
.65436 .27624 .66015 .2838 .67207 .27967 .66632 .27208 Mtetra
.66632 .27208 .67207 .27967 .68404 .27552 .67833 .26791 Mtetra
.67833 .26791 .68404 .27552 .69607 .27136 .69039 .26371 Mtetra
.69039 .26371 .69607 .27136 .70814 .26718 .7025 .2595 Mtetra
.7025 .2595 .70814 .26718 .72027 .26299 .71466 .25527 Mtetra
.71466 .25527 .72027 .26299 .73245 .25878 .72687 .25103 Mtetra
.72687 .25103 .73245 .25878 .74468 .25455 .73914 .24676 Mtetra
.73914 .24676 .74468 .25455 .75696 .2503 .75146 .24248 Mtetra
.75146 .24248 .75696 .2503 .7693 .24603 .76383 .23818 Mtetra
.76383 .23818 .7693 .24603 .78168 .24175 .77626 .23387 Mtetra
.5 .668 .938 r
.11723 .45439 .12429 .46158 .14749 .34583 .1267 .45401 Mtetra
.468 .218 .452 r
.1267 .45401 .14749 .34583 .14427 .45223 .13738 .44388 Mtetra
.522 .641 .908 r
.13738 .44388 .14427 .45223 .15398 .45039 .14695 .44338 Mtetra
.59 .709 .926 r
.14695 .44338 .15398 .45039 .16365 .44928 .15673 .44141 Mtetra
0 0 .483 r
.15673 .44141 .16365 .44928 .17441 .43858 .1653 .45095 Mtetra
.765 .906 .516 r
.1653 .45095 .17441 .43858 .18399 .4391 .17706 .4317 Mtetra
.585 .698 .92 r
.17706 .4317 .18399 .4391 .19391 .43686 .18695 .42984 Mtetra
.595 .714 .927 r
.18695 .42984 .19391 .43686 .20375 .43591 .19692 .42772 Mtetra
.928 .543 .198 r
.19692 .42772 .20375 .43591 .21455 .42546 .20408 .45485 Mtetra
0 0 0 r
.20408 .45485 .21455 .42546 .22441 .42514 .21754 .41778 Mtetra
.596 .705 .92 r
.21754 .41778 .22441 .42514 .23452 .42264 .22764 .41564 Mtetra
.613 .723 .924 r
.22764 .41564 .23452 .42264 .24464 .42053 .23781 .41311 Mtetra
.485 .659 .938 r
.23781 .41311 .24464 .42053 .25687 .39375 .24783 .41295 Mtetra
.106 0 .092 r
.24783 .41295 .25687 .39375 .26551 .41034 .25879 .40216 Mtetra
.561 .669 .91 r
.25879 .40216 .26551 .41034 .27579 .40787 .269 .40081 Mtetra
.623 .727 .921 r
.269 .40081 .27579 .40787 .28614 .40501 .27937 .39799 Mtetra
.622 .729 .923 r
.27937 .39799 .28614 .40501 .29651 .40259 .28978 .39517 Mtetra
.53 .682 .935 r
.28978 .39517 .29651 .40259 .31474 .28471 .30011 .39423 Mtetra
.468 .22 .454 r
.30011 .39423 .31474 .28471 .31776 .39209 .31116 .38347 Mtetra
.55 .655 .904 r
.31116 .38347 .31776 .39209 .32826 .38951 .32158 .38236 Mtetra
.629 .731 .92 r
.32158 .38236 .32826 .38951 .33885 .38634 .33218 .37933 Mtetra
.639 .739 .921 r
.33218 .37933 .33885 .38634 .34949 .38306 .34285 .37605 Mtetra
.639 .74 .922 r
.34285 .37605 .34949 .38306 .36016 .37988 .35355 .37275 Mtetra
.627 .733 .924 r
.35355 .37275 .36016 .37988 .37085 .37751 .36429 .36974 Mtetra
.434 .63 .937 r
.36429 .36974 .37085 .37751 .3822 .36141 .3749 .37042 Mtetra
0 0 0 r
.3749 .37042 .3822 .36141 .39264 .3664 .38615 .3583 Mtetra
.591 .691 .912 r
.38615 .3583 .39264 .3664 .40348 .36339 .39698 .35617 Mtetra
.64 .738 .92 r
.39698 .35617 .40348 .36339 .41439 .35989 .40791 .3528 Mtetra
.649 .746 .92 r
.40791 .3528 .41439 .35989 .42535 .35622 .41889 .34916 Mtetra
.653 .749 .92 r
.41889 .34916 .42535 .35622 .43636 .35245 .42993 .3454 Mtetra
.656 .751 .92 r
.42993 .3454 .43636 .35245 .44741 .34862 .44101 .34156 Mtetra
.657 .753 .92 r
.44101 .34156 .44741 .34862 .45851 .34473 .45214 .33766 Mtetra
.658 .753 .92 r
.45214 .33766 .45851 .34473 .46966 .34081 .46332 .33372 Mtetra
.659 .754 .92 r
.46332 .33372 .46966 .34081 .48085 .33687 .47454 .32974 Mtetra
.47454 .32974 .48085 .33687 .49209 .33291 .4858 .32576 Mtetra
.4858 .32576 .49209 .33291 .50337 .32894 .49712 .32176 Mtetra
.659 .753 .92 r
.49712 .32176 .50337 .32894 .5147 .32497 .50848 .31775 Mtetra
.658 .753 .92 r
.50848 .31775 .5147 .32497 .52607 .32098 .51988 .31373 Mtetra
.51988 .31373 .52607 .32098 .5375 .31699 .53134 .3097 Mtetra
.53134 .3097 .5375 .31699 .54896 .31298 .54284 .30566 Mtetra
.54284 .30566 .54896 .31298 .56048 .30896 .55438 .30161 Mtetra
.55438 .30161 .56048 .30896 .57205 .30492 .56598 .29754 Mtetra
.56598 .29754 .57205 .30492 .58366 .30087 .57762 .29346 Mtetra
.657 .753 .92 r
.57762 .29346 .58366 .30087 .59532 .29681 .58932 .28936 Mtetra
.58932 .28936 .59532 .29681 .60703 .29272 .60106 .28525 Mtetra
.60106 .28525 .60703 .29272 .61879 .28863 .61285 .28112 Mtetra
.657 .752 .92 r
.61285 .28112 .61879 .28863 .63059 .28452 .62469 .27697 Mtetra
.62469 .27697 .63059 .28452 .64245 .28039 .63659 .27281 Mtetra
.63659 .27281 .64245 .28039 .65436 .27624 .64853 .26863 Mtetra
.64853 .26863 .65436 .27624 .66632 .27208 .66052 .26444 Mtetra
.66052 .26444 .66632 .27208 .67833 .26791 .67257 .26023 Mtetra
.67257 .26023 .67833 .26791 .69039 .26371 .68466 .256 Mtetra
.68466 .256 .69039 .26371 .7025 .2595 .69681 .25176 Mtetra
.69681 .25176 .7025 .2595 .71466 .25527 .70901 .2475 Mtetra
.70901 .2475 .71466 .25527 .72687 .25103 .72126 .24322 Mtetra
.72126 .24322 .72687 .25103 .73914 .24676 .73356 .23892 Mtetra
.73356 .23892 .73914 .24676 .75146 .24248 .74592 .2346 Mtetra
.74592 .2346 .75146 .24248 .76383 .23818 .75833 .23027 Mtetra
.75833 .23027 .76383 .23818 .77626 .23387 .77079 .22592 Mtetra
.577 .703 .928 r
.11011 .44731 .11723 .45439 .1267 .45401 .11975 .4456 Mtetra
.927 .697 .572 r
.11975 .4456 .1267 .45401 .13738 .44388 .14331 .32935 Mtetra
0 0 .161 r
.14331 .32935 .13738 .44388 .14695 .44338 .1399 .43611 Mtetra
.586 .701 .922 r
.1399 .43611 .14695 .44338 .15673 .44141 .14969 .43422 Mtetra
.545 .69 .934 r
.14969 .43422 .15673 .44141 .1653 .45095 .15944 .43306 Mtetra
.719 .586 .706 r
.15944 .43306 .1653 .45095 .17706 .4317 .1703 .42225 Mtetra
.476 .592 .89 r
.1703 .42225 .17706 .4317 .18695 .42984 .17995 .42273 Mtetra
.603 .715 .924 r
.17995 .42273 .18695 .42984 .19692 .42772 .18996 .42043 Mtetra
.535 .685 .935 r
.18996 .42043 .19692 .42772 .20408 .45485 .19987 .41943 Mtetra
.644 .47 .633 r
.19987 .41943 .20408 .45485 .21754 .41778 .21078 .40888 Mtetra
.516 .628 .9 r
.21078 .40888 .21754 .41778 .22764 .41564 .22071 .40852 Mtetra
.613 .721 .922 r
.22071 .40852 .22764 .41564 .23781 .41311 .23091 .40596 Mtetra
.594 .714 .928 r
.23091 .40596 .23781 .41311 .24783 .41295 .24112 .40379 Mtetra
.886 .724 .675 r
.24112 .40379 .24783 .41295 .25879 .40216 .25348 .37684 Mtetra
.016 .072 .577 r
.25348 .37684 .25879 .40216 .269 .40081 .26217 .39345 Mtetra
.61 .715 .92 r
.26217 .39345 .269 .40081 .27937 .39799 .27254 .39092 Mtetra
.626 .731 .922 r
.27254 .39092 .27937 .39799 .28978 .39517 .28299 .38799 Mtetra
.606 .721 .926 r
.28299 .38799 .28978 .39517 .30011 .39423 .29344 .38551 Mtetra
.946 .705 .543 r
.29344 .38551 .30011 .39423 .31116 .38347 .31194 .26713 Mtetra
0 0 .28 r
.31194 .26713 .31116 .38347 .32158 .38236 .31488 .37485 Mtetra
.612 .715 .918 r
.31488 .37485 .32158 .38236 .33218 .37933 .32548 .37221 Mtetra
.636 .737 .921 r
.32548 .37221 .33218 .37933 .34285 .37605 .33616 .36898 Mtetra
.64 .74 .921 r
.33616 .36898 .34285 .37605 .35355 .37275 .34689 .36563 Mtetra
.636 .738 .922 r
.34689 .36563 .35355 .37275 .36429 .36974 .35766 .36238 Mtetra
.6 .718 .927 r
.35766 .36238 .36429 .36974 .3749 .37042 .36844 .35994 Mtetra
.835 .716 .733 r
.36844 .35994 .3749 .37042 .38615 .3583 .37991 .34372 Mtetra
.329 .406 .79 r
.37991 .34372 .38615 .3583 .39698 .35617 .39044 .34867 Mtetra
.627 .726 .919 r
.39044 .34867 .39698 .35617 .40791 .3528 .40138 .34559 Mtetra
.646 .743 .92 r
.40138 .34559 .40791 .3528 .41889 .34916 .41239 .34202 Mtetra
.652 .748 .92 r
.41239 .34202 .41889 .34916 .42993 .3454 .42345 .33828 Mtetra
.655 .75 .92 r
.42345 .33828 .42993 .3454 .44101 .34156 .43456 .33444 Mtetra
.657 .752 .92 r
.43456 .33444 .44101 .34156 .45214 .33766 .44572 .33053 Mtetra
.658 .753 .92 r
.44572 .33053 .45214 .33766 .46332 .33372 .45692 .32657 Mtetra
.659 .754 .92 r
.45692 .32657 .46332 .33372 .47454 .32974 .46817 .32257 Mtetra
.46817 .32257 .47454 .32974 .4858 .32576 .47947 .31855 Mtetra
.47947 .31855 .4858 .32576 .49712 .32176 .49081 .31452 Mtetra
.49081 .31452 .49712 .32176 .50848 .31775 .5022 .31048 Mtetra
.658 .753 .92 r
.5022 .31048 .50848 .31775 .51988 .31373 .51364 .30642 Mtetra
.51364 .30642 .51988 .31373 .53134 .3097 .52513 .30236 Mtetra
.52513 .30236 .53134 .3097 .54284 .30566 .53666 .29829 Mtetra
.53666 .29829 .54284 .30566 .55438 .30161 .54824 .2942 Mtetra
.54824 .2942 .55438 .30161 .56598 .29754 .55987 .2901 Mtetra
.55987 .2901 .56598 .29754 .57762 .29346 .57155 .28598 Mtetra
.57155 .28598 .57762 .29346 .58932 .28936 .58327 .28185 Mtetra
.657 .753 .92 r
.58327 .28185 .58932 .28936 .60106 .28525 .59505 .27771 Mtetra
.59505 .27771 .60106 .28525 .61285 .28112 .60687 .27355 Mtetra
.60687 .27355 .61285 .28112 .62469 .27697 .61875 .26937 Mtetra
.657 .752 .92 r
.61875 .26937 .62469 .27697 .63659 .27281 .63067 .26517 Mtetra
.63067 .26517 .63659 .27281 .64853 .26863 .64265 .26096 Mtetra
.64265 .26096 .64853 .26863 .66052 .26444 .65468 .25674 Mtetra
.65468 .25674 .66052 .26444 .67257 .26023 .66676 .25249 Mtetra
.66676 .25249 .67257 .26023 .68466 .256 .67889 .24823 Mtetra
.67889 .24823 .68466 .256 .69681 .25176 .69107 .24395 Mtetra
.69107 .24395 .69681 .25176 .70901 .2475 .70331 .23966 Mtetra
.70331 .23966 .70901 .2475 .72126 .24322 .7156 .23534 Mtetra
.7156 .23534 .72126 .24322 .73356 .23892 .72794 .23101 Mtetra
.72794 .23101 .73356 .23892 .74592 .2346 .74033 .22666 Mtetra
.74033 .22666 .74592 .2346 .75833 .23027 .75278 .22229 Mtetra
.75278 .22229 .75833 .23027 .77079 .22592 .76528 .2179 Mtetra
.574 .693 .923 r
.10297 .43992 .11011 .44731 .11975 .4456 .11262 .43828 Mtetra
.5 .668 .938 r
.11262 .43828 .11975 .4456 .14331 .32935 .12216 .43785 Mtetra
.463 .212 .447 r
.12216 .43785 .14331 .32935 .1399 .43611 .13294 .42764 Mtetra
.522 .641 .908 r
.13294 .42764 .1399 .43611 .14969 .43422 .14258 .42708 Mtetra
.59 .709 .926 r
.14258 .42708 .14969 .43422 .15944 .43306 .15245 .42506 Mtetra
0 0 .49 r
.15245 .42506 .15944 .43306 .1703 .42225 .16107 .43459 Mtetra
.772 .91 .523 r
.16107 .43459 .1703 .42225 .17995 .42273 .17294 .41521 Mtetra
.585 .698 .92 r
.17294 .41521 .17995 .42273 .18996 .42043 .18292 .41329 Mtetra
.595 .714 .927 r
.18292 .41329 .18996 .42043 .19987 .41943 .19297 .41111 Mtetra
.927 .54 .192 r
.19297 .41111 .19987 .41943 .21078 .40888 .20015 .4383 Mtetra
0 0 0 r
.20015 .4383 .21078 .40888 .22071 .40852 .21377 .40103 Mtetra
.596 .705 .92 r
.21377 .40103 .22071 .40852 .23091 .40596 .22395 .39883 Mtetra
.613 .723 .924 r
.22395 .39883 .23091 .40596 .24112 .40379 .23422 .39623 Mtetra
.485 .659 .938 r
.23422 .39623 .24112 .40379 .25348 .37684 .24432 .39602 Mtetra
.092 0 .078 r
.24432 .39602 .25348 .37684 .26217 .39345 .25538 .38514 Mtetra
.561 .669 .91 r
.25538 .38514 .26217 .39345 .27254 .39092 .26567 .38372 Mtetra
.623 .727 .921 r
.26567 .38372 .27254 .39092 .28299 .38799 .27613 .38084 Mtetra
.622 .729 .923 r
.27613 .38084 .28299 .38799 .29344 .38551 .28664 .37796 Mtetra
.53 .682 .935 r
.28664 .37796 .29344 .38551 .31194 .26713 .29706 .37696 Mtetra
.464 .214 .449 r
.29706 .37696 .31194 .26713 .31488 .37485 .30821 .3661 Mtetra
.55 .655 .905 r
.30821 .3661 .31488 .37485 .32548 .37221 .31873 .36493 Mtetra
.629 .731 .92 r
.31873 .36493 .32548 .37221 .33616 .36898 .32942 .36183 Mtetra
.639 .739 .921 r
.32942 .36183 .33616 .36898 .34689 .36563 .34018 .35848 Mtetra
.639 .74 .922 r
.34018 .35848 .34689 .36563 .35766 .36238 .35098 .35511 Mtetra
.627 .733 .924 r
.35098 .35511 .35766 .36238 .36844 .35994 .36182 .35204 Mtetra
.434 .63 .936 r
.36182 .35204 .36844 .35994 .37991 .34372 .37252 .35266 Mtetra
0 0 0 r
.37252 .35266 .37991 .34372 .39044 .34867 .38388 .34043 Mtetra
.59 .691 .912 r
.38388 .34043 .39044 .34867 .40138 .34559 .3948 .33824 Mtetra
.64 .738 .92 r
.3948 .33824 .40138 .34559 .41239 .34202 .40583 .33479 Mtetra
.649 .746 .92 r
.40583 .33479 .41239 .34202 .42345 .33828 .41692 .33108 Mtetra
.653 .749 .92 r
.41692 .33108 .42345 .33828 .43456 .33444 .42806 .32725 Mtetra
.656 .751 .92 r
.42806 .32725 .43456 .33444 .44572 .33053 .43925 .32333 Mtetra
.657 .753 .92 r
.43925 .32333 .44572 .33053 .45692 .32657 .45048 .31936 Mtetra
.658 .753 .92 r
.45048 .31936 .45692 .32657 .46817 .32257 .46176 .31534 Mtetra
.659 .754 .92 r
.46176 .31534 .46817 .32257 .47947 .31855 .47309 .31129 Mtetra
.47309 .31129 .47947 .31855 .49081 .31452 .48446 .30722 Mtetra
.48446 .30722 .49081 .31452 .5022 .31048 .49589 .30315 Mtetra
.659 .753 .92 r
.49589 .30315 .5022 .31048 .51364 .30642 .50735 .29906 Mtetra
.658 .753 .92 r
.50735 .29906 .51364 .30642 .52513 .30236 .51887 .29496 Mtetra
.51887 .29496 .52513 .30236 .53666 .29829 .53043 .29086 Mtetra
.53043 .29086 .53666 .29829 .54824 .2942 .54205 .28674 Mtetra
.54205 .28674 .54824 .2942 .55987 .2901 .55371 .2826 Mtetra
.55371 .2826 .55987 .2901 .57155 .28598 .56542 .27845 Mtetra
.56542 .27845 .57155 .28598 .58327 .28185 .57718 .27429 Mtetra
.657 .753 .92 r
.57718 .27429 .58327 .28185 .59505 .27771 .58899 .27011 Mtetra
.58899 .27011 .59505 .27771 .60687 .27355 .60085 .26592 Mtetra
.60085 .26592 .60687 .27355 .61875 .26937 .61276 .26171 Mtetra
.657 .752 .92 r
.61276 .26171 .61875 .26937 .63067 .26517 .62472 .25748 Mtetra
.62472 .25748 .63067 .26517 .64265 .26096 .63673 .25323 Mtetra
.63673 .25323 .64265 .26096 .65468 .25674 .64879 .24897 Mtetra
.64879 .24897 .65468 .25674 .66676 .25249 .6609 .24469 Mtetra
.6609 .24469 .66676 .25249 .67889 .24823 .67307 .2404 Mtetra
.67307 .2404 .67889 .24823 .69107 .24395 .68529 .23609 Mtetra
.68529 .23609 .69107 .24395 .70331 .23966 .69756 .23175 Mtetra
.69756 .23175 .70331 .23966 .7156 .23534 .70989 .22741 Mtetra
.70989 .22741 .7156 .23534 .72794 .23101 .72227 .22304 Mtetra
.72227 .22304 .72794 .23101 .74033 .22666 .7347 .21865 Mtetra
.7347 .21865 .74033 .22666 .75278 .22229 .74718 .21425 Mtetra
.74718 .21425 .75278 .22229 .76528 .2179 .75973 .20983 Mtetra
.479 .604 .898 r
.09601 .43081 .10297 .43992 .11262 .43828 .10541 .43108 Mtetra
.577 .703 .928 r
.10541 .43108 .11262 .43828 .12216 .43785 .11514 .42932 Mtetra
.928 .698 .57 r
.11514 .42932 .12216 .43785 .13294 .42764 .13905 .31257 Mtetra
0 0 .153 r
.13905 .31257 .13294 .42764 .14258 .42708 .13545 .41969 Mtetra
.586 .702 .922 r
.13545 .41969 .14258 .42708 .15245 .42506 .14532 .41775 Mtetra
.545 .69 .934 r
.14532 .41775 .15245 .42506 .16107 .43459 .15515 .41653 Mtetra
.719 .586 .706 r
.15515 .41653 .16107 .43459 .17294 .41521 .16611 .40563 Mtetra
.475 .592 .89 r
.16611 .40563 .17294 .41521 .18292 .41329 .17584 .40606 Mtetra
.603 .715 .924 r
.17584 .40606 .18292 .41329 .19297 .41111 .18593 .4037 Mtetra
.535 .685 .935 r
.18593 .4037 .19297 .41111 .20015 .4383 .19593 .40264 Mtetra
.643 .468 .632 r
.19593 .40264 .20015 .4383 .21377 .40103 .20693 .392 Mtetra
.515 .628 .9 r
.20693 .392 .21377 .40103 .22395 .39883 .21695 .39158 Mtetra
.613 .721 .922 r
.21695 .39158 .22395 .39883 .23422 .39623 .22724 .38896 Mtetra
.594 .714 .928 r
.22724 .38896 .23422 .39623 .24432 .39602 .23753 .38672 Mtetra
.887 .724 .675 r
.23753 .38672 .24432 .39602 .25538 .38514 .25003 .35961 Mtetra
.011 .068 .575 r
.25003 .35961 .25538 .38514 .26567 .38372 .25877 .37624 Mtetra
.61 .715 .92 r
.25877 .37624 .26567 .38372 .27613 .38084 .26923 .37364 Mtetra
.626 .731 .922 r
.26923 .37364 .27613 .38084 .28664 .37796 .27977 .37064 Mtetra
.606 .721 .926 r
.27977 .37064 .28664 .37796 .29706 .37696 .29032 .3681 Mtetra
.947 .705 .54 r
.29032 .3681 .29706 .37696 .30821 .3661 .30909 .24923 Mtetra
0 0 .274 r
.30909 .24923 .30821 .3661 .31873 .36493 .31195 .35729 Mtetra
.612 .715 .918 r
.31195 .35729 .31873 .36493 .32942 .36183 .32264 .35458 Mtetra
.636 .737 .921 r
.32264 .35458 .32942 .36183 .34018 .35848 .33341 .35128 Mtetra
.64 .74 .921 r
.33341 .35128 .34018 .35848 .35098 .35511 .34425 .34786 Mtetra
.636 .738 .922 r
.34425 .34786 .35098 .35511 .36182 .35204 .35512 .34454 Mtetra
.601 .718 .927 r
.35512 .34454 .36182 .35204 .37252 .35266 .366 .34203 Mtetra
.836 .717 .733 r
.366 .34203 .37252 .35266 .38388 .34043 .37757 .32569 Mtetra
.328 .405 .79 r
.37757 .32569 .38388 .34043 .3948 .33824 .38819 .3306 Mtetra
.627 .726 .919 r
.38819 .3306 .3948 .33824 .40583 .33479 .39923 .32745 Mtetra
.646 .743 .92 r
.39923 .32745 .40583 .33479 .41692 .33108 .41035 .32381 Mtetra
.652 .748 .92 r
.41035 .32381 .41692 .33108 .42806 .32725 .42151 .31999 Mtetra
.655 .75 .92 r
.42151 .31999 .42806 .32725 .43925 .32333 .43273 .31607 Mtetra
.657 .752 .92 r
.43273 .31607 .43925 .32333 .45048 .31936 .44399 .31208 Mtetra
.658 .753 .92 r
.44399 .31208 .45048 .31936 .46176 .31534 .4553 .30805 Mtetra
.659 .754 .92 r
.4553 .30805 .46176 .31534 .47309 .31129 .46666 .30397 Mtetra
.46666 .30397 .47309 .31129 .48446 .30722 .47806 .29988 Mtetra
.47806 .29988 .48446 .30722 .49589 .30315 .48952 .29576 Mtetra
.48952 .29576 .49589 .30315 .50735 .29906 .50102 .29164 Mtetra
.658 .753 .92 r
.50102 .29164 .50735 .29906 .51887 .29496 .51256 .28751 Mtetra
.51256 .28751 .51887 .29496 .53043 .29086 .52416 .28337 Mtetra
.52416 .28337 .53043 .29086 .54205 .28674 .53581 .27921 Mtetra
.53581 .27921 .54205 .28674 .55371 .2826 .5475 .27505 Mtetra
.5475 .27505 .55371 .2826 .56542 .27845 .55924 .27086 Mtetra
.55924 .27086 .56542 .27845 .57718 .27429 .57104 .26667 Mtetra
.57104 .26667 .57718 .27429 .58899 .27011 .58288 .26245 Mtetra
.657 .753 .92 r
.58288 .26245 .58899 .27011 .60085 .26592 .59477 .25823 Mtetra
.59477 .25823 .60085 .26592 .61276 .26171 .60672 .25398 Mtetra
.60672 .25398 .61276 .26171 .62472 .25748 .61871 .24972 Mtetra
.657 .752 .92 r
.61871 .24972 .62472 .25748 .63673 .25323 .63076 .24544 Mtetra
.63076 .24544 .63673 .25323 .64879 .24897 .64285 .24115 Mtetra
.64285 .24115 .64879 .24897 .6609 .24469 .65501 .23683 Mtetra
.65501 .23683 .6609 .24469 .67307 .2404 .66721 .2325 Mtetra
.66721 .2325 .67307 .2404 .68529 .23609 .67946 .22816 Mtetra
.67946 .22816 .68529 .23609 .69756 .23175 .69177 .22379 Mtetra
.69177 .22379 .69756 .23175 .70989 .22741 .70413 .2194 Mtetra
.70413 .2194 .70989 .22741 .72227 .22304 .71655 .215 Mtetra
.71655 .215 .72227 .22304 .7347 .21865 .72902 .21058 Mtetra
.72902 .21058 .7347 .21865 .74718 .21425 .74154 .20614 Mtetra
.74154 .20614 .74718 .21425 .75973 .20983 .75412 .20168 Mtetra
.79 .888 .469 r
.08543 .4483 .09601 .43081 .10541 .43108 .0982 .42358 Mtetra
.573 .693 .923 r
.0982 .42358 .10541 .43108 .11514 .42932 .10792 .42189 Mtetra
.5 .668 .938 r
.10792 .42189 .11514 .42932 .13905 .31257 .11754 .42141 Mtetra
.458 .205 .442 r
.11754 .42141 .13905 .31257 .13545 .41969 .12842 .4111 Mtetra
.522 .641 .908 r
.12842 .4111 .13545 .41969 .14532 .41775 .13813 .41049 Mtetra
.59 .709 .926 r
.13813 .41049 .14532 .41775 .15515 .41653 .14808 .40841 Mtetra
0 0 .498 r
.14808 .40841 .15515 .41653 .16611 .40563 .15675 .41792 Mtetra
.779 .915 .531 r
.15675 .41792 .16611 .40563 .17584 .40606 .16875 .39841 Mtetra
.585 .698 .92 r
.16875 .39841 .17584 .40606 .18593 .4037 .17881 .39643 Mtetra
.595 .714 .927 r
.17881 .39643 .18593 .4037 .19593 .40264 .18895 .39419 Mtetra
.926 .538 .185 r
.18895 .39419 .19593 .40264 .20693 .392 .19615 .42144 Mtetra
0 0 0 r
.19615 .42144 .20693 .392 .21695 .39158 .20993 .38396 Mtetra
.596 .705 .92 r
.20993 .38396 .21695 .39158 .22724 .38896 .2202 .3817 Mtetra
.613 .723 .924 r
.2202 .3817 .22724 .38896 .23753 .38672 .23055 .37904 Mtetra
.485 .659 .938 r
.23055 .37904 .23753 .38672 .25003 .35961 .24074 .37877 Mtetra
.078 0 .064 r
.24074 .37877 .25003 .35961 .25877 .37624 .25191 .36779 Mtetra
.561 .669 .911 r
.25191 .36779 .25877 .37624 .26923 .37364 .26228 .36631 Mtetra
.623 .727 .921 r
.26228 .36631 .26923 .37364 .27977 .37064 .27284 .36336 Mtetra
.622 .729 .923 r
.27284 .36336 .27977 .37064 .29032 .3681 .28344 .36041 Mtetra
.531 .682 .935 r
.28344 .36041 .29032 .3681 .30909 .24923 .29395 .35936 Mtetra
.459 .208 .444 r
.29395 .35936 .30909 .24923 .31195 .35729 .3052 .34839 Mtetra
.55 .655 .905 r
.3052 .34839 .31195 .35729 .32264 .35458 .31581 .34716 Mtetra
.629 .731 .92 r
.31581 .34716 .32264 .35458 .33341 .35128 .3266 .344 Mtetra
.639 .739 .921 r
.3266 .344 .33341 .35128 .34425 .34786 .33746 .34057 Mtetra
.639 .74 .922 r
.33746 .34057 .34425 .34786 .35512 .34454 .34836 .33713 Mtetra
.627 .733 .924 r
.34836 .33713 .35512 .34454 .366 .34203 .35929 .33399 Mtetra
.435 .63 .936 r
.35929 .33399 .366 .34203 .37757 .32569 .3701 .33455 Mtetra
0 0 0 r
.3701 .33455 .37757 .32569 .38819 .3306 .38156 .32222 Mtetra
.59 .691 .912 r
.38156 .32222 .38819 .3306 .39923 .32745 .39259 .31995 Mtetra
.64 .738 .92 r
.39259 .31995 .39923 .32745 .41035 .32381 .40372 .31644 Mtetra
.649 .746 .92 r
.40372 .31644 .41035 .32381 .42151 .31999 .41491 .31265 Mtetra
.653 .749 .92 r
.41491 .31265 .42151 .31999 .43273 .31607 .42616 .30874 Mtetra
.656 .751 .92 r
.42616 .30874 .43273 .31607 .44399 .31208 .43745 .30475 Mtetra
.657 .753 .92 r
.43745 .30475 .44399 .31208 .4553 .30805 .44879 .30069 Mtetra
.658 .753 .92 r
.44879 .30069 .4553 .30805 .46666 .30397 .46018 .2966 Mtetra
.659 .754 .92 r
.46018 .2966 .46666 .30397 .47806 .29988 .47161 .29247 Mtetra
.47161 .29247 .47806 .29988 .48952 .29576 .4831 .28833 Mtetra
.4831 .28833 .48952 .29576 .50102 .29164 .49463 .28417 Mtetra
.659 .753 .92 r
.49463 .28417 .50102 .29164 .51256 .28751 .50621 .28 Mtetra
.658 .753 .92 r
.50621 .28 .51256 .28751 .52416 .28337 .51784 .27582 Mtetra
.51784 .27582 .52416 .28337 .53581 .27921 .52952 .27163 Mtetra
.52952 .27163 .53581 .27921 .5475 .27505 .54124 .26743 Mtetra
.54124 .26743 .5475 .27505 .55924 .27086 .55302 .26322 Mtetra
.55302 .26322 .55924 .27086 .57104 .26667 .56484 .25898 Mtetra
.56484 .25898 .57104 .26667 .58288 .26245 .57672 .25474 Mtetra
.657 .753 .92 r
.57672 .25474 .58288 .26245 .59477 .25823 .58865 .25048 Mtetra
.58865 .25048 .59477 .25823 .60672 .25398 .60063 .2462 Mtetra
.60063 .2462 .60672 .25398 .61871 .24972 .61266 .2419 Mtetra
.657 .752 .92 r
.61266 .2419 .61871 .24972 .63076 .24544 .62474 .23759 Mtetra
.62474 .23759 .63076 .24544 .64285 .24115 .63687 .23326 Mtetra
.63687 .23326 .64285 .24115 .65501 .23683 .64906 .22891 Mtetra
.64906 .22891 .65501 .23683 .66721 .2325 .6613 .22454 Mtetra
.6613 .22454 .66721 .2325 .67946 .22816 .67359 .22016 Mtetra
.67359 .22016 .67946 .22816 .69177 .22379 .68593 .21576 Mtetra
.68593 .21576 .69177 .22379 .70413 .2194 .69833 .21134 Mtetra
.69833 .21134 .70413 .2194 .71655 .215 .71079 .2069 Mtetra
.71079 .2069 .71655 .215 .72902 .21058 .7233 .20244 Mtetra
.7233 .20244 .72902 .21058 .74154 .20614 .73586 .19797 Mtetra
.73586 .19797 .74154 .20614 .75412 .20168 .74848 .19347 Mtetra
.685 .535 .676 r
.08027 .42481 .08543 .4483 .0982 .42358 .09116 .41434 Mtetra
.479 .603 .898 r
.09116 .41434 .0982 .42358 .10792 .42189 .10063 .41456 Mtetra
.577 .703 .928 r
.10063 .41456 .10792 .42189 .11754 .42141 .11043 .41274 Mtetra
.929 .698 .569 r
.11043 .41274 .11754 .42141 .12842 .4111 .13472 .2955 Mtetra
0 0 .146 r
.13472 .2955 .12842 .4111 .13813 .41049 .13092 .40297 Mtetra
.586 .702 .922 r
.13092 .40297 .13813 .41049 .14808 .40841 .14087 .40097 Mtetra
.545 .69 .934 r
.14087 .40097 .14808 .40841 .15675 .41792 .15078 .39969 Mtetra
.72 .586 .706 r
.15078 .39969 .15675 .41792 .16875 .39841 .16185 .3887 Mtetra
.475 .592 .89 r
.16185 .3887 .16875 .39841 .17881 .39643 .17165 .38907 Mtetra
.603 .715 .924 r
.17165 .38907 .17881 .39643 .18895 .39419 .18183 .38665 Mtetra
.535 .685 .935 r
.18183 .38665 .18895 .39419 .19615 .42144 .19191 .38553 Mtetra
.642 .467 .631 r
.19191 .38553 .19615 .42144 .20993 .38396 .20302 .3748 Mtetra
.515 .628 .901 r
.20302 .3748 .20993 .38396 .2202 .3817 .21312 .37432 Mtetra
.613 .721 .922 r
.21312 .37432 .2202 .3817 .23055 .37904 .22349 .37163 Mtetra
.594 .714 .928 r
.22349 .37163 .23055 .37904 .24074 .37877 .23388 .36934 Mtetra
.888 .725 .674 r
.23388 .36934 .24074 .37877 .25191 .36779 .24651 .34206 Mtetra
.006 .064 .572 r
.24651 .34206 .25191 .36779 .26228 .36631 .25531 .3587 Mtetra
.61 .715 .92 r
.25531 .3587 .26228 .36631 .27284 .36336 .26586 .35603 Mtetra
.626 .731 .922 r
.26586 .35603 .27284 .36336 .28344 .36041 .27649 .35296 Mtetra
.606 .721 .926 r
.27649 .35296 .28344 .36041 .29395 .35936 .28713 .35035 Mtetra
.948 .706 .538 r
.28713 .35035 .29395 .35936 .3052 .34839 .30618 .231 Mtetra
0 0 .268 r
.30618 .231 .3052 .34839 .31581 .34716 .30896 .33939 Mtetra
.612 .715 .918 r
.30896 .33939 .31581 .34716 .3266 .344 .31974 .33661 Mtetra
.636 .737 .921 r
.31974 .33661 .3266 .344 .33746 .34057 .33062 .33323 Mtetra
.64 .74 .921 r
.33062 .33323 .33746 .34057 .34836 .33713 .34155 .32974 Mtetra
.636 .738 .922 r
.34155 .32974 .34836 .33713 .35929 .33399 .35252 .32635 Mtetra
.601 .718 .927 r
.35252 .32635 .35929 .33399 .3701 .33455 .3635 .32377 Mtetra
.837 .718 .733 r
.3635 .32377 .3701 .33455 .38156 .32222 .37519 .30731 Mtetra
.326 .405 .79 r
.37519 .30731 .38156 .32222 .39259 .31995 .3859 .31218 Mtetra
.627 .726 .919 r
.3859 .31218 .39259 .31995 .40372 .31644 .39705 .30895 Mtetra
.646 .743 .92 r
.39705 .30895 .40372 .31644 .41491 .31265 .40827 .30523 Mtetra
.652 .748 .92 r
.40827 .30523 .41491 .31265 .42616 .30874 .41954 .30134 Mtetra
.655 .75 .92 r
.41954 .30134 .42616 .30874 .43745 .30475 .43086 .29734 Mtetra
.657 .752 .92 r
.43086 .29734 .43745 .30475 .44879 .30069 .44223 .29328 Mtetra
.658 .753 .92 r
.44223 .29328 .44879 .30069 .46018 .2966 .45365 .28916 Mtetra
.659 .754 .92 r
.45365 .28916 .46018 .2966 .47161 .29247 .46511 .28501 Mtetra
.46511 .28501 .47161 .29247 .4831 .28833 .47663 .28083 Mtetra
.47663 .28083 .4831 .28833 .49463 .28417 .48819 .27664 Mtetra
.48819 .27664 .49463 .28417 .50621 .28 .4998 .27243 Mtetra
.658 .753 .92 r
.4998 .27243 .50621 .28 .51784 .27582 .51147 .26822 Mtetra
.51147 .26822 .51784 .27582 .52952 .27163 .52318 .264 Mtetra
.52318 .264 .52952 .27163 .54124 .26743 .53493 .25976 Mtetra
.53493 .25976 .54124 .26743 .55302 .26322 .54674 .25551 Mtetra
.54674 .25551 .55302 .26322 .56484 .25898 .5586 .25124 Mtetra
.5586 .25124 .56484 .25898 .57672 .25474 .57051 .24696 Mtetra
.57051 .24696 .57672 .25474 .58865 .25048 .58248 .24266 Mtetra
.657 .753 .92 r
.58248 .24266 .58865 .25048 .60063 .2462 .59449 .23835 Mtetra
.59449 .23835 .60063 .2462 .61266 .2419 .60655 .23402 Mtetra
.60655 .23402 .61266 .2419 .62474 .23759 .61867 .22967 Mtetra
.657 .752 .92 r
.61867 .22967 .62474 .23759 .63687 .23326 .63084 .22531 Mtetra
.63084 .22531 .63687 .23326 .64906 .22891 .64306 .22092 Mtetra
.64306 .22092 .64906 .22891 .6613 .22454 .65534 .21652 Mtetra
.65534 .21652 .6613 .22454 .67359 .22016 .66767 .2121 Mtetra
.66767 .2121 .67359 .22016 .68593 .21576 .68005 .20767 Mtetra
.68005 .20767 .68593 .21576 .69833 .21134 .69249 .20321 Mtetra
.69249 .20321 .69833 .21134 .71079 .2069 .70498 .19873 Mtetra
.70498 .19873 .71079 .2069 .7233 .20244 .71752 .19424 Mtetra
.71752 .19424 .7233 .20244 .73586 .19797 .73013 .18973 Mtetra
.73013 .18973 .73586 .19797 .74848 .19347 .74278 .1852 Mtetra
.83 .378 0 r
.07302 .41656 .08027 .42481 .09116 .41434 .08042 .4318 Mtetra
.797 .892 .476 r
.08042 .4318 .09116 .41434 .10063 .41456 .09333 .40694 Mtetra
.573 .693 .923 r
.09333 .40694 .10063 .41456 .11043 .41274 .10313 .40518 Mtetra
.5 .668 .938 r
.10313 .40518 .11043 .41274 .13472 .2955 .11283 .40465 Mtetra
.453 .199 .437 r
.11283 .40465 .13472 .2955 .13092 .40297 .12381 .39425 Mtetra
.522 .641 .908 r
.12381 .39425 .13092 .40297 .14087 .40097 .1336 .39358 Mtetra
.59 .709 .926 r
.1336 .39358 .14087 .40097 .15078 .39969 .14363 .39144 Mtetra
0 0 .505 r
.14363 .39144 .15078 .39969 .16185 .3887 .15236 .40094 Mtetra
.785 .919 .539 r
.15236 .40094 .16185 .3887 .17165 .38907 .16449 .3813 Mtetra
.585 .698 .92 r
.16449 .3813 .17165 .38907 .18183 .38665 .17463 .37926 Mtetra
.595 .714 .927 r
.17463 .37926 .18183 .38665 .19191 .38553 .18485 .37696 Mtetra
.924 .535 .179 r
.18485 .37696 .19191 .38553 .20302 .3748 .19207 .40426 Mtetra
.668 .745 .249 r
.19207 .40426 .20302 .3748 .21312 .37432 .20602 .36657 Mtetra
.596 .705 .92 r
.20602 .36657 .21312 .37432 .22349 .37163 .21637 .36424 Mtetra
.613 .723 .924 r
.21637 .36424 .22349 .37163 .23388 .36934 .22682 .36152 Mtetra
.486 .659 .938 r
.22682 .36152 .23388 .36934 .24651 .34206 .23709 .36119 Mtetra
.064 0 .049 r
.23709 .36119 .24651 .34206 .25531 .3587 .24836 .35011 Mtetra
.561 .669 .911 r
.24836 .35011 .25531 .3587 .26586 .35603 .25883 .34857 Mtetra
.623 .727 .921 r
.25883 .34857 .26586 .35603 .27649 .35296 .26948 .34555 Mtetra
.622 .729 .923 r
.26948 .34555 .27649 .35296 .28713 .35035 .28017 .34253 Mtetra
.531 .682 .935 r
.28017 .34253 .28713 .35035 .30618 .231 .29077 .34142 Mtetra
.454 .201 .439 r
.29077 .34142 .30618 .231 .30896 .33939 .30214 .33035 Mtetra
.549 .655 .905 r
.30214 .33035 .30896 .33939 .31974 .33661 .31284 .32905 Mtetra
.629 .731 .92 r
.31284 .32905 .31974 .33661 .33062 .33323 .32373 .32582 Mtetra
.639 .739 .921 r
.32373 .32582 .33062 .33323 .34155 .32974 .33469 .32232 Mtetra
.639 .74 .922 r
.33469 .32232 .34155 .32974 .35252 .32635 .34569 .31881 Mtetra
.627 .733 .924 r
.34569 .31881 .35252 .32635 .3635 .32377 .35672 .31559 Mtetra
.436 .63 .936 r
.35672 .31559 .3635 .32377 .37519 .30731 .36762 .31609 Mtetra
0 0 0 r
.36762 .31609 .37519 .30731 .3859 .31218 .3792 .30365 Mtetra
.59 .691 .912 r
.3792 .30365 .3859 .31218 .39705 .30895 .39033 .30131 Mtetra
.639 .738 .92 r
.39033 .30131 .39705 .30895 .40827 .30523 .40157 .29772 Mtetra
.649 .746 .92 r
.40157 .29772 .40827 .30523 .41954 .30134 .41287 .29386 Mtetra
.653 .749 .92 r
.41287 .29386 .41954 .30134 .43086 .29734 .42421 .28987 Mtetra
.656 .751 .92 r
.42421 .28987 .43086 .29734 .44223 .29328 .43562 .28579 Mtetra
.657 .753 .92 r
.43562 .28579 .44223 .29328 .45365 .28916 .44706 .28166 Mtetra
.658 .753 .92 r
.44706 .28166 .45365 .28916 .46511 .28501 .45856 .27748 Mtetra
.659 .754 .92 r
.45856 .27748 .46511 .28501 .47663 .28083 .47011 .27328 Mtetra
.47011 .27328 .47663 .28083 .48819 .27664 .4817 .26905 Mtetra
.4817 .26905 .48819 .27664 .4998 .27243 .49335 .26481 Mtetra
.659 .753 .92 r
.49335 .26481 .4998 .27243 .51147 .26822 .50504 .26056 Mtetra
.658 .753 .92 r
.50504 .26056 .51147 .26822 .52318 .264 .51678 .2563 Mtetra
.51678 .2563 .52318 .264 .53493 .25976 .52858 .25203 Mtetra
.52858 .25203 .53493 .25976 .54674 .25551 .54042 .24774 Mtetra
.54042 .24774 .54674 .25551 .5586 .25124 .55231 .24344 Mtetra
.55231 .24344 .5586 .25124 .57051 .24696 .56426 .23912 Mtetra
.56426 .23912 .57051 .24696 .58248 .24266 .57625 .23479 Mtetra
.657 .753 .92 r
.57625 .23479 .58248 .24266 .59449 .23835 .5883 .23044 Mtetra
.5883 .23044 .59449 .23835 .60655 .23402 .6004 .22607 Mtetra
.6004 .22607 .60655 .23402 .61867 .22967 .61256 .22169 Mtetra
.657 .752 .92 r
.61256 .22169 .61867 .22967 .63084 .22531 .62476 .21729 Mtetra
.62476 .21729 .63084 .22531 .64306 .22092 .63702 .21287 Mtetra
.63702 .21287 .64306 .22092 .65534 .21652 .64933 .20843 Mtetra
.64933 .20843 .65534 .21652 .66767 .2121 .6617 .20398 Mtetra
.6617 .20398 .66767 .2121 .68005 .20767 .67412 .19951 Mtetra
.67412 .19951 .68005 .20767 .69249 .20321 .68659 .19501 Mtetra
.68659 .19501 .69249 .20321 .70498 .19873 .69912 .1905 Mtetra
.69912 .1905 .70498 .19873 .71752 .19424 .71171 .18597 Mtetra
.71171 .18597 .71752 .19424 .73013 .18973 .72435 .18142 Mtetra
.72435 .18142 .73013 .18973 .74278 .1852 .73704 .17685 Mtetra
.523 .678 .936 r
.06561 .40904 .07302 .41656 .08042 .4318 .07523 .40813 Mtetra
.685 .535 .676 r
.07523 .40813 .08042 .4318 .09333 .40694 .08621 .39757 Mtetra
.478 .603 .898 r
.08621 .39757 .09333 .40694 .10313 .40518 .09576 .39774 Mtetra
.577 .703 .928 r
.09576 .39774 .10313 .40518 .11283 .40465 .10564 .39585 Mtetra
.93 .699 .567 r
.10564 .39585 .11283 .40465 .12381 .39425 .13031 .27812 Mtetra
0 0 .138 r
.13031 .27812 .12381 .39425 .1336 .39358 .12631 .38594 Mtetra
.586 .702 .922 r
.12631 .38594 .1336 .39358 .14363 .39144 .13634 .38387 Mtetra
.545 .69 .934 r
.13634 .38387 .14363 .39144 .15236 .40094 .14633 .38254 Mtetra
.72 .586 .706 r
.14633 .38254 .15236 .40094 .16449 .3813 .1575 .37145 Mtetra
.474 .592 .891 r
.1575 .37145 .16449 .3813 .17463 .37926 .16739 .37177 Mtetra
.603 .715 .924 r
.16739 .37177 .17463 .37926 .18485 .37696 .17764 .36928 Mtetra
.535 .685 .935 r
.17764 .36928 .18485 .37696 .19207 .40426 .18781 .3681 Mtetra
.641 .466 .63 r
.18781 .3681 .19207 .40426 .20602 .36657 .19903 .35727 Mtetra
.515 .628 .901 r
.19903 .35727 .20602 .36657 .21637 .36424 .20921 .35673 Mtetra
.613 .721 .922 r
.20921 .35673 .21637 .36424 .22682 .36152 .21967 .35398 Mtetra
.594 .714 .928 r
.21967 .35398 .22682 .36152 .23709 .36119 .23015 .35161 Mtetra
.889 .726 .674 r
.23015 .35161 .23709 .36119 .24836 .35011 .24292 .32418 Mtetra
0 .059 .57 r
.24292 .32418 .24836 .35011 .25883 .34857 .25178 .34082 Mtetra
.61 .715 .92 r
.25178 .34082 .25883 .34857 .26948 .34555 .26242 .33809 Mtetra
.626 .731 .922 r
.26242 .33809 .26948 .34555 .28017 .34253 .27314 .33495 Mtetra
.606 .721 .926 r
.27314 .33495 .28017 .34253 .29077 .34142 .28388 .33227 Mtetra
.949 .706 .536 r
.28388 .33227 .29077 .34142 .30214 .33035 .30322 .21243 Mtetra
0 0 .261 r
.30322 .21243 .30214 .33035 .31284 .32905 .30591 .32114 Mtetra
.612 .715 .919 r
.30591 .32114 .31284 .32905 .32373 .32582 .3168 .31829 Mtetra
.636 .737 .921 r
.3168 .31829 .32373 .32582 .33469 .32232 .32777 .31484 Mtetra
.64 .74 .921 r
.32777 .31484 .33469 .32232 .34569 .31881 .3388 .31127 Mtetra
.636 .738 .922 r
.3388 .31127 .34569 .31881 .35672 .31559 .34987 .3078 Mtetra
.601 .718 .927 r
.34987 .3078 .35672 .31559 .36762 .31609 .36095 .30516 Mtetra
.838 .719 .733 r
.36095 .30516 .36762 .31609 .3792 .30365 .37277 .28857 Mtetra
.324 .404 .79 r
.37277 .28857 .3792 .30365 .39033 .30131 .38357 .29339 Mtetra
.627 .726 .919 r
.38357 .29339 .39033 .30131 .40157 .29772 .39482 .29009 Mtetra
.646 .743 .92 r
.39482 .29009 .40157 .29772 .41287 .29386 .40614 .28629 Mtetra
.652 .748 .92 r
.40614 .28629 .41287 .29386 .42421 .28987 .41752 .28232 Mtetra
.655 .75 .92 r
.41752 .28232 .42421 .28987 .43562 .28579 .42895 .27824 Mtetra
.657 .752 .92 r
.42895 .27824 .43562 .28579 .44706 .28166 .44043 .2741 Mtetra
.658 .753 .92 r
.44043 .2741 .44706 .28166 .45856 .27748 .45196 .2699 Mtetra
.659 .754 .92 r
.45196 .2699 .45856 .27748 .47011 .27328 .46354 .26566 Mtetra
.46354 .26566 .47011 .27328 .4817 .26905 .47517 .2614 Mtetra
.47517 .2614 .4817 .26905 .49335 .26481 .48684 .25713 Mtetra
.48684 .25713 .49335 .26481 .50504 .26056 .49857 .25284 Mtetra
.658 .753 .92 r
.49857 .25284 .50504 .26056 .51678 .2563 .51034 .24854 Mtetra
.51034 .24854 .51678 .2563 .52858 .25203 .52217 .24423 Mtetra
.52217 .24423 .52858 .25203 .54042 .24774 .53405 .23991 Mtetra
.53405 .23991 .54042 .24774 .55231 .24344 .54597 .23557 Mtetra
.54597 .23557 .55231 .24344 .56426 .23912 .55795 .23122 Mtetra
.55795 .23122 .56426 .23912 .57625 .23479 .56998 .22685 Mtetra
.56998 .22685 .57625 .23479 .5883 .23044 .58207 .22247 Mtetra
.657 .753 .92 r
.58207 .22247 .5883 .23044 .6004 .22607 .5942 .21807 Mtetra
.5942 .21807 .6004 .22607 .61256 .22169 .60639 .21365 Mtetra
.60639 .21365 .61256 .22169 .62476 .21729 .61863 .20921 Mtetra
.657 .752 .92 r
.61863 .20921 .62476 .21729 .63702 .21287 .63093 .20475 Mtetra
.63093 .20475 .63702 .21287 .64933 .20843 .64327 .20028 Mtetra
.64327 .20028 .64933 .20843 .6617 .20398 .65568 .19579 Mtetra
.65568 .19579 .6617 .20398 .67412 .19951 .66813 .19128 Mtetra
.66813 .19128 .67412 .19951 .68659 .19501 .68065 .18675 Mtetra
.68065 .18675 .68659 .19501 .69912 .1905 .69322 .1822 Mtetra
.69322 .1822 .69912 .1905 .71171 .18597 .70584 .17763 Mtetra
.70584 .17763 .71171 .18597 .72435 .18142 .71852 .17304 Mtetra
.71852 .17304 .72435 .18142 .73704 .17685 .73126 .16844 Mtetra
.57 .696 .927 r
.05815 .40148 .06561 .40904 .07523 .40813 .06789 .39974 Mtetra
.827 .374 0 r
.06789 .39974 .07523 .40813 .08621 .39757 .07532 .415 Mtetra
.804 .897 .484 r
.07532 .415 .08621 .39757 .09576 .39774 .08838 .38998 Mtetra
.573 .693 .923 r
.08838 .38998 .09576 .39774 .10564 .39585 .09826 .38817 Mtetra
.501 .668 .938 r
.09826 .38817 .10564 .39585 .13031 .27812 .10803 .38758 Mtetra
.448 .192 .432 r
.10803 .38758 .13031 .27812 .12631 .38594 .11911 .37708 Mtetra
.521 .641 .908 r
.11911 .37708 .12631 .38594 .13634 .38387 .12898 .37636 Mtetra
.59 .709 .926 r
.12898 .37636 .13634 .38387 .14633 .38254 .13909 .37415 Mtetra
0 0 .512 r
.13909 .37415 .14633 .38254 .1575 .37145 .14788 .38364 Mtetra
.792 .923 .546 r
.14788 .38364 .1575 .37145 .16739 .37177 .16014 .36386 Mtetra
.585 .698 .92 r
.16014 .36386 .16739 .37177 .17764 .36928 .17036 .36175 Mtetra
.595 .714 .927 r
.17036 .36175 .17764 .36928 .18781 .3681 .18067 .35939 Mtetra
.923 .532 .172 r
.18067 .35939 .18781 .3681 .19903 .35727 .18791 .38675 Mtetra
.677 .752 .258 r
.18791 .38675 .19903 .35727 .20921 .35673 .20203 .34885 Mtetra
.596 .705 .92 r
.20203 .34885 .20921 .35673 .21967 .35398 .21248 .34646 Mtetra
.613 .723 .924 r
.21248 .34646 .21967 .35398 .23015 .35161 .22301 .34366 Mtetra
.486 .659 .938 r
.22301 .34366 .23015 .35161 .24292 .32418 .23337 .34328 Mtetra
.049 0 .034 r
.23337 .34328 .24292 .32418 .25178 .34082 .24475 .33209 Mtetra
.561 .669 .911 r
.24475 .33209 .25178 .34082 .26242 .33809 .25531 .33049 Mtetra
.623 .727 .921 r
.25531 .33049 .26242 .33809 .27314 .33495 .26605 .3274 Mtetra
.622 .729 .923 r
.26605 .3274 .27314 .33495 .28388 .33227 .27684 .32431 Mtetra
.531 .682 .935 r
.27684 .32431 .28388 .33227 .30322 .21243 .28754 .32312 Mtetra
.449 .194 .434 r
.28754 .32312 .30322 .21243 .30591 .32114 .29902 .31195 Mtetra
.549 .655 .905 r
.29902 .31195 .30591 .32114 .3168 .31829 .30981 .31059 Mtetra
.629 .731 .92 r
.30981 .31059 .3168 .31829 .32777 .31484 .3208 .30728 Mtetra
.639 .739 .921 r
.3208 .30728 .32777 .31484 .3388 .31127 .33186 .30371 Mtetra
.639 .74 .922 r
.33186 .30371 .3388 .31127 .34987 .3078 .34296 .30012 Mtetra
.627 .733 .923 r
.34296 .30012 .34987 .3078 .36095 .30516 .3541 .29682 Mtetra
.437 .63 .936 r
.3541 .29682 .36095 .30516 .37277 .28857 .3651 .29727 Mtetra
0 0 0 r
.3651 .29727 .37277 .28857 .38357 .29339 .37679 .28471 Mtetra
.59 .691 .912 r
.37679 .28471 .38357 .29339 .39482 .29009 .38803 .2823 Mtetra
.639 .738 .92 r
.38803 .2823 .39482 .29009 .40614 .28629 .39937 .27863 Mtetra
.649 .746 .92 r
.39937 .27863 .40614 .28629 .41752 .28232 .41078 .27469 Mtetra
.653 .749 .92 r
.41078 .27469 .41752 .28232 .42895 .27824 .42223 .27062 Mtetra
.656 .751 .92 r
.42223 .27062 .42895 .27824 .44043 .2741 .43374 .26646 Mtetra
.657 .753 .92 r
.43374 .26646 .44043 .2741 .45196 .2699 .4453 .26225 Mtetra
.658 .753 .92 r
.4453 .26225 .45196 .2699 .46354 .26566 .45691 .25798 Mtetra
.659 .754 .92 r
.45691 .25798 .46354 .26566 .47517 .2614 .46857 .25369 Mtetra
.46857 .25369 .47517 .2614 .48684 .25713 .48028 .24938 Mtetra
.48028 .24938 .48684 .25713 .49857 .25284 .49204 .24506 Mtetra
.659 .753 .92 r
.49204 .24506 .49857 .25284 .51034 .24854 .50385 .24072 Mtetra
.658 .753 .92 r
.50385 .24072 .51034 .24854 .52217 .24423 .51571 .23638 Mtetra
.51571 .23638 .52217 .24423 .53405 .23991 .52762 .23202 Mtetra
.52762 .23202 .53405 .23991 .54597 .23557 .53958 .22764 Mtetra
.53958 .22764 .54597 .23557 .55795 .23122 .5516 .22326 Mtetra
.5516 .22326 .55795 .23122 .56998 .22685 .56366 .21885 Mtetra
.56366 .21885 .56998 .22685 .58207 .22247 .57578 .21443 Mtetra
.657 .753 .92 r
.57578 .21443 .58207 .22247 .5942 .21807 .58795 .20999 Mtetra
.58795 .20999 .5942 .21807 .60639 .21365 .60017 .20554 Mtetra
.60017 .20554 .60639 .21365 .61863 .20921 .61245 .20106 Mtetra
.657 .752 .92 r
.61245 .20106 .61863 .20921 .63093 .20475 .62478 .19657 Mtetra
.62478 .19657 .63093 .20475 .64327 .20028 .63717 .19206 Mtetra
.63717 .19206 .64327 .20028 .65568 .19579 .64961 .18753 Mtetra
.64961 .18753 .65568 .19579 .66813 .19128 .6621 .18298 Mtetra
.6621 .18298 .66813 .19128 .68065 .18675 .67465 .17842 Mtetra
.67465 .17842 .68065 .18675 .69322 .1822 .68726 .17383 Mtetra
.68726 .17383 .69322 .1822 .70584 .17763 .69992 .16923 Mtetra
.69992 .16923 .70584 .17763 .71852 .17304 .71264 .1646 Mtetra
.71264 .1646 .71852 .17304 .73126 .16844 .72542 .15995 Mtetra
.538 .664 .918 r
.05074 .3932 .05815 .40148 .06789 .39974 .0604 .3921 Mtetra
.523 .678 .935 r
.0604 .3921 .06789 .39974 .07532 .415 .07009 .39113 Mtetra
.685 .534 .675 r
.07009 .39113 .07532 .415 .08838 .38998 .08118 .38047 Mtetra
.478 .603 .899 r
.08118 .38047 .08838 .38998 .09826 .38817 .0908 .38059 Mtetra
.577 .703 .928 r
.0908 .38059 .09826 .38817 .10803 .38758 .10076 .37865 Mtetra
.931 .699 .566 r
.10076 .37865 .10803 .38758 .11911 .37708 .12582 .26042 Mtetra
0 0 .131 r
.12582 .26042 .11911 .37708 .12898 .37636 .12161 .36858 Mtetra
.586 .702 .923 r
.12161 .36858 .12898 .37636 .13909 .37415 .13172 .36645 Mtetra
.546 .69 .933 r
.13172 .36645 .13909 .37415 .14788 .38364 .1418 .36506 Mtetra
.72 .587 .706 r
.1418 .36506 .14788 .38364 .16014 .36386 .15307 .35386 Mtetra
.474 .592 .891 r
.15307 .35386 .16014 .36386 .17036 .36175 .16304 .35413 Mtetra
.603 .715 .924 r
.16304 .35413 .17036 .36175 .18067 .35939 .17338 .35158 Mtetra
.536 .685 .935 r
.17338 .35158 .18067 .35939 .18791 .38675 .18364 .35034 Mtetra
.64 .464 .629 r
.18364 .35034 .18791 .38675 .20203 .34885 .19496 .3394 Mtetra
.515 .628 .901 r
.19496 .3394 .20203 .34885 .21248 .34646 .20523 .33881 Mtetra
.613 .721 .922 r
.20523 .33881 .21248 .34646 .22301 .34366 .21578 .33598 Mtetra
.594 .714 .927 r
.21578 .33598 .22301 .34366 .23337 .34328 .22635 .33355 Mtetra
.89 .727 .673 r
.22635 .33355 .23337 .34328 .24475 .33209 .23927 .30595 Mtetra
0 .055 .568 r
.23927 .30595 .24475 .33209 .25531 .33049 .24818 .32259 Mtetra
.61 .716 .92 r
.24818 .32259 .25531 .33049 .26605 .3274 .25891 .31979 Mtetra
.626 .731 .922 r
.25891 .31979 .26605 .3274 .27684 .32431 .26973 .31658 Mtetra
.606 .721 .926 r
.26973 .31658 .27684 .32431 .28754 .32312 .28057 .31383 Mtetra
.95 .707 .534 r
.28057 .31383 .28754 .32312 .29902 .31195 .30021 .1935 Mtetra
0 0 .255 r
.30021 .1935 .29902 .31195 .30981 .31059 .3028 .30253 Mtetra
.612 .715 .919 r
.3028 .30253 .30981 .31059 .3208 .30728 .31379 .29961 Mtetra
.636 .737 .921 r
.31379 .29961 .3208 .30728 .33186 .30371 .32486 .29608 Mtetra
.64 .74 .921 r
.32486 .29608 .33186 .30371 .34296 .30012 .336 .29244 Mtetra
.636 .738 .922 r
.336 .29244 .34296 .30012 .3541 .29682 .34717 .28889 Mtetra
.601 .718 .927 r
.34717 .28889 .3541 .29682 .3651 .29727 .35835 .28617 Mtetra
.839 .72 .733 r
.35835 .28617 .3651 .29727 .37679 .28471 .37029 .26945 Mtetra
.323 .403 .79 r
.37029 .26945 .37679 .28471 .38803 .2823 .38119 .27423 Mtetra
.627 .726 .919 r
.38119 .27423 .38803 .2823 .39937 .27863 .39255 .27085 Mtetra
.646 .743 .92 r
.39255 .27085 .39937 .27863 .41078 .27469 .40398 .26697 Mtetra
.652 .748 .92 r
.40398 .26697 .41078 .27469 .42223 .27062 .41547 .26291 Mtetra
.655 .75 .92 r
.41547 .26291 .42223 .27062 .43374 .26646 .42701 .25876 Mtetra
.657 .752 .92 r
.42701 .25876 .43374 .26646 .4453 .26225 .4386 .25453 Mtetra
.658 .753 .92 r
.4386 .25453 .4453 .26225 .45691 .25798 .45024 .25024 Mtetra
.659 .754 .92 r
.45024 .25024 .45691 .25798 .46857 .25369 .46193 .24592 Mtetra
.46193 .24592 .46857 .25369 .48028 .24938 .47367 .24158 Mtetra
.47367 .24158 .48028 .24938 .49204 .24506 .48546 .23722 Mtetra
.48546 .23722 .49204 .24506 .50385 .24072 .49731 .23285 Mtetra
.658 .753 .92 r
.49731 .23285 .50385 .24072 .51571 .23638 .5092 .22846 Mtetra
.5092 .22846 .51571 .23638 .52762 .23202 .52114 .22406 Mtetra
.52114 .22406 .52762 .23202 .53958 .22764 .53314 .21965 Mtetra
.53314 .21965 .53958 .22764 .5516 .22326 .54519 .21523 Mtetra
.54519 .21523 .5516 .22326 .56366 .21885 .55729 .21079 Mtetra
.55729 .21079 .56366 .21885 .57578 .21443 .56944 .20633 Mtetra
.56944 .20633 .57578 .21443 .58795 .20999 .58165 .20185 Mtetra
.657 .753 .92 r
.58165 .20185 .58795 .20999 .60017 .20554 .59391 .19736 Mtetra
.59391 .19736 .60017 .20554 .61245 .20106 .60622 .19285 Mtetra
.60622 .19285 .61245 .20106 .62478 .19657 .61859 .18832 Mtetra
.657 .752 .92 r
.61859 .18832 .62478 .19657 .63717 .19206 .63101 .18377 Mtetra
.63101 .18377 .63717 .19206 .64961 .18753 .64349 .17921 Mtetra
.64349 .17921 .64961 .18753 .6621 .18298 .65602 .17462 Mtetra
.65602 .17462 .6621 .18298 .67465 .17842 .66861 .17002 Mtetra
.66861 .17002 .67465 .17842 .68726 .17383 .68126 .16539 Mtetra
.68126 .16539 .68726 .17383 .69992 .16923 .69396 .16075 Mtetra
.69396 .16075 .69992 .16923 .71264 .1646 .70672 .15608 Mtetra
.70672 .15608 .71264 .1646 .72542 .15995 .71953 .1514 Mtetra
.074 .194 .685 r
.04465 .37572 .05074 .3932 .0604 .3921 .05285 .38441 Mtetra
.57 .696 .927 r
.05285 .38441 .0604 .3921 .07009 .39113 .06267 .38262 Mtetra
.823 .369 0 r
.06267 .38262 .07009 .39113 .08118 .38047 .07013 .39788 Mtetra
.81 .901 .491 r
.07013 .39788 .08118 .38047 .0908 .38059 .08333 .3727 Mtetra
.573 .693 .923 r
.08333 .3727 .0908 .38059 .10076 .37865 .09329 .37083 Mtetra
.501 .668 .937 r
.09329 .37083 .10076 .37865 .12582 .26042 .10314 .37018 Mtetra
.443 .185 .426 r
.10314 .37018 .12582 .26042 .12161 .36858 .11433 .35959 Mtetra
.521 .641 .908 r
.11433 .35959 .12161 .36858 .13172 .36645 .12428 .35881 Mtetra
.59 .709 .926 r
.12428 .35881 .13172 .36645 .1418 .36506 .13447 .35654 Mtetra
0 0 .519 r
.13447 .35654 .1418 .36506 .15307 .35386 .14331 .366 Mtetra
.798 .928 .553 r
.14331 .366 .15307 .35386 .16304 .35413 .1557 .34609 Mtetra
.585 .698 .92 r
.1557 .34609 .16304 .35413 .17338 .35158 .16602 .34391 Mtetra
.595 .714 .927 r
.16602 .34391 .17338 .35158 .18364 .35034 .17642 .34148 Mtetra
.921 .529 .165 r
.17642 .34148 .18364 .35034 .19496 .3394 .18367 .3689 Mtetra
.686 .76 .267 r
.18367 .3689 .19496 .3394 .20523 .33881 .19797 .33079 Mtetra
.596 .705 .92 r
.19797 .33079 .20523 .33881 .21578 .33598 .2085 .32832 Mtetra
.613 .723 .924 r
.2085 .32832 .21578 .33598 .22635 .33355 .21913 .32546 Mtetra
.487 .659 .938 r
.21913 .32546 .22635 .33355 .23927 .30595 .22958 .32501 Mtetra
.034 0 .019 r
.22958 .32501 .23927 .30595 .24818 .32259 .24107 .31372 Mtetra
.56 .669 .911 r
.24107 .31372 .24818 .32259 .25891 .31979 .25173 .31205 Mtetra
.623 .727 .921 r
.25173 .31205 .25891 .31979 .26973 .31658 .26256 .30888 Mtetra
.622 .729 .923 r
.26256 .30888 .26973 .31658 .28057 .31383 .27345 .30572 Mtetra
.531 .682 .935 r
.27345 .30572 .28057 .31383 .30021 .1935 .28424 .30447 Mtetra
.444 .187 .429 r
.28424 .30447 .30021 .1935 .3028 .30253 .29583 .2932 Mtetra
.549 .655 .905 r
.29583 .2932 .3028 .30253 .31379 .29961 .30673 .29176 Mtetra
.629 .731 .92 r
.30673 .29176 .31379 .29961 .32486 .29608 .31782 .28838 Mtetra
.639 .739 .921 r
.31782 .28838 .32486 .29608 .336 .29244 .32898 .28472 Mtetra
.639 .74 .922 r
.32898 .28472 .336 .29244 .34717 .28889 .34018 .28106 Mtetra
.627 .733 .923 r
.34018 .28106 .34717 .28889 .35835 .28617 .35143 .27769 Mtetra
.438 .63 .935 r
.35143 .27769 .35835 .28617 .37029 .26945 .36252 .27806 Mtetra
0 0 0 r
.36252 .27806 .37029 .26945 .38119 .27423 .37434 .2654 Mtetra
.59 .692 .912 r
.37434 .2654 .38119 .27423 .39255 .27085 .38568 .26291 Mtetra
.639 .738 .92 r
.38568 .26291 .39255 .27085 .40398 .26697 .39713 .25916 Mtetra
.649 .746 .92 r
.39713 .25916 .40398 .26697 .41547 .26291 .40864 .25513 Mtetra
.653 .749 .92 r
.40864 .25513 .41547 .26291 .42701 .25876 .42021 .25098 Mtetra
.656 .751 .92 r
.42021 .25098 .42701 .25876 .4386 .25453 .43184 .24674 Mtetra
.657 .753 .92 r
.43184 .24674 .4386 .25453 .45024 .25024 .44351 .24244 Mtetra
.658 .753 .92 r
.44351 .24244 .45024 .25024 .46193 .24592 .45523 .23809 Mtetra
.659 .754 .92 r
.45523 .23809 .46193 .24592 .47367 .24158 .46701 .23371 Mtetra
.46701 .23371 .47367 .24158 .48546 .23722 .47883 .22932 Mtetra
.47883 .22932 .48546 .23722 .49731 .23285 .49071 .22491 Mtetra
.659 .753 .92 r
.49071 .22491 .49731 .23285 .5092 .22846 .50264 .22048 Mtetra
.658 .753 .92 r
.50264 .22048 .5092 .22846 .52114 .22406 .51461 .21605 Mtetra
.51461 .21605 .52114 .22406 .53314 .21965 .52664 .2116 Mtetra
.52664 .2116 .53314 .21965 .54519 .21523 .53873 .20714 Mtetra
.53873 .20714 .54519 .21523 .55729 .21079 .55086 .20266 Mtetra
.55086 .20266 .55729 .21079 .56944 .20633 .56305 .19816 Mtetra
.56305 .19816 .56944 .20633 .58165 .20185 .57529 .19365 Mtetra
.657 .753 .92 r
.57529 .19365 .58165 .20185 .59391 .19736 .58759 .18912 Mtetra
.58759 .18912 .59391 .19736 .60622 .19285 .59994 .18457 Mtetra
.59994 .18457 .60622 .19285 .61859 .18832 .61235 .18001 Mtetra
.657 .752 .92 r
.61235 .18001 .61859 .18832 .63101 .18377 .62481 .17542 Mtetra
.62481 .17542 .63101 .18377 .64349 .17921 .63732 .17082 Mtetra
.63732 .17082 .64349 .17921 .65602 .17462 .64989 .16619 Mtetra
.64989 .16619 .65602 .17462 .66861 .17002 .66252 .16155 Mtetra
.66252 .16155 .66861 .17002 .68126 .16539 .6752 .15688 Mtetra
.6752 .15688 .68126 .16539 .69396 .16075 .68795 .1522 Mtetra
.68795 .1522 .69396 .16075 .70672 .15608 .70074 .1475 Mtetra
.70074 .1475 .70672 .15608 .71953 .1514 .7136 .14277 Mtetra
0 0 0 r
.03417 .38698 .04465 .37572 .05285 .38441 .04535 .376 Mtetra
.538 .664 .918 r
.04535 .376 .05285 .38441 .06267 .38262 .05508 .37484 Mtetra
.523 .678 .935 r
.05508 .37484 .06267 .38262 .07013 .39788 .06485 .37382 Mtetra
.685 .534 .675 r
.06485 .37382 .07013 .39788 .08333 .3727 .07604 .36306 Mtetra
.478 .603 .899 r
.07604 .36306 .08333 .3727 .09329 .37083 .08574 .36312 Mtetra
.577 .702 .928 r
.08574 .36312 .09329 .37083 .10314 .37018 .09578 .36111 Mtetra
.932 .7 .564 r
.09578 .36111 .10314 .37018 .11433 .35959 .12124 .2424 Mtetra
0 0 .123 r
.12124 .2424 .11433 .35959 .12428 .35881 .11681 .3509 Mtetra
.586 .702 .923 r
.11681 .3509 .12428 .35881 .13447 .35654 .12701 .3487 Mtetra
.546 .689 .933 r
.12701 .3487 .13447 .35654 .14331 .366 .13717 .34724 Mtetra
.72 .587 .706 r
.13717 .34724 .14331 .366 .1557 .34609 .14856 .33595 Mtetra
.474 .592 .891 r
.14856 .33595 .1557 .34609 .16602 .34391 .15861 .33615 Mtetra
.603 .715 .924 r
.15861 .33615 .16602 .34391 .17642 .34148 .16904 .33353 Mtetra
.536 .685 .935 r
.16904 .33353 .17642 .34148 .18367 .3689 .17938 .33223 Mtetra
.64 .463 .628 r
.17938 .33223 .18367 .3689 .19797 .33079 .19081 .32119 Mtetra
.514 .628 .901 r
.19081 .32119 .19797 .33079 .2085 .32832 .20117 .32053 Mtetra
.613 .721 .922 r
.20117 .32053 .2085 .32832 .21913 .32546 .21182 .31764 Mtetra
.594 .714 .927 r
.21182 .31764 .21913 .32546 .22958 .32501 .22248 .31513 Mtetra
.891 .728 .673 r
.22248 .31513 .22958 .32501 .24107 .31372 .23554 .28736 Mtetra
0 .051 .565 r
.23554 .28736 .24107 .31372 .25173 .31205 .24451 .30401 Mtetra
.61 .716 .92 r
.24451 .30401 .25173 .31205 .26256 .30888 .25534 .30113 Mtetra
.626 .731 .922 r
.25534 .30113 .26256 .30888 .27345 .30572 .26626 .29785 Mtetra
.606 .721 .926 r
.26626 .29785 .27345 .30572 .28424 .30447 .27719 .29502 Mtetra
.952 .707 .532 r
.27719 .29502 .28424 .30447 .29583 .2932 .29714 .17422 Mtetra
0 0 .249 r
.29714 .17422 .29583 .2932 .30673 .29176 .29964 .28355 Mtetra
.612 .715 .919 r
.29964 .28355 .30673 .29176 .31782 .28838 .31072 .28056 Mtetra
.636 .737 .921 r
.31072 .28056 .31782 .28838 .32898 .28472 .3219 .27695 Mtetra
.64 .74 .921 r
.3219 .27695 .32898 .28472 .34018 .28106 .33314 .27323 Mtetra
.636 .738 .922 r
.33314 .27323 .34018 .28106 .35143 .27769 .34442 .2696 Mtetra
.601 .718 .927 r
.34442 .2696 .35143 .27769 .36252 .27806 .35571 .26681 Mtetra
.839 .721 .733 r
.35571 .26681 .36252 .27806 .37434 .2654 .36777 .24996 Mtetra
.321 .402 .79 r
.36777 .24996 .37434 .2654 .38568 .26291 .37876 .25469 Mtetra
.627 .726 .919 r
.37876 .25469 .38568 .26291 .39713 .25916 .39023 .25123 Mtetra
.646 .743 .92 r
.39023 .25123 .39713 .25916 .40864 .25513 .40177 .24726 Mtetra
.652 .748 .92 r
.40177 .24726 .40864 .25513 .42021 .25098 .41337 .24312 Mtetra
.655 .75 .92 r
.41337 .24312 .42021 .25098 .43184 .24674 .42502 .23888 Mtetra
.657 .752 .92 r
.42502 .23888 .43184 .24674 .44351 .24244 .43673 .23456 Mtetra
.658 .753 .92 r
.43673 .23456 .44351 .24244 .45523 .23809 .44848 .23019 Mtetra
.659 .754 .92 r
.44848 .23019 .45523 .23809 .46701 .23371 .46029 .22578 Mtetra
.46029 .22578 .46701 .23371 .47883 .22932 .47215 .22135 Mtetra
.47215 .22135 .47883 .22932 .49071 .22491 .48406 .2169 Mtetra
.48406 .2169 .49071 .22491 .50264 .22048 .49602 .21244 Mtetra
.658 .753 .92 r
.49602 .21244 .50264 .22048 .51461 .21605 .50803 .20797 Mtetra
.50803 .20797 .51461 .21605 .52664 .2116 .5201 .20348 Mtetra
.5201 .20348 .52664 .2116 .53873 .20714 .53221 .19898 Mtetra
.53221 .19898 .53873 .20714 .55086 .20266 .54439 .19446 Mtetra
.54439 .19446 .55086 .20266 .56305 .19816 .55661 .18993 Mtetra
.55661 .18993 .56305 .19816 .57529 .19365 .56889 .18538 Mtetra
.56889 .18538 .57529 .19365 .58759 .18912 .58122 .18081 Mtetra
.657 .753 .92 r
.58122 .18081 .58759 .18912 .59994 .18457 .59361 .17622 Mtetra
.59361 .17622 .59994 .18457 .61235 .18001 .60605 .17162 Mtetra
.60605 .17162 .61235 .18001 .62481 .17542 .61855 .167 Mtetra
.657 .752 .92 r
.61855 .167 .62481 .17542 .63732 .17082 .6311 .16235 Mtetra
.6311 .16235 .63732 .17082 .64989 .16619 .64371 .15769 Mtetra
.64371 .15769 .64989 .16619 .66252 .16155 .65638 .15301 Mtetra
.65638 .15301 .66252 .16155 .6752 .15688 .6691 .14831 Mtetra
.6691 .14831 .6752 .15688 .68795 .1522 .68188 .14358 Mtetra
.68188 .14358 .68795 .1522 .70074 .1475 .69472 .13884 Mtetra
.69472 .13884 .70074 .1475 .7136 .14277 .70762 .13408 Mtetra
.841 .709 .718 r
.02684 .37691 .03417 .38698 .04535 .376 .0392 .35835 Mtetra
.07 .191 .684 r
.0392 .35835 .04535 .376 .05508 .37484 .04744 .36702 Mtetra
.57 .696 .927 r
.04744 .36702 .05508 .37484 .06485 .37382 .05734 .36516 Mtetra
.819 .364 0 r
.05734 .36516 .06485 .37382 .07604 .36306 .06483 .38043 Mtetra
.816 .905 .499 r
.06483 .38043 .07604 .36306 .08574 .36312 .07818 .3551 Mtetra
.573 .693 .923 r
.07818 .3551 .08574 .36312 .09578 .36111 .08822 .35316 Mtetra
.501 .668 .937 r
.08822 .35316 .09578 .36111 .12124 .2424 .09815 .35245 Mtetra
.437 .177 .42 r
.09815 .35245 .12124 .2424 .11681 .3509 .10945 .34176 Mtetra
.521 .641 .909 r
.10945 .34176 .11681 .3509 .12701 .3487 .11948 .34091 Mtetra
.59 .709 .926 r
.11948 .34091 .12701 .3487 .13717 .34724 .12976 .33858 Mtetra
0 0 .526 r
.12976 .33858 .13717 .34724 .14856 .33595 .13866 .34802 Mtetra
.804 .931 .56 r
.13866 .34802 .14856 .33595 .15861 .33615 .15118 .32797 Mtetra
.585 .698 .92 r
.15118 .32797 .15861 .33615 .16904 .33353 .16159 .32573 Mtetra
.595 .714 .927 r
.16159 .32573 .16904 .33353 .17938 .33223 .17207 .32323 Mtetra
.92 .527 .159 r
.17207 .32323 .17938 .33223 .19081 .32119 .17935 .35069 Mtetra
.695 .767 .277 r
.17935 .35069 .19081 .32119 .20117 .32053 .19382 .31237 Mtetra
.596 .705 .92 r
.19382 .31237 .20117 .32053 .21182 .31764 .20445 .30983 Mtetra
.613 .723 .924 r
.20445 .30983 .21182 .31764 .22248 .31513 .21517 .30689 Mtetra
.487 .659 .937 r
.21517 .30689 .22248 .31513 .23554 .28736 .22571 .30638 Mtetra
.018 0 .003 r
.22571 .30638 .23554 .28736 .24451 .30401 .23732 .29499 Mtetra
.56 .669 .911 r
.23732 .29499 .24451 .30401 .25534 .30113 .24807 .29325 Mtetra
.623 .727 .921 r
.24807 .29325 .25534 .30113 .26626 .29785 .259 .29001 Mtetra
.622 .729 .923 r
.259 .29001 .26626 .29785 .27719 .29502 .26999 .28677 Mtetra
.532 .682 .935 r
.26999 .28677 .27719 .29502 .29714 .17422 .28088 .28545 Mtetra
.439 .18 .423 r
.28088 .28545 .29714 .17422 .29964 .28355 .29258 .27406 Mtetra
.549 .655 .905 r
.29258 .27406 .29964 .28355 .31072 .28056 .30358 .27256 Mtetra
.629 .731 .92 r
.30358 .27256 .31072 .28056 .3219 .27695 .31477 .2691 Mtetra
.639 .739 .921 r
.31477 .2691 .3219 .27695 .33314 .27323 .32603 .26536 Mtetra
.639 .74 .922 r
.32603 .26536 .33314 .27323 .34442 .2696 .33735 .26162 Mtetra
.627 .733 .923 r
.33735 .26162 .34442 .2696 .35571 .26681 .3487 .25816 Mtetra
.438 .63 .935 r
.3487 .25816 .35571 .26681 .36777 .24996 .3599 .25847 Mtetra
0 0 0 r
.3599 .25847 .36777 .24996 .37876 .25469 .37183 .24569 Mtetra
.59 .692 .912 r
.37183 .24569 .37876 .25469 .39023 .25123 .38328 .24313 Mtetra
.639 .738 .92 r
.38328 .24313 .39023 .25123 .40177 .24726 .39484 .23929 Mtetra
.649 .746 .92 r
.39484 .23929 .40177 .24726 .41337 .24312 .40647 .23518 Mtetra
.653 .749 .92 r
.40647 .23518 .41337 .24312 .42502 .23888 .41815 .23094 Mtetra
.656 .751 .92 r
.41815 .23094 .42502 .23888 .43673 .23456 .42989 .22661 Mtetra
.657 .753 .92 r
.42989 .22661 .43673 .23456 .44848 .23019 .44168 .22222 Mtetra
.658 .753 .92 r
.44168 .22222 .44848 .23019 .46029 .22578 .45352 .21779 Mtetra
.659 .754 .92 r
.45352 .21779 .46029 .22578 .47215 .22135 .46541 .21332 Mtetra
.46541 .21332 .47215 .22135 .48406 .2169 .47735 .20884 Mtetra
.47735 .20884 .48406 .2169 .49602 .21244 .48935 .20434 Mtetra
.659 .753 .92 r
.48935 .20434 .49602 .21244 .50803 .20797 .50139 .19982 Mtetra
.658 .753 .92 r
.50139 .19982 .50803 .20797 .5201 .20348 .51349 .1953 Mtetra
.51349 .1953 .5201 .20348 .53221 .19898 .52565 .19076 Mtetra
.52565 .19076 .53221 .19898 .54439 .19446 .53785 .1862 Mtetra
.53785 .1862 .54439 .19446 .55661 .18993 .55011 .18163 Mtetra
.55011 .18163 .55661 .18993 .56889 .18538 .56243 .17704 Mtetra
.56243 .17704 .56889 .18538 .58122 .18081 .5748 .17243 Mtetra
.657 .753 .92 r
.5748 .17243 .58122 .18081 .59361 .17622 .58722 .16781 Mtetra
.58722 .16781 .59361 .17622 .60605 .17162 .5997 .16317 Mtetra
.5997 .16317 .60605 .17162 .61855 .167 .61224 .1585 Mtetra
.657 .752 .92 r
.61224 .1585 .61855 .167 .6311 .16235 .62483 .15382 Mtetra
.62483 .15382 .6311 .16235 .64371 .15769 .63748 .14912 Mtetra
.63748 .14912 .64371 .15769 .65638 .15301 .65018 .1444 Mtetra
.65018 .1444 .65638 .15301 .6691 .14831 .66295 .13965 Mtetra
.66295 .13965 .6691 .14831 .68188 .14358 .67577 .13489 Mtetra
.67577 .13489 .68188 .14358 .69472 .13884 .68865 .13011 Mtetra
.68865 .13011 .69472 .13884 .70762 .13408 .70158 .1253 Mtetra
.396 .615 .938 r
.01914 .36883 .02684 .37691 .0392 .35835 .02857 .36955 Mtetra
0 0 0 r
.02857 .36955 .0392 .35835 .04744 .36702 .03986 .35847 Mtetra
.538 .664 .918 r
.03986 .35847 .04744 .36702 .05734 .36516 .04967 .35725 Mtetra
.523 .678 .935 r
.04967 .35725 .05734 .36516 .06483 .38043 .05951 .35617 Mtetra
.684 .533 .675 r
.05951 .35617 .06483 .38043 .07818 .3551 .07081 .34531 Mtetra
.477 .603 .899 r
.07081 .34531 .07818 .3551 .08822 .35316 .08059 .34531 Mtetra
.577 .702 .928 r
.08059 .34531 .08822 .35316 .09815 .35245 .09071 .34324 Mtetra
.933 .7 .562 r
.09071 .34324 .09815 .35245 .10945 .34176 .11658 .22404 Mtetra
0 0 .115 r
.11658 .22404 .10945 .34176 .11948 .34091 .11193 .33287 Mtetra
.586 .702 .923 r
.11193 .33287 .11948 .34091 .12976 .33858 .12221 .3306 Mtetra
.546 .689 .933 r
.12221 .3306 .12976 .33858 .13866 .34802 .13246 .32908 Mtetra
.72 .587 .706 r
.13246 .32908 .13866 .34802 .15118 .32797 .14396 .31768 Mtetra
.473 .592 .891 r
.14396 .31768 .15118 .32797 .16159 .32573 .15409 .31782 Mtetra
.603 .715 .924 r
.15409 .31782 .16159 .32573 .17207 .32323 .16461 .31514 Mtetra
.536 .685 .934 r
.16461 .31514 .17207 .32323 .17935 .35069 .17504 .31376 Mtetra
.639 .461 .627 r
.17504 .31376 .17935 .35069 .19382 .31237 .18658 .30262 Mtetra
.514 .628 .901 r
.18658 .30262 .19382 .31237 .20445 .30983 .19703 .3019 Mtetra
.613 .721 .922 r
.19703 .3019 .20445 .30983 .21517 .30689 .20777 .29893 Mtetra
.594 .714 .927 r
.20777 .29893 .21517 .30689 .22571 .30638 .21853 .29635 Mtetra
.892 .729 .672 r
.21853 .29635 .22571 .30638 .23732 .29499 .23174 .26842 Mtetra
0 .047 .563 r
.23174 .26842 .23732 .29499 .24807 .29325 .24076 .28506 Mtetra
.61 .716 .92 r
.24076 .28506 .24807 .29325 .259 .29001 .25169 .28211 Mtetra
.626 .731 .922 r
.25169 .28211 .259 .29001 .26999 .28677 .26271 .27874 Mtetra
.606 .721 .926 r
.26271 .27874 .26999 .28677 .28088 .28545 .27374 .27584 Mtetra
.953 .707 .529 r
.27374 .27584 .28088 .28545 .29258 .27406 .29401 .15456 Mtetra
0 0 .242 r
.29401 .15456 .29258 .27406 .30358 .27256 .2964 .2642 Mtetra
.612 .715 .919 r
.2964 .2642 .30358 .27256 .31477 .2691 .30759 .26112 Mtetra
.636 .737 .921 r
.30759 .26112 .31477 .2691 .32603 .26536 .31888 .25744 Mtetra
.64 .74 .921 r
.31888 .25744 .32603 .26536 .33735 .26162 .33022 .25363 Mtetra
.636 .738 .922 r
.33022 .25363 .33735 .26162 .3487 .25816 .34161 .24992 Mtetra
.601 .718 .927 r
.34161 .24992 .3487 .25816 .3599 .25847 .353 .24705 Mtetra
.84 .722 .733 r
.353 .24705 .3599 .25847 .37183 .24569 .36519 .23007 Mtetra
.319 .401 .79 r
.36519 .23007 .37183 .24569 .38328 .24313 .37629 .23474 Mtetra
.627 .726 .919 r
.37629 .23474 .38328 .24313 .39484 .23929 .38786 .2312 Mtetra
.646 .743 .92 r
.38786 .2312 .39484 .23929 .40647 .23518 .39952 .22715 Mtetra
.652 .748 .92 r
.39952 .22715 .40647 .23518 .41815 .23094 .41123 .22292 Mtetra
.655 .75 .92 r
.41123 .22292 .41815 .23094 .42989 .22661 .423 .21859 Mtetra
.657 .752 .92 r
.423 .21859 .42989 .22661 .44168 .22222 .43482 .21419 Mtetra
.658 .753 .92 r
.43482 .21419 .44168 .22222 .45352 .21779 .44669 .20973 Mtetra
.659 .754 .92 r
.44669 .20973 .45352 .21779 .46541 .21332 .45862 .20523 Mtetra
.45862 .20523 .46541 .21332 .47735 .20884 .47059 .20071 Mtetra
.47059 .20071 .47735 .20884 .48935 .20434 .48262 .19617 Mtetra
.48262 .19617 .48935 .20434 .50139 .19982 .4947 .19161 Mtetra
.658 .753 .92 r
.4947 .19161 .50139 .19982 .51349 .1953 .50684 .18705 Mtetra
.50684 .18705 .51349 .1953 .52565 .19076 .51903 .18247 Mtetra
.51903 .18247 .52565 .19076 .53785 .1862 .53127 .17787 Mtetra
.53127 .17787 .53785 .1862 .55011 .18163 .54357 .17326 Mtetra
.54357 .17326 .55011 .18163 .56243 .17704 .55592 .16863 Mtetra
.55592 .16863 .56243 .17704 .5748 .17243 .56832 .16399 Mtetra
.56832 .16399 .5748 .17243 .58722 .16781 .58078 .15932 Mtetra
.657 .753 .92 r
.58078 .15932 .58722 .16781 .5997 .16317 .5933 .15464 Mtetra
.5933 .15464 .5997 .16317 .61224 .1585 .60588 .14994 Mtetra
.60588 .14994 .61224 .1585 .62483 .15382 .61851 .14522 Mtetra
.657 .752 .92 r
.61851 .14522 .62483 .15382 .63748 .14912 .63119 .14048 Mtetra
.63119 .14048 .63748 .14912 .65018 .1444 .64394 .13571 Mtetra
.64394 .13571 .65018 .1444 .66295 .13965 .65674 .13093 Mtetra
.65674 .13093 .66295 .13965 .67577 .13489 .6696 .12613 Mtetra
.6696 .12613 .67577 .13489 .68865 .13011 .68252 .1213 Mtetra
.68252 .1213 .68865 .13011 .70158 .1253 .6955 .11646 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05eoo`0GD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBo@0GOol00`00
Oomoo`17Ool008Moo`<006=oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aB
o5;mD_`005;lD_d00U;l5goo00<007ooOol0AWoo0025Ool2001ROol085;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_dFOol00`00Oomoo`16
Ool0089oo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`00e;mD_aoo`0FOol00`00Oomoo`15Ool0081oo`8006=oo`0UD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_`05goo00<007ooOol0A7oo001mOol3001QOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo003D_eB
o7oo01Eoo`03001oogoo04Aoo`00Ngoo0P000Woo00<007ooOol0GGoo02aBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;m5goo00<007ooOol0@goo001hOol3001ROol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@0GOol00`00Oomoo`12Ool007Ioo`8000Ioo`03N]1oogoo05Qoo`0dD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`12Ool007=oo`<0
00Qoo`03M[1oogoo05Ioo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo004D_eB
o5;lD_`GOol00`00Oomoo`11Ool0075oo`8000]oo`03N]1oogoo05Aoo`0iD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;l01Eoo`03001oo`00049oo`00KWoo
0`003Goo00=f/7ooOol0D7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
o@00D_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomoo`10Ool006]oo`<0011oo`03N]1oogoo04io
o`11D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0oOol006Uoo`8000=oo`03001oogoo00eoo`03M[1oogoo
04]oo`03D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
001Bo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol0?goo001VOol3000DOol00gJ`N]1oo`18
Ool0BE;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Ioo`03001oogoo03ioo`00I7oo0P005goo00=f
d7J`@[d0AWoo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol0?Goo
001QOol3000IOol00gJ_N]0dS014Ool0Ce;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m01Eoo`03001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P0077oo00=jd7J`=:d0@7oo00=Bo5;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007oo
Ool09Woo00<007ooOol04goo000dOol00`00Oomoo`02Ool00`00Oomoo`0POol3000NOol00gJ`N]0d
S00oOol0EE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Io
o`03001oogoo02Eoo`03001oogoo01=oo`00>Goo00<007ooOol07Woo0P000Woo00<007ooOol077oo
00=fd7J`=:d0?Goo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01U;m
D_aBo5;lD_eBo1Eoo`03001oogoo02Aoo`03001oo`0001Aoo`00;7oo1P001goo00<007ooOol06goo
0`008Woo00Ajd7J_N]0dS3Uoo`1LD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo02=oo`03001oo`0001Aoo`00=Goo1000
77oo0P009Goo00Ef/7[@M[0d[D:m03Ioo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Ioo`03001oogoo025oo`05001oogoo
Ool0000COol003Eoo`03001oogoo01Yoo`<002Moo`05N]1f/7[@=8`h[@0dOol0HU;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_dDOol2000SOol01@00Oomoogoo00004goo000eOol00`00Oomoo`0GOol3000ZOol01GJ`M]1f
/3B]=:`0<7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Eoo`03001oogoo01moo`<00004Ool0
0000000BOol003Eoo`D001=oo`8002eoo`05N]1f[g[@=8`d[@0^Ool0JE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0gOol004Yoo`<00003Ool007oo02aoo`03M[1jd006008d
[Baoo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l
00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`08Ool4
000[Ool004Qoo`80035oo`06MZmjd7J`00LdS3R]:7oo071Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Qoo`00
AGoo0`00<goo00Mjd7J`M]001cB]=:a2_@0UOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0:7oo
0013Ool2000fOol01gJ`N]1f[`07=8`d[CB/02=oo`1eC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo02Qoo`00@7oo0`00>7oo00Afd7J`N]001P<d[Amoo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Eoo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo02Qoo`00?Woo0P00>goo00Mf[g[@M[001cB<>:dd[@0KOol0OdkLD_e>
g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l01Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00>goo100017oo
00=fdGooOol0=7oo00Qf/7[@M[1fd007=:dd[3B]4goo00=ZeRFH9IP017oo0TkL00=Bo5;mC_`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoE;lOol057oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0:7oo000iOol20004Ool0
1@00OomoogooL[40=Woo00Qjd7J`N]1f[`07=8`d[CB/4goo08UVeV[G9GPUVBEhC_e>g4kMC]a>oDkL
D_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l01Eoo`03001oogoo00=oo`@002]oo`00=Woo0`002Woo00=f/GooOol0=7oo00Ef
/7K@M[1jd00600<d[@03@[eoogoo00moo`03J]IZef[F00@UV09>g005C]e>g4kLD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
Oomoo`0AOol200000goo001oo`0bOol003=oo`<000eoo`03L[1oogoo03Aoo`09N]1f[g[@M[001cB<
>:dd[CS=011oo`2<I]IZef[FJ]MVeRVI9GPUVBEhD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001o
ogoo035oo`00<Goo0P0047oo00=fdGooOol0=7oo00Mf/7[@M[1fd007=:dd[002=:d@Ool01F[GJ]IZ
eV[FJ]L01DZl00A>o4kLD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d00000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0`Ool002ioo`<0015o
o`03M]5b/Goo03Eoo`09N]1f/7[@MZl01cB<=:dd[3S=00moo`05J]MZeV[GI]IZe`020000J4JlB]e:
_4ZlC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d300007E;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d05Goo00<007ooOol0;goo000/Ool4000BOol2M[400goo
=:eoo`0bOol01W[@M[1fd7J`N]001P@d[@]oo`05B]a:gD[MB]e:g002J]H016[G000000001DZl00E>
o5;lD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00000005;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo004D_eBo5;lD_`EOol00`00Oomoo`0_Ool002Yoo`8001Ioo`04M]400Woo=8`c
Ool02WJ`N]1f[g[@M[001cB<>:dd[CS=1goo075BoDkLD_e>g5;mB[a>gD[LB]eVeV[G001ZebEh:ITU
N4kMC]a>oDkLC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m00<0000TD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol0;Woo000ZOol2000FOol0
17Ja00=oocB/<goo00Qfd7J`N]1f/7K@00Ld[CB/0SB]17oo00YBoDkLC_a>o4kmC]a>oDkLC_e>g0=:
g@04=WeZeV[FJ]L39IP01TkMC]a>g4kLD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0800005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Eoo`03001oogoo
02ioo`0047oo1@000goo100017oo10001Woo00<007oo00005Goo00Afd@02Ool`S3=oo`0JMZmjd7J`
N]1f[`07=8`d[CB/><e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]`fW@8fO@1QI]IZefKF:ITU
N2VI9GQ>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`00`0002YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0]Ool0019oo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool200000goo001oo`0BOol0
1GKAM[400cB/=:d0<goo00Yjd7J`M]1f/7[@00I>g4[LC]e:g09>g00=C_e>g4klC_aBoDkLC_e>o5;m
C]a>gDkLC_d00SIm00=ZeV[GJ]H00V[F12FH00EBoDkLC_a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo006D_eBo5;lD_aBoE;l0`000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00EOol0
0`00Oomoo`0/Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomo
o`02Ool20003Ool00`00Oomoo`0@Ool01G:aM]400SB]=8`0<goo021f/7[@MZmjd7J`00L01TkMB]a>
gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g4kmI]IZefKFJ]MVeV[G0TZl05E6_4[MB[aBoDkL
D_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0030000<U;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`0/Ool000Moo`H000Eoo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`0?Ool2M[401003=8`d[3B]<Goo00If/7K@M[1jd7J`M]0200L01@06C]a:g4kMB]`00Tkl00YBoDkL
C_a>o5;mC]a>oDklB]e:g0=:g@=ZeP03J]L0000000E:_005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006
D_eBo5;lD_aBoE;l0`000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l
Ool057oo00<007ooOol0:goo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol03Woo00Ib/7KA008d[Goo>:dSOol00`0aOomo
o`0;Ool0LW[@MZmjd7J`N]1f[`0700H01`06D_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MB[a>
gD[LJ]MVeV[GI]HYVBEh:IU>g4kMC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0<0000i
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03
001oo`0002aoo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
009oo`8000Ioo`8000ioo`06M]5f/@03=:aoocB/8Woo00=beFkDOol037oo00]f/7[@M[1fd7J`N]1f
/4JL@Ya6W4:L009>g00;C_e>g4kLC_aBoDkLC_a>g4kmC]a>o@02B]d014[LB]e:gF[G0f[F0bFH00M>
g4kMC]a>g5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo000008000=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol0:Woo000@
Ool30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol01goo00<0
07ooOol02Woo00MfdG:aM]400SB]Oold[@0ROol00fkDL_D0<@08Ool0L4kMB]a>gD[LC]ef/7[@MZmj
d7J`N]12NdJL@Ya6W4kLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4[MB[a>gCImJ]MVeV[G9IPY
VBEhC_e>g4kMC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0`00041Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo02Uoo`004Woo
00<007ooOol00goo100017oo10001Goo00<007ooOol027oo00<007ooOol02Goo0gJa00@d[CB<Oold
[B5oo`04K]AbeFkD0345Ool014kMC]a>oDkL0T[M019>gD[LM]1f/7[@M[1fd7J`00M2W4JL@Ya6W4kL
C_a>g4kmC]`2C_`01e;mC]a>o4kLC_e>g4kM00<fO@9ZeP03J]MZeV[F00<UV007C_a>g5;mC]a>o5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003
D_eBo000008000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol0:7oo000XOol00`00Oomoo`0:
Ool00`00Oomoo`08Ool01gKAL[1fdCB<=:ddS3R]025oo`03L_E^e7;e0080<@0^B[a>gD[LC]e:_4km
C]a>oDkLC]e:g4kMB]ajd7J`N]1f/7[@00M>gDZlC]e:g4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4km
C]a>oDkLJ]MVeV[GI]IZefKFB[d2B[`0@TJlD_e>g5;mC]aBoDklD_e>g5;mC_aBoDkLD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@800017D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo00EOol00`00Oomoo`0XOol002Qoo`<000]oo`03001oogoo00Moo`03M[5fdGJa008d[004=:dd
[7oo=:dNOol01G;EK]AbeFkDL]D00P0a00U:g4kLB]a>gDkLC]e>g4kmC]`00T:m00Ijd7J`M]1f/7[@
M[0200L01TkMB]a>g4[LC]e>g09>o007D_e>g4kmC_aBoDkLC_d00T[M00A:g4[MB]eZe`=ZeP8000A:
_004C_a>g5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l0`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`EOol00`00Oomoo`0WOol002Qoo`03
001oogoo00aoo`03001oogoo00Eoo`0:L[1fdG:aM]4`S3B]=:`d[Goo><dNOol01FkDL_E^e7;eK]@0
0P0a019>gDZlC]e:g4kMB]a>oDkLC_e:g4:mM[1jd7J`N]1f/7[@00H300L06TkLD_e>g4kmC]aBoDkL
D_e>g5;mC]aBoDkLD_e:g4[MB[a>gFKFJ]MVeV[G9IP004JlB[d2B[`0>TJlD_e>g5;mC]aBoDklD_e>
g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0`0004iBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0VOol002Qoo`03001oogoo00eoo`03001oogoo
00Aoo`06M]5f/GJaM[4d[CB<0SB]00=oocB]Ool077oo00I^e7;EK]AbeFkDL]D303405DkMC]a>g4kL
C]e>g4kMC]a>gDkLM]1f/7[@M[1fd7J`AYa2W4JL@Ya6W003C]`02TkmC]a>o4klD_e>g4kmC]a>oDkL
0d[M00E:g4[MJ]IZef[F00<UV0=>g006C]e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00U;l0`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UB
oE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aB
o5;l57oo00<007ooOol09Woo000XOol2000?Ool00`00Oomoo`03Ool02W:aM]5b/7KA=8`d[CB<>:eo
ocR]7Goo06ebmFkDL_E^e7;eK]@0<D:LA[e6W4kmB]a>oDkLC_e:g4kMB]a>gD[LN]1f/7[@M[1jd7J`
AYa2NdJL@Ya>oDkLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4[MB[`fWFKFJ]MVeRVI9IPYVDkL
C_e>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@030000EU;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`0UOol0
02Qoo`03001oogoo00moo`03001oogoo009oo`9f/@06M]5f/CB/=:`d[CB/0SB]6Goo00a:g4[MB]e:
gD[LL]E^e7;EK]Abe@0aA[`3AY`01TJlC]a>gDkLC_e:g09:g@0BC]ef/7K@M[1jd7J`M]12W4JL@Ya6
W4:LC_e>g4klC]a>oDkL0Tkl00IBoDkLC]e>g4kmC]`3=Wd3J]H00f[G9IPUV0029IP01DkLC_a>g5;m
C]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo0030002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`EOol00`00Oomoo`0TOol002Qoo`03
001oogoo011oo`0?001oogooOomb/7KAL[5fdC2<=:dd[3B]=:`hcCB]01Eoo`0=B]a>gD[LC]e:_4[M
B[a:gFkDL_E^e7;eK]@00P0a02m>gDZlC]e:g4kMC]a>oDkLC_e:g4kMB]a>gGJ`N]1f/7[@M[0024[L
C]e:_4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL=YdfOF[GI]IZefKFJ]M6_4Zm009:_00^
C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d30000GE;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol2000VOol002Moo`03
001oogoo019oo`04001oogJaM]43M[400cB]=8`d[@02=:d00`03=:eoo`0?Ool00dgCDM<nO002?W`0
1T9lB]a>gD[LC]e:g0=:g@05K]AbeFkDL]E^e00203402DkMB]a>g4[LC_e>g4kMC]a>o@03@[d01G[@
M[1fd7J`N]000P0700M:g4kMB]a>g4[LD_e>g002C_`02U;mC]a>oDklD_e>g4kMC]a>oDkL0V[F00=Z
ef[FJ]H00P000dZl00EBoDkLC_a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo0030002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l
57oo00<007ooOol08goo000WOol3000COol03@00M]5b/GKAL[1fdCB<=:ddS3R]=:aoocB/00ioo`0E
DM==/e7CCK=Adcik@W`nNd9lB]a>oD[LC]e:g3jM>YebmFkDL_E^e7;e00<0<@0@C]e:_4kMB]a>oD[L
C_e>g4km?Yajd7J`N]1f/7[@M[0200L0A@0800M>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDZlC]e:
g4[MB[aZefKFJ]LUN2VI001:_4JlB[e:_5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBo@030000I5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l5Goo00<007ooOol08Woo000WOol00`00Oomoo`0DOol3M[402GKAM[4d[3B/=:dd[3B]
Oolh[@0=Ool2CM<0557CCM==ddgCDM=:_4[LB[a:gD[LC]e:g4kM>YebeFkDL]E^e7;EK]@403405DkM
C]a>g4kLC]e>g4kMC]a2_GJ`M]1f/7[@M[1fd4:LAYa2W4JL@Ya>o@03C]`02U;mC]a>o4klC_e>g4km
C]a>oD[L0d[M0f[F00EZebFH9IPUV4kM00=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l0P000U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00IBoE;lD_aBo5;mD_`DOol00`00Oomoo`0ROol001Eoo`@000Aoo`@000Ioo`03001oogoo01Aoo`0<
M]5b/7KAL[400c2<=:dd[3R]=:aoocB]2Woo06i6_D:m@[e=/e7CCK=AddfcDM==/eL8B[a:gDZlB]e:
g4kmB]a>gFkDL_E^e7;eK]Abm@0aA[a2W4JmAYa>oD[LC_e>g4kmB]a>oDkLN]1f/7[@M[1jd7J`N]52
W4JL@W]6W4kLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e:_4kMB]a:gFJfJ]MVeRVI9GPYVBFHC]e>
g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;l0`0006YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo025o
o`0057oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo01Aoo`07M[5f
dGJaM[400cB]=8`01CB]1goo00A:gD[LB]e:g092_@0>DM==ddgCCM=AddgCE`QFj4[MB[a:g4ZlB]e:
g0=:g@08K]AbeFkDL]E^e00aAYa6_0=6W006C_e>g4kMC]a>oD[L0T[M019jd7J`M]1f/7K@M[16W4:L
AYa2W4JLC]a>oDkLC_a>g5;mC]`2C_`01E;mC]a>gDkLC_d00SIm00=ZeV[GJ]H00V[F00TYV2FH9IQ>
g4kMC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l0`0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo01=oo`03
001oogoo021oo`006Goo00@007ooOol000Aoo`03001oogoo00=oo`8001Aoo`1oL[1fdG:aM]5b/003
=8`d[CB<><dd[3S==:aoocB]FUIJ=CiL>U/jG3XkC]e:g4kM@Ya6_DfcDM==/e7CCK=AdeKWF`QFidkM
B]a>gD[LC]e:_4[MB[abmFkDL_E^e7;eK]@0<T[LC]e:_4kMB]a>oDkLC_e>g4kMB]a>gGJ`N]1f/7[A
M[1jd007C]e:g4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL=WdbO6[GI]IZefJfJ]LUV2VI
9GPYVDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_`00`00079Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol0
0`00Oomoo`0POol000aoo`H000Moo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0DOol0
1WKAM[5f/GJaM]400P8d[0@d[@0=>:eooeYFFUEJEUYE>U`jFcYL>U]:gD[LB]d00T:m00I=de7CCM==
deKXDM<3?W`01TkMB]a>gD[LC]e:g09:g@05?Ye^e6kEK]Abe@0203400d[LC]e:g002C]`034kmC]a>
gDkLC]e:g4[MM[1fd7J`M]1f/0801`08C]a:g4kMB]a>g4klD_e>g09>o009D_e>g4kmC_a>oDkLC]e>
g6[G00=ZeP03J]L0000000A:_006C]aBoDkLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00ABoE;lD_aBo1Eoo`03001oogoo01moo`005Goo10000goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol057oo035b/GKAL[1fdG:a00<`S3R]=:`h[CB/><dd[EYFFSEJEUXeFUIJ=D[MA[a:
gDJlB]e:_4:m@YaAddfcDM==/e7CCK=2O3ik@W`nNdkMB]a>oD[LC]djWCjMK]AbmFkDL_E^e0020340
;@0bB]a>gDZlC]e>g4kmB]a>oDkL@[ef/7[AM[1jd7J`N]401`0800M>gD[LC]e>g5;mC]aBoDkLD_e>
g5;mC]aBoDkLB]e:_4kMB]aZefJfJ]MVeRVI001:_@02B[`05dJlB[e>g5;mC]aBoDkLD_e>g5;mC_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_`00`0007UBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0OOol001Eoo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo009oo`8001Eoo`9f/@06M]5f/GJa00<d[CB/13B]00QJEUYE
FUIJEEYFFUEW/F>a0TZl00E:_D[LB]e:gD:m00==d`0CDM==ddgCCM=:gDZlB]a:_4kMB]a>gD[L?Ydj
WFkEK]AbeFkDK]D0100a00=>g4kMC]`00TkL00Y>gDkLC]e2_GK@M[1fd7J`M]1f/0@01`9>g00>C_e>
g4kLC_aBoDkLC_a>g4kmC]a>oDkLB]e:g09:g@06J]MZeV[FJ]HYV2FH0TkL00I>gDkLC]aBo5;mC_`2
D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo0<00003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l57oo00<007ooOol07Woo
000EOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0DOol0Lg:`M]5b
/GKAL[000dJlB]e6_4[M@[a6_EXeFUIJ=EYFFSEJEV>AIk56_4[MA[a:gDZlB]e2_E7CCK=AddfcDM==
/e7CE^M:gDZlB]e:_4kMB]a>oD[LL_E^e7;eK]AbmFkDA[e6W4Jl@Ya6_DkLC_e:g4kmC]a>oD[LC_ef
/7[@M[1jdGJ`N]1f/4JL@Ya6W49kD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MB[a>gD[LJ]MV
]V[G9IPYVBEhC_e>g4kMC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;l00<00021D_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l01Aoo`03001oogoo01eoo`005Goo1@000goo10001Goo00<007ooOol04goo00=f/GKA
M[400WJa00ifd@0200=:_4[MB[a:_D:mA[eJEEYFFUEJEV>a0fNa00A:g4[MB]a:g@92_@03CM=AddgC
009=d`0:DM=FieKXB[a:gDZlB]a:_4[MB]`2B]d01W;EK]A^eFkDL]E^e096W00JA[a6W4JLC]a>oDkL
C]e>g4kMB]a:gGJ`M]1f/7K@M[1fd4:LAYa2W4JL@Ya>o4kLC_e>g09>o008D_e>g4klC]a>oDkLC]e>
g08fO@9ZeP06J]MZeV[F9IPYV2FH0TkL00E>gDkLC_aBo5;m00=Bo004D_eBo5;lD_`300000e;lD_eB
o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eBo5;l01=oo`8001moo`009Woo00<007ooOol04goo05UfdG:aM]5b/7KA
L[400`0200=6_4[MA[a:gD:lFUIJ=EYFHi5JEUXe?U`jFcYLB[a>gD[LC]e2W57CCK=AddfcDM==/eL8
D^MG24[LC]e:g4kMB]a:gDZlB]e:_7;eK]AbmFkDL]D0<@0bB]a>gDZlC]e>g4kmC]a>oD[LC]e:g7[A
M[1jd7J`N]5f/008B[a>gD[LC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4km008fO@0DI[IZefKF
J]MV]RVI9IPYVBEhD_e>g5;mC]aBoDkLD_e>g5;mD_aBo@800028D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_dDOol00`00Oomoo`0LOol002Eoo`03001oo`0001Aoo`=f/@07M]5f/GJa@Wa2W3il
@Y`00T[M015:_4[MFUEJEV>aFUIJEEYF>U/jG3YK>Ua:g4[MB]a:gD:m009=d`05DM==deKXCM=2O002
?W`01d[LC]e:g4kMB]a:gD[L009:g@05L]E^e6kEK]Abe@0203405d[LC]e:g4kMC]a>oDkLC]e:gDkM
B]afd7J`M]1f/7K@00L024[LC]a:g4kMB]`00Tkl00eBoDkLC_a>o5;mC]a>oDkLC_e>g4kMJ]IZe`03
J]H20004B[`014klC]aBoDkL0U;l00EBo@00000005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m009Bo1Aoo`03001oogoo00Moo`D000moo`009Goo0P004Goo03Q:gDJlB]e6_4[ML[1fdG:a
M]5b/GKA?Wa2W3il@Ya:_4[MA[a6_EXeFUIJ=EYFFSEJETJlB]e6_4[MB[a:gDZl@[e=/e7CCK=Addfc
DM@nNd9l?W]2O3ikC]e:g4kmB]`nWCZM?Ye^e7;EK]AbmFkD0P0a02e>gD[LC]e:_4kmC]a>oD[LC_e2
WG[@M[1jdGJ`N]1f/00800L02007D_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4[MB[a>gFKFJ]MV
]V[G9IP004JlB[d00TZl00A6_5;mC]aBo@<0002>D_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`07Ool01@00Oomoogoo00003goo000UOol00`00Oomoo`0<
Ool00eHDEQDjG002>U`01D[MA[a6_DJmM]400gJa019fdGJa@Ya2O4:L?Wa2W4:mA[e2_EYFFUEJEUYE
FUIS/FNaA[`2B[`01DZmB]a:gD:mDM<00dgC01=AddgCCM=:_4[MB[a:g4ZlC]e:g4kMB]`nWFkDK]E^
e7;EK]A^e@030342C]`04TkMC]a>gDkLC]e>g4:mM[1fd7J`M]1f/7K@@Ya6W4:LAYa2W09>g00;C_e>
g4klC_aBoDkLC_e>g4kmC]a>o@02B]d024[LJ]IZeSImI]IZeRFH:IP3C]`01TkM00000000D_e>o09B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol0
1goo00<007ooOol047oo000UOol00`00Oomoo`0:Ool0KEHEDQAF5EHDEQDjFcil>U/nO4JlB]e6_7KA
L[5fdG:aM]400T[MA[a:gDJlB]e2_4Jm@[aJEUXeFUIJ=FNaHi1W/DJlB]e6_4[MB[a:gD:mDM==/e7D
CK=AddfcE^Q:_4[MB[a:gD[LC]e:g4kmB]abeFkDL_E^e7;EK]@4<TJLA[a2W4kmC]a>oD[LC_e>g4km
B]ajdGJ`N]1f/7[AM[1jdD9kAYa2W4JLC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LB]e:_3JM
I]IZefJf:ITUV2VI00<0002FC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l57oo00<007ooOol01goo00<007ooOol03goo000UOol2000:Ool035HE
EQAF5EHDEQEF55HEA[a6_DJlA[dnW@9f/@04M]5f/GJaM[4200<014ZmB[a:gDZl0T:m00e6_EYEFUIJ
EFNaHi1W/F>aIk5:g4[MB]a:g@02@[d00dgCDM==d`02CM<01eKWD^MFidZlB]e:_4[L009:g@09B]a:
gD[ML]E^e6kEK]Abe@0a0096W00JA[a6W4kMC]a>oDkLC]e:gDkMB]afd7J`M]1f/7K@M[16W4:LAYa2
W4JLC]a>o4kLC_e>g09>o007D_e>g4kMC]a>oDkLC]d00SIm00AVeV[FJ]IZe`<00006:IQ>g4klC]aB
oDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGoo
Ool04Woo00<007ooOol027oo00<007ooOol03Woo000UOol00`00Oomoo`06Ool02D:m?Ye2_E8DEQEF
55HEDQAF5@02Ihl02TJlB]e6_3jmL[5fdG:aM]5b/GKA0P0305@00P03A[a:gDJlA[e2_5YFFSEJEUXe
FUHj>ciL>U/jG4ZlC]e:g4kM@YaAddfcDM==/e7DD^MFj5;WE^Q:g4kMB]a>gDZlB]e:_4[MK]AbeFkD
L_E^e00b035>gD[LC]e:_4kmC]a>oDkLC]e:g4kMB]a>gGJ`N]5f/7[A00M>gDZlC]e:g4kMC]aBoDkL
D_e>g5;mC]aBoDkLC_e>g4kmC]`fWCImJ]L300000f[GA[a:_@02B[`0V4kLD_e>g5;mC]aBoDkLD_e>
g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001B
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`08
Ool00`00Oomoo`0=Ool002Eoo`03001oogoo009oo`05J[H4]D:L@Ye2W003@[d01EHDEQEF55HEEQ@0
0VN?00E6_DJlA[e6_7KA00=f/@07M]5f/D:L@Wa2W3il@Y`00T[M00e:_4:mFUEJEV>@FUIJEEYF>U/j
G3YK>Ua:g002B]d02D:mCM==ddgCDM==de7C?Wa2O002?W`014[LC]e:g4kM0T[M00M:g4[MK]AbeFkD
K]E^e002034024kLB]a>gD[LC]e>g4kmC]`2@[d01WK@M[1fd7J`M]1f/0802006C]e:g4kLB]a>gDkL
0Tkl00UBoDkLC_e>o5;mC]a>gDkLC_d00`0000=ZefKFJ]H00P0014Zl00A>g4klC]aBo@=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001B
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo1Eoo`03001oogoo00=oo`05
001oogooOol0000?Ool002Aoo`03001oogoo009oo`0?;UeZeVJe2;E2W4:M@Ya6_CjMEQEB55HEEQAW
SfM^009WS`1IB]e6_4[MA[afdG:aM]5b/GKAL[52W3il@Y`nO4[MB[a:gDJlA[eJ=EYFFSEJEUXeFUI6
_4[MA[a:gDZlB]e:_57CCK=Ae4fcDM==/e7D?W]2O3ik@Wa:g4kMB]a>oCZM?YdjWG;eK]AbeFkDL_D0
<@0bB[a>gD[LC]e:_4kmC]a>oD[L@[ef/7[AM[1jdGJ`N]401`0800L024kLD_e>g4kmC]aBoDkLD_e>
g5;mC]aBo@0300002d[MB[aZefKFJ]MV]RVI001:_4JlB[d00TZl09M>g5;mC]aBoDkLD_e>o5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`04Ool3
000@Ool002Aoo`<00003Ool^GF[F009ZeP84]@96_@08A[a2_EHDEQEF55HEEQAF5@<jG005B]e6_4Jm
A[efd@05M[401003@Wa2W3il0T:m00Y6_D:mFUIJEEYFFUEJEV>@Hk56_09:_005B]e:g4[M@[eAd`03
CM<01U7CCM=AddZlB]e:_09:g00:C]e:g4kM>YebeFkDK]E^e7;EK]@30343C]`04DkMC]a>gDkLC]e>
g7K@M[1fd7J`M]1f/4JL@Ya6W4:LAY`00dkL00IBoDkLC_a>o5;mC]`200000dkmC]a:g@02B]d026KF
J]IZeV[GI]HYV2FHC]d3C]`01DkMC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00Ool05goo000TOol0JP00OomoobiM
J]IV]F[FJ[H4]@Bd2;E6_4KMA[aF5EHDEQEB55HEEQ@nO3YK?W`jFcilA[a:gDJlM]5b/GKAL[5fd@03
00A6_4[MA[a6_D:lA[e2_5YFFSEJEUXeIk5ST4[MA[a:gDJl@[e2W4JmCK=AddfcDMA=de7CCK=FidZl
B]e:_4[MB]a>gD[LC_e^e7;EK]AbmFkDL]D0<DJmAYa6_4[LC_e>g4kmB]a>gD[LC]e:g7[AM[1jdGJ`
N]5f/4JL@W]6W4:LC_e>g5;mC]aBoDkL0`000:]>g5;mC]aBoDkLC]e:g4[M<WaZefKFJ]LUV2VI9IQ>
gDkLC_e>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`057oo00<007ooOol05Goo000JOol40006Ool01000<Wd^GC9m0V[F00=Z]V[FJ]H0
0PBe0dJm00dnWEHEIhmF5EHDEQEF54JmA[a6_DJlA[dnW@06M[4200<04TZmB[a:gDZlB[e2_DJmFUEJ
EUYEFUIJECYL>U]:gD[LB]e:g092_@9=d`05DM==de7CCM=Fi`02D^L014[LC]e:g4kM0T[M00Q:g4[M
K]AbeFkDK]E^e00b0dJL00I6_4kLC]e>g4kmC]`2B]d03TkMB]afd7J`M]5f/7K@@Ya6W4:LAYa2W4km
C]`300002DkLC_a>o5;mC]a>gDkLC_e>g002=Wd03F[GI]IZeV[FJ]LUV2VH9IQBoDkLC_a>g5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`C
Ool00`00Oomoo`0EOol001Uoo`03001oogoo009oo`03001oogoo00=oo`09001oogooI[EZeVZfJ]IV
]F[F0084]@0F1;A2_CjM@[eB55HEEQAF5E8DEQEWKTZmA[a:gDJl?[eb/GKAL[5fdG:aM]4300<0@4[M
B[a:gDJlB]e2_5YFFSEW/EXeFUHj>ciL>U]>gDZlC]e:g4kMCK=Ae4gCDM==/e7D?W]2O3ik@Wa:g4kM
B]a>gDZlB]e:_7;eK]AbeFkDL_D0<@@bB[a>gD[LC]e>g4kmC]a>oD[LC]e:g4kMB]ajdGJ`N]5f/008
B]a>gDZl0`000;=>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g6[GI]IZefJfJ]MVeTZlA[a:_DZlD_e>
g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l01=oo`03001oogoo01Aoo`006Goo00<007ooOol00Woo00<007ooOol00goo0P000Woo
00UZ]V[FJ]IZeWoo1;E2W4:M@Y`00d:m00EF55HEEQAF5FN>00=WS`03A[a6_DJl00Mf/@03@Wa2W3il
00=:g@0=B[`03d:mFUIJEEYFFUEJESYK>U`jFd[MB]`00T[M00m2_DgCDM==de7CD^MAdcil@W`nO4kM
B]a>gD[LC]d00T[M011:g6kEK]AbeFkDK]D0<@0bB]a>g4[LC]e>g4kMC]a>o@92_@07M[1fdGJ`M]1f
/7KA00P00`0000E:g4kLB]aBoDkL009>o006D_e>g4kmC_aBoD[L0d[M00E:g6[FJ]IZefKF008000=:
_003C]aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol04goo000IOol00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00f[FI[EZeP03Ool0E4Jm@Ya2WD:LA[dnWEHEDQAF5EHDEQEB53il>U/nO4Jl
B]e6_7KAL[5fdG:aM]5b/D:L?Wa2W3ilB]e:_4[MA[aJEUXeFUIJ=EYFFSE:gDJlB]e6_4[MB[a:gD:m
DM==/e7DCM=Addfc@W`nNd9l?W]>oD[LC]e:g4km>YdnWFkDL_E^e7;EK]@4DP0a139:_4kMB]a>gD[L
C_e>g4km?YajdGJ`N]5f/0<0002j00L02008C_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a:
gFJfJ]MVeRVI9IPYVBFHB[a6_4ZmC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m4goo00<007ooOol04goo000IOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00f[FOomoo`02Ool030BeA[e6_DJmA[a2_EHDEQEF
56N?EQAF5@<jG003B]e6_4Jm00Mf/@04@Ya2O4:L?W`2@[d01TJmFUEJEUYEFUIJE@9ST00MB[e6_4Zl
B[a:_D[LB]e2_E7CCM=AddgCDM==dd[LB[a:gDZlC]e:g4kMB]a>gFkDL]E^e6kEK]Abe@03AY`02TJl
C]a>g4kLC]e>g4kMC]a>gGJ`0`0000Qf/7K@M[16W4:LAYa2W4km0dkL00YBoDkLC_a>o5;mC]a>oDkL
B]e:g0=:g@05I]IZeV[F:IPUV002:IP01TkMC]a>g5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04goo00<007ooOol04Woo
000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool0CPRe1;A:gDJlA]e6_5HEEQAF
5E8DEQEF55HE>U/nO3YKB]e6_4[ML[5fdG:aM]9b/GKA00=:gDJlB]e6_4Jm@[e6_EXeFUIJ=EYFHi1S
/F>@C]e:_4kMB]a>gD:L@[e=de7CCK=Ae4gCDM<004[MB[a:gDZlB]e:_4[MB[a:gFkDL]E^e7;eK]@4
DT:LA[a6W4kmB]a>oDkLC_e:g0<00031M[1jdGJ`N]5f/7[A@Ya6W49kAYa2W5;mC]aBoDkLD_e>g5;m
C]aBoDkLD_e>g4[MB]a>gD[LJ]MV]V[G9IPYVBFH:IU>g4kMC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007oo
Ool04Goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool2000:Ool31;D2A[d03CjMEQEF55HEEQAF
5EHDA[e6_4JmA[`n_CjM00If/@0600@00dZmB[a:gDZl0T:m00EJEUYEFUIJEEYF00<jF`04B]e:g4[M
B]`2@[d01E7CCM=AddgCDM<00`0000E>gD[LC]e:g4kM009:g@08B]a^eFkDL]E^e6kE0356_0=6W003
C_e>g0000080000AB]a:gD[MC]ef/7K@M[1fdGJ`00Q:g4kMB]a>g4[LC_e>g002C_`025;mC]a>o4kl
C_e>g4kMC]`3=Wd016[FJ]MVeV[F0RVH00PUV2VHC]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l4goo00<007ooOol0
4Goo000JOol40005Ool00`00Oomoo`09Ool0B4:L@Ye2W4Jm?Ye2_E8DEQEF55HEDQAF5F=^B[e6_4[M
A[a:_G:aM]9b/GKAL[5fdP0300@00d[MB[a:gDJlA[eJ=EYFHi1JEUXe>U`j>ciL>U]>gDZlC]e:g4:m
CK=Ae4gCDM==/e7D?W]2O3ikC]e:g4kMB]a:gDZlB]e:_7;eK]AbeFkD1580<DkMB[a>g@80000VC]a>
oDkLC_e:g4kMB]a>gGJ`N]5f/7KA00P02D[LC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]a>
oFJfJ]MV]V[GI[I:_@9:_02PA[a:_DkLD_e>g5;mC_aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dBOol3000BOol000Eoo`800003Ool0
000001Uoo`03001oogoo00Yoo`03@Ya2WD:L00=2_@05EQAF5EHDEQESKP02Ihh01D[MA[a6_DJmB]d0
17Ja00Eb/GJa@Wa2W3il00=:g@0800m2_EYEFUIJEEYFFUDjG0<jF`0:B]e:g4[M@[eAddgCDM==de7C
CM<2?W`01T9l?W`nO4[LC]e:g0=:g@06K]A^eFkDK]E^e0@a0`0000i>g4[LC]e>g4kMC]a>gD:mM]1f
/7KAM[1fd7J`0`0800M:g4kMB]a>g4klD_e>g002C_`01U;mC]a>oDklB]e:g0=:g@05I]IZeV[F:IP0
0005B[`00e;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04Goo00<007ooOol047oo0004Ool00`00Oomoo`02
000JOol00`00Oomoo`0;Ool0@4:L@Ye2W4:m?YeF5E8DEQEF55HE>U/nO3YKB]e6_4[MA[afdG:aM]9b
/GKAL[52W3il@Y`nO4[MB[a:gEXeFUIJ=EYFFSES/6>@B]e6_4[MA[a:gDZl@[e=de7CCK=Ae4gCDM==
/d[MB[a:gDZlB]e:g4kMB]`nWFkDL]E^e7;e0`000144DP0aC_e:g4kmC]a>oD[LC_e>g4:mM[1jdGJ`
M]5f/7[A00<0202k00U>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MB]a>gD[LJ]MV]V[GI[HYVBFH
C_e>g4kMC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04goo00<007ooOol03goo0004Ool01@00Oomoogoo0000
6Goo0`003Goo0TJm00E6_4:mEQAF5EHD00=F5@05>U/jG3YLB]e6_002A[d00gJaL[5f/@02M[401@03
B[e:_4[MB[`00T:m00EJEUYEFUIJEEYF00=ST00GB[e6_4ZlB[a:gD[L@[e=de7CCM=AddgCDM<004[L
B[a:gDZlC]e:g4kMB]a^e@0300000fkEK]A6_003AY`05DkMC]a>g4kLC]e>g4kMC]afdGJ`M]1f/7KA
M[1fdD:LAYa2W4JLC]a>o@02C]`00dklD_e>g002C_`01TkmC]a>oDkLB]e:g09:g@03J]MVeV[F008Y
V0049IQ>g4kLC]d2C]`00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04Goo00<007ooOol03Woo0004Ool0
1@00Oomoogoo00006Goo00<007ooOol03Goo035:gDJlA]dnW5HEEQAF5E8DEQEF55HE>U/nO3YK?[dj
WGKBL[5fdG:aM]9b/@0400=:gDJlB]e6_4Jm@[eJEUXeFUIST6>`GhmS/6>@C]e:_4kMB]a2_D:LDMA=
de7CCK=Ae00200001TZlB]e:_4[MB[a:g@<0003FL_E^e7;EK]Abm@0aA[a2W4JlAYa6_4kLC_e>g4km
B]a>gD[LM]5f/7[AM[1fdGJ`AYa2W4JL@W]6W4kLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL=WdbO6[G
I[IZefJfJ]LUV2VI9IQBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`COol00`00Oomoo`0>Ool000Aoo`05
001oogooOol0000IOol00`00Oomoo`0>Ool3@[d03CjMEQEF5EHEEQAF5F=^Ihi6_4JmA[`n_G:a00=f
/@0@L[5f/@0400@00dZmB[a:gDZl@[eJEEYFFUEST5YEFUH3>U/02T[MB]a:gD[L@[e=de7CCM=AddgC
0`0000=:g4kM00000P000d[M015^e6kEK]E^eFkD1384<DkMB]a>g4[LC]e>g4kMC]a>gD[L009:g@0:
C]ef/7KAM[1fd@08C]a:g4kMB]`2C]`02dkmC]a>o4klD_e>g4kmC_a>oDkLC]d00SIm00EVeV[FJ]IZ
efKF00A:_004C_a>g5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo00eoo`000goo0P000Woo
0P006Goo00<007ooOol03goo0352_CjM@[eB55HEEQAF5E8DIhmSKTZmA[a:gDJlM]5b/GKBL[5fdG:a
M]8nO4:L?Wa:gDZlB]e6_5YFFSES/5XeFUIJ=CYL>S/nG3YKB]e:_4[M@[eAddfcDMA=de7CCM=2O003
0000=TkMB]a>gD[LB]e:_4[MK]AbmFkDL]E^e0AB035>gDZlC]e:g4kmC]a>oDkL@[dnW7[AM[1fdGJ`
N]5f/00900Q>gD[LC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmI[IZefJfJ]MV]P80002VB[e:
_4ZlA[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`COol00`00Oomoo`0<Ool0029oo`80019oo`03@[eF
5EHD009F5@06IhiSKVN>Hfi:gDJl0TJm00=f/G:aM[400WJa00Eb/D:L@Wa2W3il00=:g@09@[eJEUYE
FUIJEEYFFUE:_DJl009:_007B]e:g4[MCM=AddgCDM<00`0000a2O3il@W`nO4kMB]a>gD[L?YdjWFkE
K]@3K]D04P0a139:g4kMB]a>g4[LC]e>g4kMC]a2_GJ`M]5f/7KAM[1fd@<0209>g00EC_e>g4kLC_aB
oDkLC_a>g4kmC]a>oDkLB]e:g4[MJ]IZefKFJ]HYV00000E:_09Bo005D_e>o5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
D_aBo00COol00`00Oomoo`0<Ool0029oo`03001oogoo015oo`0Y@[dnWEHEDQAF5EHDEQDjFcil>U]:
gDJlB]e6_7KAL[5fdW:aM]5b/D:L?Wa2W3ilA[e2_DJmFSEJEUXeFUIJ=F>@Ghm:gDJlB]e:_4[MB[a2
_@030000iE7DCM=Ae4ZlB]e:_4[MB[a>oD[LC]djWG;eK]AbeFkDL_E^e0AB0344DTkLC_e:g4kmC]a>
oD[LC_e>g7KAM[1jdGJ`M]5f/7[A@Ya6W49kD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4[MB]aZ
efJfJ]MV]V[G9IPYVDkLC_e>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001B
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01=oo`03001oogoo00]o
o`008Goo00<007ooOol04goo00A2_EHEEQEF509F5@06>U`jFcYL>Ua:gDJl0TJm00=f/G:aM[400WJa
00D014ZmB[a:gDZl0092_@06A[eJEEYFFUEJEUn?0V>@00A:_DJlB[a2_@80000@DM==de7CCM=AddgC
001:_4[LB[a:gDZlC]e:g4kMK]@3K]D016kDK]D4<DJl0TJL00=>g4kMC]`00TkL019>gD[LB]e:gGKA
M[1fdGJ`M]5f/4JL@Ya6W4:LAYa>g4kmC]`2C_`01e;mC]a>o4kLC_e>g4km009:g@05B]`fOFKFJ]MV
eP03:IP3C]`01DkMC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo019oo`8000aoo`008Goo00<007oo0000
4goo02<nW5HEHfiF5E8DEQEF54ZmA[a:gDJl?[djWGKBL[5fdG:aM]9b/@0400=:gDJlB]e6_4Jm@[eJ
EUXeFUIJ=EYF>S/nG3YK00<00092_@05CK=Ae4gCDMA=d`040000h4kMB]a>gD[LB]e:_4[MK]AbmFkD
L]E^e0ABAYa6_4:LA[a6W4kmC]a>oDkLC]e:g4kMM[1fdGJ`N]5f/7KA00Q>gD[LC]e:_4kMC]aBoDkL
D_e>g5;mC]aBoDkLC_e>g4km<WdfOFJfJ]MV]V[GI[HYVBFH:IU>g5;mC]aBoDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`COol00`00Oomoo`0:Ool0025oo`8001Eoo`0=EQAF5EHEEQEF55HEHfi6_DJlA[e6_4Jm
L[400gJa00=b/GJa00@00P040d[M00M:_4:mFUEJEUn?FUIJE@0300004d[LB]e:g4[MB]aAddgCDM==
de7CCM=2O3il@W`nO4kMB]a>gD[L009:g@03K]E^e6kE009^e@0/K]@4DT[LC]e:g4kLB]a>oDkLC]e>
g4kMB]a:gGJ`M]5f/7KAM[002@08C]a:g4kMB]a>o4kLC_e>g4kmC_aBoDkLC_e>g4kmC]a>gFKFJ]MV
eV[FI]IZe`A:_005C]a>o4kLD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0AOol2000;Ool000mo
o`@000Aoo`@000Ioo`03001oogoo01Eoo`0KDQAF5EHDEQESKVN>HfiWSTJlB]e6_4[ML[5fdW:aM]5b
/GKB?Wa2W3ilB]e:_4[M00i6_EXe00<0001<FSDjG3Xk?Ua:_4[MB[a:gD:mDM==de7DCM=Ae4gC@W`n
Nd9l?W]>gD[LC]e:_4[MB[abeFkDL]E^e7;E0344DT[LC]e:_4kMB]a>oD[LC_e>g4:mM[1jdGJ`M]5f
/7[A00P02DZlC]e:g4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e:g4[MB]a>gFJfJ]MV]V[G9IP004JlB[d2
B[`0YDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00>Ool300000goo001oo`0:Ool000ioo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`0EOol01UHEEQAF5EHEOolj
F`<jG005A[a6_DJmM[5b/@03M[401G:a@Ya2O4:L?W`00T[M0`0000QJEEYFFUEOT5n?B[e6_4Zl0T[M
00E:g4:mCM=AddgC00=Ad`09CM=:g4ZlB]e:_4kMB]a>gCZM00=^e@08K]A^eFkE1584<@ABC]a>g@=>
g00=C]e>g4kM@[efdGJ`M]5f/7KAM[002@0800T00dkL00]>oDkLC_a>o5;mC]a>oDkLC_e>g4km009:
g@05B]aZeVKFJ]MVeP03:IP3C]`01TkMC_aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aB
o5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00Yoo`@0
00Aoo`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03001oogoo00=oo`8001Ioo`03EQAF5E8D
00=oo`0?>U/nO3YK?Wa6_4[MA[afdW:aM]9b/GKB00A:gDJl00<0003j@[eJEUXeFUIJ=EYFGfmST4Jl
B]e6_4[MA[a:gDZl@[e=de7DCM=Ae4gCDM@004[MB[a:gD[LC_e:g4kMK]AbeFkDL]E^e7;E1356_4:L
A[a>g4kmB]a>oDkLC_e:g4kmM[1fdGJ`N]5f/7KAM[16W4:LAYa>g5;mC]a>oDkLD_e>g5;mC]aBoDkL
D_e>g5;mB]a:gD[LJ]MV]V[G9IPY^BFH:IU>g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d6Ool30008Ool00`00Oomoo`09Ool001=oo`04001oogoo0004Ool00`00Oomoo`02Ool2000GOol3
EQD4Ool01DJlA[e6_4Jm?Yd00gJa00=b/GJaM[400`0000=:_4[MB[`00T:m00EJEUYEFUIJEEYF008j
F`05B]a:gD[LB]e:g002@[d01E7CCM=AddgCDM<00`0000A:g4ZlB]e:g0=:g@08K]A^eFkEK]E^e6kE
AYa6_0=6W00:C_e>g4kMC]a>gD[LB]ef/7KAM[02M[400gKA@Ya6W002AY`01DkLC_a>g4kmC]`00Tkl
00MBoDkLC]e>g4kmC]a>g@02=Wd016KFJ]IVeV[G12VH00A>g4klC]aBo@=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l0goo0`0037oo00<007ooOol027oo000?Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0GOol00eHEOomoo`04Ool01dJlB]e6_3jmL[5fdW:a00<000<0101EB]e:_4[MA[a6
_EXeFUIJ=EYFFSDjG3Xk?Ua:g4kMB[a>gD[L@[e=de7DCM=Ae4gC@W`nNd9l?W]>gD[LC]e:_4[MB[a:
gFkDL]E^e7;EK]@4DT[LC]e:_4kMB]a>oDkLC_e:g4kMB]a>gGJ`M]5f/7KAM[002DZlC]e:g4kMC]aB
oDkLD_e>g5;mC]aBoDkLC_e>g4kmC]a>oFJfJ]MV]V[GI[I:_4JlB[d00TZl0:M>g5;mC]aBoDkLD_e>
o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l008000moo`03001oogoo00Qoo`003goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol05goo00=F57ooOol01Goo00=6_4JmA[`00`000WJa
00Eb/GJa@Wa2W3il00=:g@08B[aJEUYEFUIJEEYFFUDjG0<jF`06B]e:g4[M@[eAddgC0U7C00X004gC
@W`nO49lB]a>gD[LC]e:g0=:g@0>K]A^eFkEK]D4<@ABB]a>gD[LC]a:g4kmC]a>g@92_@06M[1f/GJa
M]5f/7Ja0P0900E:g4kLB]a>gD[L009>o006D_e>g4kmC_aBoDkL0d[M00E:g4[MI]IZefKF008000E:
_004C_aBo5;lD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo11oo`03001oogoo00Qoo`003goo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol087oo0P000?m6_7KBL[5fdW:aM]9b
/D:L?Wa2W3il@Ya:_4[M@[aJEUXeFUIJ=EYFA[a:gDJlB]e6_4[MB[a2_DgCDMA=de7DCM=Ae4gC@W`n
Nd9lB]a>oD[LC]djWCjM>YebeFkDL]E^e0AB1344DTkLC_e:g4kmC]a>oD[LC_e2WGKAM[1fdGJ`M]5f
/00900P02DkLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4[MB]aZefJfJ]MV]RVi9IQ>gDkLC_e>
g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`000YBoE;lD_eBo5;mD_aBoE;lD_eBo0moo`03001oogoo00Qoo`003goo
1@000goo10001Goo0P007Woo0`0001Y:gDJlA[e6_GJaL[5f/G:aM[5b/DZmB[a:gDZlB[e2_DJmFUEJ
EUYEFUIJEEn?B[a:_DJl0TZl00=:gD[LDM<00U7C00e=de7CDM=Ad`00B]a:_4[MB]a>gD[LC]e:g003
K]D016kDK]E6W4Jl0TJL00=>g4kMC]`00TkL00I>gDkLC]ef/GKAM[02M[400gKAM[16W002AY`3C]`0
2TkmC]a>o4klD_e>g4kmC]a>oDkL0d[M00A:g6[FI]IZe`<YV006C]e>g4kLC]aBoDkl0U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`00e;mD_aBo00?Ool00`00Oomoo`08Ool0021oo`03001oogoo01Yoo`<000Ao
o`0SB]e6_4[MA[afdW:aM]9b/GKB00A:gDJlB]e6_4Jm@[e6_EXeFUIJ=F>@GfmST5m_C]e:_4kMB]a2
_D:LDMA=de7DCM=Ae0020000iTZlB]e:_4[MB[a:gDZlB]e:_7;EK]AbeFkDL]E6W4Jl@Ya6_4kLC_e:
g4kmB]a>gD[LC]ef/7KAM[1fdGJ`M]52NdJL@Ya6W4kLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL=Ydb
OCImI[IZefJfJ]LUV2ViC]a>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d>
Ool00`00Oomoo`08Ool0021oo`03001oogoo01Moo`<000Qoo`09?[dnWGJaL[5f/G:aM[5b/@050080
1003B[a:gDZl0092_@05FUIJEEYFFUEJEP03>U/00d[MB]a:g@02@[d01DgCDM=Ade7CCM<00`0000E:
g4kMB]a>gD[L00=:g@08K]A^eFkEK]E^e0ABAYa6_096W007C]a>oDkLC]e:gDkMB]`00WJa01IfdGJ`
M[5f/@09B]a>g4[LC]e>g4klC]a>oDkLC_e>o5;mC]a>gDkLC_e>g08fO@04J]MVeV[FI]H3:IP01TkL
D_e>g4klC]aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`03Goo00<007ooOol027oo000O
Ool00`00Oomoo`0EOol3000=Ool01G:aM]9b/GKBL[400Woo0592W3il@Ya:_4[MA[a6_EXeFUIOKeYF
FSDnG3Xk?U`jFdkMB[a>gD:mDMA=de7DCM<004gC@W`nNd9lB]a>gD[LC]e:_4[MB[a:gFkDL]E^e6kE
1344DT[LC]e:_4kMC]a>oDkLC_e:g4kMB]afdGJ`M]5f/7KA00P02DZlC]e:g4kMC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4kmC]aZefJfJ]MV]P80002_B[a6_4ZmC]aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d03Goo00<007ooOol01goo000OOol2000COol3000AOol00g:aM[5b/@03
Ool00d9l@Y`nO003B]d02DZl@[eJEEYFFUEJEUYEB[e6_002B[`00d[MB]a2_@02DM<034gCDM=Ade7C
?Wa2O3il@Wa:g4kMB]a>g@<jW@0:K]E^e6kEK]D4DPAAC]a:g4kMB]`2C]`01TkMC]a>gD:mM]5f/09f
/@03M]5f/00900802@=>g00:C_e>g4klC_aBoDkLC_e>g4kmC]`3B]d01T[LJ]IVeV[GI[H000A:_003
D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003
001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol037oo00<007oo
Ool01goo000OOol00`00Oomoo`0?Ool3000DOol00gKBL[5oo`03Ool0o`05?Wa2W3ilA[e2_DJmFSEJ
EUXeFUIJ=En?Gfm:gDJlB]e6_4[MB[aAe4gCDMA=de7dCM=Ae4ZlB]e:_4[MB]a>oD[LC]e:g7;EK]A^
eFkDL]D4<@AB135>oDkLC_e:g4kmC]a>oD[LC_ef/7KAM[1fdGJ`M]5f/4JL@Ya6W4kLD_e>g4kmC]aB
oDkLD_e>g5;mC]aBoD[LC]e:g4[MI[IZefJfJ]LUV2ViC]a>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@001E;lD_eBo5;mD_`037oo00<007ooOol01goo000OOol00`00Oomoo`0<Ool3
000MOol01@0400E:_4[MB[`00T:m00I6_EYEFUIJEEYFGfl2Ghl014[MB]a:gD[L0T:m0e7C00U=de7C
DM<004ZlB]a:_4[MB]`00d[M00U:g6kEK]E^eFkDK]E6W4JlAY`00TkL00Y>gDkLC]a:gDkMB]a:gGJa
M]5f/09f/@03M]52W4JL0096W005C]a>o4kLC_e>g002C_`01U;mC]a>oDkLC_e:g0=:g@04I[IZeVKF
J]L2:IP01TkLC]e>g4kLD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;l
D_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0:
Ool00`00Oomoo`07Ool001moo`03001oogoo00Uoo`<0021oo`0C00D01005A[a:gDJlA[e2_EYFFSEJ
EUXeFUHj>ciL>U]>gDZlC]d00T:m00E=de7DCM=Ae4gC00<0003YB]a>gD[LC]e:_4[MB[a:gFkDL]E^
e6kEK]@4DTJLA[a2W4JlC]a>oDkLC_e:g4kMB]afdGJ`M]5f/7KAM[002DZlC]e:g4kMC]aBoDkLD_e>
g5;mC]aBoDkLC_e>g4km<WdfWFJfJ]MV]V[GI[HYVBFH:KU>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00:Ool00`00Oomoo`07Ool001moo`8000Qoo`8002=oo`04
@Wa2W3il@Y`2B]d024Zl@[eJEEYFGfmJEUYE>U`3>U/01T[MB]a:gD:mDM==d`=Ad`09CM=2O3il@Wa:
g4kMB]a>gD[L00=:g@04K]A^eFkEK]D215800d[LC]e:g002C]`01TkmC]a>gD[MC]e:g09f/@03M]5f
/7Ja00802@05B]a>g4[LC]e>g002C_`03U;mC]a>oDklD_e>g4kMC]a>oFJfJ]IVeV[GI[H20003B[`0
1TkLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;m
D_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`08Ool00`00
Oomoo`07Ool001ioo`03001oogoo00Eoo`<002Ioo`0k?Wa2W3ilB]e:_4[MA[a6_EXeFUIJ=EYFFSE:
gDJlB]e6_4[MB[a2_DgCDMA=de7dCM=Ae3ik@W`nNd9lB]a>oD[LC]e:g3jM>Ye^eFkDL]E^e0AB135>
gD[LC]e:_4kMC]a>oD[LC_e2WGKAM[1fdGJ`M]5f/00300T05TkLD_e>g4kmC]aBoDkLD_e>g5;mC]aB
oD[LC]e:g4[MI[IZefJfJ]LUV0000TZl0;16_4ZmC]aBoDkLD_e>o5;mC]aBoDklD_e>o5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m2Woo00<007ooOol01Woo000NOol00`00Oomoo`02Ool3000ZOol00d9l
@Y`nO002@[d01TJmFUEJEUYEFUIJE@9OK`03B[e6_4Zl009:g@05B]a2_E7CDM==d`03DM<02DZlB]a:
_4[MB]a>gD[LC]djW@03K]D00fkDK]D4DP021582C]`02TkMC]a>g4kLC]e>g4kMM[5fdGJ`0WJa00=f
dD:LAY`00TJL0dkL00Y>oDkLC_a>o5;mC]a>oDkLC_e:g09:g@04J]MV]V[FI]H3:IP01dkLC]e>g4kL
D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0Yoo`03001oogoo00Io
o`007Woo00<007oo00000P00;Woo0116_4[MA[a6_D:mA[eJ=EYFFSEJEU]^GhmKKT[MA[a:g@92_@3c
@YaAm4gCDMA=de7dCM<004ZlB]e:_4[MB[a>oD[LC]e^e7;EK]A^eFkDL]E6W4Jl@Ya>oDkLC_e:g4km
B]a>gD[LC]ef/7KAM[1fdGJ`00U2NdJL@Ya6W4kLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g6[G
I[IZefJf:ITUV2ViC]a>gDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l00Uoo`03001oogoo00Ioo`007Woo0`00<7oo00]:_DZlB]e:_4Zm@[eJEUYEFUIJEEYF00<j
F`03B]e:g4[M0092_@05CM=Ade7CDM==d`0300001D[LC]e:g4kMB]`00d[M00Q^e6kEK]E^eFkD1596
W4Jl0TJL00M>g4kmC]a>gD[MC]e:g002M[400gKAM[5f/@0200T02D[LC]a:g4kMC]a>o4kLC_e>g002
C_`02e;mC]a>gDkLC_dbOCImI]IZefJfJ]H012VH00I>g5;mC]a>o5;lD_d3D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`8Ool00`00Oomoo`06Ool000Aoo`D000=oo`@000Aoo`@000Mo
o`03001oogoo031oo`0iB]e:_4[MA[a:gEXeFUIKKUYFFSDnG3Xk?U`jFdkMB[a>gD[LDMA=de7dCM=A
e4gC@W`nNd9lB]a>gD[LC]e:g4[MB[a:gFkDL]E^e6kE1544DT[LC]e:_4kMC]a>oDkLC_e:g4kMB]af
dGJ`M]5f/00:00802@0DB[a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_eV]V[GI[IZe`80009:
_02cA[a:_DkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o007Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool0
0`00Oomoo`05Ool2000aOol3B]d02DZl@[eJEEYFFUEJEUYEB[e6_002B[`01T[MB]a:gD:mDM==d`9A
d`0:DM@nO49l?Wa2O4[LC]e:g4kMB]`2>Yd016kEK]A^eFkE0PAB00A>g4[LC]e:g09>g005C]e>g4kM
@[efd@03M[400gKA00T02@0200T3C]`02TkmC]a>o4klD_e>g4kmC_aBoD[L0d[M00EV]V[FI]IZe`00
00E:_003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l
00Moo`03001oogoo00Ioo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03
001oogoo00Moo`03001oogoo031oo`3o@[e6_D:lFUIJ=EYFFSEJEU]^B]e6_4[MA[a:gDZl@[e=de7D
CM=Am4gCDMA:_4[MB[a:gD[LC_e:g4kM>YebeFkDK]E^e7;E1544DPAAC_e>g4kmB]a>oDkLC_e:g4km
M[1fdGJ`M]5f/4JL@W]6W4:LAYa>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e:g4kMB]aZefJfJ]MV]RVI
:IQ>oDkLC]e>g4kmC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0005D_eB
o5;mD_aBo@06Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool02d:mA[e2_EYFFUEJEU]^GfiKKTZmA[`00TZl0d:m
0U7C00e=de7CDM<004ZlB]a:_4[MB[a>gD[LC]e^e003K]D01FkDK]E6W4JlAY`00TkL00U>gDkLC]a:
gDkMB]a:gGJaM]400gJa00=6W4:LAY`00TJL00E>g4klC]a>oDkL009>o006C_e>g4kmC]a>oD[L0T[M
00AZefJfI]IVeP8YV09>g005C]e>g4kLD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aoo`06Ool00`00Oomoo`05Ool000Ioo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`09Ool00`00Oomoo`0`Ool04d:mA[eJ=EYFFSEJESXk?U`jFdkM
B[a>gD[L@[e2W57dCM=Ae4gC00<0003]B]a>gD[LC]e:g4[MB[a:gFkDL]E^e6kEK[@4LTJLA[a2W4Jl
C]a>oDkLC_e:g4kMB]afdGJ`M]5b/7KA00U>gDZlC]e:g4kMC]aBoDkLD_e>g5;mC]a>oDkLC_e>g4km
<WdfWFJfJ]MV]V[G:IPYVBVHD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l00Ioo`03001oogoo00Eoo`001Woo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo00Yoo`80035oo`06@[eJEUYEFUIJEEYF0cYK00HjG4[LB]e:
g4:mCM<2DM<02U7DCM=2O3il@Wa:g4kMB]a>gD[L0d[M00A^e6kEK]E^e@84DP03B]a>gD[L009>g006
C_e>g4kMB]e>gD[L0WJa00YfdGJa00T02DkMB]a>g4[LC]e>g09>o00:D_e>g4kmC_a>oDkLC]e>g4km
I[H2I]H00f[G00000003B[`014klC]aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol017oo00<007ooOol01Goo0004Ool30004Ool00`00Oomo
o`02Ool01000Oomoo`0017oo00<007ooOol037oo00<007ooOol0;goo04a2_EYFFSEJEUXeFUI6_4[M
A[a:gDZlB]e2_E7DCM=Am4gCDO@nNd9l?W]2O3ikC_e:g4kMB]`nWCZMK]E^]7;EK]@4DPAAC]e:g4kM
B[a>gDkLC_e:g4km@YefdG:`M]5f/7KA00T02P0900Y>g5;mC]a>oDkLD_e>g5;mC]aBoDkLB]e:g4kM
B]a:gFJfJ]MV]V[G001:_@9:_02eA[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`017oo00<007ooOol01Goo0006Ool00`00Oomoo`03Ool40004
Ool4000@Ool00`00Oomoo`0^Ool01EYFFUEJEUYEFUH00U]^00U6_4ZlB[a:gD[L@[eAde7DCM<00U7C
00YAe4ZlB]a:_4[MB[a>gD[LC]djW@=^e@03K]A^e@AB0084DP9>g009C]e>g4kLC]a>gDkLC]ef/GKA
00=f/@03M]52W4JL0096W0=>g00:C_e>g4klC_aBoDkLC_e>g4[MB]`2B]d016[GI[IVeVKF0RVH0TkL
00I>gDkLD_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eoogoo009oo`03001oogoo00Eoo`00:Goo00<007ooOol0;Woo0?mJEUXeFUIJ=En?FfiOKTJl
B]e6_4:m@Ya2_DgCDMA=de7dCM<004ZlB]e:_4[MB[a>oD[LC]e^]7;EK]A^eFjdK]E6W4Jl@Ya>oDkL
C_e:g4kmB]a>gD[LC]ef/7KAL[1fdGJaAYa2NdJL@Ya6W4kLD_e>g5;mC]aBoDkLD_e>g5;mC]a:gD[L
C]e:g6[GI[IZefJf:KTYV4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d000ABo5;mD_aBo@=oo`03001oogoo00Eoo`00:Woo00<007ooOol0;Goo00=J
EEYFFUD00Woo0SYK00@jG4[LB]e:g092_@9Ad`03DMA=d`0000<00004C]e:g4kMB]`3B]d026kDK]E^
eFkEK]@4DTJLA[`2AY`01dkLC_e>g4kMB]e>gD[L009f/@0FM]5f/GJa00U>gD[LC]a:g4kMC]a>o4kL
C_e>g4kmC_aBoDkLC]e>g3Im<Wd2I]H00f[GI[IVeP03:IP014klC]aBoDkL0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0=oo`03001oogoo00Eoo`00:goo
0P00;Goo00=JEUXeGhl00Woo04@j>ciL>U/nG4ZlC]e:g4:mCM=Am4gCDOA=dd9l?W]2O3ikC]e:g4kM
B]a:gDZlB]e^]6kEK]A^e@AA179:g4kMB[a>gDkLC_e>g4kmB]a>gD[LM]5f/GKAL[002P09C]e:_4kM
B]a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aZefJfJ]MV]V[G0P000TZl0;M6_5;mC]aBoDkLD_e>o5;m
C]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00goo00<007oo
Ool017oo000]Ool00`00Oomoo`0[Ool00eYFOomoo`02Ool02DJlB[a:_4ZmB]a:gD:mDMA=d`02DM<0
2U7D?Wa2O3il@W`nO4kMB]a>gD[L0SZM00A^eFkDK]E^e@<4DP03B]a>gD[L009>g005C]e>g4kM@[ef
d@03M[401GKA00T02P09C_d00dkL00Y>oDkLC_a>o5;mC]a>oDkLC_e:g09:g@04J]MV]VKFI[H2:IP4
B[`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004
D_eBo5;lD_`2Ool00`00Oomoo`04Ool002ioo`03001oogoo031oo`3oA[a:gDJlB]e:_4[MCM=Am4gC
DOA=de7dB[a:gDZlB]e:_4kmB]a>gD[LK]E^e6kEK[A^eDJLA[a2W4JlC]a>oD[LC_e>g4kmB]a>oGJa
M]5b/7KAM[5fdD9kAYa2W4kmC]aBoDkLC_e>g5;mC]aBoDkLD_e>g4[MB]a>gFJfJ]MV]V[G:IPY^BVH
C_e>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l005oo`4000Ioo`00;goo00<007ooOol0<7oo00A:g4[MB]a:g@92_@03DM=Ae57C
009Ad`06001:_4[LB[a:gDZl0d[M00U:g6kEK]E^eFkDK]E6W4JlAY`00TkL00U>gDkLC]a:gDkMB]a:
gGJaM]400gJa00Y6W4:LAYa6W4kmC]a>o4kLC_e>g09>o00;D_e>g4kmC]a:gD[LB]eV]V[GI[IVeP02
:IP3C]`01DkMC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m009Bo003Ool007oo00Eoo`00<7oo0P00<Goo00U:_4kMB]a>gD:LDOA=de7dCM<01000
0?9>gD[LC]e:g4[MB]a:gFjdK]E^e6kEK[@4LTJLA[a2W4kmC]a>oDkLC_e:g4kMB]afdGJaM]5b/7KA
00U>gDZlC]e:g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g3Im<WeZefJfJ]MV]RVi:IPY^DkLD_e>g5;m
C]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@001Woo000bOol00`00Oomoo`0_Ool01D[LB]e:gD:mCM<00U7C00YAe000DM<nO49l?Wa>gD[L
C]e:g0=:g@04K]A^eFkEK]D215802d[LC]e:g4kMC]a>oDkLC]e:gDkMB]`00WJa00YfdGJa00X02TkM
B]a>g4[LD_e>g09>o00<D_e>g4kmC_aBoDkLC]e>g6[GI[IVeVJf0P0014Zl00A>o4kLD_e>g09Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`3Ool00`00Oomo
o`04Ool003=oo`03001oogoo02moo`3eB[a:gD:mDOA=de7dCM=Am4gCDO@nNd9l?W]>oD[LC]e:g3jM
>Ye^eFjdK]E^e0Ab1584LT[LC]e:_4kmC]a>oD[LC_e2WGKAL[1fdGJaM]402@0:00U>oDkLD_e>g5;m
C]aBoDkLD_e>g5;mC]aBoD[LC]e:g6[GI[IZefJf:KTYV4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo008Ool00`00Oomoo`03Ool003Aoo`03001o
ogoo02moo`0AB]a:gE7CDMAAd`00DM=Ae57C001:_4[MB[a>gD[LC]e:g003K]D016kDK]E6W4Jl0TJL
00=>g4kMC]`00TkL00E>gDkLC]ef/GKA00=f/@05M]52W4JLAYa>g@03C]`03e;mC]a>o4klC_e>g4km
C]a>oD[LB]eV]V[GI[IVeP03:IP2C]`01DkMC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`0
1E;mD_aBo5;lD_d00U;l2Woo00<007ooOol00goo000eOol2000`Ool01d:L@[e=de7dCM=Am4gC00<0
003UB[a:gDZlB]e:g4[MB[a^eFkDK]E^]6kEAYa6_4:LA[a>g4kmC]a>oD[LC]e:g4kMM[5fdG:aM]5b
/DJL@W]6W4:LD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLC_dbOCImI[IZefJfJ]LYV2Vi:IQBoDkLD_e>
g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_`037oo00<007ooOol00goo000g
Ool00`00Oomoo`0^Ool014:mDM<0057D0e7C00I2O3il@Wa:g4kMB]`3B]d02FkDK]E^eFkEK]@4DT[L
C]e:g002C]`02DkmC]a>gDkLB]e:g4[MM[5fd@02M[405`0:C]e:g4kLB]a>oDkLC_a>g5;mC]a>oDkl
C_e>g4kMC]a>oFJfI]IV]V[GI[H014Zl00A>o4kLD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<0
05;mD_`00U;l3goo00<007ooOol00goo000hOol00`00Oomoo`0]Ool09T:mCM=Am4gCDOA=de7d?W]2
O3ik@Wa:g4kMB]a:gD[LB]e^]6kEK]A^e@AB179:g4kMB[a>gDkLC_e:g4km?YefdG:aM]5b/GKAL[42
00X05dkMB[a>gD[LD_e>g5;mC]aBoDkLD_e>g4[MB]a>gD[LJ]MV]V[GI[HY^@00B[d00TZl0:M6_5;m
C]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00019oo`03001oogoo00=oo`00>Goo00<007ooOol0
;Goo00EAe57CDM=Ade7D009Ad`03B[a:gDZl009:g006C]e:g3ZM>Ye^eFkD0VkE00D4LPAB159>g4kM
00=>g005C]e>g4kMM[5fd@03M[401GKA00X02P0:C]d00dkL00YBoDkLC_a>o4kmC]a>oDkLB]e:g09:
g@04J]MV]VKFI[H2:IP2C]`01TkMC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo004Ool00`00Oomoo`0?
Ool00`00Oomoo`03Ool003Yoo`8002eoo`3O@[eAm4gCDOA=de7dCM<004ZlB]e:_4[MB]a>gD[LK]E^
e6kEK[A^e@ABA[a2W4JlC]a>oD[LC_e>g4kmB]afdG:aM]5b/GKAL[5fdD9kAYa2W4kmC]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4[MB]a>gC9mJ]MV]V[G:IPY^BVHC_e>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`027oo00<0
07ooOol03goo00<007ooOol00goo000lOol00`00Oomoo`0ZOol00d:mDM=Ae003DM<3000014[LC]e:
g4kM0T[M00=:g6kEK]D00VkE00<4LTJLA[`00TJL00A>g4kmC]a>g@9:g@04B]af/GJaM]43M[402P0:
@Ya6W4JLC_e>g4klC]aBoDkL0Tkl00Y>oDkLC]e>g3Im<WeVeVJfJ]MV]P@YV004C_a>g5;mC]`2D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eB
o0aoo`03001oogoo00moo`03001oogoo009oo`00?Goo00<007ooOol0:Woo02EAm4gCDOA=de7dOom2
O3ik@Wa:g4kMB]a>gD[LB]e:_6kEK]A^eFZd27=:g4kMB[a>gDkLC_e>g4kmB]a>gD[LM]5b/GKAL[5f
d@0200X04dZlC]e:g4kMC]aBoDkLD_e>g5;mC]a>oDkLC_e>g6[GI[IZefJf0080002HB[e:_4ZlA[aB
oDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03
001oogoo00ioo`03001oogoo009oo`00?Woo00<007ooOol0:Goo0e7C00aAe57COolnO49l?Wa2O4[L
C]e:g4kM>Yd5K]D01@AB179:g4kMB]`00TkL00E>gDkLC]e2_GKA00=f/@03M]5f/@0:00802P=>g00:
C]e>g4klC_aBoDkLC_e>o4[MB]`2B]d01F[GI[IVeVJf000014Zl00E>o5;lD_aBoDkl009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol05goo00<007ooOol03Goo00<007ooOol0
0Woo000oOol00`00Oomoo`0XOol014:mCM=Am4gC0goo0<I:_4[MB[a:gD[LC]e:g4kmK]A^eFZdK]E^
e0Qb1588LdkLC_e:g4kmC]a>oD[LC_eb/GKAL[5fdG:aM]52NdJL@Ya6W4kLD_e>g4kmC]aBoDkLD_e>
g5;mC]a:gD[LC]eV]V[GI[IZebVH:KU>g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_dLOol00`00Oomoo`0=Ool00`00Oomoo`02Ool0041oo`8002Uoo`03DMAAde7C00Ao
o`04B[a:gDZlB]`2B]d00d[LB]e^e@03K]D00`AbA[a6W002AY`00dkMC]a>g002B]d014[LB]ef/GKA
0gJa00<02T:LAY`00TJL00E>g4klC]a>oDkL009>o00>D_e>g4kmC]a:gD[LB]eV]V[GI[IVeRVH:KPY
V09>g005C]eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol07Woo00<007ooOol037oo
00<007ooOol00Woo0012Ool00`00Oomoo`0VOol00dgCDOA=d`05Ool0=4[LC]e:g4kMB]a:gDZlK]E^
e6kEJ[@8L`ABC]e:_4kMB]a>oDkLC_e:g4kMB]afdG:aM]5b/GKA00Y>gDZlC]e:g4kMC]aBoDkLD_e>
g5;mC]aBoDkLC_e>g3Im<WeZefJfJ]MV]TZm0TZl08M6_5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`09Goo00<007ooOol02goo00<007ooOol00Woo0013Ool00`00Oomoo`0UOol2DM<7Ool014[LC]e:
g4kM0T[M00=:g6kEK]D00VkE0PAb00M>gD[LC]a:g4kmC]a>g@02B]d00d[LM[5f/@02M[4200X01TkM
B]a>g4[LD_e>g09>o00>D_e>g4kmC_aBoDkLC]e>g6[GI[IVeVJfI]L000A:_09Bo005D_e>o5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`XOol00`00Oomoo`0;Ool00`00Oomoo`02Ool004Aoo`03001oogoo02Aoo`03CM=Am7oo00Mo
o`2dB]a>gD[LC_djWFkEJ[A^eFjdK]D4DPQc159>oD[LC_e>g4kmB]a>oCjMM]5b/GKAL[5fd@0:00/0
2TkmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LJ]MV]V[GI[H]^BVHC_e>g4kMC]aBoDkLD_e>
g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m;Goo00<007ooOol02goo00<007ooOol00Goo0015Ool2000UOol00e7COomoo`07Ool014[LC]e:
g4kM1FkE00D8LTJLAYa6W4kM00=>g003C]e>g4kM00If/@04@Ya6W4JLC]d3C]`04U;mC]a>o4klD_e>
g4kmC]a>oD[LB]eV]V[GI[IVeVJf:KPYV09>g005C]e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l035oo`03001oogoo00Yoo`03001oogoo
005oo`00Agoo00<007ooOol0;Goo0:a:g4[MB[a:gFjdK]EZ]6kE1596_4JLA[a6W4kmC]a>oDkLC]e:
g4kML[5fdG:aM]9b/@0;@W]6W4:LD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLC_dbOF[GI[IZefJfJ]LY
V2fi:IQBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoCEoo`03001oogoo00Uoo`03001oogoo005oo`00B7oo00<007ooOol0;Woo00=:gD[LK]D0
16kE00`4LTkMB]a>g4[LC_e>g4kMC]a:gD[LB]d4M[4200X05D[LC]a:g4kMC]a>o4kLD_e>g4kmC_a>
oDkLC]e>g6KGI[IVeVJfI]L00004B[`014klC]aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo006D_eBo5;lD_aBoE;l>Goo00<007ooOol02Goo00<007ooOol00Goo0019Ool00`00Oomoo`0^
Ool0;3jMJ[A^eFjdK]EZ]0Qc159>gDZlC]e:g4kmB]a>oDkL@[eb/GKBL[5fdG:a00/02P0;C]aBoDkL
C_e>g5;mC]aBoDkLD_e>g4[MB]a>gD[LJ]MV]V[GI[H20000M4ZmB[a:_4kLD_e>g5;mC]aBoDklD_e>
g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`mOol00`00Oomoo`08Ool00`00Oomoo`01Ool004Yo
o`8002moo`E^e@041788LPAbC]d3C]`014kMC]a>gDkL1GJa00Ab/DJLAYa6W0=>g00=C]e>g4klC_aB
oDkLC_e>g4[MB]a:gFJfI]L00VJf00<YV2VhC]`00TkL00E>gDklD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o006D_eBo5;lD_aBoE;l@Goo00<007ooOol01goo00<007ooOol00Goo001<Ool00`00Oomoo`0]Ool0
VFkEJ[A^eGoo27=6W4JlAYa6_4[LC_e>g4kMB]a>gD[LM]5b/GKBL[5fdD9kAYa2W4JLC]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4[MB]a>gFJfJ]MV]V[G:IP]^BVHC_e>g4kMC]aBoDkLD_e>g5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@16Ool00`00Oomoo`06Ool00`00Oomoo`01Ool004eoo`03001oogoo02aoo`9^e@9oo`88
LP09B]a>g4[LC]e>g4kMC]a:gD[L009:g@0FM[5b/GJaM[402d[LC]a:g4kMC]a>o4kLC_e>g4kmC_aB
oDkLC]e>g3Im<Wd2I[H00fKGI[I:_003B[`014klC]aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol0
Agoo00<007ooOol01goo0@000Goo0Goo001>Ool00`00Oomoo`0`Ool0:0Ab27=:_4kMB]a>gDkLC_e>
g4:m?YafdW:aM]5b/GKB00X02dZlC]e:g4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g6[GI[IZefJfJ]L0
04Zm0TZl06A6_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoDeoo`03001oogoo00Ioo`40005oo`5oo`00Cgoo0P00
<7oo0`Qb0dkL00I>gDkLC]e>g4:mL[43M[4017:a00/02P0;0dkL00Y>gDkLC_a>o5;mC]a>oDkLC_e:
g09:g@06I]MV]VJfI[H]^2VH0TkL00I>gDkLD_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo59oo`03001oogoo00Eoo`40005oo`5oo`00
DGoo00<007ooOol0;Woo08I6_4JLA[a:g4kmC]a>oD[LC_e>g7KAL[5fdW:aM]9b/DJL@Ya6W49kD_e>
g4kmC]aBoDkLD_e>g5;mC]aBoD[LC]e:g6[GI[IZefJf;KTYV4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>
g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lEGoo00<007ooOol01Goo
0@000Goo0Goo001BOol00`00Oomoo`0^Ool2AY`01TJlC]a>gDkLC_e:g09:g@03M[5b/GJa009f/@09
00Y>g4[LC]e:g4klC]a>oDkL009>o005D_e>g4kMC]a>o@02<Wd02fJfI]MV]VJf:IP]^2VHC_a>g5;m
C]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_aIOol0
0`00Oomoo`04Ool10001Ool1Ool005=oo`03001oogoo02ioo`0SC]e:g4kMC]a>oDkLC_e:g4kMB]af
dW:aM]9b/@0;00Y>gD[LC]e:_5;mC]aBoDkLD_e>g5;mC]a>oDkLC_eV]V[GI[IZe`020002B[`0EdJl
D_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo01MOol00`00
Oomoo`03Ool10001Ool1Ool005Aoo`03001oogoo02ioo`08C]a:g4kMC]a>gDkLC]e2_@=f/@05L[5f
/@0;00/02P02C]`02TkMC]a>o4klD_e>g4kmC]a>oDkL0T[M00IVefJfI[IV]Rfh:IP4B[`2D_`01E;m
C_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lHWoo00<007ooOol00goo0@000Goo001E
Ool2000_Ool0MDkmC]a>oD[LC_e>g4kmL[5fdW:aM]9b/@0;@Ya6W49kD_e>g4kmC]aBoDkLD_e>g5;m
C]aBoD[LC]e:g6[GI[IZefJf;KTYV4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@1UOol00`00Oomoo`03Ool10001Ool005Moo`03001oogoo02aoo`05C]a>gDkLC_e:g003B]d0
1G:aM[5f/GJa00/00dJL00E>g4klC]a>oDkL009>o005D_e>g4kMC]a>o@02<Wd02fJfI]MV]VJf:IP]
^2VHC_a>g5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;lK7oo00<007ooOol00Woo0@000Goo001HOol0
0`00Oomoo`0/Ool084kLC_e>g4kmB]a>gD[LM]9b/GKBL[402`0:C]e:g4kMB[aBoDkLD_e>g5;mC]aB
oDkLC_e>g4kmI[IZefJfJ]L20002B[`0ATJlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mLGoo00D007ooOomoo`00
005oo`00FGoo00<007ooOol0;7oo00E>g4kMC]a>gD:m00=f/@03L[5f/@0;00802`9>g00:C]e>g4kl
C_aBoDkLC_e>o5;mB]`3B]d3I[H00fKG:IPY^003B[`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo7Eoo`04001oogoo0001Ool0
05Yoo`8002eoo`1RB]a>oDkLC_eb/GKBL[5fdW:aM]92VdJL@W]BoDkLC_e>g5;mC]aBoDkLD_e>g5;m
C]a>gD[LJ]MV]V[GI[H]^BVH;KU>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoGQoo`04001oogoo0001Ool005aoo`03001oogoo02]o
o`09B]a:gD[MB]eb/GJaL[5f/G:a00=6W005@Ya>o4kLC_e>g002C_`01U;mC]a>gDkLC_e>g08bO@0:
I]MV]VJfI[H]^2VH:KQ>g4kMC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00U;lO7oo00<007oo00000Goo001MOol00`00Oomoo`0/Ool07DkMB]a>gG:aM]9b
/GKB00Y>gD[LC]e:_5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g6[GI[IZefJfJ]L00TZl03Y6_4ZmC]aB
oDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoH1oo`40005oo`40
0000GWoo00<007ooOol0;7oo00I2_G:aM[5b/GJaL[4300/00d[LC]e:g002C_`01U;mC]a>oDklD_e>
g0=:g@06B]aV]VJfI]LYV00014Zl00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00U;lQ7oo0P00001OOol2000]Ool017KBL[5fdW:a0Woo04Y6W49kAYa>g4kmC]aBoDkLD_e>
g5;mC]aBoDkLC]e:g4[MI[IZefJfJ]LYV4kmC]a>gDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lR7oo0P00001QOol00`00Oomoo`0[Ool00gJaL[5oo`02Ool2AY`01D:LAYa>g4kmC]`0
0Tkl00IBoDkLC_a>g4kmC]`3B]d3I[H01Rfh:IP]^4kLC]e>g09Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoE;lOol0RWoo0P00001ROol00`00Oomoo`0_Ool05@0;B]a>gDZlC]e>g5;mC]aBoDkLD_e>g5;m
C]a>oDkL=WeV]V[GI[IZe`02B[`0:TJlB[e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoHeoo`@0009oo`00Hgoo
00<007ooOol0;Woo0`0;00I>gD[LC]a>o5;mC]`2C_`01E;mC]a>gDkLC_d00fJf00=VefJf000014Zl
00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m009Bo8aoo`@000Ioo`00I7oo0P00;Woo03]6W49kAYa2VdkmC]aBoDkLD_e>g5;m
C]aBoDkLC]e:g4[MI[IZefJfI]LYV2fiC]a>gDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m08]oo`@000Yoo`00IWoo00<007ooOol0
;7oo00I6W4:LAYa>g4kmC]`2C_`01U;mC]a>o4kLC_e>g0=:g@=V]P05I]LYV2fhC]a>g@02C]`00e;l
D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b:Ool4
000>Ool006Moo`03001oogoo02]oo`0dB]a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL=WdbOFKG
I[IZefJf;KTYV2fiC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaf:Ool3000BOol006Qoo`03001oogoo02]oo`07B]a>gD[LC]a>o5;mC]`00Tkl00IBoDkL
C_e>g4kmC]`2I[H016KGI[H]^0000dZl00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aBo029Ool4000EOol006Uoo`8002aoo`0/C]a>oDkLD_e>g5;mC]aBoDkLD_e>
g5;mB]a:gD[LJ]MV]VKGI[H]^DkLC]e>g4kmC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aC7HQoo`@001Uoo`00Jgoo00<007ooOol0:goo00I>gDkLC]a>o5;mC]`2C_`00dkmC]a>o@02
B]d024[LI[IV]VJg:IP]^4kLC]d2C]`00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0
Qgoo10007Goo001/Ool00`00Oomoo`0[Ool085;mC]aBoDkLD_e>g5;mC]a>oDkLC_dbOFKGI[IZefJf
;KTYV2fiC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_b9Ool4000QOol006eoo`03001oogoo02]oo`0:
D_e>g4klC_aBoDkLC_e>o4kmC]`2I[H016JgI[IV]P0014Zl00EBoDklD_aBo5;m00=Bo8Uoo`<002Eo
o`00KWoo00<007ooOol0;7oo01M>g5;mC]aBoDkLD_e>g4[MB]aZefJfI]MV]Rfi:IQ>gDkLC_e>g5;m
C]aBoDkL08Qoo`@002Qoo`00Kgoo0P00;Goo00I>g4klC_a>oDkLC_d2B]d024[LI[IV]VJgI[H]^2fH
;KP3C]b7Ool4000/Ool0075oo`03001oogoo02Yoo`0=D_e>g5;mC]a>oDkLC_dbOCImI[IZefJfI]L0
RGoo1000<7oo001bOol00`00Oomoo`0ZOol02E;mC]a>oDklC_e>g4kMI[IV]`02I[J6Ool4000dOol0
07=oo`03001oogoo02Yoo`09D_e>g5;mC]a:gD[LC]eV]VKG08=oo`@003Qoo`00M7oo0P00;7oo00I>
g4kmC]a:gD[LB]f1Ool3000lOol007Ioo`03001oogoo02Uoo`03001oogoo081oo`@003moo`00Mgoo
00<007ooOol0:7oo00<007ooOol0O7oo1000@goo001hOol00`00Oomoo`0WOol00`00Oomoo`1hOol4
0017Ool007Uoo`8002Moo`03001oogoo07Aoo`@004]oo`00Ngoo00<007ooOol097oo00<007ooOol0
LGoo0`00Cgoo001lOol00`00Oomoo`0SOol00`00Oomoo`1]Ool4001BOol007eoo`03001oogoo029o
o`03001oogoo06Uoo`@005Ioo`00OWoo0P008Woo00<007ooOol0IGoo1000FWoo0020Ool00`00Oomo
o`0OOol00`00Oomoo`1QOol4001NOol0085oo`03001oogoo01ioo`03001oogoo05ioo`<0069oo`00
PWoo00<007ooOol07Goo00<007ooOol0FWoo1000IGoo0023Ool00`00Oomoo`0LOol00`00Oomoo`1F
Ool4001YOol008Aoo`8001aoo`03001oogoo059oo`@006eoo`00QWoo00<007ooOol06Goo00<007oo
Ool0CWoo1000LGoo0027Ool00`00Oomoo`0HOol00`00Oomoo`1;Ool3001eOol008Qoo`03001oogoo
01Moo`03001oogoo04Moo`@007Qoo`00RGoo0P005goo00<007ooOol0@goo1000O7oo002;Ool00`00
Oomoo`0DOol00`00Oomoo`0oOol40020Ool008aoo`03001oogoo019oo`03001oogoo03aoo`@008Ao
o`00SGoo00<007ooOol04Goo00<007ooOol0>Goo0`00R7oo002>Ool2000AOol00`00Oomoo`0eOol4
002;Ool0091oo`03001oogoo00ioo`03001oogoo035oo`@008moo`00TGoo00<007ooOol03Goo00<0
07ooOol0;Goo1000Tgoo002BOol00`00Oomoo`0<Ool00`00Oomoo`0YOol4002GOol009=oo`8000ao
o`03001oogoo02Eoo`@009]oo`00UGoo00<007ooOol02Goo00<007ooOol08Woo0`00Wgoo002FOol0
0`00Oomoo`08Ool00`00Oomoo`0NOol4002ROol009Moo`03001oogoo00Moo`03001oogoo01Yoo`@0
0:Ioo`00V7oo00<007ooOol01Woo00<007ooOol05Woo1000ZWoo002IOol20006Ool00`00Oomoo`0B
Ool4002^Ool009]oo`03001oogoo00=oo`03001oogoo00moo`<00;9oo`00W7oo00<007ooOol00Woo
00<007ooOol02goo1000]Goo002MOol01@00Oomoogoo00002Goo1000^Goo002NOol200000goo001o
o`04Ool4002mOol00:1oo`800003Ool0000000800<5oo`00XGoo0P00aGoo003oOomYOol00?moofUo
o`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.64 .74 .921 r
.39635 .69743 .40168 .70226 .41059 .70011 .40528 .69526 Mtetra
.637 .739 .922 r
.40528 .69526 .41059 .70011 .41953 .69816 .41424 .69314 Mtetra
.613 .726 .926 r
.41424 .69314 .41953 .69816 .42845 .69796 .42322 .69154 Mtetra
.928 .698 .57 r
.42322 .69154 .42845 .69796 .43763 .68883 .43503 .58358 Mtetra
0 0 .427 r
.43503 .58358 .43763 .68883 .44662 .6885 .4414 .68321 Mtetra
.62 .718 .917 r
.4414 .68321 .44662 .6885 .45568 .6864 .45047 .68149 Mtetra
.644 .741 .92 r
.45047 .68149 .45568 .6864 .46478 .68402 .45958 .67918 Mtetra
.651 .747 .92 r
.45958 .67918 .46478 .68402 .47391 .68151 .46873 .67671 Mtetra
.654 .75 .92 r
.46873 .67671 .47391 .68151 .48307 .67894 .47792 .67415 Mtetra
.656 .752 .92 r
.47792 .67415 .48307 .67894 .49227 .67631 .48713 .67152 Mtetra
.658 .753 .92 r
.48713 .67152 .49227 .67631 .50149 .67364 .49638 .66885 Mtetra
.659 .754 .92 r
.49638 .66885 .50149 .67364 .51075 .67096 .50565 .66616 Mtetra
.50565 .66616 .51075 .67096 .52004 .66826 .51496 .66344 Mtetra
.51496 .66344 .52004 .66826 .52936 .66556 .5243 .66072 Mtetra
.5243 .66072 .52936 .66556 .53871 .66286 .53367 .658 Mtetra
.658 .753 .92 r
.53367 .658 .53871 .66286 .54809 .66015 .54308 .65527 Mtetra
.54308 .65527 .54809 .66015 .5575 .65744 .55251 .65254 Mtetra
.55251 .65254 .5575 .65744 .56695 .65472 .56198 .64981 Mtetra
.56198 .64981 .56695 .65472 .57642 .652 .57148 .64707 Mtetra
.57148 .64707 .57642 .652 .58593 .64928 .58101 .64432 Mtetra
.58101 .64432 .58593 .64928 .59548 .64654 .59057 .64157 Mtetra
.59057 .64157 .59548 .64654 .60505 .6438 .60017 .63881 Mtetra
.657 .753 .92 r
.60017 .63881 .60505 .6438 .61466 .64105 .6098 .63604 Mtetra
.6098 .63604 .61466 .64105 .6243 .63829 .61946 .63327 Mtetra
.61946 .63327 .6243 .63829 .63397 .63553 .62916 .63048 Mtetra
.657 .752 .92 r
.62916 .63048 .63397 .63553 .64368 .63275 .63889 .62769 Mtetra
.63889 .62769 .64368 .63275 .65342 .62997 .64865 .62489 Mtetra
.64865 .62489 .65342 .62997 .66319 .62718 .65845 .62208 Mtetra
.65845 .62208 .66319 .62718 .673 .62438 .66828 .61926 Mtetra
.66828 .61926 .673 .62438 .68284 .62157 .67815 .61643 Mtetra
.67815 .61643 .68284 .62157 .69272 .61875 .68805 .6136 Mtetra
.68805 .6136 .69272 .61875 .70263 .61593 .69798 .61075 Mtetra
.69798 .61075 .70263 .61593 .71258 .61309 .70795 .6079 Mtetra
.70795 .6079 .71258 .61309 .72256 .61025 .71795 .60503 Mtetra
.71795 .60503 .72256 .61025 .73257 .60739 .72799 .60216 Mtetra
.72799 .60216 .73257 .60739 .74262 .60453 .73807 .59928 Mtetra
.73807 .59928 .74262 .60453 .75271 .60165 .74818 .59639 Mtetra
.74818 .59639 .75271 .60165 .76283 .59877 .75833 .59348 Mtetra
.75833 .59348 .76283 .59877 .77298 .59588 .76851 .59057 Mtetra
.76851 .59057 .77298 .59588 .78318 .59297 .77873 .58765 Mtetra
.77873 .58765 .78318 .59297 .79341 .59006 .78898 .58472 Mtetra
.78898 .58472 .79341 .59006 .80367 .58714 .79927 .58178 Mtetra
.79927 .58178 .80367 .58714 .81397 .58421 .8096 .57882 Mtetra
.8096 .57882 .81397 .58421 .82431 .58126 .81996 .57586 Mtetra
.81996 .57586 .82431 .58126 .83469 .57831 .83036 .57289 Mtetra
.83036 .57289 .83469 .57831 .8451 .57535 .8408 .56991 Mtetra
.8408 .56991 .8451 .57535 .85555 .57237 .85128 .56691 Mtetra
.85128 .56691 .85555 .57237 .86603 .56939 .86179 .56391 Mtetra
.86179 .56391 .86603 .56939 .87656 .5664 .87235 .5609 Mtetra
.87235 .5609 .87656 .5664 .88712 .56339 .88294 .55787 Mtetra
.88294 .55787 .88712 .56339 .89772 .56038 .89357 .55484 Mtetra
.89357 .55484 .89772 .56038 .90836 .55735 .90423 .55179 Mtetra
.90423 .55179 .90836 .55735 .91904 .55432 .91494 .54873 Mtetra
.91494 .54873 .91904 .55432 .92975 .55127 .92568 .54567 Mtetra
.92568 .54567 .92975 .55127 .94051 .54821 .93647 .54259 Mtetra
.93647 .54259 .94051 .54821 .9513 .54514 .94729 .5395 Mtetra
.94729 .5395 .9513 .54514 .96214 .54206 .95815 .5364 Mtetra
.95815 .5364 .96214 .54206 .97301 .53897 .96906 .53328 Mtetra
.96906 .53328 .97301 .53897 .98392 .53587 .98 .53016 Mtetra
.639 .738 .921 r
.391 .69254 .39635 .69743 .40528 .69526 .39995 .69039 Mtetra
.64 .74 .921 r
.39995 .69039 .40528 .69526 .41424 .69314 .40892 .6882 Mtetra
.631 .735 .923 r
.40892 .6882 .41424 .69314 .42322 .69154 .41793 .68621 Mtetra
.536 .688 .937 r
.41793 .68621 .42322 .69154 .43503 .58358 .42692 .68598 Mtetra
.54 .319 .529 r
.42692 .68598 .43503 .58358 .4414 .68321 .43617 .67678 Mtetra
.562 .657 .9 r
.43617 .67678 .4414 .68321 .45047 .68149 .44523 .67642 Mtetra
.637 .735 .919 r
.44523 .67642 .45047 .68149 .45958 .67918 .45436 .67428 Mtetra
.648 .745 .92 r
.45436 .67428 .45958 .67918 .46873 .67671 .46353 .67186 Mtetra
.653 .749 .92 r
.46353 .67186 .46873 .67671 .47792 .67415 .47273 .66931 Mtetra
.656 .751 .92 r
.47273 .66931 .47792 .67415 .48713 .67152 .48196 .6667 Mtetra
.657 .752 .92 r
.48196 .6667 .48713 .67152 .49638 .66885 .49123 .66403 Mtetra
.658 .753 .92 r
.49123 .66403 .49638 .66885 .50565 .66616 .50053 .66132 Mtetra
.659 .754 .92 r
.50053 .66132 .50565 .66616 .51496 .66344 .50986 .65859 Mtetra
.50986 .65859 .51496 .66344 .5243 .66072 .51922 .65586 Mtetra
.51922 .65586 .5243 .66072 .53367 .658 .52861 .65311 Mtetra
.52861 .65311 .53367 .658 .54308 .65527 .53803 .65036 Mtetra
.658 .753 .92 r
.53803 .65036 .54308 .65527 .55251 .65254 .54749 .64761 Mtetra
.54749 .64761 .55251 .65254 .56198 .64981 .55698 .64486 Mtetra
.55698 .64486 .56198 .64981 .57148 .64707 .5665 .6421 Mtetra
.5665 .6421 .57148 .64707 .58101 .64432 .57605 .63934 Mtetra
.57605 .63934 .58101 .64432 .59057 .64157 .58564 .63657 Mtetra
.58564 .63657 .59057 .64157 .60017 .63881 .59526 .63379 Mtetra
.657 .753 .92 r
.59526 .63379 .60017 .63881 .6098 .63604 .60491 .631 Mtetra
.60491 .631 .6098 .63604 .61946 .63327 .61459 .62821 Mtetra
.61459 .62821 .61946 .63327 .62916 .63048 .62431 .6254 Mtetra
.62431 .6254 .62916 .63048 .63889 .62769 .63407 .62259 Mtetra
.657 .752 .92 r
.63407 .62259 .63889 .62769 .64865 .62489 .64385 .61978 Mtetra
.64385 .61978 .64865 .62489 .65845 .62208 .65367 .61695 Mtetra
.65367 .61695 .65845 .62208 .66828 .61926 .66353 .61411 Mtetra
.66353 .61411 .66828 .61926 .67815 .61643 .67342 .61127 Mtetra
.67342 .61127 .67815 .61643 .68805 .6136 .68334 .60841 Mtetra
.68334 .60841 .68805 .6136 .69798 .61075 .6933 .60555 Mtetra
.6933 .60555 .69798 .61075 .70795 .6079 .70329 .60267 Mtetra
.70329 .60267 .70795 .6079 .71795 .60503 .71332 .59979 Mtetra
.71332 .59979 .71795 .60503 .72799 .60216 .72339 .5969 Mtetra
.72339 .5969 .72799 .60216 .73807 .59928 .73349 .594 Mtetra
.73349 .594 .73807 .59928 .74818 .59639 .74362 .59108 Mtetra
.74362 .59108 .74818 .59639 .75833 .59348 .75379 .58816 Mtetra
.75379 .58816 .75833 .59348 .76851 .59057 .764 .58523 Mtetra
.764 .58523 .76851 .59057 .77873 .58765 .77424 .58229 Mtetra
.77424 .58229 .77873 .58765 .78898 .58472 .78452 .57934 Mtetra
.78452 .57934 .78898 .58472 .79927 .58178 .79484 .57638 Mtetra
.79484 .57638 .79927 .58178 .8096 .57882 .8052 .57341 Mtetra
.8052 .57341 .8096 .57882 .81996 .57586 .81559 .57042 Mtetra
.81559 .57042 .81996 .57586 .83036 .57289 .82602 .56743 Mtetra
.82602 .56743 .83036 .57289 .8408 .56991 .83648 .56443 Mtetra
.83648 .56443 .8408 .56991 .85128 .56691 .84699 .56142 Mtetra
.84699 .56142 .85128 .56691 .86179 .56391 .85753 .55839 Mtetra
.85753 .55839 .86179 .56391 .87235 .5609 .86811 .55536 Mtetra
.86811 .55536 .87235 .5609 .88294 .55787 .87872 .55231 Mtetra
.87872 .55231 .88294 .55787 .89357 .55484 .88938 .54926 Mtetra
.88938 .54926 .89357 .55484 .90423 .55179 .90008 .54619 Mtetra
.90008 .54619 .90423 .55179 .91494 .54873 .91081 .54311 Mtetra
.91081 .54311 .91494 .54873 .92568 .54567 .92158 .54002 Mtetra
.92158 .54002 .92568 .54567 .93647 .54259 .9324 .53693 Mtetra
.9324 .53693 .93647 .54259 .94729 .5395 .94325 .53381 Mtetra
.94325 .53381 .94729 .5395 .95815 .5364 .95414 .53069 Mtetra
.95414 .53069 .95815 .5364 .96906 .53328 .96507 .52756 Mtetra
.96507 .52756 .96906 .53328 .98 .53016 .97605 .52442 Mtetra
.635 .735 .92 r
.38562 .68755 .391 .69254 .39995 .69039 .39458 .68548 Mtetra
.64 .74 .921 r
.39458 .68548 .39995 .69039 .40892 .6882 .40357 .68327 Mtetra
.637 .739 .922 r
.40357 .68327 .40892 .6882 .41793 .68621 .4126 .68112 Mtetra
.613 .726 .926 r
.4126 .68112 .41793 .68621 .42692 .68598 .42164 .67948 Mtetra
.929 .699 .568 r
.42164 .67948 .42692 .68598 .43617 .67678 .43359 .57104 Mtetra
0 0 .424 r
.43359 .57104 .43617 .67678 .44523 .67642 .43996 .67105 Mtetra
.62 .718 .917 r
.43996 .67105 .44523 .67642 .45436 .67428 .4491 .66929 Mtetra
.644 .741 .92 r
.4491 .66929 .45436 .67428 .46353 .67186 .45829 .66695 Mtetra
.651 .747 .92 r
.45829 .66695 .46353 .67186 .47273 .66931 .46751 .66444 Mtetra
.654 .75 .92 r
.46751 .66444 .47273 .66931 .48196 .6667 .47676 .66183 Mtetra
.656 .752 .92 r
.47676 .66183 .48196 .6667 .49123 .66403 .48605 .65916 Mtetra
.658 .753 .92 r
.48605 .65916 .49123 .66403 .50053 .66132 .49537 .65645 Mtetra
.659 .754 .92 r
.49537 .65645 .50053 .66132 .50986 .65859 .50472 .65371 Mtetra
.50472 .65371 .50986 .65859 .51922 .65586 .5141 .65096 Mtetra
.5141 .65096 .51922 .65586 .52861 .65311 .52351 .64819 Mtetra
.52351 .64819 .52861 .65311 .53803 .65036 .53296 .64543 Mtetra
.658 .753 .92 r
.53296 .64543 .53803 .65036 .54749 .64761 .54243 .64266 Mtetra
.54243 .64266 .54749 .64761 .55698 .64486 .55194 .63988 Mtetra
.55194 .63988 .55698 .64486 .5665 .6421 .56149 .6371 Mtetra
.56149 .6371 .5665 .6421 .57605 .63934 .57106 .63432 Mtetra
.57106 .63432 .57605 .63934 .58564 .63657 .58067 .63153 Mtetra
.58067 .63153 .58564 .63657 .59526 .63379 .59031 .62873 Mtetra
.59031 .62873 .59526 .63379 .60491 .631 .59999 .62593 Mtetra
.657 .753 .92 r
.59999 .62593 .60491 .631 .61459 .62821 .60969 .62312 Mtetra
.60969 .62312 .61459 .62821 .62431 .6254 .61944 .6203 Mtetra
.61944 .6203 .62431 .6254 .63407 .62259 .62921 .61747 Mtetra
.657 .752 .92 r
.62921 .61747 .63407 .62259 .64385 .61978 .63902 .61463 Mtetra
.63902 .61463 .64385 .61978 .65367 .61695 .64887 .61178 Mtetra
.64887 .61178 .65367 .61695 .66353 .61411 .65874 .60893 Mtetra
.65874 .60893 .66353 .61411 .67342 .61127 .66866 .60606 Mtetra
.66866 .60606 .67342 .61127 .68334 .60841 .67861 .60319 Mtetra
.67861 .60319 .68334 .60841 .6933 .60555 .68859 .60031 Mtetra
.68859 .60031 .6933 .60555 .70329 .60267 .69861 .59741 Mtetra
.69861 .59741 .70329 .60267 .71332 .59979 .70866 .59451 Mtetra
.70866 .59451 .71332 .59979 .72339 .5969 .71875 .5916 Mtetra
.71875 .5916 .72339 .5969 .73349 .594 .72887 .58868 Mtetra
.72887 .58868 .73349 .594 .74362 .59108 .73903 .58575 Mtetra
.73903 .58575 .74362 .59108 .75379 .58816 .74923 .58281 Mtetra
.74923 .58281 .75379 .58816 .764 .58523 .75946 .57986 Mtetra
.75946 .57986 .764 .58523 .77424 .58229 .76973 .5769 Mtetra
.76973 .5769 .77424 .58229 .78452 .57934 .78004 .57392 Mtetra
.78004 .57392 .78452 .57934 .79484 .57638 .79038 .57094 Mtetra
.79038 .57094 .79484 .57638 .8052 .57341 .80076 .56795 Mtetra
.80076 .56795 .8052 .57341 .81559 .57042 .81118 .56495 Mtetra
.81118 .56495 .81559 .57042 .82602 .56743 .82164 .56194 Mtetra
.82164 .56194 .82602 .56743 .83648 .56443 .83213 .55891 Mtetra
.83213 .55891 .83648 .56443 .84699 .56142 .84266 .55588 Mtetra
.84266 .55588 .84699 .56142 .85753 .55839 .85323 .55284 Mtetra
.85323 .55284 .85753 .55839 .86811 .55536 .86384 .54978 Mtetra
.86384 .54978 .86811 .55536 .87872 .55231 .87448 .54672 Mtetra
.87448 .54672 .87872 .55231 .88938 .54926 .88517 .54364 Mtetra
.88517 .54364 .88938 .54926 .90008 .54619 .89589 .54055 Mtetra
.89589 .54055 .90008 .54619 .91081 .54311 .90666 .53746 Mtetra
.90666 .53746 .91081 .54311 .92158 .54002 .91746 .53435 Mtetra
.91746 .53435 .92158 .54002 .9324 .53693 .9283 .53123 Mtetra
.9283 .53123 .9324 .53693 .94325 .53381 .93918 .52809 Mtetra
.93918 .52809 .94325 .53381 .95414 .53069 .9501 .52495 Mtetra
.9501 .52495 .95414 .53069 .96507 .52756 .96107 .5218 Mtetra
.96107 .5218 .96507 .52756 .97605 .52442 .97207 .51863 Mtetra
.626 .727 .919 r
.38021 .68239 .38562 .68755 .39458 .68548 .38918 .68051 Mtetra
.639 .738 .921 r
.38918 .68051 .39458 .68548 .40357 .68327 .39819 .67832 Mtetra
.64 .74 .921 r
.39819 .67832 .40357 .68327 .4126 .68112 .40723 .6761 Mtetra
.631 .735 .923 r
.40723 .6761 .4126 .68112 .42164 .67948 .41631 .67407 Mtetra
.536 .688 .937 r
.41631 .67407 .42164 .67948 .43359 .57104 .42536 .67381 Mtetra
.537 .316 .527 r
.42536 .67381 .43359 .57104 .43996 .67105 .43469 .66454 Mtetra
.562 .657 .9 r
.43469 .66454 .43996 .67105 .4491 .66929 .44381 .66415 Mtetra
.637 .735 .919 r
.44381 .66415 .4491 .66929 .45829 .66695 .45301 .66197 Mtetra
.648 .745 .92 r
.45301 .66197 .45829 .66695 .46751 .66444 .46225 .65951 Mtetra
.653 .749 .92 r
.46225 .65951 .46751 .66444 .47676 .66183 .47153 .65692 Mtetra
.656 .751 .92 r
.47153 .65692 .47676 .66183 .48605 .65916 .48083 .65426 Mtetra
.657 .752 .92 r
.48083 .65426 .48605 .65916 .49537 .65645 .49017 .65155 Mtetra
.658 .753 .92 r
.49017 .65155 .49537 .65645 .50472 .65371 .49954 .6488 Mtetra
.659 .754 .92 r
.49954 .6488 .50472 .65371 .5141 .65096 .50895 .64603 Mtetra
.50895 .64603 .5141 .65096 .52351 .64819 .51838 .64325 Mtetra
.51838 .64325 .52351 .64819 .53296 .64543 .52785 .64046 Mtetra
.52785 .64046 .53296 .64543 .54243 .64266 .53735 .63767 Mtetra
.658 .753 .92 r
.53735 .63767 .54243 .64266 .55194 .63988 .54688 .63487 Mtetra
.54688 .63487 .55194 .63988 .56149 .6371 .55644 .63208 Mtetra
.55644 .63208 .56149 .6371 .57106 .63432 .56604 .62927 Mtetra
.56604 .62927 .57106 .63432 .58067 .63153 .57567 .62646 Mtetra
.57567 .62646 .58067 .63153 .59031 .62873 .58534 .62365 Mtetra
.58534 .62365 .59031 .62873 .59999 .62593 .59503 .62082 Mtetra
.657 .753 .92 r
.59503 .62082 .59999 .62593 .60969 .62312 .60476 .61799 Mtetra
.60476 .61799 .60969 .62312 .61944 .6203 .61453 .61515 Mtetra
.61453 .61515 .61944 .6203 .62921 .61747 .62433 .61231 Mtetra
.62433 .61231 .62921 .61747 .63902 .61463 .63416 .60945 Mtetra
.657 .752 .92 r
.63416 .60945 .63902 .61463 .64887 .61178 .64403 .60658 Mtetra
.64403 .60658 .64887 .61178 .65874 .60893 .65393 .60371 Mtetra
.65393 .60371 .65874 .60893 .66866 .60606 .66387 .60083 Mtetra
.66387 .60083 .66866 .60606 .67861 .60319 .67384 .59793 Mtetra
.67384 .59793 .67861 .60319 .68859 .60031 .68385 .59503 Mtetra
.68385 .59503 .68859 .60031 .69861 .59741 .69389 .59212 Mtetra
.69389 .59212 .69861 .59741 .70866 .59451 .70397 .5892 Mtetra
.70397 .5892 .70866 .59451 .71875 .5916 .71408 .58627 Mtetra
.71408 .58627 .71875 .5916 .72887 .58868 .72423 .58333 Mtetra
.72423 .58333 .72887 .58868 .73903 .58575 .73442 .58038 Mtetra
.73442 .58038 .73903 .58575 .74923 .58281 .74464 .57742 Mtetra
.74464 .57742 .74923 .58281 .75946 .57986 .7549 .57445 Mtetra
.7549 .57445 .75946 .57986 .76973 .5769 .76519 .57146 Mtetra
.76519 .57146 .76973 .5769 .78004 .57392 .77553 .56847 Mtetra
.77553 .56847 .78004 .57392 .79038 .57094 .7859 .56547 Mtetra
.7859 .56547 .79038 .57094 .80076 .56795 .7963 .56246 Mtetra
.7963 .56246 .80076 .56795 .81118 .56495 .80675 .55944 Mtetra
.80675 .55944 .81118 .56495 .82164 .56194 .81723 .55641 Mtetra
.81723 .55641 .82164 .56194 .83213 .55891 .82775 .55336 Mtetra
.82775 .55336 .83213 .55891 .84266 .55588 .83831 .55031 Mtetra
.83831 .55031 .84266 .55588 .85323 .55284 .84891 .54725 Mtetra
.84891 .54725 .85323 .55284 .86384 .54978 .85954 .54417 Mtetra
.85954 .54417 .86384 .54978 .87448 .54672 .87021 .54108 Mtetra
.87021 .54108 .87448 .54672 .88517 .54364 .88093 .53799 Mtetra
.88093 .53799 .88517 .54364 .89589 .54055 .89168 .53488 Mtetra
.89168 .53488 .89589 .54055 .90666 .53746 .90247 .53176 Mtetra
.90247 .53176 .90666 .53746 .91746 .53435 .9133 .52863 Mtetra
.9133 .52863 .91746 .53435 .9283 .53123 .92418 .52549 Mtetra
.92418 .52549 .9283 .53123 .93918 .52809 .93509 .52233 Mtetra
.93509 .52233 .93918 .52809 .9501 .52495 .94604 .51917 Mtetra
.94604 .51917 .9501 .52495 .96107 .5218 .95703 .51599 Mtetra
.95703 .51599 .96107 .5218 .97207 .51863 .96806 .51281 Mtetra
.602 .703 .915 r
.37478 .67679 .38021 .68239 .38918 .68051 .38374 .67545 Mtetra
.635 .735 .92 r
.38374 .67545 .38918 .68051 .39819 .67832 .39277 .67334 Mtetra
.64 .74 .921 r
.39277 .67334 .39819 .67832 .40723 .6761 .40184 .67109 Mtetra
.637 .739 .922 r
.40184 .67109 .40723 .6761 .41631 .67407 .41093 .6689 Mtetra
.613 .726 .926 r
.41093 .6689 .41631 .67407 .42536 .67381 .42004 .66722 Mtetra
.931 .699 .567 r
.42004 .66722 .42536 .67381 .43469 .66454 .43213 .5583 Mtetra
0 0 .42 r
.43213 .5583 .43469 .66454 .44381 .66415 .4385 .6587 Mtetra
.62 .718 .917 r
.4385 .6587 .44381 .66415 .45301 .66197 .44771 .6569 Mtetra
.644 .741 .92 r
.44771 .6569 .45301 .66197 .46225 .65951 .45697 .65452 Mtetra
.651 .747 .92 r
.45697 .65452 .46225 .65951 .47153 .65692 .46626 .65196 Mtetra
.654 .75 .92 r
.46626 .65196 .47153 .65692 .48083 .65426 .47559 .64931 Mtetra
.656 .752 .92 r
.47559 .64931 .48083 .65426 .49017 .65155 .48495 .64661 Mtetra
.658 .753 .92 r
.48495 .64661 .49017 .65155 .49954 .6488 .49434 .64385 Mtetra
.659 .754 .92 r
.49434 .64385 .49954 .6488 .50895 .64603 .50376 .64107 Mtetra
.50376 .64107 .50895 .64603 .51838 .64325 .51322 .63827 Mtetra
.51322 .63827 .51838 .64325 .52785 .64046 .52271 .63546 Mtetra
.52271 .63546 .52785 .64046 .53735 .63767 .53223 .63265 Mtetra
.658 .753 .92 r
.53223 .63265 .53735 .63767 .54688 .63487 .54178 .62984 Mtetra
.54178 .62984 .54688 .63487 .55644 .63208 .55137 .62702 Mtetra
.55137 .62702 .55644 .63208 .56604 .62927 .56099 .62419 Mtetra
.56099 .62419 .56604 .62927 .57567 .62646 .57064 .62136 Mtetra
.57064 .62136 .57567 .62646 .58534 .62365 .58033 .61853 Mtetra
.58033 .61853 .58534 .62365 .59503 .62082 .59005 .61569 Mtetra
.59005 .61569 .59503 .62082 .60476 .61799 .5998 .61284 Mtetra
.657 .753 .92 r
.5998 .61284 .60476 .61799 .61453 .61515 .60959 .60998 Mtetra
.60959 .60998 .61453 .61515 .62433 .61231 .61941 .60711 Mtetra
.61941 .60711 .62433 .61231 .63416 .60945 .62927 .60424 Mtetra
.657 .752 .92 r
.62927 .60424 .63416 .60945 .64403 .60658 .63916 .60135 Mtetra
.63916 .60135 .64403 .60658 .65393 .60371 .64908 .59846 Mtetra
.64908 .59846 .65393 .60371 .66387 .60083 .65905 .59555 Mtetra
.65905 .59555 .66387 .60083 .67384 .59793 .66904 .59264 Mtetra
.66904 .59264 .67384 .59793 .68385 .59503 .67907 .58972 Mtetra
.67907 .58972 .68385 .59503 .69389 .59212 .68914 .58679 Mtetra
.68914 .58679 .69389 .59212 .70397 .5892 .69924 .58385 Mtetra
.69924 .58385 .70397 .5892 .71408 .58627 .70938 .5809 Mtetra
.70938 .5809 .71408 .58627 .72423 .58333 .71956 .57794 Mtetra
.71956 .57794 .72423 .58333 .73442 .58038 .72977 .57497 Mtetra
.72977 .57497 .73442 .58038 .74464 .57742 .74002 .57199 Mtetra
.74002 .57199 .74464 .57742 .7549 .57445 .7503 .569 Mtetra
.7503 .569 .7549 .57445 .76519 .57146 .76062 .566 Mtetra
.76062 .566 .76519 .57146 .77553 .56847 .77098 .56299 Mtetra
.77098 .56299 .77553 .56847 .7859 .56547 .78138 .55997 Mtetra
.78138 .55997 .7859 .56547 .7963 .56246 .79181 .55693 Mtetra
.79181 .55693 .7963 .56246 .80675 .55944 .80228 .55389 Mtetra
.80228 .55389 .80675 .55944 .81723 .55641 .81279 .55084 Mtetra
.81279 .55084 .81723 .55641 .82775 .55336 .82334 .54778 Mtetra
.82334 .54778 .82775 .55336 .83831 .55031 .83393 .5447 Mtetra
.83393 .5447 .83831 .55031 .84891 .54725 .84455 .54162 Mtetra
.84455 .54162 .84891 .54725 .85954 .54417 .85521 .53852 Mtetra
.85521 .53852 .85954 .54417 .87021 .54108 .86592 .53541 Mtetra
.86592 .53541 .87021 .54108 .88093 .53799 .87666 .53229 Mtetra
.87666 .53229 .88093 .53799 .89168 .53488 .88744 .52916 Mtetra
.88744 .52916 .89168 .53488 .90247 .53176 .89826 .52602 Mtetra
.89826 .52602 .90247 .53176 .9133 .52863 .90912 .52287 Mtetra
.90912 .52287 .9133 .52863 .92418 .52549 .92002 .51971 Mtetra
.92002 .51971 .92418 .52549 .93509 .52233 .93096 .51653 Mtetra
.93096 .51653 .93509 .52233 .94604 .51917 .94195 .51335 Mtetra
.94195 .51335 .94604 .51917 .95703 .51599 .95297 .51015 Mtetra
.95297 .51015 .95703 .51599 .96806 .51281 .96403 .50694 Mtetra
.489 .581 .875 r
.36943 .66889 .37478 .67679 .38374 .67545 .37829 .67022 Mtetra
.626 .727 .919 r
.37829 .67022 .38374 .67545 .39277 .67334 .38732 .6683 Mtetra
.639 .738 .921 r
.38732 .6683 .39277 .67334 .40184 .67109 .3964 .66607 Mtetra
.64 .74 .921 r
.3964 .66607 .40184 .67109 .41093 .6689 .40552 .66381 Mtetra
.631 .735 .923 r
.40552 .66381 .41093 .6689 .42004 .66722 .41466 .66174 Mtetra
.536 .688 .936 r
.41466 .66174 .42004 .66722 .43213 .5583 .42378 .66145 Mtetra
.535 .313 .524 r
.42378 .66145 .43213 .5583 .4385 .6587 .43319 .6521 Mtetra
.562 .657 .9 r
.43319 .6521 .4385 .6587 .44771 .6569 .44238 .65168 Mtetra
.637 .735 .919 r
.44238 .65168 .44771 .6569 .45697 .65452 .45165 .64946 Mtetra
.648 .745 .92 r
.45165 .64946 .45697 .65452 .46626 .65196 .46096 .64696 Mtetra
.653 .749 .92 r
.46096 .64696 .46626 .65196 .47559 .64931 .47031 .64433 Mtetra
.656 .751 .92 r
.47031 .64433 .47559 .64931 .48495 .64661 .47969 .64162 Mtetra
.657 .752 .92 r
.47969 .64162 .48495 .64661 .49434 .64385 .4891 .63887 Mtetra
.658 .753 .92 r
.4891 .63887 .49434 .64385 .50376 .64107 .49855 .63608 Mtetra
.659 .754 .92 r
.49855 .63608 .50376 .64107 .51322 .63827 .50802 .63326 Mtetra
.50802 .63326 .51322 .63827 .52271 .63546 .51753 .63043 Mtetra
.51753 .63043 .52271 .63546 .53223 .63265 .52708 .6276 Mtetra
.52708 .6276 .53223 .63265 .54178 .62984 .53665 .62477 Mtetra
.658 .753 .92 r
.53665 .62477 .54178 .62984 .55137 .62702 .54626 .62193 Mtetra
.54626 .62193 .55137 .62702 .56099 .62419 .5559 .61908 Mtetra
.5559 .61908 .56099 .62419 .57064 .62136 .56558 .61623 Mtetra
.56558 .61623 .57064 .62136 .58033 .61853 .57529 .61338 Mtetra
.57529 .61338 .58033 .61853 .59005 .61569 .58503 .61052 Mtetra
.58503 .61052 .59005 .61569 .5998 .61284 .59481 .60765 Mtetra
.657 .753 .92 r
.59481 .60765 .5998 .61284 .60959 .60998 .60462 .60477 Mtetra
.60462 .60477 .60959 .60998 .61941 .60711 .61446 .60188 Mtetra
.61446 .60188 .61941 .60711 .62927 .60424 .62434 .59899 Mtetra
.62434 .59899 .62927 .60424 .63916 .60135 .63426 .59608 Mtetra
.657 .752 .92 r
.63426 .59608 .63916 .60135 .64908 .59846 .64421 .59317 Mtetra
.64421 .59317 .64908 .59846 .65905 .59555 .65419 .59025 Mtetra
.65419 .59025 .65905 .59555 .66904 .59264 .66421 .58732 Mtetra
.66421 .58732 .66904 .59264 .67907 .58972 .67427 .58438 Mtetra
.67427 .58438 .67907 .58972 .68914 .58679 .68436 .58143 Mtetra
.68436 .58143 .68914 .58679 .69924 .58385 .69449 .57847 Mtetra
.69449 .57847 .69924 .58385 .70938 .5809 .70465 .5755 Mtetra
.70465 .5755 .70938 .5809 .71956 .57794 .71485 .57252 Mtetra
.71485 .57252 .71956 .57794 .72977 .57497 .72509 .56953 Mtetra
.72509 .56953 .72977 .57497 .74002 .57199 .73536 .56653 Mtetra
.73536 .56653 .74002 .57199 .7503 .569 .74567 .56352 Mtetra
.74567 .56352 .7503 .569 .76062 .566 .75602 .5605 Mtetra
.75602 .5605 .76062 .566 .77098 .56299 .76641 .55746 Mtetra
.76641 .55746 .77098 .56299 .78138 .55997 .77683 .55442 Mtetra
.77683 .55442 .78138 .55997 .79181 .55693 .78729 .55137 Mtetra
.78729 .55137 .79181 .55693 .80228 .55389 .79779 .54831 Mtetra
.79779 .54831 .80228 .55389 .81279 .55084 .80833 .54523 Mtetra
.80833 .54523 .81279 .55084 .82334 .54778 .8189 .54215 Mtetra
.8189 .54215 .82334 .54778 .83393 .5447 .82951 .53905 Mtetra
.82951 .53905 .83393 .5447 .84455 .54162 .84017 .53595 Mtetra
.84017 .53595 .84455 .54162 .85521 .53852 .85086 .53283 Mtetra
.85086 .53283 .85521 .53852 .86592 .53541 .86159 .5297 Mtetra
.86159 .5297 .86592 .53541 .87666 .53229 .87236 .52656 Mtetra
.87236 .52656 .87666 .53229 .88744 .52916 .88317 .52341 Mtetra
.88317 .52341 .88744 .52916 .89826 .52602 .89402 .52025 Mtetra
.89402 .52025 .89826 .52602 .90912 .52287 .90491 .51708 Mtetra
.90491 .51708 .90912 .52287 .92002 .51971 .91584 .51389 Mtetra
.91584 .51389 .92002 .51971 .93096 .51653 .92681 .51069 Mtetra
.92681 .51069 .93096 .51653 .94195 .51335 .93782 .50749 Mtetra
.93782 .50749 .94195 .51335 .95297 .51015 .94888 .50427 Mtetra
.94888 .50427 .95297 .51015 .96403 .50694 .95997 .50103 Mtetra
0 0 0 r
.36321 .67907 .36943 .66889 .37829 .67022 .37281 .66454 Mtetra
.601 .703 .915 r
.37281 .66454 .37829 .67022 .38732 .6683 .38184 .66316 Mtetra
.635 .735 .92 r
.38184 .66316 .38732 .6683 .3964 .66607 .39094 .66101 Mtetra
.64 .74 .921 r
.39094 .66101 .3964 .66607 .40552 .66381 .40007 .65872 Mtetra
.637 .739 .922 r
.40007 .65872 .40552 .66381 .41466 .66174 .40923 .65649 Mtetra
.613 .726 .926 r
.40923 .65649 .41466 .66174 .42378 .66145 .41842 .65477 Mtetra
.932 .7 .565 r
.41842 .65477 .42378 .66145 .43319 .6521 .43065 .54536 Mtetra
0 0 .416 r
.43065 .54536 .43319 .6521 .44238 .65168 .43702 .64615 Mtetra
.62 .718 .917 r
.43702 .64615 .44238 .65168 .45165 .64946 .4463 .64431 Mtetra
.644 .741 .92 r
.4463 .64431 .45165 .64946 .46096 .64696 .45563 .64189 Mtetra
.651 .747 .92 r
.45563 .64189 .46096 .64696 .47031 .64433 .465 .63929 Mtetra
.654 .75 .92 r
.465 .63929 .47031 .64433 .47969 .64162 .4744 .6366 Mtetra
.656 .752 .92 r
.4744 .6366 .47969 .64162 .4891 .63887 .48383 .63384 Mtetra
.658 .753 .92 r
.48383 .63384 .4891 .63887 .49855 .63608 .4933 .63105 Mtetra
.659 .754 .92 r
.4933 .63105 .49855 .63608 .50802 .63326 .5028 .62822 Mtetra
.5028 .62822 .50802 .63326 .51753 .63043 .51233 .62537 Mtetra
.51233 .62537 .51753 .63043 .52708 .6276 .52189 .62252 Mtetra
.52189 .62252 .52708 .6276 .53665 .62477 .53149 .61966 Mtetra
.658 .753 .92 r
.53149 .61966 .53665 .62477 .54626 .62193 .54112 .6168 Mtetra
.54112 .6168 .54626 .62193 .5559 .61908 .55078 .61394 Mtetra
.55078 .61394 .5559 .61908 .56558 .61623 .56048 .61107 Mtetra
.56048 .61107 .56558 .61623 .57529 .61338 .57021 .6082 Mtetra
.57021 .6082 .57529 .61338 .58503 .61052 .57998 .60531 Mtetra
.57998 .60531 .58503 .61052 .59481 .60765 .58978 .60242 Mtetra
.58978 .60242 .59481 .60765 .60462 .60477 .59961 .59953 Mtetra
.657 .753 .92 r
.59961 .59953 .60462 .60477 .61446 .60188 .60948 .59662 Mtetra
.60948 .59662 .61446 .60188 .62434 .59899 .61938 .59371 Mtetra
.61938 .59371 .62434 .59899 .63426 .59608 .62932 .59078 Mtetra
.657 .752 .92 r
.62932 .59078 .63426 .59608 .64421 .59317 .6393 .58785 Mtetra
.6393 .58785 .64421 .59317 .65419 .59025 .64931 .58491 Mtetra
.64931 .58491 .65419 .59025 .66421 .58732 .65935 .58196 Mtetra
.65935 .58196 .66421 .58732 .67427 .58438 .66943 .579 Mtetra
.66943 .579 .67427 .58438 .68436 .58143 .67955 .57603 Mtetra
.67955 .57603 .68436 .58143 .69449 .57847 .6897 .57305 Mtetra
.6897 .57305 .69449 .57847 .70465 .5755 .69989 .57006 Mtetra
.69989 .57006 .70465 .5755 .71485 .57252 .71012 .56706 Mtetra
.71012 .56706 .71485 .57252 .72509 .56953 .72038 .56405 Mtetra
.72038 .56405 .72509 .56953 .73536 .56653 .73068 .56103 Mtetra
.73068 .56103 .73536 .56653 .74567 .56352 .74102 .558 Mtetra
.74102 .558 .74567 .56352 .75602 .5605 .75139 .55496 Mtetra
.75139 .55496 .75602 .5605 .76641 .55746 .7618 .5519 Mtetra
.7618 .5519 .76641 .55746 .77683 .55442 .77225 .54884 Mtetra
.77225 .54884 .77683 .55442 .78729 .55137 .78274 .54577 Mtetra
.78274 .54577 .78729 .55137 .79779 .54831 .79326 .54269 Mtetra
.79326 .54269 .79779 .54831 .80833 .54523 .80383 .53959 Mtetra
.80383 .53959 .80833 .54523 .8189 .54215 .81443 .53649 Mtetra
.81443 .53649 .8189 .54215 .82951 .53905 .82507 .53337 Mtetra
.82507 .53337 .82951 .53905 .84017 .53595 .83575 .53024 Mtetra
.83575 .53024 .84017 .53595 .85086 .53283 .84647 .5271 Mtetra
.84647 .5271 .85086 .53283 .86159 .5297 .85723 .52395 Mtetra
.85723 .52395 .86159 .5297 .87236 .52656 .86803 .52079 Mtetra
.86803 .52079 .87236 .52656 .88317 .52341 .87887 .51762 Mtetra
.87887 .51762 .88317 .52341 .89402 .52025 .88975 .51444 Mtetra
.88975 .51444 .89402 .52025 .90491 .51708 .90067 .51124 Mtetra
.90067 .51124 .90491 .51708 .91584 .51389 .91163 .50803 Mtetra
.91163 .50803 .91584 .51389 .92681 .51069 .92263 .50481 Mtetra
.92263 .50481 .92681 .51069 .93782 .50749 .93367 .50158 Mtetra
.93367 .50158 .93782 .50749 .94888 .50427 .94476 .49834 Mtetra
.94476 .49834 .94888 .50427 .95997 .50103 .95588 .49509 Mtetra
.745 .622 .723 r
.358 .66659 .36321 .67907 .37281 .66454 .36741 .65655 Mtetra
.488 .581 .875 r
.36741 .65655 .37281 .66454 .38184 .66316 .37633 .65785 Mtetra
.626 .727 .919 r
.37633 .65785 .38184 .66316 .39094 .66101 .38544 .65589 Mtetra
.639 .738 .921 r
.38544 .65589 .39094 .66101 .40007 .65872 .39459 .65362 Mtetra
.64 .74 .921 r
.39459 .65362 .40007 .65872 .40923 .65649 .40377 .65131 Mtetra
.631 .735 .923 r
.40377 .65131 .40923 .65649 .41842 .65477 .41298 .6492 Mtetra
.537 .688 .936 r
.41298 .6492 .41842 .65477 .43065 .54536 .42218 .64889 Mtetra
.532 .309 .522 r
.42218 .64889 .43065 .54536 .43702 .64615 .43166 .63946 Mtetra
.562 .657 .901 r
.43166 .63946 .43702 .64615 .4463 .64431 .44092 .63901 Mtetra
.637 .735 .919 r
.44092 .63901 .4463 .64431 .45563 .64189 .45027 .63675 Mtetra
.648 .745 .92 r
.45027 .63675 .45563 .64189 .465 .63929 .45965 .6342 Mtetra
.653 .749 .92 r
.45965 .6342 .465 .63929 .4744 .6366 .46907 .63153 Mtetra
.656 .751 .92 r
.46907 .63153 .4744 .6366 .48383 .63384 .47852 .62878 Mtetra
.657 .752 .92 r
.47852 .62878 .48383 .63384 .4933 .63105 .48801 .62598 Mtetra
.658 .753 .92 r
.48801 .62598 .4933 .63105 .5028 .62822 .49753 .62314 Mtetra
.659 .754 .92 r
.49753 .62314 .5028 .62822 .51233 .62537 .50709 .62028 Mtetra
.50709 .62028 .51233 .62537 .52189 .62252 .51667 .61741 Mtetra
.51667 .61741 .52189 .62252 .53149 .61966 .52629 .61453 Mtetra
.52629 .61453 .53149 .61966 .54112 .6168 .53594 .61165 Mtetra
.658 .753 .92 r
.53594 .61165 .54112 .6168 .55078 .61394 .54563 .60876 Mtetra
.54563 .60876 .55078 .61394 .56048 .61107 .55535 .60587 Mtetra
.55535 .60587 .56048 .61107 .57021 .6082 .56511 .60298 Mtetra
.56511 .60298 .57021 .6082 .57998 .60531 .57489 .60008 Mtetra
.57489 .60008 .57998 .60531 .58978 .60242 .58472 .59717 Mtetra
.58472 .59717 .58978 .60242 .59961 .59953 .59457 .59425 Mtetra
.657 .753 .92 r
.59457 .59425 .59961 .59953 .60948 .59662 .60447 .59132 Mtetra
.60447 .59132 .60948 .59662 .61938 .59371 .61439 .58839 Mtetra
.61439 .58839 .61938 .59371 .62932 .59078 .62436 .58545 Mtetra
.62436 .58545 .62932 .59078 .6393 .58785 .63435 .5825 Mtetra
.657 .752 .92 r
.63435 .5825 .6393 .58785 .64931 .58491 .64439 .57953 Mtetra
.64439 .57953 .64931 .58491 .65935 .58196 .65446 .57656 Mtetra
.65446 .57656 .65935 .58196 .66943 .579 .66456 .57358 Mtetra
.66456 .57358 .66943 .579 .67955 .57603 .6747 .57059 Mtetra
.6747 .57059 .67955 .57603 .6897 .57305 .68488 .56759 Mtetra
.68488 .56759 .6897 .57305 .69989 .57006 .6951 .56458 Mtetra
.6951 .56458 .69989 .57006 .71012 .56706 .70535 .56156 Mtetra
.70535 .56156 .71012 .56706 .72038 .56405 .71564 .55853 Mtetra
.71564 .55853 .72038 .56405 .73068 .56103 .72596 .55549 Mtetra
.72596 .55549 .73068 .56103 .74102 .558 .73633 .55244 Mtetra
.73633 .55244 .74102 .558 .75139 .55496 .74673 .54938 Mtetra
.74673 .54938 .75139 .55496 .7618 .5519 .75716 .54631 Mtetra
.75716 .54631 .7618 .5519 .77225 .54884 .76764 .54322 Mtetra
.76764 .54322 .77225 .54884 .78274 .54577 .77815 .54013 Mtetra
.77815 .54013 .78274 .54577 .79326 .54269 .78871 .53702 Mtetra
.78871 .53702 .79326 .54269 .80383 .53959 .7993 .53391 Mtetra
.7993 .53391 .80383 .53959 .81443 .53649 .80993 .53078 Mtetra
.80993 .53078 .81443 .53649 .82507 .53337 .8206 .52765 Mtetra
.8206 .52765 .82507 .53337 .83575 .53024 .83131 .5245 Mtetra
.83131 .5245 .83575 .53024 .84647 .5271 .84206 .52134 Mtetra
.84206 .52134 .84647 .5271 .85723 .52395 .85285 .51816 Mtetra
.85285 .51816 .85723 .52395 .86803 .52079 .86367 .51498 Mtetra
.86367 .51498 .86803 .52079 .87887 .51762 .87454 .51179 Mtetra
.87454 .51179 .87887 .51762 .88975 .51444 .88545 .50858 Mtetra
.88545 .50858 .88975 .51444 .90067 .51124 .8964 .50536 Mtetra
.8964 .50536 .90067 .51124 .91163 .50803 .90739 .50214 Mtetra
.90739 .50214 .91163 .50803 .92263 .50481 .91842 .49889 Mtetra
.91842 .49889 .92263 .50481 .93367 .50158 .92949 .49564 Mtetra
.92949 .49564 .93367 .50158 .94476 .49834 .94061 .49238 Mtetra
.94061 .49238 .94476 .49834 .95588 .49509 .95177 .4891 Mtetra
0 .276 .77 r
.35245 .66052 .358 .66659 .36741 .65655 .36113 .66672 Mtetra
0 0 0 r
.36113 .66672 .36741 .65655 .37633 .65785 .37081 .65209 Mtetra
.601 .703 .915 r
.37081 .65209 .37633 .65785 .38544 .65589 .37991 .65067 Mtetra
.635 .735 .92 r
.37991 .65067 .38544 .65589 .39459 .65362 .38907 .64848 Mtetra
.64 .74 .921 r
.38907 .64848 .39459 .65362 .40377 .65131 .39828 .64615 Mtetra
.637 .739 .922 r
.39828 .64615 .40377 .65131 .41298 .6492 .40751 .64388 Mtetra
.613 .726 .926 r
.40751 .64388 .41298 .6492 .42218 .64889 .41676 .64212 Mtetra
.933 .7 .563 r
.41676 .64212 .42218 .64889 .43166 .63946 .42914 .53222 Mtetra
0 0 .412 r
.42914 .53222 .43166 .63946 .44092 .63901 .43552 .63339 Mtetra
.62 .718 .917 r
.43552 .63339 .44092 .63901 .45027 .63675 .44487 .63152 Mtetra
.644 .741 .92 r
.44487 .63152 .45027 .63675 .45965 .6342 .45427 .62905 Mtetra
.651 .747 .92 r
.45427 .62905 .45965 .6342 .46907 .63153 .46371 .62641 Mtetra
.654 .75 .92 r
.46371 .62641 .46907 .63153 .47852 .62878 .47319 .62367 Mtetra
.656 .752 .92 r
.47319 .62367 .47852 .62878 .48801 .62598 .48269 .62087 Mtetra
.658 .753 .92 r
.48269 .62087 .48801 .62598 .49753 .62314 .49224 .61803 Mtetra
.659 .754 .92 r
.49224 .61803 .49753 .62314 .50709 .62028 .50181 .61516 Mtetra
.50181 .61516 .50709 .62028 .51667 .61741 .51142 .61227 Mtetra
.51142 .61227 .51667 .61741 .52629 .61453 .52106 .60937 Mtetra
.52106 .60937 .52629 .61453 .53594 .61165 .53074 .60646 Mtetra
.658 .753 .92 r
.53074 .60646 .53594 .61165 .54563 .60876 .54045 .60356 Mtetra
.54045 .60356 .54563 .60876 .55535 .60587 .55019 .60065 Mtetra
.55019 .60065 .55535 .60587 .56511 .60298 .55997 .59773 Mtetra
.55997 .59773 .56511 .60298 .57489 .60008 .56978 .59481 Mtetra
.56978 .59481 .57489 .60008 .58472 .59717 .57962 .59188 Mtetra
.57962 .59188 .58472 .59717 .59457 .59425 .5895 .58894 Mtetra
.5895 .58894 .59457 .59425 .60447 .59132 .59942 .58599 Mtetra
.657 .753 .92 r
.59942 .58599 .60447 .59132 .61439 .58839 .60937 .58304 Mtetra
.60937 .58304 .61439 .58839 .62436 .58545 .61936 .58008 Mtetra
.61936 .58008 .62436 .58545 .63435 .5825 .62938 .57711 Mtetra
.657 .752 .92 r
.62938 .57711 .63435 .5825 .64439 .57953 .63944 .57412 Mtetra
.63944 .57412 .64439 .57953 .65446 .57656 .64953 .57113 Mtetra
.64953 .57113 .65446 .57656 .66456 .57358 .65966 .56813 Mtetra
.65966 .56813 .66456 .57358 .6747 .57059 .66983 .56512 Mtetra
.66983 .56512 .6747 .57059 .68488 .56759 .68003 .5621 Mtetra
.68003 .5621 .68488 .56759 .6951 .56458 .69027 .55907 Mtetra
.69027 .55907 .6951 .56458 .70535 .56156 .70055 .55603 Mtetra
.70055 .55603 .70535 .56156 .71564 .55853 .71086 .55298 Mtetra
.71086 .55298 .71564 .55853 .72596 .55549 .72121 .54992 Mtetra
.72121 .54992 .72596 .55549 .73633 .55244 .7316 .54685 Mtetra
.7316 .54685 .73633 .55244 .74673 .54938 .74203 .54376 Mtetra
.74203 .54376 .74673 .54938 .75716 .54631 .7525 .54067 Mtetra
.7525 .54067 .75716 .54631 .76764 .54322 .763 .53757 Mtetra
.763 .53757 .76764 .54322 .77815 .54013 .77354 .53445 Mtetra
.77354 .53445 .77815 .54013 .78871 .53702 .78412 .53133 Mtetra
.78412 .53133 .78871 .53702 .7993 .53391 .79474 .52819 Mtetra
.79474 .52819 .7993 .53391 .80993 .53078 .8054 .52504 Mtetra
.8054 .52504 .80993 .53078 .8206 .52765 .8161 .52188 Mtetra
.8161 .52188 .8206 .52765 .83131 .5245 .82683 .51871 Mtetra
.82683 .51871 .83131 .5245 .84206 .52134 .83761 .51553 Mtetra
.83761 .51553 .84206 .52134 .85285 .51816 .84843 .51234 Mtetra
.84843 .51234 .85285 .51816 .86367 .51498 .85929 .50913 Mtetra
.85929 .50913 .86367 .51498 .87454 .51179 .87018 .50592 Mtetra
.87018 .50592 .87454 .51179 .88545 .50858 .88112 .50269 Mtetra
.88112 .50269 .88545 .50858 .8964 .50536 .8921 .49945 Mtetra
.8921 .49945 .8964 .50536 .90739 .50214 .90312 .4962 Mtetra
.90312 .4962 .90739 .50214 .91842 .49889 .91418 .49293 Mtetra
.91418 .49293 .91842 .49889 .92949 .49564 .92529 .48966 Mtetra
.92529 .48966 .92949 .49564 .94061 .49238 .93643 .48637 Mtetra
.93643 .48637 .94061 .49238 .95177 .4891 .94762 .48307 Mtetra
.571 .705 .932 r
.34684 .65505 .35245 .66052 .36113 .66672 .35587 .65412 Mtetra
.745 .623 .723 r
.35587 .65412 .36113 .66672 .37081 .65209 .36536 .644 Mtetra
.488 .581 .875 r
.36536 .644 .37081 .65209 .37991 .65067 .37435 .64528 Mtetra
.626 .727 .919 r
.37435 .64528 .37991 .65067 .38907 .64848 .38352 .64328 Mtetra
.639 .738 .921 r
.38352 .64328 .38907 .64848 .39828 .64615 .39274 .64097 Mtetra
.64 .74 .921 r
.39274 .64097 .39828 .64615 .40751 .64388 .402 .63862 Mtetra
.631 .735 .923 r
.402 .63862 .40751 .64388 .41676 .64212 .41128 .63647 Mtetra
.537 .688 .936 r
.41128 .63647 .41676 .64212 .42914 .53222 .42055 .63612 Mtetra
.53 .306 .519 r
.42055 .63612 .42914 .53222 .43552 .63339 .43011 .62662 Mtetra
.561 .657 .901 r
.43011 .62662 .43552 .63339 .44487 .63152 .43944 .62614 Mtetra
.637 .735 .919 r
.43944 .62614 .44487 .63152 .45427 .62905 .44886 .62383 Mtetra
.648 .745 .92 r
.44886 .62383 .45427 .62905 .46371 .62641 .45832 .62124 Mtetra
.653 .749 .92 r
.45832 .62124 .46371 .62641 .47319 .62367 .46781 .61852 Mtetra
.656 .751 .92 r
.46781 .61852 .47319 .62367 .48269 .62087 .47734 .61573 Mtetra
.657 .752 .92 r
.47734 .61573 .48269 .62087 .49224 .61803 .4869 .61288 Mtetra
.658 .753 .92 r
.4869 .61288 .49224 .61803 .50181 .61516 .4965 .61 Mtetra
.659 .754 .92 r
.4965 .61 .50181 .61516 .51142 .61227 .50613 .60709 Mtetra
.50613 .60709 .51142 .61227 .52106 .60937 .5158 .60417 Mtetra
.5158 .60417 .52106 .60937 .53074 .60646 .52549 .60125 Mtetra
.52549 .60125 .53074 .60646 .54045 .60356 .53523 .59832 Mtetra
.658 .753 .92 r
.53523 .59832 .54045 .60356 .55019 .60065 .54499 .59538 Mtetra
.54499 .59538 .55019 .60065 .55997 .59773 .55479 .59245 Mtetra
.55479 .59245 .55997 .59773 .56978 .59481 .56463 .5895 Mtetra
.56463 .5895 .56978 .59481 .57962 .59188 .5745 .58655 Mtetra
.5745 .58655 .57962 .59188 .5895 .58894 .5844 .58359 Mtetra
.5844 .58359 .5895 .58894 .59942 .58599 .59434 .58063 Mtetra
.657 .753 .92 r
.59434 .58063 .59942 .58599 .60937 .58304 .60431 .57765 Mtetra
.60431 .57765 .60937 .58304 .61936 .58008 .61433 .57467 Mtetra
.61433 .57467 .61936 .58008 .62938 .57711 .62437 .57168 Mtetra
.62437 .57168 .62938 .57711 .63944 .57412 .63445 .56868 Mtetra
.657 .752 .92 r
.63445 .56868 .63944 .57412 .64953 .57113 .64457 .56567 Mtetra
.64457 .56567 .64953 .57113 .65966 .56813 .65473 .56265 Mtetra
.65473 .56265 .65966 .56813 .66983 .56512 .66492 .55961 Mtetra
.66492 .55961 .66983 .56512 .68003 .5621 .67515 .55657 Mtetra
.67515 .55657 .68003 .5621 .69027 .55907 .68541 .55352 Mtetra
.68541 .55352 .69027 .55907 .70055 .55603 .69572 .55046 Mtetra
.69572 .55046 .70055 .55603 .71086 .55298 .70606 .54739 Mtetra
.70606 .54739 .71086 .55298 .72121 .54992 .71643 .54431 Mtetra
.71643 .54431 .72121 .54992 .7316 .54685 .72685 .54121 Mtetra
.72685 .54121 .7316 .54685 .74203 .54376 .7373 .53811 Mtetra
.7373 .53811 .74203 .54376 .7525 .54067 .7478 .535 Mtetra
.7478 .535 .7525 .54067 .763 .53757 .75833 .53187 Mtetra
.75833 .53187 .763 .53757 .77354 .53445 .7689 .52874 Mtetra
.7689 .52874 .77354 .53445 .78412 .53133 .7795 .52559 Mtetra
.7795 .52559 .78412 .53133 .79474 .52819 .79015 .52243 Mtetra
.79015 .52243 .79474 .52819 .8054 .52504 .80084 .51926 Mtetra
.80084 .51926 .8054 .52504 .8161 .52188 .81156 .51608 Mtetra
.81156 .51608 .8161 .52188 .82683 .51871 .82233 .51289 Mtetra
.82233 .51289 .82683 .51871 .83761 .51553 .83313 .50968 Mtetra
.83313 .50968 .83761 .51553 .84843 .51234 .84398 .50647 Mtetra
.84398 .50647 .84843 .51234 .85929 .50913 .85487 .50324 Mtetra
.85487 .50324 .85929 .50913 .87018 .50592 .86579 .5 Mtetra
.86579 .5 .87018 .50592 .88112 .50269 .87676 .49675 Mtetra
.87676 .49675 .88112 .50269 .8921 .49945 .88777 .49349 Mtetra
.88777 .49349 .8921 .49945 .90312 .4962 .89882 .49022 Mtetra
.89882 .49022 .90312 .4962 .91418 .49293 .90992 .48693 Mtetra
.90992 .48693 .91418 .49293 .92529 .48966 .92105 .48363 Mtetra
.92105 .48363 .92529 .48966 .93643 .48637 .93223 .48032 Mtetra
.93223 .48032 .93643 .48637 .94762 .48307 .94344 .477 Mtetra
.614 .725 .925 r
.34119 .64973 .34684 .65505 .35587 .65412 .35027 .64797 Mtetra
0 .28 .773 r
.35027 .64797 .35587 .65412 .36536 .644 .35901 .65416 Mtetra
0 0 0 r
.35901 .65416 .36536 .644 .37435 .64528 .36878 .63943 Mtetra
.601 .703 .915 r
.36878 .63943 .37435 .64528 .38352 .64328 .37794 .63798 Mtetra
.635 .735 .92 r
.37794 .63798 .38352 .64328 .39274 .64097 .38718 .63574 Mtetra
.64 .74 .921 r
.38718 .63574 .39274 .64097 .402 .63862 .39645 .63337 Mtetra
.637 .739 .922 r
.39645 .63337 .402 .63862 .41128 .63647 .40576 .63106 Mtetra
.613 .726 .926 r
.40576 .63106 .41128 .63647 .42055 .63612 .41508 .62926 Mtetra
.934 .701 .562 r
.41508 .62926 .42055 .63612 .43011 .62662 .42761 .51887 Mtetra
0 0 .408 r
.42761 .51887 .43011 .62662 .43944 .62614 .43399 .62043 Mtetra
.62 .718 .917 r
.43399 .62043 .43944 .62614 .44886 .62383 .44341 .61852 Mtetra
.644 .741 .92 r
.44341 .61852 .44886 .62383 .45832 .62124 .45289 .616 Mtetra
.651 .747 .92 r
.45289 .616 .45832 .62124 .46781 .61852 .4624 .61332 Mtetra
.654 .75 .92 r
.4624 .61332 .46781 .61852 .47734 .61573 .47195 .61053 Mtetra
.656 .752 .92 r
.47195 .61053 .47734 .61573 .4869 .61288 .48154 .60769 Mtetra
.658 .753 .92 r
.48154 .60769 .4869 .61288 .4965 .61 .49116 .6048 Mtetra
.659 .754 .92 r
.49116 .6048 .4965 .61 .50613 .60709 .50081 .60188 Mtetra
.50081 .60188 .50613 .60709 .5158 .60417 .5105 .59894 Mtetra
.5105 .59894 .5158 .60417 .52549 .60125 .52022 .59599 Mtetra
.52022 .59599 .52549 .60125 .53523 .59832 .52997 .59304 Mtetra
.658 .753 .92 r
.52997 .59304 .53523 .59832 .54499 .59538 .53976 .59009 Mtetra
.53976 .59009 .54499 .59538 .55479 .59245 .54958 .58713 Mtetra
.54958 .58713 .55479 .59245 .56463 .5895 .55944 .58416 Mtetra
.55944 .58416 .56463 .5895 .5745 .58655 .56933 .58119 Mtetra
.56933 .58119 .5745 .58655 .5844 .58359 .57926 .57822 Mtetra
.57926 .57822 .5844 .58359 .59434 .58063 .58923 .57523 Mtetra
.58923 .57523 .59434 .58063 .60431 .57765 .59922 .57223 Mtetra
.657 .753 .92 r
.59922 .57223 .60431 .57765 .61433 .57467 .60926 .56923 Mtetra
.60926 .56923 .61433 .57467 .62437 .57168 .61933 .56622 Mtetra
.61933 .56622 .62437 .57168 .63445 .56868 .62944 .5632 Mtetra
.657 .752 .92 r
.62944 .5632 .63445 .56868 .64457 .56567 .63958 .56016 Mtetra
.63958 .56016 .64457 .56567 .65473 .56265 .64976 .55712 Mtetra
.64976 .55712 .65473 .56265 .66492 .55961 .65998 .55407 Mtetra
.65998 .55407 .66492 .55961 .67515 .55657 .67023 .55101 Mtetra
.67023 .55101 .67515 .55657 .68541 .55352 .68052 .54794 Mtetra
.68052 .54794 .68541 .55352 .69572 .55046 .69085 .54486 Mtetra
.69085 .54486 .69572 .55046 .70606 .54739 .70122 .54176 Mtetra
.70122 .54176 .70606 .54739 .71643 .54431 .71162 .53866 Mtetra
.71162 .53866 .71643 .54431 .72685 .54121 .72206 .53555 Mtetra
.72206 .53555 .72685 .54121 .7373 .53811 .73255 .53242 Mtetra
.73255 .53242 .7373 .53811 .7478 .535 .74306 .52929 Mtetra
.74306 .52929 .7478 .535 .75833 .53187 .75362 .52614 Mtetra
.75362 .52614 .75833 .53187 .7689 .52874 .76422 .52298 Mtetra
.76422 .52298 .7689 .52874 .7795 .52559 .77485 .51981 Mtetra
.77485 .51981 .7795 .52559 .79015 .52243 .78553 .51663 Mtetra
.78553 .51663 .79015 .52243 .80084 .51926 .79624 .51344 Mtetra
.79624 .51344 .80084 .51926 .81156 .51608 .807 .51024 Mtetra
.807 .51024 .81156 .51608 .82233 .51289 .81779 .50702 Mtetra
.81779 .50702 .82233 .51289 .83313 .50968 .82863 .5038 Mtetra
.82863 .5038 .83313 .50968 .84398 .50647 .8395 .50056 Mtetra
.8395 .50056 .84398 .50647 .85487 .50324 .85042 .49731 Mtetra
.85042 .49731 .85487 .50324 .86579 .5 .86138 .49405 Mtetra
.86138 .49405 .86579 .5 .87676 .49675 .87237 .49078 Mtetra
.87237 .49078 .87676 .49675 .88777 .49349 .88341 .48749 Mtetra
.88341 .48749 .88777 .49349 .89882 .49022 .89449 .48419 Mtetra
.89449 .48419 .89882 .49022 .90992 .48693 .90562 .48088 Mtetra
.90562 .48088 .90992 .48693 .92105 .48363 .91678 .47756 Mtetra
.91678 .47756 .92105 .48363 .93223 .48032 .92799 .47423 Mtetra
.92799 .47423 .93223 .48032 .94344 .477 .93924 .47088 Mtetra
.625 .731 .923 r
.3355 .64442 .34119 .64973 .35027 .64797 .34461 .64242 Mtetra
.572 .705 .932 r
.34461 .64242 .35027 .64797 .35901 .65416 .35371 .64145 Mtetra
.745 .623 .724 r
.35371 .64145 .35901 .65416 .36878 .63943 .36328 .63125 Mtetra
.487 .581 .875 r
.36328 .63125 .36878 .63943 .37794 .63798 .37233 .6325 Mtetra
.626 .727 .92 r
.37233 .6325 .37794 .63798 .38718 .63574 .38158 .63046 Mtetra
.639 .738 .921 r
.38158 .63046 .38718 .63574 .39645 .63337 .39087 .62811 Mtetra
.64 .74 .921 r
.39087 .62811 .39645 .63337 .40576 .63106 .4002 .62572 Mtetra
.631 .735 .923 r
.4002 .62572 .40576 .63106 .41508 .62926 .40955 .62352 Mtetra
.537 .688 .936 r
.40955 .62352 .41508 .62926 .42761 .51887 .41889 .62314 Mtetra
.527 .302 .516 r
.41889 .62314 .42761 .51887 .43399 .62043 .42853 .61357 Mtetra
.561 .658 .901 r
.42853 .61357 .43399 .62043 .44341 .61852 .43793 .61305 Mtetra
.637 .735 .919 r
.43793 .61305 .44341 .61852 .45289 .616 .44743 .6107 Mtetra
.648 .745 .92 r
.44743 .6107 .45289 .616 .4624 .61332 .45696 .60806 Mtetra
.653 .749 .92 r
.45696 .60806 .4624 .61332 .47195 .61053 .46653 .60529 Mtetra
.656 .751 .92 r
.46653 .60529 .47195 .61053 .48154 .60769 .47614 .60245 Mtetra
.657 .752 .92 r
.47614 .60245 .48154 .60769 .49116 .6048 .48578 .59956 Mtetra
.658 .753 .92 r
.48578 .59956 .49116 .6048 .50081 .60188 .49545 .59663 Mtetra
.659 .754 .92 r
.49545 .59663 .50081 .60188 .5105 .59894 .50516 .59368 Mtetra
.50516 .59368 .5105 .59894 .52022 .59599 .51491 .59071 Mtetra
.51491 .59071 .52022 .59599 .52997 .59304 .52468 .58774 Mtetra
.52468 .58774 .52997 .59304 .53976 .59009 .53449 .58476 Mtetra
.658 .753 .92 r
.53449 .58476 .53976 .59009 .54958 .58713 .54434 .58178 Mtetra
.54434 .58178 .54958 .58713 .55944 .58416 .55422 .57879 Mtetra
.55422 .57879 .55944 .58416 .56933 .58119 .56414 .5758 Mtetra
.56414 .5758 .56933 .58119 .57926 .57822 .57409 .5728 Mtetra
.57409 .5728 .57926 .57822 .58923 .57523 .58408 .56979 Mtetra
.58408 .56979 .58923 .57523 .59922 .57223 .5941 .56678 Mtetra
.657 .753 .92 r
.5941 .56678 .59922 .57223 .60926 .56923 .60416 .56375 Mtetra
.60416 .56375 .60926 .56923 .61933 .56622 .61426 .56072 Mtetra
.61426 .56072 .61933 .56622 .62944 .5632 .62439 .55768 Mtetra
.62439 .55768 .62944 .5632 .63958 .56016 .63456 .55462 Mtetra
.657 .752 .92 r
.63456 .55462 .63958 .56016 .64976 .55712 .64476 .55156 Mtetra
.64476 .55156 .64976 .55712 .65998 .55407 .655 .54849 Mtetra
.655 .54849 .65998 .55407 .67023 .55101 .66528 .54541 Mtetra
.66528 .54541 .67023 .55101 .68052 .54794 .6756 .54231 Mtetra
.6756 .54231 .68052 .54794 .69085 .54486 .68595 .53921 Mtetra
.68595 .53921 .69085 .54486 .70122 .54176 .69635 .5361 Mtetra
.69635 .5361 .70122 .54176 .71162 .53866 .70678 .53297 Mtetra
.70678 .53297 .71162 .53866 .72206 .53555 .71725 .52984 Mtetra
.71725 .52984 .72206 .53555 .73255 .53242 .72775 .52669 Mtetra
.72775 .52669 .73255 .53242 .74306 .52929 .7383 .52353 Mtetra
.7383 .52353 .74306 .52929 .75362 .52614 .74888 .52037 Mtetra
.74888 .52037 .75362 .52614 .76422 .52298 .75951 .51719 Mtetra
.75951 .51719 .76422 .52298 .77485 .51981 .77017 .514 Mtetra
.77017 .514 .77485 .51981 .78553 .51663 .78088 .51079 Mtetra
.78088 .51079 .78553 .51663 .79624 .51344 .79162 .50758 Mtetra
.79162 .50758 .79624 .51344 .807 .51024 .8024 .50436 Mtetra
.8024 .50436 .807 .51024 .81779 .50702 .81322 .50112 Mtetra
.81322 .50112 .81779 .50702 .82863 .5038 .82409 .49787 Mtetra
.82409 .49787 .82863 .5038 .8395 .50056 .83499 .49461 Mtetra
.83499 .49461 .8395 .50056 .85042 .49731 .84594 .49134 Mtetra
.84594 .49134 .85042 .49731 .86138 .49405 .85693 .48805 Mtetra
.85693 .48805 .86138 .49405 .87237 .49078 .86795 .48476 Mtetra
.86795 .48476 .87237 .49078 .88341 .48749 .87902 .48145 Mtetra
.87902 .48145 .88341 .48749 .89449 .48419 .89013 .47813 Mtetra
.89013 .47813 .89449 .48419 .90562 .48088 .90129 .4748 Mtetra
.90129 .4748 .90562 .48088 .91678 .47756 .91248 .47145 Mtetra
.91248 .47145 .91678 .47756 .92799 .47423 .92372 .46809 Mtetra
.92372 .46809 .92799 .47423 .93924 .47088 .93501 .46472 Mtetra
.626 .73 .922 r
.32977 .63906 .3355 .64442 .34461 .64242 .33891 .63701 Mtetra
.614 .725 .925 r
.33891 .63701 .34461 .64242 .35371 .64145 .34806 .63521 Mtetra
0 .284 .776 r
.34806 .63521 .35371 .64145 .36328 .63125 .35686 .6414 Mtetra
0 0 0 r
.35686 .6414 .36328 .63125 .37233 .6325 .36671 .62657 Mtetra
.601 .703 .915 r
.36671 .62657 .37233 .6325 .38158 .63046 .37594 .62508 Mtetra
.635 .735 .92 r
.37594 .62508 .38158 .63046 .39087 .62811 .38525 .6228 Mtetra
.64 .74 .921 r
.38525 .6228 .39087 .62811 .4002 .62572 .3946 .62039 Mtetra
.637 .739 .922 r
.3946 .62039 .4002 .62572 .40955 .62352 .40398 .61803 Mtetra
.613 .726 .926 r
.40398 .61803 .40955 .62352 .41889 .62314 .41338 .61619 Mtetra
.935 .701 .56 r
.41338 .61619 .41889 .62314 .42853 .61357 .42605 .50531 Mtetra
0 0 .404 r
.42605 .50531 .42853 .61357 .43793 .61305 .43243 .60726 Mtetra
.62 .718 .917 r
.43243 .60726 .43793 .61305 .44743 .6107 .44193 .6053 Mtetra
.644 .741 .92 r
.44193 .6053 .44743 .6107 .45696 .60806 .45148 .60274 Mtetra
.651 .747 .92 r
.45148 .60274 .45696 .60806 .46653 .60529 .46108 .60001 Mtetra
.654 .75 .92 r
.46108 .60001 .46653 .60529 .47614 .60245 .4707 .59718 Mtetra
.656 .752 .92 r
.4707 .59718 .47614 .60245 .48578 .59956 .48037 .59428 Mtetra
.658 .753 .92 r
.48037 .59428 .48578 .59956 .49545 .59663 .49006 .59135 Mtetra
.659 .754 .92 r
.49006 .59135 .49545 .59663 .50516 .59368 .49979 .58838 Mtetra
.49979 .58838 .50516 .59368 .51491 .59071 .50956 .58539 Mtetra
.50956 .58539 .51491 .59071 .52468 .58774 .51936 .5824 Mtetra
.51936 .5824 .52468 .58774 .53449 .58476 .52919 .5794 Mtetra
.658 .753 .92 r
.52919 .5794 .53449 .58476 .54434 .58178 .53906 .57639 Mtetra
.53906 .57639 .54434 .58178 .55422 .57879 .54897 .57338 Mtetra
.54897 .57338 .55422 .57879 .56414 .5758 .55891 .57037 Mtetra
.55891 .57037 .56414 .5758 .57409 .5728 .56888 .56735 Mtetra
.56888 .56735 .57409 .5728 .58408 .56979 .5789 .56432 Mtetra
.5789 .56432 .58408 .56979 .5941 .56678 .58894 .56129 Mtetra
.58894 .56129 .5941 .56678 .60416 .56375 .59903 .55824 Mtetra
.657 .753 .92 r
.59903 .55824 .60416 .56375 .61426 .56072 .60915 .55519 Mtetra
.60915 .55519 .61426 .56072 .62439 .55768 .6193 .55212 Mtetra
.6193 .55212 .62439 .55768 .63456 .55462 .6295 .54905 Mtetra
.657 .752 .92 r
.6295 .54905 .63456 .55462 .64476 .55156 .63973 .54596 Mtetra
.63973 .54596 .64476 .55156 .655 .54849 .64999 .54287 Mtetra
.64999 .54287 .655 .54849 .66528 .54541 .6603 .53977 Mtetra
.6603 .53977 .66528 .54541 .6756 .54231 .67064 .53665 Mtetra
.67064 .53665 .6756 .54231 .68595 .53921 .68102 .53353 Mtetra
.68102 .53353 .68595 .53921 .69635 .5361 .69144 .53039 Mtetra
.69144 .53039 .69635 .5361 .70678 .53297 .7019 .52725 Mtetra
.7019 .52725 .70678 .53297 .71725 .52984 .7124 .52409 Mtetra
.7124 .52409 .71725 .52984 .72775 .52669 .72293 .52092 Mtetra
.72293 .52092 .72775 .52669 .7383 .52353 .7335 .51774 Mtetra
.7335 .51774 .7383 .52353 .74888 .52037 .74412 .51455 Mtetra
.74412 .51455 .74888 .52037 .75951 .51719 .75477 .51135 Mtetra
.75477 .51135 .75951 .51719 .77017 .514 .76546 .50814 Mtetra
.76546 .50814 .77017 .514 .78088 .51079 .77619 .50492 Mtetra
.77619 .50492 .78088 .51079 .79162 .50758 .78696 .50168 Mtetra
.78696 .50168 .79162 .50758 .8024 .50436 .79777 .49843 Mtetra
.79777 .49843 .8024 .50436 .81322 .50112 .80863 .49517 Mtetra
.80863 .49517 .81322 .50112 .82409 .49787 .81952 .4919 Mtetra
.81952 .4919 .82409 .49787 .83499 .49461 .83045 .48862 Mtetra
.83045 .48862 .83499 .49461 .84594 .49134 .84143 .48532 Mtetra
.84143 .48532 .84594 .49134 .85693 .48805 .85244 .48202 Mtetra
.85244 .48202 .85693 .48805 .86795 .48476 .8635 .4787 Mtetra
.8635 .4787 .86795 .48476 .87902 .48145 .8746 .47537 Mtetra
.8746 .47537 .87902 .48145 .89013 .47813 .88574 .47202 Mtetra
.88574 .47202 .89013 .47813 .90129 .4748 .89693 .46867 Mtetra
.89693 .46867 .90129 .4748 .91248 .47145 .90816 .4653 Mtetra
.90816 .4653 .91248 .47145 .92372 .46809 .91943 .46192 Mtetra
.91943 .46192 .92372 .46809 .93501 .46472 .93074 .45852 Mtetra
.621 .725 .921 r
.32402 .63356 .32977 .63906 .33891 .63701 .33316 .63162 Mtetra
.625 .731 .923 r
.33316 .63162 .33891 .63701 .34806 .63521 .34235 .62957 Mtetra
.572 .705 .932 r
.34235 .62957 .34806 .63521 .35686 .6414 .35151 .62857 Mtetra
.745 .623 .724 r
.35151 .62857 .35686 .6414 .36671 .62657 .36116 .6183 Mtetra
.487 .581 .875 r
.36116 .6183 .36671 .62657 .37594 .62508 .37028 .61952 Mtetra
.626 .727 .92 r
.37028 .61952 .37594 .62508 .38525 .6228 .3796 .61744 Mtetra
.639 .738 .921 r
.3796 .61744 .38525 .6228 .3946 .62039 .38896 .61504 Mtetra
.64 .74 .921 r
.38896 .61504 .3946 .62039 .40398 .61803 .39837 .6126 Mtetra
.631 .735 .923 r
.39837 .6126 .40398 .61803 .41338 .61619 .4078 .61037 Mtetra
.537 .688 .936 r
.4078 .61037 .41338 .61619 .42605 .50531 .4172 .60995 Mtetra
.525 .298 .513 r
.4172 .60995 .42605 .50531 .43243 .60726 .42692 .6003 Mtetra
.561 .658 .901 r
.42692 .6003 .43243 .60726 .44193 .6053 .4364 .59974 Mtetra
.636 .735 .919 r
.4364 .59974 .44193 .6053 .45148 .60274 .44597 .59735 Mtetra
.648 .745 .92 r
.44597 .59735 .45148 .60274 .46108 .60001 .45558 .59466 Mtetra
.653 .749 .92 r
.45558 .59466 .46108 .60001 .4707 .59718 .46523 .59185 Mtetra
.656 .751 .92 r
.46523 .59185 .4707 .59718 .48037 .59428 .47492 .58896 Mtetra
.657 .752 .92 r
.47492 .58896 .48037 .59428 .49006 .59135 .48463 .58602 Mtetra
.658 .753 .92 r
.48463 .58602 .49006 .59135 .49979 .58838 .49439 .58304 Mtetra
.659 .754 .92 r
.49439 .58304 .49979 .58838 .50956 .58539 .50418 .58004 Mtetra
.50418 .58004 .50956 .58539 .51936 .5824 .514 .57702 Mtetra
.514 .57702 .51936 .5824 .52919 .5794 .52386 .574 Mtetra
.52386 .574 .52919 .5794 .53906 .57639 .53375 .57097 Mtetra
.658 .753 .92 r
.53375 .57097 .53906 .57639 .54897 .57338 .54368 .56794 Mtetra
.54368 .56794 .54897 .57338 .55891 .57037 .55364 .56491 Mtetra
.55364 .56491 .55891 .57037 .56888 .56735 .56364 .56186 Mtetra
.56364 .56186 .56888 .56735 .5789 .56432 .57368 .55881 Mtetra
.57368 .55881 .5789 .56432 .58894 .56129 .58375 .55576 Mtetra
.58375 .55576 .58894 .56129 .59903 .55824 .59386 .55269 Mtetra
.657 .753 .92 r
.59386 .55269 .59903 .55824 .60915 .55519 .604 .54961 Mtetra
.604 .54961 .60915 .55519 .6193 .55212 .61418 .54653 Mtetra
.61418 .54653 .6193 .55212 .6295 .54905 .6244 .54343 Mtetra
.6244 .54343 .6295 .54905 .63973 .54596 .63466 .54033 Mtetra
.657 .752 .92 r
.63466 .54033 .63973 .54596 .64999 .54287 .64495 .53721 Mtetra
.64495 .53721 .64999 .54287 .6603 .53977 .65528 .53409 Mtetra
.65528 .53409 .6603 .53977 .67064 .53665 .66565 .53095 Mtetra
.66565 .53095 .67064 .53665 .68102 .53353 .67606 .52781 Mtetra
.67606 .52781 .68102 .53353 .69144 .53039 .6865 .52465 Mtetra
.6865 .52465 .69144 .53039 .7019 .52725 .69699 .52148 Mtetra
.69699 .52148 .7019 .52725 .7124 .52409 .70751 .5183 Mtetra
.70751 .5183 .7124 .52409 .72293 .52092 .71807 .51511 Mtetra
.71807 .51511 .72293 .52092 .7335 .51774 .72867 .51191 Mtetra
.72867 .51191 .7335 .51774 .74412 .51455 .73931 .5087 Mtetra
.73931 .5087 .74412 .51455 .75477 .51135 .74999 .50548 Mtetra
.74999 .50548 .75477 .51135 .76546 .50814 .76071 .50224 Mtetra
.76071 .50224 .76546 .50814 .77619 .50492 .77147 .499 Mtetra
.77147 .499 .77619 .50492 .78696 .50168 .78227 .49574 Mtetra
.78227 .49574 .78696 .50168 .79777 .49843 .79311 .49247 Mtetra
.79311 .49247 .79777 .49843 .80863 .49517 .80399 .48919 Mtetra
.80399 .48919 .80863 .49517 .81952 .4919 .81492 .48589 Mtetra
.81492 .48589 .81952 .4919 .83045 .48862 .82588 .48259 Mtetra
.82588 .48259 .83045 .48862 .84143 .48532 .83688 .47927 Mtetra
.83688 .47927 .84143 .48532 .85244 .48202 .84793 .47594 Mtetra
.84793 .47594 .85244 .48202 .8635 .4787 .85902 .47259 Mtetra
.85902 .47259 .8635 .4787 .8746 .47537 .87015 .46924 Mtetra
.87015 .46924 .8746 .47537 .88574 .47202 .88132 .46587 Mtetra
.88132 .46587 .88574 .47202 .89693 .46867 .89254 .46249 Mtetra
.89254 .46249 .89693 .46867 .90816 .4653 .9038 .4591 Mtetra
.9038 .4591 .90816 .4653 .91943 .46192 .9151 .45569 Mtetra
.9151 .45569 .91943 .46192 .93074 .45852 .92645 .45228 Mtetra
.601 .706 .918 r
.31825 .62769 .32402 .63356 .33316 .63162 .32739 .62617 Mtetra
.626 .73 .922 r
.32739 .62617 .33316 .63162 .34235 .62957 .33659 .62408 Mtetra
.614 .725 .925 r
.33659 .62408 .34235 .62957 .35151 .62857 .34581 .62224 Mtetra
0 .287 .779 r
.34581 .62224 .35151 .62857 .36116 .6183 .35468 .62842 Mtetra
0 0 0 r
.35468 .62842 .36116 .6183 .37028 .61952 .36461 .6135 Mtetra
.601 .703 .916 r
.36461 .6135 .37028 .61952 .3796 .61744 .37391 .61197 Mtetra
.635 .735 .92 r
.37391 .61197 .3796 .61744 .38896 .61504 .38329 .60965 Mtetra
.64 .74 .921 r
.38329 .60965 .38896 .61504 .39837 .6126 .39272 .60719 Mtetra
.637 .739 .922 r
.39272 .60719 .39837 .6126 .4078 .61037 .40217 .60478 Mtetra
.613 .726 .926 r
.40217 .60478 .4078 .61037 .4172 .60995 .41164 .60291 Mtetra
.936 .702 .558 r
.41164 .60291 .4172 .60995 .42692 .6003 .42447 .49153 Mtetra
0 0 .4 r
.42447 .49153 .42692 .6003 .4364 .59974 .43085 .59386 Mtetra
.62 .719 .917 r
.43085 .59386 .4364 .59974 .44597 .59735 .44043 .59186 Mtetra
.644 .741 .92 r
.44043 .59186 .44597 .59735 .45558 .59466 .45006 .58926 Mtetra
.651 .747 .92 r
.45006 .58926 .45558 .59466 .46523 .59185 .45972 .58647 Mtetra
.654 .75 .92 r
.45972 .58647 .46523 .59185 .47492 .58896 .46943 .5836 Mtetra
.656 .752 .92 r
.46943 .5836 .47492 .58896 .48463 .58602 .47917 .58065 Mtetra
.658 .753 .92 r
.47917 .58065 .48463 .58602 .49439 .58304 .48895 .57767 Mtetra
.659 .754 .92 r
.48895 .57767 .49439 .58304 .50418 .58004 .49876 .57465 Mtetra
.49876 .57465 .50418 .58004 .514 .57702 .50861 .57162 Mtetra
.50861 .57162 .514 .57702 .52386 .574 .51849 .56857 Mtetra
.51849 .56857 .52386 .574 .53375 .57097 .5284 .56552 Mtetra
.658 .753 .92 r
.5284 .56552 .53375 .57097 .54368 .56794 .53835 .56247 Mtetra
.53835 .56247 .54368 .56794 .55364 .56491 .54834 .55941 Mtetra
.54834 .55941 .55364 .56491 .56364 .56186 .55837 .55634 Mtetra
.55837 .55634 .56364 .56186 .57368 .55881 .56843 .55327 Mtetra
.56843 .55327 .57368 .55881 .58375 .55576 .57852 .55019 Mtetra
.57852 .55019 .58375 .55576 .59386 .55269 .58866 .5471 Mtetra
.58866 .5471 .59386 .55269 .604 .54961 .59882 .54401 Mtetra
.657 .753 .92 r
.59882 .54401 .604 .54961 .61418 .54653 .60903 .5409 Mtetra
.60903 .5409 .61418 .54653 .6244 .54343 .61928 .53778 Mtetra
.61928 .53778 .6244 .54343 .63466 .54033 .62956 .53466 Mtetra
.657 .752 .92 r
.62956 .53466 .63466 .54033 .64495 .53721 .63988 .53152 Mtetra
.63988 .53152 .64495 .53721 .65528 .53409 .65023 .52837 Mtetra
.65023 .52837 .65528 .53409 .66565 .53095 .66063 .52522 Mtetra
.66063 .52522 .66565 .53095 .67606 .52781 .67106 .52205 Mtetra
.67106 .52205 .67606 .52781 .6865 .52465 .68153 .51887 Mtetra
.68153 .51887 .6865 .52465 .69699 .52148 .69204 .51568 Mtetra
.69204 .51568 .69699 .52148 .70751 .5183 .70259 .51248 Mtetra
.70259 .51248 .70751 .5183 .71807 .51511 .71318 .50927 Mtetra
.71318 .50927 .71807 .51511 .72867 .51191 .72381 .50604 Mtetra
.72381 .50604 .72867 .51191 .73931 .5087 .73448 .50281 Mtetra
.73448 .50281 .73931 .5087 .74999 .50548 .74519 .49956 Mtetra
.74519 .49956 .74999 .50548 .76071 .50224 .75593 .49631 Mtetra
.75593 .49631 .76071 .50224 .77147 .499 .76672 .49304 Mtetra
.76672 .49304 .77147 .499 .78227 .49574 .77755 .48975 Mtetra
.77755 .48975 .78227 .49574 .79311 .49247 .78842 .48646 Mtetra
.78842 .48646 .79311 .49247 .80399 .48919 .79933 .48316 Mtetra
.79933 .48316 .80399 .48919 .81492 .48589 .81028 .47984 Mtetra
.81028 .47984 .81492 .48589 .82588 .48259 .82127 .47651 Mtetra
.82127 .47651 .82588 .48259 .83688 .47927 .83231 .47317 Mtetra
.83231 .47317 .83688 .47927 .84793 .47594 .84339 .46982 Mtetra
.84339 .46982 .84793 .47594 .85902 .47259 .85451 .46645 Mtetra
.85451 .46645 .85902 .47259 .87015 .46924 .86567 .46307 Mtetra
.86567 .46307 .87015 .46924 .88132 .46587 .87687 .45968 Mtetra
.87687 .45968 .88132 .46587 .89254 .46249 .88812 .45627 Mtetra
.88812 .45627 .89254 .46249 .9038 .4591 .89941 .45286 Mtetra
.89941 .45286 .9038 .4591 .9151 .45569 .91074 .44943 Mtetra
.91074 .44943 .9151 .45569 .92645 .45228 .92212 .44599 Mtetra
.515 .618 .892 r
.31255 .62016 .31825 .62769 .32739 .62617 .32158 .62059 Mtetra
.621 .725 .921 r
.32158 .62059 .32739 .62617 .33659 .62408 .33079 .61861 Mtetra
.625 .731 .923 r
.33079 .61861 .33659 .62408 .34581 .62224 .34004 .61652 Mtetra
.572 .705 .932 r
.34004 .61652 .34581 .62224 .35468 .62842 .34928 .61548 Mtetra
.746 .624 .724 r
.34928 .61548 .35468 .62842 .36461 .6135 .35901 .60513 Mtetra
.486 .581 .875 r
.35901 .60513 .36461 .6135 .37391 .61197 .3682 .60632 Mtetra
.626 .727 .92 r
.3682 .60632 .37391 .61197 .38329 .60965 .37759 .60419 Mtetra
.639 .738 .921 r
.37759 .60419 .38329 .60965 .39272 .60719 .38703 .60175 Mtetra
.64 .74 .921 r
.38703 .60175 .39272 .60719 .40217 .60478 .3965 .59927 Mtetra
.631 .735 .923 r
.3965 .59927 .40217 .60478 .41164 .60291 .40601 .59699 Mtetra
.538 .688 .936 r
.40601 .59699 .41164 .60291 .42447 .49153 .41549 .59653 Mtetra
.522 .294 .511 r
.41549 .59653 .42447 .49153 .43085 .59386 .42529 .58681 Mtetra
.561 .658 .901 r
.42529 .58681 .43085 .59386 .44043 .59186 .43485 .58621 Mtetra
.636 .735 .919 r
.43485 .58621 .44043 .59186 .45006 .58926 .44449 .58377 Mtetra
.648 .745 .92 r
.44449 .58377 .45006 .58926 .45972 .58647 .45418 .58104 Mtetra
.653 .749 .92 r
.45418 .58104 .45972 .58647 .46943 .5836 .46391 .57818 Mtetra
.656 .751 .92 r
.46391 .57818 .46943 .5836 .47917 .58065 .47367 .57524 Mtetra
.657 .752 .92 r
.47367 .57524 .47917 .58065 .48895 .57767 .48347 .57225 Mtetra
.658 .753 .92 r
.48347 .57225 .48895 .57767 .49876 .57465 .4933 .56922 Mtetra
.659 .754 .92 r
.4933 .56922 .49876 .57465 .50861 .57162 .50317 .56617 Mtetra
.50317 .56617 .50861 .57162 .51849 .56857 .51308 .56311 Mtetra
.51308 .56311 .51849 .56857 .5284 .56552 .52302 .56003 Mtetra
.52302 .56003 .5284 .56552 .53835 .56247 .53299 .55695 Mtetra
.658 .753 .92 r
.53299 .55695 .53835 .56247 .54834 .55941 .54301 .55387 Mtetra
.54301 .55387 .54834 .55941 .55837 .55634 .55305 .55078 Mtetra
.55305 .55078 .55837 .55634 .56843 .55327 .56314 .54769 Mtetra
.56314 .54769 .56843 .55327 .57852 .55019 .57326 .54459 Mtetra
.57326 .54459 .57852 .55019 .58866 .5471 .58342 .54148 Mtetra
.58342 .54148 .58866 .5471 .59882 .54401 .59361 .53836 Mtetra
.657 .753 .92 r
.59361 .53836 .59882 .54401 .60903 .5409 .60384 .53523 Mtetra
.60384 .53523 .60903 .5409 .61928 .53778 .61411 .53209 Mtetra
.61411 .53209 .61928 .53778 .62956 .53466 .62442 .52894 Mtetra
.62442 .52894 .62956 .53466 .63988 .53152 .63476 .52579 Mtetra
.657 .752 .92 r
.63476 .52579 .63988 .53152 .65023 .52837 .64515 .52262 Mtetra
.64515 .52262 .65023 .52837 .66063 .52522 .65557 .51944 Mtetra
.65557 .51944 .66063 .52522 .67106 .52205 .66603 .51625 Mtetra
.66603 .51625 .67106 .52205 .68153 .51887 .67653 .51305 Mtetra
.67653 .51305 .68153 .51887 .69204 .51568 .68706 .50984 Mtetra
.68706 .50984 .69204 .51568 .70259 .51248 .69764 .50661 Mtetra
.69764 .50661 .70259 .51248 .71318 .50927 .70826 .50338 Mtetra
.70826 .50338 .71318 .50927 .72381 .50604 .71891 .50013 Mtetra
.71891 .50013 .72381 .50604 .73448 .50281 .72961 .49688 Mtetra
.72961 .49688 .73448 .50281 .74519 .49956 .74034 .49361 Mtetra
.74034 .49361 .74519 .49956 .75593 .49631 .75112 .49033 Mtetra
.75112 .49033 .75593 .49631 .76672 .49304 .76194 .48703 Mtetra
.76194 .48703 .76672 .49304 .77755 .48975 .77279 .48373 Mtetra
.77279 .48373 .77755 .48975 .78842 .48646 .78369 .48041 Mtetra
.78369 .48041 .78842 .48646 .79933 .48316 .79463 .47709 Mtetra
.79463 .47709 .79933 .48316 .81028 .47984 .80561 .47374 Mtetra
.80561 .47374 .81028 .47984 .82127 .47651 .81664 .47039 Mtetra
.81664 .47039 .82127 .47651 .83231 .47317 .8277 .46703 Mtetra
.8277 .46703 .83231 .47317 .84339 .46982 .83881 .46365 Mtetra
.83881 .46365 .84339 .46982 .85451 .46645 .84996 .46026 Mtetra
.84996 .46026 .85451 .46645 .86567 .46307 .86115 .45686 Mtetra
.86115 .45686 .86567 .46307 .87687 .45968 .87239 .45344 Mtetra
.87239 .45344 .87687 .45968 .88812 .45627 .88367 .45001 Mtetra
.88367 .45001 .88812 .45627 .89941 .45286 .89499 .44657 Mtetra
.89499 .44657 .89941 .45286 .91074 .44943 .90635 .44312 Mtetra
.90635 .44312 .91074 .44943 .92212 .44599 .91776 .43965 Mtetra
0 0 0 r
.3052 .63809 .31255 .62016 .32158 .62059 .31575 .61463 Mtetra
.601 .706 .918 r
.31575 .61463 .32158 .62059 .33079 .61861 .32496 .61308 Mtetra
.626 .73 .922 r
.32496 .61308 .33079 .61861 .34004 .61652 .33423 .61094 Mtetra
.614 .725 .925 r
.33423 .61094 .34004 .61652 .34928 .61548 .34352 .60906 Mtetra
0 .291 .782 r
.34352 .60906 .34928 .61548 .35901 .60513 .35245 .61523 Mtetra
0 0 0 r
.35245 .61523 .35901 .60513 .3682 .60632 .36247 .60021 Mtetra
.601 .703 .916 r
.36247 .60021 .3682 .60632 .37759 .60419 .37185 .59864 Mtetra
.635 .735 .92 r
.37185 .59864 .37759 .60419 .38703 .60175 .3813 .59627 Mtetra
.64 .74 .921 r
.3813 .59627 .38703 .60175 .3965 .59927 .3908 .59377 Mtetra
.637 .739 .922 r
.3908 .59377 .3965 .59927 .40601 .59699 .40033 .59132 Mtetra
.613 .726 .926 r
.40033 .59132 .40601 .59699 .41549 .59653 .40988 .5894 Mtetra
.937 .702 .556 r
.40988 .5894 .41549 .59653 .42529 .58681 .42286 .47752 Mtetra
0 0 .396 r
.42286 .47752 .42529 .58681 .43485 .58621 .42924 .58024 Mtetra
.62 .719 .917 r
.42924 .58024 .43485 .58621 .44449 .58377 .4389 .57819 Mtetra
.644 .741 .92 r
.4389 .57819 .44449 .58377 .45418 .58104 .4486 .57554 Mtetra
.651 .747 .92 r
.4486 .57554 .45418 .58104 .46391 .57818 .45835 .57271 Mtetra
.654 .75 .92 r
.45835 .57271 .46391 .57818 .47367 .57524 .46814 .56979 Mtetra
.656 .752 .92 r
.46814 .56979 .47367 .57524 .48347 .57225 .47796 .56679 Mtetra
.658 .753 .92 r
.47796 .56679 .48347 .57225 .4933 .56922 .48781 .56376 Mtetra
.659 .754 .92 r
.48781 .56376 .4933 .56922 .50317 .56617 .49771 .56069 Mtetra
.49771 .56069 .50317 .56617 .51308 .56311 .50764 .5576 Mtetra
.50764 .5576 .51308 .56311 .52302 .56003 .5176 .55451 Mtetra
.5176 .55451 .52302 .56003 .53299 .55695 .5276 .55141 Mtetra
.658 .753 .92 r
.5276 .55141 .53299 .55695 .54301 .55387 .53763 .5483 Mtetra
.53763 .5483 .54301 .55387 .55305 .55078 .54771 .54519 Mtetra
.54771 .54519 .55305 .55078 .56314 .54769 .55781 .54207 Mtetra
.55781 .54207 .56314 .54769 .57326 .54459 .56796 .53895 Mtetra
.56796 .53895 .57326 .54459 .58342 .54148 .57814 .53582 Mtetra
.57814 .53582 .58342 .54148 .59361 .53836 .58836 .53267 Mtetra
.58836 .53267 .59361 .53836 .60384 .53523 .59862 .52952 Mtetra
.657 .753 .92 r
.59862 .52952 .60384 .53523 .61411 .53209 .60891 .52636 Mtetra
.60891 .52636 .61411 .53209 .62442 .52894 .61925 .52319 Mtetra
.61925 .52319 .62442 .52894 .63476 .52579 .62962 .52001 Mtetra
.657 .752 .92 r
.62962 .52001 .63476 .52579 .64515 .52262 .64003 .51682 Mtetra
.64003 .51682 .64515 .52262 .65557 .51944 .65047 .51362 Mtetra
.65047 .51362 .65557 .51944 .66603 .51625 .66096 .51041 Mtetra
.66096 .51041 .66603 .51625 .67653 .51305 .67149 .50719 Mtetra
.67149 .50719 .67653 .51305 .68706 .50984 .68205 .50395 Mtetra
.68205 .50395 .68706 .50984 .69764 .50661 .69265 .50071 Mtetra
.69265 .50071 .69764 .50661 .70826 .50338 .7033 .49745 Mtetra
.7033 .49745 .70826 .50338 .71891 .50013 .71398 .49418 Mtetra
.71398 .49418 .71891 .50013 .72961 .49688 .72471 .4909 Mtetra
.72471 .4909 .72961 .49688 .74034 .49361 .73547 .48761 Mtetra
.73547 .48761 .74034 .49361 .75112 .49033 .74627 .48431 Mtetra
.74627 .48431 .75112 .49033 .76194 .48703 .75712 .48099 Mtetra
.75712 .48099 .76194 .48703 .77279 .48373 .76801 .47766 Mtetra
.76801 .47766 .77279 .48373 .78369 .48041 .77893 .47432 Mtetra
.77893 .47432 .78369 .48041 .79463 .47709 .7899 .47097 Mtetra
.7899 .47097 .79463 .47709 .80561 .47374 .80091 .46761 Mtetra
.80091 .46761 .80561 .47374 .81664 .47039 .81197 .46423 Mtetra
.81197 .46423 .81664 .47039 .8277 .46703 .82306 .46084 Mtetra
.82306 .46084 .8277 .46703 .83881 .46365 .8342 .45744 Mtetra
.8342 .45744 .83881 .46365 .84996 .46026 .84538 .45403 Mtetra
.84538 .45403 .84996 .46026 .86115 .45686 .85661 .4506 Mtetra
.85661 .4506 .86115 .45686 .87239 .45344 .86787 .44716 Mtetra
.86787 .44716 .87239 .45344 .88367 .45001 .87918 .44371 Mtetra
.87918 .44371 .88367 .45001 .89499 .44657 .89054 .44024 Mtetra
.89054 .44024 .89499 .44657 .90635 .44312 .90193 .43676 Mtetra
.90193 .43676 .90635 .44312 .91776 .43965 .91338 .43327 Mtetra
.69 .54 .679 r
.3003 .61664 .3052 .63809 .31575 .61463 .31 .60701 Mtetra
.515 .618 .892 r
.31 .60701 .31575 .61463 .32496 .61308 .31909 .6074 Mtetra
.621 .725 .921 r
.31909 .6074 .32496 .61308 .33423 .61094 .32838 .60538 Mtetra
.625 .731 .923 r
.32838 .60538 .33423 .61094 .34352 .60906 .3377 .60325 Mtetra
.572 .705 .932 r
.3377 .60325 .34352 .60906 .35245 .61523 .34701 .60217 Mtetra
.746 .624 .724 r
.34701 .60217 .35245 .61523 .36247 .60021 .35682 .59174 Mtetra
.486 .581 .876 r
.35682 .59174 .36247 .60021 .37185 .59864 .36608 .5929 Mtetra
.626 .727 .92 r
.36608 .5929 .37185 .59864 .3813 .59627 .37554 .59073 Mtetra
.639 .738 .921 r
.37554 .59073 .3813 .59627 .3908 .59377 .38506 .58824 Mtetra
.64 .74 .921 r
.38506 .58824 .3908 .59377 .40033 .59132 .39461 .58572 Mtetra
.631 .735 .923 r
.39461 .58572 .40033 .59132 .40988 .5894 .40419 .58339 Mtetra
.538 .687 .936 r
.40419 .58339 .40988 .5894 .42286 .47752 .41375 .58289 Mtetra
.519 .29 .508 r
.41375 .58289 .42286 .47752 .42924 .58024 .42363 .57309 Mtetra
.561 .658 .901 r
.42363 .57309 .42924 .58024 .4389 .57819 .43326 .57246 Mtetra
.636 .735 .919 r
.43326 .57246 .4389 .57819 .4486 .57554 .44299 .56997 Mtetra
.648 .745 .92 r
.44299 .56997 .4486 .57554 .45835 .57271 .45276 .56719 Mtetra
.653 .749 .92 r
.45276 .56719 .45835 .57271 .46814 .56979 .46256 .56428 Mtetra
.656 .751 .92 r
.46256 .56428 .46814 .56979 .47796 .56679 .47241 .56129 Mtetra
.657 .752 .92 r
.47241 .56129 .47796 .56679 .48781 .56376 .48229 .55825 Mtetra
.658 .753 .92 r
.48229 .55825 .48781 .56376 .49771 .56069 .4922 .55517 Mtetra
.659 .754 .92 r
.4922 .55517 .49771 .56069 .50764 .5576 .50215 .55207 Mtetra
.50215 .55207 .50764 .5576 .5176 .55451 .51214 .54895 Mtetra
.51214 .54895 .5176 .55451 .5276 .55141 .52217 .54582 Mtetra
.52217 .54582 .5276 .55141 .53763 .5483 .53223 .54269 Mtetra
.658 .753 .92 r
.53223 .54269 .53763 .5483 .54771 .54519 .54232 .53956 Mtetra
.54232 .53956 .54771 .54519 .55781 .54207 .55246 .53642 Mtetra
.55246 .53642 .55781 .54207 .56796 .53895 .56263 .53327 Mtetra
.56263 .53327 .56796 .53895 .57814 .53582 .57283 .53012 Mtetra
.57283 .53012 .57814 .53582 .58836 .53267 .58308 .52695 Mtetra
.58308 .52695 .58836 .53267 .59862 .52952 .59336 .52378 Mtetra
.657 .753 .92 r
.59336 .52378 .59862 .52952 .60891 .52636 .60368 .5206 Mtetra
.60368 .5206 .60891 .52636 .61925 .52319 .61404 .5174 Mtetra
.61404 .5174 .61925 .52319 .62962 .52001 .62444 .5142 Mtetra
.62444 .5142 .62962 .52001 .64003 .51682 .63487 .51099 Mtetra
.657 .752 .92 r
.63487 .51099 .64003 .51682 .65047 .51362 .64534 .50777 Mtetra
.64534 .50777 .65047 .51362 .66096 .51041 .65586 .50453 Mtetra
.65586 .50453 .66096 .51041 .67149 .50719 .66641 .50128 Mtetra
.66641 .50128 .67149 .50719 .68205 .50395 .677 .49803 Mtetra
.677 .49803 .68205 .50395 .69265 .50071 .68763 .49476 Mtetra
.68763 .49476 .69265 .50071 .7033 .49745 .6983 .49148 Mtetra
.6983 .49148 .7033 .49745 .71398 .49418 .70902 .48819 Mtetra
.70902 .48819 .71398 .49418 .72471 .4909 .71977 .48488 Mtetra
.71977 .48488 .72471 .4909 .73547 .48761 .73056 .48157 Mtetra
.73056 .48157 .73547 .48761 .74627 .48431 .74139 .47824 Mtetra
.74139 .47824 .74627 .48431 .75712 .48099 .75227 .4749 Mtetra
.75227 .4749 .75712 .48099 .76801 .47766 .76318 .47155 Mtetra
.76318 .47155 .76801 .47766 .77893 .47432 .77414 .46819 Mtetra
.77414 .46819 .77893 .47432 .7899 .47097 .78514 .46481 Mtetra
.78514 .46481 .7899 .47097 .80091 .46761 .79618 .46143 Mtetra
.79618 .46143 .80091 .46761 .81197 .46423 .80726 .45803 Mtetra
.80726 .45803 .81197 .46423 .82306 .46084 .81839 .45461 Mtetra
.81839 .45461 .82306 .46084 .8342 .45744 .82956 .45119 Mtetra
.82956 .45119 .8342 .45744 .84538 .45403 .84077 .44775 Mtetra
.84077 .44775 .84538 .45403 .85661 .4506 .85203 .4443 Mtetra
.85203 .4443 .85661 .4506 .86787 .44716 .86332 .44083 Mtetra
.86332 .44083 .86787 .44716 .87918 .44371 .87467 .43735 Mtetra
.87467 .43735 .87918 .44371 .89054 .44024 .88605 .43386 Mtetra
.88605 .43386 .89054 .44024 .90193 .43676 .89748 .43036 Mtetra
.89748 .43036 .90193 .43676 .91338 .43327 .90896 .42684 Mtetra
.822 .367 0 r
.29442 .60996 .3003 .61664 .31 .60701 .30256 .62496 Mtetra
0 0 0 r
.30256 .62496 .31 .60701 .31909 .6074 .31321 .60136 Mtetra
.601 .706 .918 r
.31321 .60136 .31909 .6074 .32838 .60538 .32249 .59976 Mtetra
.626 .73 .922 r
.32249 .59976 .32838 .60538 .3377 .60325 .33183 .59759 Mtetra
.614 .725 .925 r
.33183 .59759 .3377 .60325 .34701 .60217 .3412 .59566 Mtetra
0 .294 .785 r
.3412 .59566 .34701 .60217 .35682 .59174 .35019 .60183 Mtetra
0 0 0 r
.35019 .60183 .35682 .59174 .36608 .5929 .3603 .5867 Mtetra
.601 .703 .916 r
.3603 .5867 .36608 .5929 .37554 .59073 .36975 .58509 Mtetra
.635 .735 .921 r
.36975 .58509 .37554 .59073 .38506 .58824 .37928 .58267 Mtetra
.64 .74 .921 r
.37928 .58267 .38506 .58824 .39461 .58572 .38885 .58012 Mtetra
.637 .739 .922 r
.38885 .58012 .39461 .58572 .40419 .58339 .39846 .57763 Mtetra
.613 .726 .926 r
.39846 .57763 .40419 .58339 .41375 .58289 .40808 .57566 Mtetra
.939 .703 .555 r
.40808 .57566 .41375 .58289 .42363 .57309 .42123 .46329 Mtetra
0 0 .392 r
.42123 .46329 .42363 .57309 .43326 .57246 .42761 .56639 Mtetra
.619 .719 .917 r
.42761 .56639 .43326 .57246 .44299 .56997 .43734 .5643 Mtetra
.644 .741 .92 r
.43734 .5643 .44299 .56997 .45276 .56719 .44713 .5616 Mtetra
.651 .747 .92 r
.44713 .5616 .45276 .56719 .46256 .56428 .45695 .55872 Mtetra
.654 .75 .92 r
.45695 .55872 .46256 .56428 .47241 .56129 .46682 .55574 Mtetra
.656 .752 .92 r
.46682 .55574 .47241 .56129 .48229 .55825 .47672 .5527 Mtetra
.658 .753 .92 r
.47672 .5527 .48229 .55825 .4922 .55517 .48666 .54961 Mtetra
.659 .754 .92 r
.48666 .54961 .4922 .55517 .50215 .55207 .49664 .54649 Mtetra
.49664 .54649 .50215 .55207 .51214 .54895 .50665 .54335 Mtetra
.50665 .54335 .51214 .54895 .52217 .54582 .5167 .5402 Mtetra
.5167 .5402 .52217 .54582 .53223 .54269 .52678 .53705 Mtetra
.658 .753 .92 r
.52678 .53705 .53223 .54269 .54232 .53956 .5369 .53389 Mtetra
.5369 .53389 .54232 .53956 .55246 .53642 .54706 .53073 Mtetra
.54706 .53073 .55246 .53642 .56263 .53327 .55725 .52756 Mtetra
.55725 .52756 .56263 .53327 .57283 .53012 .56749 .52438 Mtetra
.56749 .52438 .57283 .53012 .58308 .52695 .57776 .52119 Mtetra
.57776 .52119 .58308 .52695 .59336 .52378 .58806 .518 Mtetra
.58806 .518 .59336 .52378 .60368 .5206 .59841 .51479 Mtetra
.657 .753 .92 r
.59841 .51479 .60368 .5206 .61404 .5174 .60879 .51158 Mtetra
.60879 .51158 .61404 .5174 .62444 .5142 .61922 .50835 Mtetra
.61922 .50835 .62444 .5142 .63487 .51099 .62968 .50511 Mtetra
.657 .752 .92 r
.62968 .50511 .63487 .51099 .64534 .50777 .64018 .50187 Mtetra
.64018 .50187 .64534 .50777 .65586 .50453 .65072 .49861 Mtetra
.65072 .49861 .65586 .50453 .66641 .50128 .6613 .49534 Mtetra
.6613 .49534 .66641 .50128 .677 .49803 .67192 .49206 Mtetra
.67192 .49206 .677 .49803 .68763 .49476 .68258 .48877 Mtetra
.68258 .48877 .68763 .49476 .6983 .49148 .69328 .48547 Mtetra
.69328 .48547 .6983 .49148 .70902 .48819 .70402 .48215 Mtetra
.70402 .48215 .70902 .48819 .71977 .48488 .7148 .47883 Mtetra
.7148 .47883 .71977 .48488 .73056 .48157 .72562 .47549 Mtetra
.72562 .47549 .73056 .48157 .74139 .47824 .73648 .47214 Mtetra
.73648 .47214 .74139 .47824 .75227 .4749 .74738 .46878 Mtetra
.74738 .46878 .75227 .4749 .76318 .47155 .75833 .4654 Mtetra
.75833 .4654 .76318 .47155 .77414 .46819 .76931 .46201 Mtetra
.76931 .46201 .77414 .46819 .78514 .46481 .78034 .45861 Mtetra
.78034 .45861 .78514 .46481 .79618 .46143 .79141 .4552 Mtetra
.79141 .4552 .79618 .46143 .80726 .45803 .80253 .45178 Mtetra
.80253 .45178 .80726 .45803 .81839 .45461 .81368 .44834 Mtetra
.81368 .44834 .81839 .45461 .82956 .45119 .82488 .44489 Mtetra
.82488 .44489 .82956 .45119 .84077 .44775 .83613 .44143 Mtetra
.83613 .44143 .84077 .44775 .85203 .4443 .84741 .43795 Mtetra
.84741 .43795 .85203 .4443 .86332 .44083 .85874 .43446 Mtetra
.85874 .43446 .86332 .44083 .87467 .43735 .87012 .43096 Mtetra
.87012 .43096 .87467 .43735 .88605 .43386 .88154 .42744 Mtetra
.88154 .42744 .88605 .43386 .89748 .43036 .893 .42391 Mtetra
.893 .42391 .89748 .43036 .90896 .42684 .90451 .42037 Mtetra
.549 .693 .935 r
.28846 .60404 .29442 .60996 .30256 .62496 .29762 .60335 Mtetra
.689 .54 .678 r
.29762 .60335 .30256 .62496 .31321 .60136 .3074 .59364 Mtetra
.515 .618 .893 r
.3074 .59364 .31321 .60136 .32249 .59976 .31657 .594 Mtetra
.621 .725 .921 r
.31657 .594 .32249 .59976 .33183 .59759 .32592 .59194 Mtetra
.625 .731 .923 r
.32592 .59194 .33183 .59759 .3412 .59566 .33532 .58976 Mtetra
.572 .704 .932 r
.33532 .58976 .3412 .59566 .35019 .60183 .3447 .58864 Mtetra
.746 .624 .724 r
.3447 .58864 .35019 .60183 .3603 .5867 .35459 .57812 Mtetra
.485 .581 .876 r
.35459 .57812 .3603 .5867 .36975 .58509 .36393 .57926 Mtetra
.626 .727 .92 r
.36393 .57926 .36975 .58509 .37928 .58267 .37347 .57704 Mtetra
.639 .738 .921 r
.37347 .57704 .37928 .58267 .38885 .58012 .38306 .57451 Mtetra
.64 .74 .921 r
.38306 .57451 .38885 .58012 .39846 .57763 .39269 .57193 Mtetra
.631 .735 .923 r
.39269 .57193 .39846 .57763 .40808 .57566 .40234 .56956 Mtetra
.538 .687 .935 r
.40234 .56956 .40808 .57566 .42123 .46329 .41198 .56902 Mtetra
.516 .286 .505 r
.41198 .56902 .42123 .46329 .42761 .56639 .42195 .55914 Mtetra
.561 .658 .901 r
.42195 .55914 .42761 .56639 .43734 .5643 .43165 .55847 Mtetra
.636 .735 .919 r
.43165 .55847 .43734 .5643 .44713 .5616 .44146 .55593 Mtetra
.648 .745 .92 r
.44146 .55593 .44713 .5616 .45695 .55872 .45131 .5531 Mtetra
.653 .749 .92 r
.45131 .5531 .45695 .55872 .46682 .55574 .4612 .55014 Mtetra
.656 .751 .92 r
.4612 .55014 .46682 .55574 .47672 .5527 .47112 .5471 Mtetra
.657 .752 .92 r
.47112 .5471 .47672 .5527 .48666 .54961 .48108 .54401 Mtetra
.658 .753 .92 r
.48108 .54401 .48666 .54961 .49664 .54649 .49108 .54087 Mtetra
.659 .754 .92 r
.49108 .54087 .49664 .54649 .50665 .54335 .50112 .53772 Mtetra
.50112 .53772 .50665 .54335 .5167 .5402 .51119 .53455 Mtetra
.51119 .53455 .5167 .5402 .52678 .53705 .5213 .53137 Mtetra
.5213 .53137 .52678 .53705 .5369 .53389 .53144 .52818 Mtetra
.658 .753 .92 r
.53144 .52818 .5369 .53389 .54706 .53073 .54163 .525 Mtetra
.54163 .525 .54706 .53073 .55725 .52756 .55185 .5218 Mtetra
.55185 .5218 .55725 .52756 .56749 .52438 .5621 .5186 Mtetra
.5621 .5186 .56749 .52438 .57776 .52119 .5724 .51539 Mtetra
.5724 .51539 .57776 .52119 .58806 .518 .58273 .51217 Mtetra
.58273 .51217 .58806 .518 .59841 .51479 .5931 .50894 Mtetra
.657 .753 .92 r
.5931 .50894 .59841 .51479 .60879 .51158 .60351 .50571 Mtetra
.60351 .50571 .60879 .51158 .61922 .50835 .61396 .50246 Mtetra
.61396 .50246 .61922 .50835 .62968 .50511 .62445 .4992 Mtetra
.62445 .4992 .62968 .50511 .64018 .50187 .63498 .49593 Mtetra
.657 .752 .92 r
.63498 .49593 .64018 .50187 .65072 .49861 .64555 .49265 Mtetra
.64555 .49265 .65072 .49861 .6613 .49534 .65615 .48936 Mtetra
.65615 .48936 .6613 .49534 .67192 .49206 .6668 .48605 Mtetra
.6668 .48605 .67192 .49206 .68258 .48877 .67749 .48274 Mtetra
.67749 .48274 .68258 .48877 .69328 .48547 .68821 .47941 Mtetra
.68821 .47941 .69328 .48547 .70402 .48215 .69898 .47608 Mtetra
.69898 .47608 .70402 .48215 .7148 .47883 .70979 .47273 Mtetra
.70979 .47273 .7148 .47883 .72562 .47549 .72064 .46936 Mtetra
.72064 .46936 .72562 .47549 .73648 .47214 .73153 .46599 Mtetra
.73153 .46599 .73648 .47214 .74738 .46878 .74246 .4626 Mtetra
.74246 .4626 .74738 .46878 .75833 .4654 .75344 .4592 Mtetra
.75344 .4592 .75833 .4654 .76931 .46201 .76445 .45579 Mtetra
.76445 .45579 .76931 .46201 .78034 .45861 .77551 .45237 Mtetra
.77551 .45237 .78034 .45861 .79141 .4552 .78661 .44893 Mtetra
.78661 .44893 .79141 .4552 .80253 .45178 .79776 .44548 Mtetra
.79776 .44548 .80253 .45178 .81368 .44834 .80894 .44202 Mtetra
.80894 .44202 .81368 .44834 .82488 .44489 .82017 .43855 Mtetra
.82017 .43855 .82488 .44489 .83613 .44143 .83145 .43506 Mtetra
.83145 .43506 .83613 .44143 .84741 .43795 .84277 .43156 Mtetra
.84277 .43156 .84741 .43795 .85874 .43446 .85413 .42804 Mtetra
.85413 .42804 .85874 .43446 .87012 .43096 .86553 .42451 Mtetra
.86553 .42451 .87012 .43096 .88154 .42744 .87699 .42097 Mtetra
.87699 .42097 .88154 .42744 .893 .42391 .88848 .41742 Mtetra
.88848 .41742 .893 .42391 .90451 .42037 .90002 .41385 Mtetra
.604 .719 .926 r
.28244 .59829 .28846 .60404 .29762 .60335 .29169 .59657 Mtetra
.818 .362 0 r
.29169 .59657 .29762 .60335 .3074 .59364 .29988 .6116 Mtetra
0 0 0 r
.29988 .6116 .3074 .59364 .31657 .594 .31063 .58786 Mtetra
.601 .706 .918 r
.31063 .58786 .31657 .594 .32592 .59194 .31998 .58623 Mtetra
.626 .73 .922 r
.31998 .58623 .32592 .59194 .33532 .58976 .32939 .584 Mtetra
.614 .725 .925 r
.32939 .584 .33532 .58976 .3447 .58864 .33884 .58203 Mtetra
0 .298 .788 r
.33884 .58203 .3447 .58864 .35459 .57812 .34789 .58819 Mtetra
0 0 0 r
.34789 .58819 .35459 .57812 .36393 .57926 .35809 .57296 Mtetra
.601 .704 .916 r
.35809 .57296 .36393 .57926 .37347 .57704 .36762 .57131 Mtetra
.635 .735 .921 r
.36762 .57131 .37347 .57704 .38306 .57451 .37722 .56885 Mtetra
.64 .74 .921 r
.37722 .56885 .38306 .57451 .39269 .57193 .38687 .56625 Mtetra
.637 .739 .922 r
.38687 .56625 .39269 .57193 .40234 .56956 .39656 .5637 Mtetra
.613 .726 .926 r
.39656 .5637 .40234 .56956 .41198 .56902 .40626 .56169 Mtetra
.94 .703 .553 r
.40626 .56169 .41198 .56902 .42195 .55914 .41957 .44882 Mtetra
0 0 .388 r
.41957 .44882 .42195 .55914 .43165 .55847 .42594 .5523 Mtetra
.619 .719 .917 r
.42594 .5523 .43165 .55847 .44146 .55593 .43575 .55016 Mtetra
.644 .741 .92 r
.43575 .55016 .44146 .55593 .45131 .5531 .44562 .54741 Mtetra
.651 .747 .92 r
.44562 .54741 .45131 .5531 .4612 .55014 .45553 .54448 Mtetra
.654 .75 .92 r
.45553 .54448 .4612 .55014 .47112 .5471 .46548 .54145 Mtetra
.656 .752 .92 r
.46548 .54145 .47112 .5471 .48108 .54401 .47547 .53836 Mtetra
.658 .753 .92 r
.47547 .53836 .48108 .54401 .49108 .54087 .48549 .53522 Mtetra
.659 .754 .92 r
.48549 .53522 .49108 .54087 .50112 .53772 .49555 .53204 Mtetra
.49555 .53204 .50112 .53772 .51119 .53455 .50564 .52885 Mtetra
.50564 .52885 .51119 .53455 .5213 .53137 .51578 .52565 Mtetra
.51578 .52565 .5213 .53137 .53144 .52818 .52595 .52244 Mtetra
.658 .753 .92 r
.52595 .52244 .53144 .52818 .54163 .525 .53616 .51923 Mtetra
.53616 .51923 .54163 .525 .55185 .5218 .5464 .51601 Mtetra
.5464 .51601 .55185 .5218 .5621 .5186 .55668 .51278 Mtetra
.55668 .51278 .5621 .5186 .5724 .51539 .567 .50955 Mtetra
.567 .50955 .5724 .51539 .58273 .51217 .57736 .50631 Mtetra
.57736 .50631 .58273 .51217 .5931 .50894 .58776 .50306 Mtetra
.58776 .50306 .5931 .50894 .60351 .50571 .5982 .4998 Mtetra
.657 .753 .92 r
.5982 .4998 .60351 .50571 .61396 .50246 .60867 .49653 Mtetra
.60867 .49653 .61396 .50246 .62445 .4992 .61919 .49324 Mtetra
.61919 .49324 .62445 .4992 .63498 .49593 .62974 .48995 Mtetra
.657 .752 .92 r
.62974 .48995 .63498 .49593 .64555 .49265 .64034 .48665 Mtetra
.64034 .48665 .64555 .49265 .65615 .48936 .65097 .48333 Mtetra
.65097 .48333 .65615 .48936 .6668 .48605 .66164 .48001 Mtetra
.66164 .48001 .6668 .48605 .67749 .48274 .67236 .47667 Mtetra
.67236 .47667 .67749 .48274 .68821 .47941 .68311 .47332 Mtetra
.68311 .47332 .68821 .47941 .69898 .47608 .69391 .46996 Mtetra
.69391 .46996 .69898 .47608 .70979 .47273 .70475 .46658 Mtetra
.70475 .46658 .70979 .47273 .72064 .46936 .71563 .4632 Mtetra
.71563 .4632 .72064 .46936 .73153 .46599 .72655 .4598 Mtetra
.72655 .4598 .73153 .46599 .74246 .4626 .73751 .45639 Mtetra
.73751 .45639 .74246 .4626 .75344 .4592 .74851 .45296 Mtetra
.74851 .45296 .75344 .4592 .76445 .45579 .75956 .44953 Mtetra
.75956 .44953 .76445 .45579 .77551 .45237 .77065 .44608 Mtetra
.77065 .44608 .77551 .45237 .78661 .44893 .78178 .44262 Mtetra
.78178 .44262 .78661 .44893 .79776 .44548 .79295 .43914 Mtetra
.79295 .43914 .79776 .44548 .80894 .44202 .80417 .43566 Mtetra
.80417 .43566 .80894 .44202 .82017 .43855 .81543 .43216 Mtetra
.81543 .43216 .82017 .43855 .83145 .43506 .82674 .42864 Mtetra
.82674 .42864 .83145 .43506 .84277 .43156 .83809 .42512 Mtetra
.83809 .42512 .84277 .43156 .85413 .42804 .84948 .42158 Mtetra
.84948 .42158 .85413 .42804 .86553 .42451 .86092 .41802 Mtetra
.86092 .41802 .86553 .42451 .87699 .42097 .8724 .41446 Mtetra
.8724 .41446 .87699 .42097 .88848 .41742 .88393 .41088 Mtetra
.88393 .41088 .88848 .41742 .90002 .41385 .89551 .40728 Mtetra
.614 .723 .923 r
.27639 .59252 .28244 .59829 .29169 .59657 .28567 .59057 Mtetra
.549 .693 .934 r
.28567 .59057 .29169 .59657 .29988 .6116 .2949 .58984 Mtetra
.689 .54 .678 r
.2949 .58984 .29988 .6116 .31063 .58786 .30477 .58005 Mtetra
.514 .618 .893 r
.30477 .58005 .31063 .58786 .31998 .58623 .314 .58037 Mtetra
.621 .725 .921 r
.314 .58037 .31998 .58623 .32939 .584 .32343 .57826 Mtetra
.625 .731 .923 r
.32343 .57826 .32939 .584 .33884 .58203 .3329 .57604 Mtetra
.572 .704 .932 r
.3329 .57604 .33884 .58203 .34789 .58819 .34235 .57488 Mtetra
.746 .625 .724 r
.34235 .57488 .34789 .58819 .35809 .57296 .35233 .56428 Mtetra
.485 .581 .876 r
.35233 .56428 .35809 .57296 .36762 .57131 .36174 .56538 Mtetra
.626 .727 .92 r
.36174 .56538 .36762 .57131 .37722 .56885 .37135 .56312 Mtetra
.639 .738 .921 r
.37135 .56312 .37722 .56885 .38687 .56625 .38102 .56054 Mtetra
.64 .74 .921 r
.38102 .56054 .38687 .56625 .39656 .5637 .39073 .55791 Mtetra
.631 .735 .923 r
.39073 .55791 .39656 .5637 .40626 .56169 .40046 .55549 Mtetra
.538 .687 .935 r
.40046 .55549 .40626 .56169 .41957 .44882 .41018 .55492 Mtetra
.513 .282 .501 r
.41018 .55492 .41957 .44882 .42594 .5523 .42023 .54495 Mtetra
.56 .658 .901 r
.42023 .54495 .42594 .5523 .43575 .55016 .43002 .54424 Mtetra
.636 .735 .919 r
.43002 .54424 .43575 .55016 .44562 .54741 .4399 .54165 Mtetra
.648 .745 .92 r
.4399 .54165 .44562 .54741 .45553 .54448 .44983 .53877 Mtetra
.653 .749 .92 r
.44983 .53877 .45553 .54448 .46548 .54145 .4598 .53575 Mtetra
.656 .751 .92 r
.4598 .53575 .46548 .54145 .47547 .53836 .46981 .53266 Mtetra
.657 .752 .92 r
.46981 .53266 .47547 .53836 .48549 .53522 .47986 .52952 Mtetra
.658 .753 .92 r
.47986 .52952 .48549 .53522 .49555 .53204 .48994 .52633 Mtetra
.659 .754 .92 r
.48994 .52633 .49555 .53204 .50564 .52885 .50006 .52312 Mtetra
.50006 .52312 .50564 .52885 .51578 .52565 .51022 .51989 Mtetra
.51022 .51989 .51578 .52565 .52595 .52244 .52041 .51666 Mtetra
.52041 .51666 .52595 .52244 .53616 .51923 .53065 .51342 Mtetra
.658 .753 .92 r
.53065 .51342 .53616 .51923 .5464 .51601 .54092 .51018 Mtetra
.54092 .51018 .5464 .51601 .55668 .51278 .55123 .50693 Mtetra
.55123 .50693 .55668 .51278 .567 .50955 .56157 .50367 Mtetra
.56157 .50367 .567 .50955 .57736 .50631 .57196 .50041 Mtetra
.57196 .50041 .57736 .50631 .58776 .50306 .58238 .49713 Mtetra
.58238 .49713 .58776 .50306 .5982 .4998 .59284 .49385 Mtetra
.657 .753 .92 r
.59284 .49385 .5982 .4998 .60867 .49653 .60335 .49055 Mtetra
.60335 .49055 .60867 .49653 .61919 .49324 .61389 .48725 Mtetra
.61389 .48725 .61919 .49324 .62974 .48995 .62447 .48393 Mtetra
.62447 .48393 .62974 .48995 .64034 .48665 .63509 .4806 Mtetra
.657 .752 .92 r
.63509 .4806 .64034 .48665 .65097 .48333 .64575 .47727 Mtetra
.64575 .47727 .65097 .48333 .66164 .48001 .65645 .47391 Mtetra
.65645 .47391 .66164 .48001 .67236 .47667 .6672 .47055 Mtetra
.6672 .47055 .67236 .47667 .68311 .47332 .67798 .46718 Mtetra
.67798 .46718 .68311 .47332 .69391 .46996 .6888 .46379 Mtetra
.6888 .46379 .69391 .46996 .70475 .46658 .69967 .4604 Mtetra
.69967 .4604 .70475 .46658 .71563 .4632 .71058 .45698 Mtetra
.71058 .45698 .71563 .4632 .72655 .4598 .72153 .45356 Mtetra
.72153 .45356 .72655 .4598 .73751 .45639 .73252 .45013 Mtetra
.73252 .45013 .73751 .45639 .74851 .45296 .74355 .44668 Mtetra
.74355 .44668 .74851 .45296 .75956 .44953 .75463 .44322 Mtetra
.75463 .44322 .75956 .44953 .77065 .44608 .76575 .43975 Mtetra
.76575 .43975 .77065 .44608 .78178 .44262 .77691 .43626 Mtetra
.77691 .43626 .78178 .44262 .79295 .43914 .78811 .43276 Mtetra
.78811 .43276 .79295 .43914 .80417 .43566 .79936 .42925 Mtetra
.79936 .42925 .80417 .43566 .81543 .43216 .81066 .42572 Mtetra
.81066 .42572 .81543 .43216 .82674 .42864 .82199 .42218 Mtetra
.82199 .42218 .82674 .42864 .83809 .42512 .83337 .41863 Mtetra
.83337 .41863 .83809 .42512 .84948 .42158 .8448 .41507 Mtetra
.8448 .41507 .84948 .42158 .86092 .41802 .85627 .41149 Mtetra
.85627 .41149 .86092 .41802 .8724 .41446 .86779 .40789 Mtetra
.86779 .40789 .8724 .41446 .88393 .41088 .87935 .40429 Mtetra
.87935 .40429 .88393 .41088 .89551 .40728 .89096 .40066 Mtetra
.61 .717 .921 r
.27031 .58659 .27639 .59252 .28567 .59057 .27959 .58472 Mtetra
.604 .719 .926 r
.27959 .58472 .28567 .59057 .2949 .58984 .28891 .58296 Mtetra
.814 .357 0 r
.28891 .58296 .2949 .58984 .30477 .58005 .29715 .59802 Mtetra
0 0 0 r
.29715 .59802 .30477 .58005 .314 .58037 .30801 .57414 Mtetra
.601 .706 .918 r
.30801 .57414 .314 .58037 .32343 .57826 .31742 .57246 Mtetra
.626 .73 .922 r
.31742 .57246 .32343 .57826 .3329 .57604 .32692 .57019 Mtetra
.614 .725 .925 r
.32692 .57019 .3329 .57604 .34235 .57488 .33643 .56818 Mtetra
0 .301 .79 r
.33643 .56818 .34235 .57488 .35233 .56428 .34556 .57432 Mtetra
.592 .805 .399 r
.34556 .57432 .35233 .56428 .36174 .56538 .35584 .55899 Mtetra
.601 .704 .916 r
.35584 .55899 .36174 .56538 .37135 .56312 .36545 .55729 Mtetra
.635 .735 .921 r
.36545 .55729 .37135 .56312 .38102 .56054 .37513 .55478 Mtetra
.64 .74 .921 r
.37513 .55478 .38102 .56054 .39073 .55791 .38486 .55213 Mtetra
.637 .739 .922 r
.38486 .55213 .39073 .55791 .40046 .55549 .39462 .54954 Mtetra
.613 .726 .926 r
.39462 .54954 .40046 .55549 .41018 .55492 .4044 .54748 Mtetra
.941 .703 .551 r
.4044 .54748 .41018 .55492 .42023 .54495 .41788 .43411 Mtetra
0 0 .384 r
.41788 .43411 .42023 .54495 .43002 .54424 .42425 .53797 Mtetra
.619 .719 .917 r
.42425 .53797 .43002 .54424 .4399 .54165 .43414 .53579 Mtetra
.644 .741 .92 r
.43414 .53579 .4399 .54165 .44983 .53877 .44409 .53298 Mtetra
.651 .747 .92 r
.44409 .53298 .44983 .53877 .4598 .53575 .45409 .53 Mtetra
.654 .75 .92 r
.45409 .53 .4598 .53575 .46981 .53266 .46412 .52692 Mtetra
.656 .752 .92 r
.46412 .52692 .46981 .53266 .47986 .52952 .47419 .52377 Mtetra
.658 .753 .92 r
.47419 .52377 .47986 .52952 .48994 .52633 .4843 .52057 Mtetra
.659 .754 .92 r
.4843 .52057 .48994 .52633 .50006 .52312 .49444 .51735 Mtetra
.49444 .51735 .50006 .52312 .51022 .51989 .50462 .5141 Mtetra
.50462 .5141 .51022 .51989 .52041 .51666 .51484 .51084 Mtetra
.51484 .51084 .52041 .51666 .53065 .51342 .5251 .50758 Mtetra
.658 .753 .92 r
.5251 .50758 .53065 .51342 .54092 .51018 .5354 .50431 Mtetra
.5354 .50431 .54092 .51018 .55123 .50693 .54573 .50104 Mtetra
.54573 .50104 .55123 .50693 .56157 .50367 .5561 .49775 Mtetra
.5561 .49775 .56157 .50367 .57196 .50041 .56651 .49446 Mtetra
.56651 .49446 .57196 .50041 .58238 .49713 .57696 .49117 Mtetra
.57696 .49117 .58238 .49713 .59284 .49385 .58745 .48786 Mtetra
.58745 .48786 .59284 .49385 .60335 .49055 .59798 .48454 Mtetra
.657 .753 .92 r
.59798 .48454 .60335 .49055 .61389 .48725 .60855 .48121 Mtetra
.60855 .48121 .61389 .48725 .62447 .48393 .61916 .47787 Mtetra
.61916 .47787 .62447 .48393 .63509 .4806 .62981 .47452 Mtetra
.657 .752 .92 r
.62981 .47452 .63509 .4806 .64575 .47727 .6405 .47116 Mtetra
.6405 .47116 .64575 .47727 .65645 .47391 .65122 .46778 Mtetra
.65122 .46778 .65645 .47391 .6672 .47055 .662 .46439 Mtetra
.662 .46439 .6672 .47055 .67798 .46718 .67281 .461 Mtetra
.67281 .461 .67798 .46718 .6888 .46379 .68366 .45759 Mtetra
.68366 .45759 .6888 .46379 .69967 .4604 .69455 .45416 Mtetra
.69455 .45416 .69967 .4604 .71058 .45698 .70549 .45073 Mtetra
.70549 .45073 .71058 .45698 .72153 .45356 .71647 .44728 Mtetra
.71647 .44728 .72153 .45356 .73252 .45013 .72749 .44382 Mtetra
.72749 .44382 .73252 .45013 .74355 .44668 .73855 .44035 Mtetra
.73855 .44035 .74355 .44668 .75463 .44322 .74966 .43686 Mtetra
.74966 .43686 .75463 .44322 .76575 .43975 .76081 .43337 Mtetra
.76081 .43337 .76575 .43975 .77691 .43626 .772 .42985 Mtetra
.772 .42985 .77691 .43626 .78811 .43276 .78324 .42633 Mtetra
.78324 .42633 .78811 .43276 .79936 .42925 .79452 .42279 Mtetra
.79452 .42279 .79936 .42925 .81066 .42572 .80584 .41924 Mtetra
.80584 .41924 .81066 .42572 .82199 .42218 .81721 .41568 Mtetra
.81721 .41568 .82199 .42218 .83337 .41863 .82863 .4121 Mtetra
.82863 .4121 .83337 .41863 .8448 .41507 .84008 .40851 Mtetra
.84008 .40851 .8448 .41507 .85627 .41149 .85159 .4049 Mtetra
.85159 .4049 .85627 .41149 .86779 .40789 .86314 .40128 Mtetra
.86314 .40128 .86779 .40789 .87935 .40429 .87473 .39765 Mtetra
.87473 .39765 .87935 .40429 .89096 .40066 .88637 .394 Mtetra
.583 .692 .916 r
.26422 .58014 .27031 .58659 .27959 .58472 .27348 .57886 Mtetra
.614 .723 .923 r
.27348 .57886 .27959 .58472 .28891 .58296 .28283 .57686 Mtetra
.549 .693 .934 r
.28283 .57686 .28891 .58296 .29715 .59802 .29214 .57609 Mtetra
.689 .539 .678 r
.29214 .57609 .29715 .59802 .30801 .57414 .30208 .56623 Mtetra
.514 .618 .893 r
.30208 .56623 .30801 .57414 .31742 .57246 .31139 .56652 Mtetra
.621 .725 .921 r
.31139 .56652 .31742 .57246 .32692 .57019 .32089 .56436 Mtetra
.625 .731 .923 r
.32089 .56436 .32692 .57019 .33643 .56818 .33044 .56209 Mtetra
.572 .704 .931 r
.33044 .56209 .33643 .56818 .34556 .57432 .33997 .56088 Mtetra
.747 .625 .724 r
.33997 .56088 .34556 .57432 .35584 .55899 .35003 .5502 Mtetra
.484 .581 .876 r
.35003 .5502 .35584 .55899 .36545 .55729 .35951 .55127 Mtetra
.626 .727 .92 r
.35951 .55127 .36545 .55729 .37513 .55478 .3692 .54896 Mtetra
.639 .738 .921 r
.3692 .54896 .37513 .55478 .38486 .55213 .37895 .54633 Mtetra
.64 .74 .921 r
.37895 .54633 .38486 .55213 .39462 .54954 .38874 .54365 Mtetra
.631 .735 .923 r
.38874 .54365 .39462 .54954 .4044 .54748 .39855 .54118 Mtetra
.539 .687 .935 r
.39855 .54118 .4044 .54748 .41788 .43411 .40834 .54056 Mtetra
.51 .278 .498 r
.40834 .54056 .41788 .43411 .42425 .53797 .41848 .53052 Mtetra
.56 .658 .902 r
.41848 .53052 .42425 .53797 .43414 .53579 .42835 .52976 Mtetra
.636 .735 .919 r
.42835 .52976 .43414 .53579 .44409 .53298 .43832 .52712 Mtetra
.648 .745 .92 r
.43832 .52712 .44409 .53298 .45409 .53 .44833 .52418 Mtetra
.653 .749 .92 r
.44833 .52418 .45409 .53 .46412 .52692 .45839 .52112 Mtetra
.656 .751 .92 r
.45839 .52112 .46412 .52692 .47419 .52377 .46848 .51797 Mtetra
.657 .752 .92 r
.46848 .51797 .47419 .52377 .4843 .52057 .47861 .51477 Mtetra
.658 .753 .92 r
.47861 .51477 .4843 .52057 .49444 .51735 .48878 .51153 Mtetra
.659 .754 .92 r
.48878 .51153 .49444 .51735 .50462 .5141 .49899 .50827 Mtetra
.49899 .50827 .50462 .5141 .51484 .51084 .50923 .50499 Mtetra
.50923 .50499 .51484 .51084 .5251 .50758 .51952 .5017 Mtetra
.51952 .5017 .5251 .50758 .5354 .50431 .52984 .4984 Mtetra
.658 .753 .92 r
.52984 .4984 .5354 .50431 .54573 .50104 .5402 .4951 Mtetra
.5402 .4951 .54573 .50104 .5561 .49775 .55059 .49179 Mtetra
.55059 .49179 .5561 .49775 .56651 .49446 .56103 .48848 Mtetra
.56103 .48848 .56651 .49446 .57696 .49117 .57151 .48516 Mtetra
.57151 .48516 .57696 .49117 .58745 .48786 .58202 .48182 Mtetra
.58202 .48182 .58745 .48786 .59798 .48454 .59258 .47848 Mtetra
.657 .753 .92 r
.59258 .47848 .59798 .48454 .60855 .48121 .60317 .47513 Mtetra
.60317 .47513 .60855 .48121 .61916 .47787 .61381 .47176 Mtetra
.61381 .47176 .61916 .47787 .62981 .47452 .62449 .46839 Mtetra
.62449 .46839 .62981 .47452 .6405 .47116 .6352 .465 Mtetra
.657 .752 .92 r
.6352 .465 .6405 .47116 .65122 .46778 .64596 .4616 Mtetra
.64596 .4616 .65122 .46778 .662 .46439 .65676 .45819 Mtetra
.65676 .45819 .662 .46439 .67281 .461 .6676 .45477 Mtetra
.6676 .45477 .67281 .461 .68366 .45759 .67848 .45134 Mtetra
.67848 .45134 .68366 .45759 .69455 .45416 .6894 .44789 Mtetra
.6894 .44789 .69455 .45416 .70549 .45073 .70037 .44443 Mtetra
.70037 .44443 .70549 .45073 .71647 .44728 .71138 .44096 Mtetra
.71138 .44096 .71647 .44728 .72749 .44382 .72243 .43747 Mtetra
.72243 .43747 .72749 .44382 .73855 .44035 .73352 .43397 Mtetra
.73352 .43397 .73855 .44035 .74966 .43686 .74466 .43046 Mtetra
.74466 .43046 .74966 .43686 .76081 .43337 .75584 .42694 Mtetra
.75584 .42694 .76081 .43337 .772 .42985 .76706 .4234 Mtetra
.76706 .4234 .772 .42985 .78324 .42633 .77833 .41985 Mtetra
.77833 .41985 .78324 .42633 .79452 .42279 .78964 .41629 Mtetra
.78964 .41629 .79452 .42279 .80584 .41924 .801 .41271 Mtetra
.801 .41271 .80584 .41924 .81721 .41568 .8124 .40912 Mtetra
.8124 .40912 .81721 .41568 .82863 .4121 .82384 .40552 Mtetra
.82384 .40552 .82863 .4121 .84008 .40851 .83533 .4019 Mtetra
.83533 .4019 .84008 .40851 .85159 .4049 .84687 .39827 Mtetra
.84687 .39827 .85159 .4049 .86314 .40128 .85845 .39462 Mtetra
.85845 .39462 .86314 .40128 .87473 .39765 .87008 .39096 Mtetra
.87008 .39096 .87473 .39765 .88637 .394 .88176 .38729 Mtetra
.417 .519 .854 r
.25836 .57038 .26422 .58014 .27348 .57886 .26734 .57284 Mtetra
.61 .717 .921 r
.26734 .57284 .27348 .57886 .28283 .57686 .2767 .57092 Mtetra
.604 .719 .926 r
.2767 .57092 .28283 .57686 .29214 .57609 .28609 .56912 Mtetra
.809 .352 0 r
.28609 .56912 .29214 .57609 .30208 .56623 .29438 .58421 Mtetra
0 0 0 r
.29438 .58421 .30208 .56623 .31139 .56652 .30534 .56019 Mtetra
.601 .706 .918 r
.30534 .56019 .31139 .56652 .32089 .56436 .31483 .55846 Mtetra
.626 .73 .922 r
.31483 .55846 .32089 .56436 .33044 .56209 .3244 .55615 Mtetra
.614 .725 .925 r
.3244 .55615 .33044 .56209 .33997 .56088 .33399 .55408 Mtetra
0 .305 .793 r
.33399 .55408 .33997 .56088 .35003 .5502 .34318 .56022 Mtetra
.603 .813 .409 r
.34318 .56022 .35003 .5502 .35951 .55127 .35356 .54478 Mtetra
.601 .704 .916 r
.35356 .54478 .35951 .55127 .3692 .54896 .36324 .54303 Mtetra
.635 .735 .921 r
.36324 .54303 .3692 .54896 .37895 .54633 .373 .54048 Mtetra
.64 .74 .921 r
.373 .54048 .37895 .54633 .38874 .54365 .38281 .53777 Mtetra
.637 .739 .922 r
.38281 .53777 .38874 .54365 .39855 .54118 .39265 .53513 Mtetra
.613 .726 .926 r
.39265 .53513 .39855 .54118 .40834 .54056 .40251 .53302 Mtetra
.942 .704 .549 r
.40251 .53302 .40834 .54056 .41848 .53052 .41617 .41916 Mtetra
0 0 .379 r
.41617 .41916 .41848 .53052 .42835 .52976 .42253 .5234 Mtetra
.619 .719 .917 r
.42253 .5234 .42835 .52976 .43832 .52712 .43251 .52116 Mtetra
.644 .741 .92 r
.43251 .52116 .43832 .52712 .44833 .52418 .44254 .5183 Mtetra
.651 .747 .92 r
.44254 .5183 .44833 .52418 .45839 .52112 .45262 .51526 Mtetra
.654 .75 .92 r
.45262 .51526 .45839 .52112 .46848 .51797 .46273 .51213 Mtetra
.656 .752 .92 r
.46273 .51213 .46848 .51797 .47861 .51477 .47289 .50893 Mtetra
.658 .753 .92 r
.47289 .50893 .47861 .51477 .48878 .51153 .48308 .50567 Mtetra
.659 .754 .92 r
.48308 .50567 .48878 .51153 .49899 .50827 .49331 .50239 Mtetra
.49331 .50239 .49899 .50827 .50923 .50499 .50358 .49909 Mtetra
.50358 .49909 .50923 .50499 .51952 .5017 .51389 .49577 Mtetra
.51389 .49577 .51952 .5017 .52984 .4984 .52424 .49245 Mtetra
.658 .753 .92 r
.52424 .49245 .52984 .4984 .5402 .4951 .53462 .48913 Mtetra
.53462 .48913 .5402 .4951 .55059 .49179 .54505 .48579 Mtetra
.54505 .48579 .55059 .49179 .56103 .48848 .55551 .48246 Mtetra
.55551 .48246 .56103 .48848 .57151 .48516 .56601 .47911 Mtetra
.56601 .47911 .57151 .48516 .58202 .48182 .57656 .47575 Mtetra
.57656 .47575 .58202 .48182 .59258 .47848 .58714 .47238 Mtetra
.58714 .47238 .59258 .47848 .60317 .47513 .59776 .46901 Mtetra
.657 .753 .92 r
.59776 .46901 .60317 .47513 .61381 .47176 .60842 .46562 Mtetra
.60842 .46562 .61381 .47176 .62449 .46839 .61913 .46222 Mtetra
.61913 .46222 .62449 .46839 .6352 .465 .62987 .45881 Mtetra
.657 .752 .92 r
.62987 .45881 .6352 .465 .64596 .4616 .64066 .45538 Mtetra
.64066 .45538 .64596 .4616 .65676 .45819 .65148 .45195 Mtetra
.65148 .45195 .65676 .45819 .6676 .45477 .66235 .4485 Mtetra
.66235 .4485 .6676 .45477 .67848 .45134 .67326 .44504 Mtetra
.67326 .44504 .67848 .45134 .6894 .44789 .68422 .44157 Mtetra
.68422 .44157 .6894 .44789 .70037 .44443 .69521 .43808 Mtetra
.69521 .43808 .70037 .44443 .71138 .44096 .70625 .43459 Mtetra
.70625 .43459 .71138 .44096 .72243 .43747 .71733 .43108 Mtetra
.71733 .43108 .72243 .43747 .73352 .43397 .72845 .42755 Mtetra
.72845 .42755 .73352 .43397 .74466 .43046 .73962 .42402 Mtetra
.73962 .42402 .74466 .43046 .75584 .42694 .75083 .42047 Mtetra
.75083 .42047 .75584 .42694 .76706 .4234 .76208 .41691 Mtetra
.76208 .41691 .76706 .4234 .77833 .41985 .77338 .41333 Mtetra
.77338 .41333 .77833 .41985 .78964 .41629 .78473 .40974 Mtetra
.78473 .40974 .78964 .41629 .801 .41271 .79611 .40614 Mtetra
.79611 .40614 .801 .41271 .8124 .40912 .80755 .40252 Mtetra
.80755 .40252 .8124 .40912 .82384 .40552 .81903 .39889 Mtetra
.81903 .39889 .82384 .40552 .83533 .4019 .83055 .39524 Mtetra
.83055 .39524 .83533 .4019 .84687 .39827 .84212 .39158 Mtetra
.84212 .39158 .84687 .39827 .85845 .39462 .85373 .38791 Mtetra
.85373 .38791 .85845 .39462 .87008 .39096 .8654 .38422 Mtetra
.8654 .38422 .87008 .39096 .88176 .38729 .8771 .38052 Mtetra
.609 .86 .508 r
.25101 .57872 .25836 .57038 .26734 .57284 .26119 .56629 Mtetra
.583 .692 .916 r
.26119 .56629 .26734 .57284 .2767 .57092 .27052 .56497 Mtetra
.614 .723 .923 r
.27052 .56497 .2767 .57092 .28609 .56912 .27995 .56293 Mtetra
.549 .693 .934 r
.27995 .56293 .28609 .56912 .29438 .58421 .28932 .56211 Mtetra
.689 .539 .677 r
.28932 .56211 .29438 .58421 .30534 .56019 .29936 .55217 Mtetra
.514 .618 .893 r
.29936 .55217 .30534 .56019 .31483 .55846 .30873 .55242 Mtetra
.621 .725 .921 r
.30873 .55242 .31483 .55846 .3244 .55615 .31831 .55022 Mtetra
.625 .73 .923 r
.31831 .55022 .3244 .55615 .33399 .55408 .32793 .5479 Mtetra
.572 .704 .931 r
.32793 .5479 .33399 .55408 .34318 .56022 .33754 .54665 Mtetra
.747 .625 .724 r
.33754 .54665 .34318 .56022 .35356 .54478 .34769 .53588 Mtetra
.484 .581 .876 r
.34769 .53588 .35356 .54478 .36324 .54303 .35724 .53692 Mtetra
.626 .727 .92 r
.35724 .53692 .36324 .54303 .373 .54048 .36702 .53456 Mtetra
.639 .739 .921 r
.36702 .53456 .373 .54048 .38281 .53777 .37684 .53187 Mtetra
.64 .74 .921 r
.37684 .53187 .38281 .53777 .39265 .53513 .38671 .52915 Mtetra
.631 .735 .923 r
.38671 .52915 .39265 .53513 .40251 .53302 .39661 .52662 Mtetra
.539 .687 .935 r
.39661 .52662 .40251 .53302 .41617 .41916 .40648 .52596 Mtetra
.507 .273 .495 r
.40648 .52596 .41617 .41916 .42253 .5234 .41671 .51583 Mtetra
.56 .658 .902 r
.41671 .51583 .42253 .5234 .43251 .52116 .42666 .51503 Mtetra
.636 .735 .919 r
.42666 .51503 .43251 .52116 .44254 .5183 .43671 .51234 Mtetra
.648 .745 .92 r
.43671 .51234 .44254 .5183 .45262 .51526 .44681 .50935 Mtetra
.653 .749 .92 r
.44681 .50935 .45262 .51526 .46273 .51213 .45695 .50623 Mtetra
.656 .751 .92 r
.45695 .50623 .46273 .51213 .47289 .50893 .46713 .50303 Mtetra
.657 .752 .92 r
.46713 .50303 .47289 .50893 .48308 .50567 .47734 .49977 Mtetra
.658 .753 .92 r
.47734 .49977 .48308 .50567 .49331 .50239 .4876 .49647 Mtetra
.659 .754 .92 r
.4876 .49647 .49331 .50239 .50358 .49909 .4979 .49315 Mtetra
.4979 .49315 .50358 .49909 .51389 .49577 .50823 .48981 Mtetra
.50823 .48981 .51389 .49577 .52424 .49245 .5186 .48647 Mtetra
.5186 .48647 .52424 .49245 .53462 .48913 .52901 .48311 Mtetra
.658 .753 .92 r
.52901 .48311 .53462 .48913 .54505 .48579 .53946 .47975 Mtetra
.53946 .47975 .54505 .48579 .55551 .48246 .54995 .47639 Mtetra
.54995 .47639 .55551 .48246 .56601 .47911 .56048 .47302 Mtetra
.56048 .47302 .56601 .47911 .57656 .47575 .57105 .46963 Mtetra
.57105 .46963 .57656 .47575 .58714 .47238 .58166 .46624 Mtetra
.58166 .46624 .58714 .47238 .59776 .46901 .59231 .46284 Mtetra
.657 .753 .92 r
.59231 .46284 .59776 .46901 .60842 .46562 .603 .45943 Mtetra
.603 .45943 .60842 .46562 .61913 .46222 .61373 .456 Mtetra
.61373 .456 .61913 .46222 .62987 .45881 .6245 .45257 Mtetra
.6245 .45257 .62987 .45881 .64066 .45538 .63532 .44912 Mtetra
.657 .752 .92 r
.63532 .44912 .64066 .45538 .65148 .45195 .64617 .44566 Mtetra
.64617 .44566 .65148 .45195 .66235 .4485 .65707 .44219 Mtetra
.65707 .44219 .66235 .4485 .67326 .44504 .66801 .4387 Mtetra
.66801 .4387 .67326 .44504 .68422 .44157 .67899 .4352 Mtetra
.67899 .4352 .68422 .44157 .69521 .43808 .69002 .43169 Mtetra
.69002 .43169 .69521 .43808 .70625 .43459 .70108 .42817 Mtetra
.70108 .42817 .70625 .43459 .71733 .43108 .71219 .42464 Mtetra
.71219 .42464 .71733 .43108 .72845 .42755 .72335 .42109 Mtetra
.72335 .42109 .72845 .42755 .73962 .42402 .73454 .41752 Mtetra
.73454 .41752 .73962 .42402 .75083 .42047 .74579 .41395 Mtetra
.74579 .41395 .75083 .42047 .76208 .41691 .75707 .41036 Mtetra
.75707 .41036 .76208 .41691 .77338 .41333 .7684 .40676 Mtetra
.7684 .40676 .77338 .41333 .78473 .40974 .77978 .40314 Mtetra
.77978 .40314 .78473 .40974 .79611 .40614 .7912 .39951 Mtetra
.7912 .39951 .79611 .40614 .80755 .40252 .80266 .39587 Mtetra
.80266 .39587 .80755 .40252 .81903 .39889 .81417 .39221 Mtetra
.81417 .39221 .81903 .39889 .83055 .39524 .82573 .38854 Mtetra
.82573 .38854 .83055 .39524 .84212 .39158 .83733 .38485 Mtetra
.83733 .38485 .84212 .39158 .85373 .38791 .84898 .38115 Mtetra
.84898 .38115 .85373 .38791 .8654 .38422 .86068 .37744 Mtetra
.86068 .37744 .8654 .38422 .8771 .38052 .87242 .37371 Mtetra
.776 .663 .739 r
.24515 .5679 .25101 .57872 .26119 .56629 .25527 .55642 Mtetra
.417 .519 .855 r
.25527 .55642 .26119 .56629 .27052 .56497 .26432 .55885 Mtetra
.61 .717 .921 r
.26432 .55885 .27052 .56497 .27995 .56293 .27375 .55689 Mtetra
.604 .719 .926 r
.27375 .55689 .27995 .56293 .28932 .56211 .28322 .55504 Mtetra
.805 .347 0 r
.28322 .55504 .28932 .56211 .29936 .55217 .29155 .57016 Mtetra
0 0 0 r
.29155 .57016 .29936 .55217 .30873 .55242 .30262 .54599 Mtetra
.601 .706 .918 r
.30262 .54599 .30873 .55242 .31831 .55022 .31219 .54422 Mtetra
.626 .73 .922 r
.31219 .54422 .31831 .55022 .32793 .5479 .32183 .54186 Mtetra
.614 .725 .925 r
.32183 .54186 .32793 .5479 .33754 .54665 .3315 .53975 Mtetra
0 .308 .796 r
.3315 .53975 .33754 .54665 .34769 .53588 .34076 .54587 Mtetra
.612 .821 .419 r
.34076 .54587 .34769 .53588 .35724 .53692 .35123 .53033 Mtetra
.601 .704 .916 r
.35123 .53033 .35724 .53692 .36702 .53456 .36099 .52853 Mtetra
.635 .735 .921 r
.36099 .52853 .36702 .53456 .37684 .53187 .37084 .52592 Mtetra
.64 .74 .921 r
.37084 .52592 .37684 .53187 .38671 .52915 .38072 .52317 Mtetra
.637 .739 .922 r
.38072 .52317 .38671 .52915 .39661 .52662 .39065 .52047 Mtetra
.613 .726 .926 r
.39065 .52047 .39661 .52662 .40648 .52596 .40059 .51831 Mtetra
.943 .704 .547 r
.40059 .51831 .40648 .52596 .41671 .51583 .41442 .40395 Mtetra
0 0 .375 r
.41442 .40395 .41671 .51583 .42666 .51503 .42078 .50856 Mtetra
.619 .719 .917 r
.42078 .50856 .42666 .51503 .43671 .51234 .43084 .50627 Mtetra
.644 .741 .92 r
.43084 .50627 .43671 .51234 .44681 .50935 .44096 .50336 Mtetra
.651 .747 .92 r
.44096 .50336 .44681 .50935 .45695 .50623 .45112 .50027 Mtetra
.654 .75 .92 r
.45112 .50027 .45695 .50623 .46713 .50303 .46132 .49708 Mtetra
.656 .752 .92 r
.46132 .49708 .46713 .50303 .47734 .49977 .47157 .49382 Mtetra
.658 .753 .92 r
.47157 .49382 .47734 .49977 .4876 .49647 .48185 .49051 Mtetra
.659 .754 .92 r
.48185 .49051 .4876 .49647 .4979 .49315 .49217 .48717 Mtetra
.49217 .48717 .4979 .49315 .50823 .48981 .50253 .48381 Mtetra
.50253 .48381 .50823 .48981 .5186 .48647 .51292 .48044 Mtetra
.51292 .48044 .5186 .48647 .52901 .48311 .52336 .47706 Mtetra
.658 .753 .92 r
.52336 .47706 .52901 .48311 .53946 .47975 .53384 .47367 Mtetra
.53384 .47367 .53946 .47975 .54995 .47639 .54435 .47028 Mtetra
.54435 .47028 .54995 .47639 .56048 .47302 .55491 .46688 Mtetra
.55491 .46688 .56048 .47302 .57105 .46963 .56551 .46347 Mtetra
.56551 .46347 .57105 .46963 .58166 .46624 .57614 .46006 Mtetra
.57614 .46006 .58166 .46624 .59231 .46284 .58682 .45663 Mtetra
.58682 .45663 .59231 .46284 .603 .45943 .59754 .45319 Mtetra
.657 .753 .92 r
.59754 .45319 .603 .45943 .61373 .456 .6083 .44974 Mtetra
.6083 .44974 .61373 .456 .6245 .45257 .6191 .44628 Mtetra
.6191 .44628 .6245 .45257 .63532 .44912 .62994 .44281 Mtetra
.657 .752 .92 r
.62994 .44281 .63532 .44912 .64617 .44566 .64082 .43932 Mtetra
.64082 .43932 .64617 .44566 .65707 .44219 .65175 .43582 Mtetra
.65175 .43582 .65707 .44219 .66801 .4387 .66272 .43232 Mtetra
.66272 .43232 .66801 .4387 .67899 .4352 .67373 .42879 Mtetra
.67373 .42879 .67899 .4352 .69002 .43169 .68478 .42526 Mtetra
.68478 .42526 .69002 .43169 .70108 .42817 .69588 .42171 Mtetra
.69588 .42171 .70108 .42817 .71219 .42464 .70702 .41815 Mtetra
.70702 .41815 .71219 .42464 .72335 .42109 .7182 .41457 Mtetra
.7182 .41457 .72335 .42109 .73454 .41752 .72943 .41098 Mtetra
.72943 .41098 .73454 .41752 .74579 .41395 .74071 .40738 Mtetra
.74071 .40738 .74579 .41395 .75707 .41036 .75202 .40377 Mtetra
.75202 .40377 .75707 .41036 .7684 .40676 .76338 .40014 Mtetra
.76338 .40014 .7684 .40676 .77978 .40314 .77479 .3965 Mtetra
.77479 .3965 .77978 .40314 .7912 .39951 .78624 .39284 Mtetra
.78624 .39284 .7912 .39951 .80266 .39587 .79774 .38917 Mtetra
.79774 .38917 .80266 .39587 .81417 .39221 .80928 .38548 Mtetra
.80928 .38548 .81417 .39221 .82573 .38854 .82087 .38178 Mtetra
.82087 .38178 .82573 .38854 .83733 .38485 .83251 .37807 Mtetra
.83251 .37807 .83733 .38485 .84898 .38115 .84419 .37434 Mtetra
.84419 .37434 .84898 .38115 .86068 .37744 .85592 .3706 Mtetra
.85592 .3706 .86068 .37744 .87242 .37371 .8677 .36684 Mtetra
.177 .491 .903 r
.23891 .5612 .24515 .5679 .25527 .55642 .24784 .56473 Mtetra
.62 .868 .518 r
.24784 .56473 .25527 .55642 .26432 .55885 .25811 .55221 Mtetra
.583 .692 .916 r
.25811 .55221 .26432 .55885 .27375 .55689 .26751 .55084 Mtetra
.614 .723 .923 r
.26751 .55084 .27375 .55689 .28322 .55504 .27701 .54875 Mtetra
.55 .693 .934 r
.27701 .54875 .28322 .55504 .29155 .57016 .28646 .5479 Mtetra
.689 .539 .677 r
.28646 .5479 .29155 .57016 .30262 .54599 .29658 .53787 Mtetra
.513 .618 .893 r
.29658 .53787 .30262 .54599 .31219 .54422 .30603 .53808 Mtetra
.621 .725 .921 r
.30603 .53808 .31219 .54422 .32183 .54186 .31569 .53583 Mtetra
.625 .73 .923 r
.31569 .53583 .32183 .54186 .3315 .53975 .32539 .53346 Mtetra
.572 .704 .931 r
.32539 .53346 .3315 .53975 .34076 .54587 .33507 .53217 Mtetra
.747 .626 .725 r
.33507 .53217 .34076 .54587 .35123 .53033 .34531 .52131 Mtetra
.483 .581 .876 r
.34531 .52131 .35123 .53033 .36099 .52853 .35494 .52231 Mtetra
.626 .727 .92 r
.35494 .52231 .36099 .52853 .37084 .52592 .36479 .5199 Mtetra
.639 .739 .921 r
.36479 .5199 .37084 .52592 .38072 .52317 .3747 .51716 Mtetra
.64 .74 .921 r
.3747 .51716 .38072 .52317 .39065 .52047 .38465 .51439 Mtetra
.631 .735 .923 r
.38465 .51439 .39065 .52047 .40059 .51831 .39463 .51181 Mtetra
.539 .687 .935 r
.39463 .51181 .40059 .51831 .41442 .40395 .40458 .51111 Mtetra
.504 .269 .491 r
.40458 .51111 .41442 .40395 .42078 .50856 .4149 .50089 Mtetra
.56 .658 .902 r
.4149 .50089 .42078 .50856 .43084 .50627 .42493 .50004 Mtetra
.636 .735 .919 r
.42493 .50004 .43084 .50627 .44096 .50336 .43507 .4973 Mtetra
.648 .745 .92 r
.43507 .4973 .44096 .50336 .45112 .50027 .44525 .49425 Mtetra
.653 .749 .92 r
.44525 .49425 .45112 .50027 .46132 .49708 .45548 .49107 Mtetra
.656 .751 .92 r
.45548 .49107 .46132 .49708 .47157 .49382 .46575 .48782 Mtetra
.657 .752 .92 r
.46575 .48782 .47157 .49382 .48185 .49051 .47605 .4845 Mtetra
.658 .753 .92 r
.47605 .4845 .48185 .49051 .49217 .48717 .4864 .48115 Mtetra
.659 .754 .92 r
.4864 .48115 .49217 .48717 .50253 .48381 .49678 .47776 Mtetra
.49678 .47776 .50253 .48381 .51292 .48044 .50721 .47437 Mtetra
.50721 .47437 .51292 .48044 .52336 .47706 .51767 .47096 Mtetra
.51767 .47096 .52336 .47706 .53384 .47367 .52817 .46755 Mtetra
.658 .753 .92 r
.52817 .46755 .53384 .47367 .54435 .47028 .53872 .46413 Mtetra
.53872 .46413 .54435 .47028 .55491 .46688 .5493 .46071 Mtetra
.5493 .46071 .55491 .46688 .56551 .46347 .55992 .45727 Mtetra
.55992 .45727 .56551 .46347 .57614 .46006 .57058 .45383 Mtetra
.57058 .45383 .57614 .46006 .58682 .45663 .58129 .45038 Mtetra
.58129 .45038 .58682 .45663 .59754 .45319 .59203 .44691 Mtetra
.657 .753 .92 r
.59203 .44691 .59754 .45319 .6083 .44974 .60282 .44344 Mtetra
.60282 .44344 .6083 .44974 .6191 .44628 .61365 .43995 Mtetra
.61365 .43995 .6191 .44628 .62994 .44281 .62452 .43645 Mtetra
.62452 .43645 .62994 .44281 .64082 .43932 .63543 .43294 Mtetra
.657 .752 .92 r
.63543 .43294 .64082 .43932 .65175 .43582 .64639 .42942 Mtetra
.64639 .42942 .65175 .43582 .66272 .43232 .65739 .42588 Mtetra
.65739 .42588 .66272 .43232 .67373 .42879 .66843 .42234 Mtetra
.66843 .42234 .67373 .42879 .68478 .42526 .67951 .41877 Mtetra
.67951 .41877 .68478 .42526 .69588 .42171 .69064 .4152 Mtetra
.69064 .4152 .69588 .42171 .70702 .41815 .70181 .41161 Mtetra
.70181 .41161 .70702 .41815 .7182 .41457 .71302 .40801 Mtetra
.71302 .40801 .7182 .41457 .72943 .41098 .72428 .4044 Mtetra
.72428 .4044 .72943 .41098 .74071 .40738 .73559 .40077 Mtetra
.73559 .40077 .74071 .40738 .75202 .40377 .74694 .39713 Mtetra
.74694 .39713 .75202 .40377 .76338 .40014 .75833 .39347 Mtetra
.75833 .39347 .76338 .40014 .77479 .3965 .76977 .3898 Mtetra
.76977 .3898 .77479 .3965 .78624 .39284 .78125 .38612 Mtetra
.78125 .38612 .78624 .39284 .79774 .38917 .79278 .38242 Mtetra
.79278 .38242 .79774 .38917 .80928 .38548 .80436 .37871 Mtetra
.80436 .37871 .80928 .38548 .82087 .38178 .81598 .37498 Mtetra
.81598 .37498 .82087 .38178 .83251 .37807 .82765 .37124 Mtetra
.82765 .37124 .83251 .37807 .84419 .37434 .83937 .36748 Mtetra
.83937 .36748 .84419 .37434 .85592 .3706 .85113 .36371 Mtetra
.85113 .36371 .85592 .3706 .8677 .36684 .86294 .35993 Mtetra
.569 .702 .931 r
.23259 .55498 .23891 .5612 .24784 .56473 .24192 .55379 Mtetra
.776 .664 .739 r
.24192 .55379 .24784 .56473 .25811 .55221 .25214 .54222 Mtetra
.416 .519 .855 r
.25214 .54222 .25811 .55221 .26751 .55084 .26125 .54462 Mtetra
.61 .717 .921 r
.26125 .54462 .26751 .55084 .27701 .54875 .27075 .54262 Mtetra
.604 .719 .926 r
.27075 .54262 .27701 .54875 .28646 .5479 .28029 .54072 Mtetra
.8 .342 0 r
.28029 .54072 .28646 .5479 .29658 .53787 .28868 .55587 Mtetra
0 0 0 r
.28868 .55587 .29658 .53787 .30603 .53808 .29986 .53155 Mtetra
.601 .706 .918 r
.29986 .53155 .30603 .53808 .31569 .53583 .3095 .52974 Mtetra
.626 .73 .922 r
.3095 .52974 .31569 .53583 .32539 .53346 .31922 .52732 Mtetra
.614 .725 .925 r
.31922 .52732 .32539 .53346 .33507 .53217 .32897 .52516 Mtetra
0 .312 .798 r
.32897 .52516 .33507 .53217 .34531 .52131 .3383 .53127 Mtetra
.622 .829 .429 r
.3383 .53127 .34531 .52131 .35494 .52231 .34887 .51562 Mtetra
.601 .704 .916 r
.34887 .51562 .35494 .52231 .36479 .5199 .35871 .51377 Mtetra
.635 .735 .921 r
.35871 .51377 .36479 .5199 .3747 .51716 .36863 .51111 Mtetra
.64 .74 .921 r
.36863 .51111 .3747 .51716 .38465 .51439 .3786 .5083 Mtetra
.637 .739 .922 r
.3786 .5083 .38465 .51439 .39463 .51181 .38861 .50556 Mtetra
.613 .726 .926 r
.38861 .50556 .39463 .51181 .40458 .51111 .39864 .50335 Mtetra
.944 .705 .545 r
.39864 .50335 .40458 .51111 .4149 .50089 .41265 .38848 Mtetra
0 0 .37 r
.41265 .38848 .4149 .50089 .42493 .50004 .419 .49347 Mtetra
.619 .719 .917 r
.419 .49347 .42493 .50004 .43507 .4973 .42914 .49113 Mtetra
.644 .741 .92 r
.42914 .49113 .43507 .4973 .44525 .49425 .43935 .48816 Mtetra
.651 .747 .92 r
.43935 .48816 .44525 .49425 .45548 .49107 .4496 .48501 Mtetra
.654 .75 .92 r
.4496 .48501 .45548 .49107 .46575 .48782 .45989 .48176 Mtetra
.656 .752 .92 r
.45989 .48176 .46575 .48782 .47605 .4845 .47022 .47844 Mtetra
.658 .753 .92 r
.47022 .47844 .47605 .4845 .4864 .48115 .48059 .47508 Mtetra
.659 .754 .92 r
.48059 .47508 .4864 .48115 .49678 .47776 .491 .47168 Mtetra
.491 .47168 .49678 .47776 .50721 .47437 .50145 .46826 Mtetra
.50145 .46826 .50721 .47437 .51767 .47096 .51194 .46482 Mtetra
.51194 .46482 .51767 .47096 .52817 .46755 .52247 .46138 Mtetra
.658 .753 .92 r
.52247 .46138 .52817 .46755 .53872 .46413 .53304 .45794 Mtetra
.53304 .45794 .53872 .46413 .5493 .46071 .54365 .45449 Mtetra
.54365 .45449 .5493 .46071 .55992 .45727 .5543 .45103 Mtetra
.5543 .45103 .55992 .45727 .57058 .45383 .56499 .44756 Mtetra
.56499 .44756 .57058 .45383 .58129 .45038 .57572 .44408 Mtetra
.57572 .44408 .58129 .45038 .59203 .44691 .58649 .44059 Mtetra
.58649 .44059 .59203 .44691 .60282 .44344 .59731 .43709 Mtetra
.657 .753 .92 r
.59731 .43709 .60282 .44344 .61365 .43995 .60817 .43358 Mtetra
.60817 .43358 .61365 .43995 .62452 .43645 .61906 .43005 Mtetra
.61906 .43005 .62452 .43645 .63543 .43294 .63001 .42652 Mtetra
.657 .752 .92 r
.63001 .42652 .63543 .43294 .64639 .42942 .64099 .42297 Mtetra
.64099 .42297 .64639 .42942 .65739 .42588 .65202 .41941 Mtetra
.65202 .41941 .65739 .42588 .66843 .42234 .66309 .41583 Mtetra
.66309 .41583 .66843 .42234 .67951 .41877 .6742 .41224 Mtetra
.6742 .41224 .67951 .41877 .69064 .4152 .68536 .40864 Mtetra
.68536 .40864 .69064 .4152 .70181 .41161 .69656 .40503 Mtetra
.69656 .40503 .70181 .41161 .71302 .40801 .70781 .4014 Mtetra
.70781 .4014 .71302 .40801 .72428 .4044 .7191 .39776 Mtetra
.7191 .39776 .72428 .4044 .73559 .40077 .73043 .39411 Mtetra
.73043 .39411 .73559 .40077 .74694 .39713 .74181 .39044 Mtetra
.74181 .39044 .74694 .39713 .75833 .39347 .75324 .38675 Mtetra
.75324 .38675 .75833 .39347 .76977 .3898 .76471 .38306 Mtetra
.76471 .38306 .76977 .3898 .78125 .38612 .77622 .37935 Mtetra
.77622 .37935 .78125 .38612 .79278 .38242 .78779 .37562 Mtetra
.78779 .37562 .79278 .38242 .80436 .37871 .7994 .37188 Mtetra
.7994 .37188 .80436 .37871 .81598 .37498 .81105 .36813 Mtetra
.81105 .36813 .81598 .37498 .82765 .37124 .82276 .36436 Mtetra
.82276 .36436 .82765 .37124 .83937 .36748 .83451 .36057 Mtetra
.83451 .36057 .83937 .36748 .85113 .36371 .8463 .35677 Mtetra
.8463 .35677 .85113 .36371 .86294 .35993 .85815 .35296 Mtetra
.601 .716 .925 r
.22622 .54881 .23259 .55498 .24192 .55379 .23562 .54699 Mtetra
.179 .492 .903 r
.23562 .54699 .24192 .55379 .25214 .54222 .24461 .55049 Mtetra
.63 .876 .528 r
.24461 .55049 .25214 .54222 .26125 .54462 .25498 .53788 Mtetra
.583 .692 .917 r
.25498 .53788 .26125 .54462 .27075 .54262 .26445 .53647 Mtetra
.614 .723 .923 r
.26445 .53647 .27075 .54262 .28029 .54072 .27403 .53433 Mtetra
.55 .693 .934 r
.27403 .53433 .28029 .54072 .28868 .55587 .28355 .53343 Mtetra
.689 .538 .677 r
.28355 .53343 .28868 .55587 .29986 .53155 .29376 .52332 Mtetra
.513 .618 .893 r
.29376 .52332 .29986 .53155 .3095 .52974 .30328 .5235 Mtetra
.621 .725 .921 r
.30328 .5235 .3095 .52974 .31922 .52732 .31301 .52119 Mtetra
.625 .73 .923 r
.31301 .52119 .31922 .52732 .32897 .52516 .3228 .51877 Mtetra
.573 .704 .931 r
.3228 .51877 .32897 .52516 .3383 .53127 .33256 .51743 Mtetra
.748 .626 .725 r
.33256 .51743 .3383 .53127 .34887 .51562 .34289 .50649 Mtetra
.483 .581 .877 r
.34289 .50649 .34887 .51562 .35871 .51377 .35259 .50745 Mtetra
.626 .727 .92 r
.35259 .50745 .35871 .51377 .36863 .51111 .36253 .50499 Mtetra
.639 .739 .921 r
.36253 .50499 .36863 .51111 .3786 .5083 .37252 .5022 Mtetra
.64 .74 .921 r
.37252 .5022 .3786 .5083 .38861 .50556 .38255 .49937 Mtetra
.631 .735 .923 r
.38255 .49937 .38861 .50556 .39864 .50335 .39261 .49674 Mtetra
.539 .687 .935 r
.39261 .49674 .39864 .50335 .41265 .38848 .40265 .49599 Mtetra
.5 .264 .488 r
.40265 .49599 .41265 .38848 .419 .49347 .41306 .48568 Mtetra
.56 .658 .902 r
.41306 .48568 .419 .49347 .42914 .49113 .42318 .48479 Mtetra
.636 .735 .919 r
.42318 .48479 .42914 .49113 .43935 .48816 .4334 .48199 Mtetra
.648 .745 .92 r
.4334 .48199 .43935 .48816 .4496 .48501 .44367 .47888 Mtetra
.653 .749 .92 r
.44367 .47888 .4496 .48501 .45989 .48176 .45399 .47565 Mtetra
.656 .751 .92 r
.45399 .47565 .45989 .48176 .47022 .47844 .46434 .47233 Mtetra
.657 .752 .92 r
.46434 .47233 .47022 .47844 .48059 .47508 .47474 .46896 Mtetra
.658 .753 .92 r
.47474 .46896 .48059 .47508 .491 .47168 .48518 .46554 Mtetra
.659 .754 .92 r
.48518 .46554 .491 .47168 .50145 .46826 .49565 .4621 Mtetra
.49565 .4621 .50145 .46826 .51194 .46482 .50617 .45864 Mtetra
.50617 .45864 .51194 .46482 .52247 .46138 .51672 .45518 Mtetra
.51672 .45518 .52247 .46138 .53304 .45794 .52732 .4517 Mtetra
.658 .753 .92 r
.52732 .4517 .53304 .45794 .54365 .45449 .53796 .44822 Mtetra
.53796 .44822 .54365 .45449 .5543 .45103 .54863 .44474 Mtetra
.54863 .44474 .5543 .45103 .56499 .44756 .55935 .44124 Mtetra
.55935 .44124 .56499 .44756 .57572 .44408 .57011 .43774 Mtetra
.57011 .43774 .57572 .44408 .58649 .44059 .58091 .43422 Mtetra
.58091 .43422 .58649 .44059 .59731 .43709 .59176 .4307 Mtetra
.657 .753 .92 r
.59176 .4307 .59731 .43709 .60817 .43358 .60264 .42716 Mtetra
.60264 .42716 .60817 .43358 .61906 .43005 .61357 .42361 Mtetra
.61357 .42361 .61906 .43005 .63001 .42652 .62454 .42004 Mtetra
.62454 .42004 .63001 .42652 .64099 .42297 .63555 .41647 Mtetra
.657 .752 .92 r
.63555 .41647 .64099 .42297 .65202 .41941 .64661 .41288 Mtetra
.64661 .41288 .65202 .41941 .66309 .41583 .65771 .40928 Mtetra
.65771 .40928 .66309 .41583 .6742 .41224 .66885 .40567 Mtetra
.66885 .40567 .6742 .41224 .68536 .40864 .68004 .40204 Mtetra
.68004 .40204 .68536 .40864 .69656 .40503 .69127 .3984 Mtetra
.69127 .3984 .69656 .40503 .70781 .4014 .70255 .39474 Mtetra
.70255 .39474 .70781 .4014 .7191 .39776 .71387 .39107 Mtetra
.71387 .39107 .7191 .39776 .73043 .39411 .72524 .38739 Mtetra
.72524 .38739 .73043 .39411 .74181 .39044 .73665 .3837 Mtetra
.73665 .3837 .74181 .39044 .75324 .38675 .74811 .37999 Mtetra
.74811 .37999 .75324 .38675 .76471 .38306 .75961 .37626 Mtetra
.75961 .37626 .76471 .38306 .77622 .37935 .77116 .37252 Mtetra
.77116 .37252 .77622 .37935 .78779 .37562 .78275 .36877 Mtetra
.78275 .36877 .78779 .37562 .7994 .37188 .7944 .365 Mtetra
.7944 .365 .7994 .37188 .81105 .36813 .80609 .36122 Mtetra
.80609 .36122 .81105 .36813 .82276 .36436 .81782 .35742 Mtetra
.81782 .35742 .82276 .36436 .83451 .36057 .82961 .35361 Mtetra
.82961 .35361 .83451 .36057 .8463 .35677 .84144 .34978 Mtetra
.84144 .34978 .8463 .35677 .85815 .35296 .85332 .34594 Mtetra
.6 .712 .922 r
.21982 .54249 .22622 .54881 .23562 .54699 .22923 .54067 Mtetra
.569 .702 .931 r
.22923 .54067 .23562 .54699 .24461 .55049 .23864 .53943 Mtetra
.777 .664 .739 r
.23864 .53943 .24461 .55049 .25498 .53788 .24894 .52778 Mtetra
.415 .518 .855 r
.24894 .52778 .25498 .53788 .26445 .53647 .25812 .53015 Mtetra
.61 .718 .921 r
.25812 .53015 .26445 .53647 .27403 .53433 .2677 .5281 Mtetra
.604 .719 .926 r
.2677 .5281 .27403 .53433 .28355 .53343 .27732 .52615 Mtetra
.796 .337 0 r
.27732 .52615 .28355 .53343 .29376 .52332 .28576 .54132 Mtetra
0 0 0 r
.28576 .54132 .29376 .52332 .30328 .5235 .29704 .51686 Mtetra
.601 .706 .918 r
.29704 .51686 .30328 .5235 .31301 .52119 .30677 .515 Mtetra
.626 .73 .922 r
.30677 .515 .31301 .52119 .3228 .51877 .31657 .51253 Mtetra
.614 .725 .925 r
.31657 .51253 .3228 .51877 .33256 .51743 .3264 .51032 Mtetra
0 .315 .801 r
.3264 .51032 .33256 .51743 .34289 .50649 .3358 .51641 Mtetra
.632 .837 .439 r
.3358 .51641 .34289 .50649 .35259 .50745 .34646 .50065 Mtetra
.601 .704 .916 r
.34646 .50065 .35259 .50745 .36253 .50499 .35638 .49876 Mtetra
.635 .735 .921 r
.35638 .49876 .36253 .50499 .37252 .5022 .36639 .49604 Mtetra
.64 .74 .921 r
.36639 .49604 .37252 .5022 .38255 .49937 .37644 .49318 Mtetra
.637 .739 .922 r
.37644 .49318 .38255 .49937 .39261 .49674 .38654 .49037 Mtetra
.613 .726 .926 r
.38654 .49037 .39261 .49674 .40265 .49599 .39665 .48811 Mtetra
.946 .705 .543 r
.39665 .48811 .40265 .49599 .41306 .48568 .41084 .37275 Mtetra
0 0 .366 r
.41084 .37275 .41306 .48568 .42318 .48479 .41718 .4781 Mtetra
.619 .719 .917 r
.41718 .4781 .42318 .48479 .4334 .48199 .42741 .47571 Mtetra
.644 .741 .92 r
.42741 .47571 .4334 .48199 .44367 .47888 .43771 .47268 Mtetra
.651 .747 .92 r
.43771 .47268 .44367 .47888 .45399 .47565 .44805 .46947 Mtetra
.654 .75 .92 r
.44805 .46947 .45399 .47565 .46434 .47233 .45843 .46617 Mtetra
.656 .752 .92 r
.45843 .46617 .46434 .47233 .47474 .46896 .46885 .46279 Mtetra
.658 .753 .92 r
.46885 .46279 .47474 .46896 .48518 .46554 .47931 .45936 Mtetra
.659 .754 .92 r
.47931 .45936 .48518 .46554 .49565 .4621 .48981 .4559 Mtetra
.48981 .4559 .49565 .4621 .50617 .45864 .50035 .45242 Mtetra
.50035 .45242 .50617 .45864 .51672 .45518 .51094 .44893 Mtetra
.51094 .44893 .51672 .45518 .52732 .4517 .52156 .44543 Mtetra
.658 .753 .92 r
.52156 .44543 .52732 .4517 .53796 .44822 .53222 .44192 Mtetra
.53222 .44192 .53796 .44822 .54863 .44474 .54293 .4384 Mtetra
.54293 .4384 .54863 .44474 .55935 .44124 .55367 .43488 Mtetra
.55367 .43488 .55935 .44124 .57011 .43774 .56446 .43135 Mtetra
.56446 .43135 .57011 .43774 .58091 .43422 .57529 .42781 Mtetra
.57529 .42781 .58091 .43422 .59176 .4307 .58616 .42426 Mtetra
.58616 .42426 .59176 .4307 .60264 .42716 .59708 .42069 Mtetra
.657 .753 .92 r
.59708 .42069 .60264 .42716 .61357 .42361 .60803 .41711 Mtetra
.60803 .41711 .61357 .42361 .62454 .42004 .61903 .41352 Mtetra
.61903 .41352 .62454 .42004 .63555 .41647 .63007 .40992 Mtetra
.657 .752 .92 r
.63007 .40992 .63555 .41647 .64661 .41288 .64116 .40631 Mtetra
.64116 .40631 .64661 .41288 .65771 .40928 .65229 .40268 Mtetra
.65229 .40268 .65771 .40928 .66885 .40567 .66347 .39904 Mtetra
.66347 .39904 .66885 .40567 .68004 .40204 .67468 .39539 Mtetra
.67468 .39539 .68004 .40204 .69127 .3984 .68595 .39172 Mtetra
.68595 .39172 .69127 .3984 .70255 .39474 .69725 .38804 Mtetra
.69725 .38804 .70255 .39474 .71387 .39107 .70861 .38434 Mtetra
.70861 .38434 .71387 .39107 .72524 .38739 .72 .38063 Mtetra
.72 .38063 .72524 .38739 .73665 .3837 .73145 .37691 Mtetra
.73145 .37691 .73665 .3837 .74811 .37999 .74294 .37317 Mtetra
.74294 .37317 .74811 .37999 .75961 .37626 .75447 .36942 Mtetra
.75447 .36942 .75961 .37626 .77116 .37252 .76606 .36565 Mtetra
.76606 .36565 .77116 .37252 .78275 .36877 .77768 .36187 Mtetra
.77768 .36187 .78275 .36877 .7944 .365 .78936 .35807 Mtetra
.78936 .35807 .7944 .365 .80609 .36122 .80108 .35426 Mtetra
.80108 .35426 .80609 .36122 .81782 .35742 .81286 .35044 Mtetra
.81286 .35044 .81782 .35742 .82961 .35361 .82467 .34659 Mtetra
.82467 .34659 .82961 .35361 .84144 .34978 .83654 .34274 Mtetra
.83654 .34274 .84144 .34978 .85332 .34594 .84846 .33887 Mtetra
.569 .681 .916 r
.21343 .53554 .21982 .54249 .22923 .54067 .2228 .5344 Mtetra
.601 .716 .925 r
.2228 .5344 .22923 .54067 .23864 .53943 .23227 .53253 Mtetra
.182 .493 .904 r
.23227 .53253 .23864 .53943 .24894 .52778 .24133 .53601 Mtetra
.64 .883 .539 r
.24133 .53601 .24894 .52778 .25812 .53015 .25179 .52331 Mtetra
.583 .692 .917 r
.25179 .52331 .25812 .53015 .2677 .5281 .26134 .52185 Mtetra
.614 .723 .923 r
.26134 .52185 .2677 .5281 .27732 .52615 .27099 .51966 Mtetra
.55 .693 .934 r
.27099 .51966 .27732 .52615 .28576 .54132 .28059 .51872 Mtetra
.688 .538 .677 r
.28059 .51872 .28576 .54132 .29704 .51686 .29089 .50852 Mtetra
.513 .618 .894 r
.29089 .50852 .29704 .51686 .30677 .515 .30048 .50865 Mtetra
.621 .725 .921 r
.30048 .50865 .30677 .515 .31657 .51253 .3103 .5063 Mtetra
.625 .73 .923 r
.3103 .5063 .31657 .51253 .3264 .51032 .32016 .50383 Mtetra
.573 .704 .931 r
.32016 .50383 .3264 .51032 .3358 .51641 .33 .50244 Mtetra
.748 .626 .725 r
.33 .50244 .3358 .51641 .34646 .50065 .34042 .49141 Mtetra
.482 .58 .877 r
.34042 .49141 .34646 .50065 .35638 .49876 .35021 .49233 Mtetra
.625 .727 .92 r
.35021 .49233 .35638 .49876 .36639 .49604 .36022 .48981 Mtetra
.639 .739 .921 r
.36022 .48981 .36639 .49604 .37644 .49318 .3703 .48696 Mtetra
.64 .74 .921 r
.3703 .48696 .37644 .49318 .38654 .49037 .38041 .48408 Mtetra
.631 .735 .923 r
.38041 .48408 .38654 .49037 .39665 .48811 .39056 .48139 Mtetra
.54 .687 .935 r
.39056 .48139 .39665 .48811 .41084 .37275 .40068 .48059 Mtetra
.497 .259 .484 r
.40068 .48059 .41084 .37275 .41718 .4781 .41119 .4702 Mtetra
.56 .658 .902 r
.41119 .4702 .41718 .4781 .42741 .47571 .42139 .46926 Mtetra
.636 .735 .919 r
.42139 .46926 .42741 .47571 .43771 .47268 .4317 .4664 Mtetra
.648 .745 .92 r
.4317 .4664 .43771 .47268 .44805 .46947 .44206 .46324 Mtetra
.653 .749 .92 r
.44206 .46324 .44805 .46947 .45843 .46617 .45247 .45994 Mtetra
.656 .751 .92 r
.45247 .45994 .45843 .46617 .46885 .46279 .46291 .45657 Mtetra
.657 .752 .92 r
.46291 .45657 .46885 .46279 .47931 .45936 .4734 .45313 Mtetra
.658 .753 .92 r
.4734 .45313 .47931 .45936 .48981 .4559 .48393 .44966 Mtetra
.659 .754 .92 r
.48393 .44966 .48981 .4559 .50035 .45242 .4945 .44615 Mtetra
.4945 .44615 .50035 .45242 .51094 .44893 .50511 .44263 Mtetra
.50511 .44263 .51094 .44893 .52156 .44543 .51576 .43911 Mtetra
.51576 .43911 .52156 .44543 .53222 .44192 .52645 .43557 Mtetra
.658 .753 .92 r
.52645 .43557 .53222 .44192 .54293 .4384 .53718 .43203 Mtetra
.53718 .43203 .54293 .4384 .55367 .43488 .54795 .42848 Mtetra
.54795 .42848 .55367 .43488 .56446 .43135 .55877 .42492 Mtetra
.55877 .42492 .56446 .43135 .57529 .42781 .56963 .42135 Mtetra
.56963 .42135 .57529 .42781 .58616 .42426 .58053 .41777 Mtetra
.58053 .41777 .58616 .42426 .59708 .42069 .59147 .41418 Mtetra
.657 .753 .92 r
.59147 .41418 .59708 .42069 .60803 .41711 .60246 .41057 Mtetra
.60246 .41057 .60803 .41711 .61903 .41352 .61348 .40696 Mtetra
.61348 .40696 .61903 .41352 .63007 .40992 .62456 .40333 Mtetra
.62456 .40333 .63007 .40992 .64116 .40631 .63567 .39969 Mtetra
.657 .752 .92 r
.63567 .39969 .64116 .40631 .65229 .40268 .64683 .39603 Mtetra
.64683 .39603 .65229 .40268 .66347 .39904 .65804 .39237 Mtetra
.65804 .39237 .66347 .39904 .67468 .39539 .66929 .38868 Mtetra
.66929 .38868 .67468 .39539 .68595 .39172 .68058 .38499 Mtetra
.68058 .38499 .68595 .39172 .69725 .38804 .69192 .38128 Mtetra
.69192 .38128 .69725 .38804 .70861 .38434 .7033 .37756 Mtetra
.7033 .37756 .70861 .38434 .72 .38063 .71473 .37382 Mtetra
.71473 .37382 .72 .38063 .73145 .37691 .72621 .37007 Mtetra
.72621 .37007 .73145 .37691 .74294 .37317 .73773 .3663 Mtetra
.73773 .3663 .74294 .37317 .75447 .36942 .7493 .36252 Mtetra
.7493 .36252 .75447 .36942 .76606 .36565 .76091 .35873 Mtetra
.76091 .35873 .76606 .36565 .77768 .36187 .77258 .35492 Mtetra
.77258 .35492 .77768 .36187 .78936 .35807 .78429 .35109 Mtetra
.78429 .35109 .78936 .35807 .80108 .35426 .79604 .34725 Mtetra
.79604 .34725 .80108 .35426 .81286 .35044 .80785 .3434 Mtetra
.80785 .3434 .81286 .35044 .82467 .34659 .8197 .33953 Mtetra
.8197 .33953 .82467 .34659 .83654 .34274 .8316 .33564 Mtetra
.8316 .33564 .83654 .34274 .84846 .33887 .84356 .33174 Mtetra
.312 .412 .804 r
.20751 .52329 .21343 .53554 .2228 .5344 .21633 .52798 Mtetra
.6 .712 .922 r
.21633 .52798 .2228 .5344 .23227 .53253 .22582 .52611 Mtetra
.569 .702 .931 r
.22582 .52611 .23227 .53253 .24133 .53601 .23529 .52483 Mtetra
.777 .665 .739 r
.23529 .52483 .24133 .53601 .25179 .52331 .24569 .51309 Mtetra
.414 .518 .855 r
.24569 .51309 .25179 .52331 .26134 .52185 .25494 .51543 Mtetra
.61 .718 .921 r
.25494 .51543 .26134 .52185 .27099 .51966 .2646 .51332 Mtetra
.604 .719 .926 r
.2646 .51332 .27099 .51966 .28059 .51872 .27429 .51132 Mtetra
.791 .331 0 r
.27429 .51132 .28059 .51872 .29089 .50852 .28279 .52652 Mtetra
0 0 0 r
.28279 .52652 .29089 .50852 .30048 .50865 .29418 .50192 Mtetra
.601 .706 .918 r
.29418 .50192 .30048 .50865 .3103 .5063 .30398 .5 Mtetra
.626 .73 .922 r
.30398 .5 .3103 .5063 .32016 .50383 .31387 .49748 Mtetra
.614 .725 .925 r
.31387 .49748 .32016 .50383 .33 .50244 .32378 .49521 Mtetra
0 .318 .803 r
.32378 .49521 .33 .50244 .34042 .49141 .33325 .50129 Mtetra
.642 .844 .448 r
.33325 .50129 .34042 .49141 .35021 .49233 .34401 .48542 Mtetra
.601 .704 .916 r
.34401 .48542 .35021 .49233 .36022 .48981 .35402 .48347 Mtetra
.635 .735 .921 r
.35402 .48347 .36022 .48981 .3703 .48696 .36411 .4807 Mtetra
.64 .74 .921 r
.36411 .4807 .3703 .48696 .38041 .48408 .37425 .47778 Mtetra
.637 .739 .922 r
.37425 .47778 .38041 .48408 .39056 .48139 .38442 .47492 Mtetra
.613 .726 .926 r
.38442 .47492 .39056 .48139 .40068 .48059 .39462 .4726 Mtetra
.947 .706 .541 r
.39462 .4726 .40068 .48059 .41119 .4702 .409 .35674 Mtetra
0 0 .361 r
.409 .35674 .41119 .4702 .42139 .46926 .41534 .46246 Mtetra
.619 .719 .917 r
.41534 .46246 .42139 .46926 .4317 .4664 .42566 .46001 Mtetra
.644 .741 .92 r
.42566 .46001 .4317 .4664 .44206 .46324 .43604 .45693 Mtetra
.651 .747 .92 r
.43604 .45693 .44206 .46324 .45247 .45994 .44647 .45366 Mtetra
.654 .75 .92 r
.44647 .45366 .45247 .45994 .46291 .45657 .45694 .45029 Mtetra
.656 .752 .92 r
.45694 .45029 .46291 .45657 .4734 .45313 .46745 .44685 Mtetra
.658 .753 .92 r
.46745 .44685 .4734 .45313 .48393 .44966 .47801 .44336 Mtetra
.659 .754 .92 r
.47801 .44336 .48393 .44966 .4945 .44615 .4886 .43984 Mtetra
.4886 .43984 .4945 .44615 .50511 .44263 .49924 .4363 Mtetra
.49924 .4363 .50511 .44263 .51576 .43911 .50991 .43274 Mtetra
.50991 .43274 .51576 .43911 .52645 .43557 .52063 .42918 Mtetra
.658 .753 .92 r
.52063 .42918 .52645 .43557 .53718 .43203 .53139 .4256 Mtetra
.53139 .4256 .53718 .43203 .54795 .42848 .54219 .42203 Mtetra
.54219 .42203 .54795 .42848 .55877 .42492 .55304 .41844 Mtetra
.55304 .41844 .55877 .42492 .56963 .42135 .56392 .41484 Mtetra
.56392 .41484 .56963 .42135 .58053 .41777 .57485 .41124 Mtetra
.57485 .41124 .58053 .41777 .59147 .41418 .58582 .40762 Mtetra
.58582 .40762 .59147 .41418 .60246 .41057 .59684 .40399 Mtetra
.657 .753 .92 r
.59684 .40399 .60246 .41057 .61348 .40696 .6079 .40034 Mtetra
.6079 .40034 .61348 .40696 .62456 .40333 .619 .39669 Mtetra
.619 .39669 .62456 .40333 .63567 .39969 .63015 .39302 Mtetra
.657 .752 .92 r
.63015 .39302 .63567 .39969 .64683 .39603 .64134 .38934 Mtetra
.64134 .38934 .64683 .39603 .65804 .39237 .65257 .38564 Mtetra
.65257 .38564 .65804 .39237 .66929 .38868 .66385 .38193 Mtetra
.66385 .38193 .66929 .38868 .68058 .38499 .67517 .37821 Mtetra
.67517 .37821 .68058 .38499 .69192 .38128 .68654 .37447 Mtetra
.68654 .37447 .69192 .38128 .7033 .37756 .69796 .37072 Mtetra
.69796 .37072 .7033 .37756 .71473 .37382 .70942 .36696 Mtetra
.70942 .36696 .71473 .37382 .72621 .37007 .72093 .36318 Mtetra
.72093 .36318 .72621 .37007 .73773 .3663 .73248 .35938 Mtetra
.73248 .35938 .73773 .3663 .7493 .36252 .74409 .35557 Mtetra
.74409 .35557 .7493 .36252 .76091 .35873 .75573 .35175 Mtetra
.75573 .35175 .76091 .35873 .77258 .35492 .76743 .34791 Mtetra
.76743 .34791 .77258 .35492 .78429 .35109 .77917 .34406 Mtetra
.77917 .34406 .78429 .35109 .79604 .34725 .79097 .34019 Mtetra
.79097 .34019 .79604 .34725 .80785 .3434 .8028 .3363 Mtetra
.8028 .3363 .80785 .3434 .8197 .33953 .81469 .3324 Mtetra
.81469 .3324 .8197 .33953 .8316 .33564 .82663 .32849 Mtetra
.82663 .32849 .8316 .33564 .84356 .33174 .83862 .32456 Mtetra
0 0 0 r
.19952 .53201 .20751 .52329 .21633 .52798 .20988 .52093 Mtetra
.569 .681 .916 r
.20988 .52093 .21633 .52798 .22582 .52611 .21931 .51974 Mtetra
.601 .716 .925 r
.21931 .51974 .22582 .52611 .23529 .52483 .22886 .51783 Mtetra
.185 .494 .904 r
.22886 .51783 .23529 .52483 .24569 .51309 .23799 .52128 Mtetra
.65 .891 .549 r
.23799 .52128 .24569 .51309 .25494 .51543 .24854 .50848 Mtetra
.583 .692 .917 r
.24854 .50848 .25494 .51543 .2646 .51332 .25817 .50697 Mtetra
.614 .723 .923 r
.25817 .50697 .2646 .51332 .27429 .51132 .2679 .50473 Mtetra
.55 .693 .934 r
.2679 .50473 .27429 .51132 .28279 .52652 .27757 .50374 Mtetra
.688 .537 .676 r
.27757 .50374 .28279 .52652 .29418 .50192 .28796 .49346 Mtetra
.512 .618 .894 r
.28796 .49346 .29418 .50192 .30398 .5 .29764 .49355 Mtetra
.621 .725 .921 r
.29764 .49355 .30398 .5 .31387 .49748 .30753 .49114 Mtetra
.625 .73 .923 r
.30753 .49114 .31387 .49748 .32378 .49521 .31747 .48862 Mtetra
.573 .704 .931 r
.31747 .48862 .32378 .49521 .33325 .50129 .32739 .48718 Mtetra
.748 .627 .725 r
.32739 .48718 .33325 .50129 .34401 .48542 .33791 .47605 Mtetra
.482 .58 .877 r
.33791 .47605 .34401 .48542 .35402 .48347 .34778 .47693 Mtetra
.625 .727 .92 r
.34778 .47693 .35402 .48347 .36411 .4807 .35788 .47436 Mtetra
.639 .739 .921 r
.35788 .47436 .36411 .4807 .37425 .47778 .36804 .47146 Mtetra
.64 .74 .921 r
.36804 .47146 .37425 .47778 .38442 .47492 .37824 .46851 Mtetra
.631 .735 .923 r
.37824 .46851 .38442 .47492 .39462 .4726 .38848 .46577 Mtetra
.54 .687 .934 r
.38848 .46577 .39462 .4726 .409 .35674 .39868 .46493 Mtetra
.493 .254 .48 r
.39868 .46493 .409 .35674 .41534 .46246 .40928 .45444 Mtetra
.559 .658 .902 r
.40928 .45444 .41534 .46246 .42566 .46001 .41957 .45345 Mtetra
.636 .735 .919 r
.41957 .45345 .42566 .46001 .43604 .45693 .42997 .45053 Mtetra
.648 .745 .92 r
.42997 .45053 .43604 .45693 .44647 .45366 .44042 .44731 Mtetra
.653 .749 .92 r
.44042 .44731 .44647 .45366 .45694 .45029 .45092 .44395 Mtetra
.656 .751 .92 r
.45092 .44395 .45694 .45029 .46745 .44685 .46146 .44052 Mtetra
.657 .752 .92 r
.46146 .44052 .46745 .44685 .47801 .44336 .47204 .43702 Mtetra
.658 .753 .92 r
.47204 .43702 .47801 .44336 .4886 .43984 .48266 .43348 Mtetra
.659 .754 .92 r
.48266 .43348 .4886 .43984 .49924 .4363 .49332 .42991 Mtetra
.49332 .42991 .49924 .4363 .50991 .43274 .50403 .42633 Mtetra
.50403 .42633 .50991 .43274 .52063 .42918 .51477 .42274 Mtetra
.51477 .42274 .52063 .42918 .53139 .4256 .52556 .41914 Mtetra
.658 .753 .92 r
.52556 .41914 .53139 .4256 .54219 .42203 .53639 .41553 Mtetra
.53639 .41553 .54219 .42203 .55304 .41844 .54726 .41192 Mtetra
.54726 .41192 .55304 .41844 .56392 .41484 .55818 .40829 Mtetra
.55818 .40829 .56392 .41484 .57485 .41124 .56914 .40466 Mtetra
.56914 .40466 .57485 .41124 .58582 .40762 .58014 .40101 Mtetra
.58014 .40101 .58582 .40762 .59684 .40399 .59118 .39735 Mtetra
.657 .753 .92 r
.59118 .39735 .59684 .40399 .6079 .40034 .60227 .39368 Mtetra
.60227 .39368 .6079 .40034 .619 .39669 .6134 .39 Mtetra
.6134 .39 .619 .39669 .63015 .39302 .62458 .3863 Mtetra
.62458 .3863 .63015 .39302 .64134 .38934 .6358 .38259 Mtetra
.657 .752 .92 r
.6358 .38259 .64134 .38934 .65257 .38564 .64706 .37887 Mtetra
.64706 .37887 .65257 .38564 .66385 .38193 .65837 .37513 Mtetra
.65837 .37513 .66385 .38193 .67517 .37821 .66973 .37138 Mtetra
.66973 .37138 .67517 .37821 .68654 .37447 .68113 .36762 Mtetra
.68113 .36762 .68654 .37447 .69796 .37072 .69258 .36384 Mtetra
.69258 .36384 .69796 .37072 .70942 .36696 .70407 .36004 Mtetra
.70407 .36004 .70942 .36696 .72093 .36318 .71561 .35623 Mtetra
.71561 .35623 .72093 .36318 .73248 .35938 .7272 .35241 Mtetra
.7272 .35241 .73248 .35938 .74409 .35557 .73883 .34857 Mtetra
.73883 .34857 .74409 .35557 .75573 .35175 .75052 .34472 Mtetra
.75052 .34472 .75573 .35175 .76743 .34791 .76224 .34085 Mtetra
.76224 .34085 .76743 .34791 .77917 .34406 .77402 .33697 Mtetra
.77402 .33697 .77917 .34406 .79097 .34019 .78585 .33307 Mtetra
.78585 .33307 .79097 .34019 .8028 .3363 .79772 .32916 Mtetra
.79772 .32916 .8028 .3363 .81469 .3324 .80965 .32523 Mtetra
.80965 .32523 .81469 .3324 .82663 .32849 .82162 .32128 Mtetra
.82162 .32128 .82663 .32849 .83862 .32456 .83364 .31732 Mtetra
.809 .693 .737 r
.19325 .52236 .19952 .53201 .20988 .52093 .20389 .50854 Mtetra
.31 .411 .804 r
.20389 .50854 .20988 .52093 .21931 .51974 .21278 .51321 Mtetra
.6 .712 .922 r
.21278 .51321 .21931 .51974 .22886 .51783 .22234 .5113 Mtetra
.569 .702 .931 r
.22234 .5113 .22886 .51783 .23799 .52128 .2319 .50997 Mtetra
.778 .665 .739 r
.2319 .50997 .23799 .52128 .24854 .50848 .24239 .49813 Mtetra
.413 .518 .855 r
.24239 .49813 .24854 .50848 .25817 .50697 .2517 .50044 Mtetra
.61 .718 .921 r
.2517 .50044 .25817 .50697 .2679 .50473 .26144 .49829 Mtetra
.604 .719 .926 r
.26144 .49829 .2679 .50473 .27757 .50374 .27121 .49624 Mtetra
.786 .326 0 r
.27121 .49624 .27757 .50374 .28796 .49346 .27976 .51146 Mtetra
0 0 0 r
.27976 .51146 .28796 .49346 .29764 .49355 .29127 .4867 Mtetra
.601 .706 .918 r
.29127 .4867 .29764 .49355 .30753 .49114 .30115 .48474 Mtetra
.626 .73 .922 r
.30115 .48474 .30753 .49114 .31747 .48862 .31112 .48216 Mtetra
.614 .725 .925 r
.31112 .48216 .31747 .48862 .32739 .48718 .32111 .47984 Mtetra
0 .321 .805 r
.32111 .47984 .32739 .48718 .33791 .47605 .33065 .4859 Mtetra
.651 .852 .458 r
.33065 .4859 .33791 .47605 .34778 .47693 .34152 .46991 Mtetra
.601 .704 .916 r
.34152 .46991 .34778 .47693 .35788 .47436 .35161 .46791 Mtetra
.635 .735 .921 r
.35161 .46791 .35788 .47436 .36804 .47146 .36178 .46508 Mtetra
.64 .74 .921 r
.36178 .46508 .36804 .47146 .37824 .46851 .37201 .46211 Mtetra
.637 .739 .922 r
.37201 .46211 .37824 .46851 .38848 .46577 .38228 .45919 Mtetra
.613 .726 .926 r
.38228 .45919 .38848 .46577 .39868 .46493 .39256 .45682 Mtetra
.948 .706 .539 r
.39256 .45682 .39868 .46493 .40928 .45444 .40713 .34045 Mtetra
0 0 .356 r
.40713 .34045 .40928 .45444 .41957 .45345 .41346 .44654 Mtetra
.619 .719 .917 r
.41346 .44654 .41957 .45345 .42997 .45053 .42387 .44403 Mtetra
.644 .741 .92 r
.42387 .44403 .42997 .45053 .44042 .44731 .43434 .44089 Mtetra
.651 .747 .92 r
.43434 .44089 .44042 .44731 .45092 .44395 .44486 .43756 Mtetra
.654 .75 .92 r
.44486 .43756 .45092 .44395 .46146 .44052 .45542 .43412 Mtetra
.656 .752 .92 r
.45542 .43412 .46146 .44052 .47204 .43702 .46603 .43062 Mtetra
.658 .753 .92 r
.46603 .43062 .47204 .43702 .48266 .43348 .47668 .42707 Mtetra
.659 .754 .92 r
.47668 .42707 .48266 .43348 .49332 .42991 .48737 .42348 Mtetra
.48737 .42348 .49332 .42991 .50403 .42633 .4981 .41987 Mtetra
.4981 .41987 .50403 .42633 .51477 .42274 .50887 .41625 Mtetra
.50887 .41625 .51477 .42274 .52556 .41914 .51969 .41262 Mtetra
.658 .753 .92 r
.51969 .41262 .52556 .41914 .53639 .41553 .53055 .40899 Mtetra
.53055 .40899 .53639 .41553 .54726 .41192 .54145 .40534 Mtetra
.54145 .40534 .54726 .41192 .55818 .40829 .55239 .40169 Mtetra
.55239 .40169 .55818 .40829 .56914 .40466 .56338 .39803 Mtetra
.56338 .39803 .56914 .40466 .58014 .40101 .57441 .39435 Mtetra
.57441 .39435 .58014 .40101 .59118 .39735 .58548 .39067 Mtetra
.58548 .39067 .59118 .39735 .60227 .39368 .5966 .38697 Mtetra
.657 .753 .92 r
.5966 .38697 .60227 .39368 .6134 .39 .60776 .38326 Mtetra
.60776 .38326 .6134 .39 .62458 .3863 .61897 .37953 Mtetra
.61897 .37953 .62458 .3863 .6358 .38259 .63022 .3758 Mtetra
.657 .752 .92 r
.63022 .3758 .6358 .38259 .64706 .37887 .64151 .37204 Mtetra
.64151 .37204 .64706 .37887 .65837 .37513 .65285 .36828 Mtetra
.65285 .36828 .65837 .37513 .66973 .37138 .66424 .3645 Mtetra
.66424 .3645 .66973 .37138 .68113 .36762 .67568 .36071 Mtetra
.67568 .36071 .68113 .36762 .69258 .36384 .68715 .3569 Mtetra
.68715 .3569 .69258 .36384 .70407 .36004 .69868 .35308 Mtetra
.69868 .35308 .70407 .36004 .71561 .35623 .71025 .34924 Mtetra
.71025 .34924 .71561 .35623 .7272 .35241 .72187 .34539 Mtetra
.72187 .34539 .7272 .35241 .73883 .34857 .73354 .34152 Mtetra
.73354 .34152 .73883 .34857 .75052 .34472 .74526 .33764 Mtetra
.74526 .33764 .75052 .34472 .76224 .34085 .75702 .33374 Mtetra
.75702 .33374 .76224 .34085 .77402 .33697 .76883 .32983 Mtetra
.76883 .32983 .77402 .33697 .78585 .33307 .78069 .3259 Mtetra
.78069 .3259 .78585 .33307 .79772 .32916 .7926 .32196 Mtetra
.7926 .32196 .79772 .32916 .80965 .32523 .80456 .318 Mtetra
.80456 .318 .80965 .32523 .82162 .32128 .81657 .31402 Mtetra
.81657 .31402 .82162 .32128 .83364 .31732 .82862 .31003 Mtetra
.343 .587 .935 r
.18668 .51542 .19325 .52236 .20389 .50854 .19582 .51723 Mtetra
0 0 0 r
.19582 .51723 .20389 .50854 .21278 .51321 .20626 .50606 Mtetra
.568 .681 .916 r
.20626 .50606 .21278 .51321 .22234 .5113 .21577 .50483 Mtetra
.601 .716 .925 r
.21577 .50483 .22234 .5113 .2319 .50997 .2254 .50286 Mtetra
.188 .495 .904 r
.2254 .50286 .2319 .50997 .24239 .49813 .23459 .50628 Mtetra
.659 .897 .558 r
.23459 .50628 .24239 .49813 .2517 .50044 .24524 .49339 Mtetra
.583 .692 .917 r
.24524 .49339 .2517 .50044 .26144 .49829 .25494 .49183 Mtetra
.614 .723 .923 r
.25494 .49183 .26144 .49829 .27121 .49624 .26475 .48953 Mtetra
.55 .693 .934 r
.26475 .48953 .27121 .49624 .27976 .51146 .27451 .4885 Mtetra
.688 .537 .676 r
.27451 .4885 .27976 .51146 .29127 .4867 .28499 .47813 Mtetra
.512 .618 .894 r
.28499 .47813 .29127 .4867 .30115 .48474 .29474 .47817 Mtetra
.621 .725 .921 r
.29474 .47817 .30115 .48474 .31112 .48216 .30472 .47571 Mtetra
.625 .73 .923 r
.30472 .47571 .31112 .48216 .32111 .47984 .31474 .47313 Mtetra
.573 .704 .931 r
.31474 .47313 .32111 .47984 .33065 .4859 .32475 .47164 Mtetra
.749 .627 .725 r
.32475 .47164 .33065 .4859 .34152 .46991 .33536 .46043 Mtetra
.481 .58 .877 r
.33536 .46043 .34152 .46991 .35161 .46791 .3453 .46126 Mtetra
.625 .727 .92 r
.3453 .46126 .35161 .46791 .36178 .46508 .35549 .45864 Mtetra
.639 .739 .921 r
.35549 .45864 .36178 .46508 .37201 .46211 .36574 .45567 Mtetra
.64 .74 .921 r
.36574 .45567 .37201 .46211 .38228 .45919 .37603 .45267 Mtetra
.631 .735 .923 r
.37603 .45267 .38228 .45919 .39256 .45682 .38635 .44987 Mtetra
.54 .687 .934 r
.38635 .44987 .39256 .45682 .40713 .34045 .39664 .44897 Mtetra
.489 .249 .477 r
.39664 .44897 .40713 .34045 .41346 .44654 .40734 .4384 Mtetra
.559 .658 .902 r
.40734 .4384 .41346 .44654 .42387 .44403 .41772 .43735 Mtetra
.636 .735 .919 r
.41772 .43735 .42387 .44403 .43434 .44089 .42821 .43438 Mtetra
.648 .745 .92 r
.42821 .43438 .43434 .44089 .44486 .43756 .43876 .43109 Mtetra
.653 .749 .92 r
.43876 .43109 .44486 .43756 .45542 .43412 .44934 .42767 Mtetra
.656 .751 .92 r
.44934 .42767 .45542 .43412 .46603 .43062 .45998 .42417 Mtetra
.657 .752 .92 r
.45998 .42417 .46603 .43062 .47668 .42707 .47065 .42061 Mtetra
.658 .753 .92 r
.47065 .42061 .47668 .42707 .48737 .42348 .48137 .417 Mtetra
.659 .754 .92 r
.48137 .417 .48737 .42348 .4981 .41987 .49213 .41337 Mtetra
.49213 .41337 .4981 .41987 .50887 .41625 .50293 .40972 Mtetra
.50293 .40972 .50887 .41625 .51969 .41262 .51377 .40607 Mtetra
.51377 .40607 .51969 .41262 .53055 .40899 .52466 .4024 Mtetra
.658 .753 .92 r
.52466 .4024 .53055 .40899 .54145 .40534 .53559 .39873 Mtetra
.53559 .39873 .54145 .40534 .55239 .40169 .54656 .39504 Mtetra
.54656 .39504 .55239 .40169 .56338 .39803 .55758 .39135 Mtetra
.55758 .39135 .56338 .39803 .57441 .39435 .56863 .38765 Mtetra
.56863 .38765 .57441 .39435 .58548 .39067 .57974 .38393 Mtetra
.57974 .38393 .58548 .39067 .5966 .38697 .59088 .38021 Mtetra
.657 .753 .92 r
.59088 .38021 .5966 .38697 .60776 .38326 .60208 .37647 Mtetra
.60208 .37647 .60776 .38326 .61897 .37953 .61331 .37272 Mtetra
.61331 .37272 .61897 .37953 .63022 .3758 .6246 .36895 Mtetra
.6246 .36895 .63022 .3758 .64151 .37204 .63592 .36517 Mtetra
.657 .752 .92 r
.63592 .36517 .64151 .37204 .65285 .36828 .6473 .36138 Mtetra
.6473 .36138 .65285 .36828 .66424 .3645 .65871 .35757 Mtetra
.65871 .35757 .66424 .3645 .67568 .36071 .67018 .35375 Mtetra
.67018 .35375 .67568 .36071 .68715 .3569 .68169 .34991 Mtetra
.68169 .34991 .68715 .3569 .69868 .35308 .69325 .34606 Mtetra
.69325 .34606 .69868 .35308 .71025 .34924 .70486 .34219 Mtetra
.70486 .34219 .71025 .34924 .72187 .34539 .71651 .33831 Mtetra
.71651 .33831 .72187 .34539 .73354 .34152 .72821 .33441 Mtetra
.72821 .33441 .73354 .34152 .74526 .33764 .73996 .3305 Mtetra
.73996 .3305 .74526 .33764 .75702 .33374 .75176 .32657 Mtetra
.75176 .32657 .75702 .33374 .76883 .32983 .7636 .32263 Mtetra
.7636 .32263 .76883 .32983 .78069 .3259 .7755 .31867 Mtetra
.7755 .31867 .78069 .3259 .7926 .32196 .78744 .3147 Mtetra
.78744 .3147 .7926 .32196 .80456 .318 .79943 .31071 Mtetra
.79943 .31071 .80456 .318 .81657 .31402 .81148 .3067 Mtetra
.81148 .3067 .81657 .31402 .82862 .31003 .82357 .30268 Mtetra
.571 .702 .93 r
.18002 .50884 .18668 .51542 .19582 .51723 .18948 .50746 Mtetra
.809 .693 .737 r
.18948 .50746 .19582 .51723 .20626 .50606 .20022 .49354 Mtetra
.308 .411 .804 r
.20022 .49354 .20626 .50606 .21577 .50483 .20917 .49819 Mtetra
.6 .712 .922 r
.20917 .49819 .21577 .50483 .2254 .50286 .21881 .49623 Mtetra
.569 .702 .931 r
.21881 .49623 .2254 .50286 .23459 .50628 .22844 .49485 Mtetra
.778 .666 .74 r
.22844 .49485 .23459 .50628 .24524 .49339 .23902 .48292 Mtetra
.412 .517 .855 r
.23902 .48292 .24524 .49339 .25494 .49183 .24841 .48519 Mtetra
.61 .718 .921 r
.24841 .48519 .25494 .49183 .26475 .48953 .25823 .48298 Mtetra
.604 .719 .926 r
.25823 .48298 .26475 .48953 .27451 .4885 .26808 .48088 Mtetra
.781 .321 0 r
.26808 .48088 .27451 .4885 .28499 .47813 .27668 .49613 Mtetra
0 0 0 r
.27668 .49613 .28499 .47813 .29474 .47817 .28831 .47122 Mtetra
.601 .706 .918 r
.28831 .47122 .29474 .47817 .30472 .47571 .29827 .4692 Mtetra
.626 .73 .922 r
.29827 .4692 .30472 .47571 .31474 .47313 .30832 .46656 Mtetra
.614 .725 .925 r
.30832 .46656 .31474 .47313 .32475 .47164 .3184 .46419 Mtetra
0 .325 .808 r
.3184 .46419 .32475 .47164 .33536 .46043 .32801 .47023 Mtetra
.66 .859 .468 r
.32801 .47023 .33536 .46043 .3453 .46126 .33898 .45413 Mtetra
.601 .704 .916 r
.33898 .45413 .3453 .46126 .35549 .45864 .34915 .45207 Mtetra
.635 .735 .921 r
.34915 .45207 .35549 .45864 .36574 .45567 .35942 .44919 Mtetra
.64 .74 .921 r
.35942 .44919 .36574 .45567 .37603 .45267 .36973 .44615 Mtetra
.637 .739 .922 r
.36973 .44615 .37603 .45267 .38635 .44987 .38009 .44317 Mtetra
.613 .726 .926 r
.38009 .44317 .38635 .44987 .39664 .44897 .39046 .44074 Mtetra
.949 .706 .537 r
.39046 .44074 .39664 .44897 .40734 .4384 .40523 .32388 Mtetra
0 0 .351 r
.40523 .32388 .40734 .4384 .41772 .43735 .41154 .43032 Mtetra
.619 .719 .917 r
.41154 .43032 .41772 .43735 .42821 .43438 .42204 .42775 Mtetra
.644 .741 .92 r
.42204 .42775 .42821 .43438 .43876 .43109 .43261 .42455 Mtetra
.651 .747 .92 r
.43261 .42455 .43876 .43109 .44934 .42767 .44322 .42115 Mtetra
.654 .75 .92 r
.44322 .42115 .44934 .42767 .45998 .42417 .45388 .41766 Mtetra
.656 .752 .92 r
.45388 .41766 .45998 .42417 .47065 .42061 .46458 .41409 Mtetra
.658 .753 .92 r
.46458 .41409 .47065 .42061 .48137 .417 .47533 .41047 Mtetra
.659 .754 .92 r
.47533 .41047 .48137 .417 .49213 .41337 .48611 .40682 Mtetra
.48611 .40682 .49213 .41337 .50293 .40972 .49694 .40315 Mtetra
.49694 .40315 .50293 .40972 .51377 .40607 .50781 .39946 Mtetra
.50781 .39946 .51377 .40607 .52466 .4024 .51873 .39576 Mtetra
.658 .753 .92 r
.51873 .39576 .52466 .4024 .53559 .39873 .52969 .39206 Mtetra
.52969 .39206 .53559 .39873 .54656 .39504 .54069 .38835 Mtetra
.54069 .38835 .54656 .39504 .55758 .39135 .55173 .38463 Mtetra
.55173 .38463 .55758 .39135 .56863 .38765 .56282 .3809 Mtetra
.56282 .3809 .56863 .38765 .57974 .38393 .57395 .37715 Mtetra
.57395 .37715 .57974 .38393 .59088 .38021 .58513 .3734 Mtetra
.58513 .3734 .59088 .38021 .60208 .37647 .59635 .36963 Mtetra
.657 .753 .92 r
.59635 .36963 .60208 .37647 .61331 .37272 .60762 .36585 Mtetra
.60762 .36585 .61331 .37272 .6246 .36895 .61893 .36205 Mtetra
.61893 .36205 .6246 .36895 .63592 .36517 .63029 .35824 Mtetra
.657 .752 .92 r
.63029 .35824 .63592 .36517 .6473 .36138 .64169 .35442 Mtetra
.64169 .35442 .6473 .36138 .65871 .35757 .65314 .35059 Mtetra
.65314 .35059 .65871 .35757 .67018 .35375 .66464 .34673 Mtetra
.66464 .34673 .67018 .35375 .68169 .34991 .67619 .34287 Mtetra
.67619 .34287 .68169 .34991 .69325 .34606 .68778 .33899 Mtetra
.68778 .33899 .69325 .34606 .70486 .34219 .69942 .33509 Mtetra
.69942 .33509 .70486 .34219 .71651 .33831 .7111 .33118 Mtetra
.7111 .33118 .71651 .33831 .72821 .33441 .72284 .32725 Mtetra
.72284 .32725 .72821 .33441 .73996 .3305 .73462 .32331 Mtetra
.73462 .32331 .73996 .3305 .75176 .32657 .74645 .31935 Mtetra
.74645 .31935 .75176 .32657 .7636 .32263 .75833 .31538 Mtetra
.75833 .31538 .7636 .32263 .7755 .31867 .77026 .31139 Mtetra
.77026 .31139 .7755 .31867 .78744 .3147 .78224 .30739 Mtetra
.78224 .30739 .78744 .3147 .79943 .31071 .79427 .30337 Mtetra
.79427 .30337 .79943 .31071 .81148 .3067 .80635 .29933 Mtetra
.80635 .29933 .81148 .3067 .82357 .30268 .81848 .29527 Mtetra
.592 .709 .925 r
.17331 .50222 .18002 .50884 .18948 .50746 .18283 .50041 Mtetra
.344 .587 .935 r
.18283 .50041 .18948 .50746 .20022 .49354 .19204 .50219 Mtetra
.525 .823 .492 r
.19204 .50219 .20022 .49354 .20917 .49819 .20258 .49093 Mtetra
.568 .681 .916 r
.20258 .49093 .20917 .49819 .21881 .49623 .21217 .48965 Mtetra
.601 .716 .925 r
.21217 .48965 .21881 .49623 .22844 .49485 .22187 .48763 Mtetra
.19 .496 .905 r
.22187 .48763 .22844 .49485 .23902 .48292 .23113 .49102 Mtetra
.669 .904 .568 r
.23113 .49102 .23902 .48292 .24841 .48519 .24188 .47802 Mtetra
.583 .692 .917 r
.24188 .47802 .24841 .48519 .25823 .48298 .25166 .47641 Mtetra
.614 .723 .923 r
.25166 .47641 .25823 .48298 .26808 .48088 .26155 .47407 Mtetra
.55 .693 .934 r
.26155 .47407 .26808 .48088 .27668 .49613 .27138 .47298 Mtetra
.688 .537 .676 r
.27138 .47298 .27668 .49613 .28831 .47122 .28196 .46252 Mtetra
.512 .618 .894 r
.28196 .46252 .28831 .47122 .29827 .4692 .29179 .46252 Mtetra
.62 .725 .921 r
.29179 .46252 .29827 .4692 .30832 .46656 .30185 .46 Mtetra
.625 .73 .923 r
.30185 .46 .30832 .46656 .3184 .46419 .31196 .45737 Mtetra
.573 .704 .931 r
.31196 .45737 .3184 .46419 .32801 .47023 .32205 .45582 Mtetra
.749 .628 .725 r
.32205 .45582 .32801 .47023 .33898 .45413 .33276 .44452 Mtetra
.481 .58 .877 r
.33276 .44452 .33898 .45413 .34915 .45207 .34278 .44531 Mtetra
.625 .727 .92 r
.34278 .44531 .34915 .45207 .35942 .44919 .35306 .44262 Mtetra
.639 .739 .921 r
.35306 .44262 .35942 .44919 .36973 .44615 .36339 .4396 Mtetra
.64 .74 .921 r
.36339 .4396 .36973 .44615 .38009 .44317 .37377 .43654 Mtetra
.631 .735 .923 r
.37377 .43654 .38009 .44317 .39046 .44074 .38419 .43368 Mtetra
.54 .687 .934 r
.38419 .43368 .39046 .44074 .40523 .32388 .39457 .43272 Mtetra
.486 .244 .473 r
.39457 .43272 .40523 .32388 .41154 .43032 .40536 .42206 Mtetra
.559 .658 .902 r
.40536 .42206 .41154 .43032 .42204 .42775 .41583 .42096 Mtetra
.636 .735 .919 r
.41583 .42096 .42204 .42775 .43261 .42455 .42642 .41792 Mtetra
.648 .745 .92 r
.42642 .41792 .43261 .42455 .44322 .42115 .43706 .41457 Mtetra
.653 .749 .92 r
.43706 .41457 .44322 .42115 .45388 .41766 .44774 .41109 Mtetra
.656 .751 .92 r
.44774 .41109 .45388 .41766 .46458 .41409 .45847 .40752 Mtetra
.657 .752 .92 r
.45847 .40752 .46458 .41409 .47533 .41047 .46924 .40389 Mtetra
.658 .753 .92 r
.46924 .40389 .47533 .41047 .48611 .40682 .48005 .40022 Mtetra
.659 .754 .92 r
.48005 .40022 .48611 .40682 .49694 .40315 .49091 .39652 Mtetra
.49091 .39652 .49694 .40315 .50781 .39946 .50181 .39281 Mtetra
.50181 .39281 .50781 .39946 .51873 .39576 .51275 .38908 Mtetra
.51275 .38908 .51873 .39576 .52969 .39206 .52374 .38535 Mtetra
.658 .753 .92 r
.52374 .38535 .52969 .39206 .54069 .38835 .53477 .3816 Mtetra
.53477 .3816 .54069 .38835 .55173 .38463 .54584 .37785 Mtetra
.54584 .37785 .55173 .38463 .56282 .3809 .55696 .37409 Mtetra
.55696 .37409 .56282 .3809 .57395 .37715 .56812 .37032 Mtetra
.56812 .37032 .57395 .37715 .58513 .3734 .57933 .36654 Mtetra
.57933 .36654 .58513 .3734 .59635 .36963 .59058 .36274 Mtetra
.657 .753 .92 r
.59058 .36274 .59635 .36963 .60762 .36585 .60188 .35893 Mtetra
.60188 .35893 .60762 .36585 .61893 .36205 .61322 .35511 Mtetra
.61322 .35511 .61893 .36205 .63029 .35824 .62461 .35127 Mtetra
.62461 .35127 .63029 .35824 .64169 .35442 .63605 .34742 Mtetra
.657 .752 .92 r
.63605 .34742 .64169 .35442 .65314 .35059 .64753 .34355 Mtetra
.64753 .34355 .65314 .35059 .66464 .34673 .65906 .33967 Mtetra
.65906 .33967 .66464 .34673 .67619 .34287 .67064 .33577 Mtetra
.67064 .33577 .67619 .34287 .68778 .33899 .68226 .33186 Mtetra
.68226 .33186 .68778 .33899 .69942 .33509 .69393 .32794 Mtetra
.69393 .32794 .69942 .33509 .7111 .33118 .70565 .324 Mtetra
.70565 .324 .7111 .33118 .72284 .32725 .71742 .32004 Mtetra
.71742 .32004 .72284 .32725 .73462 .32331 .72924 .31607 Mtetra
.72924 .31607 .73462 .32331 .74645 .31935 .7411 .31208 Mtetra
.7411 .31208 .74645 .31935 .75833 .31538 .75302 .30807 Mtetra
.75302 .30807 .75833 .31538 .77026 .31139 .76498 .30405 Mtetra
.76498 .30405 .77026 .31139 .78224 .30739 .777 .30002 Mtetra
.777 .30002 .78224 .30739 .79427 .30337 .78906 .29597 Mtetra
.78906 .29597 .79427 .30337 .80635 .29933 .80118 .2919 Mtetra
.80118 .2919 .80635 .29933 .81848 .29527 .81334 .28781 Mtetra
.576 .691 .92 r
.1666 .49518 .17331 .50222 .18283 .50041 .1761 .49372 Mtetra
.571 .702 .93 r
.1761 .49372 .18283 .50041 .19204 .50219 .18564 .49229 Mtetra
.81 .694 .737 r
.18564 .49229 .19204 .50219 .20258 .49093 .19648 .47828 Mtetra
.307 .41 .804 r
.19648 .47828 .20258 .49093 .21217 .48965 .20549 .4829 Mtetra
.6 .712 .922 r
.20549 .4829 .21217 .48965 .22187 .48763 .21521 .48088 Mtetra
.569 .702 .931 r
.21521 .48088 .22187 .48763 .23113 .49102 .22491 .47946 Mtetra
.779 .667 .74 r
.22491 .47946 .23113 .49102 .24188 .47802 .2356 .46743 Mtetra
.411 .517 .855 r
.2356 .46743 .24188 .47802 .25166 .47641 .24506 .46967 Mtetra
.61 .718 .922 r
.24506 .46967 .25166 .47641 .26155 .47407 .25496 .46741 Mtetra
.604 .719 .926 r
.25496 .46741 .26155 .47407 .27138 .47298 .26489 .46525 Mtetra
.776 .315 0 r
.26489 .46525 .27138 .47298 .28196 .46252 .27354 .48051 Mtetra
0 0 0 r
.27354 .48051 .28196 .46252 .29179 .46252 .28529 .45545 Mtetra
.601 .706 .918 r
.28529 .45545 .29179 .46252 .30185 .46 .29534 .45338 Mtetra
.626 .73 .922 r
.29534 .45338 .30185 .46 .31196 .45737 .30547 .45069 Mtetra
.614 .725 .925 r
.30547 .45069 .31196 .45737 .32205 .45582 .31563 .44825 Mtetra
0 .328 .81 r
.31563 .44825 .32205 .45582 .33276 .44452 .32532 .45427 Mtetra
.669 .866 .477 r
.32532 .45427 .33276 .44452 .34278 .44531 .33639 .43806 Mtetra
.601 .704 .916 r
.33639 .43806 .34278 .44531 .35306 .44262 .34666 .43594 Mtetra
.635 .735 .921 r
.34666 .43594 .35306 .44262 .36339 .4396 .35701 .433 Mtetra
.64 .74 .921 r
.35701 .433 .36339 .4396 .37377 .43654 .36741 .4299 Mtetra
.637 .739 .922 r
.36741 .4299 .37377 .43654 .38419 .43368 .37786 .42686 Mtetra
.613 .726 .925 r
.37786 .42686 .38419 .43368 .39457 .43272 .38832 .42437 Mtetra
.95 .707 .534 r
.38832 .42437 .39457 .43272 .40536 .42206 .4033 .30701 Mtetra
0 0 .347 r
.4033 .30701 .40536 .42206 .41583 .42096 .40959 .41381 Mtetra
.619 .719 .917 r
.40959 .41381 .41583 .42096 .42642 .41792 .42019 .41118 Mtetra
.644 .741 .92 r
.42019 .41118 .42642 .41792 .43706 .41457 .43085 .40791 Mtetra
.651 .747 .92 r
.43085 .40791 .43706 .41457 .44774 .41109 .44155 .40445 Mtetra
.654 .75 .92 r
.44155 .40445 .44774 .41109 .45847 .40752 .45231 .40089 Mtetra
.656 .752 .92 r
.45231 .40089 .45847 .40752 .46924 .40389 .46311 .39725 Mtetra
.658 .753 .92 r
.46311 .39725 .46924 .40389 .48005 .40022 .47395 .39357 Mtetra
.659 .754 .92 r
.47395 .39357 .48005 .40022 .49091 .39652 .48483 .38985 Mtetra
.48483 .38985 .49091 .39652 .50181 .39281 .49576 .38611 Mtetra
.49576 .38611 .50181 .39281 .51275 .38908 .50673 .38235 Mtetra
.50673 .38235 .51275 .38908 .52374 .38535 .51775 .37859 Mtetra
.658 .753 .92 r
.51775 .37859 .52374 .38535 .53477 .3816 .52881 .37481 Mtetra
.52881 .37481 .53477 .3816 .54584 .37785 .53991 .37103 Mtetra
.53991 .37103 .54584 .37785 .55696 .37409 .55106 .36724 Mtetra
.55106 .36724 .55696 .37409 .56812 .37032 .56225 .36344 Mtetra
.56225 .36344 .56812 .37032 .57933 .36654 .57349 .35962 Mtetra
.57349 .35962 .57933 .36654 .59058 .36274 .58477 .3558 Mtetra
.58477 .3558 .59058 .36274 .60188 .35893 .5961 .35196 Mtetra
.657 .753 .92 r
.5961 .35196 .60188 .35893 .61322 .35511 .60748 .3481 Mtetra
.60748 .3481 .61322 .35511 .62461 .35127 .6189 .34424 Mtetra
.6189 .34424 .62461 .35127 .63605 .34742 .63036 .34036 Mtetra
.657 .752 .92 r
.63036 .34036 .63605 .34742 .64753 .34355 .64188 .33646 Mtetra
.64188 .33646 .64753 .34355 .65906 .33967 .65344 .33255 Mtetra
.65344 .33255 .65906 .33967 .67064 .33577 .66505 .32862 Mtetra
.66505 .32862 .67064 .33577 .68226 .33186 .67671 .32468 Mtetra
.67671 .32468 .68226 .33186 .69393 .32794 .68841 .32073 Mtetra
.68841 .32073 .69393 .32794 .70565 .324 .70016 .31676 Mtetra
.70016 .31676 .70565 .324 .71742 .32004 .71197 .31277 Mtetra
.71197 .31277 .71742 .32004 .72924 .31607 .72382 .30876 Mtetra
.72382 .30876 .72924 .31607 .7411 .31208 .73572 .30475 Mtetra
.73572 .30475 .7411 .31208 .75302 .30807 .74767 .30071 Mtetra
.74767 .30071 .75302 .30807 .76498 .30405 .75967 .29666 Mtetra
.75967 .29666 .76498 .30405 .777 .30002 .77172 .29259 Mtetra
.77172 .29259 .777 .30002 .78906 .29597 .78382 .28851 Mtetra
.78382 .28851 .78906 .29597 .80118 .2919 .79597 .28441 Mtetra
.79597 .28441 .80118 .2919 .81334 .28781 .80817 .28029 Mtetra
.443 .561 .879 r
.16012 .48568 .1666 .49518 .1761 .49372 .16933 .487 Mtetra
.592 .709 .925 r
.16933 .487 .1761 .49372 .18564 .49229 .17892 .48514 Mtetra
.345 .588 .934 r
.17892 .48514 .18564 .49229 .19648 .47828 .1882 .48688 Mtetra
.539 .834 .505 r
.1882 .48688 .19648 .47828 .20549 .4829 .19883 .47552 Mtetra
.568 .681 .916 r
.19883 .47552 .20549 .4829 .21521 .48088 .2085 .47419 Mtetra
.601 .716 .925 r
.2085 .47419 .21521 .48088 .22491 .47946 .21828 .47212 Mtetra
.193 .497 .905 r
.21828 .47212 .22491 .47946 .2356 .46743 .22761 .47548 Mtetra
.678 .91 .577 r
.22761 .47548 .2356 .46743 .24506 .46967 .23846 .46239 Mtetra
.583 .692 .917 r
.23846 .46239 .24506 .46967 .25496 .46741 .24832 .46072 Mtetra
.614 .723 .923 r
.24832 .46072 .25496 .46741 .26489 .46525 .25829 .45832 Mtetra
.551 .693 .934 r
.25829 .45832 .26489 .46525 .27354 .48051 .2682 .45718 Mtetra
.688 .536 .675 r
.2682 .45718 .27354 .48051 .28529 .45545 .27888 .44663 Mtetra
.512 .618 .894 r
.27888 .44663 .28529 .45545 .29534 .45338 .28879 .44659 Mtetra
.62 .725 .921 r
.28879 .44659 .29534 .45338 .30547 .45069 .29893 .44401 Mtetra
.625 .73 .923 r
.29893 .44401 .30547 .45069 .31563 .44825 .30913 .44132 Mtetra
.573 .704 .931 r
.30913 .44132 .31563 .44825 .32532 .45427 .3193 .43972 Mtetra
.749 .628 .725 r
.3193 .43972 .32532 .45427 .33639 .43806 .33011 .42831 Mtetra
.48 .58 .878 r
.33011 .42831 .33639 .43806 .34666 .43594 .34022 .42906 Mtetra
.625 .727 .92 r
.34022 .42906 .34666 .43594 .35701 .433 .35058 .42631 Mtetra
.639 .739 .921 r
.35058 .42631 .35701 .433 .36741 .4299 .36101 .42323 Mtetra
.64 .74 .921 r
.36101 .42323 .36741 .4299 .37786 .42686 .37148 .4201 Mtetra
.631 .735 .923 r
.37148 .4201 .37786 .42686 .38832 .42437 .38198 .41718 Mtetra
.541 .687 .934 r
.38198 .41718 .38832 .42437 .4033 .30701 .39245 .41618 Mtetra
.482 .238 .468 r
.39245 .41618 .4033 .30701 .40959 .41381 .40335 .40541 Mtetra
.559 .658 .902 r
.40335 .40541 .40959 .41381 .42019 .41118 .41391 .40426 Mtetra
.636 .735 .919 r
.41391 .40426 .42019 .41118 .43085 .40791 .42459 .40116 Mtetra
.648 .745 .92 r
.42459 .40116 .43085 .40791 .44155 .40445 .43532 .39774 Mtetra
.653 .749 .92 r
.43532 .39774 .44155 .40445 .45231 .40089 .4461 .39419 Mtetra
.655 .751 .92 r
.4461 .39419 .45231 .40089 .46311 .39725 .45693 .39056 Mtetra
.657 .752 .92 r
.45693 .39056 .46311 .39725 .47395 .39357 .4678 .38686 Mtetra
.658 .753 .92 r
.4678 .38686 .47395 .39357 .48483 .38985 .47871 .38312 Mtetra
.659 .754 .92 r
.47871 .38312 .48483 .38985 .49576 .38611 .48967 .37936 Mtetra
.48967 .37936 .49576 .38611 .50673 .38235 .50067 .37557 Mtetra
.50067 .37557 .50673 .38235 .51775 .37859 .51171 .37178 Mtetra
.51171 .37178 .51775 .37859 .52881 .37481 .5228 .36797 Mtetra
.658 .753 .92 r
.5228 .36797 .52881 .37481 .53991 .37103 .53394 .36416 Mtetra
.53394 .36416 .53991 .37103 .55106 .36724 .54511 .36034 Mtetra
.54511 .36034 .55106 .36724 .56225 .36344 .55634 .3565 Mtetra
.55634 .3565 .56225 .36344 .57349 .35962 .5676 .35266 Mtetra
.5676 .35266 .57349 .35962 .58477 .3558 .57892 .3488 Mtetra
.57892 .3488 .58477 .3558 .5961 .35196 .59028 .34493 Mtetra
.657 .753 .92 r
.59028 .34493 .5961 .35196 .60748 .3481 .60168 .34105 Mtetra
.60168 .34105 .60748 .3481 .6189 .34424 .61314 .33715 Mtetra
.61314 .33715 .6189 .34424 .63036 .34036 .62463 .33324 Mtetra
.62463 .33324 .63036 .34036 .64188 .33646 .63618 .32932 Mtetra
.657 .752 .92 r
.63618 .32932 .64188 .33646 .65344 .33255 .64777 .32538 Mtetra
.64777 .32538 .65344 .33255 .66505 .32862 .65942 .32142 Mtetra
.65942 .32142 .66505 .32862 .67671 .32468 .67111 .31745 Mtetra
.67111 .31745 .67671 .32468 .68841 .32073 .68284 .31346 Mtetra
.68284 .31346 .68841 .32073 .70016 .31676 .69463 .30946 Mtetra
.69463 .30946 .70016 .31676 .71197 .31277 .70647 .30544 Mtetra
.70647 .30544 .71197 .31277 .72382 .30876 .71835 .30141 Mtetra
.71835 .30141 .72382 .30876 .73572 .30475 .73029 .29736 Mtetra
.73029 .29736 .73572 .30475 .74767 .30071 .74227 .29329 Mtetra
.74227 .29329 .74767 .30071 .75967 .29666 .75431 .28921 Mtetra
.75431 .28921 .75967 .29666 .77172 .29259 .76639 .28511 Mtetra
.76639 .28511 .77172 .29259 .78382 .28851 .77853 .28099 Mtetra
.77853 .28099 .78382 .28851 .79597 .28441 .79072 .27686 Mtetra
.79072 .27686 .79597 .28441 .80817 .28029 .80296 .27271 Mtetra
.758 .934 .587 r
.15146 .49521 .16012 .48568 .16933 .487 .16255 .47985 Mtetra
.576 .691 .92 r
.16255 .47985 .16933 .487 .17892 .48514 .17212 .47834 Mtetra
.571 .702 .93 r
.17212 .47834 .17892 .48514 .1882 .48688 .18173 .47686 Mtetra
.81 .695 .737 r
.18173 .47686 .1882 .48688 .19883 .47552 .19267 .46274 Mtetra
.305 .409 .804 r
.19267 .46274 .19883 .47552 .2085 .47419 .20175 .46734 Mtetra
.6 .712 .922 r
.20175 .46734 .2085 .47419 .21828 .47212 .21155 .46526 Mtetra
.569 .702 .931 r
.21155 .46526 .21828 .47212 .22761 .47548 .22133 .46379 Mtetra
.779 .667 .74 r
.22133 .46379 .22761 .47548 .23846 .46239 .23211 .45166 Mtetra
.411 .517 .856 r
.23211 .45166 .23846 .46239 .24832 .46072 .24165 .45387 Mtetra
.61 .718 .922 r
.24165 .45387 .24832 .46072 .25829 .45832 .25163 .45155 Mtetra
.604 .719 .926 r
.25163 .45155 .25829 .45832 .2682 .45718 .26164 .44933 Mtetra
.77 .31 0 r
.26164 .44933 .2682 .45718 .27888 .44663 .27035 .46461 Mtetra
.648 .774 .308 r
.27035 .46461 .27888 .44663 .28879 .44659 .28222 .4394 Mtetra
.601 .706 .918 r
.28222 .4394 .28879 .44659 .29893 .44401 .29235 .43727 Mtetra
.626 .73 .922 r
.29235 .43727 .29893 .44401 .30913 .44132 .30257 .43452 Mtetra
.614 .725 .925 r
.30257 .43452 .30913 .44132 .3193 .43972 .31282 .43203 Mtetra
0 .331 .812 r
.31282 .43203 .3193 .43972 .33011 .42831 .32258 .43802 Mtetra
.678 .872 .486 r
.32258 .43802 .33011 .42831 .34022 .42906 .33376 .42169 Mtetra
.601 .704 .916 r
.33376 .42169 .34022 .42906 .35058 .42631 .34411 .41952 Mtetra
.635 .735 .921 r
.34411 .41952 .35058 .42631 .36101 .42323 .35456 .41651 Mtetra
.64 .74 .921 r
.35456 .41651 .36101 .42323 .37148 .4201 .36505 .41335 Mtetra
.637 .739 .922 r
.36505 .41335 .37148 .4201 .38198 .41718 .37559 .41024 Mtetra
.613 .725 .925 r
.37559 .41024 .38198 .41718 .39245 .41618 .38614 .40769 Mtetra
.951 .707 .532 r
.38614 .40769 .39245 .41618 .40335 .40541 .40133 .28984 Mtetra
0 0 .342 r
.40133 .28984 .40335 .40541 .41391 .40426 .4076 .39698 Mtetra
.619 .719 .917 r
.4076 .39698 .41391 .40426 .42459 .40116 .41829 .39429 Mtetra
.644 .741 .92 r
.41829 .39429 .42459 .40116 .43532 .39774 .42905 .39096 Mtetra
.651 .747 .92 r
.42905 .39096 .43532 .39774 .4461 .39419 .43986 .38743 Mtetra
.654 .75 .92 r
.43986 .38743 .4461 .39419 .45693 .39056 .45071 .3838 Mtetra
.656 .752 .92 r
.45071 .3838 .45693 .39056 .4678 .38686 .4616 .3801 Mtetra
.658 .753 .92 r
.4616 .3801 .4678 .38686 .47871 .38312 .47255 .37634 Mtetra
.659 .754 .92 r
.47255 .37634 .47871 .38312 .48967 .37936 .48353 .37255 Mtetra
.48353 .37255 .48967 .37936 .50067 .37557 .49456 .36874 Mtetra
.49456 .36874 .50067 .37557 .51171 .37178 .50563 .36492 Mtetra
.50563 .36492 .51171 .37178 .5228 .36797 .51675 .36108 Mtetra
.658 .753 .92 r
.51675 .36108 .5228 .36797 .53394 .36416 .52791 .35724 Mtetra
.52791 .35724 .53394 .36416 .54511 .36034 .53912 .35338 Mtetra
.53912 .35338 .54511 .36034 .55634 .3565 .55037 .34952 Mtetra
.55037 .34952 .55634 .3565 .5676 .35266 .56167 .34565 Mtetra
.56167 .34565 .5676 .35266 .57892 .3488 .57302 .34176 Mtetra
.57302 .34176 .57892 .3488 .59028 .34493 .58441 .33786 Mtetra
.58441 .33786 .59028 .34493 .60168 .34105 .59585 .33395 Mtetra
.657 .753 .92 r
.59585 .33395 .60168 .34105 .61314 .33715 .60733 .33002 Mtetra
.60733 .33002 .61314 .33715 .62463 .33324 .61886 .32608 Mtetra
.61886 .32608 .62463 .33324 .63618 .32932 .63044 .32212 Mtetra
.657 .752 .92 r
.63044 .32212 .63618 .32932 .64777 .32538 .64207 .31815 Mtetra
.64207 .31815 .64777 .32538 .65942 .32142 .65374 .31416 Mtetra
.65374 .31416 .65942 .32142 .67111 .31745 .66546 .31016 Mtetra
.66546 .31016 .67111 .31745 .68284 .31346 .67724 .30614 Mtetra
.67724 .30614 .68284 .31346 .69463 .30946 .68906 .30211 Mtetra
.68906 .30211 .69463 .30946 .70647 .30544 .70093 .29806 Mtetra
.70093 .29806 .70647 .30544 .71835 .30141 .71285 .29399 Mtetra
.71285 .29399 .71835 .30141 .73029 .29736 .72482 .28991 Mtetra
.72482 .28991 .73029 .29736 .74227 .29329 .73684 .28581 Mtetra
.73684 .28581 .74227 .29329 .75431 .28921 .74891 .2817 Mtetra
.74891 .2817 .75431 .28921 .76639 .28511 .76103 .27757 Mtetra
.76103 .27757 .76639 .28511 .77853 .28099 .7732 .27342 Mtetra
.7732 .27342 .77853 .28099 .79072 .27686 .78543 .26925 Mtetra
.78543 .26925 .79072 .27686 .80296 .27271 .7977 .26507 Mtetra
.746 .626 .727 r
.14538 .48113 .15146 .49521 .16255 .47985 .15599 .47022 Mtetra
.443 .561 .879 r
.15599 .47022 .16255 .47985 .17212 .47834 .16527 .4715 Mtetra
.592 .709 .925 r
.16527 .4715 .17212 .47834 .18173 .47686 .17494 .46959 Mtetra
.347 .588 .934 r
.17494 .46959 .18173 .47686 .19267 .46274 .18429 .47129 Mtetra
.551 .844 .518 r
.18429 .47129 .19267 .46274 .20175 .46734 .19502 .45984 Mtetra
.568 .681 .916 r
.19502 .45984 .20175 .46734 .21155 .46526 .20476 .45846 Mtetra
.601 .716 .925 r
.20476 .45846 .21155 .46526 .22133 .46379 .21462 .45633 Mtetra
.196 .498 .906 r
.21462 .45633 .22133 .46379 .23211 .45166 .22402 .45967 Mtetra
.687 .917 .587 r
.22402 .45967 .23211 .45166 .24165 .45387 .23497 .44647 Mtetra
.583 .692 .917 r
.23497 .44647 .24165 .45387 .25163 .45155 .24492 .44475 Mtetra
.614 .723 .923 r
.24492 .44475 .25163 .45155 .26164 .44933 .25497 .44229 Mtetra
.551 .693 .933 r
.25497 .44229 .26164 .44933 .27035 .46461 .26496 .4411 Mtetra
.687 .536 .675 r
.26496 .4411 .27035 .46461 .28222 .4394 .27574 .43046 Mtetra
.511 .618 .894 r
.27574 .43046 .28222 .4394 .29235 .43727 .28573 .43036 Mtetra
.62 .725 .921 r
.28573 .43036 .29235 .43727 .30257 .43452 .29596 .42772 Mtetra
.625 .73 .923 r
.29596 .42772 .30257 .43452 .31282 .43203 .30624 .42497 Mtetra
.573 .704 .931 r
.30624 .42497 .31282 .43203 .32258 .43802 .3165 .42331 Mtetra
.75 .628 .725 r
.3165 .42331 .32258 .43802 .33376 .42169 .32741 .41181 Mtetra
.48 .58 .878 r
.32741 .41181 .33376 .42169 .34411 .41952 .33761 .41251 Mtetra
.625 .727 .92 r
.33761 .41251 .34411 .41952 .35456 .41651 .34806 .4097 Mtetra
.639 .739 .921 r
.34806 .4097 .35456 .41651 .36505 .41335 .35858 .40656 Mtetra
.64 .74 .921 r
.35858 .40656 .36505 .41335 .37559 .41024 .36914 .40337 Mtetra
.631 .735 .923 r
.36914 .40337 .37559 .41024 .38614 .40769 .37974 .40038 Mtetra
.541 .687 .934 r
.37974 .40038 .38614 .40769 .40133 .28984 .3903 .39932 Mtetra
.478 .233 .464 r
.3903 .39932 .40133 .28984 .4076 .39698 .4013 .38846 Mtetra
.559 .658 .903 r
.4013 .38846 .4076 .39698 .41829 .39429 .41195 .38725 Mtetra
.636 .735 .919 r
.41195 .38725 .41829 .39429 .42905 .39096 .42273 .38408 Mtetra
.648 .745 .92 r
.42273 .38408 .42905 .39096 .43986 .38743 .43356 .3806 Mtetra
.653 .749 .92 r
.43356 .3806 .43986 .38743 .45071 .3838 .44444 .37698 Mtetra
.655 .751 .92 r
.44444 .37698 .45071 .3838 .4616 .3801 .45536 .37327 Mtetra
.657 .752 .92 r
.45536 .37327 .4616 .3801 .47255 .37634 .46633 .36951 Mtetra
.658 .753 .92 r
.46633 .36951 .47255 .37634 .48353 .37255 .47735 .3657 Mtetra
.659 .754 .92 r
.47735 .3657 .48353 .37255 .49456 .36874 .48841 .36186 Mtetra
.48841 .36186 .49456 .36874 .50563 .36492 .49951 .35801 Mtetra
.49951 .35801 .50563 .36492 .51675 .36108 .51066 .35414 Mtetra
.51066 .35414 .51675 .36108 .52791 .35724 .52185 .35026 Mtetra
.658 .753 .92 r
.52185 .35026 .52791 .35724 .53912 .35338 .53309 .34638 Mtetra
.53309 .34638 .53912 .35338 .55037 .34952 .54437 .34248 Mtetra
.54437 .34248 .55037 .34952 .56167 .34565 .5557 .33858 Mtetra
.5557 .33858 .56167 .34565 .57302 .34176 .56707 .33466 Mtetra
.56707 .33466 .57302 .34176 .58441 .33786 .5785 .33073 Mtetra
.5785 .33073 .58441 .33786 .59585 .33395 .58996 .32679 Mtetra
.657 .753 .92 r
.58996 .32679 .59585 .33395 .60733 .33002 .60148 .32283 Mtetra
.60148 .32283 .60733 .33002 .61886 .32608 .61304 .31885 Mtetra
.61304 .31885 .61886 .32608 .63044 .32212 .62465 .31487 Mtetra
.62465 .31487 .63044 .32212 .64207 .31815 .63631 .31086 Mtetra
.657 .752 .92 r
.63631 .31086 .64207 .31815 .65374 .31416 .64802 .30685 Mtetra
.64802 .30685 .65374 .31416 .66546 .31016 .65978 .30281 Mtetra
.65978 .30281 .66546 .31016 .67724 .30614 .67158 .29876 Mtetra
.67158 .29876 .67724 .30614 .68906 .30211 .68344 .2947 Mtetra
.68344 .2947 .68906 .30211 .70093 .29806 .69534 .29062 Mtetra
.69534 .29062 .70093 .29806 .71285 .29399 .7073 .28652 Mtetra
.7073 .28652 .71285 .29399 .72482 .28991 .7193 .28241 Mtetra
.7193 .28241 .72482 .28991 .73684 .28581 .73136 .27828 Mtetra
.73136 .27828 .73684 .28581 .74891 .2817 .74346 .27413 Mtetra
.74346 .27413 .74891 .2817 .76103 .27757 .75562 .26997 Mtetra
.75562 .26997 .76103 .27757 .7732 .27342 .76783 .26578 Mtetra
.76783 .26578 .7732 .27342 .78543 .26925 .78009 .26159 Mtetra
.78009 .26159 .78543 .26925 .7977 .26507 .79241 .25737 Mtetra
0 .25 .75 r
.13853 .47358 .14538 .48113 .15599 .47022 .14722 .47971 Mtetra
.765 .938 .594 r
.14722 .47971 .15599 .47022 .16527 .4715 .15841 .46424 Mtetra
.576 .691 .92 r
.15841 .46424 .16527 .4715 .17494 .46959 .16806 .46268 Mtetra
.571 .702 .93 r
.16806 .46268 .17494 .46959 .18429 .47129 .17776 .46115 Mtetra
.811 .696 .737 r
.17776 .46115 .18429 .47129 .19502 .45984 .1888 .44692 Mtetra
.303 .408 .804 r
.1888 .44692 .19502 .45984 .20476 .45846 .19794 .45149 Mtetra
.6 .712 .922 r
.19794 .45149 .20476 .45846 .21462 .45633 .20782 .44936 Mtetra
.569 .701 .931 r
.20782 .44936 .21462 .45633 .22402 .45967 .21768 .44783 Mtetra
.779 .668 .74 r
.21768 .44783 .22402 .45967 .23497 .44647 .22857 .43561 Mtetra
.41 .517 .856 r
.22857 .43561 .23497 .44647 .24492 .44475 .23817 .43777 Mtetra
.61 .718 .922 r
.23817 .43777 .24492 .44475 .25497 .44229 .24823 .4354 Mtetra
.604 .719 .926 r
.24823 .4354 .25497 .44229 .26496 .4411 .25833 .43312 Mtetra
.765 .304 0 r
.25833 .43312 .26496 .4411 .27574 .43046 .26709 .44842 Mtetra
.657 .782 .317 r
.26709 .44842 .27574 .43046 .28573 .43036 .27909 .42305 Mtetra
.601 .706 .918 r
.27909 .42305 .28573 .43036 .29596 .42772 .28931 .42086 Mtetra
.626 .73 .922 r
.28931 .42086 .29596 .42772 .30624 .42497 .29961 .41805 Mtetra
.614 .725 .925 r
.29961 .41805 .30624 .42497 .3165 .42331 .30995 .4155 Mtetra
0 .334 .815 r
.30995 .4155 .3165 .42331 .32741 .41181 .31979 .42147 Mtetra
.687 .879 .495 r
.31979 .42147 .32741 .41181 .33761 .41251 .33108 .40502 Mtetra
.601 .704 .916 r
.33108 .40502 .33761 .41251 .34806 .4097 .34152 .40278 Mtetra
.635 .735 .921 r
.34152 .40278 .34806 .4097 .35858 .40656 .35206 .39971 Mtetra
.64 .74 .921 r
.35206 .39971 .35858 .40656 .36914 .40337 .36265 .39649 Mtetra
.637 .739 .922 r
.36265 .39649 .36914 .40337 .37974 .40038 .37327 .39332 Mtetra
.613 .725 .925 r
.37327 .39332 .37974 .40038 .3903 .39932 .38392 .3907 Mtetra
.953 .708 .53 r
.38392 .3907 .3903 .39932 .4013 .38846 .39932 .27235 Mtetra
0 0 .337 r
.39932 .27235 .4013 .38846 .41195 .38725 .40558 .37984 Mtetra
.619 .719 .917 r
.40558 .37984 .41195 .38725 .42273 .38408 .41637 .37708 Mtetra
.644 .741 .92 r
.41637 .37708 .42273 .38408 .43356 .3806 .42722 .37368 Mtetra
.651 .747 .92 r
.42722 .37368 .43356 .3806 .44444 .37698 .43812 .37009 Mtetra
.654 .75 .92 r
.43812 .37009 .44444 .37698 .45536 .37327 .44908 .36639 Mtetra
.656 .752 .92 r
.44908 .36639 .45536 .37327 .46633 .36951 .46007 .36262 Mtetra
.658 .753 .92 r
.46007 .36262 .46633 .36951 .47735 .3657 .47112 .35879 Mtetra
.659 .754 .92 r
.47112 .35879 .47735 .3657 .48841 .36186 .4822 .35493 Mtetra
.4822 .35493 .48841 .36186 .49951 .35801 .49334 .35105 Mtetra
.49334 .35105 .49951 .35801 .51066 .35414 .50451 .34715 Mtetra
.50451 .34715 .51066 .35414 .52185 .35026 .51574 .34324 Mtetra
.658 .753 .92 r
.51574 .34324 .52185 .35026 .53309 .34638 .527 .33932 Mtetra
.527 .33932 .53309 .34638 .54437 .34248 .53832 .33539 Mtetra
.53832 .33539 .54437 .34248 .5557 .33858 .54968 .33146 Mtetra
.54968 .33146 .5557 .33858 .56707 .33466 .56108 .32751 Mtetra
.56108 .32751 .56707 .33466 .5785 .33073 .57254 .32355 Mtetra
.57254 .32355 .5785 .33073 .58996 .32679 .58404 .31957 Mtetra
.58404 .31957 .58996 .32679 .60148 .32283 .59559 .31558 Mtetra
.657 .753 .92 r
.59559 .31558 .60148 .32283 .61304 .31885 .60718 .31158 Mtetra
.60718 .31158 .61304 .31885 .62465 .31487 .61882 .30756 Mtetra
.61882 .30756 .62465 .31487 .63631 .31086 .63052 .30353 Mtetra
.657 .752 .92 r
.63052 .30353 .63631 .31086 .64802 .30685 .64226 .29948 Mtetra
.64226 .29948 .64802 .30685 .65978 .30281 .65405 .29541 Mtetra
.65405 .29541 .65978 .30281 .67158 .29876 .66589 .29133 Mtetra
.66589 .29133 .67158 .29876 .68344 .2947 .67778 .28723 Mtetra
.67778 .28723 .68344 .2947 .69534 .29062 .68972 .28312 Mtetra
.68972 .28312 .69534 .29062 .7073 .28652 .70171 .27899 Mtetra
.70171 .27899 .7073 .28652 .7193 .28241 .71375 .27484 Mtetra
.71375 .27484 .7193 .28241 .73136 .27828 .72584 .27068 Mtetra
.72584 .27068 .73136 .27828 .74346 .27413 .73798 .2665 Mtetra
.73798 .2665 .74346 .27413 .75562 .26997 .75017 .2623 Mtetra
.75017 .2623 .75562 .26997 .76783 .26578 .76242 .25809 Mtetra
.76242 .25809 .76783 .26578 .78009 .26159 .77472 .25386 Mtetra
.77472 .25386 .78009 .26159 .79241 .25737 .78707 .24961 Mtetra
.547 .69 .933 r
.13155 .46658 .13853 .47358 .14722 .47971 .14109 .46549 Mtetra
.746 .627 .727 r
.14109 .46549 .14722 .47971 .15841 .46424 .15179 .45449 Mtetra
.442 .56 .879 r
.15179 .45449 .15841 .46424 .16806 .46268 .16114 .45573 Mtetra
.592 .709 .925 r
.16114 .45573 .16806 .46268 .17776 .46115 .17089 .45376 Mtetra
.348 .588 .934 r
.17089 .45376 .17776 .46115 .1888 .44692 .18031 .45542 Mtetra
.564 .854 .531 r
.18031 .45542 .1888 .44692 .19794 .45149 .19114 .44388 Mtetra
.568 .681 .916 r
.19114 .44388 .19794 .45149 .20782 .44936 .20096 .44244 Mtetra
.601 .716 .925 r
.20096 .44244 .20782 .44936 .21768 .44783 .2109 .44026 Mtetra
.199 .5 .906 r
.2109 .44026 .21768 .44783 .22857 .43561 .22037 .44356 Mtetra
.695 .922 .596 r
.22037 .44356 .22857 .43561 .23817 .43777 .23142 .43025 Mtetra
.583 .692 .917 r
.23142 .43025 .23817 .43777 .24823 .4354 .24145 .42848 Mtetra
.614 .723 .923 r
.24145 .42848 .24823 .4354 .25833 .43312 .25159 .42596 Mtetra
.551 .693 .933 r
.25159 .42596 .25833 .43312 .26709 .44842 .26167 .42472 Mtetra
.687 .535 .675 r
.26167 .42472 .26709 .44842 .27909 .42305 .27254 .41398 Mtetra
.511 .618 .894 r
.27254 .41398 .27909 .42305 .28931 .42086 .28261 .41383 Mtetra
.62 .725 .921 r
.28261 .41383 .28931 .42086 .29961 .41805 .29293 .41114 Mtetra
.625 .73 .923 r
.29293 .41114 .29961 .41805 .30995 .4155 .30331 .40832 Mtetra
.573 .704 .931 r
.30331 .40832 .30995 .4155 .31979 .42147 .31365 .4066 Mtetra
.75 .629 .726 r
.31365 .4066 .31979 .42147 .33108 .40502 .32467 .39501 Mtetra
.479 .58 .878 r
.32467 .39501 .33108 .40502 .34152 .40278 .33495 .39566 Mtetra
.625 .727 .92 r
.33495 .39566 .34152 .40278 .35206 .39971 .34549 .39278 Mtetra
.639 .739 .921 r
.34549 .39278 .35206 .39971 .36265 .39649 .3561 .38957 Mtetra
.64 .74 .921 r
.3561 .38957 .36265 .39649 .37327 .39332 .36676 .38631 Mtetra
.631 .735 .923 r
.36676 .38631 .37327 .39332 .38392 .3907 .37745 .38326 Mtetra
.541 .687 .934 r
.37745 .38326 .38392 .3907 .39932 .27235 .38811 .38214 Mtetra
.473 .227 .46 r
.38811 .38214 .39932 .27235 .40558 .37984 .39921 .37118 Mtetra
.558 .658 .903 r
.39921 .37118 .40558 .37984 .41637 .37708 .40996 .36991 Mtetra
.636 .735 .919 r
.40996 .36991 .41637 .37708 .42722 .37368 .42083 .36668 Mtetra
.648 .745 .92 r
.42083 .36668 .42722 .37368 .43812 .37009 .43176 .36312 Mtetra
.653 .749 .92 r
.43176 .36312 .43812 .37009 .44908 .36639 .44274 .35943 Mtetra
.655 .751 .92 r
.44274 .35943 .44908 .36639 .46007 .36262 .45377 .35566 Mtetra
.657 .752 .92 r
.45377 .35566 .46007 .36262 .47112 .35879 .46484 .35182 Mtetra
.658 .753 .92 r
.46484 .35182 .47112 .35879 .4822 .35493 .47595 .34794 Mtetra
.659 .754 .92 r
.47595 .34794 .4822 .35493 .49334 .35105 .48712 .34403 Mtetra
.48712 .34403 .49334 .35105 .50451 .34715 .49832 .3401 Mtetra
.49832 .3401 .50451 .34715 .51574 .34324 .50958 .33616 Mtetra
.50958 .33616 .51574 .34324 .527 .33932 .52087 .33221 Mtetra
.658 .753 .92 r
.52087 .33221 .527 .33932 .53832 .33539 .53222 .32825 Mtetra
.53222 .32825 .53832 .33539 .54968 .33146 .54361 .32428 Mtetra
.54361 .32428 .54968 .33146 .56108 .32751 .55505 .3203 Mtetra
.55505 .3203 .56108 .32751 .57254 .32355 .56653 .31631 Mtetra
.56653 .31631 .57254 .32355 .58404 .31957 .57806 .3123 Mtetra
.57806 .3123 .58404 .31957 .59559 .31558 .58964 .30828 Mtetra
.657 .753 .92 r
.58964 .30828 .59559 .31558 .60718 .31158 .60127 .30425 Mtetra
.60127 .30425 .60718 .31158 .61882 .30756 .61295 .3002 Mtetra
.61295 .3002 .61882 .30756 .63052 .30353 .62468 .29613 Mtetra
.62468 .29613 .63052 .30353 .64226 .29948 .63645 .29205 Mtetra
.657 .752 .92 r
.63645 .29205 .64226 .29948 .65405 .29541 .64827 .28795 Mtetra
.64827 .28795 .65405 .29541 .66589 .29133 .66015 .28384 Mtetra
.66015 .28384 .66589 .29133 .67778 .28723 .67207 .27971 Mtetra
.67207 .27971 .67778 .28723 .68972 .28312 .68404 .27556 Mtetra
.68404 .27556 .68972 .28312 .70171 .27899 .69607 .2714 Mtetra
.69607 .2714 .70171 .27899 .71375 .27484 .70814 .26722 Mtetra
.70814 .26722 .71375 .27484 .72584 .27068 .72027 .26303 Mtetra
.72027 .26303 .72584 .27068 .73798 .2665 .73245 .25881 Mtetra
.73245 .25881 .73798 .2665 .75017 .2623 .74468 .25458 Mtetra
.74468 .25458 .75017 .2623 .76242 .25809 .75696 .25033 Mtetra
.75696 .25033 .76242 .25809 .77472 .25386 .7693 .24607 Mtetra
.7693 .24607 .77472 .25386 .78707 .24961 .78169 .24179 Mtetra
.581 .703 .926 r
.12453 .45956 .13155 .46658 .14109 .46549 .13415 .45782 Mtetra
0 .254 .753 r
.13415 .45782 .14109 .46549 .15179 .45449 .1429 .46393 Mtetra
.771 .942 .602 r
.1429 .46393 .15179 .45449 .16114 .45573 .15421 .44835 Mtetra
.576 .691 .92 r
.15421 .44835 .16114 .45573 .17089 .45376 .16393 .44673 Mtetra
.571 .702 .93 r
.16393 .44673 .17089 .45376 .18031 .45542 .1737 .44515 Mtetra
.812 .696 .738 r
.1737 .44515 .18031 .45542 .19114 .44388 .18485 .43082 Mtetra
.301 .407 .804 r
.18485 .43082 .19114 .44388 .20096 .44244 .19406 .43536 Mtetra
.6 .712 .922 r
.19406 .43536 .20096 .44244 .2109 .44026 .20402 .43317 Mtetra
.569 .701 .931 r
.20402 .43317 .2109 .44026 .22037 .44356 .21396 .43158 Mtetra
.78 .668 .74 r
.21396 .43158 .22037 .44356 .23142 .43025 .22495 .41926 Mtetra
.409 .516 .856 r
.22495 .41926 .23142 .43025 .24145 .42848 .23463 .42139 Mtetra
.61 .718 .922 r
.23463 .42139 .24145 .42848 .25159 .42596 .24478 .41895 Mtetra
.604 .719 .926 r
.24478 .41895 .25159 .42596 .26167 .42472 .25496 .41662 Mtetra
.759 .298 0 r
.25496 .41662 .26167 .42472 .27254 .41398 .26378 .43193 Mtetra
.666 .789 .327 r
.26378 .43193 .27254 .41398 .28261 .41383 .2759 .4064 Mtetra
.6 .706 .918 r
.2759 .4064 .28261 .41383 .29293 .41114 .28621 .40415 Mtetra
.626 .73 .922 r
.28621 .40415 .29293 .41114 .30331 .40832 .2966 .40128 Mtetra
.614 .725 .925 r
.2966 .40128 .30331 .40832 .31365 .4066 .30703 .39866 Mtetra
0 .337 .817 r
.30703 .39866 .31365 .4066 .32467 .39501 .31695 .4046 Mtetra
.696 .885 .504 r
.31695 .4046 .32467 .39501 .33495 .39566 .32835 .38803 Mtetra
.6 .704 .916 r
.32835 .38803 .33495 .39566 .34549 .39278 .33888 .38574 Mtetra
.635 .735 .921 r
.33888 .38574 .34549 .39278 .3561 .38957 .34951 .3826 Mtetra
.64 .74 .921 r
.34951 .3826 .3561 .38957 .36676 .38631 .36019 .37931 Mtetra
.637 .739 .922 r
.36019 .37931 .36676 .38631 .37745 .38326 .37092 .37607 Mtetra
.614 .725 .925 r
.37092 .37607 .37745 .38326 .38811 .38214 .38166 .37339 Mtetra
.954 .708 .527 r
.38166 .37339 .38811 .38214 .39921 .37118 .39728 .25455 Mtetra
0 0 .331 r
.39728 .25455 .39921 .37118 .40996 .36991 .40352 .36238 Mtetra
.619 .719 .917 r
.40352 .36238 .40996 .36991 .42083 .36668 .4144 .35955 Mtetra
.644 .741 .92 r
.4144 .35955 .42083 .36668 .43176 .36312 .42536 .35608 Mtetra
.651 .747 .92 r
.42536 .35608 .43176 .36312 .44274 .35943 .43636 .35241 Mtetra
.654 .75 .92 r
.43636 .35241 .44274 .35943 .45377 .35566 .44741 .34864 Mtetra
.656 .752 .92 r
.44741 .34864 .45377 .35566 .46484 .35182 .45851 .3448 Mtetra
.658 .753 .92 r
.45851 .3448 .46484 .35182 .47595 .34794 .46966 .3409 Mtetra
.659 .754 .92 r
.46966 .3409 .47595 .34794 .48712 .34403 .48085 .33697 Mtetra
.48085 .33697 .48712 .34403 .49832 .3401 .49209 .33301 Mtetra
.49209 .33301 .49832 .3401 .50958 .33616 .50337 .32903 Mtetra
.50337 .32903 .50958 .33616 .52087 .33221 .5147 .32505 Mtetra
.658 .753 .92 r
.5147 .32505 .52087 .33221 .53222 .32825 .52607 .32106 Mtetra
.52607 .32106 .53222 .32825 .54361 .32428 .5375 .31705 Mtetra
.5375 .31705 .54361 .32428 .55505 .3203 .54897 .31304 Mtetra
.54897 .31304 .55505 .3203 .56653 .31631 .56048 .30902 Mtetra
.56048 .30902 .56653 .31631 .57806 .3123 .57205 .30498 Mtetra
.57205 .30498 .57806 .3123 .58964 .30828 .58366 .30092 Mtetra
.58366 .30092 .58964 .30828 .60127 .30425 .59532 .29686 Mtetra
.657 .753 .92 r
.59532 .29686 .60127 .30425 .61295 .3002 .60703 .29277 Mtetra
.60703 .29277 .61295 .3002 .62468 .29613 .61879 .28868 Mtetra
.61879 .28868 .62468 .29613 .63645 .29205 .6306 .28456 Mtetra
.657 .752 .92 r
.6306 .28456 .63645 .29205 .64827 .28795 .64245 .28043 Mtetra
.64245 .28043 .64827 .28795 .66015 .28384 .65436 .27629 Mtetra
.65436 .27629 .66015 .28384 .67207 .27971 .66632 .27213 Mtetra
.66632 .27213 .67207 .27971 .68404 .27556 .67833 .26795 Mtetra
.67833 .26795 .68404 .27556 .69607 .2714 .69039 .26375 Mtetra
.69039 .26375 .69607 .2714 .70814 .26722 .7025 .25954 Mtetra
.7025 .25954 .70814 .26722 .72027 .26303 .71466 .25531 Mtetra
.71466 .25531 .72027 .26303 .73245 .25881 .72688 .25106 Mtetra
.72688 .25106 .73245 .25881 .74468 .25458 .73914 .2468 Mtetra
.73914 .2468 .74468 .25458 .75696 .25033 .75146 .24252 Mtetra
.75146 .24252 .75696 .25033 .7693 .24607 .76384 .23822 Mtetra
.76384 .23822 .7693 .24607 .78169 .24179 .77626 .2339 Mtetra
.56 .679 .919 r
.11753 .452 .12453 .45956 .13415 .45782 .1271 .45071 Mtetra
.547 .69 .933 r
.1271 .45071 .13415 .45782 .1429 .46393 .13671 .44956 Mtetra
.746 .627 .727 r
.13671 .44956 .1429 .46393 .15421 .44835 .14752 .43847 Mtetra
.441 .56 .879 r
.14752 .43847 .15421 .44835 .16393 .44673 .15693 .43966 Mtetra
.592 .709 .925 r
.15693 .43966 .16393 .44673 .1737 .44515 .16676 .43764 Mtetra
.349 .589 .934 r
.16676 .43764 .1737 .44515 .18485 .43082 .17625 .43926 Mtetra
.576 .864 .543 r
.17625 .43926 .18485 .43082 .19406 .43536 .18718 .42762 Mtetra
.568 .681 .916 r
.18718 .42762 .19406 .43536 .20402 .43317 .19708 .42613 Mtetra
.601 .716 .925 r
.19708 .42613 .20402 .43317 .21396 .43158 .20711 .42389 Mtetra
.201 .501 .906 r
.20711 .42389 .21396 .43158 .22495 .41926 .21665 .42715 Mtetra
.704 .928 .604 r
.21665 .42715 .22495 .41926 .23463 .42139 .22781 .41374 Mtetra
.582 .692 .917 r
.22781 .41374 .23463 .42139 .24478 .41895 .23792 .41191 Mtetra
.614 .723 .923 r
.23792 .41191 .24478 .41895 .25496 .41662 .24814 .40933 Mtetra
.551 .693 .933 r
.24814 .40933 .25496 .41662 .26378 .43193 .25831 .40803 Mtetra
.687 .535 .674 r
.25831 .40803 .26378 .43193 .2759 .4064 .26928 .3972 Mtetra
.511 .618 .895 r
.26928 .3972 .2759 .4064 .28621 .40415 .27944 .397 Mtetra
.62 .725 .921 r
.27944 .397 .28621 .40415 .2966 .40128 .28985 .39424 Mtetra
.625 .73 .923 r
.28985 .39424 .2966 .40128 .30703 .39866 .30031 .39135 Mtetra
.573 .704 .931 r
.30031 .39135 .30703 .39866 .31695 .4046 .31075 .38958 Mtetra
.75 .629 .726 r
.31075 .38958 .31695 .4046 .32835 .38803 .32187 .37788 Mtetra
.479 .58 .878 r
.32187 .37788 .32835 .38803 .33888 .38574 .33224 .37848 Mtetra
.625 .727 .92 r
.33224 .37848 .33888 .38574 .34951 .3826 .34287 .37554 Mtetra
.639 .739 .921 r
.34287 .37554 .34951 .3826 .36019 .37931 .35358 .37226 Mtetra
.64 .74 .921 r
.35358 .37226 .36019 .37931 .37092 .37607 .36433 .36894 Mtetra
.631 .735 .923 r
.36433 .36894 .37092 .37607 .38166 .37339 .37512 .36582 Mtetra
.541 .687 .934 r
.37512 .36582 .38166 .37339 .39728 .25455 .38587 .36464 Mtetra
.469 .221 .455 r
.38587 .36464 .39728 .25455 .40352 .36238 .39708 .35358 Mtetra
.558 .658 .903 r
.39708 .35358 .40352 .36238 .4144 .35955 .40793 .35225 Mtetra
.636 .735 .919 r
.40793 .35225 .4144 .35955 .42536 .35608 .4189 .34894 Mtetra
.648 .745 .92 r
.4189 .34894 .42536 .35608 .43636 .35241 .42993 .34532 Mtetra
.653 .749 .92 r
.42993 .34532 .43636 .35241 .44741 .34864 .44101 .34155 Mtetra
.655 .751 .92 r
.44101 .34155 .44741 .34864 .45851 .3448 .45214 .33771 Mtetra
.657 .752 .92 r
.45214 .33771 .45851 .3448 .46966 .3409 .46331 .3338 Mtetra
.658 .753 .92 r
.46331 .3338 .46966 .3409 .48085 .33697 .47454 .32984 Mtetra
.659 .754 .92 r
.47454 .32984 .48085 .33697 .49209 .33301 .4858 .32586 Mtetra
.4858 .32586 .49209 .33301 .50337 .32903 .49712 .32185 Mtetra
.49712 .32185 .50337 .32903 .5147 .32505 .50848 .31784 Mtetra
.50848 .31784 .5147 .32505 .52607 .32106 .51988 .31381 Mtetra
.658 .753 .92 r
.51988 .31381 .52607 .32106 .5375 .31705 .53134 .30977 Mtetra
.53134 .30977 .5375 .31705 .54897 .31304 .54284 .30573 Mtetra
.54284 .30573 .54897 .31304 .56048 .30902 .55438 .30167 Mtetra
.55438 .30167 .56048 .30902 .57205 .30498 .56598 .2976 Mtetra
.56598 .2976 .57205 .30498 .58366 .30092 .57763 .29351 Mtetra
.57763 .29351 .58366 .30092 .59532 .29686 .58932 .28941 Mtetra
.657 .753 .92 r
.58932 .28941 .59532 .29686 .60703 .29277 .60106 .2853 Mtetra
.60106 .2853 .60703 .29277 .61879 .28868 .61285 .28117 Mtetra
.61285 .28117 .61879 .28868 .6306 .28456 .6247 .27702 Mtetra
.6247 .27702 .6306 .28456 .64245 .28043 .63659 .27286 Mtetra
.657 .752 .92 r
.63659 .27286 .64245 .28043 .65436 .27629 .64853 .26868 Mtetra
.64853 .26868 .65436 .27629 .66632 .27213 .66052 .26448 Mtetra
.66052 .26448 .66632 .27213 .67833 .26795 .67257 .26027 Mtetra
.67257 .26027 .67833 .26795 .69039 .26375 .68466 .25604 Mtetra
.68466 .25604 .69039 .26375 .7025 .25954 .69681 .2518 Mtetra
.69681 .2518 .7025 .25954 .71466 .25531 .70901 .24753 Mtetra
.70901 .24753 .71466 .25531 .72688 .25106 .72126 .24325 Mtetra
.72126 .24325 .72688 .25106 .73914 .2468 .73356 .23895 Mtetra
.73356 .23895 .73914 .2468 .75146 .24252 .74592 .23464 Mtetra
.74592 .23464 .75146 .24252 .76384 .23822 .75833 .2303 Mtetra
.75833 .2303 .76384 .23822 .77626 .2339 .7708 .22595 Mtetra
.333 .454 .834 r
.11101 .44022 .11753 .452 .1271 .45071 .12 .44357 Mtetra
.581 .703 .926 r
.12 .44357 .1271 .45071 .13671 .44956 .1297 .44178 Mtetra
0 .258 .756 r
.1297 .44178 .13671 .44956 .14752 .43847 .13851 .44787 Mtetra
.778 .946 .609 r
.13851 .44787 .14752 .43847 .15693 .43966 .14992 .43217 Mtetra
.575 .691 .92 r
.14992 .43217 .15693 .43966 .16676 .43764 .15973 .4305 Mtetra
.571 .702 .93 r
.15973 .4305 .16676 .43764 .17625 .43926 .16958 .42885 Mtetra
.812 .697 .738 r
.16958 .42885 .17625 .43926 .18718 .42762 .18084 .41441 Mtetra
.3 .406 .804 r
.18084 .41441 .18718 .42762 .19708 .42613 .19011 .41892 Mtetra
.6 .712 .922 r
.19011 .41892 .19708 .42613 .20711 .42389 .20015 .41668 Mtetra
.569 .701 .931 r
.20015 .41668 .20711 .42389 .21665 .42715 .21018 .41503 Mtetra
.78 .669 .741 r
.21018 .41503 .21665 .42715 .22781 .41374 .22127 .40261 Mtetra
.408 .516 .856 r
.22127 .40261 .22781 .41374 .23792 .41191 .23103 .40469 Mtetra
.61 .718 .922 r
.23103 .40469 .23792 .41191 .24814 .40933 .24126 .40219 Mtetra
.604 .719 .926 r
.24126 .40219 .24814 .40933 .25831 .40803 .25153 .3998 Mtetra
.753 .292 0 r
.25153 .3998 .25831 .40803 .26928 .3972 .2604 .41512 Mtetra
.675 .796 .336 r
.2604 .41512 .26928 .3972 .27944 .397 .27266 .38944 Mtetra
.6 .706 .918 r
.27266 .38944 .27944 .397 .28985 .39424 .28305 .38713 Mtetra
.626 .73 .922 r
.28305 .38713 .28985 .39424 .30031 .39135 .29354 .38419 Mtetra
.614 .725 .925 r
.29354 .38419 .30031 .39135 .31075 .38958 .30405 .38151 Mtetra
0 .34 .819 r
.30405 .38151 .31075 .38958 .32187 .37788 .31405 .38742 Mtetra
.704 .891 .513 r
.31405 .38742 .32187 .37788 .33224 .37848 .32557 .37073 Mtetra
.6 .704 .916 r
.32557 .37073 .33224 .37848 .34287 .37554 .33619 .36837 Mtetra
.635 .735 .921 r
.33619 .36837 .34287 .37554 .35358 .37226 .34692 .36516 Mtetra
.64 .74 .921 r
.34692 .36516 .35358 .37226 .36433 .36894 .35769 .3618 Mtetra
.637 .739 .922 r
.35769 .3618 .36433 .36894 .37512 .36582 .36852 .35849 Mtetra
.614 .725 .925 r
.36852 .35849 .37512 .36582 .38587 .36464 .37936 .35575 Mtetra
.955 .708 .525 r
.37936 .35575 .38587 .36464 .39708 .35358 .39519 .23641 Mtetra
0 0 .326 r
.39519 .23641 .39708 .35358 .40793 .35225 .40142 .34458 Mtetra
.619 .719 .917 r
.40142 .34458 .40793 .35225 .4189 .34894 .4124 .34168 Mtetra
.644 .741 .92 r
.4124 .34168 .4189 .34894 .42993 .34532 .42345 .33814 Mtetra
.651 .747 .92 r
.42345 .33814 .42993 .34532 .44101 .34155 .43456 .3344 Mtetra
.654 .75 .92 r
.43456 .3344 .44101 .34155 .45214 .33771 .44572 .33055 Mtetra
.656 .752 .92 r
.44572 .33055 .45214 .33771 .46331 .3338 .45692 .32663 Mtetra
.658 .753 .92 r
.45692 .32663 .46331 .3338 .47454 .32984 .46817 .32266 Mtetra
.659 .754 .92 r
.46817 .32266 .47454 .32984 .4858 .32586 .47947 .31865 Mtetra
.47947 .31865 .4858 .32586 .49712 .32185 .49081 .31462 Mtetra
.49081 .31462 .49712 .32185 .50848 .31784 .5022 .31057 Mtetra
.5022 .31057 .50848 .31784 .51988 .31381 .51364 .30651 Mtetra
.658 .753 .92 r
.51364 .30651 .51988 .31381 .53134 .30977 .52513 .30244 Mtetra
.52513 .30244 .53134 .30977 .54284 .30573 .53666 .29835 Mtetra
.53666 .29835 .54284 .30573 .55438 .30167 .54824 .29426 Mtetra
.54824 .29426 .55438 .30167 .56598 .2976 .55987 .29016 Mtetra
.55987 .29016 .56598 .2976 .57763 .29351 .57155 .28604 Mtetra
.57155 .28604 .57763 .29351 .58932 .28941 .58327 .28191 Mtetra
.58327 .28191 .58932 .28941 .60106 .2853 .59505 .27776 Mtetra
.657 .753 .92 r
.59505 .27776 .60106 .2853 .61285 .28117 .60687 .2736 Mtetra
.60687 .2736 .61285 .28117 .6247 .27702 .61875 .26942 Mtetra
.61875 .26942 .6247 .27702 .63659 .27286 .63068 .26522 Mtetra
.657 .752 .92 r
.63068 .26522 .63659 .27286 .64853 .26868 .64265 .26101 Mtetra
.64265 .26101 .64853 .26868 .66052 .26448 .65468 .25678 Mtetra
.65468 .25678 .66052 .26448 .67257 .26027 .66676 .25254 Mtetra
.66676 .25254 .67257 .26027 .68466 .25604 .67889 .24827 Mtetra
.67889 .24827 .68466 .25604 .69681 .2518 .69107 .24399 Mtetra
.69107 .24399 .69681 .2518 .70901 .24753 .70331 .2397 Mtetra
.70331 .2397 .70901 .24753 .72126 .24325 .7156 .23538 Mtetra
.7156 .23538 .72126 .24325 .73356 .23895 .72794 .23105 Mtetra
.72794 .23105 .73356 .23895 .74592 .23464 .74033 .2267 Mtetra
.74033 .2267 .74592 .23464 .75833 .2303 .75278 .22233 Mtetra
.75278 .22233 .75833 .2303 .7708 .22595 .76528 .21794 Mtetra
.7 .941 .643 r
.10192 .44805 .11101 .44022 .12 .44357 .11292 .43589 Mtetra
.56 .679 .919 r
.11292 .43589 .12 .44357 .1297 .44178 .12257 .43454 Mtetra
.547 .69 .933 r
.12257 .43454 .1297 .44178 .13851 .44787 .13225 .43334 Mtetra
.747 .627 .727 r
.13225 .43334 .13851 .44787 .14992 .43217 .14316 .42216 Mtetra
.441 .56 .88 r
.14316 .42216 .14992 .43217 .15973 .4305 .15265 .42331 Mtetra
.592 .709 .925 r
.15265 .42331 .15973 .4305 .16958 .42885 .16256 .42123 Mtetra
.35 .589 .934 r
.16256 .42123 .16958 .42885 .18084 .41441 .17212 .4228 Mtetra
.589 .873 .555 r
.17212 .4228 .18084 .41441 .19011 .41892 .18316 .41107 Mtetra
.568 .681 .916 r
.18316 .41107 .19011 .41892 .20015 .41668 .19314 .40952 Mtetra
.601 .716 .925 r
.19314 .40952 .20015 .41668 .21018 .41503 .20324 .40721 Mtetra
.204 .502 .907 r
.20324 .40721 .21018 .41503 .22127 .40261 .21286 .41044 Mtetra
.712 .933 .613 r
.21286 .41044 .22127 .40261 .23103 .40469 .22413 .39692 Mtetra
.582 .692 .917 r
.22413 .39692 .23103 .40469 .24126 .40219 .23433 .39503 Mtetra
.614 .723 .923 r
.23433 .39503 .24126 .40219 .25153 .3998 .24464 .39239 Mtetra
.551 .693 .933 r
.24464 .39239 .25153 .3998 .2604 .41512 .25489 .39103 Mtetra
.687 .534 .674 r
.25489 .39103 .2604 .41512 .27266 .38944 .26597 .3801 Mtetra
.51 .618 .895 r
.26597 .3801 .27266 .38944 .28305 .38713 .27621 .37985 Mtetra
.62 .725 .921 r
.27621 .37985 .28305 .38713 .29354 .38419 .28671 .37702 Mtetra
.625 .73 .923 r
.28671 .37702 .29354 .38419 .30405 .38151 .29726 .37407 Mtetra
.574 .704 .931 r
.29726 .37407 .30405 .38151 .31405 .38742 .30779 .37223 Mtetra
.751 .63 .726 r
.30779 .37223 .31405 .38742 .32557 .37073 .31902 .36043 Mtetra
.478 .58 .878 r
.31902 .36043 .32557 .37073 .33619 .36837 .32947 .36098 Mtetra
.625 .727 .92 r
.32947 .36098 .33619 .36837 .34692 .36516 .34021 .35797 Mtetra
.639 .739 .921 r
.34021 .35797 .34692 .36516 .35769 .3618 .35101 .35462 Mtetra
.64 .74 .921 r
.35101 .35462 .35769 .3618 .36852 .35849 .36186 .35123 Mtetra
.631 .735 .923 r
.36186 .35123 .36852 .35849 .37936 .35575 .37274 .34804 Mtetra
.542 .687 .934 r
.37274 .34804 .37936 .35575 .39519 .23641 .38359 .3468 Mtetra
.465 .215 .45 r
.38359 .3468 .39519 .23641 .40142 .34458 .39491 .33564 Mtetra
.558 .658 .903 r
.39491 .33564 .40142 .34458 .4124 .34168 .40586 .33424 Mtetra
.636 .735 .919 r
.40586 .33424 .4124 .34168 .42345 .33814 .41693 .33086 Mtetra
.648 .745 .92 r
.41693 .33086 .42345 .33814 .43456 .3344 .42806 .32716 Mtetra
.653 .749 .92 r
.42806 .32716 .43456 .3344 .44572 .33055 .43925 .32333 Mtetra
.655 .751 .92 r
.43925 .32333 .44572 .33055 .45692 .32663 .45048 .31941 Mtetra
.657 .752 .92 r
.45048 .31941 .45692 .32663 .46817 .32266 .46176 .31542 Mtetra
.658 .753 .92 r
.46176 .31542 .46817 .32266 .47947 .31865 .47309 .31139 Mtetra
.659 .754 .92 r
.47309 .31139 .47947 .31865 .49081 .31462 .48446 .30732 Mtetra
.48446 .30732 .49081 .31462 .5022 .31057 .49588 .30324 Mtetra
.49588 .30324 .5022 .31057 .51364 .30651 .50735 .29915 Mtetra
.50735 .29915 .51364 .30651 .52513 .30244 .51887 .29504 Mtetra
.658 .753 .92 r
.51887 .29504 .52513 .30244 .53666 .29835 .53043 .29093 Mtetra
.53043 .29093 .53666 .29835 .54824 .29426 .54205 .2868 Mtetra
.54205 .2868 .54824 .29426 .55987 .29016 .55371 .28266 Mtetra
.55371 .28266 .55987 .29016 .57155 .28604 .56542 .27851 Mtetra
.56542 .27851 .57155 .28604 .58327 .28191 .57718 .27434 Mtetra
.57718 .27434 .58327 .28191 .59505 .27776 .58899 .27016 Mtetra
.657 .753 .92 r
.58899 .27016 .59505 .27776 .60687 .2736 .60085 .26597 Mtetra
.60085 .26597 .60687 .2736 .61875 .26942 .61276 .26175 Mtetra
.61276 .26175 .61875 .26942 .63068 .26522 .62472 .25753 Mtetra
.62472 .25753 .63068 .26522 .64265 .26101 .63673 .25328 Mtetra
.657 .752 .92 r
.63673 .25328 .64265 .26101 .65468 .25678 .64879 .24902 Mtetra
.64879 .24902 .65468 .25678 .66676 .25254 .66091 .24474 Mtetra
.66091 .24474 .66676 .25254 .67889 .24827 .67307 .24044 Mtetra
.67307 .24044 .67889 .24827 .69107 .24399 .68529 .23613 Mtetra
.68529 .23613 .69107 .24399 .70331 .2397 .69756 .23179 Mtetra
.69756 .23179 .70331 .2397 .7156 .23538 .70989 .22744 Mtetra
.70989 .22744 .7156 .23538 .72794 .23105 .72227 .22308 Mtetra
.72227 .22308 .72794 .23105 .74033 .2267 .7347 .21869 Mtetra
.7347 .21869 .74033 .2267 .75278 .22233 .74719 .21429 Mtetra
.74719 .21429 .75278 .22233 .76528 .21794 .75973 .20986 Mtetra
.792 .68 .741 r
.0952 .43693 .10192 .44805 .11292 .43589 .10633 .42397 Mtetra
.332 .454 .834 r
.10633 .42397 .11292 .43589 .12257 .43454 .11539 .42728 Mtetra
.581 .703 .926 r
.11539 .42728 .12257 .43454 .13225 .43334 .12516 .42543 Mtetra
0 .261 .759 r
.12516 .42543 .13225 .43334 .14316 .42216 .13403 .4315 Mtetra
.784 .95 .616 r
.13403 .4315 .14316 .42216 .15265 .42331 .14556 .41569 Mtetra
.575 .691 .92 r
.14556 .41569 .15265 .42331 .16256 .42123 .15545 .41396 Mtetra
.571 .701 .93 r
.15545 .41396 .16256 .42123 .17212 .4228 .16538 .41226 Mtetra
.813 .698 .738 r
.16538 .41226 .17212 .4228 .18316 .41107 .17675 .39771 Mtetra
.298 .405 .804 r
.17675 .39771 .18316 .41107 .19314 .40952 .18609 .40218 Mtetra
.6 .712 .922 r
.18609 .40218 .19314 .40952 .20324 .40721 .19621 .39988 Mtetra
.57 .701 .931 r
.19621 .39988 .20324 .40721 .21286 .41044 .20632 .39817 Mtetra
.781 .67 .741 r
.20632 .39817 .21286 .41044 .22413 .39692 .21752 .38565 Mtetra
.407 .516 .856 r
.21752 .38565 .22413 .39692 .23433 .39503 .22735 .38769 Mtetra
.61 .718 .922 r
.22735 .38769 .23433 .39503 .24464 .39239 .23768 .38512 Mtetra
.604 .719 .926 r
.23768 .38512 .24464 .39239 .25489 .39103 .24804 .38267 Mtetra
.747 .286 0 r
.24804 .38267 .25489 .39103 .26597 .3801 .25696 .398 Mtetra
.684 .803 .345 r
.25696 .398 .26597 .3801 .27621 .37985 .26935 .37216 Mtetra
.6 .706 .918 r
.26935 .37216 .27621 .37985 .28671 .37702 .27983 .36978 Mtetra
.626 .73 .922 r
.27983 .36978 .28671 .37702 .29726 .37407 .29041 .36677 Mtetra
.614 .725 .925 r
.29041 .36677 .29726 .37407 .30779 .37223 .30102 .36403 Mtetra
0 .343 .821 r
.30102 .36403 .30779 .37223 .31902 .36043 .3111 .3699 Mtetra
.712 .897 .522 r
.3111 .3699 .31902 .36043 .32947 .36098 .32273 .35309 Mtetra
.6 .704 .916 r
.32273 .35309 .32947 .36098 .34021 .35797 .33345 .35067 Mtetra
.635 .735 .921 r
.33345 .35067 .34021 .35797 .35101 .35462 .34427 .34739 Mtetra
.64 .74 .921 r
.34427 .34739 .35101 .35462 .36186 .35123 .35515 .34396 Mtetra
.637 .739 .922 r
.35515 .34396 .36186 .35123 .37274 .34804 .36607 .34058 Mtetra
.614 .725 .925 r
.36607 .34058 .37274 .34804 .38359 .3468 .37701 .33776 Mtetra
.956 .709 .522 r
.37701 .33776 .38359 .3468 .39491 .33564 .39307 .21794 Mtetra
0 0 .321 r
.39307 .21794 .39491 .33564 .40586 .33424 .39928 .32643 Mtetra
.619 .719 .917 r
.39928 .32643 .40586 .33424 .41693 .33086 .41036 .32346 Mtetra
.644 .741 .92 r
.41036 .32346 .41693 .33086 .42806 .32716 .42152 .31985 Mtetra
.651 .747 .92 r
.42152 .31985 .42806 .32716 .43925 .32333 .43273 .31603 Mtetra
.654 .75 .92 r
.43273 .31603 .43925 .32333 .45048 .31941 .44399 .31211 Mtetra
.656 .752 .92 r
.44399 .31211 .45048 .31941 .46176 .31542 .4553 .30811 Mtetra
.658 .753 .92 r
.4553 .30811 .46176 .31542 .47309 .31139 .46666 .30406 Mtetra
.659 .754 .92 r
.46666 .30406 .47309 .31139 .48446 .30732 .47806 .29998 Mtetra
.47806 .29998 .48446 .30732 .49588 .30324 .48952 .29586 Mtetra
.48952 .29586 .49588 .30324 .50735 .29915 .50102 .29173 Mtetra
.50102 .29173 .50735 .29915 .51887 .29504 .51256 .28759 Mtetra
.658 .753 .92 r
.51256 .28759 .51887 .29504 .53043 .29093 .52416 .28344 Mtetra
.52416 .28344 .53043 .29093 .54205 .2868 .53581 .27928 Mtetra
.53581 .27928 .54205 .2868 .55371 .28266 .5475 .27511 Mtetra
.5475 .27511 .55371 .28266 .56542 .27851 .55924 .27092 Mtetra
.55924 .27092 .56542 .27851 .57718 .27434 .57104 .26672 Mtetra
.57104 .26672 .57718 .27434 .58899 .27016 .58288 .26251 Mtetra
.58288 .26251 .58899 .27016 .60085 .26597 .59477 .25828 Mtetra
.657 .753 .92 r
.59477 .25828 .60085 .26597 .61276 .26175 .60672 .25403 Mtetra
.60672 .25403 .61276 .26175 .62472 .25753 .61871 .24977 Mtetra
.61871 .24977 .62472 .25753 .63673 .25328 .63076 .24549 Mtetra
.657 .752 .92 r
.63076 .24549 .63673 .25328 .64879 .24902 .64286 .24119 Mtetra
.64286 .24119 .64879 .24902 .66091 .24474 .65501 .23688 Mtetra
.65501 .23688 .66091 .24474 .67307 .24044 .66721 .23255 Mtetra
.66721 .23255 .67307 .24044 .68529 .23613 .67947 .2282 Mtetra
.67947 .2282 .68529 .23613 .69756 .23179 .69177 .22383 Mtetra
.69177 .22383 .69756 .23179 .70989 .22744 .70414 .21944 Mtetra
.70414 .21944 .70989 .22744 .72227 .22308 .71655 .21504 Mtetra
.71655 .21504 .72227 .22308 .7347 .21869 .72902 .21062 Mtetra
.72902 .21062 .7347 .21869 .74719 .21429 .74155 .20618 Mtetra
.74155 .20618 .74719 .21429 .75973 .20986 .75413 .20172 Mtetra
.247 .532 .919 r
.08799 .42921 .0952 .43693 .10633 .42397 .09712 .43174 Mtetra
.708 .946 .652 r
.09712 .43174 .10633 .42397 .11539 .42728 .10823 .41949 Mtetra
.56 .679 .919 r
.10823 .41949 .11539 .42728 .12516 .42543 .11796 .41808 Mtetra
.547 .69 .933 r
.11796 .41808 .12516 .42543 .13403 .4315 .12771 .41682 Mtetra
.747 .628 .727 r
.12771 .41682 .13403 .4315 .14556 .41569 .13873 .40554 Mtetra
.44 .56 .88 r
.13873 .40554 .14556 .41569 .15545 .41396 .14828 .40664 Mtetra
.592 .709 .925 r
.14828 .40664 .15545 .41396 .16538 .41226 .15828 .40451 Mtetra
.352 .589 .934 r
.15828 .40451 .16538 .41226 .17675 .39771 .16791 .40604 Mtetra
.601 .882 .567 r
.16791 .40604 .17675 .39771 .18609 .40218 .17905 .3942 Mtetra
.568 .681 .916 r
.17905 .3942 .18609 .40218 .19621 .39988 .18912 .39259 Mtetra
.601 .716 .925 r
.18912 .39259 .19621 .39988 .20632 .39817 .19931 .39023 Mtetra
.206 .503 .907 r
.19931 .39023 .20632 .39817 .21752 .38565 .209 .39341 Mtetra
.72 .939 .622 r
.209 .39341 .21752 .38565 .22735 .38769 .22038 .37979 Mtetra
.582 .692 .917 r
.22038 .37979 .22735 .38769 .23768 .38512 .23066 .37783 Mtetra
.614 .723 .923 r
.23066 .37783 .23768 .38512 .24804 .38267 .24106 .37512 Mtetra
.551 .693 .933 r
.24106 .37512 .24804 .38267 .25696 .398 .2514 .3737 Mtetra
.686 .534 .674 r
.2514 .3737 .25696 .398 .26935 .37216 .26258 .36268 Mtetra
.51 .618 .895 r
.26258 .36268 .26935 .37216 .27983 .36978 .27292 .36237 Mtetra
.62 .725 .921 r
.27292 .36237 .27983 .36978 .29041 .36677 .28351 .35947 Mtetra
.625 .73 .923 r
.28351 .35947 .29041 .36677 .30102 .36403 .29416 .35646 Mtetra
.574 .704 .93 r
.29416 .35646 .30102 .36403 .3111 .3699 .30478 .35456 Mtetra
.751 .63 .726 r
.30478 .35456 .3111 .3699 .32273 .35309 .31611 .34265 Mtetra
.478 .58 .878 r
.31611 .34265 .32273 .35309 .33345 .35067 .32666 .34314 Mtetra
.625 .727 .92 r
.32666 .34314 .33345 .35067 .34427 .34739 .33749 .34007 Mtetra
.639 .739 .921 r
.33749 .34007 .34427 .34739 .35515 .34396 .34839 .33664 Mtetra
.64 .74 .921 r
.34839 .33664 .35515 .34396 .36607 .34058 .35934 .33318 Mtetra
.631 .735 .923 r
.35934 .33318 .36607 .34058 .37701 .33776 .37032 .32992 Mtetra
.542 .687 .933 r
.37032 .32992 .37701 .33776 .39307 .21794 .38127 .32861 Mtetra
.46 .209 .446 r
.38127 .32861 .39307 .21794 .39928 .32643 .3927 .31735 Mtetra
.558 .658 .903 r
.3927 .31735 .39928 .32643 .41036 .32346 .40374 .31588 Mtetra
.636 .735 .919 r
.40374 .31588 .41036 .32346 .42152 .31985 .41492 .31243 Mtetra
.648 .745 .92 r
.41492 .31243 .42152 .31985 .43273 .31603 .42616 .30866 Mtetra
.653 .749 .92 r
.42616 .30866 .43273 .31603 .44399 .31211 .43745 .30474 Mtetra
.655 .751 .92 r
.43745 .30474 .44399 .31211 .4553 .30811 .44879 .30074 Mtetra
.657 .752 .92 r
.44879 .30074 .4553 .30811 .46666 .30406 .46018 .29668 Mtetra
.658 .753 .92 r
.46018 .29668 .46666 .30406 .47806 .29998 .47161 .29257 Mtetra
.659 .754 .92 r
.47161 .29257 .47806 .29998 .48952 .29586 .4831 .28843 Mtetra
.4831 .28843 .48952 .29586 .50102 .29173 .49463 .28426 Mtetra
.49463 .28426 .50102 .29173 .51256 .28759 .50621 .28009 Mtetra
.50621 .28009 .51256 .28759 .52416 .28344 .51784 .2759 Mtetra
.658 .753 .92 r
.51784 .2759 .52416 .28344 .53581 .27928 .52952 .27171 Mtetra
.52952 .27171 .53581 .27928 .5475 .27511 .54124 .2675 Mtetra
.54124 .2675 .5475 .27511 .55924 .27092 .55302 .26328 Mtetra
.55302 .26328 .55924 .27092 .57104 .26672 .56484 .25904 Mtetra
.56484 .25904 .57104 .26672 .58288 .26251 .57672 .25479 Mtetra
.57672 .25479 .58288 .26251 .59477 .25828 .58865 .25053 Mtetra
.657 .753 .92 r
.58865 .25053 .59477 .25828 .60672 .25403 .60063 .24625 Mtetra
.60063 .24625 .60672 .25403 .61871 .24977 .61266 .24195 Mtetra
.61266 .24195 .61871 .24977 .63076 .24549 .62474 .23764 Mtetra
.62474 .23764 .63076 .24549 .64286 .24119 .63687 .2333 Mtetra
.657 .752 .92 r
.63687 .2333 .64286 .24119 .65501 .23688 .64906 .22895 Mtetra
.64906 .22895 .65501 .23688 .66721 .23255 .6613 .22459 Mtetra
.6613 .22459 .66721 .23255 .67947 .2282 .67359 .2202 Mtetra
.67359 .2202 .67947 .2282 .69177 .22383 .68594 .2158 Mtetra
.68594 .2158 .69177 .22383 .70414 .21944 .69834 .21138 Mtetra
.69834 .21138 .70414 .21944 .71655 .21504 .71079 .20694 Mtetra
.71079 .20694 .71655 .21504 .72902 .21062 .7233 .20248 Mtetra
.7233 .20248 .72902 .21062 .74155 .20618 .73586 .19801 Mtetra
.73586 .19801 .74155 .20618 .75413 .20172 .74848 .19351 Mtetra
.553 .691 .931 r
.08068 .42185 .08799 .42921 .09712 .43174 .09033 .42048 Mtetra
.792 .681 .742 r
.09033 .42048 .09712 .43174 .10823 .41949 .10157 .40742 Mtetra
.33 .453 .834 r
.10157 .40742 .10823 .41949 .11796 .41808 .11069 .4107 Mtetra
.581 .703 .926 r
.11069 .4107 .11796 .41808 .12771 .41682 .12055 .40879 Mtetra
0 .265 .763 r
.12055 .40879 .12771 .41682 .13873 .40554 .12947 .41483 Mtetra
.79 .954 .623 r
.12947 .41483 .13873 .40554 .14828 .40664 .14112 .3989 Mtetra
.575 .691 .92 r
.14112 .3989 .14828 .40664 .15828 .40451 .15108 .39711 Mtetra
.571 .701 .93 r
.15108 .39711 .15828 .40451 .16791 .40604 .16109 .39535 Mtetra
.814 .698 .738 r
.16109 .39535 .16791 .40604 .17905 .3942 .17258 .38069 Mtetra
.296 .404 .804 r
.17258 .38069 .17905 .3942 .18912 .39259 .18199 .38513 Mtetra
.6 .712 .922 r
.18199 .38513 .18912 .39259 .19931 .39023 .1922 .38276 Mtetra
.57 .701 .931 r
.1922 .38276 .19931 .39023 .209 .39341 .20239 .381 Mtetra
.781 .67 .741 r
.20239 .381 .209 .39341 .22038 .37979 .2137 .36837 Mtetra
.406 .515 .856 r
.2137 .36837 .22038 .37979 .23066 .37783 .22361 .37036 Mtetra
.61 .718 .922 r
.22361 .37036 .23066 .37783 .24106 .37512 .23402 .36773 Mtetra
.604 .719 .926 r
.23402 .36773 .24106 .37512 .2514 .3737 .24447 .36521 Mtetra
.741 .28 0 r
.24447 .36521 .2514 .3737 .26258 .36268 .25346 .38055 Mtetra
.693 .81 .354 r
.25346 .38055 .26258 .36268 .27292 .36237 .26598 .35454 Mtetra
.6 .706 .918 r
.26598 .35454 .27292 .36237 .28351 .35947 .27655 .3521 Mtetra
.626 .73 .922 r
.27655 .3521 .28351 .35947 .29416 .35646 .28723 .34902 Mtetra
.614 .725 .925 r
.28723 .34902 .29416 .35646 .30478 .35456 .29793 .34621 Mtetra
0 .346 .823 r
.29793 .34621 .30478 .35456 .31611 .34265 .30809 .35205 Mtetra
.72 .903 .531 r
.30809 .35205 .31611 .34265 .32666 .34314 .31984 .33511 Mtetra
.6 .704 .916 r
.31984 .33511 .32666 .34314 .33749 .34007 .33066 .33262 Mtetra
.635 .735 .921 r
.33066 .33262 .33749 .34007 .34839 .33664 .34158 .32927 Mtetra
.64 .74 .921 r
.34158 .32927 .34839 .33664 .35934 .33318 .35255 .32577 Mtetra
.637 .739 .922 r
.35255 .32577 .35934 .33318 .37032 .32992 .36357 .32232 Mtetra
.614 .725 .925 r
.36357 .32232 .37032 .32992 .38127 .32861 .37461 .31943 Mtetra
.957 .709 .52 r
.37461 .31943 .38127 .32861 .3927 .31735 .39092 .19912 Mtetra
0 0 .316 r
.39092 .19912 .3927 .31735 .40374 .31588 .39709 .30793 Mtetra
.619 .719 .917 r
.39709 .30793 .40374 .31588 .41492 .31243 .40828 .30489 Mtetra
.644 .741 .92 r
.40828 .30489 .41492 .31243 .42616 .30866 .41954 .3012 Mtetra
.651 .747 .92 r
.41954 .3012 .42616 .30866 .43745 .30474 .43086 .2973 Mtetra
.654 .75 .92 r
.43086 .2973 .43745 .30474 .44879 .30074 .44223 .2933 Mtetra
.656 .752 .92 r
.44223 .2933 .44879 .30074 .46018 .29668 .45365 .28923 Mtetra
.658 .753 .92 r
.45365 .28923 .46018 .29668 .47161 .29257 .46511 .2851 Mtetra
.659 .754 .92 r
.46511 .2851 .47161 .29257 .4831 .28843 .47663 .28093 Mtetra
.47663 .28093 .4831 .28843 .49463 .28426 .48819 .27674 Mtetra
.48819 .27674 .49463 .28426 .50621 .28009 .4998 .27253 Mtetra
.4998 .27253 .50621 .28009 .51784 .2759 .51146 .2683 Mtetra
.658 .753 .92 r
.51146 .2683 .51784 .2759 .52952 .27171 .52318 .26407 Mtetra
.52318 .26407 .52952 .27171 .54124 .2675 .53493 .25983 Mtetra
.53493 .25983 .54124 .2675 .55302 .26328 .54674 .25557 Mtetra
.54674 .25557 .55302 .26328 .56484 .25904 .5586 .2513 Mtetra
.5586 .2513 .56484 .25904 .57672 .25479 .57052 .24702 Mtetra
.57052 .24702 .57672 .25479 .58865 .25053 .58248 .24272 Mtetra
.58248 .24272 .58865 .25053 .60063 .24625 .59449 .2384 Mtetra
.657 .753 .92 r
.59449 .2384 .60063 .24625 .61266 .24195 .60656 .23407 Mtetra
.60656 .23407 .61266 .24195 .62474 .23764 .61867 .22972 Mtetra
.61867 .22972 .62474 .23764 .63687 .2333 .63084 .22535 Mtetra
.657 .752 .92 r
.63084 .22535 .63687 .2333 .64906 .22895 .64306 .22097 Mtetra
.64306 .22097 .64906 .22895 .6613 .22459 .65534 .21657 Mtetra
.65534 .21657 .6613 .22459 .67359 .2202 .66767 .21215 Mtetra
.66767 .21215 .67359 .2202 .68594 .2158 .68005 .20771 Mtetra
.68005 .20771 .68594 .2158 .69834 .21138 .69249 .20325 Mtetra
.69249 .20325 .69834 .21138 .71079 .20694 .70498 .19877 Mtetra
.70498 .19877 .71079 .20694 .7233 .20248 .71753 .19428 Mtetra
.71753 .19428 .7233 .20248 .73586 .19801 .73013 .18977 Mtetra
.73013 .18977 .73586 .19801 .74848 .19351 .74279 .18523 Mtetra
.568 .692 .924 r
.07334 .41428 .08068 .42185 .09033 .42048 .08304 .41264 Mtetra
.249 .533 .919 r
.08304 .41264 .09033 .42048 .10157 .40742 .09224 .41513 Mtetra
.717 .951 .661 r
.09224 .41513 .10157 .40742 .11069 .4107 .10345 .40277 Mtetra
.559 .68 .919 r
.10345 .40277 .11069 .4107 .12055 .40879 .11325 .40131 Mtetra
.547 .69 .933 r
.11325 .40131 .12055 .40879 .12947 .41483 .12309 .4 Mtetra
.747 .628 .727 r
.12309 .4 .12947 .41483 .14112 .3989 .13421 .38862 Mtetra
.439 .56 .88 r
.13421 .38862 .14112 .3989 .15108 .39711 .14384 .38967 Mtetra
.592 .709 .925 r
.14384 .38967 .15108 .39711 .16109 .39535 .15391 .38747 Mtetra
.353 .59 .934 r
.15391 .38747 .16109 .39535 .17258 .38069 .16362 .38895 Mtetra
.612 .89 .579 r
.16362 .38895 .17258 .38069 .18199 .38513 .17487 .37701 Mtetra
.568 .681 .916 r
.17487 .37701 .18199 .38513 .1922 .38276 .18502 .37535 Mtetra
.601 .716 .925 r
.18502 .37535 .1922 .38276 .20239 .381 .1953 .37292 Mtetra
.209 .504 .907 r
.1953 .37292 .20239 .381 .2137 .36837 .20507 .37606 Mtetra
.728 .943 .63 r
.20507 .37606 .2137 .36837 .22361 .37036 .21656 .36232 Mtetra
.582 .692 .917 r
.21656 .36232 .22361 .37036 .23402 .36773 .22693 .36031 Mtetra
.614 .723 .923 r
.22693 .36031 .23402 .36773 .24447 .36521 .23742 .35753 Mtetra
.552 .693 .933 r
.23742 .35753 .24447 .36521 .25346 .38055 .24785 .35605 Mtetra
.686 .533 .673 r
.24785 .35605 .25346 .38055 .26598 .35454 .25914 .34492 Mtetra
.51 .618 .895 r
.25914 .34492 .26598 .35454 .27655 .3521 .26956 .34455 Mtetra
.62 .725 .921 r
.26956 .34455 .27655 .3521 .28723 .34902 .28024 .34159 Mtetra
.625 .73 .923 r
.28024 .34159 .28723 .34902 .29793 .34621 .29099 .3385 Mtetra
.574 .704 .93 r
.29099 .3385 .29793 .34621 .30809 .35205 .3017 .33654 Mtetra
.751 .631 .726 r
.3017 .33654 .30809 .35205 .31984 .33511 .31315 .32453 Mtetra
.477 .58 .879 r
.31315 .32453 .31984 .33511 .33066 .33262 .32379 .32496 Mtetra
.625 .727 .92 r
.32379 .32496 .33066 .33262 .34158 .32927 .33472 .32181 Mtetra
.639 .739 .921 r
.33472 .32181 .34158 .32927 .35255 .32577 .34572 .31831 Mtetra
.64 .74 .921 r
.34572 .31831 .35255 .32577 .36357 .32232 .35677 .31477 Mtetra
.631 .735 .923 r
.35677 .31477 .36357 .32232 .37461 .31943 .36785 .31144 Mtetra
.542 .687 .933 r
.36785 .31144 .37461 .31943 .39092 .19912 .3789 .31006 Mtetra
.455 .202 .44 r
.3789 .31006 .39092 .19912 .39709 .30793 .39044 .2987 Mtetra
.558 .658 .903 r
.39044 .2987 .39709 .30793 .40828 .30489 .40159 .29716 Mtetra
.636 .735 .919 r
.40159 .29716 .40828 .30489 .41954 .3012 .41287 .29363 Mtetra
.648 .745 .92 r
.41287 .29363 .41954 .3012 .43086 .2973 .42422 .28978 Mtetra
.653 .749 .92 r
.42422 .28978 .43086 .2973 .44223 .2933 .43562 .28579 Mtetra
.655 .751 .92 r
.43562 .28579 .44223 .2933 .45365 .28923 .44706 .28171 Mtetra
.657 .752 .92 r
.44706 .28171 .45365 .28923 .46511 .2851 .45856 .27757 Mtetra
.658 .753 .92 r
.45856 .27757 .46511 .2851 .47663 .28093 .47011 .27337 Mtetra
.659 .754 .92 r
.47011 .27337 .47663 .28093 .48819 .27674 .4817 .26915 Mtetra
.4817 .26915 .48819 .27674 .4998 .27253 .49335 .26491 Mtetra
.49335 .26491 .4998 .27253 .51146 .2683 .50504 .26065 Mtetra
.50504 .26065 .51146 .2683 .52318 .26407 .51678 .25638 Mtetra
.658 .753 .92 r
.51678 .25638 .52318 .26407 .53493 .25983 .52858 .2521 Mtetra
.52858 .2521 .53493 .25983 .54674 .25557 .54042 .24781 Mtetra
.54042 .24781 .54674 .25557 .5586 .2513 .55231 .2435 Mtetra
.55231 .2435 .5586 .2513 .57052 .24702 .56426 .23918 Mtetra
.56426 .23918 .57052 .24702 .58248 .24272 .57626 .23484 Mtetra
.57626 .23484 .58248 .24272 .59449 .2384 .5883 .23049 Mtetra
.657 .753 .92 r
.5883 .23049 .59449 .2384 .60656 .23407 .6004 .22613 Mtetra
.6004 .22613 .60656 .23407 .61867 .22972 .61256 .22174 Mtetra
.61256 .22174 .61867 .22972 .63084 .22535 .62476 .21734 Mtetra
.62476 .21734 .63084 .22535 .64306 .22097 .63702 .21292 Mtetra
.657 .752 .92 r
.63702 .21292 .64306 .22097 .65534 .21657 .64933 .20848 Mtetra
.64933 .20848 .65534 .21657 .66767 .21215 .6617 .20402 Mtetra
.6617 .20402 .66767 .21215 .68005 .20771 .67412 .19955 Mtetra
.67412 .19955 .68005 .20771 .69249 .20325 .68659 .19505 Mtetra
.68659 .19505 .69249 .20325 .70498 .19877 .69912 .19054 Mtetra
.69912 .19054 .70498 .19877 .71753 .19428 .71171 .18601 Mtetra
.71171 .18601 .71753 .19428 .73013 .18977 .72435 .18146 Mtetra
.72435 .18146 .73013 .18977 .74279 .18523 .73705 .17689 Mtetra
.495 .622 .906 r
.06614 .40534 .07334 .41428 .08304 .41264 .07564 .40515 Mtetra
.553 .691 .931 r
.07564 .40515 .08304 .41264 .09224 .41513 .08537 .40373 Mtetra
.793 .682 .742 r
.08537 .40373 .09224 .41513 .10345 .40277 .09672 .39056 Mtetra
.329 .452 .834 r
.09672 .39056 .10345 .40277 .11325 .40131 .10591 .3938 Mtetra
.581 .703 .926 r
.10591 .3938 .11325 .40131 .12309 .4 .11584 .39183 Mtetra
0 .269 .766 r
.11584 .39183 .12309 .4 .13421 .38862 .12483 .39784 Mtetra
.796 .957 .629 r
.12483 .39784 .13421 .38862 .14384 .38967 .13659 .38179 Mtetra
.575 .691 .92 r
.13659 .38179 .14384 .38967 .15391 .38747 .14664 .37995 Mtetra
.571 .701 .93 r
.14664 .37995 .15391 .38747 .16362 .38895 .15673 .37813 Mtetra
.814 .699 .738 r
.15673 .37813 .16362 .38895 .17487 .37701 .16833 .36335 Mtetra
.294 .404 .804 r
.16833 .36335 .17487 .37701 .18502 .37535 .17781 .36775 Mtetra
.6 .712 .922 r
.17781 .36775 .18502 .37535 .1953 .37292 .18811 .36532 Mtetra
.57 .701 .931 r
.18811 .36532 .1953 .37292 .20507 .37606 .19839 .36349 Mtetra
.782 .671 .741 r
.19839 .36349 .20507 .37606 .21656 .36232 .20981 .35076 Mtetra
.405 .515 .857 r
.20981 .35076 .21656 .36232 .22693 .36031 .2198 .3527 Mtetra
.61 .718 .922 r
.2198 .3527 .22693 .36031 .23742 .35753 .2303 .35 Mtetra
.604 .719 .926 r
.2303 .35 .23742 .35753 .24785 .35605 .24084 .34741 Mtetra
.735 .274 0 r
.24084 .34741 .24785 .35605 .25914 .34492 .24988 .36276 Mtetra
.702 .817 .363 r
.24988 .36276 .25914 .34492 .26956 .34455 .26254 .33659 Mtetra
.6 .706 .918 r
.26254 .33659 .26956 .34455 .28024 .34159 .27321 .33408 Mtetra
.626 .73 .922 r
.27321 .33408 .28024 .34159 .29099 .3385 .28398 .33093 Mtetra
.614 .725 .925 r
.28398 .33093 .29099 .3385 .3017 .33654 .29478 .32805 Mtetra
0 .349 .825 r
.29478 .32805 .3017 .33654 .31315 .32453 .30502 .33385 Mtetra
.728 .908 .539 r
.30502 .33385 .31315 .32453 .32379 .32496 .31689 .31679 Mtetra
.6 .704 .916 r
.31689 .31679 .32379 .32496 .33472 .32181 .32781 .31422 Mtetra
.635 .735 .921 r
.32781 .31422 .33472 .32181 .34572 .31831 .33883 .3108 Mtetra
.64 .74 .921 r
.33883 .3108 .34572 .31831 .35677 .31477 .34991 .30722 Mtetra
.637 .739 .922 r
.34991 .30722 .35677 .31477 .36785 .31144 .36103 .30369 Mtetra
.614 .725 .925 r
.36103 .30369 .36785 .31144 .3789 .31006 .37217 .30073 Mtetra
.958 .709 .517 r
.37217 .30073 .3789 .31006 .39044 .2987 .38871 .17995 Mtetra
0 0 .31 r
.38871 .17995 .39044 .2987 .40159 .29716 .39486 .28906 Mtetra
.619 .719 .917 r
.39486 .28906 .40159 .29716 .41287 .29363 .40616 .28595 Mtetra
.644 .741 .92 r
.40616 .28595 .41287 .29363 .42422 .28978 .41753 .28217 Mtetra
.651 .747 .92 r
.41753 .28217 .42422 .28978 .43562 .28579 .42895 .2782 Mtetra
.654 .75 .92 r
.42895 .2782 .43562 .28579 .44706 .28171 .44043 .27412 Mtetra
.656 .752 .92 r
.44043 .27412 .44706 .28171 .45856 .27757 .45196 .26997 Mtetra
.658 .753 .92 r
.45196 .26997 .45856 .27757 .47011 .27337 .46354 .26575 Mtetra
.659 .754 .92 r
.46354 .26575 .47011 .27337 .4817 .26915 .47516 .2615 Mtetra
.47516 .2615 .4817 .26915 .49335 .26491 .48684 .25723 Mtetra
.48684 .25723 .49335 .26491 .50504 .26065 .49857 .25293 Mtetra
.49857 .25293 .50504 .26065 .51678 .25638 .51034 .24863 Mtetra
.658 .753 .92 r
.51034 .24863 .51678 .25638 .52858 .2521 .52217 .24431 Mtetra
.52217 .24431 .52858 .2521 .54042 .24781 .53405 .23998 Mtetra
.53405 .23998 .54042 .24781 .55231 .2435 .54597 .23564 Mtetra
.54597 .23564 .55231 .2435 .56426 .23918 .55795 .23128 Mtetra
.55795 .23128 .56426 .23918 .57626 .23484 .56998 .22691 Mtetra
.56998 .22691 .57626 .23484 .5883 .23049 .58207 .22252 Mtetra
.58207 .22252 .5883 .23049 .6004 .22613 .5942 .21812 Mtetra
.657 .753 .92 r
.5942 .21812 .6004 .22613 .61256 .22174 .60639 .2137 Mtetra
.60639 .2137 .61256 .22174 .62476 .21734 .61863 .20926 Mtetra
.61863 .20926 .62476 .21734 .63702 .21292 .63093 .2048 Mtetra
.657 .752 .92 r
.63093 .2048 .63702 .21292 .64933 .20848 .64328 .20033 Mtetra
.64328 .20033 .64933 .20848 .6617 .20402 .65568 .19583 Mtetra
.65568 .19583 .6617 .20402 .67412 .19955 .66814 .19132 Mtetra
.66814 .19132 .67412 .19955 .68659 .19505 .68065 .18679 Mtetra
.68065 .18679 .68659 .19505 .69912 .19054 .69322 .18224 Mtetra
.69322 .18224 .69912 .19054 .71171 .18601 .70584 .17767 Mtetra
.70584 .17767 .71171 .18601 .72435 .18146 .71852 .17308 Mtetra
.71852 .17308 .72435 .18146 .73705 .17689 .73126 .16848 Mtetra
.723 .759 .254 r
.05086 .45187 .06614 .40534 .07564 .40515 .06822 .39745 Mtetra
.568 .692 .924 r
.06822 .39745 .07564 .40515 .08537 .40373 .07799 .39576 Mtetra
.251 .533 .919 r
.07799 .39576 .08537 .40373 .09672 .39056 .08726 .3982 Mtetra
.725 .956 .669 r
.08726 .3982 .09672 .39056 .10591 .3938 .09858 .38575 Mtetra
.559 .68 .919 r
.09858 .38575 .10591 .3938 .11584 .39183 .10846 .38423 Mtetra
.547 .689 .933 r
.10846 .38423 .11584 .39183 .12483 .39784 .11838 .38285 Mtetra
.748 .629 .728 r
.11838 .38285 .12483 .39784 .13659 .38179 .1296 .37137 Mtetra
.439 .56 .88 r
.1296 .37137 .13659 .38179 .14664 .37995 .13931 .37238 Mtetra
.592 .709 .925 r
.13931 .37238 .14664 .37995 .15673 .37813 .14947 .37011 Mtetra
.354 .59 .934 r
.14947 .37011 .15673 .37813 .16833 .36335 .15926 .37154 Mtetra
.624 .898 .591 r
.15926 .37154 .16833 .36335 .17781 .36775 .17062 .3595 Mtetra
.568 .681 .916 r
.17062 .3595 .17781 .36775 .18811 .36532 .18085 .35777 Mtetra
.601 .716 .925 r
.18085 .35777 .18811 .36532 .19839 .36349 .19122 .35527 Mtetra
.212 .505 .908 r
.19122 .35527 .19839 .36349 .20981 .35076 .20106 .35837 Mtetra
.735 .948 .638 r
.20106 .35837 .20981 .35076 .2198 .3527 .21267 .34453 Mtetra
.582 .692 .917 r
.21267 .34453 .2198 .3527 .2303 .35 .22312 .34244 Mtetra
.614 .723 .923 r
.22312 .34244 .2303 .35 .24084 .34741 .23371 .3396 Mtetra
.552 .693 .933 r
.23371 .3396 .24084 .34741 .24988 .36276 .24422 .33805 Mtetra
.686 .533 .673 r
.24422 .33805 .24988 .36276 .26254 .33659 .25563 .32682 Mtetra
.509 .618 .895 r
.25563 .32682 .26254 .33659 .27321 .33408 .26614 .32639 Mtetra
.62 .725 .921 r
.26614 .32639 .27321 .33408 .28398 .33093 .27692 .32336 Mtetra
.625 .73 .923 r
.27692 .32336 .28398 .33093 .29478 .32805 .28776 .3202 Mtetra
.574 .704 .93 r
.28776 .3202 .29478 .32805 .30502 .33385 .29857 .31816 Mtetra
.752 .631 .726 r
.29857 .31816 .30502 .33385 .31689 .31679 .31013 .30605 Mtetra
.477 .58 .879 r
.31013 .30605 .31689 .31679 .32781 .31422 .32086 .30642 Mtetra
.625 .727 .92 r
.32086 .30642 .32781 .31422 .33883 .3108 .33189 .3032 Mtetra
.639 .739 .921 r
.33189 .3032 .33883 .3108 .34991 .30722 .34299 .29962 Mtetra
.64 .74 .921 r
.34299 .29962 .34991 .30722 .36103 .30369 .35414 .296 Mtetra
.631 .735 .923 r
.35414 .296 .36103 .30369 .37217 .30073 .36534 .29259 Mtetra
.542 .687 .933 r
.36534 .29259 .37217 .30073 .38871 .17995 .37649 .29115 Mtetra
.45 .195 .435 r
.37649 .29115 .38871 .17995 .39486 .28906 .38814 .27967 Mtetra
.558 .658 .903 r
.38814 .27967 .39486 .28906 .40616 .28595 .39939 .27807 Mtetra
.636 .735 .919 r
.39939 .27807 .40616 .28595 .41753 .28217 .41078 .27446 Mtetra
.648 .745 .92 r
.41078 .27446 .41753 .28217 .42895 .2782 .42224 .27053 Mtetra
.653 .749 .92 r
.42224 .27053 .42895 .2782 .44043 .27412 .43374 .26646 Mtetra
.655 .751 .92 r
.43374 .26646 .44043 .27412 .45196 .26997 .4453 .2623 Mtetra
.657 .752 .92 r
.4453 .2623 .45196 .26997 .46354 .26575 .45691 .25807 Mtetra
.658 .753 .92 r
.45691 .25807 .46354 .26575 .47516 .2615 .46857 .25379 Mtetra
.659 .754 .92 r
.46857 .25379 .47516 .2615 .48684 .25723 .48028 .24948 Mtetra
.48028 .24948 .48684 .25723 .49857 .25293 .49204 .24516 Mtetra
.49204 .24516 .49857 .25293 .51034 .24863 .50385 .24081 Mtetra
.50385 .24081 .51034 .24863 .52217 .24431 .51571 .23646 Mtetra
.658 .753 .92 r
.51571 .23646 .52217 .24431 .53405 .23998 .52762 .23209 Mtetra
.52762 .23209 .53405 .23998 .54597 .23564 .53958 .22771 Mtetra
.53958 .22771 .54597 .23564 .55795 .23128 .5516 .22332 Mtetra
.5516 .22332 .55795 .23128 .56998 .22691 .56366 .21891 Mtetra
.56366 .21891 .56998 .22691 .58207 .22252 .57578 .21449 Mtetra
.57578 .21449 .58207 .22252 .5942 .21812 .58795 .21005 Mtetra
.657 .753 .92 r
.58795 .21005 .5942 .21812 .60639 .2137 .60018 .20559 Mtetra
.60018 .20559 .60639 .2137 .61863 .20926 .61245 .20111 Mtetra
.61245 .20111 .61863 .20926 .63093 .2048 .62478 .19662 Mtetra
.62478 .19662 .63093 .2048 .64328 .20033 .63717 .19211 Mtetra
.657 .752 .92 r
.63717 .19211 .64328 .20033 .65568 .19583 .64961 .18758 Mtetra
.64961 .18758 .65568 .19583 .66814 .19132 .66211 .18303 Mtetra
.66211 .18303 .66814 .19132 .68065 .18679 .67466 .17846 Mtetra
.67466 .17846 .68065 .18679 .69322 .18224 .68726 .17387 Mtetra
.68726 .17387 .69322 .18224 .70584 .17767 .69993 .16927 Mtetra
.69993 .16927 .70584 .17767 .71852 .17308 .71265 .16464 Mtetra
.71265 .16464 .71852 .17308 .73126 .16848 .72542 .15999 Mtetra
.603 .41 .593 r
.04992 .39873 .05086 .45187 .06822 .39745 .06093 .38838 Mtetra
.495 .622 .906 r
.06093 .38838 .06822 .39745 .07799 .39576 .07051 .38814 Mtetra
.553 .691 .931 r
.07051 .38814 .07799 .39576 .08726 .3982 .08032 .38666 Mtetra
.793 .682 .742 r
.08032 .38666 .08726 .3982 .09858 .38575 .09178 .37339 Mtetra
.328 .452 .834 r
.09178 .37339 .09858 .38575 .10846 .38423 .10103 .37659 Mtetra
.581 .703 .926 r
.10103 .37659 .10846 .38423 .11838 .38285 .11104 .37455 Mtetra
0 .272 .769 r
.11104 .37455 .11838 .38285 .1296 .37137 .1201 .38054 Mtetra
.802 .96 .636 r
.1201 .38054 .1296 .37137 .13931 .37238 .13198 .36437 Mtetra
.575 .691 .92 r
.13198 .36437 .13931 .37238 .14947 .37011 .14211 .36246 Mtetra
.571 .701 .93 r
.14211 .36246 .14947 .37011 .15926 .37154 .15229 .36057 Mtetra
.815 .7 .738 r
.15229 .36057 .15926 .37154 .17062 .3595 .164 .34568 Mtetra
.293 .403 .803 r
.164 .34568 .17062 .3595 .18085 .35777 .17355 .35004 Mtetra
.6 .712 .922 r
.17355 .35004 .18085 .35777 .19122 .35527 .18394 .34754 Mtetra
.57 .701 .93 r
.18394 .34754 .19122 .35527 .20106 .35837 .19431 .34565 Mtetra
.782 .672 .741 r
.19431 .34565 .20106 .35837 .21267 .34453 .20584 .33281 Mtetra
.404 .515 .857 r
.20584 .33281 .21267 .34453 .22312 .34244 .21591 .3347 Mtetra
.61 .718 .922 r
.21591 .3347 .22312 .34244 .23371 .3396 .2265 .33193 Mtetra
.604 .719 .926 r
.2265 .33193 .23371 .3396 .24422 .33805 .23714 .32927 Mtetra
.729 .268 0 r
.23714 .32927 .24422 .33805 .25563 .32682 .24624 .34462 Mtetra
.71 .824 .372 r
.24624 .34462 .25563 .32682 .26614 .32639 .25904 .31829 Mtetra
.6 .706 .918 r
.25904 .31829 .26614 .32639 .27692 .32336 .2698 .3157 Mtetra
.626 .73 .922 r
.2698 .3157 .27692 .32336 .28776 .3202 .28067 .31248 Mtetra
.614 .725 .925 r
.28067 .31248 .28776 .3202 .29857 .31816 .29157 .30953 Mtetra
0 .352 .827 r
.29157 .30953 .29857 .31816 .31013 .30605 .3019 .3153 Mtetra
.736 .913 .547 r
.3019 .3153 .31013 .30605 .32086 .30642 .31389 .2981 Mtetra
.6 .704 .917 r
.31389 .2981 .32086 .30642 .33189 .3032 .3249 .29546 Mtetra
.635 .735 .921 r
.3249 .29546 .33189 .3032 .34299 .29962 .33603 .29196 Mtetra
.64 .74 .921 r
.33603 .29196 .34299 .29962 .35414 .296 .34721 .2883 Mtetra
.637 .739 .922 r
.34721 .2883 .35414 .296 .36534 .29259 .35843 .2847 Mtetra
.614 .725 .925 r
.35843 .2847 .36534 .29259 .37649 .29115 .36968 .28166 Mtetra
.96 .71 .515 r
.36968 .28166 .37649 .29115 .38814 .27967 .38647 .1604 Mtetra
0 0 .305 r
.38647 .1604 .38814 .27967 .39939 .27807 .39259 .26982 Mtetra
.619 .719 .918 r
.39259 .26982 .39939 .27807 .41078 .27446 .40399 .26663 Mtetra
.644 .741 .92 r
.40399 .26663 .41078 .27446 .42224 .27053 .41547 .26277 Mtetra
.651 .747 .92 r
.41547 .26277 .42224 .27053 .43374 .26646 .42701 .25872 Mtetra
.654 .75 .92 r
.42701 .25872 .43374 .26646 .4453 .2623 .4386 .25455 Mtetra
.656 .752 .92 r
.4386 .25455 .4453 .2623 .45691 .25807 .45024 .25031 Mtetra
.658 .753 .92 r
.45024 .25031 .45691 .25807 .46857 .25379 .46193 .24602 Mtetra
.659 .754 .92 r
.46193 .24602 .46857 .25379 .48028 .24948 .47367 .24168 Mtetra
.47367 .24168 .48028 .24948 .49204 .24516 .48546 .23732 Mtetra
.48546 .23732 .49204 .24516 .50385 .24081 .49731 .23294 Mtetra
.49731 .23294 .50385 .24081 .51571 .23646 .5092 .22854 Mtetra
.658 .753 .92 r
.5092 .22854 .51571 .23646 .52762 .23209 .52114 .22414 Mtetra
.52114 .22414 .52762 .23209 .53958 .22771 .53314 .21972 Mtetra
.53314 .21972 .53958 .22771 .5516 .22332 .54519 .21529 Mtetra
.54519 .21529 .5516 .22332 .56366 .21891 .55729 .21085 Mtetra
.55729 .21085 .56366 .21891 .57578 .21449 .56944 .20639 Mtetra
.56944 .20639 .57578 .21449 .58795 .21005 .58165 .20191 Mtetra
.58165 .20191 .58795 .21005 .60018 .20559 .59391 .19741 Mtetra
.657 .753 .92 r
.59391 .19741 .60018 .20559 .61245 .20111 .60622 .1929 Mtetra
.60622 .1929 .61245 .20111 .62478 .19662 .61859 .18837 Mtetra
.61859 .18837 .62478 .19662 .63717 .19211 .63101 .18382 Mtetra
.657 .752 .92 r
.63101 .18382 .63717 .19211 .64961 .18758 .64349 .17925 Mtetra
.64349 .17925 .64961 .18758 .66211 .18303 .65603 .17467 Mtetra
.65603 .17467 .66211 .18303 .67466 .17846 .66862 .17006 Mtetra
.66862 .17006 .67466 .17846 .68726 .17387 .68126 .16543 Mtetra
.68126 .16543 .68726 .17387 .69993 .16927 .69396 .16079 Mtetra
.69396 .16079 .69993 .16927 .71265 .16464 .70672 .15612 Mtetra
.70672 .15612 .71265 .16464 .72542 .15999 .71954 .15144 Mtetra
.95 .626 .379 r
.04251 .39001 .04992 .39873 .06093 .38838 .0454 .43502 Mtetra
.731 .765 .263 r
.0454 .43502 .06093 .38838 .07051 .38814 .063 .38032 Mtetra
.568 .692 .924 r
.063 .38032 .07051 .38814 .08032 .38666 .07285 .37856 Mtetra
.253 .534 .92 r
.07285 .37856 .08032 .38666 .09178 .37339 .08219 .38096 Mtetra
.732 .96 .677 r
.08219 .38096 .09178 .37339 .10103 .37659 .09362 .3684 Mtetra
.559 .68 .919 r
.09362 .3684 .10103 .37659 .11104 .37455 .10358 .36682 Mtetra
.547 .689 .933 r
.10358 .36682 .11104 .37455 .1201 .38054 .11358 .36538 Mtetra
.748 .629 .728 r
.11358 .36538 .1201 .38054 .13198 .36437 .12491 .3538 Mtetra
.438 .559 .88 r
.12491 .3538 .13198 .36437 .14211 .36246 .13469 .35475 Mtetra
.592 .709 .925 r
.13469 .35475 .14211 .36246 .15229 .36057 .14494 .35242 Mtetra
.355 .59 .934 r
.14494 .35242 .15229 .36057 .164 .34568 .1548 .3538 Mtetra
.635 .906 .602 r
.1548 .3538 .164 .34568 .17355 .35004 .16627 .34165 Mtetra
.568 .681 .917 r
.16627 .34165 .17355 .35004 .18394 .34754 .17659 .33986 Mtetra
.601 .716 .925 r
.17659 .33986 .18394 .34754 .19431 .34565 .18705 .33729 Mtetra
.214 .506 .908 r
.18705 .33729 .19431 .34565 .20584 .33281 .19698 .34034 Mtetra
.743 .952 .646 r
.19698 .34034 .20584 .33281 .21591 .3347 .2087 .32638 Mtetra
.582 .692 .917 r
.2087 .32638 .21591 .3347 .2265 .33193 .21925 .32423 Mtetra
.614 .723 .923 r
.21925 .32423 .2265 .33193 .23714 .32927 .22992 .32132 Mtetra
.552 .692 .933 r
.22992 .32132 .23714 .32927 .24624 .34462 .24053 .3197 Mtetra
.686 .532 .672 r
.24053 .3197 .24624 .34462 .25904 .31829 .25205 .30837 Mtetra
.509 .618 .895 r
.25205 .30837 .25904 .31829 .2698 .3157 .26265 .30788 Mtetra
.62 .725 .921 r
.26265 .30788 .2698 .3157 .28067 .31248 .27353 .30477 Mtetra
.625 .73 .923 r
.27353 .30477 .28067 .31248 .29157 .30953 .28447 .30153 Mtetra
.574 .704 .93 r
.28447 .30153 .29157 .30953 .3019 .3153 .29537 .29943 Mtetra
.752 .631 .726 r
.29537 .29943 .3019 .3153 .31389 .2981 .30705 .2872 Mtetra
.476 .579 .879 r
.30705 .2872 .31389 .2981 .3249 .29546 .31788 .28751 Mtetra
.625 .727 .92 r
.31788 .28751 .3249 .29546 .33603 .29196 .32901 .28421 Mtetra
.639 .739 .921 r
.32901 .28421 .33603 .29196 .34721 .2883 .34021 .28056 Mtetra
.64 .74 .921 r
.34021 .28056 .34721 .2883 .35843 .2847 .35147 .27686 Mtetra
.631 .735 .923 r
.35147 .27686 .35843 .2847 .36968 .28166 .36277 .27337 Mtetra
.542 .687 .933 r
.36277 .27337 .36968 .28166 .38647 .1604 .37402 .27186 Mtetra
.445 .188 .43 r
.37402 .27186 .38647 .1604 .39259 .26982 .3858 .26027 Mtetra
.557 .658 .903 r
.3858 .26027 .39259 .26982 .40399 .26663 .39715 .2586 Mtetra
.636 .735 .92 r
.39715 .2586 .40399 .26663 .41547 .26277 .40865 .25491 Mtetra
.648 .745 .92 r
.40865 .25491 .41547 .26277 .42701 .25872 .42022 .25089 Mtetra
.653 .749 .92 r
.42022 .25089 .42701 .25872 .4386 .25455 .43184 .24674 Mtetra
.655 .751 .92 r
.43184 .24674 .4386 .25455 .45024 .25031 .44351 .24249 Mtetra
.657 .752 .92 r
.44351 .24249 .45024 .25031 .46193 .24602 .45523 .23817 Mtetra
.658 .753 .92 r
.45523 .23817 .46193 .24602 .47367 .24168 .46701 .23381 Mtetra
.659 .754 .92 r
.46701 .23381 .47367 .24168 .48546 .23732 .47883 .22942 Mtetra
.47883 .22942 .48546 .23732 .49731 .23294 .49071 .225 Mtetra
.49071 .225 .49731 .23294 .5092 .22854 .50263 .22057 Mtetra
.50263 .22057 .5092 .22854 .52114 .22414 .51461 .21613 Mtetra
.658 .753 .92 r
.51461 .21613 .52114 .22414 .53314 .21972 .52664 .21167 Mtetra
.52664 .21167 .53314 .21972 .54519 .21529 .53873 .2072 Mtetra
.53873 .2072 .54519 .21529 .55729 .21085 .55086 .20272 Mtetra
.55086 .20272 .55729 .21085 .56944 .20639 .56305 .19822 Mtetra
.56305 .19822 .56944 .20639 .58165 .20191 .5753 .19371 Mtetra
.5753 .19371 .58165 .20191 .59391 .19741 .58759 .18917 Mtetra
.657 .753 .92 r
.58759 .18917 .59391 .19741 .60622 .1929 .59994 .18462 Mtetra
.59994 .18462 .60622 .1929 .61859 .18837 .61235 .18005 Mtetra
.61235 .18005 .61859 .18837 .63101 .18382 .62481 .17547 Mtetra
.62481 .17547 .63101 .18382 .64349 .17925 .63732 .17086 Mtetra
.657 .752 .92 r
.63732 .17086 .64349 .17925 .65603 .17467 .6499 .16624 Mtetra
.6499 .16624 .65603 .17467 .66862 .17006 .66252 .16159 Mtetra
.66252 .16159 .66862 .17006 .68126 .16543 .67521 .15693 Mtetra
.67521 .15693 .68126 .16543 .69396 .16079 .68795 .15224 Mtetra
.68795 .15224 .69396 .16079 .70672 .15612 .70075 .14754 Mtetra
.70075 .14754 .70672 .15612 .71954 .15144 .7136 .14281 Mtetra
.501 .666 .937 r
.0349 .3822 .04251 .39001 .0454 .43502 .04452 .38155 Mtetra
.602 .408 .591 r
.04452 .38155 .0454 .43502 .063 .38032 .05563 .37111 Mtetra
.495 .622 .906 r
.05563 .37111 .063 .38032 .07285 .37856 .06528 .37081 Mtetra
.553 .691 .931 r
.06528 .37081 .07285 .37856 .08219 .38096 .07517 .36927 Mtetra
.794 .683 .742 r
.07517 .36927 .08219 .38096 .09362 .3684 .08674 .35588 Mtetra
.326 .451 .834 r
.08674 .35588 .09362 .3684 .10358 .36682 .09606 .35904 Mtetra
.581 .703 .926 r
.09606 .35904 .10358 .36682 .11358 .36538 .10616 .35695 Mtetra
0 .276 .771 r
.10616 .35695 .11358 .36538 .12491 .3538 .11527 .36289 Mtetra
.807 .963 .642 r
.11527 .36289 .12491 .3538 .13469 .35475 .12728 .3466 Mtetra
.575 .691 .92 r
.12728 .3466 .13469 .35475 .14494 .35242 .13749 .34463 Mtetra
.571 .701 .93 r
.13749 .34463 .14494 .35242 .1548 .3538 .14776 .34268 Mtetra
.816 .701 .738 r
.14776 .34268 .1548 .3538 .16627 .34165 .15959 .32767 Mtetra
.291 .402 .803 r
.15959 .32767 .16627 .34165 .17659 .33986 .16921 .33199 Mtetra
.6 .712 .923 r
.16921 .33199 .17659 .33986 .18705 .33729 .17969 .32942 Mtetra
.57 .701 .93 r
.17969 .32942 .18705 .33729 .19698 .34034 .19015 .32746 Mtetra
.783 .672 .742 r
.19015 .32746 .19698 .34034 .2087 .32638 .20179 .31451 Mtetra
.404 .514 .857 r
.20179 .31451 .2087 .32638 .21925 .32423 .21195 .31635 Mtetra
.61 .718 .922 r
.21195 .31635 .21925 .32423 .22992 .32132 .22263 .31351 Mtetra
.604 .719 .926 r
.22263 .31351 .22992 .32132 .24053 .3197 .23336 .31078 Mtetra
.722 .262 0 r
.23336 .31078 .24053 .3197 .25205 .30837 .24252 .32612 Mtetra
.719 .83 .381 r
.24252 .32612 .25205 .30837 .26265 .30788 .25547 .29963 Mtetra
.6 .706 .918 r
.25547 .29963 .26265 .30788 .27353 .30477 .26633 .29697 Mtetra
.626 .73 .922 r
.26633 .29697 .27353 .30477 .28447 .30153 .2773 .29367 Mtetra
.614 .725 .925 r
.2773 .29367 .28447 .30153 .29537 .29943 .28829 .29064 Mtetra
0 .354 .829 r
.28829 .29064 .29537 .29943 .30705 .2872 .29871 .29637 Mtetra
.743 .918 .555 r
.29871 .29637 .30705 .2872 .31788 .28751 .31083 .27904 Mtetra
.6 .704 .917 r
.31083 .27904 .31788 .28751 .32901 .28421 .32194 .27633 Mtetra
.635 .735 .921 r
.32194 .27633 .32901 .28421 .34021 .28056 .33317 .27275 Mtetra
.64 .74 .921 r
.33317 .27275 .34021 .28056 .35147 .27686 .34445 .26901 Mtetra
.637 .739 .922 r
.34445 .26901 .35147 .27686 .36277 .27337 .35579 .26533 Mtetra
.614 .725 .925 r
.35579 .26533 .36277 .27337 .37402 .27186 .36714 .26221 Mtetra
.961 .71 .512 r
.36714 .26221 .37402 .27186 .3858 .26027 .38419 .14048 Mtetra
0 0 .299 r
.38419 .14048 .3858 .26027 .39715 .2586 .39027 .25019 Mtetra
.619 .719 .918 r
.39027 .25019 .39715 .2586 .40865 .25491 .40178 .24691 Mtetra
.644 .741 .92 r
.40178 .24691 .40865 .25491 .42022 .25089 .41337 .24298 Mtetra
.651 .747 .92 r
.41337 .24298 .42022 .25089 .43184 .24674 .42502 .23884 Mtetra
.654 .75 .92 r
.42502 .23884 .43184 .24674 .44351 .24249 .43673 .23459 Mtetra
.656 .752 .92 r
.43673 .23459 .44351 .24249 .45523 .23817 .44848 .23026 Mtetra
.658 .753 .92 r
.44848 .23026 .45523 .23817 .46701 .23381 .46029 .22588 Mtetra
.659 .754 .92 r
.46029 .22588 .46701 .23381 .47883 .22942 .47215 .22145 Mtetra
.47215 .22145 .47883 .22942 .49071 .225 .48406 .217 Mtetra
.48406 .217 .49071 .225 .50263 .22057 .49602 .21253 Mtetra
.49602 .21253 .50263 .22057 .51461 .21613 .50803 .20805 Mtetra
.658 .753 .92 r
.50803 .20805 .51461 .21613 .52664 .21167 .5201 .20356 Mtetra
.5201 .20356 .52664 .21167 .53873 .2072 .53221 .19905 Mtetra
.53221 .19905 .53873 .2072 .55086 .20272 .54439 .19453 Mtetra
.54439 .19453 .55086 .20272 .56305 .19822 .55661 .18999 Mtetra
.55661 .18999 .56305 .19822 .5753 .19371 .56889 .18544 Mtetra
.56889 .18544 .5753 .19371 .58759 .18917 .58122 .18087 Mtetra
.58122 .18087 .58759 .18917 .59994 .18462 .59361 .17628 Mtetra
.657 .753 .92 r
.59361 .17628 .59994 .18462 .61235 .18005 .60605 .17167 Mtetra
.60605 .17167 .61235 .18005 .62481 .17547 .61855 .16704 Mtetra
.61855 .16704 .62481 .17547 .63732 .17086 .6311 .1624 Mtetra
.657 .752 .92 r
.6311 .1624 .63732 .17086 .6499 .16624 .64371 .15774 Mtetra
.64371 .15774 .6499 .16624 .66252 .16159 .65638 .15305 Mtetra
.65638 .15305 .66252 .16159 .67521 .15693 .6691 .14835 Mtetra
.6691 .14835 .67521 .15693 .68795 .15224 .68188 .14363 Mtetra
.68188 .14363 .68795 .15224 .70075 .14754 .69472 .13888 Mtetra
.69472 .13888 .70075 .14754 .7136 .14281 .70762 .13412 Mtetra
.559 .689 .927 r
.02724 .37433 .0349 .3822 .04452 .38155 .03701 .3727 Mtetra
.95 .625 .375 r
.03701 .3727 .04452 .38155 .05563 .37111 .03984 .41783 Mtetra
.739 .772 .272 r
.03984 .41783 .05563 .37111 .06528 .37081 .05768 .36285 Mtetra
.568 .692 .924 r
.05768 .36285 .06528 .37081 .07517 .36927 .06762 .36103 Mtetra
.255 .535 .92 r
.06762 .36103 .07517 .36927 .08674 .35588 .07702 .36339 Mtetra
.74 .964 .685 r
.07702 .36339 .08674 .35588 .09606 .35904 .08856 .35072 Mtetra
.559 .68 .919 r
.08856 .35072 .09606 .35904 .10616 .35695 .09861 .34907 Mtetra
.547 .689 .933 r
.09861 .34907 .10616 .35695 .11527 .36289 .10869 .34757 Mtetra
.748 .629 .728 r
.10869 .34757 .11527 .36289 .12728 .3466 .12013 .33589 Mtetra
.438 .559 .88 r
.12013 .33589 .12728 .3466 .13749 .34463 .12999 .33678 Mtetra
.592 .709 .925 r
.12999 .33678 .13749 .34463 .14776 .34268 .14032 .33439 Mtetra
.356 .59 .934 r
.14032 .33439 .14776 .34268 .15959 .32767 .15026 .33572 Mtetra
.645 .914 .613 r
.15026 .33572 .15959 .32767 .16921 .33199 .16185 .32346 Mtetra
.567 .681 .917 r
.16185 .32346 .16921 .33199 .17969 .32942 .17226 .3216 Mtetra
.601 .716 .925 r
.17226 .3216 .17969 .32942 .19015 .32746 .1828 .31896 Mtetra
.217 .507 .908 r
.1828 .31896 .19015 .32746 .20179 .31451 .19281 .32196 Mtetra
.75 .956 .653 r
.19281 .32196 .20179 .31451 .21195 .31635 .20465 .30789 Mtetra
.582 .692 .917 r
.20465 .30789 .21195 .31635 .22263 .31351 .21529 .30567 Mtetra
.614 .723 .923 r
.21529 .30567 .22263 .31351 .23336 .31078 .22606 .30268 Mtetra
.552 .692 .933 r
.22606 .30268 .23336 .31078 .24252 .32612 .23677 .301 Mtetra
.686 .532 .672 r
.23677 .301 .24252 .32612 .25547 .29963 .24839 .28955 Mtetra
.509 .618 .896 r
.24839 .28955 .25547 .29963 .26633 .29697 .25909 .289 Mtetra
.62 .725 .921 r
.25909 .289 .26633 .29697 .2773 .29367 .27007 .28581 Mtetra
.625 .73 .923 r
.27007 .28581 .2773 .29367 .28829 .29064 .28111 .2825 Mtetra
.574 .704 .93 r
.28111 .2825 .28829 .29064 .29871 .29637 .29211 .28032 Mtetra
.752 .632 .727 r
.29211 .28032 .29871 .29637 .31083 .27904 .30391 .26798 Mtetra
.476 .579 .879 r
.30391 .26798 .31083 .27904 .32194 .27633 .31483 .26823 Mtetra
.625 .727 .92 r
.31483 .26823 .32194 .27633 .33317 .27275 .32607 .26485 Mtetra
.639 .739 .921 r
.32607 .26485 .33317 .27275 .34445 .26901 .33738 .26112 Mtetra
.64 .74 .921 r
.33738 .26112 .34445 .26901 .35579 .26533 .34874 .25734 Mtetra
.631 .735 .923 r
.34874 .25734 .35579 .26533 .36714 .26221 .36015 .25377 Mtetra
.543 .687 .933 r
.36015 .25377 .36714 .26221 .38419 .14048 .37151 .25218 Mtetra
.439 .181 .424 r
.37151 .25218 .38419 .14048 .39027 .25019 .3834 .24048 Mtetra
.557 .658 .904 r
.3834 .24048 .39027 .25019 .40178 .24691 .39487 .23873 Mtetra
.636 .735 .92 r
.39487 .23873 .40178 .24691 .41337 .24298 .40648 .23495 Mtetra
.648 .745 .92 r
.40648 .23495 .41337 .24298 .42502 .23884 .41816 .23085 Mtetra
.653 .749 .92 r
.41816 .23085 .42502 .23884 .43673 .23459 .42989 .22661 Mtetra
.655 .751 .92 r
.42989 .22661 .43673 .23459 .44848 .23026 .44168 .22227 Mtetra
.657 .752 .92 r
.44168 .22227 .44848 .23026 .46029 .22588 .45352 .21787 Mtetra
.658 .753 .92 r
.45352 .21787 .46029 .22588 .47215 .22145 .46541 .21342 Mtetra
.659 .754 .92 r
.46541 .21342 .47215 .22145 .48406 .217 .47735 .20894 Mtetra
.47735 .20894 .48406 .217 .49602 .21253 .48935 .20443 Mtetra
.48935 .20443 .49602 .21253 .50803 .20805 .50139 .19991 Mtetra
.50139 .19991 .50803 .20805 .5201 .20356 .51349 .19538 Mtetra
.658 .753 .92 r
.51349 .19538 .5201 .20356 .53221 .19905 .52565 .19083 Mtetra
.52565 .19083 .53221 .19905 .54439 .19453 .53785 .18627 Mtetra
.53785 .18627 .54439 .19453 .55661 .18999 .55012 .18169 Mtetra
.55012 .18169 .55661 .18999 .56889 .18544 .56243 .1771 Mtetra
.56243 .1771 .56889 .18544 .58122 .18087 .5748 .17249 Mtetra
.5748 .17249 .58122 .18087 .59361 .17628 .58722 .16786 Mtetra
.657 .753 .92 r
.58722 .16786 .59361 .17628 .60605 .17167 .5997 .16322 Mtetra
.5997 .16322 .60605 .17167 .61855 .16704 .61224 .15855 Mtetra
.61224 .15855 .61855 .16704 .6311 .1624 .62483 .15387 Mtetra
.62483 .15387 .6311 .1624 .64371 .15774 .63748 .14917 Mtetra
.657 .752 .92 r
.63748 .14917 .64371 .15774 .65638 .15305 .65019 .14444 Mtetra
.65019 .14444 .65638 .15305 .6691 .14835 .66295 .1397 Mtetra
.66295 .1397 .6691 .14835 .68188 .14363 .67577 .13493 Mtetra
.67577 .13493 .68188 .14363 .69472 .13888 .68865 .13015 Mtetra
.68865 .13015 .69472 .13888 .70762 .13412 .70159 .12535 Mtetra
.513 .643 .914 r
.01967 .36548 .02724 .37433 .03701 .3727 .02931 .36475 Mtetra
.501 .666 .937 r
.02931 .36475 .03701 .3727 .03984 .41783 .03901 .36405 Mtetra
.6 .405 .59 r
.03901 .36405 .03984 .41783 .05768 .36285 .05023 .3535 Mtetra
.494 .622 .906 r
.05023 .3535 .05768 .36285 .06762 .36103 .05995 .35315 Mtetra
.553 .691 .931 r
.05995 .35315 .06762 .36103 .07702 .36339 .06992 .35154 Mtetra
.795 .684 .742 r
.06992 .35154 .07702 .36339 .08856 .35072 .08161 .33805 Mtetra
.325 .45 .834 r
.08161 .33805 .08856 .35072 .09861 .34907 .091 .34116 Mtetra
.581 .703 .926 r
.091 .34116 .09861 .34907 .10869 .34757 .10118 .339 Mtetra
0 .279 .774 r
.10118 .339 .10869 .34757 .12013 .33589 .11035 .34491 Mtetra
.813 .966 .649 r
.11035 .34491 .12013 .33589 .12999 .33678 .12248 .3285 Mtetra
.575 .691 .92 r
.12248 .3285 .12999 .33678 .14032 .33439 .13278 .32645 Mtetra
.571 .701 .93 r
.13278 .32645 .14032 .33439 .15026 .33572 .14314 .32444 Mtetra
.816 .702 .738 r
.14314 .32444 .15026 .33572 .16185 .32346 .15509 .30931 Mtetra
.289 .401 .803 r
.15509 .30931 .16185 .32346 .17226 .3216 .16479 .31359 Mtetra
.6 .712 .923 r
.16479 .31359 .17226 .3216 .1828 .31896 .17535 .31095 Mtetra
.57 .701 .93 r
.17535 .31095 .1828 .31896 .19281 .32196 .1859 .30892 Mtetra
.784 .673 .742 r
.1859 .30892 .19281 .32196 .20465 .30789 .19767 .29585 Mtetra
.403 .514 .857 r
.19767 .29585 .20465 .30789 .21529 .30567 .20791 .29763 Mtetra
.61 .718 .922 r
.20791 .29763 .21529 .30567 .22606 .30268 .21869 .29472 Mtetra
.604 .719 .926 r
.21869 .29472 .22606 .30268 .23677 .301 .22951 .29192 Mtetra
.716 .255 0 r
.22951 .29192 .23677 .301 .24839 .28955 .23873 .30725 Mtetra
.727 .837 .39 r
.23873 .30725 .24839 .28955 .25909 .289 .25183 .28059 Mtetra
.6 .706 .918 r
.25183 .28059 .25909 .289 .27007 .28581 .26279 .27786 Mtetra
.626 .73 .922 r
.26279 .27786 .27007 .28581 .28111 .2825 .27385 .27449 Mtetra
.614 .725 .925 r
.27385 .27449 .28111 .2825 .29211 .28032 .28495 .27138 Mtetra
.001 .357 .83 r
.28495 .27138 .29211 .28032 .30391 .26798 .29545 .27706 Mtetra
.75 .923 .563 r
.29545 .27706 .30391 .26798 .31483 .26823 .3077 .2596 Mtetra
.6 .704 .917 r
.3077 .2596 .31483 .26823 .32607 .26485 .31892 .25681 Mtetra
.635 .735 .921 r
.31892 .25681 .32607 .26485 .33738 .26112 .33025 .25315 Mtetra
.64 .74 .921 r
.33025 .25315 .33738 .26112 .34874 .25734 .34164 .24933 Mtetra
.637 .739 .922 r
.34164 .24933 .34874 .25734 .36015 .25377 .35309 .24556 Mtetra
.614 .725 .925 r
.35309 .24556 .36015 .25377 .37151 .25218 .36455 .24237 Mtetra
.962 .71 .509 r
.36455 .24237 .37151 .25218 .3834 .24048 .38185 .12017 Mtetra
0 0 .293 r
.38185 .12017 .3834 .24048 .39487 .23873 .38791 .23016 Mtetra
.619 .719 .918 r
.38791 .23016 .39487 .23873 .40648 .23495 .39953 .2268 Mtetra
.644 .741 .92 r
.39953 .2268 .40648 .23495 .41816 .23085 .41123 .22278 Mtetra
.651 .747 .92 r
.41123 .22278 .41816 .23085 .42989 .22661 .423 .21855 Mtetra
.654 .75 .92 r
.423 .21855 .42989 .22661 .44168 .22227 .43482 .21421 Mtetra
.656 .752 .92 r
.43482 .21421 .44168 .22227 .45352 .21787 .44669 .2098 Mtetra
.658 .753 .92 r
.44669 .2098 .45352 .21787 .46541 .21342 .45861 .20532 Mtetra
.659 .754 .92 r
.45861 .20532 .46541 .21342 .47735 .20894 .47059 .20081 Mtetra
.47059 .20081 .47735 .20894 .48935 .20443 .48262 .19627 Mtetra
.48262 .19627 .48935 .20443 .50139 .19991 .4947 .1917 Mtetra
.4947 .1917 .50139 .19991 .51349 .19538 .50684 .18713 Mtetra
.658 .753 .92 r
.50684 .18713 .51349 .19538 .52565 .19083 .51903 .18254 Mtetra
.51903 .18254 .52565 .19083 .53785 .18627 .53127 .17794 Mtetra
.53127 .17794 .53785 .18627 .55012 .18169 .54357 .17333 Mtetra
.54357 .17333 .55012 .18169 .56243 .1771 .55592 .16869 Mtetra
.55592 .16869 .56243 .1771 .5748 .17249 .56832 .16405 Mtetra
.56832 .16405 .5748 .17249 .58722 .16786 .58079 .15938 Mtetra
.58079 .15938 .58722 .16786 .5997 .16322 .5933 .15469 Mtetra
.657 .753 .92 r
.5933 .15469 .5997 .16322 .61224 .15855 .60588 .14999 Mtetra
.60588 .14999 .61224 .15855 .62483 .15387 .61851 .14527 Mtetra
.61851 .14527 .62483 .15387 .63748 .14917 .63119 .14052 Mtetra
.657 .752 .92 r
.63119 .14052 .63748 .14917 .65019 .14444 .64394 .13576 Mtetra
.64394 .13576 .65019 .14444 .66295 .1397 .65674 .13098 Mtetra
.65674 .13098 .66295 .1397 .67577 .13493 .6696 .12617 Mtetra
.6696 .12617 .67577 .13493 .68865 .13015 .68252 .12135 Mtetra
.68252 .12135 .68865 .13015 .70159 .12535 .6955 .1165 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`002Woo00=jcgooOol0EGoo00=Bo5;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<0
00=oo`03001oogoo00Moo`03N]1oogoo05=oo`0GD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d005;mD_aBo@0GOol00`00Oomoo`17Ool008Moo`<0011oo`03NZmoogoo051oo`05D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00U;l5goo00<007oo
Ool0AWoo0025Ool2000COol00g[@Oomoo`1<Ool085;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_dFOol00`00Oomoo`16Ool0089oo`<001Eo
o`03N/l02Goo04Yoo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`00e;mD_aoo`0FOol00`00Oomoo`15Ool0081oo`8001Qoo`03N]0027oo
04Qoo`0UD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_`05goo00<007ooOol0A7oo001mOol3000JOol00gZ_00Qoo`14Ool0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;l001Bo5;m00=Bo003D_eBo7oo01Eoo`03001oogoo04Aoo`00Ngoo0P000Woo00<007oo
Ool067oo00=jd008Ool0@Woo02aBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;m5goo00<007ooOol0
@goo001hOol3000NOol2N/l00`09Oomoo`0oOol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;l
D_aBo@0GOol00`00Oomoo`12Ool007Ioo`80025oo`03MZmjd00803eoo`0dD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`12Ool007=oo`<002=oo`03N/mj
[`0803]oo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo004D_eBo5;lD_`GOol0
0`00Oomoo`11Ool0075oo`8002Ioo`04MZmjd008=:dhOol0>E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo00EOol00`00Ool00012Ool006ioo`<002Qoo`9j
c`0300Td[7oo03=oo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;l
D_aBo@03D_`015;mD_aBo5;l5Woo00<007ooOol0@7oo001[Ool3000[Ool017J_N]0023B]<Woo041B
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoAMoo`03001oogoo03moo`00JGoo0P000goo00<007ooOol0:7oo00AjcgZ_00Pd[2moo`03
D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03
D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol0?goo001VOol3000`Ool017J_N]1f[cB]:goo04UB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
05;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0FOol00`00Oomoo`0nOol006Aoo`80039oo`05NZmjcg[?
N/ld[00YOol00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`FOol00`00Oomoo`0mOol0
065oo`<003Aoo`06N]1f[g[@MZld[CB/9Woo04mBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@0EOol00`00Oomoo`0UOol3000EOol003Eoo`@002Ioo`8003Moo`9jc`04NZmjccB/=:dR
Ool00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0E
Ool00`00Oomoo`0VOol00`00Oomoo`0COol003Aoo`03001oogoo009oo`03001oogoo021oo`<003Uo
o`06N]1f[g[@MZld[CB/8Goo05EBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo00FOol00`00Oomoo`0UOol00`00Oomoo`0COol003Uoo`03001oogoo01ioo`80009o
o`03001oogoo03Moo`06NZmjcg[?N/ld[3B]7goo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005
D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Eoo`03001oogoo02Aoo`03001oo`0001Aoo`00;7oo
1P001goo00<007ooOol06goo0`00?Woo00Ijd7J_N]1f[cB]=:`KOol0G5;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`0S
Ool00`00Ool0000DOol003Eoo`@001aoo`80045oo`9jc`04NZmjc`08=:dIOol2D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0F
Ool00`00Oomoo`0QOol01@00Oomoogoo00004goo000eOol00`00Oomoo`0JOol30013Ool01W[@MZmj
d7J_00Td[1Moo`1RD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`8002=oo`05001oogooOol0000COol003Eoo`03
001oogoo01Moo`<004Eoo`03N/mj[g[?009jc`0300Pd[CB]019oo`9Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@0EOol00`00Oomoo`0OOol3000017oo000000004Woo000eOol5000COol20018Ool027J_
N]1f[g[@MZl02CB/><d@Ool0JE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomo
o`0gOol004Yoo`<00003Ool007oo04Moo`=jc`03NZmjc`08008d[@ioo`05D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`08Ool4000[Ool004Qoo`8004eoo`08MZmj
d7J_N]1f[`09=:`h[@Yoo`1`D_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_dFOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004Eoo`<004moo`03N/mj[g[?
009jc`0300Pd[CB]00Qoo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@02D_`FOol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004=oo`80059oo`08
MZmjd7J_N]1f[`09=8`hc@Ioo`1eC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo02Qoo`00@7oo
0`00E7oo0g[?00=j[g[?00P00SB]0Woo00EBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol0:7oo000nOol2001GOol0QGJ_N]1f[g[@MZl02D[LC]e:g4kMB]aBoDkLD_e>g5;mC]aB
oE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00>goo1000Egoo0W[?00Aj[g[?N/mjc`802007
C]a>gDkLC]a>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo01Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00
>Goo0P0017oo00<007ooOol0E7oo08Qjd7J_N]1f[g[@MZl02@0800U:g4kMB]a>gDkLD_e>g5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03
001oogoo00=oo`@002]oo`00=Woo0`00GGoo00Qj[g[?N/mjcgZ_N/l020090P0800M>g4kmC]a>o5;l
D_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@0COol200000goo001oo`0bOol003=oo`<0061oo`29N]1f[g[@MZmjd7J_N]12W4JL@Y]6W4kL
D_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@0EOol00`00Oomoo`0aOol0035oo`8005moo`07C]a>gD[LC]e>g7[?NZl00W[?00=j
d7Z_AY`00dJL00M>o4kLC_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d00000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0`Ool002ioo`<005eoo`1cD_e>g5;m
C]aBoD[LC]e:g4kmMZmjd7J_N]1f[g[@00Q6W4:LAYa2Ve;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d00`0001eBoE;l001Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Eoo`03001oogoo
02moo`00;7oo1000G7oo00m>o5;mC]a>oDklD_e>g4kMC]a>gD[LC]ejcg[@NZl00W[?00X02DkLC]a>
g4kMC]aBo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00`0000IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`0_Ool002Yoo`8005ioo`1aD_e>g5;mC]aBoDkLD_e>
g5;mC]a6_D:lA[ef[g[@MZmjd7J_N]002009B]a>gD[LC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@03000095;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo
02ioo`00:Woo0P00Fgoo00I>oDkLC_a>g5;mC]`2C_`01U;mC]a>oDkLC_e>g092_@0>N]1j[g[?N/mj
d7Z_00T02009C]a>o4kLC_e>g09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_`00000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Eoo`03001oogoo02ioo`0047oo1@000goo1000
17oo10001Woo00<007oo0000EWoo07=:_4[MB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>
g4JmMZmjd7J_N]1f[g[@@Y]6W4:LAYa>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo0030000:U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo02eoo`00
4Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`800003Ool0
07oo05=oo`09Gi5O/DZlB]a:_4[LB[aBoDkL009>o00:D_e>g4klC_aBoDkLC_e>g4kmC]`2N/l01G[@
NZmjcg[?00T014JL00A>g4klC]a>o@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo0000080
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`05Goo00<007ooOol0;7oo000BOol00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo0P000goo00<007ooOol0D7oo
06mOTEnaFi5>gDZlB]e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>gD[LN]1f[g[@MZmjd008
AYa2VdJL@Ya6W4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`00039Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol0;7oo0007Ool60005Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0Cgoo0Uif00DjFcXkC]a>g4kM009>g003C_aBoDkL009>o00:D_e>g4kmC_aBoD[LC]e>g4kM
NZl2N/l01G[@MZl02@09C]d00dkL00I>gDkLD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo000008000=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Aoo`03001oogoo02]o
o`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo04eoo`1ZGWMNMUjG>S/jFcXkC_e>g4kmB]a>oDkLD_e>g5;mC]aBoDkLD_e>
g5;mB]a>oD[LC]ef[g[@MZmjd00800T024kMB]a>gD[LD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`30000>E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00
Ool0000/Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02
Ool20006Ool20015Ool01dkLC]e:g4kMC]`1NP5I00ENMP07>S/jFcXk>U]>g4kmC]`00Tkl00YBoDkL
C_a>o4kmC]a>oDkLC_e2_@9jc`04N]1f[g[?N/l300T00dkLC]e>g002C]`01E;mC_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo000
008000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBoE;l57oo00<007ooOol0:Woo000@Ool30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol0?Woo071>oDkLC_e>g4kmB]a>gD[LC_e:g5ig
GWINUeifGWMNMTkMB[a:gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4JmMZmjd7J_N]1f[g[@
00P02@0800U>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo0<00010D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0YOol0019oo`03001o
ogoo00=oo`@000Aoo`@000Eoo`03001oogoo00Qoo`03001oogoo03Yoo`0=B]a:_4[MB[a>gDkLC]e>
g4kMA[e6gDJmA]d01Eif00YO/EnAB]a:_4[LB[a>o4kLC_e>g09>o00:D_e>g4klC_a>oDkLC_e>g7[@
MZl2N/l00g[@MZmjd004AY`01TkLC_e>g4klC]aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo006D_eBo5;lD_aBoE;l0`000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0X
Ool002Qoo`03001oogoo00Yoo`03001oogoo03Qoo`1_GdaK:dkMB[a:gDZlC]e>g4kmB]a>oDJlB]e6
_4[MGWINMeifGYMKT5naB[a>gDZlB]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kmB]ajd7J_N]1f
[g[@MZl02D:LAYa2VdJLC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m00800017D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00EOol00`00Oomoo`0XOol0
02Qoo`<000]oo`03001oogoo03Moo`03Fd]KC5];009>g00:C]e>g4kLC]a>gDkLC]e6_DKMA[d3GWH3
Gi401UnaC]a>g4kLC]e>g09>o00AD_e>g4klC_aBoDkLC_e>o4kMB]a>gDkLN]1f[g[@N/mjd00200T4
C]`00dklD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo003
0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo02Moo`00:7oo00<007ooOol0
37oo00<007ooOol0=Goo01=K:d9l?U]2O3iKC_e:g4kMB]a>oDkLC_e:g4kmA[a:gEifGYMKT002GWH0
ECiL>S/jFd[LC_e>g4kmB]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>oD[LN]1f[g[@MZl02@0800U:
g4kMB]a>gDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00<0001>D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol09Woo000XOol00`00Oomo
o`0=Ool00`00Oomoo`0[Ool2B]d00d[LB]eoo`04Ool00eHEEQ@nO002?W`3C]`02DkMC]a>gDkLC]e:
g4kMA[e6g@04GWH02CXk>U/j>cYK>S]>o4kLC_e>g002C_`01e;mC]a>oDklD_e>g4km0092_@06MZmj
d7[?N]1f[g[@0`091DkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo0030002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol0
02Qoo`8000moo`03001oogoo02Ioo`09C]e:g4kMB[a>gD[LC]e:g5T0009oo`0CE>1F5EHDEQDnFd9l
?U]2O4kLC_e>g4kmC]a>oD[LC]e:g05j0ET00Uif01aNUeifGWI:_4kMB[a:gDZlD_e>g5;mC]aBoDkL
D_e>g5;mC]a>oDkLD_e2_7[@MZmjd7J_N]1f[`<02@0b00QBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@<0001FD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo1Aoo`03001oogoo02Eoo`00:7oo00<007ooOol03goo00<007ooOol08Goo00URUV:g
<OXb6c7jC]e:g4kMB]`00d[M01E:g5SPF>1KC5HDEQEF55HEB[a:g4ZlB]e>g4kMC]a>gDkLC]e>g4kM
B]`01Eif00]KT5nAB[a:g4ZlB]a>g4klC]a>oDkL009>o00=D_e>g4kmC]a>oDkLC_ejcg[@MZmjd7[?
N]001DJL00M>o4kLC_e>g4klD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`00`000U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Goo00<007ooOol097oo000X
Ool00`00Oomoo`0@Ool00`00Oomoo`0OOol096:FH[MRUS8K<OXb6bgjC]e:g4kMB[a6gD:lA[eDh5T0
EQAF5E8DEQEF55];B[a>gDZlB]e>g4kmC]a>oD[LB]e6_4[MGWINU`=NMP19Gk5KT4[MB[a>gDZlB]e>
g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4kmMZmjd7J_N]1f[g[@@Y]6W4:LAYa>g5;mC]aBoDkLD_e>
o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_d00`0005eBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04goo0P009Woo000WOol00`00Oomoo`0BOol00`00Oomoo`0M
Ool01F:FH[MRUf:gHYH00S7j00Hb6c7jC]e>g4kMB]`3A[d055HDEQEF55HEEQAKBe/[B]e:_4[LB[a:
gDkLC]e>g4kMC]a6gDJmA]d3GWH01EnAFi1OTE^@C]d00dkL01A>gDkLC_a>o5;mC]a>oDklD_e>g4km
C]a>gD[LN]1jcg[@MZmjd7K@1DJL00E>g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l
57oo00<007ooOol08goo000WOol3000COol00`00Oomoo`0KOol09F:FH[MRUV:gHYIR]dJlB]e6_4Zm
A[a>oD[LC]e:g4KM@[a6_E8DEQEF55HEFb]KC5/[C]e:g4kmB]a>gD[LC_e>g4kmB]a:gDJl009NMP15
Gk5NMUif>S/nG3XkC_e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>gD[LN]1f[g[@MZmjd009
C]e:g4kMB]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<M00<0001TD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0ROol0
02Moo`03001oogoo01Aoo`03001oogoo00moo`04I[HQVB6H8IT4Ool04dJmA]e6_DJmHYMR]f:FH[MO
]5oDA[a:_4JlB[a6_4kMC]a>gD[L0096_@06EQEF55HEFb]F5Cik0Sil00a>gDkLC]a>g4kMB]a>gDkL
C]e:g4KMA[d4GWH01CYK>S/jFcXkC]d00dkL00YBoDkLC_a>o5;mC]a>oDklD_e>g092_@06N]1f[g[@
M]1jd7J_0P091DkL00E>o5;lD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo080009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol0
8Woo000EOol40004Ool40006Ool00`00Oomoo`0EOol00`00Oomoo`0=Ool0<VJfI]MV]R6I8GPUVDZl
B]e:_4kMA[a6gDJlH[MRUV:gFk=Oe5ndGmAK/dkMB]a>gDZlC]e:g4kMB]a6gEHDEQEB55HEEQA2O3iK
@W`nFd9lC]a>oDkLC_e:g4kmB]a>g@5I0GX3GWH06ejGGWHnFcXk?U`j>e;mC]aBoDkLD_e>g5;mC]aB
oDkLD_e>g4kmC]a6_GJ_N]1f[g[@MZmjd00400T07dkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l00<0001ZD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_dEOol00`00Oomoo`0QOol001Aoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`03Ool00`00Oomoo`0FOol2000=Ool00fKGI[IV]`028IT03B6H8IU:g4[MB]a:gDJmA]e6_F:g
GkAR]f:F008anP06<Q/anTkMB]a>gD[L0d[M01A2_EHEEQAKBeHDEQEF54[MB[a:g4ZlB]e>g4kMC]a>
gD[LC]e>g4kM1Eif0U^@00Y:g4ZlB]a:_4kmC]a>o4kLC_e>g09>o00<D_e>g4kmC]a>oDkLN]1fd7[@
MZmjd7K@1DJL00A>g4klC]a>o@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;l
D_aBo0<00003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0COol0
0`00Oomoo`0POol001Uoo`04001oogoo0004Ool00`00Oomoo`03Ool2000IOol00`00Oomoo`09Ool0
3FKGI[IVefJfI]LQN26I8GPUVD[LB]e:_4kM008Io00S5OaR]f:FH[MRUS8K<OXb6dZlC]e:g4kM@[a6
gD:lA[e2_5HEEQAF5E8DEQEG:d[MB[a>gDZlC_e>g4kmC]a:gDJlB]e6_002GWH0>UjGGWINMU^@Gi5:
_4[MB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LC]e:g7[@MZmjd7J_N]1f[dJL@Y]6W4:LD_e>
g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l0`00079Bo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`0POol000aoo`H0
00Moo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`07Ool01VKGI[IV
]fJfI]MV]PE6_003B]a:gD[L008Io005H[MRUV:gHYMR]`03<OX01S8KB]a>gDkLC]e2_@=6_@0CFb]F
5EHDEQEG:e/[B[a:gDZlB]a:_4kMC]a>gDkLA]e6_DKMA[d00eif15^@00=>g4kMC]`00TkL01=BoDkL
C_a>o5;mC]a>oDklD_e:g4kMC]a>gGJ_N]1fd7[@MZmjd005AY`01E;mC]aBo4klD_d00e;l00EBoE;l
D_aBo5;m00=Bo004D_eBo5;lD_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo01moo`005Goo10000goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol06goo00<007ooOol00goo03M:gDJlB]e6_6KGI[IVefJfDi=?
TTZmAYa6_DJLC]e:g4[MB[aR]f:FH[MRUV:gHYIR]dJlB]e6_4ZmB]a>oD[LC]e2_4KM@[aF5E8DEQEF
55];EbYKBd[LC]e:g4kmB]a>oD[LC_e>g4kmA[a:g@02GWH0<e^@GYMNMSiK>S/nG4kLC_e:g4kmC]aB
oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>gGJ_N]1f[g[@MZl02T[LC]e:g4kMB]aBoDkLD_e>g5;mC]aB
oE;lD_e>o5;mD_aBoDklD_eBo0030000NE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01moo`005Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo0P007Goo0VOD00E:_DJlA[a6_4KM0096_@08I[IVefJfI[MV
]R6I8IPQV@=6_096_@0MA]e6_F:gHYMR]f:FH[MO]5oDA[a:_4JlB[a:g4kMC]a>gD:mA[eF55HEEQAK
:eHD?W`nNcilC]a>g@03C]`01dkMB]a>gDkLC]e6_DKM00ANMP06>S/jFcXk>U]>g4kM0TkL00=>o5;m
C]`00Tkl00EBoDkLC_e>o5;m0092_@06M]1jd7J_N]1fd7[@0P091DkL00EBoDklD_aBo5;m00=Bo004
D_eBo5;lD_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Aoo`03001oogoo01ioo`005Goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol077oo03iW/fODIm=:_DJlB[e6_4[MA[a:gFJfI]MV
]VKG8GPUVB5h9IU:_4[MB[a:gDJlA]e6_6:gHYIR]e^cGmAK/eoDB[a>gD[LC]e:g4kMB]a>gD:lEQEF
55HEDQAF5CiK@W`nFd9l?U]>oDkLC_e>g4kMB]a>oD[L0EX1FEjG0eif02YNUcXk?U/j>ciLC]aBoDkL
D_e>g5;mC]aBoDkLC_e>g5;mC]a>oD:LN]1f[g[@MZmjd7J_00X02@0:C]aBoDkLD_e>g5;mC]aBoDkL
D_e>g5;mD_`30000PE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0MOol001Eoo`D000=oo`@0
00Eoo`03001oogoo01]oo`EWe005B]e:_4[MB]`^G@02:Ud016JfI]MV]VJg0R6I00DQV4[MB]a:gD[L
0096_@06A]eRUV:gGkAR]f:F0S7j00Hb6d[LC]e:g4kMB]`2B]d054JmEQAF5E/[EQEF55HEB[a:gDZl
B]a:_4kMC]a>gDkLC]e:g4kMC]`5GWH2Fi001dZlB]a:_4[LC]a>oDkL009>o00?D_e>g4klC_a>oDkL
C_e>g4kmMZmjd7K@N]1f[g[@00A6W006C]a>oDkLC_a>g5;m0e;l0`0000=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_aBo00COol2000OOol002Ioo`03001oogoo00moo`04I[LU^BWJ9KT7Ool0?VNcGYMNMSHk
=Q/f?3HkB]e6_4[M:Ud^GFJfI]MV]VKGI[HUVB5h9ITQN4kMB]a:gDZl6Q`Eo1Wl5OaR]f:FH[L]nS8K
<OY>gDZlC]e:g4kM@[a6gD:lA[eB55HEEQAF5E8DFd]:_4[MB[a>gDkLC_e>g4kmC]a:gDJlB]d3GWH0
9ejGGWIKT5]_C]e:_4[MB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[LC]ef[g[@MZmjd7J_00Y2
W4JL@Y]BoDkLD_e>g5;mC]aBo@020000R4klD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo
00<007ooOol077oo000UOol00`00Ool0000?Ool02FJgH[IR]bFj:MXU^DZmA[e:g@03Ool0104HGWIN
MUif0cHk00]:g4[MB[a:gFJfI]MV]VJgI[IVefJf00A6_004B]e:g4[MB]`26O`01F:gHYIR]f:GH[L0
0c7j00I>gD[LC]e>g4kM@[d2A[d04e/[EQAF5EHDFb]G:UL[B[a:gDZlB]a>g4kMC]a>gDkLA]e6_DKM
00=NMPAKT09>g006C]e>g4kLC_aBoDkL0Tkl00iBoDkLC_e>o4kMB]a>gDkLN]1f[g[@M]1jd00914JL
00=Bo4klD_d00`0000EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00DOol00`00
Oomoo`07Ool5000?Ool002Eoo`80011oo`1^H[IV]f:F:MXU^BWJA[a:gDJlB]d0m`4HGWINMeYfGYMN
MSHk=Q/f?4JlB]e6_4[MI[IVefJfI]MV]U>CCg9:_DJLA[e:_4kMB]a:gDZlH[MRUV:gHYIR]f:FB[e6
_4[MA[a>gD[LC_e:g4Jm@[a6gEHDEQEB55HEEbYK:eLZFd]:g4kMB]a>oDkLC_e:g4kmC]a:gDJlGYMN
MU^@GWINUcXk?U/j>dkmC]a>oD[LD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC_e:g7[@MZmjd7J_00X0
2DkMB]a>g@<0002>D_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol0
0`00Oomoo`07Ool01@00Oomoogoo00003goo000UOol00`00Oomoo`0>Ool01F:fH[MR]fJgH[H00RFj
00DYfTJlB[e6_D[M00ENMP03ImAWddZm0096_00;A[e6gDJmA[eV]VKGI[IV]b6I9ITQV003A[`3A[d0
5dKMA[eR]f:GH[MRUUncFk=:_4JlB[a6_4ZlB]a>gDkLA[e2_EHEEQAF5ELZEQD00Sil00@nNcilC]a>
g@=>g006C]e:g4kMC]a6gDJm15if00<jFcXk>U/00dkL00I>gDkLC_a>o5;mC]`2C_`00e;mC]a>o@03
@[d01g[@M]1jd7J`N]002@0:00<000=>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoE;lOol04goo00<007ooOol01goo00<007ooOol047oo000UOol00`00Oomoo`0=
Ool0D6:fI[MRUVJgH[IV]d:LA[e6W4Jm@[a6_D:lGWMJMUjGGWINMf>cImA6_4ZmA[a:_DJlB]e6_6KG
I[IVefJfI]LQV2FI8GQ>gDZlB]e6_4[MA[a6gF:FH[MRUUoDFk=Oe5^cC]e:_4kMB]a>gD[LC]e:g4Jm
DQAF5EHDEQEB549l?U]2O3iK@Wa>g4kmC]a>oD[LC]e:g4km0ET1FUifGYL3GWH05ciK>S/nFdkLD_e>
g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e2_DJmMZmjd7J_N]000`0009H02P09D_e>g5;mC]aBoDkLD_e>
g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`07Ool00`00
Oomoo`0?Ool002Eoo`8000Moo`DnO007A[e2_DJmH[MV]f:fH[L00UoE0dJl00A6_D:mA[e2_@=NMP09
Im=We6OCImA:g4[MB[a:gD[L00<ZG@03I[IVefJf008QV@069IU:g4[MB]a:gD[L0TJm00E6gF:FGk=R
Uf:g00<anP0KC]e:g4kMB]a:gD[LB]e6_EHEEQAG:eHDEQEF54[LB[a:gDZlB]a>g4kMC]a>gDkLC]e:
g4kM00ENMP0:Fi1KKd[LB[a:g4kLC_a>g4kmC]`2C_`02E;mC]a>o4kLC_e>g4kmC]ajd00300000g[@
AYa6W003AY`01dklC]a>oDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoGooOol04Woo00<007ooOol027oo00<007ooOol03Woo000UOol00`00Oomoo`05Ool0ETUaCI8j
O3il>U/nO4:lA[e2_6JgH[IV]f:FI[LU^BWJ@Ya6_DJLA[e2_4JmGWINMf>cGYMNMSHk=Q/f?4ZlB]e6
_4[M:Ud^GFJfI]MV]VKGI[HUVB6H9IU:_4kMB]a:gDZl6Q`Eo1WlHYIR]f:F<Q/]nS8KB]a>gDZlC]e:
g4Jm@[a6gD:lEQEB55HEEQAF5EL:C]e:_4[MB[a>oDkLC_e>g4kmA[a:gDJlGYL3GWH04ejGEfmKT4Zl
C]e:_4[MB[aBoDkLD_e>g5;mC]aBoDkLD_e:g4kM00<0002MN]1f[g[@MZmjd4:KAYa2W4JLC]aBoDkL
D_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d057oo00<007oo
Ool027oo00<007ooOol03Goo000UOol00`00Oomoo`04Ool4BI84?W`2A[d03T:mH[LN76JgH[IR]bFj
:MY6_4ZmA[e:gD:mA[d4GWH5=S/02D[MB[a:gFJfI]MV]VJgI[IVe`04A[`014[LB]e:g4[M0QWl00=R
Uf:gHYH00V:G00lb6c7j<OY>g4kMB]a>gDkLA[e2_DJmEbYF5EHDEQD015LZ00]:_4[MB[a>gDkLC]e>
g4kMA[e6gDJm00=NMP04FfmKT5^@Fi03C]`02DkMC]a>o4klD_e>g4kmC_aBo@0300002TkMB]a>gGK@
N]1f/7[@M]002P090dJL00E>g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00ABoE;lD_aBo1Eoo`03001oogoo00=oo`05001oogooOol0000?Ool002Aoo`03001oogoo00Ao
o`1KBG5=TTVBBI99LDfBA[a6_DJlB]dN71hM7QaV]f:FI[MRURWJ9KTYfTJlB]e6_4[MFWINUeifGWMJ
MUjGA[a:_DJlB[e6_4[MA[a:gFJfI]MV]VKGCg9?TTJLB[e6W4JmAYa>gD[LB]eRUV:gHYIR]f:FGmAK
/dZmA[a:gD[LC]e:g4kmB]a6_D:lEQEF55HEDQA2O3iK@W`nFd9lB]a>gD[LC_e>g4kmB]a>oDJlB]eN
MUjGEfl00Uif00/nFcXk?U]:g4kmC]a>oD[LD_e>g5;m00<0002TD_e>g4kmB]a>gD[LC_ef[g[@MZmj
d00900X02DkMB]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo1Aoo`03001oogoo00Aoo`<0011oo`0097oo00D003jL?Wa2W3il008nW@I9TP08G`Q6_4Jm
A[a6_AhL7QeR]P9R]`08I[MR]RFj9KXYfT:mA[e2_@ENMP04Hk=WddJlB[d2A[`03dJmA]e6_FJgI[I?
TVJfI[LQVBFIB]a:gD[LB]e:g002A[d014KMHYIRUf:G0e^c00M6_4ZlA[a:_4JlB]e:g002B]d01TJm
EQAF5EHDEQEF50<nO00<?W]>g4kLC]e>g4kMC]a>gD[LC]e6_DKM15if00Tj>cYK>S/jFdkLC_a>g4km
C]`00P0000IBoDkLC_e>o5;mC]`2@[d02G[@M[1jd7K@N]1f/00:00T02P04C]`01DklD_aBo5;mC_`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00Ool0
5goo000TOol01`00Oom2WCil@Y`nW3jm0099TP1GBG5=TTVBG`QJiel8A[a6_DJlB]eRUVJgHYIV]f:F
GmEK]4JmAYa6_D:lA[e2_5igFWINUf>cImAS/fODA[a:_DJlB[e6_4[MA[`^GFJfI]MV]RFI8IPUVDZl
C]e:_4[MA[a:gDJlH[MRUV:gHYIR]bgj<Q]:g4kMB[a>gD[LC]e:g4kM@[aF5E8DEQEF55HE?U]2O3iK
@W`nFdkmC]a>oDkLC_e:g4kMB]`1FP5I009NMP08GYMNMUifB[a>gDZlB]e>g0<0002[C]aBoDkLD_e>
g5;mC]a>oDkLA[ef[g[@MZmjd7J_N]002@0:00T02TkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01Eoo`006Woo10001Woo
00L007ooOolnW3il@Y`nW@06BI83?W`2A[d01D:mA[eR]fJgH[H00U_E00MOeDJlA[a6_4Jm@[e6_@03
GWH00fOCGWINMP02=S/014[LB]e:_4[M0bYM00AV]fJfI[MV]P8QV@059IU:g4[MB]a:g@03A[d01F:g
HYIRUf:G<Q/00S7j00A:g4kMB]a>g@9:g@0EB]a:gDJmEQEF55HEEQAF5DZlB]a:_4[MB[a>gDkLC]e>
g4kMC]a>gD[L00ENMP03EfmKT4Zl00<00005C]a>o4kLC_e>g002C_`03E;mC]a>oDkLC_e>g7[@M]1j
d7J`N]1fd7[@00A6W004C]a>o4kLC_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo004D_eBo5;lD_`COol00`00Oomoo`0EOol001Uoo`03001oogoo009oo`03001oogoo
00=oo`09001oogooOom6_DJl?[e9LDfB0099TP1FBG5=TTVB?W`jFcil@[a6_D:lI[MRUVJgHYIV]bFi
:MY6_4[MA[a:gD:lA[eNMP4HFWINUeif=S/f6cHlB[a:gDJl;UdZGFKGI[IVefJfI]LQN2FI8IPUVDZl
C]e:g4[M5O`J71GlH[MNUV:gHYHb6bgj<Q]:g4kMB[a>gD:lA[e2_4KMEQAF5E8DEQEF55LZB[a>gDZl
B]e:_4kmC]a>oD[LC_e6_4[MGWINU`=NMP<0002cB[a>gDZlB]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[L
C]e:g7[@MZmjd7J_N]1f/4JL@Y]6W4:LAYa>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Oomoo`0DOol001Uoo`03001oogoo009o
o`03001oogoo00=oo`80009oo`03A[a6_CjM00Q9TP<nO096_@05@[eR]f:gI[MR]P029KX01bWJA[a:
_DJmB]d0m`4H00ENMP<f>`0:B]a:gDZlI[MV]VJgI[IV]d]aCi84A[`01D[LB]e:g1Wl5O`00V:G00ER
]f:FHYLanS8K008anP04C]a>gD[LC]d2A[d01D:mEQEF55HEEQ@00eLZ00eG2TkLC]a>gDkLC]e>g4kM
C]a6gDJmA]eNMP03000015M_FhmGKdkM0dkL01A>gDkLC_a>o5;mC]a>oDklD_e>g4kMC]a>gGJ`N]1f
d7[@M[1fd00:1TkL00=Bo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo003D_eBo5;l01Aoo`03001oogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo05U2_3jmBI99TTUaCI99TTfBBI5=TU[WA[e6_4[M7Q`N7F:FI[MRUVJgHYHYfRFi:MY6
_4[MA[a:gEYfGYMNMUigFWINUdJlB[e6_4ZmA[a:gDJlI]MV]VKGI[IVeb6HCi96W4ZmAYa6_DZlC]e:
g6:gGYIR]f:FH[MK/U^cA[a:_DJlB]e:g4kMB]a>oD:lA[eB55HEEQAF5E8D@W`nFd9l?U]>oD[LC]e:
g4kmC]a>oD[L00<0002jGWIKT5ifGWHj>ciK>S]>oD[LC_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC_e:
g4kMMZmjd7J`N]1f[`0:00U>gD[LC]e:g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m4goo00<007ooOol04goo000IOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00cjMBI99TP05BI82F^L01dJlA[e6_4JmH[MV]f:f009R]`08
I[LU^BFj9KXYfT:mA[e2_@ENMP04Hk=SddJlB[d2A[`03TJmA]e6_FJgI[IV]fJfI[LQVBFIB]a:gD[L
B]d3A[d016:gHYIRUf:G0e^c00A6_4ZlA[a:_09:g@09B]a:gDJmA[eF55HEEQAF5EHD00<nO0=>g003
C]e:g00000800003B]a6gDJm00ANMP0:>U/j>cYK>S]>oDkLC_a>g4kmC]`2C_`02U;mC]a>oDkLC_e>
g4:mM]1jd7J`0WK@00=jd00:00X01DkL00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0COol00`00Oomoo`0BOol001Uoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Aoo`1B?[e9LDfBBI9=TTVACI99TUl8F^MO24:lA[e2_4JmHYIV
]f:FI[MK]5_E@Ya6_DJLA[e2_4Jm@[aNMeYfGYMS/fOCHk=We4JlB[e6_4ZmA[a:gDJl;UeV]VKGI[HU
VB6H9IU:_4kMB[a6gDJlB]e6_6:gGYIR]f:F<Q/anS8KB]a>gDZlC]e:g4kMB]a6gD:lEQEB55HEEQAF
5E8D@W`nFd9lC]`300001T[LC_e:g4kMB]aNU`9NMP2iFWINUeifB]e:_4kMB[aBoDkLD_e>g5;mC]aB
oDkLD_e>g5;mC]a>oD:LN]1f/7[@MZmjd7J`00X02@0:C]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aB
oDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0AOol0
01Uoo`03001oogoo009oo`03001oogoo009oo`8000Eoo`03?Ye9TTVB00I9TP<nO096_@08@[e6_F:g
I[MR]U_DFkAKe@=6_003A[e2_DJm00ENMP<f>`04B]a:gDZlB]d2:Ud01FJfI[MV]VJgI[H00R6I00DU
VD[LB]e:g4KM0096_@03HYMR]f:F009RU`07<Q/anS8JB]a>gD[LC]d00T[M00U:g4JmEQAF5EHDEQEF
55LZD`X00`0000Q>g4kMC]a>gDkLA]e6_DKM1Eif0UM_00I:g4ZlB]a:_5;mC]`2C_`02U;mC]a>o4kl
D_e>g4kmC]a>oGJ`0WK@00Ajd7J`M]002P=6W006C]a>oDkLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04Woo00<007ooOol04Goo000J
Ool40005Ool00`00Oomoo`04Ool08CjmBI99TTUaCI99TTfBBI5=TSYl?W`jFcil>Wa6_D:lI[MRUU_E
HYIV]bFi:MY6_4[MA[a:gD:lA[eNMUigFWINM`02=S/0:SHK=Sa:_4[MA[a:gFJfI]MV]VKGI[IVedJL
B[e6W4JmB[a>gD[L6O`Eo1WlHYIR]ejFH[LanS8K<OXb6d[LC]e:g4km@[a6_D:lEQEF55HEDQAF5@80
000ZB[a>gDZlB]e:g4kmC]a>oD[LB]e6_4[MFWINUeifFhmGKe^@Efm>oD[LC_e>g5;mC]aBoDkLD_e>
g5;mC]aBoD[LC_e:g4kMMZmjd7J`N]1f/00:0TJL09a2VdJLC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dBOol3000BOol000Eoo`80
0003Ool0000001Uoo`03001oogoo00Eoo`U9TP06A[a6_DJlA[e6_1hM0QhL00]R]fJgH[HY^RFj:MY6
_4ZmA[d1603g00ENMP@f>`08A[e6gDJmA[eV]VJgI[IV]`9;L@=6_006B]e:g4[MB]a:gF:F0V:G00]R
]f:FHYM6_4ZlA[a:_4kLC]e:g4kM0096_@03EQAF5@0000800003E`YC2ULZ00=>g008C]e>g4kMC]a>
gDkLA]e6_@ENMP04>S/jFcXkC]d3C]`04E;mC]a>o4klD_e>g4kmC_aBoD[LC]e:g7[@M[1fd7J`N]00
0P0:14kL00I>o5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mOomoo`0AOol00`00Oomoo`0@Ool000Aoo`03001oogoo008001Yoo`03001o
ogoo00Eoo`16BG5=TTVBCI99TDfBBI9=TTVAG`Q6_4JmA[a:gAhL7QeRUVJgHYIV]f:F:MXU^BWJA[a:
gDJlGWMJMUigGWINMf>bIm=6_4ZmA[a:_DJlB]e6_6KGI[IVefJfI]M;LDJmAYa:_DJLA]e6_4[MA[a6
gEjFH[MRUV:gEi9K/dJlB[e6_4kmB]a>gD[LC_d30000ceHEEQAF5CiK@W`nFd9lB]a>oD[LC]e:g4km
B]a>gD[LB]e6_5ifFWINUeif?U/j>ciKC]a>oD[LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g7[@
M[1jd7J`00X02@0:B]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol00`00Oomoo`0?Ool000Aoo`05001oogooOol0
000IOol30006Ool8BI83F^L01dJlA[e6_4JmH[MV]f:f009R]`07I[M6_4JlA[a6_D:mA[d01Eif00ES
df>cHm=6_4Zm0096_00>A[e6gDJmI[MV]VJgI[HUVB6IB]e:g4[MB]a6g@=6_@0;H[MRUV:GFk9K/e^b
Fk=6_4ZlA[a:g@030002A[d01UHEEQAF5EHDEQDnN`<nO008C]a>gDkLC]e:g4kMC]a>g@81F@ENMP0:
>U/j>cYKC]a>oDkLC_a>g5;mC]`2C_`02dkmC]a>oDkLC_e2_GK@M[1jd7J`M]00100:00M>g4kmC]a>
o5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d04goo00<007ooOol03Woo0004Ool01@00Oomoogoo00006Goo00<007ooOol01Woo
0419TSjmBI5=TTVBCI99TDfBF^MK1e[WG`Q2_4Jm@[a6_F:FI[MRUVJgFkAKe4:LA[e6W4Jm@[a6_Eif
GWMJMVOCHk=Wdf>bIm=:_4[MA[a:gBXm;UdZ?6KGI[IVefJf9ITQV4[MB[a>gDZlB]e6_4[MA[aR]eNB
H[MRUS8K<OXb6`<0000IC]e:g4kMB]a6gEHDEQEB55HEEQAF5DZlC]e:_4[MC]a>oDkLC_e:g4kmB]a>
gEYfGYL00Uif0;]JMUN?Efi:gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4kmM[1jd7J`N]1f
/4JLAY]6W4:KAYa>g5;mC]aBoDklD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Oomoo`0>Ool000Aoo`05001oogooOol0000I
Ool00`00Oomoo`06Ool00dVB?Ye9TP05BI800e[WOolnO002?W`2A[d024:mH[MR]fJgH[IR]bFj:MX3
A[`01TJm@[eNMUifHm=S/`9NMP<f>`03B]a:gDZl008ZG@0CI[MV]VJgI[IV]b6H9ITQVD[MB]a:gD[L
B]dEo1Wl5OaR]f:FHYL00`0000A>gD[LC]e:g0=6_@0C@[eF5EHDEQEF55HEEQAC2TZlB]a:_4[MC]a>
gDkLC]e6_DKMA[d01Eif0UM_00M:_4[LB[a:g4klD_e>g002C_`03U;mC]a>o4klC]e:g4kMB]a>gGJ`
M]1f/7[@M[05AY`00dklD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4goo00<007ooOol03Goo0003Ool20002Ool2
000IOol00`00Oomoo`06Ool024UaOom9TTfBBI5=TTVBCI82Ool063Yl?W`jFcil@[a6_D:lI[LN76Jg
HYHYfRFi:MY6_4[MA[a:gD:lGWMNMUigFWINM`8f>`0F=Q/f?4ZlB]e6_6KGI[IVefJfI]M7L4]aAYa:
_DJLB]e:_4kMB]`Io1GlH[L30000>f:g<OXb6c7jC_e:g4kMB]a6gD:lA[eB55HEEQAF5E8DEbYC2EL:
B]a>oD[LC]e:g4kmC]a>oDJlB]e6_5ifFWINUeM^EfmCKUN?C]a>oD[LC_e>g5;mC]aBoDkLD_e>g5;m
C]a>gD[LC_e:g7[@M[1jd7J`N]000P0:0:5:g4kMB]a>gDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03001oogoo
00aoo`008Woo0P002Goo1DVB00]JigooOomoodJlA[e6_4Jm7Q`N7AhL00=R]`08H[HY^RFj:MY6_4Zm
A[e:g@INMP0:A[a:_DJlA[a6_DKMA[eV]fJfI[L3Bg45A[`00d[LB]d000020002HYL02f:gEi9K/TJl
B[a6_4kMC]a>gD[LC]d00TJm00QF55HEEQAF5Cik?W`nNcil0dkL00M>gDkLC]e>g4kMA[e6g@02GWH0
25M_GWINMSYK>S/jFdkLC]d2C]`00dklD_e>g002C_`035;mC]a>oDklC]e:g4kMB]ajd7J`M]1f/0<0
2P=>g004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aBo00COol00`00Oomoo`0<Ool0029oo`03001oogoo00Qoo`06
BI5=TTVBCI99TEl817oo02Q6_4JmA[a:gAhL7QeRUVJgHYIV]bFi:MXU^BWJ@[a6_D:lGWMJMUigGWIN
Mf>bHm=6_4ZmA[a:gDJlB]eV]VKGAg1Vef:f9ITQV4[MB[a>g@<0000UB]e6_6:gGYIR]eNBFk=GTT[M
A[a:_DJlC]e:g4kMB]a>gD:lEQEB55HEEQAF5CiK@W`nFdkMB]a>oD[LC]e:g4kmB]a>gDJlB]d00Uif
01YJMUig>S/nFcXk?U]>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4Jm@Yajd7J`N]1f/7[@0`0:0:5>
gD[LC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m01=oo`03001oogoo00]oo`008Goo00<007ooOol02Goo1DVB1Woo
00A6_4JmA[a6_@9R]`05H[IR]e^dFkA6W002A[`014Jm@[e6_D:m0eif00MS/f?CHk9S/dJlB[e6_002
A[d024KM:UdZGFJfI[LQV2FI8IT200000d[MB]a6g@02A[d00f:GH[MRUP02HYL01S8K<OY>gD[LC]e:
g0=:g@0DB]a6_EHDEQEF55HEEQAF5Cik?W`nNdkMC]a>gDkLC]e:g4kMC]a>g@INMP0;B[a:g4ZlB]a>
g4kmC]a>o4kLD_e>g002C_`02TkmC]a>oDkL@[ef/7K@M[1jd7J`100:00A>o4kLC_e>g09Bo005D_e>
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
0e;mD_aoo`0BOol2000<Ool0025oo`03001oo`0000Uoo`05BI9oodVACI99TP07Ool08D:lA[e2_4Jm
HYIV]f:FFmAG/e_D@Ya6_DJLA[e2_4JmGWINMeYfGWMNMSHk=Q/f?4ZlB]e6_2iM:SdZGF:fI]MV]P03
0000;26H9IU:_4kMB[a6gDJlB]eRUV:gGYIR]c7j<Q/anTkMB]a>gDZlC]e:g4kMB]a6gEHDEQEB55HE
EQAC2DZlC]e:_4kmC]a>oDkLC_e6_4[MA[aNMUYfGWL2GWH0_E=>Efm:_4[MB[a>gDkLD_e>g5;mC]aB
oDkLD_e>g4kmC]aBoDkLN]1f/7[@M[1jd7J`AYa6VdJL@Y]BoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol0
0`00Oomoo`0:Ool0025oo`8000Yoo`05BI9oodVBBI9Ji`09Ool03dJm@[eR]f:gFkAR]V:g9KXYfTJl
B[e6_D[M@[e6_@04GWH3=S/01T[MB]a:gDZlB]eV]P<00003I[I6_4Jl00=6_005B]a:gD[L6O`Eo002
HYL02f:gHYIRUc7j<Q/anTkMC]a>gD[LC]d00TJm00E2_EHEEQAF5EHD009C2@0<B]e:_4[LB[a>gDkL
C]e>g4kMA[e6gDJm0eif00IGKUM_DfiGKdkLC]d2C]`00dklD_e>g002C_`03E;mC]a>o4[LC]e:g4kM
B]ajd7J`M]1f/7K@00E6W004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04Goo0P002goo000?Ool40004
Ool40006Ool00`00Oomoo`0;Ool00dVBCI9oo`0:Ool04ahM6Q`N7F:FI[MRURWJ9KTYfTJlB]e6_04H
0?MNMeifGWMJMUig008f>`03=Q]:gDJl00<0000`I[IVef:fBg57D4JmAYa:_DJLB]e:_4kMB]aR]ejF
H[MRUV:gGYI:gDJlB[e6_4kmB]a>gD[LA]e2_4JmDQAF5EHDEQEC2E<:D`U>gD[LC_e:g4kmB]a>oDkL
C_e6_4[M0Uif0<5JMUig>S/nFcXk?U]>g4kmB]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>oGJ`N]1f
/7[AM[002T[LC]e:g4kMB]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00>Ool300000goo001oo`0:Ool000io
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool2BI8;Ool00ahL
7QeR]P03H[L01f:f:MXU^RWJA[a:_DJm00ENMP9S/P0<A[`000000016_DKMA[eV]fJfI[MV]VJg0RFI
0dJl00I6gDJmA[e6_F:gHYH2HYL00eNbEi9:_002B[`01DJlC]e>g4kMB]`00TJm00UF5EHDEQEC2EHE
?W/nO3ikC]d00dkL00M>gD[LC]e>g4kMA[e6g@03GWH013YK>S/jFcXk0TkL00I>gDkLC_a>o5;mC]`2
C_`02e;mC]a>oD[LC]e:g4kMM[1fd7J`M]000P0:1DkL0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;l
D_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d02Woo1000
17oo00<007ooOol02Goo000COol01000Oomoo`0017oo00<007ooOol00goo0P0037oo00=9TEl8Ool0
2goo015RUVJgHYIV]f:FI[M2W4JmAYa6_D:lA[eNMUigFWINMeif00<0000hA[a:_DJlB[e6_4[MA[aV
efJfI]MR]RFI8IPUVDZlC]e:_4KMA[a:gF:FH[MNUU^bEi9G/UNBC]e:g4kMB[a>gD[LC]e:g4KMEQAF
5E8DESEF549l?U]2O3iKC_e>g4kmC]a>gD[LC_e:g05I0CQNM`9NMP0JFWHnFcXk?U/j>e;mC]aBoDkL
D_e>g5;mC]aBoDkLC_e>g5;m@[ejd7J`N]5f/7[@M[002`802P2TC]aBoDkLD_e>g5;mC]aBoDkLD_eB
o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@Ioo`<000Qoo`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03001oogoo009oo`80
00eoo`03BI9oogoo00aoo`9R]`05H[IR]eNcFkA6W002A[`014Jm@[e6_Eif0`0000QNMSHk=S]:gD[L
B]e:_4[M0bYM00AV]fJfI[MV]P8UV@05B]e:g4[MB]a6g@02A[d02f:GEk9RUV:G<OXb6c7jC]e:g4kM
B]`00d[M01=2_EHEEQAC2EHDEQEF54[MB[a:g4ZlC]e>g4kMC]a>gD[LC]e>g005GWH02E=>B]a:_4[L
B[a>o4kLC_e>g002C_`03U;mC]a>o4kLC_e>g4kmM[1fd7J`M]1f/7K@00X3AY`01DkLC_a>g4kmC]`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`015;mD_aBo5;l0goo0`0037oo00<007ooOol027oo000?Ool40003Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00dVBOomoo`0<Ool00fJgHYIV]`02Ool01BFi:MY2W4Jm
AY`00`0003aNMV?CFWINMeYf=S/f6d[MB[a:gDJl;UdZ?FKGH[IVefJfI]LQV2FI8IQ:gDZlC]e:g1Wl
5M/Io6:FH[MNUS8K<OXb6dZlC]e:g4kMB[a6gD:lA[e2_5HEEQAF5E8DESE>j4[MB[a>gDZlC_e:g4km
C]a>oDJlB]d2GWH0`eYfGWMCCUM_Ddi>gDZlB]e:_5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4kmM[1j
d7J`N]5f/00;@Y]6W4JKAYa>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001B
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo002000?Ool00`00Oomoo`08
Ool000moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00aoo`03BI9o
ogoo00eoo`03H[Moogoo009oo`07:KX000000016_D[M@[d01Eif13Hk00Q:g4[MB[aV]fJfI[MV]VJg
0TM@0dJl00=:gD[LB]d00QGl00eRUV:GHYMR]f:F<QXanS8KB]a>gDkLC]e:g003A[d01E<9EQEF55HE
C`T00U<900]>gDkLC]a>g4kMC]a>gDkLA]e6_DKM00ANMP03>S/nFcXk009>g00EC]e>g4klC_aBoDkL
C_e>o5;mC]a>oD[MC]e:g7K@M[1fd7J`M]002P0;00E>g004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aB
o11oo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol087oo0P0004@U^BWJ9KU:gDJlB]eJMUigFWINMeYfGWM6_4ZmA[a:_DJlB]e6_6KGI[IVef:f
I]M7D4JmAYa:_DJLB]e:_4kMHYIR]ejFH[MRUUNbDi5:gDJlB[e:g4kmB]a>gD[LA]e2_5HEDQAF=EHD
EQDnFd9l?U]>gD[LC_e:g4kmB]a>oDkLB]e6_5ig0Uif0<=JMSiK>S/nFcXkC_e>g4kmB]aBoDkLD_e>
g5;mC]aBoDkLD_e:g4kMB]ajdGJ`N]1f/00;00X02d[LC]e:g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`03goo00<007ooOol027oo000?Ool50003Ool40005Ool2000NOol30002Ool2A[`014JmAYa6
_D:m1Eif00AO/V>bA[a:_@96_007A[e6gFJfI[MV]VJgI[H00RFI00E:gD[LB]e:g4KM0096_@04HYMR
]f:FHYL2Ei801DJlB[a:_4ZlA[`00d[M01E:g4JmEQAF5EHDEQEF549l?W/nO3ikC]e>g4kMC]a>gD[L
C]e>g4KMA[d015if00PjFcXk?U/j>dklC]a>oDkL0Tkl00eBoDkLC_e>g4kmC]a>oD:mM]1f/7K@M[1f
d00300X01P0;C]a>o4kLC_e>o09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l3goo00<007ooOol027oo000P
Ool00`00Oomoo`0JOol30006Ool0ADJmAYa6_D:lA[e2_5igFWINMenbHk=O/V?CB[a:gDJlB]dZ?BYM
:SaVefJfI]MR]RFI8IQ:gDZlC]e:_4KMA[a:gF:FH[MNUV:g<OXb6dZlC]e:g4kMB[a>gD[LC]e2_5He
EQAF5EHDESEF54[MB[a>gDZlC_e>g4kmB]a>gD[LC_e:g5ifFWINM`02GWH0`TZlC]e:_4[MB[aBoDkL
D_e>g5;mC]aBoDkLD_e>g4kmC]aBoGJ`N]1f/7[AM[16W4:KAYa6VdJLC]aBoDkLD_e>g5;mC_aBoDkL
D_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d>Ool00`00Oomoo`08Ool0021oo`03001oogoo01Moo`<000Yoo`96_003A[e2
_DJm00ENMP<f>`03B]a:gDZl008ZG@06I[MV]VJgI[IV]b6H0RFI00A:gD[LB]e:g0@Eo00:HYMRUS8J
<OXb6d[LC]e:g4kMB]`3B]d04T:mEQEF55HEEQAF5@00B]e:_4[LC]a>gDkLC]e6_DKMA[e6g@ANMP07
DdiCKTZlB]a:_4[LB[`00Tkl011BoDkLC_a>o5;mC]a>o4[MC]e:g4kMM[1fd7J`M]1f/0A6W005C_e>
g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`03Goo00<007ooOol027oo000OOol00`00
Oomoo`0EOol3000>Ool02D[MA[a:gD:lA[eJMUigFWINM`02=S/0:3HK>Sa:_4[MA[aVefJfI]MR]VKG
@dm7D4JLB[e6W4[MB[a>gD[L6O`Eff:gHYIR]ejF=Q/anS8K<OY>oD[LC]e:g4KM@[e6_E8DESEF55HE
0`0000]:gDZlC]e>g4kmB]a>oDJlB]e6_4[M009NMP36FWICKU=>Dfi:g4kmC]a>oD[LD_e>g5;mC]aB
oDkLD_e>g5;mB]a>gD[LN]5f/7[AM[1jd@0:AYa2VdJLAY]BoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aB
oDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m3Goo00<007ooOol01goo000OOol2000COol3000AOol014JlB[e6_D[M1Uif00e6_4Zm
A[a6_4JmA]e6_FJgI[IV]fJf9IU7C`04A[`01T[MB]a:gD[LHYMRUP9RU`03Ei9CTDZl009:_005A[a>
gDkLC]e:g002A[d02EHEEQAF5EHDEQDnNcil?W]>g@03C]`01TkMC]a>gDkLA]e6_@ANMP03>U/j>ciK
00=>g00DC]e>g4klC_aBoDkLC_e>o5;mC]a>oD[MC]e:g7K@M[1fd7J`00/02PA>g005D_e>g5;lC_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol037oo00<007ooOol01goo000OOol00`00Oomoo`0?
Ool3000EOol0@T:lA[e2_5igFWINMeYfGWMO/V>bA[a:_DJlB]e6_4[MH[IVebXmI[MR]RFI8IQ:gDZl
C]e:_4KMA[a:gDJlH[MNUV:gDi5GTTJlB]e6_4ZmA[a>gD[LC]e:g4KMEQAF5EHDESEF549l?U]2O4[L
C]e:g4kmB]a>gD[LC_e:g4[MA[aNM`9NMP35>S/nFcXk?U]>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>
g5;m@[ejdGJ`N]5f/7[A00X02d[LC]e:g4kMB]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o00<Ool00`00Oomoo`07Ool001moo`03001oogoo00aoo`<001Uoo`03@[e6_D:m00=NMP07Gk9S/Unb
Gk96_4ZmA[`00TJm00I6gBYMI[MV]VJg9IP29IT01D[MB]a:gD[LA]d00TJm0V:G00URUV:G<OXb6T[L
C]e:g4kMB]`00d[M00E2_EHEEQAF5EHD009F5@0<@W`nNcilC]a>gDkLC]e>g4kMB]a>gDkL1Eif00U:
_4[LB[a:g4kLC_a>g4kmC]`00Tkl01IBoDkLC_e>g4kmC]a2_GJ`M]1f/7K@M[002`0:00]>g4kmC]a>
o4kLD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol02Woo00<007ooOol01goo000OOol0
0`00Oomoo`09Ool3000MOol0?T:lA[eJMUigFWINMeYf=S/f6cXlB[a:gDJl:UdZ?BYMH[IVefJfI[LQ
V2FI8IQ:gDZlC]e:_4KMA[a:gF:FH[MNUSHK<OXb6dZlC]e:g4kMB[a>gD[LC]eF55HeEQAF5EHDESD0
04[MB[a>gDkLC_e>g4kmA[a:gDJlB]d2GWH0bEYfGWM?CE=^B[a>gDZlB]e:_5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g7[AM[1jdGJ`N]5f/4JL@Y]6W4kLD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo00:Ool00`00Oomoo`07Ool001moo`8000Qoo`80025oo`03@[e6_Eif00=NMP<f>`0:
B]e:g4[MB[a:gFJfI[MV]VJgI[H4A[`014[MB]a:gD[L0QGl0f:G00eRUS8J<OXb6S7jC]e>g4kMB]a6
_D:mA[eF5003EQD2000034ZlB]e:_4[LC]a>gDkLC]e6_DKMA[e6g@=NMP=CCP=>g00DC]e>g4klC_aB
oDkLC_e>o5;mC]a>gD[MC]e:g7K@M[1fdGJ`M]002`=6W006C_aBoDkLD_a>o5;m0e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mOomoo`08Ool00`00Oomoo`07Ool001ioo`03001oogoo00Eoo`<002Eoo`05
GWMJMUigFWINM`02=S/0=SHKB]e6_4[MA[a:gFJfI[MR]TM@@bm6_DJLB[e6W4JmB[a>gD[LH[MNUV:g
HYIGTE=aB]e6_4ZmA[a>oD[LC]e:g4KM@[eF5EHDESEF55HE?U]2O4[LC]e:g4kmC]a>oD[LC_e6_4[M
A[aNM`9NMP38FWHnFcXk?U]:g4kmC]a>oD[LD_e>g5;mC]aBoDkLD_e:g4kmB]a>gD[LN]5f/7[AM[00
2`0:C]e:g4kMC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@Yoo`03001oogoo
00Ioo`007Woo00<007ooOol00Woo0`00:7oo15if0Unb00=6_4ZmA[`00TJm00I6gDJmI[MV]VJgI[H2
9IT01D[MB]a:gD[LB]d00dJm00IRUf:FHYMCTENADi43B[`01TJlB]e:gD[MB]a6_@9F5@08EQAF5EHE
@W`nNcilC]a>g@=>g006C]e:g4kM0CU6gDJm0eif00Tj>cYK>S/nFdkLC_a>g4kmC]`00Tkl00EBoDkL
C_e>o5;m0092_@08M[1fdGJ`M]1f/7KA00X02`A>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`:Ool00`00Oomoo`06Ool001ioo`03001oo`00008002aoo`0nFWINMeYfHk9O
TF>bGk5:_DJlB[e6_4[MA[`ZGFJfI[LQV2FI8IQ:gDZlC]e:_4KMA[a:gF:FH[MNUV:g<OXb6c7jC]e:
g4kMB[a>gD[LC]e2_5HeEQAF5EHDESEF549l?U]2O4kLC_e>g4kmB]a>gD[LC_e:g5ifFWINM`9NMP37
B[a>gDZlB]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e2W7[AM[1jdGJ`N]5f/00;00X02dkLD_e>g5;m
C]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`02Goo00<007ooOol01Woo000NOol3
000^Ool2GWH00enbOomoo`03=S/00d[MB[a:g@02:Ud01FJfI[MV]VJg9IP00bFI00A:g4[MB]a6g@96
_@9RU`09HYIRUc7j<QXanTkLB]a>gD[L00=:g@0BEQAF5EHEEQEF55HE001:gDZlB]a>g4kMC]a>gDJm
A]e6_DKM15if00M?CE==B[a:g4ZlB]a>g002C_`045;mC]a>o4klD_e>g4kmC]a>oGJ`M]1f/7KAM[1f
d00;0dJL00I>g4kmC]a>o5;lD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l27oo00<0
07ooOol01Woo0004Ool50003Ool40004Ool40007Ool00`00Oomoo`0^Ool0;EigOomoogoo=S/f6cXl
B[a:gDJlB]eV]VJgH[IVefJfA[e6W4ZmAYa6_DZlC]e:g1Gl5M]R]f:FH[MNUSHK<OXb6c7jC_e:g4kM
B]a6gD:mA[eF55HeEQAF5@02000034ZlB]e:_4kMC]a>oD[LC_e6_4[MA[aNM`9NMP3;CdeCCTm=Ddi:
g4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>gGJ`N]5f/7KAM[002dJKAYa2VdJLC]aBoDkLD_e>
o5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo007Ool00`00Oomoo`06Ool000Ioo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`05Ool2000cOol3=S/01dJm
A]e6_DJmI[IV]fJf0093;`E6_005B]a:gD[LHYMRUP03HYL03F:FB[a:_4ZlA[a>gDkLC]e:g4Jm@[eF
5EHD009F5@<00003C]a>gDkL009>g006C]e>g4kMA[e6gDJm15if00<jFcXk?U/00dkL015>gDkLC_a>
o5;mC]a>oDklD_e:g4kMB]e>gGJ`M]1f/7KA00802`A>g003C_aBoDkL009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m009Bo0Moo`03001oogoo00Ioo`001Woo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo00Moo`03001oogoo035oo`0gB[e6_4ZmA[a:gDJlI]MV
]T=?H[IVeb6H9IU:_4kMB[a:gDJlB]e6_6:gGYIR]f:FDi5CL4[MA[a:_DJlC]e:g4kMB]a6gEHDEQEF
55HeEQA2O3iK@Wa:g4kMB]a>oD[LC]e:g4kmA[a:gEYfGWL00Uif0<Xj>ciK>S/nFdkLD_e>g5;mC]aB
oDkLD_e>g5;mC]aBoD:LA[ef/7KAM[1jdGJ`00/02P0;B]a>gD[LC]e>g5;mC]aBoE;lD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@Ioo`03001oogoo00Ioo`001Woo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo00Qoo`03001oogoo035oo`0:B[e6_4JlA[e6gDJm
:UeV]VJgI[H39IT014[LB]e:g4KM0TJm0V:G00URUV:GHYLb6S7jC]a:g4kMB]`00d[M00E2_EHEEQEF
5EHD009F5@0;@W`nNcilC]a>gDkLC]e>g4kMB]a>g@06GWH02DZlB]a:_4[LC]a>o4kLC_e>g002C_`0
2e;mC]a>oDkLC_e2_GK@M[1fdGJ`M]00100;00M>g4kmC]a>o5;lD_e>o002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Ioo`03001oogoo00Eoo`001Woo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Uoo`03001oogoo035oo`0cB]e6_4[M:SdZ
GF:fI]MV]VJgH[HU^B6H9IU:_4kMB[a6gDJlB]eRUV:gGYIR]c7j<Q/anTkMB]a>gDZlC]e:g4kMEQAF
=EHDEQEF55He001:gDZlC]e>g4kmC]a>oDJlB]e6_5ig009NMP3=FWINMdl]Cde:_4kMB[a:gDkLD_e>
g5;mC]aBoDkLD_e>g5;mC]a>oGJ`N]5f/7KAM[1jdDJKAYa2VdJLC]aBoDkLD_e>o5;mC]aBoE;lD_e>
g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`01Woo00<007ooOol01Goo0006Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol02Woo0P00<Goo00Y:g4[MB[a:gFJfI[MV
]VJgI[IV]`A6_003B]a:gD[L008Eo0=RU`0=HYIRUc7j<QXanTkMC]a>gD[LA[e2_DJmEQ@00eHE0P00
00]:_4[MB[a:g4kLC]e>g4kMA[e6gDJm00=NMPA?C@=>g006C]e>g4klC_aBoDkL0Tkl00]BoD[LC]e:
gDkMM[1fd7J`M]5f/00;00=6W004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aoo`04Ool00`00Oomoo`05Ool000Aoo`<000Aoo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0<Ool00`00Oomoo`0_Ool0=4JlB]e6_4[MI[IV]f:fI]LUV000AYa:_DJL
A[e:_4kMB]aR]ejFH[MRUV:gCg1CTDJlB[e6_4kmB]a>gD[LA]e2_EHEEQAF=EHDEQDnFd9lB]a>gD[L
C_e>g4kmB]a>oDJlB]eJMUig0Uif0<eJMSiK>S/nFdkLC_e>g4kmC]aBoDkLD_e>g5;mC]aBoD[LC_e:
g4kMM[1jdGJ`M]402P0;B]a>gD[LD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo004Ool00`00Oomoo`05Ool000Ioo`03001oogoo00=oo`@000Aoo`@0011oo`03
001oogoo02moo`08A[e6gDJmI[MV]VJgI[IV]`8UV@04B]a:gD[LB]d3A[d01V:GHYIRUe=`Di5CL0=:
_006A[a:gD[MB]e:g4Jm0UHE00QF55HEEQE2O3ik?Wa>g4kM0dkL00E>gD[LC]e6_DKM00ANMP09>S/j
FcXk?U]>g4klC]a>oDkL009>o005D_e>g4kmC_aBo@02@[d01GJ`M]5f/7KAM[000P0;14kL0U;l00EB
oDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`0
05;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`02Ool00`00Oomo
o`05Ool002Uoo`03001oogoo02moo`0`A[a:gDJl:UeV]VJgH[HU^BFH9IU:_4kMB[a6gDJlB]eRUV:g
GYIR]ejF<Q/anTkMB]a>gDZlC]e:g4kM@[aF=EHDEQEF55HeEQA2O3iK@Wa>g4kmC]a>oD[LC]e:g4km
0Uif01YJMUigGWINMTZlC]e:_4[MC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4km@YajdGJ`M]5f/7[A0P0;
0;@02U;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d3Ool00`00Oomoo`05Ool002Yoo`03001oogoo02moo`8ZG@05I[IV]fJfI[MV]P039IT014[LB]e:
g4KM0TJm0V:G00URUV:G<OXb6S7jC]a:g4kMB]`00d[M015F55HEEQEF5EHDEQD004[MB[a:g4kLC]e>
g4kMA[e6gDJm00ENMP07Cbe?CDZlB]a:_4[LC]`00Tkl00mBoDkLC_a>o5;mC]a>oDkLC_ef/7KAM[1f
dGJ`00/00dJL00A>o4kLC_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l0goo00<007ooOol01Goo000[Ool2000`Ool08VJfI[MR]VKGI[IV]dJLB[e6W4JmB[a>gD[L
5O`Aff:gGYIR]ejFH[LanS8K<OY>oD[LC]e:g4KM@[e6_EHDESEF55HE0`0000]:gDZlC]e>g4kmB]a>
oDJlB]e6_5ig009NMP3?Bba?CDl/Cde>g4kmC]a>oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>gGJ`N]5f
/7KA00/034JKAYa2Ve;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l00=oo`03001oogoo00Aoo`00;Goo00<007ooOol0;Woo00IV]VJgI[IV]goo0004A[`0
1D[LB]e:g6:GHYH00f:G0Tm`0TZl00U6_4kMC]a>gD[LA[e2_EHEEQ@00UHE00E2O3ik?W`nNdkM00=>
g005C]e>g4kMA[e6g@04GWH013Xk>U/j>ciK0dkL011>gDkLC_a>o5;mC]a>oDklD_e:g4kMB]efdGJ`
M]5f/0<02`=>g004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00ABoE;lD_aBo09oo`03001oogoo00Aoo`00;Woo00<007ooOol0;Goo00=VefJfOol00Woo04@UV2FI
B[a>gDZlB]e6_4[MA[aR]ejFH[M?L5>@Cg1:gDJlB[e6_4kMB]a>gD[LA]eF55HEEQAF=CiK@W`nFd9l
?U]>gD[LC_e:g4kMB]a>oDJlB]eJMUigGWHnFcXk?U/j>ciKC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4km
@YajdGJ`M]5f/7[A0`0;0;P034[LC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lOol000Ioo`00;goo00<007ooOol0<Woo0RFI00A:g4[MB]a:g@96
_@9RU`09HYIRUf:G<QXanTkLB]a>gD[L00=:g@0B@[eF5EHEEQEF55HEB[a:gDZlB]a:_4kMC]a>gDkL
C]e:g4kM1Eif00Y:g4ZlB]a:_4[LC]a>o4kLC_e>g09>o00:D_e>g4kmC]a2_GJ`M]5f/7KAM[05AY`0
0dkLC_e>g002D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0U;l00=oo`00Ool01Goo000`Ool2000bOol0:BFi9IPUVDZlC]e:g4[MA[a:gEjFHYMNUV:g<OXf6c7j
C]e:g4kMB[a>gD[LC]eF55HeEQAF5EHD001:_4[MB[a>gDZlC_e>g4kmA[a:gDJlGWL00Uif0==JMTm=
Bba:gDZlC]e:_4[MC]aBoDkLD_e>g5;mC]aBoDkLD_e>g7KAM[1jdGJ`M]5f/4JLAY]6W4:KAYa>g5;m
C]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d00006
Ool0039oo`03001oogoo031oo`=6_003B]a:gD[L008Eo0=RU`0=HYIRUc7j<QXanTkMC]a>gD[LA[e2
_DJmEQ@00UHE0`0000=>g4kMC]`00TkL00I>gDkLC]e6_DKMA[d4GWH00cYK>S]>g@03C]`03TkMC]a>
o4klD_e>g4kmC_aBoD[LC]e:gGKAM[02M[400gKA00]>g004C]`00dklD_e>g002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo003Ool00`00Oomoo`04Ool003=oo`03001o
ogoo02moo`0ZAYa:_DJLA[e:_4kMB]aRUejFH[MNUV:GCfmCL4JlB[e6_4kmB]a>gD[LA]e2_EHEEQAF
=EHD@W`nFd9lB]a>gD[LC_e:g4kmB]a>oDJlB]eJMUig0Uif0<Tj>ciK>S]>oDkLC_e>g5;mC]aBoDkL
D_e>g5;mC]aBoD[LC_e:g7KAM[1fdGJ`00`02dkMB]a>gD[LD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`027oo00<007ooOol00goo000dOol00`00Oomoo`0_Ool014[LB]e:
g4[M0dJm00=RUf:FHYL014m`0TZl00I6_4[MB]e:gD[LA[d2EQD045HDEQDnNd9l?W/nO3ikC]e>g4kM
C]a>gD[LC]e6_DKM15if00Tj>cYK>S]>oDkLC_a>g5;mC]`00Tkl00IBoDkLC_e>g4km@[d2M[400gKA
M[1f/@0300/014klC]a>oDkL0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00U;l2Woo
00<007ooOol00goo000eOol2000`Ool09TZlC]e:_4[MA[a:gEjFHYM?Kf:gGYHf6c7j=Q]:g4kMB[a>
gD[LC]e2_5HeEQAF5EHDESE:_4[MB[a>gDZlC_e>g4kmC]a>gD[LC_d2GWH0aeYFGWM;;4l/B[a>gDZl
D_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_ef/7KAM[1fdGJ`M]56VdJL@Y]BoDkLD_e>g5;mC_aBoDkL
D_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;l00aoo`03001oogoo00=oo`00=goo00<007ooOol0;Woo00I:
g4[MB]a:gA7L5O`2HYL03F:FHYLanS8J<OXb6T[LC]e:g4Jm@[e6_EHD00=F5@0>EQ@004ZlB]e:_4[L
B[a>gDkLC]e>g4KMA[e6g@=NMP9;;00:B]a:_4[LB[aBoDkLC_a>g5;mC]`2C_`01U;mB]a>gD[MC]ef
/09f/@03M]5f/4JL00=6W004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo0moo`03001oogoo
00=oo`00>7oo00<007ooOol0;Woo01M:_4kMB]a:gEjFH[MNUV:GGYIR]dJlB[e6_4[MB]a>gD[LA]e2
_DJmEQAF=EHD00<0000<B]a>gD[LC_e:g4kmB]a>oDkLB]e6_5ig0Uif0;mJESiK>S]>oDkLC_e>g5;m
C]aBoDkLD_e>g5;mC]aBoD[LC_e:g7KAM[1fdGJ`M]402dkMB]a>gD[LD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00019oo`03001oogoo00=oo`00>Goo00<007ooOol0;Woo0dJm00=6gF:FHYL00V:G00e?Kdm`
B[a:_4JlB[a>g4kMB]a6_D:mEQEF5002EQD01D9l?W/nO4kLC]d00dkL00I>gD[LC]e>g4KMA[d3GWH0
13Xk>U/j>ciK0dkL00iBoDkLC_a>o5;mC]a>oDklD_e:g4kMB]efdGJ`0WJa00<0300;C]`00dkL0U;l
00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo003D_eBo5;l00Aoo`03001oogoo00moo`03001oogoo00=oo`00>Woo0P00;goo02I6_4[MA[aR
UejFH[MNUV:G<OXf6d[LC]e:_4kMB]a>gD[LA]eF55HEEQAF=EHD@W`nFd9lC]a>oDkLC_e>g4kMB]a>
o@4H0CUJEUig0Uif0;E:_4kMB[a:gDkLD_e>g5;mC]aBoDkLC_e>g5;mC]a>oGJ`M]5f/7KAM[1fd@0;
00`02e;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo008Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003aoo`03001oogoo02eo
o`=6_@0;HYMRUV:GHYLb6S7j<QY:g4kMB]a>g002B]d04T:mEQEF5EHEEQAF5@00B]e:_4[LC]a>gDkL
C]e>g4kMB]a>g@ANMP9;;009B[a:g4ZlB]a>g4klC]aBoDkL009>o006C_e>g4kmC]afdGJ`0WJa00=f
dGJa00`00dJL00A>o4kLC_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo00]oo`03001oogoo00moo`03001oogoo009oo`00?Goo00<007ooOol0
;Goo01@AfaGlGYIRUejFH[MNUSHK<OXf6d[LC]e:g4km@[e6_D:lESEF55HE0P0000a:_4[MB[a>gDkL
C_e:g4kmC]a:gDJlGWL2GWH0/4L;Bba;2d//C]a>oDkLC_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[LM]5f
/7KAM[1fd@0;AYa6VdJL@Y]BoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_dAOol00`00Oomoo`0>Ool00`00Oomoo`02Ool003ioo`03001oogoo02eoo`0AHYIR
Uf:GHYMRUT]_Bdm:_4JlB[a>g4kMB]a>gD:mA[eF5003EQD013ik?Wa>g4kM0dkL00I>oDkLC]e6_DKM
A[d4GWH00ciK>S/nF`03C]`03DkMC]a>o4klD_e>g4kmC_a>gD[LC]e:gGKA00=f/@0300`02dkL00=>
g004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Uoo`03001oogoo00eoo`03
001oogoo009oo`00?goo00<007ooOol0;Goo0<QNUV:gGYI?L4]?Cg16_4ZmA[a:gD[LC]e:g4kM@[eF
5EHDESEF549l?U]2O3iKC]e:g4kmB]a>gD[LC_e6_4[MFUINMeYfGWHj>ciK>S/nFdkLD_e>g5;mC]aB
oDkLD_e>g5;mC]a2_D:LM]5f/7KAM[1fd@0;00`02dkMB]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m77oo00<007ooOol03Goo00<007ooOol00Woo0010Ool2000]Ool00f:GHYIRU`02Ool0
1S7j<QY:g4kMB]a>g09:g@05B]a6_EHEEQEF5002EQD02d[MB[a:g4ZlC]e>g4kMC]a>gD[LC]d01Uif
00U:_4[LB[a:g4kLC_a>g4kmC]`00Tkl00EBoDkLC_e>g4:m00=f/@03M]5f/DJL00=6W004C_a>g4km
C]`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol07Woo00<007ooOol037oo00<007ooOol00Woo0012
Ool00`00Oomoo`0[Ool08f:GOomoogoo=Q/anSHKB]a>gDZlC]e:g4kMB]aF=EHDEQEF55He001:gDZl
C]e:_4kmC]a>oDJlB]e6_5igFWINMUYFGWL00P0009]:_4kMB[a:gDkLD_e>g5;mC]aBoDkLD_e>g5;m
C]afdGJ`M]5f/7KAL[16W4JKAYa2Ve;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l02Eoo`03001oogoo00]oo`03
001oogoo009oo`00@goo00<007ooOol0;goo00Xb6S7j<QY>g4kMB]a>gD:mA[e2_@=F5@<0000:C]e>
g4kLC]a>oDkLC]e6_DKMA[d4GWH00ciK>S/nF`03C]`03DkMC]a>o4kLD_e>g4kmC_aBoD[LC]e:gGKA
00=f/@03M]402dkL00=>g004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`XOol00`00Oomoo`0;Ool00`00Oomoo`02Ool004Ao
o`03001oogoo02moo`2cB[e6_4[MB]a>gD[LC_e2_DJmEQAF=EHDESDnFd9l?U]>gD[LC_e:g4kmB]a>
oDJlB]eJEUigFWINMSXk?U/j>ciKC]a>oDkLC_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LM]5b/7KAM[00
300;C]e:g4kMB]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@0]Ool00`00Oomoo`0;Ool00`00Oomoo`01Ool004Eoo`80031oo`03B[a6_4Zl
009:g@05B]a:gD:mEQEF5002EQD03D9l?W/nO3ikC]e>g4kMC]a>gD[LC]e6_DKM00ANMP09>S/nFcXk
C_e>g4klC]a>oDkL009>o006D_e>g4kmC]a>oD:m0WJa00=fdGJaM[400P0<00D02dklC]a>oDkL009B
o005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0<Goo00<0
07ooOol02Woo00<007ooOol00Goo0017Ool00`00Oomoo`0^Ool06dkMB[a>gD[LC]e:g4KMEQAF5EHD
ESEF54[MB[a>gDZlC_e>g4kmC]a>gD[LC_eJMUifFUINM`020000STZlC]e:_4[MC]aBoDkLD_e>g5;m
C]aBoDkLD_e>g4kmL[1fdGJ`M]5b/4JLAY]6W4:KD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m=Goo00<007ooOol02Goo00<007ooOol00Goo0018Ool00`00
Oomoo`0^Ool01TkMB]a>gDkLA[e2_@=F5@0>EQ@00000B]e:_4[LB[a>oDkLC]e>g4KMA[e6g@=NMP<0
00=>g006C]e>g4klC]aBoDkL0Tkl00E>gD[LC]e:gDkM00=f/@03M]4034JL00=6W004D_a>o5;mC]`2
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0>7oo00<007ooOol02Goo00<007oo
Ool00Goo0019Ool00`00Oomoo`0^Ool0XTkMB]a>oD[LA[e2_5HeEQAF=EHD@W`nFdkMB]a>oD[LC_e:
g4kmC]a:gDJlGWMJMUifFUHnFcXk?U]>g4kmC]a>oDkLD_e>g5;mC]aBoDkLC]e:g4kmB]afdG:`M]5f
/00<B]a>gD[LC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo3eoo`03001oogoo
00Qoo`03001oogoo005oo`00BWoo0P00;goo00I:gD[LB]e2_EHEEQ@3EQD013ik?W`nNd9l0dkL00I>
gD[LC]e>g4KMA[d3GWH02CXk?U/j>ciKC]a>o4kLC_e>g002C_`015;mC]a>oDkl0T:m0WJa00=fdGJa
M[400`0<0dkL00E>o5;lD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo041oo`03001oogoo00Mo
o`03001oogoo005oo`00C7oo00<007ooOol0;Goo09U>gD[LC]e2_EHeEQAF=EHDESE:_4kMB[a:gDkL
C_e>g4kMB]a>oD[LGWIJEUigFWINMTZlC]e:_4[MC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmL[1fdGJ`
M]5b/4JLAY]6W4:KD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0AWoo00<007ooOol01Woo00<007oo
Ool00Goo001=Ool00`00Oomoo`0]Ool00d[MB]a6_@02EQD03UHDEQEF5@00B[a:g4ZlB]e>g4kMC]a6
gDJmA]d4GWH20003B[`01T[LC]a>o4kLD_e>g09>o005D_e:g4kMB]e>g@03M[400gKAM[56W003AY`0
15;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d0BGoo00<007ooOol01goo0@000Goo0Goo001>Ool00`00Oomoo`0]
Ool01TJm@[aF=EHDESEF50<00028B]a>oD[LC]e:g4kmC]a:gDJlB]eJMUifFUINMcXk?U]>g4kmC]a>
oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]afdG:`M]5f/GKA00]>gD[LC]e:_5;mC]aBoDkLD_eBo5;mC]aB
oE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_e=Ool00`00
Oomoo`06Ool10001Ool1Ool004moo`8002ioo`03A[eF55HE009F5@04EQ@nO3ik@W`3C]`01TkMC]a>
gDkLA]e6_@ANMP04?U/j>ciK>S/2C]`03DkMC]a>o4klD_e>g4kmC_aBoD[LC]e:gGKA00=f/@8030A>
g09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
DWoo00<007ooOol01Goo0@000Goo0Goo001AOol00`00Oomoo`0[Ool0;4:mESEF55HeEQAF=EHD@W`n
Fd9lC]a>oDkLC_e:g4kmB]a:gDJlGWMJMUifFUI>gDZlB]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e2
_7KAM[5fdG:`M]4200`0F`0;D_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l05Eoo`03001oogoo00Eoo`40005oo`5oo`00DWoo00<007ooOol0:goo
00=2_EHEEQ@00eHE00/004[LB[a:gDkLC]e>g4kMB]a>gDkL00ANMP80009:_006B]a:_4klC]aBoDkL
0Tkl00EBoDkLC_e>g4km00=f/@03M]5f/@0<00=6W004C_a>g5;mC]`2D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;lFGoo00<007ooOol017oo0@000Goo0Goo001COol00`00Oomo
o`0ZOol01DKMEQAF=EHDESD00`0000a>gDZlB]e:g4kmC]a>oDJlB]eJMUifFUH400004dkmC]a>oDkL
D_e>g5;mC]aBoDkLD_e>g4kmB]a>gG:`M]5f/GKA0080301EAY]6W4:KD_e>g5;mC]aBoDklD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0GGoo00<007ooOol00goo0@000Goo0Goo001DOol00`00
Oomoo`0ZOol3EQD01EHD?W`nNd9l?W/00TkL00M>gDkLC]e>g4kmA[e6g@04GWH00cXk?U/j>`02C]`0
3DkMC]a>o4klD_e>g4kmC_aBoD[LC]e:gDkM00=f/@<030=>g004D_a>o5;mC]`2D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@02D_aROol00`00Oomoo`03Ool10001Ool005Eoo`8002Yoo`03EQAF=EHD009oo`0U
@W`nFd9l?U]>oDkLC_e>g4kmB]a>gDJlGWMJMUifFUHnFcXk?U]>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
C_e2_7KAM[5fdG:`M]400`0<04eBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m06Eoo`03
001oogoo00=oo`40005oo`00Egoo00<007ooOol0:7oo00mF55HEOomoodZlB]a:_4[MB[a>gDkLC]e:
g4kMC]`015if0P000TZl00I:g4kLC_a>g4kmC]`2C_`01E;mC]a>oDkLC_d00gJa00=fdGJaM[400dJL
00A>o4kLD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;lK7oo00<007ooOol00Woo0@000Goo001HOol00`00Oomoo`0WOol0
0eHeOomoo`02Ool03TZlC]e:_4[MB]a>oDkLC_e6_4[MA[aNMUYFGWL30000FDkMB[a:gDkLD_e>g5;m
C]aBoDkLD_e:g4kmB]a>gG:`M]5b/GKAL[56W4JKAYa2Ve;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0LGoo00D007ooOomoo`00
005oo`00FGoo00<007ooOol09Woo00=F5GooOol00goo0dkL00M>gDkLC]e>g4kmA[e6g@04GWH00cXk
?U/j>`02C]`03DkMC]a>o4klD_e>g4kmC_aBoD[LC]e:gDkM00=f/@03M]4034kL00=>g004D_a>o5;m
C]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lMGoo
00@007ooOol0005oo`00FWoo0P00;Woo029>oD[LC]e:g4kmB]a>gDJlB]eJMUifFUINMcXk?U/j>U;m
C]aBoDkLD_e>g5;mC]aBoDkLD_e2_4JmL[5fdG:aM]5b/@80300m00e:g4kMB[aBoDkLD_e>g5;mD_aB
oDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0N7oo00@007ooOol0005oo`00
G7oo00<007ooOol0;7oo00M>gDkLC]e>g4kMC]a>g@04GWH200001dZlB]a:_4klC]a>oDkL009>o006
D_e>g4kmC]a>oDkL0WJa00AfdGJaM[4030=6W006C]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00U;lO7oo00<007oo00000Goo001MOol00`00Oomoo`0/Ool02TkmC]a>
oD[LB]e6_4[MFUINMeYf0`0004a:_4[MB[aBoDkLD_e>g5;mC]aBoDkLC_e:g4kMB]afdG:aM]5b/@0=
AY]6W4:KAYa>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoH1oo`40005o
o`400000GWoo00<007ooOol0;7oo00I>gDkLC_e>g4KMA[d4GWH01CiK>S/nFdkLC]d00dkL00UBoDkL
C_e>o5;mC]a>gD[MC]d00gJa00=fd@0<00`014kL00=>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_aBo024Ool2000005moo`8002eoo`1@C_e:g4kMB]a:gDJlGWIJEUig>S/nFcXj?U]>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kML[5fdG:a00d0300=B]a>gDZlD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo8Qoo`800000HGoo00<007ooOol0:goo00A>gDkLC]e:g0ENMP07B[a:g4ZlB[a>g4km
C]`00Tkl00IBoDkLC_a>g4kmC]`2M[400gKAM[5f/@0300`024klC]aBoDkLC_aBo5;mC_`2D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoE;lOol0RWoo0P00001ROol00`00Oomoo`0[Ool01d[MA[a:gDJlGWMJMUif0080000oB[a:gDZl
C]e>g5;mC]aBoDkLD_e>g5;mC]a>oG:aM]5b/GKAL[5fdTJKAYa2VdJLC]aBoDkLD_e>o5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
08Yoo`@0009oo`00Hgoo00<007ooOol0;7oo00=6_DKMGWH00Uif00DnFcXk?U]>g4kM00=>g009D_e>
g4kmC_aBoDkLC]e:gDkM00Ef/@0300a>g4kL009>g003C_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08aoo`@000Ioo`00I7oo0P00;Goo
03a6_4[MFUINMeYf?U/j>SiKC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>gG:aM]9b/GKA00`03D[L
C]e:_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
Daf;Ool4000:Ool006Ioo`03001oogoo02]oo`ANMP07B[a:g4ZlB[a>g4kmC]`00Tkl00MBoDkLC_a>
g4kmC]a2_@05M[402P0=00`034kLD_e>g4klD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aBo02:Ool4000>Ool006Moo`03001oogoo02Yoo`03GWMJMUif0080000`B[a:
gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLM]9b/GKAL[5fdP0<AYa2VdJLC]aBoDkLD_e>o5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MRWoo0`004Woo001XOol00`00Oomoo`0YOol3
GWH01Goo>S/nFdkLC]d00dkL00YBoDkLC_a>o5;mC]a>oD[MC]e:g0=f/@03L[403DkL00=>g003C_aB
oDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lRGoo10005Goo001YOol2000ZOol0
;UYFOomoociK>SXnFcXkC_e>g4kmC]aBoDkLD_e>g5;mC]aBoD[LC]e:g7KBL[5fd@0<00e:g4kMB[a>
gDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mR7oo10006Goo001[Ool00`00Oomoo`0WOol0
1EifOomoogooB]`00dZl00]>oDkLC_a>g5;mC]a>o4kLC_e>g4km009f/@0=L[5f/GJa00d0300=C]aB
oDkLC_aBo5;mC_`00U;l00EBoE;lD_aBo5;m009Bo8Moo`@001eoo`00K7oo00<007ooOol0:goo021>
gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]a>oDkLM]9b/GKAL[5fdW:aAYa2VdJLAY]BoDkLD_e>o5;mC]aB
oDklRGoo10008Goo001]Ool00`00Oomoo`0[Ool03TkMC]a>g4kLD_e>g4klC]aBoDkLC_e>o4kMB]`3
M[400g:aM[403@04C]`015;mC]aBo4klRGoo0`009Goo001^Ool00`00Oomoo`0/Ool05dkLC_e>g5;m
C]aBoDkLD_e>g5;mB]a>gD[LM]9b/GKAL[403@0<C]e:_4kMB]`0R7oo1000:7oo001_Ool2000]Ool0
3DkLC_a>g5;mC]a>o4kLC_e>g4km@[ef/G:a00=f/@0300`03@0=08Moo`@002aoo`00LGoo00<007oo
Ool0:Woo00mBoDkLD_e>g5;mC]aBoDkLC_e>g5;mL[5fdG:aM]80Qgoo1000<7oo001bOol00`00Oomo
o`0ZOol02e;mC]a>o4kLD_e>g4kmC_a>gD[LC]d00WJaQ7oo1000=7oo001cOol00`00Oomoo`0ZOol0
2e;mC]aBoDkLD_e>g5;mC]a>gD[LC_d0PGoo1000>7oo001dOol2000/Ool00`00Oomoo`24Ool3000l
Ool007Ioo`03001oogoo02Uoo`03001oogoo081oo`@003moo`00Mgoo00<007ooOol0:7oo00<007oo
Ool0O7oo1000@goo001hOol00`00Oomoo`0WOol00`00Oomoo`1hOol40017Ool007Uoo`8002Moo`03
001oogoo07Aoo`@004]oo`00Ngoo00<007ooOol097oo00<007ooOol0LGoo0`00Cgoo001lOol00`00
Oomoo`0SOol00`00Oomoo`1]Ool4001BOol007eoo`03001oogoo029oo`03001oogoo06Uoo`@005Io
o`00OWoo0P008Woo00<007ooOol0IGoo1000FWoo0020Ool00`00Oomoo`0OOol00`00Oomoo`1QOol4
001NOol0085oo`03001oogoo01ioo`03001oogoo05ioo`<0069oo`00PWoo00<007ooOol07Goo00<0
07ooOol0FWoo1000IGoo0023Ool00`00Oomoo`0LOol00`00Oomoo`1FOol4001YOol008Aoo`8001ao
o`03001oogoo059oo`@006eoo`00QWoo00<007ooOol06Goo00<007ooOol0CWoo1000LGoo0027Ool0
0`00Oomoo`0HOol00`00Oomoo`1;Ool3001eOol008Qoo`03001oogoo01Moo`03001oogoo04Moo`@0
07Qoo`00RGoo0P005goo00<007ooOol0@goo1000O7oo002;Ool00`00Oomoo`0DOol00`00Oomoo`0o
Ool40020Ool008aoo`03001oogoo019oo`03001oogoo03aoo`@008Aoo`00SGoo00<007ooOol04Goo
00<007ooOol0>Goo0`00R7oo002>Ool2000AOol00`00Oomoo`0eOol4002;Ool0091oo`03001oogoo
00ioo`03001oogoo035oo`@008moo`00TGoo00<007ooOol03Goo00<007ooOol0;Goo1000Tgoo002B
Ool00`00Oomoo`0<Ool00`00Oomoo`0YOol4002GOol009=oo`8000aoo`03001oogoo02Eoo`@009]o
o`00UGoo00<007ooOol02Goo00<007ooOol08Woo0`00Wgoo002FOol00`00Oomoo`08Ool00`00Oomo
o`0NOol4002ROol009Moo`03001oogoo00Moo`03001oogoo01Yoo`@00:Ioo`00V7oo00<007ooOol0
1Woo00<007ooOol05Woo1000ZWoo002IOol20006Ool00`00Oomoo`0BOol4002^Ool009]oo`03001o
ogoo00=oo`03001oogoo00moo`<00;9oo`00W7oo00<007ooOol00Woo00<007ooOol02goo1000]Goo
002MOol01@00Oomoogoo00002Goo1000^Goo002NOol200000goo001oo`04Ool4002mOol00:1oo`80
0003Ool0000000800<5oo`00XGoo0P00aGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.632 .733 .92 r
.39638 .69682 .40169 .70178 .4106 .69968 .4053 .69483 Mtetra
.64 .74 .921 r
.4053 .69483 .4106 .69968 .41954 .69752 .41426 .69266 Mtetra
.638 .739 .922 r
.41426 .69266 .41954 .69752 .42851 .69549 .42325 .69051 Mtetra
.621 .73 .925 r
.42325 .69051 .42851 .69549 .43749 .69454 .43226 .68872 Mtetra
0 .317 .801 r
.43226 .68872 .43749 .69454 .4467 .68453 .44112 .69471 Mtetra
0 0 0 r
.44112 .69471 .4467 .68453 .45569 .6858 .45049 .68028 Mtetra
.608 .707 .914 r
.45049 .68028 .45569 .6858 .46478 .68379 .45959 .67882 Mtetra
.642 .739 .92 r
.45959 .67882 .46478 .68379 .47391 .68142 .46873 .67656 Mtetra
.65 .747 .92 r
.46873 .67656 .47391 .68142 .48307 .67892 .47792 .6741 Mtetra
.654 .75 .92 r
.47792 .6741 .48307 .67892 .49227 .67635 .48713 .67154 Mtetra
.656 .751 .92 r
.48713 .67154 .49227 .67635 .50149 .67372 .49638 .66891 Mtetra
.658 .753 .92 r
.49638 .66891 .50149 .67372 .51075 .67105 .50565 .66624 Mtetra
.659 .753 .92 r
.50565 .66624 .51075 .67105 .52004 .66835 .51496 .66353 Mtetra
.659 .754 .92 r
.51496 .66353 .52004 .66835 .52936 .66565 .5243 .66081 Mtetra
.5243 .66081 .52936 .66565 .53871 .66294 .53367 .65808 Mtetra
.53367 .65808 .53871 .66294 .54809 .66022 .54308 .65535 Mtetra
.658 .753 .92 r
.54308 .65535 .54809 .66022 .5575 .65751 .55251 .65261 Mtetra
.55251 .65261 .5575 .65751 .56695 .65479 .56198 .64987 Mtetra
.56198 .64987 .56695 .65479 .57643 .65206 .57148 .64713 Mtetra
.57148 .64713 .57643 .65206 .58593 .64933 .58101 .64438 Mtetra
.58101 .64438 .58593 .64933 .59548 .64659 .59057 .64162 Mtetra
.59057 .64162 .59548 .64659 .60505 .64385 .60017 .63886 Mtetra
.60017 .63886 .60505 .64385 .61466 .6411 .6098 .63609 Mtetra
.657 .753 .92 r
.6098 .63609 .61466 .6411 .6243 .63834 .61946 .63331 Mtetra
.61946 .63331 .6243 .63834 .63397 .63557 .62916 .63053 Mtetra
.62916 .63053 .63397 .63557 .64368 .63279 .63889 .62773 Mtetra
.657 .752 .92 r
.63889 .62773 .64368 .63279 .65342 .63001 .64865 .62493 Mtetra
.64865 .62493 .65342 .63001 .6632 .62722 .65845 .62212 Mtetra
.65845 .62212 .6632 .62722 .673 .62442 .66828 .6193 Mtetra
.66828 .6193 .673 .62442 .68285 .62161 .67815 .61647 Mtetra
.67815 .61647 .68285 .62161 .69272 .61879 .68805 .61364 Mtetra
.68805 .61364 .69272 .61879 .70263 .61596 .69798 .61079 Mtetra
.69798 .61079 .70263 .61596 .71258 .61313 .70795 .60793 Mtetra
.70795 .60793 .71258 .61313 .72256 .61028 .71796 .60507 Mtetra
.71796 .60507 .72256 .61028 .73257 .60742 .728 .6022 Mtetra
.728 .6022 .73257 .60742 .74262 .60456 .73807 .59931 Mtetra
.73807 .59931 .74262 .60456 .75271 .60169 .74818 .59642 Mtetra
.74818 .59642 .75271 .60169 .76283 .5988 .75833 .59352 Mtetra
.75833 .59352 .76283 .5988 .77299 .59591 .76851 .5906 Mtetra
.76851 .5906 .77299 .59591 .78318 .593 .77873 .58768 Mtetra
.77873 .58768 .78318 .593 .79341 .59009 .78898 .58475 Mtetra
.78898 .58475 .79341 .59009 .80367 .58717 .79927 .58181 Mtetra
.79927 .58181 .80367 .58717 .81397 .58424 .8096 .57885 Mtetra
.8096 .57885 .81397 .58424 .82431 .58129 .81997 .57589 Mtetra
.81997 .57589 .82431 .58129 .83469 .57834 .83037 .57292 Mtetra
.83037 .57292 .83469 .57834 .8451 .57538 .84081 .56993 Mtetra
.84081 .56993 .8451 .57538 .85555 .5724 .85128 .56694 Mtetra
.85128 .56694 .85555 .5724 .86604 .56942 .8618 .56394 Mtetra
.8618 .56394 .86604 .56942 .87656 .56642 .87235 .56092 Mtetra
.87235 .56092 .87656 .56642 .88712 .56342 .88294 .5579 Mtetra
.88294 .5579 .88712 .56342 .89772 .5604 .89357 .55486 Mtetra
.89357 .55486 .89772 .5604 .90836 .55738 .90424 .55182 Mtetra
.90424 .55182 .90836 .55738 .91904 .55434 .91494 .54876 Mtetra
.91494 .54876 .91904 .55434 .92976 .55129 .92569 .54569 Mtetra
.92569 .54569 .92976 .55129 .94051 .54824 .93647 .54261 Mtetra
.93647 .54261 .94051 .54824 .95131 .54517 .94729 .53952 Mtetra
.94729 .53952 .95131 .54517 .96214 .54209 .95816 .53642 Mtetra
.95816 .53642 .96214 .54209 .97301 .539 .96906 .53331 Mtetra
.96906 .53331 .97301 .539 .98393 .53589 .98 .53019 Mtetra
.62 .721 .919 r
.39104 .69163 .39638 .69682 .4053 .69483 .39996 .6899 Mtetra
.638 .737 .921 r
.39996 .6899 .4053 .69483 .41426 .69266 .40894 .68777 Mtetra
.64 .74 .921 r
.40894 .68777 .41426 .69266 .42325 .69051 .41795 .68557 Mtetra
.634 .737 .923 r
.41795 .68557 .42325 .69051 .43226 .68872 .42699 .6835 Mtetra
.58 .709 .931 r
.42699 .6835 .43226 .68872 .44112 .69471 .43603 .68252 Mtetra
.747 .625 .724 r
.43603 .68252 .44112 .69471 .45049 .68028 .44532 .67244 Mtetra
.5 .586 .872 r
.44532 .67244 .45049 .68028 .45959 .67882 .45437 .67368 Mtetra
.632 .731 .919 r
.45437 .67368 .45959 .67882 .46873 .67656 .46353 .67163 Mtetra
.647 .744 .92 r
.46353 .67163 .46873 .67656 .47792 .6741 .47273 .66922 Mtetra
.652 .748 .92 r
.47273 .66922 .47792 .6741 .48713 .67154 .48196 .66668 Mtetra
.655 .751 .92 r
.48196 .66668 .48713 .67154 .49638 .66891 .49123 .66406 Mtetra
.657 .752 .92 r
.49123 .66406 .49638 .66891 .50565 .66624 .50053 .66139 Mtetra
.658 .753 .92 r
.50053 .66139 .50565 .66624 .51496 .66353 .50986 .65868 Mtetra
.659 .754 .92 r
.50986 .65868 .51496 .66353 .5243 .66081 .51922 .65595 Mtetra
.51922 .65595 .5243 .66081 .53367 .65808 .52861 .6532 Mtetra
.52861 .6532 .53367 .65808 .54308 .65535 .53803 .65044 Mtetra
.53803 .65044 .54308 .65535 .55251 .65261 .54749 .64769 Mtetra
.658 .753 .92 r
.54749 .64769 .55251 .65261 .56198 .64987 .55698 .64493 Mtetra
.55698 .64493 .56198 .64987 .57148 .64713 .5665 .64216 Mtetra
.5665 .64216 .57148 .64713 .58101 .64438 .57605 .63939 Mtetra
.57605 .63939 .58101 .64438 .59057 .64162 .58564 .63662 Mtetra
.58564 .63662 .59057 .64162 .60017 .63886 .59526 .63384 Mtetra
.59526 .63384 .60017 .63886 .6098 .63609 .60491 .63105 Mtetra
.657 .753 .92 r
.60491 .63105 .6098 .63609 .61946 .63331 .6146 .62825 Mtetra
.6146 .62825 .61946 .63331 .62916 .63053 .62431 .62545 Mtetra
.62431 .62545 .62916 .63053 .63889 .62773 .63407 .62264 Mtetra
.63407 .62264 .63889 .62773 .64865 .62493 .64385 .61982 Mtetra
.657 .752 .92 r
.64385 .61982 .64865 .62493 .65845 .62212 .65367 .61699 Mtetra
.65367 .61699 .65845 .62212 .66828 .6193 .66353 .61415 Mtetra
.66353 .61415 .66828 .6193 .67815 .61647 .67342 .6113 Mtetra
.67342 .6113 .67815 .61647 .68805 .61364 .68334 .60845 Mtetra
.68334 .60845 .68805 .61364 .69798 .61079 .6933 .60558 Mtetra
.6933 .60558 .69798 .61079 .70795 .60793 .7033 .60271 Mtetra
.7033 .60271 .70795 .60793 .71796 .60507 .71332 .59983 Mtetra
.71332 .59983 .71796 .60507 .728 .6022 .72339 .59693 Mtetra
.72339 .59693 .728 .6022 .73807 .59931 .73349 .59403 Mtetra
.73349 .59403 .73807 .59931 .74818 .59642 .74362 .59112 Mtetra
.74362 .59112 .74818 .59642 .75833 .59352 .7538 .5882 Mtetra
.7538 .5882 .75833 .59352 .76851 .5906 .764 .58526 Mtetra
.764 .58526 .76851 .5906 .77873 .58768 .77425 .58232 Mtetra
.77425 .58232 .77873 .58768 .78898 .58475 .78453 .57937 Mtetra
.78453 .57937 .78898 .58475 .79927 .58181 .79484 .57641 Mtetra
.79484 .57641 .79927 .58181 .8096 .57885 .8052 .57344 Mtetra
.8052 .57344 .8096 .57885 .81997 .57589 .81559 .57045 Mtetra
.81559 .57045 .81997 .57589 .83037 .57292 .82602 .56746 Mtetra
.82602 .56746 .83037 .57292 .84081 .56993 .83648 .56446 Mtetra
.83648 .56446 .84081 .56993 .85128 .56694 .84699 .56144 Mtetra
.84699 .56144 .85128 .56694 .8618 .56394 .85753 .55842 Mtetra
.85753 .55842 .8618 .56394 .87235 .56092 .86811 .55539 Mtetra
.86811 .55539 .87235 .56092 .88294 .5579 .87873 .55234 Mtetra
.87873 .55234 .88294 .5579 .89357 .55486 .88938 .54928 Mtetra
.88938 .54928 .89357 .55486 .90424 .55182 .90008 .54622 Mtetra
.90008 .54622 .90424 .55182 .91494 .54876 .91081 .54314 Mtetra
.91081 .54314 .91494 .54876 .92569 .54569 .92159 .54005 Mtetra
.92159 .54005 .92569 .54569 .93647 .54261 .9324 .53695 Mtetra
.9324 .53695 .93647 .54261 .94729 .53952 .94325 .53384 Mtetra
.94325 .53384 .94729 .53952 .95816 .53642 .95415 .53072 Mtetra
.95415 .53072 .95816 .53642 .96906 .53331 .96508 .52759 Mtetra
.96508 .52759 .96906 .53331 .98 .53019 .97605 .52444 Mtetra
.583 .684 .91 r
.38569 .68575 .39104 .69163 .39996 .6899 .3946 .68487 Mtetra
.632 .733 .92 r
.3946 .68487 .39996 .6899 .40894 .68777 .40359 .68284 Mtetra
.64 .74 .921 r
.40359 .68284 .40894 .68777 .41795 .68557 .41262 .68063 Mtetra
.638 .739 .922 r
.41262 .68063 .41795 .68557 .42699 .6835 .42167 .67844 Mtetra
.621 .73 .925 r
.42167 .67844 .42699 .6835 .43603 .68252 .43075 .67662 Mtetra
0 .321 .804 r
.43075 .67662 .43603 .68252 .44532 .67244 .43968 .68261 Mtetra
0 0 0 r
.43968 .68261 .44532 .67244 .45437 .67368 .44913 .66808 Mtetra
.608 .707 .914 r
.44913 .66808 .45437 .67368 .46353 .67163 .45829 .66659 Mtetra
.642 .739 .92 r
.45829 .66659 .46353 .67163 .47273 .66922 .46751 .66429 Mtetra
.65 .747 .92 r
.46751 .66429 .47273 .66922 .48196 .66668 .47676 .66178 Mtetra
.654 .75 .92 r
.47676 .66178 .48196 .66668 .49123 .66406 .48605 .65918 Mtetra
.656 .751 .92 r
.48605 .65918 .49123 .66406 .50053 .66139 .49537 .65651 Mtetra
.658 .753 .92 r
.49537 .65651 .50053 .66139 .50986 .65868 .50472 .65379 Mtetra
.659 .753 .92 r
.50472 .65379 .50986 .65868 .51922 .65595 .5141 .65105 Mtetra
.659 .754 .92 r
.5141 .65105 .51922 .65595 .52861 .6532 .52351 .64828 Mtetra
.52351 .64828 .52861 .6532 .53803 .65044 .53296 .64551 Mtetra
.53296 .64551 .53803 .65044 .54749 .64769 .54243 .64273 Mtetra
.658 .753 .92 r
.54243 .64273 .54749 .64769 .55698 .64493 .55194 .63995 Mtetra
.55194 .63995 .55698 .64493 .5665 .64216 .56149 .63717 Mtetra
.56149 .63717 .5665 .64216 .57605 .63939 .57106 .63438 Mtetra
.57106 .63438 .57605 .63939 .58564 .63662 .58067 .63159 Mtetra
.58067 .63159 .58564 .63662 .59526 .63384 .59031 .62879 Mtetra
.59031 .62879 .59526 .63384 .60491 .63105 .59999 .62598 Mtetra
.59999 .62598 .60491 .63105 .6146 .62825 .6097 .62316 Mtetra
.657 .753 .92 r
.6097 .62316 .6146 .62825 .62431 .62545 .61944 .62034 Mtetra
.61944 .62034 .62431 .62545 .63407 .62264 .62921 .61751 Mtetra
.62921 .61751 .63407 .62264 .64385 .61982 .63902 .61467 Mtetra
.657 .752 .92 r
.63902 .61467 .64385 .61982 .65367 .61699 .64887 .61182 Mtetra
.64887 .61182 .65367 .61699 .66353 .61415 .65875 .60897 Mtetra
.65875 .60897 .66353 .61415 .67342 .6113 .66866 .6061 Mtetra
.66866 .6061 .67342 .6113 .68334 .60845 .67861 .60323 Mtetra
.67861 .60323 .68334 .60845 .6933 .60558 .68859 .60034 Mtetra
.68859 .60034 .6933 .60558 .7033 .60271 .69861 .59745 Mtetra
.69861 .59745 .7033 .60271 .71332 .59983 .70866 .59455 Mtetra
.70866 .59455 .71332 .59983 .72339 .59693 .71875 .59163 Mtetra
.71875 .59163 .72339 .59693 .73349 .59403 .72888 .58871 Mtetra
.72888 .58871 .73349 .59403 .74362 .59112 .73904 .58578 Mtetra
.73904 .58578 .74362 .59112 .7538 .5882 .74923 .58284 Mtetra
.74923 .58284 .7538 .5882 .764 .58526 .75947 .57989 Mtetra
.75947 .57989 .764 .58526 .77425 .58232 .76974 .57693 Mtetra
.76974 .57693 .77425 .58232 .78453 .57937 .78004 .57396 Mtetra
.78004 .57396 .78453 .57937 .79484 .57641 .79039 .57097 Mtetra
.79039 .57097 .79484 .57641 .8052 .57344 .80077 .56798 Mtetra
.80077 .56798 .8052 .57344 .81559 .57045 .81118 .56498 Mtetra
.81118 .56498 .81559 .57045 .82602 .56746 .82164 .56197 Mtetra
.82164 .56197 .82602 .56746 .83648 .56446 .83213 .55894 Mtetra
.83213 .55894 .83648 .56446 .84699 .56144 .84266 .55591 Mtetra
.84266 .55591 .84699 .56144 .85753 .55842 .85323 .55287 Mtetra
.85323 .55287 .85753 .55842 .86811 .55539 .86384 .54981 Mtetra
.86384 .54981 .86811 .55539 .87873 .55234 .87449 .54674 Mtetra
.87449 .54674 .87873 .55234 .88938 .54928 .88517 .54367 Mtetra
.88517 .54367 .88938 .54928 .90008 .54622 .8959 .54058 Mtetra
.8959 .54058 .90008 .54622 .91081 .54314 .90666 .53748 Mtetra
.90666 .53748 .91081 .54314 .92159 .54005 .91746 .53437 Mtetra
.91746 .53437 .92159 .54005 .9324 .53695 .9283 .53125 Mtetra
.9283 .53125 .9324 .53695 .94325 .53384 .93919 .52812 Mtetra
.93919 .52812 .94325 .53384 .95415 .53072 .95011 .52498 Mtetra
.95011 .52498 .95415 .53072 .96508 .52759 .96107 .52182 Mtetra
.96107 .52182 .96508 .52759 .97605 .52444 .97207 .51866 Mtetra
.318 .378 .767 r
.3806 .67297 .38569 .68575 .3946 .68487 .38921 .6796 Mtetra
.62 .721 .919 r
.38921 .6796 .3946 .68487 .40359 .68284 .39821 .67784 Mtetra
.638 .737 .921 r
.39821 .67784 .40359 .68284 .41262 .68063 .40725 .67567 Mtetra
.64 .74 .921 r
.40725 .67567 .41262 .68063 .42167 .67844 .41633 .67343 Mtetra
.634 .737 .923 r
.41633 .67343 .42167 .67844 .43075 .67662 .42543 .67132 Mtetra
.58 .709 .931 r
.42543 .67132 .43075 .67662 .43968 .68261 .43454 .6703 Mtetra
.747 .625 .724 r
.43454 .6703 .43968 .68261 .44913 .66808 .44391 .66015 Mtetra
.5 .586 .872 r
.44391 .66015 .44913 .66808 .45829 .66659 .45303 .66136 Mtetra
.632 .731 .919 r
.45303 .66136 .45829 .66659 .46751 .66429 .46226 .65927 Mtetra
.647 .744 .92 r
.46226 .65927 .46751 .66429 .47676 .66178 .47153 .65683 Mtetra
.652 .748 .92 r
.47153 .65683 .47676 .66178 .48605 .65918 .48083 .65425 Mtetra
.655 .751 .92 r
.48083 .65425 .48605 .65918 .49537 .65651 .49017 .65159 Mtetra
.657 .752 .92 r
.49017 .65159 .49537 .65651 .50472 .65379 .49954 .64887 Mtetra
.658 .753 .92 r
.49954 .64887 .50472 .65379 .5141 .65105 .50895 .64612 Mtetra
.659 .754 .92 r
.50895 .64612 .5141 .65105 .52351 .64828 .51838 .64334 Mtetra
.51838 .64334 .52351 .64828 .53296 .64551 .52785 .64055 Mtetra
.52785 .64055 .53296 .64551 .54243 .64273 .53735 .63775 Mtetra
.53735 .63775 .54243 .64273 .55194 .63995 .54688 .63495 Mtetra
.658 .753 .92 r
.54688 .63495 .55194 .63995 .56149 .63717 .55644 .63214 Mtetra
.55644 .63214 .56149 .63717 .57106 .63438 .56604 .62933 Mtetra
.56604 .62933 .57106 .63438 .58067 .63159 .57567 .62652 Mtetra
.57567 .62652 .58067 .63159 .59031 .62879 .58534 .6237 Mtetra
.58534 .6237 .59031 .62879 .59999 .62598 .59503 .62087 Mtetra
.59503 .62087 .59999 .62598 .6097 .62316 .60476 .61804 Mtetra
.657 .753 .92 r
.60476 .61804 .6097 .62316 .61944 .62034 .61453 .6152 Mtetra
.61453 .6152 .61944 .62034 .62921 .61751 .62433 .61235 Mtetra
.62433 .61235 .62921 .61751 .63902 .61467 .63416 .60949 Mtetra
.63416 .60949 .63902 .61467 .64887 .61182 .64403 .60663 Mtetra
.657 .752 .92 r
.64403 .60663 .64887 .61182 .65875 .60897 .65393 .60375 Mtetra
.65393 .60375 .65875 .60897 .66866 .6061 .66387 .60087 Mtetra
.66387 .60087 .66866 .6061 .67861 .60323 .67384 .59797 Mtetra
.67384 .59797 .67861 .60323 .68859 .60034 .68385 .59507 Mtetra
.68385 .59507 .68859 .60034 .69861 .59745 .69389 .59216 Mtetra
.69389 .59216 .69861 .59745 .70866 .59455 .70397 .58923 Mtetra
.70397 .58923 .70866 .59455 .71875 .59163 .71408 .5863 Mtetra
.71408 .5863 .71875 .59163 .72888 .58871 .72423 .58336 Mtetra
.72423 .58336 .72888 .58871 .73904 .58578 .73442 .58041 Mtetra
.73442 .58041 .73904 .58578 .74923 .58284 .74464 .57745 Mtetra
.74464 .57745 .74923 .58284 .75947 .57989 .7549 .57448 Mtetra
.7549 .57448 .75947 .57989 .76974 .57693 .7652 .5715 Mtetra
.7652 .5715 .76974 .57693 .78004 .57396 .77553 .56851 Mtetra
.77553 .56851 .78004 .57396 .79039 .57097 .7859 .5655 Mtetra
.7859 .5655 .79039 .57097 .80077 .56798 .79631 .56249 Mtetra
.79631 .56249 .80077 .56798 .81118 .56498 .80675 .55947 Mtetra
.80675 .55947 .81118 .56498 .82164 .56197 .81723 .55644 Mtetra
.81723 .55644 .82164 .56197 .83213 .55894 .82775 .55339 Mtetra
.82775 .55339 .83213 .55894 .84266 .55591 .83831 .55034 Mtetra
.83831 .55034 .84266 .55591 .85323 .55287 .84891 .54727 Mtetra
.84891 .54727 .85323 .55287 .86384 .54981 .85954 .5442 Mtetra
.85954 .5442 .86384 .54981 .87449 .54674 .87022 .54111 Mtetra
.87022 .54111 .87449 .54674 .88517 .54367 .88093 .53801 Mtetra
.88093 .53801 .88517 .54367 .8959 .54058 .89168 .53491 Mtetra
.89168 .53491 .8959 .54058 .90666 .53748 .90248 .53179 Mtetra
.90248 .53179 .90666 .53748 .91746 .53437 .91331 .52866 Mtetra
.91331 .52866 .91746 .53437 .9283 .53125 .92418 .52551 Mtetra
.92418 .52551 .9283 .53125 .93919 .52812 .93509 .52236 Mtetra
.93509 .52236 .93919 .52812 .95011 .52498 .94604 .51919 Mtetra
.94604 .51919 .95011 .52498 .96107 .52182 .95703 .51602 Mtetra
.95703 .51602 .96107 .52182 .97207 .51866 .96807 .51283 Mtetra
0 0 0 r
.37449 .68352 .3806 .67297 .38921 .6796 .38382 .67364 Mtetra
.583 .684 .91 r
.38382 .67364 .38921 .6796 .39821 .67784 .39279 .67273 Mtetra
.632 .733 .92 r
.39279 .67273 .39821 .67784 .40725 .67567 .40185 .67066 Mtetra
.64 .74 .921 r
.40185 .67066 .40725 .67567 .41633 .67343 .41095 .66841 Mtetra
.638 .739 .922 r
.41095 .66841 .41633 .67343 .42543 .67132 .42007 .66618 Mtetra
.621 .73 .925 r
.42007 .66618 .42543 .67132 .43454 .6703 .42922 .66432 Mtetra
0 .324 .806 r
.42922 .66432 .43454 .6703 .44391 .66015 .43821 .67031 Mtetra
0 0 0 r
.43821 .67031 .44391 .66015 .45303 .66136 .44774 .65568 Mtetra
.608 .707 .914 r
.44774 .65568 .45303 .66136 .46226 .65927 .45698 .65415 Mtetra
.642 .739 .92 r
.45698 .65415 .46226 .65927 .47153 .65683 .46626 .65181 Mtetra
.65 .747 .92 r
.46626 .65181 .47153 .65683 .48083 .65425 .47559 .64927 Mtetra
.654 .75 .92 r
.47559 .64927 .48083 .65425 .49017 .65159 .48495 .64662 Mtetra
.656 .751 .92 r
.48495 .64662 .49017 .65159 .49954 .64887 .49434 .64391 Mtetra
.658 .753 .92 r
.49434 .64391 .49954 .64887 .50895 .64612 .50376 .64115 Mtetra
.659 .753 .92 r
.50376 .64115 .50895 .64612 .51838 .64334 .51322 .63836 Mtetra
.659 .754 .92 r
.51322 .63836 .51838 .64334 .52785 .64055 .52271 .63555 Mtetra
.52271 .63555 .52785 .64055 .53735 .63775 .53223 .63273 Mtetra
.53223 .63273 .53735 .63775 .54688 .63495 .54178 .62991 Mtetra
.658 .753 .92 r
.54178 .62991 .54688 .63495 .55644 .63214 .55137 .62709 Mtetra
.55137 .62709 .55644 .63214 .56604 .62933 .56099 .62426 Mtetra
.56099 .62426 .56604 .62933 .57567 .62652 .57064 .62142 Mtetra
.57064 .62142 .57567 .62652 .58534 .6237 .58033 .61858 Mtetra
.58033 .61858 .58534 .6237 .59503 .62087 .59005 .61574 Mtetra
.59005 .61574 .59503 .62087 .60476 .61804 .5998 .61289 Mtetra
.5998 .61289 .60476 .61804 .61453 .6152 .60959 .61003 Mtetra
.657 .753 .92 r
.60959 .61003 .61453 .6152 .62433 .61235 .61941 .60716 Mtetra
.61941 .60716 .62433 .61235 .63416 .60949 .62927 .60428 Mtetra
.62927 .60428 .63416 .60949 .64403 .60663 .63916 .60139 Mtetra
.657 .752 .92 r
.63916 .60139 .64403 .60663 .65393 .60375 .64909 .5985 Mtetra
.64909 .5985 .65393 .60375 .66387 .60087 .65905 .59559 Mtetra
.65905 .59559 .66387 .60087 .67384 .59797 .66904 .59268 Mtetra
.66904 .59268 .67384 .59797 .68385 .59507 .67907 .58976 Mtetra
.67907 .58976 .68385 .59507 .69389 .59216 .68914 .58683 Mtetra
.68914 .58683 .69389 .59216 .70397 .58923 .69925 .58389 Mtetra
.69925 .58389 .70397 .58923 .71408 .5863 .70938 .58094 Mtetra
.70938 .58094 .71408 .5863 .72423 .58336 .71956 .57797 Mtetra
.71956 .57797 .72423 .58336 .73442 .58041 .72977 .575 Mtetra
.72977 .575 .73442 .58041 .74464 .57745 .74002 .57202 Mtetra
.74002 .57202 .74464 .57745 .7549 .57448 .7503 .56903 Mtetra
.7503 .56903 .7549 .57448 .7652 .5715 .76062 .56603 Mtetra
.76062 .56603 .7652 .5715 .77553 .56851 .77098 .56302 Mtetra
.77098 .56302 .77553 .56851 .7859 .5655 .78138 .56 Mtetra
.78138 .56 .7859 .5655 .79631 .56249 .79181 .55697 Mtetra
.79181 .55697 .79631 .56249 .80675 .55947 .80229 .55392 Mtetra
.80229 .55392 .80675 .55947 .81723 .55644 .81279 .55087 Mtetra
.81279 .55087 .81723 .55644 .82775 .55339 .82334 .54781 Mtetra
.82334 .54781 .82775 .55339 .83831 .55034 .83393 .54473 Mtetra
.83393 .54473 .83831 .55034 .84891 .54727 .84455 .54164 Mtetra
.84455 .54164 .84891 .54727 .85954 .5442 .85522 .53855 Mtetra
.85522 .53855 .85954 .5442 .87022 .54111 .86592 .53544 Mtetra
.86592 .53544 .87022 .54111 .88093 .53801 .87666 .53232 Mtetra
.87666 .53232 .88093 .53801 .89168 .53491 .88744 .52919 Mtetra
.88744 .52919 .89168 .53491 .90248 .53179 .89826 .52605 Mtetra
.89826 .52605 .90248 .53179 .91331 .52866 .90912 .5229 Mtetra
.90912 .5229 .91331 .52866 .92418 .52551 .92003 .51974 Mtetra
.92003 .51974 .92418 .52551 .93509 .52236 .93097 .51656 Mtetra
.93097 .51656 .93509 .52236 .94604 .51919 .94195 .51337 Mtetra
.94195 .51337 .94604 .51919 .95703 .51602 .95297 .51018 Mtetra
.95297 .51018 .95703 .51602 .96807 .51283 .96404 .50697 Mtetra
.828 .702 .726 r
.36912 .67571 .37449 .68352 .38382 .67364 .37868 .66075 Mtetra
.316 .377 .767 r
.37868 .66075 .38382 .67364 .39279 .67273 .38736 .66738 Mtetra
.62 .721 .919 r
.38736 .66738 .39279 .67273 .40185 .67066 .39642 .66558 Mtetra
.638 .737 .921 r
.39642 .66558 .40185 .67066 .41095 .66841 .40553 .66337 Mtetra
.64 .74 .921 r
.40553 .66337 .41095 .66841 .42007 .66618 .41468 .66109 Mtetra
.634 .737 .923 r
.41468 .66109 .42007 .66618 .42922 .66432 .42386 .65895 Mtetra
.58 .709 .931 r
.42386 .65895 .42922 .66432 .43821 .67031 .43304 .65789 Mtetra
.747 .625 .724 r
.43304 .65789 .43821 .67031 .44774 .65568 .44248 .64766 Mtetra
.499 .586 .873 r
.44248 .64766 .44774 .65568 .45698 .65415 .45166 .64885 Mtetra
.632 .731 .919 r
.45166 .64885 .45698 .65415 .46626 .65181 .46097 .64672 Mtetra
.647 .744 .92 r
.46097 .64672 .46626 .65181 .47559 .64927 .47031 .64423 Mtetra
.652 .748 .92 r
.47031 .64423 .47559 .64927 .48495 .64662 .47969 .64161 Mtetra
.655 .751 .92 r
.47969 .64161 .48495 .64662 .49434 .64391 .4891 .63891 Mtetra
.657 .752 .92 r
.4891 .63891 .49434 .64391 .50376 .64115 .49855 .63615 Mtetra
.658 .753 .92 r
.49855 .63615 .50376 .64115 .51322 .63836 .50802 .63335 Mtetra
.659 .754 .92 r
.50802 .63335 .51322 .63836 .52271 .63555 .51753 .63053 Mtetra
.51753 .63053 .52271 .63555 .53223 .63273 .52708 .62769 Mtetra
.52708 .62769 .53223 .63273 .54178 .62991 .53665 .62485 Mtetra
.53665 .62485 .54178 .62991 .55137 .62709 .54626 .622 Mtetra
.658 .753 .92 r
.54626 .622 .55137 .62709 .56099 .62426 .5559 .61915 Mtetra
.5559 .61915 .56099 .62426 .57064 .62142 .56558 .6163 Mtetra
.56558 .6163 .57064 .62142 .58033 .61858 .57529 .61344 Mtetra
.57529 .61344 .58033 .61858 .59005 .61574 .58503 .61057 Mtetra
.58503 .61057 .59005 .61574 .5998 .61289 .59481 .6077 Mtetra
.59481 .6077 .5998 .61289 .60959 .61003 .60462 .60482 Mtetra
.657 .753 .92 r
.60462 .60482 .60959 .61003 .61941 .60716 .61446 .60193 Mtetra
.61446 .60193 .61941 .60716 .62927 .60428 .62434 .59903 Mtetra
.62434 .59903 .62927 .60428 .63916 .60139 .63426 .59613 Mtetra
.63426 .59613 .63916 .60139 .64909 .5985 .64421 .59321 Mtetra
.657 .752 .92 r
.64421 .59321 .64909 .5985 .65905 .59559 .65419 .59029 Mtetra
.65419 .59029 .65905 .59559 .66904 .59268 .66421 .58736 Mtetra
.66421 .58736 .66904 .59268 .67907 .58976 .67427 .58442 Mtetra
.67427 .58442 .67907 .58976 .68914 .58683 .68436 .58146 Mtetra
.68436 .58146 .68914 .58683 .69925 .58389 .69449 .5785 Mtetra
.69449 .5785 .69925 .58389 .70938 .58094 .70465 .57553 Mtetra
.70465 .57553 .70938 .58094 .71956 .57797 .71485 .57255 Mtetra
.71485 .57255 .71956 .57797 .72977 .575 .72509 .56956 Mtetra
.72509 .56956 .72977 .575 .74002 .57202 .73537 .56656 Mtetra
.73537 .56656 .74002 .57202 .7503 .56903 .74568 .56355 Mtetra
.74568 .56355 .7503 .56903 .76062 .56603 .75602 .56053 Mtetra
.75602 .56053 .76062 .56603 .77098 .56302 .76641 .5575 Mtetra
.76641 .5575 .77098 .56302 .78138 .56 .77683 .55445 Mtetra
.77683 .55445 .78138 .56 .79181 .55697 .78729 .5514 Mtetra
.78729 .5514 .79181 .55697 .80229 .55392 .79779 .54834 Mtetra
.79779 .54834 .80229 .55392 .81279 .55087 .80833 .54526 Mtetra
.80833 .54526 .81279 .55087 .82334 .54781 .8189 .54218 Mtetra
.8189 .54218 .82334 .54781 .83393 .54473 .82952 .53908 Mtetra
.82952 .53908 .83393 .54473 .84455 .54164 .84017 .53598 Mtetra
.84017 .53598 .84455 .54164 .85522 .53855 .85086 .53286 Mtetra
.85086 .53286 .85522 .53855 .86592 .53544 .86159 .52973 Mtetra
.86159 .52973 .86592 .53544 .87666 .53232 .87236 .52659 Mtetra
.87236 .52659 .87666 .53232 .88744 .52919 .88317 .52344 Mtetra
.88317 .52344 .88744 .52919 .89826 .52605 .89402 .52028 Mtetra
.89402 .52028 .89826 .52605 .90912 .5229 .90491 .5171 Mtetra
.90491 .5171 .90912 .5229 .92003 .51974 .91584 .51392 Mtetra
.91584 .51392 .92003 .51974 .93097 .51656 .92682 .51072 Mtetra
.92682 .51072 .93097 .51656 .94195 .51337 .93783 .50751 Mtetra
.93783 .50751 .94195 .51337 .95297 .51018 .94888 .50429 Mtetra
.94888 .50429 .95297 .51018 .96404 .50697 .95997 .50106 Mtetra
.426 .632 .941 r
.36363 .67003 .36912 .67571 .37868 .66075 .37252 .67129 Mtetra
0 0 0 r
.37252 .67129 .37868 .66075 .38736 .66738 .38192 .66134 Mtetra
.583 .684 .91 r
.38192 .66134 .38736 .66738 .39642 .66558 .39096 .66039 Mtetra
.632 .733 .92 r
.39096 .66039 .39642 .66558 .40553 .66337 .40009 .65828 Mtetra
.64 .74 .921 r
.40009 .65828 .40553 .66337 .41468 .66109 .40925 .656 Mtetra
.638 .739 .922 r
.40925 .656 .41468 .66109 .42386 .65895 .41845 .65373 Mtetra
.621 .73 .925 r
.41845 .65373 .42386 .65895 .43304 .65789 .42767 .65183 Mtetra
0 .327 .808 r
.42767 .65183 .43304 .65789 .44248 .64766 .43673 .65781 Mtetra
0 0 0 r
.43673 .65781 .44248 .64766 .45166 .64885 .44633 .64309 Mtetra
.608 .707 .914 r
.44633 .64309 .45166 .64885 .46097 .64672 .45564 .64152 Mtetra
.642 .739 .92 r
.45564 .64152 .46097 .64672 .47031 .64423 .465 .63914 Mtetra
.65 .747 .92 r
.465 .63914 .47031 .64423 .47969 .64161 .4744 .63655 Mtetra
.654 .75 .92 r
.4744 .63655 .47969 .64161 .4891 .63891 .48383 .63386 Mtetra
.656 .751 .92 r
.48383 .63386 .4891 .63891 .49855 .63615 .4933 .6311 Mtetra
.658 .753 .92 r
.4933 .6311 .49855 .63615 .50802 .63335 .50279 .6283 Mtetra
.659 .753 .92 r
.50279 .6283 .50802 .63335 .51753 .63053 .51233 .62547 Mtetra
.659 .754 .92 r
.51233 .62547 .51753 .63053 .52708 .62769 .52189 .62261 Mtetra
.52189 .62261 .52708 .62769 .53665 .62485 .53149 .61975 Mtetra
.53149 .61975 .53665 .62485 .54626 .622 .54112 .61688 Mtetra
.658 .753 .92 r
.54112 .61688 .54626 .622 .5559 .61915 .55078 .61401 Mtetra
.55078 .61401 .5559 .61915 .56558 .6163 .56048 .61113 Mtetra
.56048 .61113 .56558 .6163 .57529 .61344 .57021 .60825 Mtetra
.57021 .60825 .57529 .61344 .58503 .61057 .57998 .60537 Mtetra
.57998 .60537 .58503 .61057 .59481 .6077 .58978 .60248 Mtetra
.58978 .60248 .59481 .6077 .60462 .60482 .59961 .59958 Mtetra
.59961 .59958 .60462 .60482 .61446 .60193 .60948 .59667 Mtetra
.657 .753 .92 r
.60948 .59667 .61446 .60193 .62434 .59903 .61939 .59375 Mtetra
.61939 .59375 .62434 .59903 .63426 .59613 .62932 .59083 Mtetra
.62932 .59083 .63426 .59613 .64421 .59321 .6393 .58789 Mtetra
.657 .752 .92 r
.6393 .58789 .64421 .59321 .65419 .59029 .64931 .58495 Mtetra
.64931 .58495 .65419 .59029 .66421 .58736 .65935 .582 Mtetra
.65935 .582 .66421 .58736 .67427 .58442 .66943 .57904 Mtetra
.66943 .57904 .67427 .58442 .68436 .58146 .67955 .57607 Mtetra
.67955 .57607 .68436 .58146 .69449 .5785 .6897 .57309 Mtetra
.6897 .57309 .69449 .5785 .70465 .57553 .69989 .57009 Mtetra
.69989 .57009 .70465 .57553 .71485 .57255 .71012 .56709 Mtetra
.71012 .56709 .71485 .57255 .72509 .56956 .72038 .56408 Mtetra
.72038 .56408 .72509 .56956 .73537 .56656 .73068 .56106 Mtetra
.73068 .56106 .73537 .56656 .74568 .56355 .74102 .55803 Mtetra
.74102 .55803 .74568 .56355 .75602 .56053 .75139 .55499 Mtetra
.75139 .55499 .75602 .56053 .76641 .5575 .7618 .55194 Mtetra
.7618 .55194 .76641 .5575 .77683 .55445 .77225 .54887 Mtetra
.77225 .54887 .77683 .55445 .78729 .5514 .78274 .5458 Mtetra
.78274 .5458 .78729 .5514 .79779 .54834 .79327 .54272 Mtetra
.79327 .54272 .79779 .54834 .80833 .54526 .80383 .53962 Mtetra
.80383 .53962 .80833 .54526 .8189 .54218 .81443 .53652 Mtetra
.81443 .53652 .8189 .54218 .82952 .53908 .82507 .5334 Mtetra
.82507 .5334 .82952 .53908 .84017 .53598 .83576 .53027 Mtetra
.83576 .53027 .84017 .53598 .85086 .53286 .84648 .52713 Mtetra
.84648 .52713 .85086 .53286 .86159 .52973 .85724 .52398 Mtetra
.85724 .52398 .86159 .52973 .87236 .52659 .86803 .52082 Mtetra
.86803 .52082 .87236 .52659 .88317 .52344 .87887 .51765 Mtetra
.87887 .51765 .88317 .52344 .89402 .52028 .88975 .51446 Mtetra
.88975 .51446 .89402 .52028 .90491 .5171 .90067 .51127 Mtetra
.90067 .51127 .90491 .5171 .91584 .51392 .91163 .50806 Mtetra
.91163 .50806 .91584 .51392 .92682 .51072 .92263 .50484 Mtetra
.92263 .50484 .92682 .51072 .93783 .50751 .93368 .50161 Mtetra
.93368 .50161 .93783 .50751 .94888 .50429 .94476 .49837 Mtetra
.94476 .49837 .94888 .50429 .95997 .50106 .95589 .49511 Mtetra
.594 .715 .928 r
.35809 .66471 .36363 .67003 .37252 .67129 .3671 .66339 Mtetra
.828 .703 .726 r
.3671 .66339 .37252 .67129 .38192 .66134 .37674 .64834 Mtetra
.314 .376 .766 r
.37674 .64834 .38192 .66134 .39096 .66039 .38547 .65497 Mtetra
.62 .721 .919 r
.38547 .65497 .39096 .66039 .40009 .65828 .39461 .65313 Mtetra
.638 .737 .921 r
.39461 .65313 .40009 .65828 .40925 .656 .40379 .65088 Mtetra
.64 .74 .921 r
.40379 .65088 .40925 .656 .41845 .65373 .41301 .64855 Mtetra
.634 .737 .923 r
.41301 .64855 .41845 .65373 .42767 .65183 .42225 .64637 Mtetra
.58 .709 .931 r
.42225 .64637 .42767 .65183 .43673 .65781 .4315 .64528 Mtetra
.748 .626 .724 r
.4315 .64528 .43673 .65781 .44633 .64309 .44102 .63497 Mtetra
.499 .586 .873 r
.44102 .63497 .44633 .64309 .45564 .64152 .45028 .63613 Mtetra
.632 .731 .919 r
.45028 .63613 .45564 .64152 .465 .63914 .45966 .63397 Mtetra
.647 .744 .92 r
.45966 .63397 .465 .63914 .4744 .63655 .46907 .63143 Mtetra
.652 .748 .92 r
.46907 .63143 .4744 .63655 .48383 .63386 .47852 .62877 Mtetra
.655 .751 .92 r
.47852 .62877 .48383 .63386 .4933 .6311 .48801 .62602 Mtetra
.657 .752 .92 r
.48801 .62602 .4933 .6311 .50279 .6283 .49753 .62321 Mtetra
.658 .753 .92 r
.49753 .62321 .50279 .6283 .51233 .62547 .50709 .62037 Mtetra
.659 .754 .92 r
.50709 .62037 .51233 .62547 .52189 .62261 .51667 .6175 Mtetra
.51667 .6175 .52189 .62261 .53149 .61975 .52629 .61462 Mtetra
.52629 .61462 .53149 .61975 .54112 .61688 .53594 .61173 Mtetra
.53594 .61173 .54112 .61688 .55078 .61401 .54563 .60884 Mtetra
.658 .753 .92 r
.54563 .60884 .55078 .61401 .56048 .61113 .55535 .60594 Mtetra
.55535 .60594 .56048 .61113 .57021 .60825 .56511 .60304 Mtetra
.56511 .60304 .57021 .60825 .57998 .60537 .5749 .60013 Mtetra
.5749 .60013 .57998 .60537 .58978 .60248 .58472 .59722 Mtetra
.58472 .59722 .58978 .60248 .59961 .59958 .59458 .5943 Mtetra
.59458 .5943 .59961 .59958 .60948 .59667 .60447 .59137 Mtetra
.657 .753 .92 r
.60447 .59137 .60948 .59667 .61939 .59375 .6144 .58844 Mtetra
.6144 .58844 .61939 .59375 .62932 .59083 .62436 .58549 Mtetra
.62436 .58549 .62932 .59083 .6393 .58789 .63436 .58254 Mtetra
.63436 .58254 .6393 .58789 .64931 .58495 .64439 .57958 Mtetra
.657 .752 .92 r
.64439 .57958 .64931 .58495 .65935 .582 .65446 .5766 Mtetra
.65446 .5766 .65935 .582 .66943 .57904 .66456 .57362 Mtetra
.66456 .57362 .66943 .57904 .67955 .57607 .67471 .57063 Mtetra
.67471 .57063 .67955 .57607 .6897 .57309 .68488 .56763 Mtetra
.68488 .56763 .6897 .57309 .69989 .57009 .6951 .56462 Mtetra
.6951 .56462 .69989 .57009 .71012 .56709 .70535 .5616 Mtetra
.70535 .5616 .71012 .56709 .72038 .56408 .71564 .55857 Mtetra
.71564 .55857 .72038 .56408 .73068 .56106 .72596 .55553 Mtetra
.72596 .55553 .73068 .56106 .74102 .55803 .73633 .55247 Mtetra
.73633 .55247 .74102 .55803 .75139 .55499 .74673 .54941 Mtetra
.74673 .54941 .75139 .55499 .7618 .55194 .75717 .54634 Mtetra
.75717 .54634 .7618 .55194 .77225 .54887 .76764 .54326 Mtetra
.76764 .54326 .77225 .54887 .78274 .5458 .77816 .54016 Mtetra
.77816 .54016 .78274 .5458 .79327 .54272 .78871 .53706 Mtetra
.78871 .53706 .79327 .54272 .80383 .53962 .7993 .53394 Mtetra
.7993 .53394 .80383 .53962 .81443 .53652 .80993 .53081 Mtetra
.80993 .53081 .81443 .53652 .82507 .5334 .8206 .52768 Mtetra
.8206 .52768 .82507 .5334 .83576 .53027 .83131 .52453 Mtetra
.83131 .52453 .83576 .53027 .84648 .52713 .84206 .52137 Mtetra
.84206 .52137 .84648 .52713 .85724 .52398 .85285 .51819 Mtetra
.85285 .51819 .85724 .52398 .86803 .52082 .86368 .51501 Mtetra
.86368 .51501 .86803 .52082 .87887 .51765 .87454 .51182 Mtetra
.87454 .51182 .87887 .51765 .88975 .51446 .88545 .50861 Mtetra
.88545 .50861 .88975 .51446 .90067 .51127 .8964 .50539 Mtetra
.8964 .50539 .90067 .51127 .91163 .50806 .90739 .50216 Mtetra
.90739 .50216 .91163 .50806 .92263 .50484 .91843 .49892 Mtetra
.91843 .49892 .92263 .50484 .93368 .50161 .9295 .49567 Mtetra
.9295 .49567 .93368 .50161 .94476 .49837 .94061 .4924 Mtetra
.94061 .4924 .94476 .49837 .95589 .49511 .95177 .48913 Mtetra
.619 .728 .924 r
.3525 .65948 .35809 .66471 .3671 .66339 .36156 .65764 Mtetra
.427 .632 .941 r
.36156 .65764 .3671 .66339 .37674 .64834 .37051 .65887 Mtetra
0 0 0 r
.37051 .65887 .37674 .64834 .38547 .65497 .37998 .64884 Mtetra
.583 .684 .911 r
.37998 .64884 .38547 .65497 .39461 .65313 .3891 .64786 Mtetra
.632 .733 .92 r
.3891 .64786 .39461 .65313 .40379 .65088 .39829 .64571 Mtetra
.64 .74 .921 r
.39829 .64571 .40379 .65088 .41301 .64855 .40753 .64338 Mtetra
.638 .739 .922 r
.40753 .64338 .41301 .64855 .42225 .64637 .4168 .64107 Mtetra
.621 .73 .925 r
.4168 .64107 .42225 .64637 .4315 .64528 .42609 .63913 Mtetra
0 .33 .811 r
.42609 .63913 .4315 .64528 .44102 .63497 .43521 .64511 Mtetra
0 0 0 r
.43521 .64511 .44102 .63497 .45028 .63613 .4449 .63029 Mtetra
.608 .707 .914 r
.4449 .63029 .45028 .63613 .45966 .63397 .45428 .62868 Mtetra
.642 .739 .92 r
.45428 .62868 .45966 .63397 .46907 .63143 .46371 .62626 Mtetra
.65 .747 .92 r
.46371 .62626 .46907 .63143 .47852 .62877 .47319 .62362 Mtetra
.654 .75 .92 r
.47319 .62362 .47852 .62877 .48801 .62602 .48269 .62089 Mtetra
.656 .751 .92 r
.48269 .62089 .48801 .62602 .49753 .62321 .49224 .61809 Mtetra
.658 .753 .92 r
.49224 .61809 .49753 .62321 .50709 .62037 .50181 .61524 Mtetra
.659 .753 .92 r
.50181 .61524 .50709 .62037 .51667 .6175 .51142 .61236 Mtetra
.659 .754 .92 r
.51142 .61236 .51667 .6175 .52629 .61462 .52106 .60946 Mtetra
.52106 .60946 .52629 .61462 .53594 .61173 .53074 .60655 Mtetra
.53074 .60655 .53594 .61173 .54563 .60884 .54045 .60363 Mtetra
.658 .753 .92 r
.54045 .60363 .54563 .60884 .55535 .60594 .55019 .60072 Mtetra
.55019 .60072 .55535 .60594 .56511 .60304 .55997 .59779 Mtetra
.55997 .59779 .56511 .60304 .5749 .60013 .56978 .59487 Mtetra
.56978 .59487 .5749 .60013 .58472 .59722 .57962 .59193 Mtetra
.57962 .59193 .58472 .59722 .59458 .5943 .58951 .58899 Mtetra
.58951 .58899 .59458 .5943 .60447 .59137 .59942 .58604 Mtetra
.59942 .58604 .60447 .59137 .6144 .58844 .60937 .58309 Mtetra
.657 .753 .92 r
.60937 .58309 .6144 .58844 .62436 .58549 .61936 .58012 Mtetra
.61936 .58012 .62436 .58549 .63436 .58254 .62938 .57715 Mtetra
.62938 .57715 .63436 .58254 .64439 .57958 .63944 .57417 Mtetra
.657 .752 .92 r
.63944 .57417 .64439 .57958 .65446 .5766 .64953 .57117 Mtetra
.64953 .57117 .65446 .5766 .66456 .57362 .65966 .56817 Mtetra
.65966 .56817 .66456 .57362 .67471 .57063 .66983 .56516 Mtetra
.66983 .56516 .67471 .57063 .68488 .56763 .68003 .56214 Mtetra
.68003 .56214 .68488 .56763 .6951 .56462 .69027 .55911 Mtetra
.69027 .55911 .6951 .56462 .70535 .5616 .70055 .55607 Mtetra
.70055 .55607 .70535 .5616 .71564 .55857 .71086 .55302 Mtetra
.71086 .55302 .71564 .55857 .72596 .55553 .72122 .54995 Mtetra
.72122 .54995 .72596 .55553 .73633 .55247 .73161 .54688 Mtetra
.73161 .54688 .73633 .55247 .74673 .54941 .74203 .5438 Mtetra
.74203 .5438 .74673 .54941 .75717 .54634 .7525 .5407 Mtetra
.7525 .5407 .75717 .54634 .76764 .54326 .763 .5376 Mtetra
.763 .5376 .76764 .54326 .77816 .54016 .77354 .53448 Mtetra
.77354 .53448 .77816 .54016 .78871 .53706 .78412 .53136 Mtetra
.78412 .53136 .78871 .53706 .7993 .53394 .79474 .52822 Mtetra
.79474 .52822 .7993 .53394 .80993 .53081 .8054 .52507 Mtetra
.8054 .52507 .80993 .53081 .8206 .52768 .8161 .52191 Mtetra
.8161 .52191 .8206 .52768 .83131 .52453 .82684 .51874 Mtetra
.82684 .51874 .83131 .52453 .84206 .52137 .83761 .51556 Mtetra
.83761 .51556 .84206 .52137 .85285 .51819 .84843 .51237 Mtetra
.84843 .51237 .85285 .51819 .86368 .51501 .85929 .50916 Mtetra
.85929 .50916 .86368 .51501 .87454 .51182 .87019 .50594 Mtetra
.87019 .50594 .87454 .51182 .88545 .50861 .88112 .50272 Mtetra
.88112 .50272 .88545 .50861 .8964 .50539 .8921 .49948 Mtetra
.8921 .49948 .8964 .50539 .90739 .50216 .90312 .49622 Mtetra
.90312 .49622 .90739 .50216 .91843 .49892 .91419 .49296 Mtetra
.91419 .49296 .91843 .49892 .9295 .49567 .92529 .48968 Mtetra
.92529 .48968 .9295 .49567 .94061 .4924 .93644 .4864 Mtetra
.93644 .4864 .94061 .4924 .95177 .48913 .94762 .4831 Mtetra
.626 .731 .922 r
.34688 .65423 .3525 .65948 .36156 .65764 .35596 .65223 Mtetra
.594 .715 .928 r
.35596 .65223 .36156 .65764 .37051 .65887 .36504 .65088 Mtetra
.829 .704 .726 r
.36504 .65088 .37051 .65887 .37998 .64884 .37476 .63572 Mtetra
.312 .375 .766 r
.37476 .63572 .37998 .64884 .3891 .64786 .38356 .64235 Mtetra
.62 .721 .919 r
.38356 .64235 .3891 .64786 .39829 .64571 .39276 .64048 Mtetra
.638 .737 .921 r
.39276 .64048 .39829 .64571 .40753 .64338 .40202 .63818 Mtetra
.64 .74 .921 r
.40202 .63818 .40753 .64338 .4168 .64107 .4113 .63582 Mtetra
.634 .737 .923 r
.4113 .63582 .4168 .64107 .42609 .63913 .42062 .63359 Mtetra
.58 .709 .931 r
.42062 .63359 .42609 .63913 .43521 .64511 .42995 .63246 Mtetra
.748 .626 .724 r
.42995 .63246 .43521 .64511 .4449 .63029 .43954 .62208 Mtetra
.498 .586 .873 r
.43954 .62208 .4449 .63029 .45428 .62868 .44887 .62321 Mtetra
.632 .731 .919 r
.44887 .62321 .45428 .62868 .46371 .62626 .45832 .621 Mtetra
.647 .744 .92 r
.45832 .621 .46371 .62626 .47319 .62362 .46781 .61842 Mtetra
.652 .748 .92 r
.46781 .61842 .47319 .62362 .48269 .62089 .47734 .61571 Mtetra
.655 .751 .92 r
.47734 .61571 .48269 .62089 .49224 .61809 .4869 .61292 Mtetra
.657 .752 .92 r
.4869 .61292 .49224 .61809 .50181 .61524 .4965 .61007 Mtetra
.658 .753 .92 r
.4965 .61007 .50181 .61524 .51142 .61236 .50613 .60718 Mtetra
.659 .754 .92 r
.50613 .60718 .51142 .61236 .52106 .60946 .5158 .60426 Mtetra
.5158 .60426 .52106 .60946 .53074 .60655 .52549 .60133 Mtetra
.52549 .60133 .53074 .60655 .54045 .60363 .53523 .5984 Mtetra
.53523 .5984 .54045 .60363 .55019 .60072 .54499 .59546 Mtetra
.658 .753 .92 r
.54499 .59546 .55019 .60072 .55997 .59779 .55479 .59251 Mtetra
.55479 .59251 .55997 .59779 .56978 .59487 .56463 .58956 Mtetra
.56463 .58956 .56978 .59487 .57962 .59193 .5745 .58661 Mtetra
.5745 .58661 .57962 .59193 .58951 .58899 .5844 .58365 Mtetra
.5844 .58365 .58951 .58899 .59942 .58604 .59434 .58068 Mtetra
.59434 .58068 .59942 .58604 .60937 .58309 .60432 .5777 Mtetra
.657 .753 .92 r
.60432 .5777 .60937 .58309 .61936 .58012 .61433 .57472 Mtetra
.61433 .57472 .61936 .58012 .62938 .57715 .62437 .57173 Mtetra
.62437 .57173 .62938 .57715 .63944 .57417 .63446 .56872 Mtetra
.63446 .56872 .63944 .57417 .64953 .57117 .64457 .56571 Mtetra
.657 .752 .92 r
.64457 .56571 .64953 .57117 .65966 .56817 .65473 .56269 Mtetra
.65473 .56269 .65966 .56817 .66983 .56516 .66492 .55965 Mtetra
.66492 .55965 .66983 .56516 .68003 .56214 .67515 .55661 Mtetra
.67515 .55661 .68003 .56214 .69027 .55911 .68542 .55356 Mtetra
.68542 .55356 .69027 .55911 .70055 .55607 .69572 .5505 Mtetra
.69572 .5505 .70055 .55607 .71086 .55302 .70606 .54743 Mtetra
.70606 .54743 .71086 .55302 .72122 .54995 .71644 .54434 Mtetra
.71644 .54434 .72122 .54995 .73161 .54688 .72685 .54125 Mtetra
.72685 .54125 .73161 .54688 .74203 .5438 .73731 .53815 Mtetra
.73731 .53815 .74203 .5438 .7525 .5407 .7478 .53503 Mtetra
.7478 .53503 .7525 .5407 .763 .5376 .75833 .53191 Mtetra
.75833 .53191 .763 .5376 .77354 .53448 .7689 .52877 Mtetra
.7689 .52877 .77354 .53448 .78412 .53136 .77951 .52562 Mtetra
.77951 .52562 .78412 .53136 .79474 .52822 .79015 .52246 Mtetra
.79015 .52246 .79474 .52822 .8054 .52507 .80084 .51929 Mtetra
.80084 .51929 .8054 .52507 .8161 .52191 .81157 .51611 Mtetra
.81157 .51611 .8161 .52191 .82684 .51874 .82233 .51292 Mtetra
.82233 .51292 .82684 .51874 .83761 .51556 .83314 .50971 Mtetra
.83314 .50971 .83761 .51556 .84843 .51237 .84398 .5065 Mtetra
.84398 .5065 .84843 .51237 .85929 .50916 .85487 .50327 Mtetra
.85487 .50327 .85929 .50916 .87019 .50594 .8658 .50003 Mtetra
.8658 .50003 .87019 .50594 .88112 .50272 .87677 .49678 Mtetra
.87677 .49678 .88112 .50272 .8921 .49948 .88778 .49352 Mtetra
.88778 .49352 .8921 .49948 .90312 .49622 .89883 .49024 Mtetra
.89883 .49024 .90312 .49622 .91419 .49296 .90992 .48696 Mtetra
.90992 .48696 .91419 .49296 .92529 .48968 .92105 .48366 Mtetra
.92105 .48366 .92529 .48968 .93644 .4864 .93223 .48035 Mtetra
.93223 .48035 .93644 .4864 .94762 .4831 .94345 .47702 Mtetra
.625 .729 .921 r
.34123 .64891 .34688 .65423 .35596 .65223 .35033 .64692 Mtetra
.619 .728 .924 r
.35033 .64692 .35596 .65223 .36504 .65088 .35945 .64504 Mtetra
.427 .633 .94 r
.35945 .64504 .36504 .65088 .37476 .63572 .36847 .64624 Mtetra
0 0 0 r
.36847 .64624 .37476 .63572 .38356 .64235 .37802 .63614 Mtetra
.583 .684 .911 r
.37802 .63614 .38356 .64235 .39276 .64048 .3872 .63512 Mtetra
.632 .733 .92 r
.3872 .63512 .39276 .64048 .40202 .63818 .39647 .63293 Mtetra
.64 .74 .921 r
.39647 .63293 .40202 .63818 .4113 .63582 .40578 .63056 Mtetra
.638 .739 .922 r
.40578 .63056 .4113 .63582 .42062 .63359 .41512 .62821 Mtetra
.621 .73 .924 r
.41512 .62821 .42062 .63359 .42995 .63246 .42448 .62623 Mtetra
0 .334 .813 r
.42448 .62623 .42995 .63246 .43954 .62208 .43367 .6322 Mtetra
0 0 0 r
.43367 .6322 .43954 .62208 .44887 .62321 .44344 .61728 Mtetra
.608 .707 .914 r
.44344 .61728 .44887 .62321 .45832 .621 .4529 .61563 Mtetra
.642 .739 .92 r
.4529 .61563 .45832 .621 .46781 .61842 .46241 .61316 Mtetra
.65 .747 .92 r
.46241 .61316 .46781 .61842 .47734 .61571 .47196 .61048 Mtetra
.654 .75 .92 r
.47196 .61048 .47734 .61571 .4869 .61292 .48154 .6077 Mtetra
.656 .751 .92 r
.48154 .6077 .4869 .61292 .4965 .61007 .49116 .60486 Mtetra
.658 .753 .92 r
.49116 .60486 .4965 .61007 .50613 .60718 .50081 .60196 Mtetra
.659 .753 .92 r
.50081 .60196 .50613 .60718 .5158 .60426 .5105 .59903 Mtetra
.659 .754 .92 r
.5105 .59903 .5158 .60426 .52549 .60133 .52022 .59609 Mtetra
.52022 .59609 .52549 .60133 .53523 .5984 .52997 .59313 Mtetra
.52997 .59313 .53523 .5984 .54499 .59546 .53976 .59017 Mtetra
.658 .753 .92 r
.53976 .59017 .54499 .59546 .55479 .59251 .54958 .5872 Mtetra
.54958 .5872 .55479 .59251 .56463 .58956 .55944 .58423 Mtetra
.55944 .58423 .56463 .58956 .5745 .58661 .56934 .58125 Mtetra
.56934 .58125 .5745 .58661 .5844 .58365 .57926 .57827 Mtetra
.57926 .57827 .5844 .58365 .59434 .58068 .58923 .57528 Mtetra
.58923 .57528 .59434 .58068 .60432 .5777 .59923 .57228 Mtetra
.59923 .57228 .60432 .5777 .61433 .57472 .60926 .56928 Mtetra
.657 .753 .92 r
.60926 .56928 .61433 .57472 .62437 .57173 .61933 .56626 Mtetra
.61933 .56626 .62437 .57173 .63446 .56872 .62944 .56324 Mtetra
.62944 .56324 .63446 .56872 .64457 .56571 .63958 .56021 Mtetra
.657 .752 .92 r
.63958 .56021 .64457 .56571 .65473 .56269 .64976 .55716 Mtetra
.64976 .55716 .65473 .56269 .66492 .55965 .65998 .55411 Mtetra
.65998 .55411 .66492 .55965 .67515 .55661 .67023 .55105 Mtetra
.67023 .55105 .67515 .55661 .68542 .55356 .68053 .54798 Mtetra
.68053 .54798 .68542 .55356 .69572 .5505 .69085 .54489 Mtetra
.69085 .54489 .69572 .5505 .70606 .54743 .70122 .5418 Mtetra
.70122 .5418 .70606 .54743 .71644 .54434 .71162 .5387 Mtetra
.71162 .5387 .71644 .54434 .72685 .54125 .72207 .53558 Mtetra
.72207 .53558 .72685 .54125 .73731 .53815 .73255 .53246 Mtetra
.73255 .53246 .73731 .53815 .7478 .53503 .74307 .52932 Mtetra
.74307 .52932 .7478 .53503 .75833 .53191 .75362 .52617 Mtetra
.75362 .52617 .75833 .53191 .7689 .52877 .76422 .52301 Mtetra
.76422 .52301 .7689 .52877 .77951 .52562 .77486 .51984 Mtetra
.77486 .51984 .77951 .52562 .79015 .52246 .78553 .51666 Mtetra
.78553 .51666 .79015 .52246 .80084 .51929 .79625 .51347 Mtetra
.79625 .51347 .80084 .51929 .81157 .51611 .807 .51027 Mtetra
.807 .51027 .81157 .51611 .82233 .51292 .8178 .50705 Mtetra
.8178 .50705 .82233 .51292 .83314 .50971 .82863 .50383 Mtetra
.82863 .50383 .83314 .50971 .84398 .5065 .83951 .50059 Mtetra
.83951 .50059 .84398 .5065 .85487 .50327 .85042 .49734 Mtetra
.85042 .49734 .85487 .50327 .8658 .50003 .86138 .49408 Mtetra
.86138 .49408 .8658 .50003 .87677 .49678 .87238 .4908 Mtetra
.87238 .4908 .87677 .49678 .88778 .49352 .88342 .48752 Mtetra
.88342 .48752 .88778 .49352 .89883 .49024 .8945 .48422 Mtetra
.8945 .48422 .89883 .49024 .90992 .48696 .90562 .48091 Mtetra
.90562 .48091 .90992 .48696 .92105 .48366 .91679 .47759 Mtetra
.91679 .47759 .92105 .48366 .93223 .48035 .92799 .47426 Mtetra
.92799 .47426 .93223 .48035 .94345 .47702 .93924 .47091 Mtetra
.616 .72 .92 r
.33555 .6434 .34123 .64891 .35033 .64692 .34465 .64159 Mtetra
.626 .731 .922 r
.34465 .64159 .35033 .64692 .35945 .64504 .3538 .63955 Mtetra
.594 .715 .928 r
.3538 .63955 .35945 .64504 .36847 .64624 .36295 .63816 Mtetra
.83 .704 .726 r
.36295 .63816 .36847 .64624 .37802 .63614 .37276 .62291 Mtetra
.31 .374 .766 r
.37276 .62291 .37802 .63614 .3872 .63512 .38162 .62953 Mtetra
.62 .721 .919 r
.38162 .62953 .3872 .63512 .39647 .63293 .39089 .62762 Mtetra
.638 .737 .921 r
.39089 .62762 .39647 .63293 .40578 .63056 .40021 .62528 Mtetra
.64 .74 .921 r
.40021 .62528 .40578 .63056 .41512 .62821 .40958 .62287 Mtetra
.634 .737 .923 r
.40958 .62287 .41512 .62821 .42448 .62623 .41897 .6206 Mtetra
.58 .709 .931 r
.41897 .6206 .42448 .62623 .43367 .6322 .42836 .61943 Mtetra
.748 .626 .724 r
.42836 .61943 .43367 .6322 .44344 .61728 .43804 .60897 Mtetra
.498 .586 .873 r
.43804 .60897 .44344 .61728 .4529 .61563 .44744 .61008 Mtetra
.632 .731 .919 r
.44744 .61008 .4529 .61563 .46241 .61316 .45697 .60782 Mtetra
.647 .744 .92 r
.45697 .60782 .46241 .61316 .47196 .61048 .46653 .6052 Mtetra
.652 .748 .92 r
.46653 .6052 .47196 .61048 .48154 .6077 .47614 .60244 Mtetra
.655 .751 .92 r
.47614 .60244 .48154 .6077 .49116 .60486 .48578 .5996 Mtetra
.657 .752 .92 r
.48578 .5996 .49116 .60486 .50081 .60196 .49545 .5967 Mtetra
.658 .753 .92 r
.49545 .5967 .50081 .60196 .5105 .59903 .50516 .59377 Mtetra
.659 .754 .92 r
.50516 .59377 .5105 .59903 .52022 .59609 .51491 .5908 Mtetra
.51491 .5908 .52022 .59609 .52997 .59313 .52468 .58783 Mtetra
.52468 .58783 .52997 .59313 .53976 .59017 .53449 .58484 Mtetra
.53449 .58484 .53976 .59017 .54958 .5872 .54434 .58185 Mtetra
.658 .753 .92 r
.54434 .58185 .54958 .5872 .55944 .58423 .55422 .57886 Mtetra
.55422 .57886 .55944 .58423 .56934 .58125 .56414 .57586 Mtetra
.56414 .57586 .56934 .58125 .57926 .57827 .57409 .57286 Mtetra
.57409 .57286 .57926 .57827 .58923 .57528 .58408 .56985 Mtetra
.58408 .56985 .58923 .57528 .59923 .57228 .5941 .56683 Mtetra
.5941 .56683 .59923 .57228 .60926 .56928 .60416 .5638 Mtetra
.657 .753 .92 r
.60416 .5638 .60926 .56928 .61933 .56626 .61426 .56077 Mtetra
.61426 .56077 .61933 .56626 .62944 .56324 .62439 .55772 Mtetra
.62439 .55772 .62944 .56324 .63958 .56021 .63456 .55467 Mtetra
.63456 .55467 .63958 .56021 .64976 .55716 .64476 .5516 Mtetra
.657 .752 .92 r
.64476 .5516 .64976 .55716 .65998 .55411 .65501 .54853 Mtetra
.65501 .54853 .65998 .55411 .67023 .55105 .66528 .54545 Mtetra
.66528 .54545 .67023 .55105 .68053 .54798 .6756 .54235 Mtetra
.6756 .54235 .68053 .54798 .69085 .54489 .68596 .53925 Mtetra
.68596 .53925 .69085 .54489 .70122 .5418 .69635 .53613 Mtetra
.69635 .53613 .70122 .5418 .71162 .5387 .70678 .53301 Mtetra
.70678 .53301 .71162 .5387 .72207 .53558 .71725 .52987 Mtetra
.71725 .52987 .72207 .53558 .73255 .53246 .72776 .52673 Mtetra
.72776 .52673 .73255 .53246 .74307 .52932 .7383 .52357 Mtetra
.7383 .52357 .74307 .52932 .75362 .52617 .74889 .5204 Mtetra
.74889 .5204 .75362 .52617 .76422 .52301 .75951 .51722 Mtetra
.75951 .51722 .76422 .52301 .77486 .51984 .77017 .51403 Mtetra
.77017 .51403 .77486 .51984 .78553 .51666 .78088 .51083 Mtetra
.78088 .51083 .78553 .51666 .79625 .51347 .79162 .50761 Mtetra
.79162 .50761 .79625 .51347 .807 .51027 .8024 .50439 Mtetra
.8024 .50439 .807 .51027 .8178 .50705 .81323 .50115 Mtetra
.81323 .50115 .8178 .50705 .82863 .50383 .82409 .4979 Mtetra
.82409 .4979 .82863 .50383 .83951 .50059 .835 .49464 Mtetra
.835 .49464 .83951 .50059 .85042 .49734 .84594 .49137 Mtetra
.84594 .49137 .85042 .49734 .86138 .49408 .85693 .48808 Mtetra
.85693 .48808 .86138 .49408 .87238 .4908 .86796 .48479 Mtetra
.86796 .48479 .87238 .4908 .88342 .48752 .87903 .48148 Mtetra
.87903 .48148 .88342 .48752 .8945 .48422 .89014 .47816 Mtetra
.89014 .47816 .8945 .48422 .90562 .48091 .90129 .47482 Mtetra
.90129 .47482 .90562 .48091 .91679 .47759 .91249 .47148 Mtetra
.91249 .47148 .91679 .47759 .92799 .47426 .92373 .46812 Mtetra
.92373 .46812 .92799 .47426 .93924 .47091 .93501 .46475 Mtetra
.586 .691 .914 r
.32987 .63733 .33555 .6434 .34465 .64159 .33895 .63619 Mtetra
.625 .729 .921 r
.33895 .63619 .34465 .64159 .3538 .63955 .34811 .63416 Mtetra
.619 .728 .924 r
.34811 .63416 .3538 .63955 .36295 .63816 .35731 .63223 Mtetra
.428 .633 .94 r
.35731 .63223 .36295 .63816 .37276 .62291 .36639 .63341 Mtetra
0 0 0 r
.36639 .63341 .37276 .62291 .38162 .62953 .37602 .62324 Mtetra
.583 .684 .911 r
.37602 .62324 .38162 .62953 .39089 .62762 .38528 .62218 Mtetra
.632 .733 .92 r
.38528 .62218 .39089 .62762 .40021 .62528 .39462 .61995 Mtetra
.64 .74 .921 r
.39462 .61995 .40021 .62528 .40958 .62287 .404 .61753 Mtetra
.638 .739 .922 r
.404 .61753 .40958 .62287 .41897 .6206 .41341 .61513 Mtetra
.621 .73 .924 r
.41341 .61513 .41897 .6206 .42836 .61943 .42285 .61311 Mtetra
0 .337 .815 r
.42285 .61311 .42836 .61943 .43804 .60897 .43211 .61907 Mtetra
0 0 0 r
.43211 .61907 .43804 .60897 .44744 .61008 .44196 .60406 Mtetra
.608 .707 .914 r
.44196 .60406 .44744 .61008 .45697 .60782 .45149 .60237 Mtetra
.642 .739 .92 r
.45149 .60237 .45697 .60782 .46653 .6052 .46108 .59985 Mtetra
.65 .747 .92 r
.46108 .59985 .46653 .6052 .47614 .60244 .4707 .59713 Mtetra
.654 .75 .92 r
.4707 .59713 .47614 .60244 .48578 .5996 .48036 .5943 Mtetra
.656 .751 .92 r
.48036 .5943 .48578 .5996 .49545 .5967 .49006 .5914 Mtetra
.658 .753 .92 r
.49006 .5914 .49545 .5967 .50516 .59377 .49979 .58846 Mtetra
.659 .753 .92 r
.49979 .58846 .50516 .59377 .51491 .5908 .50956 .58549 Mtetra
.659 .754 .92 r
.50956 .58549 .51491 .5908 .52468 .58783 .51936 .58249 Mtetra
.51936 .58249 .52468 .58783 .53449 .58484 .52919 .57948 Mtetra
.52919 .57948 .53449 .58484 .54434 .58185 .53906 .57647 Mtetra
.658 .753 .92 r
.53906 .57647 .54434 .58185 .55422 .57886 .54897 .57346 Mtetra
.54897 .57346 .55422 .57886 .56414 .57586 .55891 .57044 Mtetra
.55891 .57044 .56414 .57586 .57409 .57286 .56888 .56741 Mtetra
.56888 .56741 .57409 .57286 .58408 .56985 .5789 .56438 Mtetra
.5789 .56438 .58408 .56985 .5941 .56683 .58894 .56134 Mtetra
.58894 .56134 .5941 .56683 .60416 .5638 .59903 .55829 Mtetra
.59903 .55829 .60416 .5638 .61426 .56077 .60915 .55523 Mtetra
.657 .753 .92 r
.60915 .55523 .61426 .56077 .62439 .55772 .6193 .55217 Mtetra
.6193 .55217 .62439 .55772 .63456 .55467 .6295 .54909 Mtetra
.6295 .54909 .63456 .55467 .64476 .5516 .63973 .54601 Mtetra
.657 .752 .92 r
.63973 .54601 .64476 .5516 .65501 .54853 .65 .54291 Mtetra
.65 .54291 .65501 .54853 .66528 .54545 .6603 .53981 Mtetra
.6603 .53981 .66528 .54545 .6756 .54235 .67064 .53669 Mtetra
.67064 .53669 .6756 .54235 .68596 .53925 .68103 .53357 Mtetra
.68103 .53357 .68596 .53925 .69635 .53613 .69144 .53043 Mtetra
.69144 .53043 .69635 .53613 .70678 .53301 .7019 .52728 Mtetra
.7019 .52728 .70678 .53301 .71725 .52987 .7124 .52413 Mtetra
.7124 .52413 .71725 .52987 .72776 .52673 .72293 .52096 Mtetra
.72293 .52096 .72776 .52673 .7383 .52357 .73351 .51778 Mtetra
.73351 .51778 .7383 .52357 .74889 .5204 .74412 .51459 Mtetra
.74412 .51459 .74889 .5204 .75951 .51722 .75477 .51139 Mtetra
.75477 .51139 .75951 .51722 .77017 .51403 .76546 .50817 Mtetra
.76546 .50817 .77017 .51403 .78088 .51083 .77619 .50495 Mtetra
.77619 .50495 .78088 .51083 .79162 .50761 .78696 .50171 Mtetra
.78696 .50171 .79162 .50761 .8024 .50439 .79778 .49846 Mtetra
.79778 .49846 .8024 .50439 .81323 .50115 .80863 .4952 Mtetra
.80863 .4952 .81323 .50115 .82409 .4979 .81952 .49193 Mtetra
.81952 .49193 .82409 .4979 .835 .49464 .83046 .48865 Mtetra
.83046 .48865 .835 .49464 .84594 .49137 .84143 .48535 Mtetra
.84143 .48535 .84594 .49137 .85693 .48808 .85245 .48205 Mtetra
.85245 .48205 .85693 .48808 .86796 .48479 .86351 .47873 Mtetra
.86351 .47873 .86796 .48479 .87903 .48148 .87461 .47539 Mtetra
.87461 .47539 .87903 .48148 .89014 .47816 .88575 .47205 Mtetra
.88575 .47205 .89014 .47816 .90129 .47482 .89693 .46869 Mtetra
.89693 .46869 .90129 .47482 .91249 .47148 .90816 .46533 Mtetra
.90816 .46533 .91249 .47148 .92373 .46812 .91943 .46194 Mtetra
.91943 .46194 .92373 .46812 .93501 .46475 .93074 .45855 Mtetra
.401 .49 .835 r
.32439 .62727 .32987 .63733 .33895 .63619 .33322 .6306 Mtetra
.616 .72 .92 r
.33322 .6306 .33895 .63619 .34811 .63416 .34239 .62875 Mtetra
.626 .731 .922 r
.34239 .62875 .34811 .63416 .35731 .63223 .35161 .62667 Mtetra
.594 .715 .928 r
.35161 .62667 .35731 .63223 .36639 .63341 .36083 .62523 Mtetra
.83 .705 .726 r
.36083 .62523 .36639 .63341 .37602 .62324 .37072 .60988 Mtetra
.309 .372 .766 r
.37072 .60988 .37602 .62324 .38528 .62218 .37964 .6165 Mtetra
.62 .721 .919 r
.37964 .6165 .38528 .62218 .39462 .61995 .38898 .61454 Mtetra
.638 .737 .921 r
.38898 .61454 .39462 .61995 .404 .61753 .39838 .61216 Mtetra
.64 .74 .921 r
.39838 .61216 .404 .61753 .41341 .61513 .40782 .60971 Mtetra
.634 .737 .923 r
.40782 .60971 .41341 .61513 .42285 .61311 .41728 .6074 Mtetra
.581 .709 .931 r
.41728 .6074 .42285 .61311 .43211 .61907 .42675 .60619 Mtetra
.749 .627 .724 r
.42675 .60619 .43211 .61907 .44196 .60406 .43651 .59565 Mtetra
.497 .585 .873 r
.43651 .59565 .44196 .60406 .45149 .60237 .44599 .59672 Mtetra
.632 .731 .919 r
.44599 .59672 .45149 .60237 .46108 .59985 .45559 .59442 Mtetra
.647 .744 .92 r
.45559 .59442 .46108 .59985 .4707 .59713 .46523 .59176 Mtetra
.652 .748 .92 r
.46523 .59176 .4707 .59713 .48036 .5943 .47492 .58895 Mtetra
.655 .751 .92 r
.47492 .58895 .48036 .5943 .49006 .5914 .48463 .58606 Mtetra
.657 .752 .92 r
.48463 .58606 .49006 .5914 .49979 .58846 .49439 .58312 Mtetra
.658 .753 .92 r
.49439 .58312 .49979 .58846 .50956 .58549 .50418 .58013 Mtetra
.659 .754 .92 r
.50418 .58013 .50956 .58549 .51936 .58249 .514 .57712 Mtetra
.514 .57712 .51936 .58249 .52919 .57948 .52386 .57409 Mtetra
.52386 .57409 .52919 .57948 .53906 .57647 .53375 .57106 Mtetra
.53375 .57106 .53906 .57647 .54897 .57346 .54368 .56802 Mtetra
.658 .753 .92 r
.54368 .56802 .54897 .57346 .55891 .57044 .55364 .56497 Mtetra
.55364 .56497 .55891 .57044 .56888 .56741 .56364 .56193 Mtetra
.56364 .56193 .56888 .56741 .5789 .56438 .57368 .55887 Mtetra
.57368 .55887 .5789 .56438 .58894 .56134 .58375 .55581 Mtetra
.58375 .55581 .58894 .56134 .59903 .55829 .59386 .55274 Mtetra
.59386 .55274 .59903 .55829 .60915 .55523 .604 .54966 Mtetra
.657 .753 .92 r
.604 .54966 .60915 .55523 .6193 .55217 .61419 .54658 Mtetra
.61419 .54658 .6193 .55217 .6295 .54909 .6244 .54348 Mtetra
.6244 .54348 .6295 .54909 .63973 .54601 .63466 .54037 Mtetra
.63466 .54037 .63973 .54601 .65 .54291 .64495 .53726 Mtetra
.657 .752 .92 r
.64495 .53726 .65 .54291 .6603 .53981 .65528 .53413 Mtetra
.65528 .53413 .6603 .53981 .67064 .53669 .66565 .53099 Mtetra
.66565 .53099 .67064 .53669 .68103 .53357 .67606 .52785 Mtetra
.67606 .52785 .68103 .53357 .69144 .53043 .68651 .52469 Mtetra
.68651 .52469 .69144 .53043 .7019 .52728 .69699 .52152 Mtetra
.69699 .52152 .7019 .52728 .7124 .52413 .70751 .51834 Mtetra
.70751 .51834 .7124 .52413 .72293 .52096 .71807 .51515 Mtetra
.71807 .51515 .72293 .52096 .73351 .51778 .72868 .51195 Mtetra
.72868 .51195 .73351 .51778 .74412 .51459 .73932 .50874 Mtetra
.73932 .50874 .74412 .51459 .75477 .51139 .75 .50551 Mtetra
.75 .50551 .75477 .51139 .76546 .50817 .76071 .50228 Mtetra
.76071 .50228 .76546 .50817 .77619 .50495 .77147 .49903 Mtetra
.77147 .49903 .77619 .50495 .78696 .50171 .78227 .49577 Mtetra
.78227 .49577 .78696 .50171 .79778 .49846 .79312 .4925 Mtetra
.79312 .4925 .79778 .49846 .80863 .4952 .804 .48922 Mtetra
.804 .48922 .80863 .4952 .81952 .49193 .81492 .48592 Mtetra
.81492 .48592 .81952 .49193 .83046 .48865 .82588 .48262 Mtetra
.82588 .48262 .83046 .48865 .84143 .48535 .83689 .4793 Mtetra
.83689 .4793 .84143 .48535 .85245 .48205 .84793 .47597 Mtetra
.84793 .47597 .85245 .48205 .86351 .47873 .85902 .47262 Mtetra
.85902 .47262 .86351 .47873 .87461 .47539 .87015 .46927 Mtetra
.87015 .46927 .87461 .47539 .88575 .47205 .88133 .4659 Mtetra
.88133 .4659 .88575 .47205 .89693 .46869 .89254 .46252 Mtetra
.89254 .46252 .89693 .46869 .90816 .46533 .9038 .45913 Mtetra
.9038 .45913 .90816 .46533 .91943 .46194 .9151 .45572 Mtetra
.9151 .45572 .91943 .46194 .93074 .45855 .92645 .4523 Mtetra
0 0 0 r
.31777 .63572 .32439 .62727 .33322 .6306 .32748 .62443 Mtetra
.586 .691 .914 r
.32748 .62443 .33322 .6306 .34239 .62875 .33663 .62326 Mtetra
.625 .729 .921 r
.33663 .62326 .34239 .62875 .35161 .62667 .34587 .62118 Mtetra
.619 .728 .924 r
.34587 .62118 .35161 .62667 .36083 .62523 .35513 .61922 Mtetra
.429 .633 .94 r
.35513 .61922 .36083 .62523 .37072 .60988 .36428 .62037 Mtetra
0 0 0 r
.36428 .62037 .37072 .60988 .37964 .6165 .374 .61012 Mtetra
.582 .684 .911 r
.374 .61012 .37964 .6165 .38898 .61454 .38332 .60902 Mtetra
.632 .733 .92 r
.38332 .60902 .38898 .61454 .39838 .61216 .39273 .60674 Mtetra
.64 .74 .921 r
.39273 .60674 .39838 .61216 .40782 .60971 .40219 .60428 Mtetra
.638 .739 .922 r
.40219 .60428 .40782 .60971 .41728 .6074 .41168 .60184 Mtetra
.622 .73 .924 r
.41168 .60184 .41728 .6074 .42675 .60619 .42119 .59977 Mtetra
0 .34 .818 r
.42119 .59977 .42675 .60619 .43651 .59565 .43052 .60573 Mtetra
0 0 0 r
.43052 .60573 .43651 .59565 .44599 .59672 .44046 .59061 Mtetra
.608 .707 .914 r
.44046 .59061 .44599 .59672 .45559 .59442 .45006 .58888 Mtetra
.642 .739 .92 r
.45006 .58888 .45559 .59442 .46523 .59176 .45973 .58632 Mtetra
.65 .747 .92 r
.45973 .58632 .46523 .59176 .47492 .58895 .46943 .58355 Mtetra
.654 .75 .92 r
.46943 .58355 .47492 .58895 .48463 .58606 .47917 .58067 Mtetra
.656 .751 .92 r
.47917 .58067 .48463 .58606 .49439 .58312 .48895 .57773 Mtetra
.658 .753 .92 r
.48895 .57773 .49439 .58312 .50418 .58013 .49876 .57473 Mtetra
.659 .753 .92 r
.49876 .57473 .50418 .58013 .514 .57712 .5086 .57171 Mtetra
.659 .754 .92 r
.5086 .57171 .514 .57712 .52386 .57409 .51849 .56866 Mtetra
.51849 .56866 .52386 .57409 .53375 .57106 .5284 .56561 Mtetra
.5284 .56561 .53375 .57106 .54368 .56802 .53836 .56254 Mtetra
.658 .753 .92 r
.53836 .56254 .54368 .56802 .55364 .56497 .54834 .55948 Mtetra
.54834 .55948 .55364 .56497 .56364 .56193 .55837 .55641 Mtetra
.55837 .55641 .56364 .56193 .57368 .55887 .56843 .55333 Mtetra
.56843 .55333 .57368 .55887 .58375 .55581 .57852 .55025 Mtetra
.57852 .55025 .58375 .55581 .59386 .55274 .58866 .54716 Mtetra
.58866 .54716 .59386 .55274 .604 .54966 .59883 .54406 Mtetra
.59883 .54406 .604 .54966 .61419 .54658 .60903 .54095 Mtetra
.657 .753 .92 r
.60903 .54095 .61419 .54658 .6244 .54348 .61928 .53783 Mtetra
.61928 .53783 .6244 .54348 .63466 .54037 .62956 .5347 Mtetra
.62956 .5347 .63466 .54037 .64495 .53726 .63988 .53156 Mtetra
.657 .752 .92 r
.63988 .53156 .64495 .53726 .65528 .53413 .65023 .52842 Mtetra
.65023 .52842 .65528 .53413 .66565 .53099 .66063 .52526 Mtetra
.66063 .52526 .66565 .53099 .67606 .52785 .67106 .52209 Mtetra
.67106 .52209 .67606 .52785 .68651 .52469 .68153 .51891 Mtetra
.68153 .51891 .68651 .52469 .69699 .52152 .69205 .51572 Mtetra
.69205 .51572 .69699 .52152 .70751 .51834 .70259 .51252 Mtetra
.70259 .51252 .70751 .51834 .71807 .51515 .71318 .5093 Mtetra
.71318 .5093 .71807 .51515 .72868 .51195 .72381 .50608 Mtetra
.72381 .50608 .72868 .51195 .73932 .50874 .73448 .50284 Mtetra
.73448 .50284 .73932 .50874 .75 .50551 .74519 .4996 Mtetra
.74519 .4996 .75 .50551 .76071 .50228 .75594 .49634 Mtetra
.75594 .49634 .76071 .50228 .77147 .49903 .76672 .49307 Mtetra
.76672 .49307 .77147 .49903 .78227 .49577 .77755 .48979 Mtetra
.77755 .48979 .78227 .49577 .79312 .4925 .78842 .48649 Mtetra
.78842 .48649 .79312 .4925 .804 .48922 .79933 .48319 Mtetra
.79933 .48319 .804 .48922 .81492 .48592 .81028 .47987 Mtetra
.81028 .47987 .81492 .48592 .82588 .48262 .82128 .47654 Mtetra
.82128 .47654 .82588 .48262 .83689 .4793 .83231 .4732 Mtetra
.83231 .4732 .83689 .4793 .84793 .47597 .84339 .46984 Mtetra
.84339 .46984 .84793 .47597 .85902 .47262 .85451 .46648 Mtetra
.85451 .46648 .85902 .47262 .87015 .46927 .86567 .4631 Mtetra
.86567 .4631 .87015 .46927 .88133 .4659 .87687 .45971 Mtetra
.87687 .45971 .88133 .4659 .89254 .46252 .88812 .4563 Mtetra
.88812 .4563 .89254 .46252 .9038 .45913 .89941 .45289 Mtetra
.89941 .45289 .9038 .45913 .9151 .45572 .91075 .44946 Mtetra
.91075 .44946 .9151 .45572 .92645 .4523 .92212 .44601 Mtetra
.791 .677 .739 r
.31218 .62624 .31777 .63572 .32748 .62443 .32195 .61428 Mtetra
.4 .489 .835 r
.32195 .61428 .32748 .62443 .33663 .62326 .33085 .61758 Mtetra
.616 .72 .92 r
.33085 .61758 .33663 .62326 .34587 .62118 .34009 .61569 Mtetra
.626 .731 .922 r
.34009 .61569 .34587 .62118 .35513 .61922 .34938 .61357 Mtetra
.594 .715 .928 r
.34938 .61357 .35513 .61922 .36428 .62037 .35867 .61209 Mtetra
.831 .706 .726 r
.35867 .61209 .36428 .62037 .374 .61012 .36864 .59664 Mtetra
.307 .371 .766 r
.36864 .59664 .374 .61012 .38332 .60902 .37763 .60326 Mtetra
.62 .721 .919 r
.37763 .60326 .38332 .60902 .39273 .60674 .38705 .60125 Mtetra
.638 .738 .921 r
.38705 .60125 .39273 .60674 .40219 .60428 .39652 .59883 Mtetra
.64 .74 .921 r
.39652 .59883 .40219 .60428 .41168 .60184 .40603 .59633 Mtetra
.634 .737 .923 r
.40603 .59633 .41168 .60184 .42119 .59977 .41557 .59397 Mtetra
.581 .709 .93 r
.41557 .59397 .42119 .59977 .43052 .60573 .42512 .59273 Mtetra
.749 .627 .725 r
.42512 .59273 .43052 .60573 .44046 .59061 .43496 .5821 Mtetra
.497 .585 .873 r
.43496 .5821 .44046 .59061 .45006 .58888 .44451 .58315 Mtetra
.632 .731 .919 r
.44451 .58315 .45006 .58888 .45973 .58632 .45419 .5808 Mtetra
.647 .744 .92 r
.45419 .5808 .45973 .58632 .46943 .58355 .46391 .57808 Mtetra
.652 .748 .92 r
.46391 .57808 .46943 .58355 .47917 .58067 .47367 .57523 Mtetra
.655 .751 .92 r
.47367 .57523 .47917 .58067 .48895 .57773 .48347 .57229 Mtetra
.657 .752 .92 r
.48347 .57229 .48895 .57773 .49876 .57473 .4933 .5693 Mtetra
.658 .753 .92 r
.4933 .5693 .49876 .57473 .5086 .57171 .50317 .56626 Mtetra
.659 .754 .92 r
.50317 .56626 .5086 .57171 .51849 .56866 .51308 .5632 Mtetra
.51308 .5632 .51849 .56866 .5284 .56561 .52302 .56012 Mtetra
.52302 .56012 .5284 .56561 .53836 .56254 .533 .55704 Mtetra
.533 .55704 .53836 .56254 .54834 .55948 .54301 .55395 Mtetra
.658 .753 .92 r
.54301 .55395 .54834 .55948 .55837 .55641 .55305 .55085 Mtetra
.55305 .55085 .55837 .55641 .56843 .55333 .56314 .54775 Mtetra
.56314 .54775 .56843 .55333 .57852 .55025 .57326 .54465 Mtetra
.57326 .54465 .57852 .55025 .58866 .54716 .58342 .54153 Mtetra
.58342 .54153 .58866 .54716 .59883 .54406 .59361 .53841 Mtetra
.59361 .53841 .59883 .54406 .60903 .54095 .60384 .53528 Mtetra
.657 .753 .92 r
.60384 .53528 .60903 .54095 .61928 .53783 .61411 .53214 Mtetra
.61411 .53214 .61928 .53783 .62956 .5347 .62442 .52899 Mtetra
.62442 .52899 .62956 .5347 .63988 .53156 .63477 .52583 Mtetra
.63477 .52583 .63988 .53156 .65023 .52842 .64515 .52266 Mtetra
.657 .752 .92 r
.64515 .52266 .65023 .52842 .66063 .52526 .65557 .51948 Mtetra
.65557 .51948 .66063 .52526 .67106 .52209 .66603 .51629 Mtetra
.66603 .51629 .67106 .52209 .68153 .51891 .67653 .51309 Mtetra
.67653 .51309 .68153 .51891 .69205 .51572 .68707 .50987 Mtetra
.68707 .50987 .69205 .51572 .70259 .51252 .69764 .50665 Mtetra
.69764 .50665 .70259 .51252 .71318 .5093 .70826 .50342 Mtetra
.70826 .50342 .71318 .5093 .72381 .50608 .71891 .50017 Mtetra
.71891 .50017 .72381 .50608 .73448 .50284 .72961 .49691 Mtetra
.72961 .49691 .73448 .50284 .74519 .4996 .74035 .49364 Mtetra
.74035 .49364 .74519 .4996 .75594 .49634 .75112 .49036 Mtetra
.75112 .49036 .75594 .49634 .76672 .49307 .76194 .48707 Mtetra
.76194 .48707 .76672 .49307 .77755 .48979 .7728 .48376 Mtetra
.7728 .48376 .77755 .48979 .78842 .48649 .7837 .48045 Mtetra
.7837 .48045 .78842 .48649 .79933 .48319 .79464 .47712 Mtetra
.79464 .47712 .79933 .48319 .81028 .47987 .80562 .47378 Mtetra
.80562 .47378 .81028 .47987 .82128 .47654 .81664 .47042 Mtetra
.81664 .47042 .82128 .47654 .83231 .4732 .82771 .46706 Mtetra
.82771 .46706 .83231 .4732 .84339 .46984 .83881 .46368 Mtetra
.83881 .46368 .84339 .46984 .85451 .46648 .84996 .46029 Mtetra
.84996 .46029 .85451 .46648 .86567 .4631 .86116 .45689 Mtetra
.86116 .45689 .86567 .4631 .87687 .45971 .87239 .45347 Mtetra
.87239 .45347 .87687 .45971 .88812 .4563 .88367 .45004 Mtetra
.88367 .45004 .88812 .4563 .89941 .45289 .89499 .4466 Mtetra
.89499 .4466 .89941 .45289 .91075 .44946 .90636 .44315 Mtetra
.90636 .44315 .91075 .44946 .92212 .44601 .91777 .43968 Mtetra
.289 .557 .927 r
.30635 .62006 .31218 .62624 .32195 .61428 .31526 .6227 Mtetra
0 0 0 r
.31526 .6227 .32195 .61428 .33085 .61758 .32506 .61133 Mtetra
.586 .691 .914 r
.32506 .61133 .33085 .61758 .34009 .61569 .33427 .61012 Mtetra
.625 .729 .921 r
.33427 .61012 .34009 .61569 .34938 .61357 .34358 .608 Mtetra
.619 .728 .924 r
.34358 .608 .34938 .61357 .35867 .61209 .35292 .60599 Mtetra
.43 .633 .94 r
.35292 .60599 .35867 .61209 .36864 .59664 .36214 .60712 Mtetra
0 0 0 r
.36214 .60712 .36864 .59664 .37763 .60326 .37193 .59678 Mtetra
.582 .684 .911 r
.37193 .59678 .37763 .60326 .38705 .60125 .38133 .59564 Mtetra
.632 .733 .92 r
.38133 .59564 .38705 .60125 .39652 .59883 .39082 .59332 Mtetra
.64 .74 .921 r
.39082 .59332 .39652 .59883 .40603 .59633 .40035 .59081 Mtetra
.638 .739 .922 r
.40035 .59081 .40603 .59633 .41557 .59397 .40991 .58833 Mtetra
.622 .73 .924 r
.40991 .58833 .41557 .59397 .42512 .59273 .4195 .58622 Mtetra
0 .343 .82 r
.4195 .58622 .42512 .59273 .43496 .5821 .42891 .59216 Mtetra
0 0 0 r
.42891 .59216 .43496 .5821 .44451 .58315 .43893 .57694 Mtetra
.608 .707 .914 r
.43893 .57694 .44451 .58315 .45419 .5808 .44861 .57517 Mtetra
.642 .739 .92 r
.44861 .57517 .45419 .5808 .46391 .57808 .45835 .57256 Mtetra
.65 .747 .92 r
.45835 .57256 .46391 .57808 .47367 .57523 .46814 .56974 Mtetra
.654 .75 .92 r
.46814 .56974 .47367 .57523 .48347 .57229 .47796 .56681 Mtetra
.656 .751 .92 r
.47796 .56681 .48347 .57229 .4933 .5693 .48781 .56382 Mtetra
.658 .753 .92 r
.48781 .56382 .4933 .5693 .50317 .56626 .49771 .56077 Mtetra
.659 .753 .92 r
.49771 .56077 .50317 .56626 .51308 .5632 .50763 .5577 Mtetra
.659 .754 .92 r
.50763 .5577 .51308 .5632 .52302 .56012 .5176 .5546 Mtetra
.5176 .5546 .52302 .56012 .533 .55704 .5276 .55149 Mtetra
.5276 .55149 .533 .55704 .54301 .55395 .53763 .54838 Mtetra
.658 .753 .92 r
.53763 .54838 .54301 .55395 .55305 .55085 .54771 .54526 Mtetra
.54771 .54526 .55305 .55085 .56314 .54775 .55782 .54214 Mtetra
.55782 .54214 .56314 .54775 .57326 .54465 .56796 .53901 Mtetra
.56796 .53901 .57326 .54465 .58342 .54153 .57814 .53587 Mtetra
.57814 .53587 .58342 .54153 .59361 .53841 .58836 .53273 Mtetra
.58836 .53273 .59361 .53841 .60384 .53528 .59862 .52958 Mtetra
.59862 .52958 .60384 .53528 .61411 .53214 .60892 .52641 Mtetra
.657 .753 .92 r
.60892 .52641 .61411 .53214 .62442 .52899 .61925 .52324 Mtetra
.61925 .52324 .62442 .52899 .63477 .52583 .62962 .52006 Mtetra
.62962 .52006 .63477 .52583 .64515 .52266 .64003 .51687 Mtetra
.657 .752 .92 r
.64003 .51687 .64515 .52266 .65557 .51948 .65048 .51366 Mtetra
.65048 .51366 .65557 .51948 .66603 .51629 .66096 .51045 Mtetra
.66096 .51045 .66603 .51629 .67653 .51309 .67149 .50723 Mtetra
.67149 .50723 .67653 .51309 .68707 .50987 .68205 .50399 Mtetra
.68205 .50399 .68707 .50987 .69764 .50665 .69266 .50074 Mtetra
.69266 .50074 .69764 .50665 .70826 .50342 .7033 .49749 Mtetra
.7033 .49749 .70826 .50342 .71891 .50017 .71398 .49422 Mtetra
.71398 .49422 .71891 .50017 .72961 .49691 .72471 .49094 Mtetra
.72471 .49094 .72961 .49691 .74035 .49364 .73547 .48764 Mtetra
.73547 .48764 .74035 .49364 .75112 .49036 .74628 .48434 Mtetra
.74628 .48434 .75112 .49036 .76194 .48707 .75712 .48102 Mtetra
.75712 .48102 .76194 .48707 .7728 .48376 .76801 .4777 Mtetra
.76801 .4777 .7728 .48376 .7837 .48045 .77894 .47436 Mtetra
.77894 .47436 .7837 .48045 .79464 .47712 .78991 .471 Mtetra
.78991 .471 .79464 .47712 .80562 .47378 .80092 .46764 Mtetra
.80092 .46764 .80562 .47378 .81664 .47042 .81197 .46426 Mtetra
.81197 .46426 .81664 .47042 .82771 .46706 .82307 .46087 Mtetra
.82307 .46087 .82771 .46706 .83881 .46368 .8342 .45747 Mtetra
.8342 .45747 .83881 .46368 .84996 .46029 .84538 .45406 Mtetra
.84538 .45406 .84996 .46029 .86116 .45689 .85661 .45063 Mtetra
.85661 .45063 .86116 .45689 .87239 .45347 .86787 .44719 Mtetra
.86787 .44719 .87239 .45347 .88367 .45004 .87919 .44374 Mtetra
.87919 .44374 .88367 .45004 .89499 .4466 .89054 .44027 Mtetra
.89054 .44027 .89499 .4466 .90636 .44315 .90194 .43679 Mtetra
.90194 .43679 .90636 .44315 .91777 .43968 .91338 .4333 Mtetra
.579 .707 .93 r
.30045 .61432 .30635 .62006 .31526 .6227 .30962 .61312 Mtetra
.791 .678 .739 r
.30962 .61312 .31526 .6227 .32506 .61133 .31947 .60106 Mtetra
.399 .489 .835 r
.31947 .60106 .32506 .61133 .33427 .61012 .32844 .60435 Mtetra
.616 .72 .92 r
.32844 .60435 .33427 .61012 .34358 .608 .33775 .60242 Mtetra
.626 .731 .922 r
.33775 .60242 .34358 .608 .35292 .60599 .34711 .60025 Mtetra
.594 .715 .928 r
.34711 .60025 .35292 .60599 .36214 .60712 .35647 .59874 Mtetra
.832 .706 .726 r
.35647 .59874 .36214 .60712 .37193 .59678 .36653 .58318 Mtetra
.305 .37 .766 r
.36653 .58318 .37193 .59678 .38133 .59564 .37559 .58979 Mtetra
.62 .721 .919 r
.37559 .58979 .38133 .59564 .39082 .59332 .38508 .58774 Mtetra
.638 .738 .921 r
.38508 .58774 .39082 .59332 .40035 .59081 .39463 .58527 Mtetra
.64 .74 .921 r
.39463 .58527 .40035 .59081 .40991 .58833 .40421 .58273 Mtetra
.634 .737 .922 r
.40421 .58273 .40991 .58833 .4195 .58622 .41383 .58032 Mtetra
.581 .709 .93 r
.41383 .58032 .4195 .58622 .42891 .59216 .42346 .57903 Mtetra
.749 .627 .725 r
.42346 .57903 .42891 .59216 .43893 .57694 .43338 .56833 Mtetra
.497 .585 .874 r
.43338 .56833 .43893 .57694 .44861 .57517 .443 .56934 Mtetra
.632 .731 .919 r
.443 .56934 .44861 .57517 .45835 .57256 .45276 .56695 Mtetra
.647 .744 .92 r
.45276 .56695 .45835 .57256 .46814 .56974 .46257 .56418 Mtetra
.652 .748 .92 r
.46257 .56418 .46814 .56974 .47796 .56681 .47241 .56128 Mtetra
.655 .751 .92 r
.47241 .56128 .47796 .56681 .48781 .56382 .48229 .55829 Mtetra
.657 .752 .92 r
.48229 .55829 .48781 .56382 .49771 .56077 .4922 .55524 Mtetra
.658 .753 .92 r
.4922 .55524 .49771 .56077 .50763 .5577 .50215 .55216 Mtetra
.659 .754 .92 r
.50215 .55216 .50763 .5577 .5176 .5546 .51214 .54904 Mtetra
.51214 .54904 .5176 .5546 .5276 .55149 .52217 .54591 Mtetra
.52217 .54591 .5276 .55149 .53763 .54838 .53223 .54278 Mtetra
.53223 .54278 .53763 .54838 .54771 .54526 .54232 .53963 Mtetra
.658 .753 .92 r
.54232 .53963 .54771 .54526 .55782 .54214 .55246 .53649 Mtetra
.55246 .53649 .55782 .54214 .56796 .53901 .56263 .53333 Mtetra
.56263 .53333 .56796 .53901 .57814 .53587 .57283 .53017 Mtetra
.57283 .53017 .57814 .53587 .58836 .53273 .58308 .52701 Mtetra
.58308 .52701 .58836 .53273 .59862 .52958 .59336 .52383 Mtetra
.59336 .52383 .59862 .52958 .60892 .52641 .60368 .52065 Mtetra
.657 .753 .92 r
.60368 .52065 .60892 .52641 .61925 .52324 .61404 .51745 Mtetra
.61404 .51745 .61925 .52324 .62962 .52006 .62444 .51425 Mtetra
.62444 .51425 .62962 .52006 .64003 .51687 .63487 .51103 Mtetra
.63487 .51103 .64003 .51687 .65048 .51366 .64535 .50781 Mtetra
.657 .752 .92 r
.64535 .50781 .65048 .51366 .66096 .51045 .65586 .50457 Mtetra
.65586 .50457 .66096 .51045 .67149 .50723 .66641 .50133 Mtetra
.66641 .50133 .67149 .50723 .68205 .50399 .677 .49807 Mtetra
.677 .49807 .68205 .50399 .69266 .50074 .68764 .4948 Mtetra
.68764 .4948 .69266 .50074 .7033 .49749 .69831 .49152 Mtetra
.69831 .49152 .7033 .49749 .71398 .49422 .70902 .48823 Mtetra
.70902 .48823 .71398 .49422 .72471 .49094 .71977 .48492 Mtetra
.71977 .48492 .72471 .49094 .73547 .48764 .73056 .48161 Mtetra
.73056 .48161 .73547 .48764 .74628 .48434 .7414 .47828 Mtetra
.7414 .47828 .74628 .48434 .75712 .48102 .75227 .47494 Mtetra
.75227 .47494 .75712 .48102 .76801 .4777 .76319 .47159 Mtetra
.76319 .47159 .76801 .4777 .77894 .47436 .77414 .46822 Mtetra
.77414 .46822 .77894 .47436 .78991 .471 .78514 .46485 Mtetra
.78514 .46485 .78991 .471 .80092 .46764 .79618 .46146 Mtetra
.79618 .46146 .80092 .46764 .81197 .46426 .80727 .45806 Mtetra
.80727 .45806 .81197 .46426 .82307 .46087 .81839 .45464 Mtetra
.81839 .45464 .82307 .46087 .8342 .45747 .82956 .45122 Mtetra
.82956 .45122 .8342 .45747 .84538 .45406 .84077 .44778 Mtetra
.84077 .44778 .84538 .45406 .85661 .45063 .85203 .44433 Mtetra
.85203 .44433 .85661 .45063 .86787 .44719 .86333 .44086 Mtetra
.86333 .44086 .86787 .44719 .87919 .44374 .87467 .43738 Mtetra
.87467 .43738 .87919 .44374 .89054 .44027 .88606 .43389 Mtetra
.88606 .43389 .89054 .44027 .90194 .43679 .89749 .43039 Mtetra
.89749 .43039 .90194 .43679 .91338 .4333 .90896 .42687 Mtetra
.61 .722 .925 r
.29451 .60865 .30045 .61432 .30962 .61312 .30373 .60685 Mtetra
.29 .558 .927 r
.30373 .60685 .30962 .61312 .31947 .60106 .31271 .60946 Mtetra
0 0 0 r
.31271 .60946 .31947 .60106 .32844 .60435 .32259 .59801 Mtetra
.586 .691 .914 r
.32259 .59801 .32844 .60435 .33775 .60242 .33188 .59676 Mtetra
.625 .729 .921 r
.33188 .59676 .33775 .60242 .34711 .60025 .34126 .59459 Mtetra
.619 .728 .924 r
.34126 .59459 .34711 .60025 .35647 .59874 .35067 .59254 Mtetra
.431 .633 .94 r
.35067 .59254 .35647 .59874 .36653 .58318 .35996 .59364 Mtetra
0 0 0 r
.35996 .59364 .36653 .58318 .37559 .58979 .36984 .58322 Mtetra
.582 .684 .911 r
.36984 .58322 .37559 .58979 .38508 .58774 .37931 .58204 Mtetra
.632 .733 .92 r
.37931 .58204 .38508 .58774 .39463 .58527 .38887 .57968 Mtetra
.64 .74 .921 r
.38887 .57968 .39463 .58527 .40421 .58273 .39848 .57712 Mtetra
.638 .739 .922 r
.39848 .57712 .40421 .58273 .41383 .58032 .40812 .57459 Mtetra
.622 .73 .924 r
.40812 .57459 .41383 .58032 .42346 .57903 .41779 .57243 Mtetra
0 .346 .822 r
.41779 .57243 .42346 .57903 .43338 .56833 .42726 .57836 Mtetra
0 0 0 r
.42726 .57836 .43338 .56833 .443 .56934 .43737 .56304 Mtetra
.608 .707 .914 r
.43737 .56304 .443 .56934 .45276 .56695 .44713 .56122 Mtetra
.642 .739 .92 r
.44713 .56122 .45276 .56695 .46257 .56418 .45696 .55856 Mtetra
.65 .747 .92 r
.45696 .55856 .46257 .56418 .47241 .56128 .46682 .55569 Mtetra
.654 .75 .92 r
.46682 .55569 .47241 .56128 .48229 .55829 .47672 .55271 Mtetra
.656 .751 .92 r
.47672 .55271 .48229 .55829 .4922 .55524 .48666 .54967 Mtetra
.658 .753 .92 r
.48666 .54967 .4922 .55524 .50215 .55216 .49664 .54657 Mtetra
.659 .753 .92 r
.49664 .54657 .50215 .55216 .51214 .54904 .50665 .54345 Mtetra
.659 .754 .92 r
.50665 .54345 .51214 .54904 .52217 .54591 .5167 .5403 Mtetra
.5167 .5403 .52217 .54591 .53223 .54278 .52678 .53714 Mtetra
.52678 .53714 .53223 .54278 .54232 .53963 .5369 .53397 Mtetra
.658 .753 .92 r
.5369 .53397 .54232 .53963 .55246 .53649 .54706 .5308 Mtetra
.54706 .5308 .55246 .53649 .56263 .53333 .55725 .52762 Mtetra
.55725 .52762 .56263 .53333 .57283 .53017 .56749 .52444 Mtetra
.56749 .52444 .57283 .53017 .58308 .52701 .57776 .52125 Mtetra
.57776 .52125 .58308 .52701 .59336 .52383 .58807 .51805 Mtetra
.58807 .51805 .59336 .52383 .60368 .52065 .59841 .51484 Mtetra
.59841 .51484 .60368 .52065 .61404 .51745 .6088 .51162 Mtetra
.657 .753 .92 r
.6088 .51162 .61404 .51745 .62444 .51425 .61922 .5084 Mtetra
.61922 .5084 .62444 .51425 .63487 .51103 .62968 .50516 Mtetra
.62968 .50516 .63487 .51103 .64535 .50781 .64018 .50191 Mtetra
.657 .752 .92 r
.64018 .50191 .64535 .50781 .65586 .50457 .65072 .49865 Mtetra
.65072 .49865 .65586 .50457 .66641 .50133 .6613 .49538 Mtetra
.6613 .49538 .66641 .50133 .677 .49807 .67192 .4921 Mtetra
.67192 .4921 .677 .49807 .68764 .4948 .68258 .48881 Mtetra
.68258 .48881 .68764 .4948 .69831 .49152 .69328 .48551 Mtetra
.69328 .48551 .69831 .49152 .70902 .48823 .70402 .48219 Mtetra
.70402 .48219 .70902 .48823 .71977 .48492 .7148 .47886 Mtetra
.7148 .47886 .71977 .48492 .73056 .48161 .72562 .47552 Mtetra
.72562 .47552 .73056 .48161 .7414 .47828 .73648 .47217 Mtetra
.73648 .47217 .7414 .47828 .75227 .47494 .74738 .46881 Mtetra
.74738 .46881 .75227 .47494 .76319 .47159 .75833 .46543 Mtetra
.75833 .46543 .76319 .47159 .77414 .46822 .76932 .46205 Mtetra
.76932 .46205 .77414 .46822 .78514 .46485 .78035 .45865 Mtetra
.78035 .45865 .78514 .46485 .79618 .46146 .79142 .45523 Mtetra
.79142 .45523 .79618 .46146 .80727 .45806 .80253 .45181 Mtetra
.80253 .45181 .80727 .45806 .81839 .45464 .81369 .44837 Mtetra
.81369 .44837 .81839 .45464 .82956 .45122 .82489 .44492 Mtetra
.82489 .44492 .82956 .45122 .84077 .44778 .83613 .44146 Mtetra
.83613 .44146 .84077 .44778 .85203 .44433 .84742 .43798 Mtetra
.84742 .43798 .85203 .44433 .86333 .44086 .85875 .43449 Mtetra
.85875 .43449 .86333 .44086 .87467 .43738 .87012 .43099 Mtetra
.87012 .43099 .87467 .43738 .88606 .43389 .88154 .42747 Mtetra
.88154 .42747 .88606 .43389 .89749 .43039 .893 .42394 Mtetra
.893 .42394 .89749 .43039 .90896 .42687 .90451 .4204 Mtetra
.614 .722 .923 r
.28854 .60293 .29451 .60865 .30373 .60685 .29778 .60101 Mtetra
.579 .707 .93 r
.29778 .60101 .30373 .60685 .31271 .60946 .30701 .59977 Mtetra
.792 .679 .74 r
.30701 .59977 .31271 .60946 .32259 .59801 .31696 .58763 Mtetra
.398 .489 .835 r
.31696 .58763 .32259 .59801 .33188 .59676 .32598 .5909 Mtetra
.616 .72 .92 r
.32598 .5909 .33188 .59676 .34126 .59459 .33537 .58892 Mtetra
.626 .731 .922 r
.33537 .58892 .34126 .59459 .35067 .59254 .3448 .58671 Mtetra
.594 .715 .928 r
.3448 .58671 .35067 .59254 .35996 .59364 .35424 .58515 Mtetra
.832 .707 .726 r
.35424 .58515 .35996 .59364 .36984 .58322 .36439 .56949 Mtetra
.303 .369 .765 r
.36439 .56949 .36984 .58322 .37931 .58204 .37351 .5761 Mtetra
.62 .721 .919 r
.37351 .5761 .37931 .58204 .38887 .57968 .38308 .574 Mtetra
.638 .738 .921 r
.38308 .574 .38887 .57968 .39848 .57712 .3927 .57148 Mtetra
.64 .74 .921 r
.3927 .57148 .39848 .57712 .40812 .57459 .40237 .56889 Mtetra
.634 .737 .922 r
.40237 .56889 .40812 .57459 .41779 .57243 .41206 .56644 Mtetra
.581 .709 .93 r
.41206 .56644 .41779 .57243 .42726 .57836 .42176 .56511 Mtetra
.749 .628 .725 r
.42176 .56511 .42726 .57836 .43737 .56304 .43177 .55432 Mtetra
.496 .585 .874 r
.43177 .55432 .43737 .56304 .44713 .56122 .44147 .5553 Mtetra
.632 .731 .919 r
.44147 .5553 .44713 .56122 .45696 .55856 .45131 .55286 Mtetra
.647 .744 .92 r
.45131 .55286 .45696 .55856 .46682 .55569 .4612 .55004 Mtetra
.652 .748 .92 r
.4612 .55004 .46682 .55569 .47672 .55271 .47112 .54709 Mtetra
.655 .751 .92 r
.47112 .54709 .47672 .55271 .48666 .54967 .48108 .54405 Mtetra
.657 .752 .92 r
.48108 .54405 .48666 .54967 .49664 .54657 .49108 .54095 Mtetra
.658 .753 .92 r
.49108 .54095 .49664 .54657 .50665 .54345 .50112 .53781 Mtetra
.659 .754 .92 r
.50112 .53781 .50665 .54345 .5167 .5403 .51119 .53464 Mtetra
.51119 .53464 .5167 .5403 .52678 .53714 .5213 .53146 Mtetra
.5213 .53146 .52678 .53714 .5369 .53397 .53144 .52827 Mtetra
.53144 .52827 .5369 .53397 .54706 .5308 .54163 .52507 Mtetra
.658 .753 .92 r
.54163 .52507 .54706 .5308 .55725 .52762 .55185 .52187 Mtetra
.55185 .52187 .55725 .52762 .56749 .52444 .5621 .51866 Mtetra
.5621 .51866 .56749 .52444 .57776 .52125 .5724 .51545 Mtetra
.5724 .51545 .57776 .52125 .58807 .51805 .58273 .51223 Mtetra
.58273 .51223 .58807 .51805 .59841 .51484 .59311 .509 Mtetra
.59311 .509 .59841 .51484 .6088 .51162 .60352 .50576 Mtetra
.657 .753 .92 r
.60352 .50576 .6088 .51162 .61922 .5084 .61396 .50251 Mtetra
.61396 .50251 .61922 .5084 .62968 .50516 .62445 .49925 Mtetra
.62445 .49925 .62968 .50516 .64018 .50191 .63498 .49598 Mtetra
.63498 .49598 .64018 .50191 .65072 .49865 .64555 .49269 Mtetra
.657 .752 .92 r
.64555 .49269 .65072 .49865 .6613 .49538 .65615 .4894 Mtetra
.65615 .4894 .6613 .49538 .67192 .4921 .6668 .4861 Mtetra
.6668 .4861 .67192 .4921 .68258 .48881 .67749 .48278 Mtetra
.67749 .48278 .68258 .48881 .69328 .48551 .68821 .47945 Mtetra
.68821 .47945 .69328 .48551 .70402 .48219 .69898 .47611 Mtetra
.69898 .47611 .70402 .48219 .7148 .47886 .70979 .47276 Mtetra
.70979 .47276 .7148 .47886 .72562 .47552 .72064 .4694 Mtetra
.72064 .4694 .72562 .47552 .73648 .47217 .73153 .46603 Mtetra
.73153 .46603 .73648 .47217 .74738 .46881 .74246 .46264 Mtetra
.74246 .46264 .74738 .46881 .75833 .46543 .75344 .45924 Mtetra
.75344 .45924 .75833 .46543 .76932 .46205 .76446 .45583 Mtetra
.76446 .45583 .76932 .46205 .78035 .45865 .77551 .4524 Mtetra
.77551 .4524 .78035 .45865 .79142 .45523 .78662 .44897 Mtetra
.78662 .44897 .79142 .45523 .80253 .45181 .79776 .44552 Mtetra
.79776 .44552 .80253 .45181 .81369 .44837 .80895 .44205 Mtetra
.80895 .44205 .81369 .44837 .82489 .44492 .82018 .43858 Mtetra
.82018 .43858 .82489 .44492 .83613 .44146 .83145 .43509 Mtetra
.83145 .43509 .83613 .44146 .84742 .43798 .84277 .43159 Mtetra
.84277 .43159 .84742 .43798 .85875 .43449 .85413 .42807 Mtetra
.85413 .42807 .85875 .43449 .87012 .43099 .86554 .42454 Mtetra
.86554 .42454 .87012 .43099 .88154 .42747 .87699 .421 Mtetra
.87699 .421 .88154 .42747 .893 .42394 .88848 .41745 Mtetra
.88848 .41745 .893 .42394 .90451 .4204 .90003 .41388 Mtetra
.605 .712 .92 r
.28254 .59697 .28854 .60293 .29778 .60101 .29178 .59526 Mtetra
.61 .722 .925 r
.29178 .59526 .29778 .60101 .30701 .59977 .30107 .59341 Mtetra
.292 .558 .927 r
.30107 .59341 .30701 .59977 .31696 .58763 .31012 .596 Mtetra
0 0 0 r
.31012 .596 .31696 .58763 .32598 .5909 .32008 .58447 Mtetra
.586 .691 .914 r
.32008 .58447 .32598 .5909 .33537 .58892 .32944 .58317 Mtetra
.625 .729 .921 r
.32944 .58317 .33537 .58892 .3448 .58671 .33889 .58096 Mtetra
.619 .728 .924 r
.33889 .58096 .3448 .58671 .35424 .58515 .34838 .57887 Mtetra
.431 .633 .94 r
.34838 .57887 .35424 .58515 .36439 .56949 .35775 .57993 Mtetra
0 0 0 r
.35775 .57993 .36439 .56949 .37351 .5761 .3677 .56943 Mtetra
.582 .684 .911 r
.3677 .56943 .37351 .5761 .38308 .574 .37725 .56821 Mtetra
.632 .733 .92 r
.37725 .56821 .38308 .574 .3927 .57148 .38689 .5658 Mtetra
.64 .74 .921 r
.38689 .5658 .3927 .57148 .40237 .56889 .39658 .56319 Mtetra
.638 .739 .922 r
.39658 .56319 .40237 .56889 .41206 .56644 .4063 .56061 Mtetra
.622 .73 .924 r
.4063 .56061 .41206 .56644 .42176 .56511 .41604 .55841 Mtetra
0 .349 .824 r
.41604 .55841 .42176 .56511 .43177 .55432 .42559 .56433 Mtetra
0 0 0 r
.42559 .56433 .43177 .55432 .44147 .5553 .43579 .5489 Mtetra
.608 .707 .915 r
.43579 .5489 .44147 .5553 .45131 .55286 .44563 .54703 Mtetra
.642 .739 .92 r
.44563 .54703 .45131 .55286 .4612 .55004 .45554 .54432 Mtetra
.65 .747 .92 r
.45554 .54432 .4612 .55004 .47112 .54709 .46548 .5414 Mtetra
.654 .75 .92 r
.46548 .5414 .47112 .54709 .48108 .54405 .47547 .53837 Mtetra
.656 .751 .92 r
.47547 .53837 .48108 .54405 .49108 .54095 .48549 .53528 Mtetra
.658 .753 .92 r
.48549 .53528 .49108 .54095 .50112 .53781 .49555 .53213 Mtetra
.659 .753 .92 r
.49555 .53213 .50112 .53781 .51119 .53464 .50564 .52895 Mtetra
.659 .754 .92 r
.50564 .52895 .51119 .53464 .5213 .53146 .51578 .52574 Mtetra
.51578 .52574 .5213 .53146 .53144 .52827 .52595 .52253 Mtetra
.52595 .52253 .53144 .52827 .54163 .52507 .53616 .51931 Mtetra
.658 .753 .92 r
.53616 .51931 .54163 .52507 .55185 .52187 .5464 .51608 Mtetra
.5464 .51608 .55185 .52187 .5621 .51866 .55668 .51285 Mtetra
.55668 .51285 .5621 .51866 .5724 .51545 .567 .50961 Mtetra
.567 .50961 .5724 .51545 .58273 .51223 .57736 .50637 Mtetra
.57736 .50637 .58273 .51223 .59311 .509 .58776 .50311 Mtetra
.58776 .50311 .59311 .509 .60352 .50576 .5982 .49985 Mtetra
.5982 .49985 .60352 .50576 .61396 .50251 .60867 .49658 Mtetra
.657 .753 .92 r
.60867 .49658 .61396 .50251 .62445 .49925 .61919 .49329 Mtetra
.61919 .49329 .62445 .49925 .63498 .49598 .62974 .49 Mtetra
.62974 .49 .63498 .49598 .64555 .49269 .64034 .48669 Mtetra
.657 .752 .92 r
.64034 .48669 .64555 .49269 .65615 .4894 .65097 .48338 Mtetra
.65097 .48338 .65615 .4894 .6668 .4861 .66165 .48005 Mtetra
.66165 .48005 .6668 .4861 .67749 .48278 .67236 .47671 Mtetra
.67236 .47671 .67749 .48278 .68821 .47945 .68312 .47336 Mtetra
.68312 .47336 .68821 .47945 .69898 .47611 .69391 .46999 Mtetra
.69391 .46999 .69898 .47611 .70979 .47276 .70475 .46662 Mtetra
.70475 .46662 .70979 .47276 .72064 .4694 .71563 .46323 Mtetra
.71563 .46323 .72064 .4694 .73153 .46603 .72655 .45983 Mtetra
.72655 .45983 .73153 .46603 .74246 .46264 .73751 .45642 Mtetra
.73751 .45642 .74246 .46264 .75344 .45924 .74851 .453 Mtetra
.74851 .453 .75344 .45924 .76446 .45583 .75956 .44956 Mtetra
.75956 .44956 .76446 .45583 .77551 .4524 .77065 .44611 Mtetra
.77065 .44611 .77551 .4524 .78662 .44897 .78178 .44265 Mtetra
.78178 .44265 .78662 .44897 .79776 .44552 .79296 .43918 Mtetra
.79296 .43918 .79776 .44552 .80895 .44205 .80417 .43569 Mtetra
.80417 .43569 .80895 .44205 .82018 .43858 .81543 .43219 Mtetra
.81543 .43219 .82018 .43858 .83145 .43509 .82674 .42867 Mtetra
.82674 .42867 .83145 .43509 .84277 .43159 .83809 .42515 Mtetra
.83809 .42515 .84277 .43159 .85413 .42807 .84948 .42161 Mtetra
.84948 .42161 .85413 .42807 .86554 .42454 .86092 .41805 Mtetra
.86092 .41805 .86554 .42454 .87699 .421 .87241 .41449 Mtetra
.87241 .41449 .87699 .421 .88848 .41745 .88393 .4109 Mtetra
.88393 .4109 .88848 .41745 .90003 .41388 .89551 .40731 Mtetra
.56 .668 .91 r
.27656 .59017 .28254 .59697 .29178 .59526 .28575 .58945 Mtetra
.614 .722 .923 r
.28575 .58945 .29178 .59526 .30107 .59341 .29506 .58749 Mtetra
.58 .707 .93 r
.29506 .58749 .30107 .59341 .31012 .596 .30437 .58621 Mtetra
.792 .679 .74 r
.30437 .58621 .31012 .596 .32008 .58447 .3144 .57398 Mtetra
.397 .488 .836 r
.3144 .57398 .32008 .58447 .32944 .58317 .32349 .57722 Mtetra
.616 .72 .92 r
.32349 .57722 .32944 .58317 .33889 .58096 .33295 .5752 Mtetra
.626 .731 .922 r
.33295 .5752 .33889 .58096 .34838 .57887 .34246 .57294 Mtetra
.594 .715 .928 r
.34246 .57294 .34838 .57887 .35775 .57993 .35197 .57134 Mtetra
.833 .708 .726 r
.35197 .57134 .35775 .57993 .3677 .56943 .36221 .55558 Mtetra
.301 .368 .765 r
.36221 .55558 .3677 .56943 .37725 .56821 .3714 .56217 Mtetra
.62 .721 .919 r
.3714 .56217 .37725 .56821 .38689 .5658 .38104 .56003 Mtetra
.638 .738 .921 r
.38104 .56003 .38689 .5658 .39658 .56319 .39074 .55746 Mtetra
.64 .74 .921 r
.39074 .55746 .39658 .56319 .4063 .56061 .40049 .55482 Mtetra
.634 .737 .922 r
.40049 .55482 .4063 .56061 .41604 .55841 .41026 .55232 Mtetra
.581 .709 .93 r
.41026 .55232 .41604 .55841 .42559 .56433 .42004 .55095 Mtetra
.75 .628 .725 r
.42004 .55095 .42559 .56433 .43579 .5489 .43013 .54007 Mtetra
.496 .585 .874 r
.43013 .54007 .43579 .5489 .44563 .54703 .43992 .54101 Mtetra
.632 .731 .919 r
.43992 .54101 .44563 .54703 .45554 .54432 .44984 .53852 Mtetra
.647 .744 .92 r
.44984 .53852 .45554 .54432 .46548 .5414 .45981 .53566 Mtetra
.652 .748 .92 r
.45981 .53566 .46548 .5414 .47547 .53837 .46981 .53265 Mtetra
.655 .751 .92 r
.46981 .53265 .47547 .53837 .48549 .53528 .47986 .52956 Mtetra
.657 .752 .92 r
.47986 .52956 .48549 .53528 .49555 .53213 .48994 .5264 Mtetra
.658 .753 .92 r
.48994 .5264 .49555 .53213 .50564 .52895 .50006 .52321 Mtetra
.659 .754 .92 r
.50006 .52321 .50564 .52895 .51578 .52574 .51022 .51999 Mtetra
.51022 .51999 .51578 .52574 .52595 .52253 .52041 .51675 Mtetra
.52041 .51675 .52595 .52253 .53616 .51931 .53065 .51351 Mtetra
.53065 .51351 .53616 .51931 .5464 .51608 .54092 .51026 Mtetra
.658 .753 .92 r
.54092 .51026 .5464 .51608 .55668 .51285 .55123 .507 Mtetra
.55123 .507 .55668 .51285 .567 .50961 .56157 .50374 Mtetra
.56157 .50374 .567 .50961 .57736 .50637 .57196 .50047 Mtetra
.57196 .50047 .57736 .50637 .58776 .50311 .58238 .49719 Mtetra
.58238 .49719 .58776 .50311 .5982 .49985 .59284 .4939 Mtetra
.59284 .4939 .5982 .49985 .60867 .49658 .60335 .4906 Mtetra
.657 .753 .92 r
.60335 .4906 .60867 .49658 .61919 .49329 .61389 .4873 Mtetra
.61389 .4873 .61919 .49329 .62974 .49 .62447 .48398 Mtetra
.62447 .48398 .62974 .49 .64034 .48669 .63509 .48065 Mtetra
.63509 .48065 .64034 .48669 .65097 .48338 .64575 .47731 Mtetra
.657 .752 .92 r
.64575 .47731 .65097 .48338 .66165 .48005 .65645 .47396 Mtetra
.65645 .47396 .66165 .48005 .67236 .47671 .6672 .47059 Mtetra
.6672 .47059 .67236 .47671 .68312 .47336 .67798 .46722 Mtetra
.67798 .46722 .68312 .47336 .69391 .46999 .6888 .46383 Mtetra
.6888 .46383 .69391 .46999 .70475 .46662 .69967 .46043 Mtetra
.69967 .46043 .70475 .46662 .71563 .46323 .71058 .45702 Mtetra
.71058 .45702 .71563 .46323 .72655 .45983 .72153 .4536 Mtetra
.72153 .4536 .72655 .45983 .73751 .45642 .73252 .45016 Mtetra
.73252 .45016 .73751 .45642 .74851 .453 .74355 .44671 Mtetra
.74355 .44671 .74851 .453 .75956 .44956 .75463 .44325 Mtetra
.75463 .44325 .75956 .44956 .77065 .44611 .76575 .43978 Mtetra
.76575 .43978 .77065 .44611 .78178 .44265 .77691 .43629 Mtetra
.77691 .43629 .78178 .44265 .79296 .43918 .78812 .43279 Mtetra
.78812 .43279 .79296 .43918 .80417 .43569 .79936 .42928 Mtetra
.79936 .42928 .80417 .43569 .81543 .43219 .81066 .42575 Mtetra
.81066 .42575 .81543 .43219 .82674 .42867 .822 .42221 Mtetra
.822 .42221 .82674 .42867 .83809 .42515 .83338 .41866 Mtetra
.83338 .41866 .83809 .42515 .84948 .42161 .8448 .4151 Mtetra
.8448 .4151 .84948 .42161 .86092 .41805 .85627 .41152 Mtetra
.85627 .41152 .86092 .41805 .87241 .41449 .86779 .40792 Mtetra
.86779 .40792 .87241 .41449 .88393 .4109 .87935 .40431 Mtetra
.87935 .40431 .88393 .4109 .89551 .40731 .89096 .40069 Mtetra
.101 .153 .63 r
.27158 .56953 .27656 .59017 .28575 .58945 .27969 .5834 Mtetra
.605 .712 .92 r
.27969 .5834 .28575 .58945 .29506 .58749 .289 .58164 Mtetra
.61 .722 .925 r
.289 .58164 .29506 .58749 .30437 .58621 .29837 .57975 Mtetra
.294 .559 .928 r
.29837 .57975 .30437 .58621 .3144 .57398 .30748 .58232 Mtetra
0 0 0 r
.30748 .58232 .3144 .57398 .32349 .57722 .31753 .57069 Mtetra
.586 .691 .914 r
.31753 .57069 .32349 .57722 .33295 .5752 .32697 .56936 Mtetra
.625 .729 .921 r
.32697 .56936 .33295 .5752 .34246 .57294 .33649 .5671 Mtetra
.619 .728 .924 r
.33649 .5671 .34246 .57294 .35197 .57134 .34605 .56496 Mtetra
.432 .633 .939 r
.34605 .56496 .35197 .57134 .36221 .55558 .35549 .56599 Mtetra
0 0 0 r
.35549 .56599 .36221 .55558 .3714 .56217 .36554 .5554 Mtetra
.582 .684 .911 r
.36554 .5554 .3714 .56217 .38104 .56003 .37516 .55414 Mtetra
.632 .733 .92 r
.37516 .55414 .38104 .56003 .39074 .55746 .38488 .55168 Mtetra
.64 .74 .921 r
.38488 .55168 .39074 .55746 .40049 .55482 .39464 .54903 Mtetra
.638 .739 .922 r
.39464 .54903 .40049 .55482 .41026 .55232 .40444 .5464 Mtetra
.622 .73 .924 r
.40444 .5464 .41026 .55232 .42004 .55095 .41427 .54414 Mtetra
0 .352 .826 r
.41427 .54414 .42004 .55095 .43013 .54007 .42389 .55005 Mtetra
0 0 0 r
.42389 .55005 .43013 .54007 .43992 .54101 .43418 .53452 Mtetra
.608 .707 .915 r
.43418 .53452 .43992 .54101 .44984 .53852 .4441 .5326 Mtetra
.642 .74 .92 r
.4441 .5326 .44984 .53852 .45981 .53566 .45409 .52984 Mtetra
.65 .747 .92 r
.45409 .52984 .45981 .53566 .46981 .53265 .46412 .52687 Mtetra
.654 .75 .92 r
.46412 .52687 .46981 .53265 .47986 .52956 .47419 .52378 Mtetra
.656 .751 .92 r
.47419 .52378 .47986 .52956 .48994 .5264 .4843 .52063 Mtetra
.658 .753 .92 r
.4843 .52063 .48994 .5264 .50006 .52321 .49444 .51743 Mtetra
.659 .753 .92 r
.49444 .51743 .50006 .52321 .51022 .51999 .50462 .5142 Mtetra
.659 .754 .92 r
.50462 .5142 .51022 .51999 .52041 .51675 .51484 .51094 Mtetra
.51484 .51094 .52041 .51675 .53065 .51351 .5251 .50767 Mtetra
.5251 .50767 .53065 .51351 .54092 .51026 .5354 .50439 Mtetra
.658 .753 .92 r
.5354 .50439 .54092 .51026 .55123 .507 .54573 .50111 Mtetra
.54573 .50111 .55123 .507 .56157 .50374 .5561 .49782 Mtetra
.5561 .49782 .56157 .50374 .57196 .50047 .56651 .49453 Mtetra
.56651 .49453 .57196 .50047 .58238 .49719 .57696 .49122 Mtetra
.57696 .49122 .58238 .49719 .59284 .4939 .58745 .48791 Mtetra
.58745 .48791 .59284 .4939 .60335 .4906 .59798 .48459 Mtetra
.59798 .48459 .60335 .4906 .61389 .4873 .60855 .48126 Mtetra
.657 .753 .92 r
.60855 .48126 .61389 .4873 .62447 .48398 .61916 .47792 Mtetra
.61916 .47792 .62447 .48398 .63509 .48065 .62981 .47456 Mtetra
.62981 .47456 .63509 .48065 .64575 .47731 .6405 .4712 Mtetra
.657 .752 .92 r
.6405 .4712 .64575 .47731 .65645 .47396 .65123 .46782 Mtetra
.65123 .46782 .65645 .47396 .6672 .47059 .662 .46444 Mtetra
.662 .46444 .6672 .47059 .67798 .46722 .67281 .46104 Mtetra
.67281 .46104 .67798 .46722 .6888 .46383 .68366 .45763 Mtetra
.68366 .45763 .6888 .46383 .69967 .46043 .69456 .4542 Mtetra
.69456 .4542 .69967 .46043 .71058 .45702 .70549 .45077 Mtetra
.70549 .45077 .71058 .45702 .72153 .4536 .71647 .44732 Mtetra
.71647 .44732 .72153 .4536 .73252 .45016 .72749 .44386 Mtetra
.72749 .44386 .73252 .45016 .74355 .44671 .73856 .44039 Mtetra
.73856 .44039 .74355 .44671 .75463 .44325 .74966 .4369 Mtetra
.74966 .4369 .75463 .44325 .76575 .43978 .76081 .4334 Mtetra
.76081 .4334 .76575 .43978 .77691 .43629 .772 .42989 Mtetra
.772 .42989 .77691 .43629 .78812 .43279 .78324 .42636 Mtetra
.78324 .42636 .78812 .43279 .79936 .42928 .79452 .42283 Mtetra
.79452 .42283 .79936 .42928 .81066 .42575 .80585 .41927 Mtetra
.80585 .41927 .81066 .42575 .822 .42221 .81722 .41571 Mtetra
.81722 .41571 .822 .42221 .83338 .41866 .82863 .41213 Mtetra
.82863 .41213 .83338 .41866 .8448 .4151 .84009 .40854 Mtetra
.84009 .40854 .8448 .4151 .85627 .41152 .85159 .40493 Mtetra
.85159 .40493 .85627 .41152 .86779 .40792 .86314 .40131 Mtetra
.86314 .40131 .86779 .40792 .87935 .40431 .87473 .39768 Mtetra
.87473 .39768 .87935 .40431 .89096 .40069 .88638 .39403 Mtetra
.163 0 .151 r
.26375 .58627 .27158 .56953 .27969 .5834 .27366 .5765 Mtetra
.559 .668 .91 r
.27366 .5765 .27969 .5834 .289 .58164 .28291 .57574 Mtetra
.614 .722 .923 r
.28291 .57574 .289 .58164 .29837 .57975 .2923 .57373 Mtetra
.58 .707 .93 r
.2923 .57373 .29837 .57975 .30748 .58232 .30168 .57241 Mtetra
.793 .68 .74 r
.30168 .57241 .30748 .58232 .31753 .57069 .31179 .56009 Mtetra
.396 .488 .836 r
.31179 .56009 .31753 .57069 .32697 .56936 .32095 .56331 Mtetra
.616 .72 .92 r
.32095 .56331 .32697 .56936 .33649 .5671 .33049 .56125 Mtetra
.626 .731 .922 r
.33049 .56125 .33649 .5671 .34605 .56496 .34007 .55894 Mtetra
.594 .715 .928 r
.34007 .55894 .34605 .56496 .35549 .56599 .34966 .55729 Mtetra
.834 .709 .726 r
.34966 .55729 .35549 .56599 .36554 .5554 .35999 .54142 Mtetra
.299 .367 .765 r
.35999 .54142 .36554 .5554 .37516 .55414 .36925 .54801 Mtetra
.62 .721 .919 r
.36925 .54801 .37516 .55414 .38488 .55168 .37897 .54582 Mtetra
.638 .738 .921 r
.37897 .54582 .38488 .55168 .39464 .54903 .38875 .5432 Mtetra
.64 .74 .921 r
.38875 .5432 .39464 .54903 .40444 .5464 .39858 .54051 Mtetra
.634 .737 .922 r
.39858 .54051 .40444 .5464 .41427 .54414 .40843 .53796 Mtetra
.581 .709 .93 r
.40843 .53796 .41427 .54414 .42389 .55005 .41829 .53654 Mtetra
.75 .628 .725 r
.41829 .53654 .42389 .55005 .43418 .53452 .42847 .52558 Mtetra
.495 .585 .874 r
.42847 .52558 .43418 .53452 .4441 .5326 .43834 .52648 Mtetra
.632 .731 .919 r
.43834 .52648 .4441 .5326 .45409 .52984 .44834 .52394 Mtetra
.647 .744 .92 r
.44834 .52394 .45409 .52984 .46412 .52687 .45839 .52102 Mtetra
.652 .748 .92 r
.45839 .52102 .46412 .52687 .47419 .52378 .46848 .51796 Mtetra
.655 .751 .92 r
.46848 .51796 .47419 .52378 .4843 .52063 .47861 .51481 Mtetra
.657 .752 .92 r
.47861 .51481 .4843 .52063 .49444 .51743 .48878 .51161 Mtetra
.658 .753 .92 r
.48878 .51161 .49444 .51743 .50462 .5142 .49899 .50836 Mtetra
.659 .754 .92 r
.49899 .50836 .50462 .5142 .51484 .51094 .50923 .50508 Mtetra
.50923 .50508 .51484 .51094 .5251 .50767 .51952 .50179 Mtetra
.51952 .50179 .5251 .50767 .5354 .50439 .52984 .49849 Mtetra
.52984 .49849 .5354 .50439 .54573 .50111 .5402 .49518 Mtetra
.658 .753 .92 r
.5402 .49518 .54573 .50111 .5561 .49782 .5506 .49186 Mtetra
.5506 .49186 .5561 .49782 .56651 .49453 .56103 .48854 Mtetra
.56103 .48854 .56651 .49453 .57696 .49122 .57151 .48522 Mtetra
.57151 .48522 .57696 .49122 .58745 .48791 .58202 .48188 Mtetra
.58202 .48188 .58745 .48791 .59798 .48459 .59258 .47854 Mtetra
.59258 .47854 .59798 .48459 .60855 .48126 .60318 .47518 Mtetra
.657 .753 .92 r
.60318 .47518 .60855 .48126 .61916 .47792 .61381 .47181 Mtetra
.61381 .47181 .61916 .47792 .62981 .47456 .62449 .46844 Mtetra
.62449 .46844 .62981 .47456 .6405 .4712 .6352 .46505 Mtetra
.6352 .46505 .6405 .4712 .65123 .46782 .64596 .46165 Mtetra
.657 .752 .92 r
.64596 .46165 .65123 .46782 .662 .46444 .65676 .45824 Mtetra
.65676 .45824 .662 .46444 .67281 .46104 .6676 .45481 Mtetra
.6676 .45481 .67281 .46104 .68366 .45763 .67848 .45138 Mtetra
.67848 .45138 .68366 .45763 .69456 .4542 .68941 .44793 Mtetra
.68941 .44793 .69456 .4542 .70549 .45077 .70037 .44447 Mtetra
.70037 .44447 .70549 .45077 .71647 .44732 .71138 .441 Mtetra
.71138 .441 .71647 .44732 .72749 .44386 .72243 .43751 Mtetra
.72243 .43751 .72749 .44386 .73856 .44039 .73352 .43401 Mtetra
.73352 .43401 .73856 .44039 .74966 .4369 .74466 .4305 Mtetra
.74466 .4305 .74966 .4369 .76081 .4334 .75584 .42698 Mtetra
.75584 .42698 .76081 .4334 .772 .42989 .76706 .42344 Mtetra
.76706 .42344 .772 .42989 .78324 .42636 .77833 .41989 Mtetra
.77833 .41989 .78324 .42636 .79452 .42283 .78964 .41632 Mtetra
.78964 .41632 .79452 .42283 .80585 .41927 .801 .41275 Mtetra
.801 .41275 .80585 .41927 .81722 .41571 .8124 .40915 Mtetra
.8124 .40915 .81722 .41571 .82863 .41213 .82385 .40555 Mtetra
.82385 .40555 .82863 .41213 .84009 .40854 .83534 .40193 Mtetra
.83534 .40193 .84009 .40854 .85159 .40493 .84687 .3983 Mtetra
.84687 .3983 .85159 .40493 .86314 .40131 .85846 .39465 Mtetra
.85846 .39465 .86314 .40131 .87473 .39768 .87008 .39099 Mtetra
.87008 .39099 .87473 .39768 .88638 .39403 .88176 .38731 Mtetra
.865 .713 .691 r
.25774 .57831 .26375 .58627 .27366 .5765 .26864 .5557 Mtetra
.097 .15 .629 r
.26864 .5557 .27366 .5765 .28291 .57574 .27679 .56959 Mtetra
.605 .712 .92 r
.27679 .56959 .28291 .57574 .2923 .57373 .28618 .5678 Mtetra
.61 .722 .925 r
.28618 .5678 .2923 .57373 .30168 .57241 .29562 .56586 Mtetra
.296 .559 .928 r
.29562 .56586 .30168 .57241 .31179 .56009 .3048 .5684 Mtetra
0 0 0 r
.3048 .5684 .31179 .56009 .32095 .56331 .31494 .55669 Mtetra
.586 .691 .914 r
.31494 .55669 .32095 .56331 .33049 .56125 .32445 .55531 Mtetra
.625 .729 .921 r
.32445 .55531 .33049 .56125 .34007 .55894 .33405 .553 Mtetra
.619 .728 .924 r
.33405 .553 .34007 .55894 .34966 .55729 .34368 .55081 Mtetra
.433 .633 .939 r
.34368 .55081 .34966 .55729 .35999 .54142 .3532 .55181 Mtetra
0 0 0 r
.3532 .55181 .35999 .54142 .36925 .54801 .36333 .54114 Mtetra
.582 .684 .911 r
.36333 .54114 .36925 .54801 .37897 .54582 .37303 .53983 Mtetra
.632 .733 .92 r
.37303 .53983 .37897 .54582 .38875 .5432 .38283 .53732 Mtetra
.64 .74 .921 r
.38283 .53732 .38875 .5432 .39858 .54051 .39267 .53462 Mtetra
.638 .739 .922 r
.39267 .53462 .39858 .54051 .40843 .53796 .40255 .53193 Mtetra
.622 .73 .924 r
.40255 .53193 .40843 .53796 .41829 .53654 .41246 .52963 Mtetra
0 .355 .828 r
.41246 .52963 .41829 .53654 .42847 .52558 .42216 .53553 Mtetra
0 0 0 r
.42216 .53553 .42847 .52558 .43834 .52648 .43254 .51988 Mtetra
.608 .707 .915 r
.43254 .51988 .43834 .52648 .44834 .52394 .44255 .51792 Mtetra
.642 .74 .92 r
.44255 .51792 .44834 .52394 .45839 .52102 .45262 .51511 Mtetra
.65 .747 .92 r
.45262 .51511 .45839 .52102 .46848 .51796 .46273 .51208 Mtetra
.654 .75 .92 r
.46273 .51208 .46848 .51796 .47861 .51481 .47289 .50894 Mtetra
.656 .751 .92 r
.47289 .50894 .47861 .51481 .48878 .51161 .48308 .50573 Mtetra
.658 .753 .92 r
.48308 .50573 .48878 .51161 .49899 .50836 .49331 .50248 Mtetra
.659 .753 .92 r
.49331 .50248 .49899 .50836 .50923 .50508 .50358 .49918 Mtetra
.659 .754 .92 r
.50358 .49918 .50923 .50508 .51952 .50179 .51389 .49587 Mtetra
.51389 .49587 .51952 .50179 .52984 .49849 .52424 .49254 Mtetra
.52424 .49254 .52984 .49849 .5402 .49518 .53462 .48921 Mtetra
.658 .753 .92 r
.53462 .48921 .5402 .49518 .5506 .49186 .54505 .48587 Mtetra
.54505 .48587 .5506 .49186 .56103 .48854 .55551 .48252 Mtetra
.55551 .48252 .56103 .48854 .57151 .48522 .56601 .47917 Mtetra
.56601 .47917 .57151 .48522 .58202 .48188 .57656 .47581 Mtetra
.57656 .47581 .58202 .48188 .59258 .47854 .58714 .47244 Mtetra
.58714 .47244 .59258 .47854 .60318 .47518 .59776 .46906 Mtetra
.59776 .46906 .60318 .47518 .61381 .47181 .60843 .46567 Mtetra
.657 .753 .92 r
.60843 .46567 .61381 .47181 .62449 .46844 .61913 .46226 Mtetra
.61913 .46226 .62449 .46844 .6352 .46505 .62987 .45885 Mtetra
.62987 .45885 .6352 .46505 .64596 .46165 .64066 .45543 Mtetra
.657 .752 .92 r
.64066 .45543 .64596 .46165 .65676 .45824 .65149 .45199 Mtetra
.65149 .45199 .65676 .45824 .6676 .45481 .66235 .44854 Mtetra
.66235 .44854 .6676 .45481 .67848 .45138 .67327 .44508 Mtetra
.67327 .44508 .67848 .45138 .68941 .44793 .68422 .44161 Mtetra
.68422 .44161 .68941 .44793 .70037 .44447 .69521 .43812 Mtetra
.69521 .43812 .70037 .44447 .71138 .441 .70625 .43463 Mtetra
.70625 .43463 .71138 .441 .72243 .43751 .71733 .43111 Mtetra
.71733 .43111 .72243 .43751 .73352 .43401 .72845 .42759 Mtetra
.72845 .42759 .73352 .43401 .74466 .4305 .73962 .42405 Mtetra
.73962 .42405 .74466 .4305 .75584 .42698 .75083 .4205 Mtetra
.75083 .4205 .75584 .42698 .76706 .42344 .76209 .41694 Mtetra
.76209 .41694 .76706 .42344 .77833 .41989 .77339 .41336 Mtetra
.77339 .41336 .77833 .41989 .78964 .41632 .78473 .40977 Mtetra
.78473 .40977 .78964 .41632 .801 .41275 .79612 .40617 Mtetra
.79612 .40617 .801 .41275 .8124 .40915 .80755 .40255 Mtetra
.80755 .40255 .8124 .40915 .82385 .40555 .81903 .39892 Mtetra
.81903 .39892 .82385 .40555 .83534 .40193 .83055 .39527 Mtetra
.83055 .39527 .83534 .40193 .84687 .3983 .84212 .39162 Mtetra
.84212 .39162 .84687 .3983 .85846 .39465 .85374 .38794 Mtetra
.85374 .38794 .85846 .39465 .87008 .39099 .8654 .38425 Mtetra
.8654 .38425 .87008 .39099 .88176 .38731 .87711 .38055 Mtetra
.465 .651 .94 r
.25156 .57196 .25774 .57831 .26864 .5557 .26071 .57245 Mtetra
.152 0 .14 r
.26071 .57245 .26864 .5557 .27679 .56959 .2707 .5626 Mtetra
.559 .668 .91 r
.2707 .5626 .27679 .56959 .28618 .5678 .28003 .5618 Mtetra
.614 .722 .923 r
.28003 .5618 .28618 .5678 .29562 .56586 .28949 .55975 Mtetra
.58 .707 .93 r
.28949 .55975 .29562 .56586 .3048 .5684 .29894 .55838 Mtetra
.793 .681 .74 r
.29894 .55838 .3048 .5684 .31494 .55669 .30914 .54597 Mtetra
.395 .487 .836 r
.30914 .54597 .31494 .55669 .32445 .55531 .31837 .54916 Mtetra
.616 .72 .92 r
.31837 .54916 .32445 .55531 .33405 .553 .32798 .54705 Mtetra
.626 .731 .922 r
.32798 .54705 .33405 .553 .34368 .55081 .33765 .5447 Mtetra
.595 .715 .928 r
.33765 .5447 .34368 .55081 .3532 .55181 .34731 .543 Mtetra
.835 .709 .726 r
.34731 .543 .3532 .55181 .36333 .54114 .35774 .52702 Mtetra
.297 .366 .765 r
.35774 .52702 .36333 .54114 .37303 .53983 .36706 .5336 Mtetra
.62 .721 .919 r
.36706 .5336 .37303 .53983 .38283 .53732 .37686 .53136 Mtetra
.638 .738 .921 r
.37686 .53136 .38283 .53732 .39267 .53462 .38673 .52869 Mtetra
.64 .74 .921 r
.38673 .52869 .39267 .53462 .40255 .53193 .39663 .52595 Mtetra
.634 .737 .922 r
.39663 .52595 .40255 .53193 .41246 .52963 .40657 .52335 Mtetra
.581 .709 .93 r
.40657 .52335 .41246 .52963 .42216 .53553 .41651 .52188 Mtetra
.75 .629 .725 r
.41651 .52188 .42216 .53553 .43254 .51988 .42678 .51083 Mtetra
.495 .585 .874 r
.42678 .51083 .43254 .51988 .44255 .51792 .43672 .5117 Mtetra
.632 .731 .919 r
.43672 .5117 .44255 .51792 .45262 .51511 .44681 .5091 Mtetra
.647 .744 .92 r
.44681 .5091 .45262 .51511 .46273 .51208 .45695 .50613 Mtetra
.652 .748 .92 r
.45695 .50613 .46273 .51208 .47289 .50894 .46713 .50301 Mtetra
.655 .751 .92 r
.46713 .50301 .47289 .50894 .48308 .50573 .47734 .49981 Mtetra
.657 .752 .92 r
.47734 .49981 .48308 .50573 .49331 .50248 .4876 .49655 Mtetra
.658 .753 .92 r
.4876 .49655 .49331 .50248 .50358 .49918 .4979 .49324 Mtetra
.659 .754 .92 r
.4979 .49324 .50358 .49918 .51389 .49587 .50823 .48991 Mtetra
.50823 .48991 .51389 .49587 .52424 .49254 .5186 .48656 Mtetra
.5186 .48656 .52424 .49254 .53462 .48921 .52901 .4832 Mtetra
.52901 .4832 .53462 .48921 .54505 .48587 .53946 .47983 Mtetra
.658 .753 .92 r
.53946 .47983 .54505 .48587 .55551 .48252 .54995 .47646 Mtetra
.54995 .47646 .55551 .48252 .56601 .47917 .56048 .47308 Mtetra
.56048 .47308 .56601 .47917 .57656 .47581 .57105 .46969 Mtetra
.57105 .46969 .57656 .47581 .58714 .47244 .58166 .4663 Mtetra
.58166 .4663 .58714 .47244 .59776 .46906 .59231 .46289 Mtetra
.59231 .46289 .59776 .46906 .60843 .46567 .603 .45948 Mtetra
.657 .753 .92 r
.603 .45948 .60843 .46567 .61913 .46226 .61373 .45605 Mtetra
.61373 .45605 .61913 .46226 .62987 .45885 .6245 .45261 Mtetra
.6245 .45261 .62987 .45885 .64066 .45543 .63532 .44916 Mtetra
.63532 .44916 .64066 .45543 .65149 .45199 .64617 .4457 Mtetra
.657 .752 .92 r
.64617 .4457 .65149 .45199 .66235 .44854 .65707 .44223 Mtetra
.65707 .44223 .66235 .44854 .67327 .44508 .66801 .43874 Mtetra
.66801 .43874 .67327 .44508 .68422 .44161 .67899 .43524 Mtetra
.67899 .43524 .68422 .44161 .69521 .43812 .69002 .43173 Mtetra
.69002 .43173 .69521 .43812 .70625 .43463 .70108 .42821 Mtetra
.70108 .42821 .70625 .43463 .71733 .43111 .7122 .42467 Mtetra
.7122 .42467 .71733 .43111 .72845 .42759 .72335 .42112 Mtetra
.72335 .42112 .72845 .42759 .73962 .42405 .73455 .41756 Mtetra
.73455 .41756 .73962 .42405 .75083 .4205 .74579 .41398 Mtetra
.74579 .41398 .75083 .4205 .76209 .41694 .75707 .4104 Mtetra
.75707 .4104 .76209 .41694 .77339 .41336 .7684 .40679 Mtetra
.7684 .40679 .77339 .41336 .78473 .40977 .77978 .40318 Mtetra
.77978 .40318 .78473 .40977 .79612 .40617 .7912 .39955 Mtetra
.7912 .39955 .79612 .40617 .80755 .40255 .80266 .3959 Mtetra
.80266 .3959 .80755 .40255 .81903 .39892 .81418 .39224 Mtetra
.81418 .39224 .81903 .39892 .83055 .39527 .82573 .38857 Mtetra
.82573 .38857 .83055 .39527 .84212 .39162 .83733 .38488 Mtetra
.83733 .38488 .84212 .39162 .85374 .38794 .84898 .38118 Mtetra
.84898 .38118 .85374 .38794 .8654 .38425 .86068 .37747 Mtetra
.86068 .37747 .8654 .38425 .87711 .38055 .87242 .37374 Mtetra
.587 .71 .928 r
.24531 .56587 .25156 .57196 .26071 .57245 .25464 .56438 Mtetra
.866 .714 .691 r
.25464 .56438 .26071 .57245 .2707 .5626 .26564 .54164 Mtetra
.093 .147 .627 r
.26564 .54164 .2707 .5626 .28003 .5618 .27385 .55556 Mtetra
.605 .712 .92 r
.27385 .55556 .28003 .5618 .28949 .55975 .28331 .55371 Mtetra
.61 .722 .925 r
.28331 .55371 .28949 .55975 .29894 .55838 .29282 .55173 Mtetra
.298 .56 .928 r
.29282 .55173 .29894 .55838 .30914 .54597 .30207 .55424 Mtetra
0 0 0 r
.30207 .55424 .30914 .54597 .31837 .54916 .3123 .54244 Mtetra
.586 .691 .915 r
.3123 .54244 .31837 .54916 .32798 .54705 .32188 .54101 Mtetra
.625 .729 .921 r
.32188 .54101 .32798 .54705 .33765 .5447 .33156 .53866 Mtetra
.619 .728 .924 r
.33156 .53866 .33765 .5447 .34731 .543 .34128 .53642 Mtetra
.434 .633 .939 r
.34128 .53642 .34731 .543 .35774 .52702 .35087 .53738 Mtetra
0 0 0 r
.35087 .53738 .35774 .52702 .36706 .5336 .36109 .52663 Mtetra
.582 .684 .911 r
.36109 .52663 .36706 .5336 .37686 .53136 .37087 .52528 Mtetra
.632 .733 .92 r
.37087 .52528 .37686 .53136 .38673 .52869 .38074 .52271 Mtetra
.64 .74 .921 r
.38074 .52271 .38673 .52869 .39663 .52595 .39067 .51996 Mtetra
.638 .739 .922 r
.39067 .51996 .39663 .52595 .40657 .52335 .40063 .51722 Mtetra
.622 .73 .924 r
.40063 .51722 .40657 .52335 .41651 .52188 .41062 .51487 Mtetra
0 .357 .83 r
.41062 .51487 .41651 .52188 .42678 .51083 .4204 .52075 Mtetra
0 0 0 r
.4204 .52075 .42678 .51083 .43672 .5117 .43087 .50499 Mtetra
.608 .707 .915 r
.43087 .50499 .43672 .5117 .44681 .5091 .44097 .50298 Mtetra
.642 .74 .92 r
.44097 .50298 .44681 .5091 .45695 .50613 .45112 .50011 Mtetra
.65 .747 .92 r
.45112 .50011 .45695 .50613 .46713 .50301 .46132 .49703 Mtetra
.654 .75 .92 r
.46132 .49703 .46713 .50301 .47734 .49981 .47157 .49383 Mtetra
.656 .751 .92 r
.47157 .49383 .47734 .49981 .4876 .49655 .48185 .49057 Mtetra
.658 .753 .92 r
.48185 .49057 .4876 .49655 .4979 .49324 .49217 .48726 Mtetra
.659 .753 .92 r
.49217 .48726 .4979 .49324 .50823 .48991 .50253 .4839 Mtetra
.659 .754 .92 r
.50253 .4839 .50823 .48991 .5186 .48656 .51292 .48053 Mtetra
.51292 .48053 .5186 .48656 .52901 .4832 .52336 .47715 Mtetra
.52336 .47715 .52901 .4832 .53946 .47983 .53384 .47375 Mtetra
.658 .753 .92 r
.53384 .47375 .53946 .47983 .54995 .47646 .54435 .47035 Mtetra
.54435 .47035 .54995 .47646 .56048 .47308 .55491 .46695 Mtetra
.55491 .46695 .56048 .47308 .57105 .46969 .56551 .46354 Mtetra
.56551 .46354 .57105 .46969 .58166 .4663 .57614 .46012 Mtetra
.57614 .46012 .58166 .4663 .59231 .46289 .58682 .45668 Mtetra
.58682 .45668 .59231 .46289 .603 .45948 .59754 .45324 Mtetra
.59754 .45324 .603 .45948 .61373 .45605 .6083 .44979 Mtetra
.657 .753 .92 r
.6083 .44979 .61373 .45605 .6245 .45261 .6191 .44633 Mtetra
.6191 .44633 .6245 .45261 .63532 .44916 .62994 .44285 Mtetra
.62994 .44285 .63532 .44916 .64617 .4457 .64082 .43937 Mtetra
.657 .752 .92 r
.64082 .43937 .64617 .4457 .65707 .44223 .65175 .43587 Mtetra
.65175 .43587 .65707 .44223 .66801 .43874 .66272 .43236 Mtetra
.66272 .43236 .66801 .43874 .67899 .43524 .67373 .42883 Mtetra
.67373 .42883 .67899 .43524 .69002 .43173 .68478 .4253 Mtetra
.68478 .4253 .69002 .43173 .70108 .42821 .69588 .42175 Mtetra
.69588 .42175 .70108 .42821 .7122 .42467 .70702 .41819 Mtetra
.70702 .41819 .7122 .42467 .72335 .42112 .71821 .41461 Mtetra
.71821 .41461 .72335 .42112 .73455 .41756 .72943 .41102 Mtetra
.72943 .41102 .73455 .41756 .74579 .41398 .74071 .40742 Mtetra
.74071 .40742 .74579 .41398 .75707 .4104 .75202 .4038 Mtetra
.75202 .4038 .75707 .4104 .7684 .40679 .76339 .40017 Mtetra
.76339 .40017 .7684 .40679 .77978 .40318 .77479 .39653 Mtetra
.77479 .39653 .77978 .40318 .7912 .39955 .78625 .39287 Mtetra
.78625 .39287 .7912 .39955 .80266 .3959 .79774 .3892 Mtetra
.79774 .3892 .80266 .3959 .81418 .39224 .80929 .38552 Mtetra
.80929 .38552 .81418 .39224 .82573 .38857 .82088 .38182 Mtetra
.82088 .38182 .82573 .38857 .83733 .38488 .83251 .3781 Mtetra
.83251 .3781 .83733 .38488 .84898 .38118 .84419 .37437 Mtetra
.84419 .37437 .84898 .38118 .86068 .37747 .85592 .37063 Mtetra
.85592 .37063 .86068 .37747 .87242 .37374 .8677 .36687 Mtetra
.603 .716 .924 r
.23903 .55976 .24531 .56587 .25464 .56438 .2484 .55794 Mtetra
.465 .651 .94 r
.2484 .55794 .25464 .56438 .26564 .54164 .25762 .5584 Mtetra
.14 0 .128 r
.25762 .5584 .26564 .54164 .27385 .55556 .26769 .54846 Mtetra
.559 .668 .91 r
.26769 .54846 .27385 .55556 .28331 .55371 .27709 .54762 Mtetra
.614 .722 .923 r
.27709 .54762 .28331 .55371 .29282 .55173 .28663 .54552 Mtetra
.58 .707 .93 r
.28663 .54552 .29282 .55173 .30207 .55424 .29616 .54411 Mtetra
.794 .681 .74 r
.29616 .54411 .30207 .55424 .3123 .54244 .30645 .5316 Mtetra
.394 .487 .836 r
.30645 .5316 .3123 .54244 .32188 .54101 .31575 .53477 Mtetra
.616 .72 .92 r
.31575 .53477 .32188 .54101 .33156 .53866 .32544 .53261 Mtetra
.626 .731 .922 r
.32544 .53261 .33156 .53866 .34128 .53642 .33518 .53021 Mtetra
.595 .715 .928 r
.33518 .53021 .34128 .53642 .35087 .53738 .34492 .52847 Mtetra
.835 .71 .726 r
.34492 .52847 .35087 .53738 .36109 .52663 .35544 .51238 Mtetra
.295 .365 .765 r
.35544 .51238 .36109 .52663 .37087 .52528 .36484 .51894 Mtetra
.62 .721 .919 r
.36484 .51894 .37087 .52528 .38074 .52271 .37472 .51665 Mtetra
.638 .738 .921 r
.37472 .51665 .38074 .52271 .39067 .51996 .38467 .51393 Mtetra
.64 .74 .921 r
.38467 .51393 .39067 .51996 .40063 .51722 .39465 .51113 Mtetra
.634 .737 .922 r
.39465 .51113 .40063 .51722 .41062 .51487 .40467 .50848 Mtetra
.581 .709 .93 r
.40467 .50848 .41062 .51487 .4204 .52075 .4147 .50696 Mtetra
.751 .629 .725 r
.4147 .50696 .4204 .52075 .43087 .50499 .42506 .49582 Mtetra
.494 .585 .875 r
.42506 .49582 .43087 .50499 .44097 .50298 .43509 .49665 Mtetra
.632 .731 .919 r
.43509 .49665 .44097 .50298 .45112 .50011 .44526 .494 Mtetra
.647 .744 .92 r
.44526 .494 .45112 .50011 .46132 .49703 .45548 .49098 Mtetra
.652 .748 .92 r
.45548 .49098 .46132 .49703 .47157 .49383 .46575 .4878 Mtetra
.655 .751 .92 r
.46575 .4878 .47157 .49383 .48185 .49057 .47605 .48454 Mtetra
.657 .752 .92 r
.47605 .48454 .48185 .49057 .49217 .48726 .4864 .48122 Mtetra
.658 .753 .92 r
.4864 .48122 .49217 .48726 .50253 .4839 .49678 .47786 Mtetra
.659 .754 .92 r
.49678 .47786 .50253 .4839 .51292 .48053 .50721 .47446 Mtetra
.50721 .47446 .51292 .48053 .52336 .47715 .51767 .47105 Mtetra
.51767 .47105 .52336 .47715 .53384 .47375 .52817 .46763 Mtetra
.52817 .46763 .53384 .47375 .54435 .47035 .53872 .46421 Mtetra
.658 .753 .92 r
.53872 .46421 .54435 .47035 .55491 .46695 .5493 .46078 Mtetra
.5493 .46078 .55491 .46695 .56551 .46354 .55992 .45734 Mtetra
.55992 .45734 .56551 .46354 .57614 .46012 .57059 .45389 Mtetra
.57059 .45389 .57614 .46012 .58682 .45668 .58129 .45043 Mtetra
.58129 .45043 .58682 .45668 .59754 .45324 .59204 .44697 Mtetra
.59204 .44697 .59754 .45324 .6083 .44979 .60282 .44349 Mtetra
.657 .753 .92 r
.60282 .44349 .6083 .44979 .6191 .44633 .61365 .44 Mtetra
.61365 .44 .6191 .44633 .62994 .44285 .62452 .4365 Mtetra
.62452 .4365 .62994 .44285 .64082 .43937 .63544 .43299 Mtetra
.63544 .43299 .64082 .43937 .65175 .43587 .64639 .42946 Mtetra
.657 .752 .92 r
.64639 .42946 .65175 .43587 .66272 .43236 .65739 .42593 Mtetra
.65739 .42593 .66272 .43236 .67373 .42883 .66843 .42238 Mtetra
.66843 .42238 .67373 .42883 .68478 .4253 .67951 .41881 Mtetra
.67951 .41881 .68478 .4253 .69588 .42175 .69064 .41524 Mtetra
.69064 .41524 .69588 .42175 .70702 .41819 .70181 .41165 Mtetra
.70181 .41165 .70702 .41819 .71821 .41461 .71303 .40805 Mtetra
.71303 .40805 .71821 .41461 .72943 .41102 .72429 .40443 Mtetra
.72429 .40443 .72943 .41102 .74071 .40742 .73559 .4008 Mtetra
.73559 .4008 .74071 .40742 .75202 .4038 .74694 .39716 Mtetra
.74694 .39716 .75202 .4038 .76339 .40017 .75833 .39351 Mtetra
.75833 .39351 .76339 .40017 .77479 .39653 .76977 .38984 Mtetra
.76977 .38984 .77479 .39653 .78625 .39287 .78125 .38615 Mtetra
.78125 .38615 .78625 .39287 .79774 .3892 .79278 .38245 Mtetra
.79278 .38245 .79774 .3892 .80929 .38552 .80436 .37874 Mtetra
.80436 .37874 .80929 .38552 .82088 .38182 .81598 .37501 Mtetra
.81598 .37501 .82088 .38182 .83251 .3781 .82765 .37127 Mtetra
.82765 .37127 .83251 .3781 .84419 .37437 .83937 .36751 Mtetra
.83937 .36751 .84419 .37437 .85592 .37063 .85113 .36374 Mtetra
.85113 .36374 .85592 .37063 .8677 .36687 .86294 .35996 Mtetra
.595 .706 .921 r
.23272 .5534 .23903 .55976 .2484 .55794 .24209 .55175 Mtetra
.587 .71 .928 r
.24209 .55175 .2484 .55794 .25762 .5584 .25149 .55022 Mtetra
.867 .714 .69 r
.25149 .55022 .25762 .5584 .26769 .54846 .2626 .52734 Mtetra
.089 .144 .626 r
.2626 .52734 .26769 .54846 .27709 .54762 .27085 .54128 Mtetra
.605 .712 .92 r
.27085 .54128 .27709 .54762 .28663 .54552 .28039 .53939 Mtetra
.61 .722 .925 r
.28039 .53939 .28663 .54552 .29616 .54411 .28998 .53735 Mtetra
.299 .56 .928 r
.28998 .53735 .29616 .54411 .30645 .5316 .2993 .53984 Mtetra
.535 .815 .464 r
.2993 .53984 .30645 .5316 .31575 .53477 .30961 .52794 Mtetra
.586 .691 .915 r
.30961 .52794 .31575 .53477 .32544 .53261 .31928 .52647 Mtetra
.625 .729 .921 r
.31928 .52647 .32544 .53261 .33518 .53021 .32903 .52407 Mtetra
.619 .728 .924 r
.32903 .52407 .33518 .53021 .34492 .52847 .33883 .52178 Mtetra
.434 .633 .939 r
.33883 .52178 .34492 .52847 .35544 .51238 .34849 .5227 Mtetra
0 0 0 r
.34849 .5227 .35544 .51238 .36484 .51894 .3588 .51186 Mtetra
.582 .684 .911 r
.3588 .51186 .36484 .51894 .37472 .51665 .36866 .51046 Mtetra
.632 .733 .92 r
.36866 .51046 .37472 .51665 .38467 .51393 .37862 .50785 Mtetra
.64 .74 .921 r
.37862 .50785 .38467 .51393 .39465 .51113 .38863 .50504 Mtetra
.638 .739 .922 r
.38863 .50504 .39465 .51113 .40467 .50848 .39868 .50225 Mtetra
.622 .73 .924 r
.39868 .50225 .40467 .50848 .4147 .50696 .40875 .49984 Mtetra
0 .36 .832 r
.40875 .49984 .4147 .50696 .42506 .49582 .41861 .5057 Mtetra
0 0 0 r
.41861 .5057 .42506 .49582 .43509 .49665 .42918 .48984 Mtetra
.608 .707 .915 r
.42918 .48984 .43509 .49665 .44526 .494 .43936 .48777 Mtetra
.642 .74 .92 r
.43936 .48777 .44526 .494 .45548 .49098 .4496 .48485 Mtetra
.65 .747 .92 r
.4496 .48485 .45548 .49098 .46575 .4878 .45989 .48171 Mtetra
.654 .75 .92 r
.45989 .48171 .46575 .4878 .47605 .48454 .47022 .47846 Mtetra
.656 .751 .92 r
.47022 .47846 .47605 .48454 .4864 .48122 .48059 .47514 Mtetra
.658 .753 .92 r
.48059 .47514 .4864 .48122 .49678 .47786 .491 .47176 Mtetra
.659 .753 .92 r
.491 .47176 .49678 .47786 .50721 .47446 .50145 .46835 Mtetra
.659 .754 .92 r
.50145 .46835 .50721 .47446 .51767 .47105 .51194 .46492 Mtetra
.51194 .46492 .51767 .47105 .52817 .46763 .52247 .46147 Mtetra
.52247 .46147 .52817 .46763 .53872 .46421 .53304 .45802 Mtetra
.658 .753 .92 r
.53304 .45802 .53872 .46421 .5493 .46078 .54365 .45456 Mtetra
.54365 .45456 .5493 .46078 .55992 .45734 .5543 .45109 Mtetra
.5543 .45109 .55992 .45734 .57059 .45389 .56499 .44762 Mtetra
.56499 .44762 .57059 .45389 .58129 .45043 .57572 .44414 Mtetra
.57572 .44414 .58129 .45043 .59204 .44697 .58649 .44065 Mtetra
.58649 .44065 .59204 .44697 .60282 .44349 .59731 .43714 Mtetra
.59731 .43714 .60282 .44349 .61365 .44 .60817 .43363 Mtetra
.657 .753 .92 r
.60817 .43363 .61365 .44 .62452 .4365 .61907 .4301 Mtetra
.61907 .4301 .62452 .4365 .63544 .43299 .63001 .42656 Mtetra
.63001 .42656 .63544 .43299 .64639 .42946 .64099 .42301 Mtetra
.657 .752 .92 r
.64099 .42301 .64639 .42946 .65739 .42593 .65202 .41945 Mtetra
.65202 .41945 .65739 .42593 .66843 .42238 .66309 .41587 Mtetra
.66309 .41587 .66843 .42238 .67951 .41881 .6742 .41228 Mtetra
.6742 .41228 .67951 .41881 .69064 .41524 .68536 .40868 Mtetra
.68536 .40868 .69064 .41524 .70181 .41165 .69656 .40507 Mtetra
.69656 .40507 .70181 .41165 .71303 .40805 .70781 .40144 Mtetra
.70781 .40144 .71303 .40805 .72429 .40443 .7191 .3978 Mtetra
.7191 .3978 .72429 .40443 .73559 .4008 .73043 .39414 Mtetra
.73043 .39414 .73559 .4008 .74694 .39716 .74181 .39047 Mtetra
.74181 .39047 .74694 .39716 .75833 .39351 .75324 .38679 Mtetra
.75324 .38679 .75833 .39351 .76977 .38984 .76471 .38309 Mtetra
.76471 .38309 .76977 .38984 .78125 .38615 .77623 .37938 Mtetra
.77623 .37938 .78125 .38615 .79278 .38245 .78779 .37565 Mtetra
.78779 .37565 .79278 .38245 .80436 .37874 .7994 .37191 Mtetra
.7994 .37191 .80436 .37874 .81598 .37501 .81106 .36816 Mtetra
.81106 .36816 .81598 .37501 .82765 .37127 .82276 .36439 Mtetra
.82276 .36439 .82765 .37127 .83937 .36751 .83451 .3606 Mtetra
.83451 .3606 .83937 .36751 .85113 .36374 .84631 .3568 Mtetra
.84631 .3568 .85113 .36374 .86294 .35996 .85815 .35299 Mtetra
.537 .65 .907 r
.22647 .54596 .23272 .5534 .24209 .55175 .23574 .54555 Mtetra
.603 .716 .924 r
.23574 .54555 .24209 .55175 .25149 .55022 .24518 .54367 Mtetra
.466 .651 .94 r
.24518 .54367 .25149 .55022 .2626 .52734 .25448 .5441 Mtetra
.128 0 .116 r
.25448 .5441 .2626 .52734 .27085 .54128 .26464 .53407 Mtetra
.559 .668 .911 r
.26464 .53407 .27085 .54128 .28039 .53939 .27411 .53319 Mtetra
.614 .722 .923 r
.27411 .53319 .28039 .53939 .28998 .53735 .28372 .53104 Mtetra
.58 .707 .93 r
.28372 .53104 .28998 .53735 .2993 .53984 .29333 .52959 Mtetra
.794 .682 .74 r
.29333 .52959 .2993 .53984 .30961 .52794 .30371 .51699 Mtetra
.393 .487 .836 r
.30371 .51699 .30961 .52794 .31928 .52647 .31308 .52013 Mtetra
.616 .72 .92 r
.31308 .52013 .31928 .52647 .32903 .52407 .32285 .51792 Mtetra
.626 .731 .922 r
.32285 .51792 .32903 .52407 .33883 .52178 .33267 .51546 Mtetra
.595 .715 .928 r
.33267 .51546 .33883 .52178 .34849 .5227 .34249 .51367 Mtetra
.836 .711 .726 r
.34249 .51367 .34849 .5227 .3588 .51186 .35311 .49748 Mtetra
.293 .364 .764 r
.35311 .49748 .3588 .51186 .36866 .51046 .36257 .50402 Mtetra
.62 .721 .919 r
.36257 .50402 .36866 .51046 .37862 .50785 .37254 .50168 Mtetra
.638 .738 .921 r
.37254 .50168 .37862 .50785 .38863 .50504 .38257 .49891 Mtetra
.64 .74 .921 r
.38257 .49891 .38863 .50504 .39868 .50225 .39264 .49606 Mtetra
.634 .737 .922 r
.39264 .49606 .39868 .50225 .40875 .49984 .40275 .49335 Mtetra
.581 .709 .93 r
.40275 .49335 .40875 .49984 .41861 .5057 .41285 .49178 Mtetra
.751 .63 .725 r
.41285 .49178 .41861 .5057 .42918 .48984 .42331 .48055 Mtetra
.494 .585 .875 r
.42331 .48055 .42918 .48984 .43936 .48777 .43342 .48134 Mtetra
.632 .731 .919 r
.43342 .48134 .43936 .48777 .4496 .48485 .44368 .47864 Mtetra
.647 .744 .92 r
.44368 .47864 .4496 .48485 .45989 .48171 .45399 .47555 Mtetra
.652 .748 .92 r
.45399 .47555 .45989 .48171 .47022 .47846 .46434 .47232 Mtetra
.655 .751 .92 r
.46434 .47232 .47022 .47846 .48059 .47514 .47474 .469 Mtetra
.657 .752 .92 r
.47474 .469 .48059 .47514 .491 .47176 .48517 .46562 Mtetra
.658 .753 .92 r
.48517 .46562 .491 .47176 .50145 .46835 .49565 .46219 Mtetra
.659 .754 .92 r
.49565 .46219 .50145 .46835 .51194 .46492 .50617 .45874 Mtetra
.50617 .45874 .51194 .46492 .52247 .46147 .51672 .45527 Mtetra
.51672 .45527 .52247 .46147 .53304 .45802 .52732 .45179 Mtetra
.52732 .45179 .53304 .45802 .54365 .45456 .53796 .4483 Mtetra
.658 .753 .92 r
.53796 .4483 .54365 .45456 .5543 .45109 .54863 .44481 Mtetra
.54863 .44481 .5543 .45109 .56499 .44762 .55935 .44131 Mtetra
.55935 .44131 .56499 .44762 .57572 .44414 .57011 .4378 Mtetra
.57011 .4378 .57572 .44414 .58649 .44065 .58091 .43428 Mtetra
.58091 .43428 .58649 .44065 .59731 .43714 .59176 .43075 Mtetra
.59176 .43075 .59731 .43714 .60817 .43363 .60264 .42721 Mtetra
.657 .753 .92 r
.60264 .42721 .60817 .43363 .61907 .4301 .61357 .42366 Mtetra
.61357 .42366 .61907 .4301 .63001 .42656 .62454 .42009 Mtetra
.62454 .42009 .63001 .42656 .64099 .42301 .63555 .41651 Mtetra
.63555 .41651 .64099 .42301 .65202 .41945 .64661 .41292 Mtetra
.657 .752 .92 r
.64661 .41292 .65202 .41945 .66309 .41587 .65771 .40932 Mtetra
.65771 .40932 .66309 .41587 .6742 .41228 .66885 .40571 Mtetra
.66885 .40571 .6742 .41228 .68536 .40868 .68004 .40208 Mtetra
.68004 .40208 .68536 .40868 .69656 .40507 .69127 .39844 Mtetra
.69127 .39844 .69656 .40507 .70781 .40144 .70255 .39478 Mtetra
.70255 .39478 .70781 .40144 .7191 .3978 .71387 .39111 Mtetra
.71387 .39111 .7191 .3978 .73043 .39414 .72524 .38743 Mtetra
.72524 .38743 .73043 .39414 .74181 .39047 .73665 .38373 Mtetra
.73665 .38373 .74181 .39047 .75324 .38679 .74811 .38002 Mtetra
.74811 .38002 .75324 .38679 .76471 .38309 .75961 .3763 Mtetra
.75961 .3763 .76471 .38309 .77623 .37938 .77116 .37256 Mtetra
.77116 .37256 .77623 .37938 .78779 .37565 .78276 .3688 Mtetra
.78276 .3688 .78779 .37565 .7994 .37191 .7944 .36504 Mtetra
.7944 .36504 .7994 .37191 .81106 .36816 .80609 .36125 Mtetra
.80609 .36125 .81106 .36816 .82276 .36439 .81783 .35745 Mtetra
.81783 .35745 .82276 .36439 .83451 .3606 .82961 .35364 Mtetra
.82961 .35364 .83451 .3606 .84631 .3568 .84144 .34981 Mtetra
.84144 .34981 .84631 .3568 .85815 .35299 .85332 .34597 Mtetra
0 0 .307 r
.22613 .47281 .22647 .54596 .23574 .54555 .22937 .53909 Mtetra
.595 .706 .921 r
.22937 .53909 .23574 .54555 .24518 .54367 .23881 .53739 Mtetra
.587 .71 .928 r
.23881 .53739 .24518 .54367 .25448 .5441 .24828 .53581 Mtetra
.868 .715 .69 r
.24828 .53581 .25448 .5441 .26464 .53407 .2595 .51279 Mtetra
.084 .14 .624 r
.2595 .51279 .26464 .53407 .27411 .53319 .26781 .52675 Mtetra
.605 .712 .92 r
.26781 .52675 .27411 .53319 .28372 .53104 .27742 .52481 Mtetra
.61 .722 .925 r
.27742 .52481 .28372 .53104 .29333 .52959 .28708 .52273 Mtetra
.301 .561 .928 r
.28708 .52273 .29333 .52959 .30371 .51699 .29648 .52518 Mtetra
.547 .825 .476 r
.29648 .52518 .30371 .51699 .31308 .52013 .30688 .5132 Mtetra
.586 .691 .915 r
.30688 .5132 .31308 .52013 .32285 .51792 .31662 .51168 Mtetra
.625 .729 .921 r
.31662 .51168 .32285 .51792 .33267 .51546 .32646 .50922 Mtetra
.619 .728 .924 r
.32646 .50922 .33267 .51546 .34249 .51367 .33634 .50688 Mtetra
.435 .634 .939 r
.33634 .50688 .34249 .51367 .35311 .49748 .34608 .50777 Mtetra
0 0 0 r
.34608 .50777 .35311 .49748 .36257 .50402 .35648 .49684 Mtetra
.582 .684 .911 r
.35648 .49684 .36257 .50402 .37254 .50168 .36642 .49539 Mtetra
.632 .733 .92 r
.36642 .49539 .37254 .50168 .38257 .49891 .37647 .49272 Mtetra
.64 .74 .921 r
.37647 .49272 .38257 .49891 .39264 .49606 .38656 .48985 Mtetra
.638 .739 .922 r
.38656 .48985 .39264 .49606 .40275 .49335 .39669 .48701 Mtetra
.622 .73 .924 r
.39669 .48701 .40275 .49335 .41285 .49178 .40685 .48455 Mtetra
.003 .363 .834 r
.40685 .48455 .41285 .49178 .42331 .48055 .41678 .49039 Mtetra
0 0 0 r
.41678 .49039 .42331 .48055 .43342 .48134 .42745 .47441 Mtetra
.608 .707 .915 r
.42745 .47441 .43342 .48134 .44368 .47864 .43772 .4723 Mtetra
.642 .74 .92 r
.43772 .4723 .44368 .47864 .45399 .47555 .44805 .46932 Mtetra
.65 .747 .92 r
.44805 .46932 .45399 .47555 .46434 .47232 .45843 .46611 Mtetra
.654 .75 .92 r
.45843 .46611 .46434 .47232 .47474 .469 .46885 .4628 Mtetra
.656 .751 .92 r
.46885 .4628 .47474 .469 .48517 .46562 .47931 .45942 Mtetra
.658 .753 .92 r
.47931 .45942 .48517 .46562 .49565 .46219 .48981 .45599 Mtetra
.659 .753 .92 r
.48981 .45599 .49565 .46219 .50617 .45874 .50035 .45252 Mtetra
.659 .754 .92 r
.50035 .45252 .50617 .45874 .51672 .45527 .51094 .44902 Mtetra
.51094 .44902 .51672 .45527 .52732 .45179 .52156 .44552 Mtetra
.52156 .44552 .52732 .45179 .53796 .4483 .53222 .442 Mtetra
.658 .753 .92 r
.53222 .442 .53796 .4483 .54863 .44481 .54293 .43848 Mtetra
.54293 .43848 .54863 .44481 .55935 .44131 .55367 .43495 Mtetra
.55367 .43495 .55935 .44131 .57011 .4378 .56446 .43141 Mtetra
.56446 .43141 .57011 .4378 .58091 .43428 .57529 .42787 Mtetra
.57529 .42787 .58091 .43428 .59176 .43075 .58616 .42431 Mtetra
.58616 .42431 .59176 .43075 .60264 .42721 .59708 .42074 Mtetra
.59708 .42074 .60264 .42721 .61357 .42366 .60803 .41716 Mtetra
.657 .753 .92 r
.60803 .41716 .61357 .42366 .62454 .42009 .61903 .41357 Mtetra
.61903 .41357 .62454 .42009 .63555 .41651 .63008 .40997 Mtetra
.63008 .40997 .63555 .41651 .64661 .41292 .64116 .40635 Mtetra
.657 .752 .92 r
.64116 .40635 .64661 .41292 .65771 .40932 .65229 .40272 Mtetra
.65229 .40272 .65771 .40932 .66885 .40571 .66347 .39908 Mtetra
.66347 .39908 .66885 .40571 .68004 .40208 .67469 .39543 Mtetra
.67469 .39543 .68004 .40208 .69127 .39844 .68595 .39176 Mtetra
.68595 .39176 .69127 .39844 .70255 .39478 .69726 .38808 Mtetra
.69726 .38808 .70255 .39478 .71387 .39111 .70861 .38438 Mtetra
.70861 .38438 .71387 .39111 .72524 .38743 .72001 .38067 Mtetra
.72001 .38067 .72524 .38743 .73665 .38373 .73145 .37694 Mtetra
.73145 .37694 .73665 .38373 .74811 .38002 .74294 .37321 Mtetra
.74294 .37321 .74811 .38002 .75961 .3763 .75448 .36945 Mtetra
.75448 .36945 .75961 .3763 .77116 .37256 .76606 .36569 Mtetra
.76606 .36569 .77116 .37256 .78276 .3688 .77769 .3619 Mtetra
.77769 .3619 .78276 .3688 .7944 .36504 .78936 .35811 Mtetra
.78936 .35811 .7944 .36504 .80609 .36125 .80109 .35429 Mtetra
.80109 .35429 .80609 .36125 .81783 .35745 .81286 .35047 Mtetra
.81286 .35047 .81783 .35745 .82961 .35364 .82468 .34663 Mtetra
.82468 .34663 .82961 .35364 .84144 .34981 .83654 .34277 Mtetra
.83654 .34277 .84144 .34981 .85332 .34597 .84846 .3389 Mtetra
.468 .219 .453 r
.2129 .54126 .22613 .47281 .22937 .53909 .22305 .53154 Mtetra
.537 .65 .907 r
.22305 .53154 .22937 .53909 .23881 .53739 .23239 .53109 Mtetra
.603 .716 .924 r
.23239 .53109 .23881 .53739 .24828 .53581 .24191 .52916 Mtetra
.466 .651 .94 r
.24191 .52916 .24828 .53581 .2595 .51279 .25128 .52955 Mtetra
.116 0 .104 r
.25128 .52955 .2595 .51279 .26781 .52675 .26153 .51944 Mtetra
.559 .668 .911 r
.26153 .51944 .26781 .52675 .27742 .52481 .27107 .51851 Mtetra
.614 .722 .923 r
.27107 .51851 .27742 .52481 .28708 .52273 .28076 .51632 Mtetra
.58 .707 .93 r
.28076 .51632 .28708 .52273 .29648 .52518 .29044 .51481 Mtetra
.795 .683 .741 r
.29044 .51481 .29648 .52518 .30688 .5132 .30092 .50212 Mtetra
.392 .486 .836 r
.30092 .50212 .30688 .5132 .31662 .51168 .31037 .50523 Mtetra
.616 .72 .92 r
.31037 .50523 .31662 .51168 .32646 .50922 .32021 .50297 Mtetra
.626 .731 .922 r
.32021 .50297 .32646 .50922 .33634 .50688 .33011 .50046 Mtetra
.595 .715 .928 r
.33011 .50046 .33634 .50688 .34608 .50777 .34002 .49862 Mtetra
.837 .712 .726 r
.34002 .49862 .34608 .50777 .35648 .49684 .35073 .48231 Mtetra
.291 .362 .764 r
.35073 .48231 .35648 .49684 .36642 .49539 .36027 .48884 Mtetra
.62 .721 .919 r
.36027 .48884 .36642 .49539 .37647 .49272 .37032 .48645 Mtetra
.638 .738 .921 r
.37032 .48645 .37647 .49272 .38656 .48985 .38043 .48362 Mtetra
.64 .74 .921 r
.38043 .48362 .38656 .48985 .39669 .48701 .39059 .48071 Mtetra
.634 .737 .922 r
.39059 .48071 .39669 .48701 .40685 .48455 .40078 .47794 Mtetra
.581 .709 .93 r
.40078 .47794 .40685 .48455 .41678 .49039 .41098 .47633 Mtetra
.751 .63 .726 r
.41098 .47633 .41678 .49039 .42745 .47441 .42152 .465 Mtetra
.493 .585 .875 r
.42152 .465 .42745 .47441 .43772 .4723 .43172 .46575 Mtetra
.632 .731 .919 r
.43172 .46575 .43772 .4723 .44805 .46932 .44207 .46299 Mtetra
.647 .744 .92 r
.44207 .46299 .44805 .46932 .45843 .46611 .45247 .45984 Mtetra
.652 .748 .92 r
.45247 .45984 .45843 .46611 .46885 .4628 .46291 .45655 Mtetra
.655 .751 .92 r
.46291 .45655 .46885 .4628 .47931 .45942 .4734 .45317 Mtetra
.657 .752 .92 r
.4734 .45317 .47931 .45942 .48981 .45599 .48393 .44973 Mtetra
.658 .753 .92 r
.48393 .44973 .48981 .45599 .50035 .45252 .4945 .44625 Mtetra
.659 .754 .92 r
.4945 .44625 .50035 .45252 .51094 .44902 .50511 .44273 Mtetra
.50511 .44273 .51094 .44902 .52156 .44552 .51576 .4392 Mtetra
.51576 .4392 .52156 .44552 .53222 .442 .52645 .43566 Mtetra
.52645 .43566 .53222 .442 .54293 .43848 .53718 .43211 Mtetra
.658 .753 .92 r
.53718 .43211 .54293 .43848 .55367 .43495 .54795 .42855 Mtetra
.54795 .42855 .55367 .43495 .56446 .43141 .55877 .42498 Mtetra
.55877 .42498 .56446 .43141 .57529 .42787 .56963 .42141 Mtetra
.56963 .42141 .57529 .42787 .58616 .42431 .58053 .41783 Mtetra
.58053 .41783 .58616 .42431 .59708 .42074 .59147 .41423 Mtetra
.59147 .41423 .59708 .42074 .60803 .41716 .60246 .41063 Mtetra
.657 .753 .92 r
.60246 .41063 .60803 .41716 .61903 .41357 .61349 .40701 Mtetra
.61349 .40701 .61903 .41357 .63008 .40997 .62456 .40338 Mtetra
.62456 .40338 .63008 .40997 .64116 .40635 .63567 .39973 Mtetra
.63567 .39973 .64116 .40635 .65229 .40272 .64684 .39608 Mtetra
.657 .752 .92 r
.64684 .39608 .65229 .40272 .66347 .39908 .65804 .39241 Mtetra
.65804 .39241 .66347 .39908 .67469 .39543 .66929 .38873 Mtetra
.66929 .38873 .67469 .39543 .68595 .39176 .68058 .38503 Mtetra
.68058 .38503 .68595 .39176 .69726 .38808 .69192 .38132 Mtetra
.69192 .38132 .69726 .38808 .70861 .38438 .70331 .3776 Mtetra
.70331 .3776 .70861 .38438 .72001 .38067 .71474 .37386 Mtetra
.71474 .37386 .72001 .38067 .73145 .37694 .72621 .3701 Mtetra
.72621 .3701 .73145 .37694 .74294 .37321 .73773 .36634 Mtetra
.73773 .36634 .74294 .37321 .75448 .36945 .7493 .36256 Mtetra
.7493 .36256 .75448 .36945 .76606 .36569 .76092 .35876 Mtetra
.76092 .35876 .76606 .36569 .77769 .3619 .77258 .35495 Mtetra
.77258 .35495 .77769 .3619 .78936 .35811 .78429 .35113 Mtetra
.78429 .35113 .78936 .35811 .80109 .35429 .79605 .34728 Mtetra
.79605 .34728 .80109 .35429 .81286 .35047 .80785 .34343 Mtetra
.80785 .34343 .81286 .35047 .82468 .34663 .81971 .33956 Mtetra
.81971 .33956 .82468 .34663 .83654 .34277 .83161 .33567 Mtetra
.83161 .33567 .83654 .34277 .84846 .3389 .84356 .33177 Mtetra
.918 .702 .593 r
.20654 .53342 .2129 .54126 .22305 .53154 .22277 .45802 Mtetra
0 0 .302 r
.22277 .45802 .22305 .53154 .23239 .53109 .22596 .52452 Mtetra
.595 .706 .921 r
.22596 .52452 .23239 .53109 .24191 .52916 .23547 .52278 Mtetra
.587 .71 .928 r
.23547 .52278 .24191 .52916 .25128 .52955 .24502 .52115 Mtetra
.869 .716 .69 r
.24502 .52115 .25128 .52955 .26153 .51944 .25635 .498 Mtetra
.08 .137 .623 r
.25635 .498 .26153 .51944 .27107 .51851 .26471 .51197 Mtetra
.605 .712 .92 r
.26471 .51197 .27107 .51851 .28076 .51632 .27439 .50998 Mtetra
.61 .722 .925 r
.27439 .50998 .28076 .51632 .29044 .51481 .28414 .50785 Mtetra
.303 .562 .927 r
.28414 .50785 .29044 .51481 .30092 .50212 .2936 .51027 Mtetra
.559 .835 .488 r
.2936 .51027 .30092 .50212 .31037 .50523 .3041 .49819 Mtetra
.585 .691 .915 r
.3041 .49819 .31037 .50523 .32021 .50297 .31392 .49662 Mtetra
.625 .729 .921 r
.31392 .49662 .32021 .50297 .33011 .50046 .32384 .49412 Mtetra
.619 .728 .924 r
.32384 .49412 .33011 .50046 .34002 .49862 .3338 .49172 Mtetra
.436 .634 .938 r
.3338 .49172 .34002 .49862 .35073 .48231 .34362 .49257 Mtetra
0 0 0 r
.34362 .49257 .35073 .48231 .36027 .48884 .35412 .48155 Mtetra
.582 .684 .911 r
.35412 .48155 .36027 .48884 .37032 .48645 .36414 .48005 Mtetra
.632 .733 .92 r
.36414 .48005 .37032 .48645 .38043 .48362 .37427 .47732 Mtetra
.64 .74 .921 r
.37427 .47732 .38043 .48362 .39059 .48071 .38445 .4744 Mtetra
.638 .739 .922 r
.38445 .4744 .39059 .48071 .40078 .47794 .39467 .4715 Mtetra
.622 .73 .924 r
.39467 .4715 .40078 .47794 .41098 .47633 .40491 .46898 Mtetra
.008 .366 .835 r
.40491 .46898 .41098 .47633 .42152 .465 .41492 .4748 Mtetra
.592 .805 .398 r
.41492 .4748 .42152 .465 .43172 .46575 .42569 .45871 Mtetra
.608 .707 .915 r
.42569 .45871 .43172 .46575 .44207 .46299 .43605 .45654 Mtetra
.642 .74 .92 r
.43605 .45654 .44207 .46299 .45247 .45984 .44647 .4535 Mtetra
.65 .747 .92 r
.44647 .4535 .45247 .45984 .46291 .45655 .45694 .45024 Mtetra
.654 .75 .92 r
.45694 .45024 .46291 .45655 .4734 .45317 .46745 .44687 Mtetra
.656 .751 .92 r
.46745 .44687 .4734 .45317 .48393 .44973 .47801 .44342 Mtetra
.658 .753 .92 r
.47801 .44342 .48393 .44973 .4945 .44625 .4886 .43993 Mtetra
.659 .753 .92 r
.4886 .43993 .4945 .44625 .50511 .44273 .49924 .43639 Mtetra
.659 .754 .92 r
.49924 .43639 .50511 .44273 .51576 .4392 .50991 .43284 Mtetra
.50991 .43284 .51576 .4392 .52645 .43566 .52063 .42927 Mtetra
.52063 .42927 .52645 .43566 .53718 .43211 .53139 .42569 Mtetra
.658 .753 .92 r
.53139 .42569 .53718 .43211 .54795 .42855 .54219 .4221 Mtetra
.54219 .4221 .54795 .42855 .55877 .42498 .55304 .41851 Mtetra
.55304 .41851 .55877 .42498 .56963 .42141 .56392 .41491 Mtetra
.56392 .41491 .56963 .42141 .58053 .41783 .57485 .41129 Mtetra
.57485 .41129 .58053 .41783 .59147 .41423 .58583 .40767 Mtetra
.58583 .40767 .59147 .41423 .60246 .41063 .59684 .40404 Mtetra
.59684 .40404 .60246 .41063 .61349 .40701 .6079 .40039 Mtetra
.657 .753 .92 r
.6079 .40039 .61349 .40701 .62456 .40338 .619 .39674 Mtetra
.619 .39674 .62456 .40338 .63567 .39973 .63015 .39307 Mtetra
.63015 .39307 .63567 .39973 .64684 .39608 .64134 .38938 Mtetra
.657 .752 .92 r
.64134 .38938 .64684 .39608 .65804 .39241 .65257 .38569 Mtetra
.65257 .38569 .65804 .39241 .66929 .38873 .66385 .38198 Mtetra
.66385 .38198 .66929 .38873 .68058 .38503 .67518 .37825 Mtetra
.67518 .37825 .68058 .38503 .69192 .38132 .68655 .37451 Mtetra
.68655 .37451 .69192 .38132 .70331 .3776 .69796 .37076 Mtetra
.69796 .37076 .70331 .3776 .71474 .37386 .70942 .367 Mtetra
.70942 .367 .71474 .37386 .72621 .3701 .72093 .36321 Mtetra
.72093 .36321 .72621 .3701 .73773 .36634 .73249 .35942 Mtetra
.73249 .35942 .73773 .36634 .7493 .36256 .74409 .35561 Mtetra
.74409 .35561 .7493 .36256 .76092 .35876 .75574 .35179 Mtetra
.75574 .35179 .76092 .35876 .77258 .35495 .76743 .34795 Mtetra
.76743 .34795 .77258 .35495 .78429 .35113 .77918 .34409 Mtetra
.77918 .34409 .78429 .35113 .79605 .34728 .79097 .34022 Mtetra
.79097 .34022 .79605 .34728 .80785 .34343 .80281 .33634 Mtetra
.80281 .33634 .80785 .34343 .81971 .33956 .8147 .33244 Mtetra
.8147 .33244 .81971 .33956 .83161 .33567 .82663 .32852 Mtetra
.82663 .32852 .83161 .33567 .84356 .33177 .83862 .32459 Mtetra
.498 .667 .938 r
.20003 .52678 .20654 .53342 .22277 .45802 .20934 .52667 Mtetra
.463 .213 .449 r
.20934 .52667 .22277 .45802 .22596 .52452 .21958 .51687 Mtetra
.537 .65 .907 r
.21958 .51687 .22596 .52452 .23547 .52278 .22899 .51637 Mtetra
.603 .716 .924 r
.22899 .51637 .23547 .52278 .24502 .52115 .23858 .5144 Mtetra
.467 .651 .939 r
.23858 .5144 .24502 .52115 .25635 .498 .24802 .51474 Mtetra
.104 0 .091 r
.24802 .51474 .25635 .498 .26471 .51197 .25836 .50455 Mtetra
.559 .668 .911 r
.25836 .50455 .26471 .51197 .27439 .50998 .26799 .50358 Mtetra
.614 .722 .923 r
.26799 .50358 .27439 .50998 .28414 .50785 .27775 .50133 Mtetra
.58 .707 .93 r
.27775 .50133 .28414 .50785 .2936 .51027 .28751 .49978 Mtetra
.795 .683 .741 r
.28751 .49978 .2936 .51027 .3041 .49819 .29809 .48699 Mtetra
.391 .486 .836 r
.29809 .48699 .3041 .49819 .31392 .49662 .3076 .49007 Mtetra
.616 .72 .92 r
.3076 .49007 .31392 .49662 .32384 .49412 .31753 .48775 Mtetra
.626 .731 .922 r
.31753 .48775 .32384 .49412 .3338 .49172 .32751 .48519 Mtetra
.595 .715 .928 r
.32751 .48519 .3338 .49172 .34362 .49257 .3375 .4833 Mtetra
.838 .713 .726 r
.3375 .4833 .34362 .49257 .35412 .48155 .34832 .46687 Mtetra
.289 .361 .764 r
.34832 .46687 .35412 .48155 .36414 .48005 .35793 .47339 Mtetra
.62 .722 .919 r
.35793 .47339 .36414 .48005 .37427 .47732 .36806 .47094 Mtetra
.638 .738 .921 r
.36806 .47094 .37427 .47732 .38445 .4744 .37826 .46805 Mtetra
.64 .74 .921 r
.37826 .46805 .38445 .4744 .39467 .4715 .3885 .46509 Mtetra
.634 .737 .922 r
.3885 .46509 .39467 .4715 .40491 .46898 .39878 .46226 Mtetra
.582 .708 .93 r
.39878 .46226 .40491 .46898 .41492 .4748 .40906 .46059 Mtetra
.752 .631 .726 r
.40906 .46059 .41492 .4748 .42569 .45871 .41971 .44918 Mtetra
.493 .585 .875 r
.41971 .44918 .42569 .45871 .43605 .45654 .42999 .44988 Mtetra
.632 .731 .919 r
.42999 .44988 .43605 .45654 .44647 .4535 .44043 .44706 Mtetra
.647 .744 .92 r
.44043 .44706 .44647 .4535 .45694 .45024 .45092 .44385 Mtetra
.652 .748 .92 r
.45092 .44385 .45694 .45024 .46745 .44687 .46146 .4405 Mtetra
.655 .751 .92 r
.46146 .4405 .46745 .44687 .47801 .44342 .47204 .43706 Mtetra
.657 .752 .92 r
.47204 .43706 .47801 .44342 .4886 .43993 .48266 .43356 Mtetra
.658 .753 .92 r
.48266 .43356 .4886 .43993 .49924 .43639 .49332 .43001 Mtetra
.659 .754 .92 r
.49332 .43001 .49924 .43639 .50991 .43284 .50403 .42643 Mtetra
.50403 .42643 .50991 .43284 .52063 .42927 .51477 .42283 Mtetra
.51477 .42283 .52063 .42927 .53139 .42569 .52556 .41922 Mtetra
.52556 .41922 .53139 .42569 .54219 .4221 .53639 .41561 Mtetra
.658 .753 .92 r
.53639 .41561 .54219 .4221 .55304 .41851 .54726 .41199 Mtetra
.54726 .41199 .55304 .41851 .56392 .41491 .55818 .40836 Mtetra
.55818 .40836 .56392 .41491 .57485 .41129 .56914 .40472 Mtetra
.56914 .40472 .57485 .41129 .58583 .40767 .58014 .40107 Mtetra
.58014 .40107 .58583 .40767 .59684 .40404 .59118 .39741 Mtetra
.59118 .39741 .59684 .40404 .6079 .40039 .60227 .39373 Mtetra
.657 .753 .92 r
.60227 .39373 .6079 .40039 .619 .39674 .6134 .39005 Mtetra
.6134 .39005 .619 .39674 .63015 .39307 .62458 .38635 Mtetra
.62458 .38635 .63015 .39307 .64134 .38938 .6358 .38264 Mtetra
.6358 .38264 .64134 .38938 .65257 .38569 .64706 .37891 Mtetra
.657 .752 .92 r
.64706 .37891 .65257 .38569 .66385 .38198 .65837 .37517 Mtetra
.65837 .37517 .66385 .38198 .67518 .37825 .66973 .37142 Mtetra
.66973 .37142 .67518 .37825 .68655 .37451 .68113 .36766 Mtetra
.68113 .36766 .68655 .37451 .69796 .37076 .69258 .36388 Mtetra
.69258 .36388 .69796 .37076 .70942 .367 .70407 .36008 Mtetra
.70407 .36008 .70942 .367 .72093 .36321 .71561 .35627 Mtetra
.71561 .35627 .72093 .36321 .73249 .35942 .7272 .35245 Mtetra
.7272 .35245 .73249 .35942 .74409 .35561 .73884 .34861 Mtetra
.73884 .34861 .74409 .35561 .75574 .35179 .75052 .34476 Mtetra
.75052 .34476 .75574 .35179 .76743 .34795 .76225 .34089 Mtetra
.76225 .34089 .76743 .34795 .77918 .34409 .77402 .337 Mtetra
.77402 .337 .77918 .34409 .79097 .34022 .78585 .3331 Mtetra
.78585 .3331 .79097 .34022 .80281 .33634 .79772 .32919 Mtetra
.79772 .32919 .80281 .33634 .8147 .33244 .80965 .32526 Mtetra
.80965 .32526 .8147 .33244 .82663 .32852 .82162 .32131 Mtetra
.82162 .32131 .82663 .32852 .83862 .32459 .83364 .31735 Mtetra
.584 .707 .928 r
.19346 .52031 .20003 .52678 .20934 .52667 .20291 .51873 Mtetra
.919 .702 .592 r
.20291 .51873 .20934 .52667 .21958 .51687 .21935 .44297 Mtetra
0 0 .296 r
.21935 .44297 .21958 .51687 .22899 .51637 .22249 .50971 Mtetra
.595 .706 .921 r
.22249 .50971 .22899 .51637 .23858 .5144 .23208 .50791 Mtetra
.587 .71 .928 r
.23208 .50791 .23858 .5144 .24802 .51474 .2417 .50624 Mtetra
.87 .717 .69 r
.2417 .50624 .24802 .51474 .25836 .50455 .25314 .48294 Mtetra
.075 .134 .621 r
.25314 .48294 .25836 .50455 .26799 .50358 .26155 .49693 Mtetra
.605 .712 .92 r
.26155 .49693 .26799 .50358 .27775 .50133 .27132 .49489 Mtetra
.61 .722 .925 r
.27132 .49489 .27775 .50133 .28751 .49978 .28114 .4927 Mtetra
.305 .562 .927 r
.28114 .4927 .28751 .49978 .29809 .48699 .29068 .49509 Mtetra
.571 .844 .5 r
.29068 .49509 .29809 .48699 .3076 .49007 .30128 .48292 Mtetra
.585 .691 .915 r
.30128 .48292 .3076 .49007 .31753 .48775 .31117 .4813 Mtetra
.625 .729 .921 r
.31117 .4813 .31753 .48775 .32751 .48519 .32118 .47874 Mtetra
.619 .728 .924 r
.32118 .47874 .32751 .48519 .3375 .4833 .33122 .47629 Mtetra
.437 .634 .938 r
.33122 .47629 .3375 .4833 .34832 .46687 .34112 .47709 Mtetra
0 0 0 r
.34112 .47709 .34832 .46687 .35793 .47339 .35171 .46598 Mtetra
.582 .685 .912 r
.35171 .46598 .35793 .47339 .36806 .47094 .36182 .46443 Mtetra
.632 .733 .92 r
.36182 .46443 .36806 .47094 .37826 .46805 .37203 .46165 Mtetra
.64 .74 .921 r
.37203 .46165 .37826 .46805 .3885 .46509 .3823 .45867 Mtetra
.638 .739 .922 r
.3823 .45867 .3885 .46509 .39878 .46226 .3926 .4557 Mtetra
.622 .73 .924 r
.3926 .4557 .39878 .46226 .40906 .46059 .40294 .45313 Mtetra
.013 .368 .837 r
.40294 .45313 .40906 .46059 .41971 .44918 .41303 .45893 Mtetra
.603 .813 .408 r
.41303 .45893 .41971 .44918 .42999 .44988 .42391 .44273 Mtetra
.608 .707 .915 r
.42391 .44273 .42999 .44988 .44043 .44706 .43435 .4405 Mtetra
.642 .74 .92 r
.43435 .4405 .44043 .44706 .45092 .44385 .44486 .43739 Mtetra
.65 .747 .92 r
.44486 .43739 .45092 .44385 .46146 .4405 .45542 .43407 Mtetra
.654 .75 .92 r
.45542 .43407 .46146 .4405 .47204 .43706 .46603 .43064 Mtetra
.656 .751 .92 r
.46603 .43064 .47204 .43706 .48266 .43356 .47668 .42713 Mtetra
.658 .753 .92 r
.47668 .42713 .48266 .43356 .49332 .43001 .48737 .42357 Mtetra
.659 .753 .92 r
.48737 .42357 .49332 .43001 .50403 .42643 .4981 .41997 Mtetra
.659 .754 .92 r
.4981 .41997 .50403 .42643 .51477 .42283 .50887 .41635 Mtetra
.50887 .41635 .51477 .42283 .52556 .41922 .51969 .41271 Mtetra
.51969 .41271 .52556 .41922 .53639 .41561 .53055 .40907 Mtetra
.658 .753 .92 r
.53055 .40907 .53639 .41561 .54726 .41199 .54145 .40542 Mtetra
.54145 .40542 .54726 .41199 .55818 .40836 .55239 .40176 Mtetra
.55239 .40176 .55818 .40836 .56914 .40472 .56338 .39809 Mtetra
.56338 .39809 .56914 .40472 .58014 .40107 .57441 .39441 Mtetra
.57441 .39441 .58014 .40107 .59118 .39741 .58548 .39072 Mtetra
.58548 .39072 .59118 .39741 .60227 .39373 .5966 .38702 Mtetra
.5966 .38702 .60227 .39373 .6134 .39005 .60776 .38331 Mtetra
.657 .753 .92 r
.60776 .38331 .6134 .39005 .62458 .38635 .61897 .37958 Mtetra
.61897 .37958 .62458 .38635 .6358 .38264 .63022 .37584 Mtetra
.63022 .37584 .6358 .38264 .64706 .37891 .64151 .37209 Mtetra
.657 .752 .92 r
.64151 .37209 .64706 .37891 .65837 .37517 .65286 .36832 Mtetra
.65286 .36832 .65837 .37517 .66973 .37142 .66424 .36454 Mtetra
.66424 .36454 .66973 .37142 .68113 .36766 .67568 .36075 Mtetra
.67568 .36075 .68113 .36766 .69258 .36388 .68716 .35694 Mtetra
.68716 .35694 .69258 .36388 .70407 .36008 .69868 .35312 Mtetra
.69868 .35312 .70407 .36008 .71561 .35627 .71026 .34928 Mtetra
.71026 .34928 .71561 .35627 .7272 .35245 .72188 .34543 Mtetra
.72188 .34543 .7272 .35245 .73884 .34861 .73354 .34156 Mtetra
.73354 .34156 .73884 .34861 .75052 .34476 .74526 .33767 Mtetra
.74526 .33767 .75052 .34476 .76225 .34089 .75702 .33378 Mtetra
.75702 .33378 .76225 .34089 .77402 .337 .76883 .32986 Mtetra
.76883 .32986 .77402 .337 .78585 .3331 .78069 .32593 Mtetra
.78069 .32593 .78585 .3331 .79772 .32919 .7926 .32199 Mtetra
.7926 .32199 .79772 .32919 .80965 .32526 .80456 .31803 Mtetra
.80456 .31803 .80965 .32526 .82162 .32131 .81657 .31405 Mtetra
.81657 .31405 .82162 .32131 .83364 .31735 .82863 .31006 Mtetra
.591 .706 .923 r
.18685 .51371 .19346 .52031 .20291 .51873 .19633 .51198 Mtetra
.498 .667 .938 r
.19633 .51198 .20291 .51873 .21935 .44297 .20571 .51182 Mtetra
.459 .207 .444 r
.20571 .51182 .21935 .44297 .22249 .50971 .21604 .50194 Mtetra
.537 .65 .907 r
.21604 .50194 .22249 .50971 .23208 .50791 .22553 .5014 Mtetra
.603 .716 .924 r
.22553 .5014 .23208 .50791 .2417 .50624 .23519 .49937 Mtetra
.467 .651 .939 r
.23519 .49937 .2417 .50624 .25314 .48294 .24471 .49968 Mtetra
.091 0 .078 r
.24471 .49968 .25314 .48294 .26155 .49693 .25514 .4894 Mtetra
.559 .668 .911 r
.25514 .4894 .26155 .49693 .27132 .49489 .26484 .48838 Mtetra
.614 .722 .923 r
.26484 .48838 .27132 .49489 .28114 .4927 .27469 .48608 Mtetra
.58 .707 .93 r
.27469 .48608 .28114 .4927 .29068 .49509 .28453 .48447 Mtetra
.796 .684 .741 r
.28453 .48447 .29068 .49509 .30128 .48292 .2952 .47159 Mtetra
.39 .485 .836 r
.2952 .47159 .30128 .48292 .31117 .4813 .30479 .47464 Mtetra
.616 .72 .92 r
.30479 .47464 .31117 .4813 .32118 .47874 .3148 .47226 Mtetra
.626 .731 .922 r
.3148 .47226 .32118 .47874 .33122 .47629 .32487 .46964 Mtetra
.595 .715 .928 r
.32487 .46964 .33122 .47629 .34112 .47709 .33494 .4677 Mtetra
.838 .713 .726 r
.33494 .4677 .34112 .47709 .35171 .46598 .34585 .45116 Mtetra
.287 .36 .764 r
.34585 .45116 .35171 .46598 .36182 .46443 .35554 .45766 Mtetra
.62 .722 .919 r
.35554 .45766 .36182 .46443 .37203 .46165 .36576 .45515 Mtetra
.638 .738 .921 r
.36576 .45515 .37203 .46165 .3823 .45867 .37605 .45221 Mtetra
.64 .74 .921 r
.37605 .45221 .3823 .45867 .3926 .4557 .38638 .44918 Mtetra
.634 .737 .922 r
.38638 .44918 .3926 .4557 .40294 .45313 .39675 .4463 Mtetra
.582 .708 .93 r
.39675 .4463 .40294 .45313 .41303 .45893 .40712 .44457 Mtetra
.752 .631 .726 r
.40712 .44457 .41303 .45893 .42391 .44273 .41786 .43306 Mtetra
.492 .585 .875 r
.41786 .43306 .42391 .44273 .43435 .4405 .42823 .43372 Mtetra
.632 .731 .919 r
.42823 .43372 .43435 .4405 .44486 .43739 .43876 .43084 Mtetra
.647 .744 .92 r
.43876 .43084 .44486 .43739 .45542 .43407 .44935 .42757 Mtetra
.652 .748 .92 r
.44935 .42757 .45542 .43407 .46603 .43064 .45998 .42415 Mtetra
.655 .751 .92 r
.45998 .42415 .46603 .43064 .47668 .42713 .47065 .42065 Mtetra
.657 .752 .92 r
.47065 .42065 .47668 .42713 .48737 .42357 .48137 .41708 Mtetra
.658 .753 .92 r
.48137 .41708 .48737 .42357 .4981 .41997 .49213 .41347 Mtetra
.659 .754 .92 r
.49213 .41347 .4981 .41997 .50887 .41635 .50293 .40982 Mtetra
.50293 .40982 .50887 .41635 .51969 .41271 .51377 .40616 Mtetra
.51377 .40616 .51969 .41271 .53055 .40907 .52466 .40249 Mtetra
.52466 .40249 .53055 .40907 .54145 .40542 .53559 .3988 Mtetra
.658 .753 .92 r
.53559 .3988 .54145 .40542 .55239 .40176 .54656 .39512 Mtetra
.54656 .39512 .55239 .40176 .56338 .39809 .55758 .39142 Mtetra
.55758 .39142 .56338 .39809 .57441 .39441 .56864 .38771 Mtetra
.56864 .38771 .57441 .39441 .58548 .39072 .57974 .38399 Mtetra
.57974 .38399 .58548 .39072 .5966 .38702 .59089 .38026 Mtetra
.59089 .38026 .5966 .38702 .60776 .38331 .60208 .37652 Mtetra
.657 .753 .92 r
.60208 .37652 .60776 .38331 .61897 .37958 .61331 .37277 Mtetra
.61331 .37277 .61897 .37958 .63022 .37584 .6246 .369 Mtetra
.6246 .369 .63022 .37584 .64151 .37209 .63592 .36522 Mtetra
.63592 .36522 .64151 .37209 .65286 .36832 .6473 .36142 Mtetra
.657 .752 .92 r
.6473 .36142 .65286 .36832 .66424 .36454 .65872 .35761 Mtetra
.65872 .35761 .66424 .36454 .67568 .36075 .67018 .35379 Mtetra
.67018 .35379 .67568 .36075 .68716 .35694 .68169 .34995 Mtetra
.68169 .34995 .68716 .35694 .69868 .35312 .69325 .3461 Mtetra
.69325 .3461 .69868 .35312 .71026 .34928 .70486 .34223 Mtetra
.70486 .34223 .71026 .34928 .72188 .34543 .71651 .33835 Mtetra
.71651 .33835 .72188 .34543 .73354 .34156 .72821 .33445 Mtetra
.72821 .33445 .73354 .34156 .74526 .33767 .73996 .33054 Mtetra
.73996 .33054 .74526 .33767 .75702 .33378 .75176 .32661 Mtetra
.75176 .32661 .75702 .33378 .76883 .32986 .7636 .32267 Mtetra
.7636 .32267 .76883 .32986 .78069 .32593 .7755 .31871 Mtetra
.7755 .31871 .78069 .32593 .7926 .32199 .78744 .31473 Mtetra
.78744 .31473 .7926 .32199 .80456 .31803 .79944 .31074 Mtetra
.79944 .31074 .80456 .31803 .81657 .31405 .81148 .30674 Mtetra
.81148 .30674 .81657 .31405 .82863 .31006 .82357 .30271 Mtetra
.557 .672 .915 r
.18027 .50641 .18685 .51371 .19633 .51198 .18969 .50541 Mtetra
.584 .707 .928 r
.18969 .50541 .19633 .51198 .20571 .51182 .19922 .50377 Mtetra
.921 .703 .591 r
.19922 .50377 .20571 .51182 .21604 .50194 .21587 .42766 Mtetra
0 0 .29 r
.21587 .42766 .21604 .50194 .22553 .5014 .21895 .49462 Mtetra
.595 .706 .921 r
.21895 .49462 .22553 .5014 .23519 .49937 .22862 .49278 Mtetra
.587 .71 .928 r
.22862 .49278 .23519 .49937 .24471 .49968 .23832 .49105 Mtetra
.871 .717 .689 r
.23832 .49105 .24471 .49968 .25514 .4894 .24988 .46762 Mtetra
.071 .131 .619 r
.24988 .46762 .25514 .4894 .26484 .48838 .25834 .48162 Mtetra
.605 .712 .92 r
.25834 .48162 .26484 .48838 .27469 .48608 .26819 .47953 Mtetra
.61 .722 .925 r
.26819 .47953 .27469 .48608 .28453 .48447 .27809 .47729 Mtetra
.306 .563 .927 r
.27809 .47729 .28453 .48447 .2952 .47159 .2877 .47964 Mtetra
.582 .853 .511 r
.2877 .47964 .2952 .47159 .30479 .47464 .2984 .46737 Mtetra
.585 .691 .915 r
.2984 .46737 .30479 .47464 .3148 .47226 .30838 .4657 Mtetra
.625 .729 .921 r
.30838 .4657 .3148 .47226 .32487 .46964 .31846 .46308 Mtetra
.619 .728 .924 r
.31846 .46308 .32487 .46964 .33494 .4677 .32859 .46058 Mtetra
.437 .634 .938 r
.32859 .46058 .33494 .4677 .34585 .45116 .33857 .46134 Mtetra
0 0 0 r
.33857 .46134 .34585 .45116 .35554 .45766 .34926 .45013 Mtetra
.581 .685 .912 r
.34926 .45013 .35554 .45766 .36576 .45515 .35945 .44853 Mtetra
.632 .733 .92 r
.35945 .44853 .36576 .45515 .37605 .45221 .36976 .44569 Mtetra
.64 .74 .921 r
.36976 .44569 .37605 .45221 .38638 .44918 .38011 .44264 Mtetra
.638 .739 .922 r
.38011 .44264 .38638 .44918 .39675 .4463 .39051 .43962 Mtetra
.622 .73 .924 r
.39051 .43962 .39675 .4463 .40712 .44457 .40093 .43699 Mtetra
.018 .371 .839 r
.40093 .43699 .40712 .44457 .41786 .43306 .41111 .44277 Mtetra
.612 .821 .418 r
.41111 .44277 .41786 .43306 .42823 .43372 .42208 .42644 Mtetra
.608 .707 .915 r
.42208 .42644 .42823 .43372 .43876 .43084 .43262 .42416 Mtetra
.642 .74 .92 r
.43262 .42416 .43876 .43084 .44935 .42757 .44323 .42099 Mtetra
.65 .747 .92 r
.44323 .42099 .44935 .42757 .45998 .42415 .45388 .41761 Mtetra
.654 .75 .92 r
.45388 .41761 .45998 .42415 .47065 .42065 .46458 .41411 Mtetra
.656 .751 .92 r
.46458 .41411 .47065 .42065 .48137 .41708 .47533 .41054 Mtetra
.658 .753 .92 r
.47533 .41054 .48137 .41708 .49213 .41347 .48611 .40691 Mtetra
.659 .753 .92 r
.48611 .40691 .49213 .41347 .50293 .40982 .49694 .40325 Mtetra
.659 .754 .92 r
.49694 .40325 .50293 .40982 .51377 .40616 .50781 .39956 Mtetra
.50781 .39956 .51377 .40616 .52466 .40249 .51873 .39585 Mtetra
.51873 .39585 .52466 .40249 .53559 .3988 .52969 .39214 Mtetra
.658 .753 .92 r
.52969 .39214 .53559 .3988 .54656 .39512 .54069 .38842 Mtetra
.54069 .38842 .54656 .39512 .55758 .39142 .55173 .3847 Mtetra
.55173 .3847 .55758 .39142 .56864 .38771 .56282 .38096 Mtetra
.56282 .38096 .56864 .38771 .57974 .38399 .57395 .37721 Mtetra
.57395 .37721 .57974 .38399 .59089 .38026 .58513 .37345 Mtetra
.58513 .37345 .59089 .38026 .60208 .37652 .59635 .36968 Mtetra
.59635 .36968 .60208 .37652 .61331 .37277 .60762 .3659 Mtetra
.657 .753 .92 r
.60762 .3659 .61331 .37277 .6246 .369 .61893 .3621 Mtetra
.61893 .3621 .6246 .369 .63592 .36522 .63029 .35829 Mtetra
.63029 .35829 .63592 .36522 .6473 .36142 .6417 .35447 Mtetra
.657 .752 .92 r
.6417 .35447 .6473 .36142 .65872 .35761 .65315 .35063 Mtetra
.65315 .35063 .65872 .35761 .67018 .35379 .66464 .34678 Mtetra
.66464 .34678 .67018 .35379 .68169 .34995 .67619 .34291 Mtetra
.67619 .34291 .68169 .34995 .69325 .3461 .68778 .33903 Mtetra
.68778 .33903 .69325 .3461 .70486 .34223 .69942 .33513 Mtetra
.69942 .33513 .70486 .34223 .71651 .33835 .7111 .33122 Mtetra
.7111 .33122 .71651 .33835 .72821 .33445 .72284 .32729 Mtetra
.72284 .32729 .72821 .33445 .73996 .33054 .73462 .32335 Mtetra
.73462 .32335 .73996 .33054 .75176 .32661 .74645 .31939 Mtetra
.74645 .31939 .75176 .32661 .7636 .32267 .75833 .31542 Mtetra
.75833 .31542 .7636 .32267 .7755 .31871 .77026 .31143 Mtetra
.77026 .31143 .7755 .31871 .78744 .31473 .78224 .30742 Mtetra
.78224 .30742 .78744 .31473 .79944 .31074 .79427 .3034 Mtetra
.79427 .3034 .79944 .31074 .81148 .30674 .80635 .29936 Mtetra
.80635 .29936 .81148 .30674 .82357 .30271 .81848 .29531 Mtetra
.206 .304 .744 r
.17444 .49154 .18027 .50641 .18969 .50541 .18301 .4987 Mtetra
.591 .706 .923 r
.18301 .4987 .18969 .50541 .19922 .50377 .19257 .49692 Mtetra
.499 .667 .938 r
.19257 .49692 .19922 .50377 .21587 .42766 .20202 .49672 Mtetra
.454 .201 .439 r
.20202 .49672 .21587 .42766 .21895 .49462 .21244 .48675 Mtetra
.537 .65 .908 r
.21244 .48675 .21895 .49462 .22862 .49278 .222 .48616 Mtetra
.603 .716 .924 r
.222 .48616 .22862 .49278 .23832 .49105 .23175 .48408 Mtetra
.468 .651 .939 r
.23175 .48408 .23832 .49105 .24988 .46762 .24134 .48434 Mtetra
.078 0 .064 r
.24134 .48434 .24988 .46762 .25834 .48162 .25186 .47398 Mtetra
.559 .668 .911 r
.25186 .47398 .25834 .48162 .26819 .47953 .26164 .47291 Mtetra
.614 .722 .923 r
.26164 .47291 .26819 .47953 .27809 .47729 .27157 .47055 Mtetra
.58 .707 .93 r
.27157 .47055 .27809 .47729 .2877 .47964 .28149 .4689 Mtetra
.796 .685 .741 r
.28149 .4689 .2877 .47964 .2984 .46737 .29226 .45591 Mtetra
.389 .485 .837 r
.29226 .45591 .2984 .46737 .30838 .4657 .30192 .45892 Mtetra
.616 .72 .92 r
.30192 .45892 .30838 .4657 .31846 .46308 .31202 .4565 Mtetra
.626 .731 .922 r
.31202 .4565 .31846 .46308 .32859 .46058 .32217 .45382 Mtetra
.595 .715 .928 r
.32217 .45382 .32859 .46058 .33857 .46134 .33233 .45182 Mtetra
.839 .714 .726 r
.33233 .45182 .33857 .46134 .34926 .45013 .34335 .43517 Mtetra
.285 .359 .764 r
.34335 .43517 .34926 .45013 .35945 .44853 .35311 .44164 Mtetra
.62 .722 .919 r
.35311 .44164 .35945 .44853 .36976 .44569 .36342 .43908 Mtetra
.638 .738 .921 r
.36342 .43908 .36976 .44569 .38011 .44264 .3738 .43607 Mtetra
.64 .74 .921 r
.3738 .43607 .38011 .44264 .39051 .43962 .38422 .43298 Mtetra
.634 .737 .922 r
.38422 .43298 .39051 .43962 .40093 .43699 .39468 .43004 Mtetra
.582 .708 .93 r
.39468 .43004 .40093 .43699 .41111 .44277 .40514 .42826 Mtetra
.753 .631 .726 r
.40514 .42826 .41111 .44277 .42208 .42644 .41598 .41665 Mtetra
.492 .585 .875 r
.41598 .41665 .42208 .42644 .43262 .42416 .42644 .41726 Mtetra
.632 .731 .919 r
.42644 .41726 .43262 .42416 .44323 .42099 .43706 .41432 Mtetra
.647 .744 .92 r
.43706 .41432 .44323 .42099 .45388 .41761 .44774 .41099 Mtetra
.652 .748 .92 r
.44774 .41099 .45388 .41761 .46458 .41411 .45847 .4075 Mtetra
.655 .751 .92 r
.45847 .4075 .46458 .41411 .47533 .41054 .46924 .40393 Mtetra
.657 .752 .92 r
.46924 .40393 .47533 .41054 .48611 .40691 .48005 .4003 Mtetra
.658 .753 .92 r
.48005 .4003 .48611 .40691 .49694 .40325 .49091 .39662 Mtetra
.659 .754 .92 r
.49091 .39662 .49694 .40325 .50781 .39956 .50181 .39291 Mtetra
.50181 .39291 .50781 .39956 .51873 .39585 .51275 .38918 Mtetra
.51275 .38918 .51873 .39585 .52969 .39214 .52374 .38543 Mtetra
.52374 .38543 .52969 .39214 .54069 .38842 .53477 .38168 Mtetra
.658 .753 .92 r
.53477 .38168 .54069 .38842 .55173 .3847 .54584 .37793 Mtetra
.54584 .37793 .55173 .3847 .56282 .38096 .55696 .37416 Mtetra
.55696 .37416 .56282 .38096 .57395 .37721 .56812 .37038 Mtetra
.56812 .37038 .57395 .37721 .58513 .37345 .57933 .36659 Mtetra
.57933 .36659 .58513 .37345 .59635 .36968 .59058 .36279 Mtetra
.59058 .36279 .59635 .36968 .60762 .3659 .60188 .35898 Mtetra
.657 .753 .92 r
.60188 .35898 .60762 .3659 .61893 .3621 .61323 .35516 Mtetra
.61323 .35516 .61893 .3621 .63029 .35829 .62462 .35132 Mtetra
.62462 .35132 .63029 .35829 .6417 .35447 .63605 .34746 Mtetra
.63605 .34746 .6417 .35447 .65315 .35063 .64753 .34359 Mtetra
.657 .752 .92 r
.64753 .34359 .65315 .35063 .66464 .34678 .65906 .33971 Mtetra
.65906 .33971 .66464 .34678 .67619 .34291 .67064 .33582 Mtetra
.67064 .33582 .67619 .34291 .68778 .33903 .68226 .3319 Mtetra
.68226 .3319 .68778 .33903 .69942 .33513 .69394 .32798 Mtetra
.69394 .32798 .69942 .33513 .7111 .33122 .70566 .32403 Mtetra
.70566 .32403 .7111 .33122 .72284 .32729 .71742 .32008 Mtetra
.71742 .32008 .72284 .32729 .73462 .32335 .72924 .3161 Mtetra
.72924 .3161 .73462 .32335 .74645 .31939 .74111 .31212 Mtetra
.74111 .31212 .74645 .31939 .75833 .31542 .75302 .30811 Mtetra
.75302 .30811 .75833 .31542 .77026 .31143 .76499 .30409 Mtetra
.76499 .30409 .77026 .31143 .78224 .30742 .777 .30005 Mtetra
.777 .30005 .78224 .30742 .79427 .3034 .78907 .296 Mtetra
.78907 .296 .79427 .3034 .80635 .29936 .80118 .29193 Mtetra
.80118 .29193 .80635 .29936 .81848 .29531 .81335 .28784 Mtetra
0 0 0 r
.16588 .5019 .17444 .49154 .18301 .4987 .17636 .49128 Mtetra
.556 .672 .915 r
.17636 .49128 .18301 .4987 .19257 .49692 .18585 .49024 Mtetra
.584 .707 .927 r
.18585 .49024 .19257 .49692 .20202 .49672 .19546 .48855 Mtetra
.922 .703 .59 r
.19546 .48855 .20202 .49672 .21244 .48675 .21234 .41208 Mtetra
0 0 .284 r
.21234 .41208 .21244 .48675 .222 .48616 .21536 .47928 Mtetra
.595 .706 .921 r
.21536 .47928 .222 .48616 .23175 .48408 .2251 .47738 Mtetra
.587 .71 .928 r
.2251 .47738 .23175 .48408 .24134 .48434 .23488 .4756 Mtetra
.872 .718 .689 r
.23488 .4756 .24134 .48434 .25186 .47398 .24656 .45202 Mtetra
.066 .127 .618 r
.24656 .45202 .25186 .47398 .26164 .47291 .25507 .46604 Mtetra
.605 .712 .92 r
.25507 .46604 .26164 .47291 .27157 .47055 .265 .46389 Mtetra
.61 .722 .925 r
.265 .46389 .27157 .47055 .28149 .4689 .27498 .46159 Mtetra
.308 .563 .927 r
.27498 .46159 .28149 .4689 .29226 .45591 .28467 .46391 Mtetra
.593 .861 .523 r
.28467 .46391 .29226 .45591 .30192 .45892 .29547 .45154 Mtetra
.585 .691 .915 r
.29547 .45154 .30192 .45892 .31202 .4565 .30553 .44982 Mtetra
.625 .729 .921 r
.30553 .44982 .31202 .4565 .32217 .45382 .3157 .44714 Mtetra
.619 .728 .924 r
.3157 .44714 .32217 .45382 .33233 .45182 .32591 .44458 Mtetra
.438 .634 .938 r
.32591 .44458 .33233 .45182 .34335 .43517 .33598 .44529 Mtetra
0 0 0 r
.33598 .44529 .34335 .43517 .35311 .44164 .34676 .43399 Mtetra
.581 .685 .912 r
.34676 .43399 .35311 .44164 .36342 .43908 .35704 .43234 Mtetra
.632 .733 .92 r
.35704 .43234 .36342 .43908 .3738 .43607 .36744 .42943 Mtetra
.64 .74 .921 r
.36744 .42943 .3738 .43607 .38422 .43298 .37788 .42633 Mtetra
.638 .739 .922 r
.37788 .42633 .38422 .43298 .39468 .43004 .38837 .42325 Mtetra
.622 .73 .924 r
.38837 .42325 .39468 .43004 .40514 .42826 .39888 .42055 Mtetra
.023 .374 .84 r
.39888 .42055 .40514 .42826 .41598 .41665 .40915 .4263 Mtetra
.622 .829 .428 r
.40915 .4263 .41598 .41665 .42644 .41726 .42023 .40986 Mtetra
.607 .707 .915 r
.42023 .40986 .42644 .41726 .43706 .41432 .43086 .40751 Mtetra
.642 .74 .92 r
.43086 .40751 .43706 .41432 .44774 .41099 .44156 .40429 Mtetra
.65 .747 .92 r
.44156 .40429 .44774 .41099 .45847 .4075 .45231 .40083 Mtetra
.654 .75 .92 r
.45231 .40083 .45847 .4075 .46924 .40393 .46311 .39727 Mtetra
.656 .751 .92 r
.46311 .39727 .46924 .40393 .48005 .4003 .47395 .39363 Mtetra
.658 .753 .92 r
.47395 .39363 .48005 .4003 .49091 .39662 .48483 .38994 Mtetra
.659 .753 .92 r
.48483 .38994 .49091 .39662 .50181 .39291 .49576 .3862 Mtetra
.659 .754 .92 r
.49576 .3862 .50181 .39291 .51275 .38918 .50673 .38245 Mtetra
.50673 .38245 .51275 .38918 .52374 .38543 .51775 .37868 Mtetra
.51775 .37868 .52374 .38543 .53477 .38168 .52881 .3749 Mtetra
.658 .753 .92 r
.52881 .3749 .53477 .38168 .54584 .37793 .53991 .37111 Mtetra
.53991 .37111 .54584 .37793 .55696 .37416 .55106 .36731 Mtetra
.55106 .36731 .55696 .37416 .56812 .37038 .56225 .3635 Mtetra
.56225 .3635 .56812 .37038 .57933 .36659 .57349 .35968 Mtetra
.57349 .35968 .57933 .36659 .59058 .36279 .58477 .35585 Mtetra
.58477 .35585 .59058 .36279 .60188 .35898 .5961 .35201 Mtetra
.5961 .35201 .60188 .35898 .61323 .35516 .60748 .34816 Mtetra
.657 .753 .92 r
.60748 .34816 .61323 .35516 .62462 .35132 .6189 .34429 Mtetra
.6189 .34429 .62462 .35132 .63605 .34746 .63037 .3404 Mtetra
.63037 .3404 .63605 .34746 .64753 .34359 .64188 .33651 Mtetra
.657 .752 .92 r
.64188 .33651 .64753 .34359 .65906 .33971 .65344 .33259 Mtetra
.65344 .33259 .65906 .33971 .67064 .33582 .66505 .32867 Mtetra
.66505 .32867 .67064 .33582 .68226 .3319 .67671 .32473 Mtetra
.67671 .32473 .68226 .3319 .69394 .32798 .68841 .32077 Mtetra
.68841 .32077 .69394 .32798 .70566 .32403 .70017 .3168 Mtetra
.70017 .3168 .70566 .32403 .71742 .32008 .71197 .31281 Mtetra
.71197 .31281 .71742 .32008 .72924 .3161 .72382 .3088 Mtetra
.72382 .3088 .72924 .3161 .74111 .31212 .73572 .30478 Mtetra
.73572 .30478 .74111 .31212 .75302 .30811 .74767 .30075 Mtetra
.74767 .30075 .75302 .30811 .76499 .30409 .75967 .2967 Mtetra
.75967 .2967 .76499 .30409 .777 .30005 .77172 .29263 Mtetra
.77172 .29263 .777 .30005 .78907 .296 .78382 .28854 Mtetra
.78382 .28854 .78907 .296 .80118 .29193 .79597 .28444 Mtetra
.79597 .28444 .80118 .29193 .81335 .28784 .80817 .28032 Mtetra
.83 .705 .725 r
.15936 .4926 .16588 .5019 .17636 .49128 .17048 .47627 Mtetra
.203 .302 .744 r
.17048 .47627 .17636 .49128 .18585 .49024 .1791 .48341 Mtetra
.591 .706 .923 r
.1791 .48341 .18585 .49024 .19546 .48855 .18874 .48158 Mtetra
.499 .667 .938 r
.18874 .48158 .19546 .48855 .21234 .41208 .19826 .48134 Mtetra
.45 .194 .434 r
.19826 .48134 .21234 .41208 .21536 .47928 .20878 .47129 Mtetra
.537 .65 .908 r
.20878 .47129 .21536 .47928 .2251 .47738 .21841 .47065 Mtetra
.603 .716 .924 r
.21841 .47065 .2251 .47738 .23488 .4756 .22824 .46852 Mtetra
.468 .651 .939 r
.22824 .46852 .23488 .4756 .24656 .45202 .2379 .46873 Mtetra
.064 0 .051 r
.2379 .46873 .24656 .45202 .25507 .46604 .24852 .45828 Mtetra
.558 .668 .911 r
.24852 .45828 .25507 .46604 .265 .46389 .25838 .45716 Mtetra
.614 .722 .923 r
.25838 .45716 .265 .46389 .27498 .46159 .26839 .45474 Mtetra
.58 .707 .93 r
.26839 .45474 .27498 .46159 .28467 .46391 .2784 .45303 Mtetra
.797 .685 .741 r
.2784 .45303 .28467 .46391 .29547 .45154 .28927 .43994 Mtetra
.388 .484 .837 r
.28927 .43994 .29547 .45154 .30553 .44982 .29901 .44293 Mtetra
.616 .72 .92 r
.29901 .44293 .30553 .44982 .3157 .44714 .30919 .44044 Mtetra
.626 .731 .922 r
.30919 .44044 .3157 .44714 .32591 .44458 .31943 .4377 Mtetra
.595 .715 .928 r
.31943 .4377 .32591 .44458 .33598 .44529 .32967 .43565 Mtetra
.84 .715 .726 r
.32967 .43565 .33598 .44529 .34676 .43399 .3408 .41888 Mtetra
.283 .358 .763 r
.3408 .41888 .34676 .43399 .35704 .43234 .35064 .42533 Mtetra
.62 .722 .919 r
.35064 .42533 .35704 .43234 .36744 .42943 .36103 .42271 Mtetra
.638 .738 .921 r
.36103 .42271 .36744 .42943 .37788 .42633 .3715 .41964 Mtetra
.64 .74 .921 r
.3715 .41964 .37788 .42633 .38837 .42325 .38201 .41649 Mtetra
.634 .737 .922 r
.38201 .41649 .38837 .42325 .39888 .42055 .39256 .41348 Mtetra
.582 .708 .93 r
.39256 .41348 .39888 .42055 .40915 .4263 .40312 .41164 Mtetra
.753 .632 .726 r
.40312 .41164 .40915 .4263 .42023 .40986 .41406 .39993 Mtetra
.492 .585 .876 r
.41406 .39993 .42023 .40986 .43086 .40751 .42461 .4005 Mtetra
.632 .731 .919 r
.42461 .4005 .43086 .40751 .44156 .40429 .43533 .39749 Mtetra
.647 .744 .92 r
.43533 .39749 .44156 .40429 .45231 .40083 .44611 .39409 Mtetra
.652 .748 .92 r
.44611 .39409 .45231 .40083 .46311 .39727 .45693 .39054 Mtetra
.655 .751 .92 r
.45693 .39054 .46311 .39727 .47395 .39363 .4678 .3869 Mtetra
.657 .752 .92 r
.4678 .3869 .47395 .39363 .48483 .38994 .47871 .3832 Mtetra
.658 .753 .92 r
.47871 .3832 .48483 .38994 .49576 .3862 .48967 .37945 Mtetra
.659 .754 .92 r
.48967 .37945 .49576 .3862 .50673 .38245 .50067 .37567 Mtetra
.50067 .37567 .50673 .38245 .51775 .37868 .51171 .37187 Mtetra
.51171 .37187 .51775 .37868 .52881 .3749 .5228 .36806 Mtetra
.5228 .36806 .52881 .3749 .53991 .37111 .53394 .36424 Mtetra
.658 .753 .92 r
.53394 .36424 .53991 .37111 .55106 .36731 .54511 .36041 Mtetra
.54511 .36041 .55106 .36731 .56225 .3635 .55634 .35657 Mtetra
.55634 .35657 .56225 .3635 .57349 .35968 .5676 .35272 Mtetra
.5676 .35272 .57349 .35968 .58477 .35585 .57892 .34886 Mtetra
.57892 .34886 .58477 .35585 .5961 .35201 .59028 .34499 Mtetra
.59028 .34499 .5961 .35201 .60748 .34816 .60168 .3411 Mtetra
.657 .753 .92 r
.60168 .3411 .60748 .34816 .6189 .34429 .61314 .3372 Mtetra
.61314 .3372 .6189 .34429 .63037 .3404 .62464 .33329 Mtetra
.62464 .33329 .63037 .3404 .64188 .33651 .63618 .32936 Mtetra
.63618 .32936 .64188 .33651 .65344 .33259 .64778 .32542 Mtetra
.657 .752 .92 r
.64778 .32542 .65344 .33259 .66505 .32867 .65942 .32146 Mtetra
.65942 .32146 .66505 .32867 .67671 .32473 .67111 .31749 Mtetra
.67111 .31749 .67671 .32473 .68841 .32077 .68285 .3135 Mtetra
.68285 .3135 .68841 .32077 .70017 .3168 .69463 .3095 Mtetra
.69463 .3095 .70017 .3168 .71197 .31281 .70647 .30548 Mtetra
.70647 .30548 .71197 .31281 .72382 .3088 .71836 .30145 Mtetra
.71836 .30145 .72382 .3088 .73572 .30478 .73029 .2974 Mtetra
.73029 .2974 .73572 .30478 .74767 .30075 .74228 .29333 Mtetra
.74228 .29333 .74767 .30075 .75967 .2967 .75431 .28924 Mtetra
.75431 .28924 .75967 .2967 .77172 .29263 .7664 .28514 Mtetra
.7664 .28514 .77172 .29263 .78382 .28854 .77853 .28103 Mtetra
.77853 .28103 .78382 .28854 .79597 .28444 .79072 .27689 Mtetra
.79072 .27689 .79597 .28444 .80817 .28032 .80296 .27274 Mtetra
.396 .615 .938 r
.15256 .48547 .15936 .4926 .17048 .47627 .1618 .4866 Mtetra
0 0 0 r
.1618 .4866 .17048 .47627 .1791 .48341 .17238 .47589 Mtetra
.556 .672 .915 r
.17238 .47589 .1791 .48341 .18874 .48158 .18195 .47479 Mtetra
.584 .707 .927 r
.18195 .47479 .18874 .48158 .19826 .48134 .19163 .47305 Mtetra
.923 .704 .588 r
.19163 .47305 .19826 .48134 .20878 .47129 .20873 .39623 Mtetra
0 0 .278 r
.20873 .39623 .20878 .47129 .21841 .47065 .2117 .46365 Mtetra
.595 .706 .921 r
.2117 .46365 .21841 .47065 .22824 .46852 .22152 .4617 Mtetra
.587 .71 .928 r
.22152 .4617 .22824 .46852 .2379 .46873 .23138 .45987 Mtetra
.872 .719 .689 r
.23138 .45987 .2379 .46873 .24852 .45828 .24318 .43614 Mtetra
.062 .124 .616 r
.24318 .43614 .24852 .45828 .25838 .45716 .25174 .45017 Mtetra
.605 .712 .92 r
.25174 .45017 .25838 .45716 .26839 .45474 .26175 .44797 Mtetra
.61 .722 .925 r
.26175 .44797 .26839 .45474 .2784 .45303 .27182 .44562 Mtetra
.31 .564 .927 r
.27182 .44562 .2784 .45303 .28927 .43994 .28159 .4479 Mtetra
.605 .87 .534 r
.28159 .4479 .28927 .43994 .29901 .44293 .29248 .43543 Mtetra
.585 .691 .915 r
.29248 .43543 .29901 .44293 .30919 .44044 .30263 .43365 Mtetra
.625 .729 .921 r
.30263 .43365 .30919 .44044 .31943 .4377 .31289 .43091 Mtetra
.619 .728 .924 r
.31289 .43091 .31943 .4377 .32967 .43565 .32319 .42829 Mtetra
.439 .634 .938 r
.32319 .42829 .32967 .43565 .3408 .41888 .33333 .42896 Mtetra
0 0 0 r
.33333 .42896 .3408 .41888 .35064 .42533 .34422 .41756 Mtetra
.581 .685 .912 r
.34422 .41756 .35064 .42533 .36103 .42271 .35459 .41584 Mtetra
.632 .733 .92 r
.35459 .41584 .36103 .42271 .3715 .41964 .36507 .41288 Mtetra
.64 .74 .921 r
.36507 .41288 .3715 .41964 .38201 .41649 .37561 .40971 Mtetra
.638 .739 .922 r
.37561 .40971 .38201 .41649 .39256 .41348 .38619 .40657 Mtetra
.622 .73 .924 r
.38619 .40657 .39256 .41348 .40312 .41164 .3968 .40381 Mtetra
.028 .376 .842 r
.3968 .40381 .40312 .41164 .41406 .39993 .40715 .40953 Mtetra
.632 .836 .438 r
.40715 .40953 .41406 .39993 .42461 .4005 .41834 .39297 Mtetra
.607 .707 .915 r
.41834 .39297 .42461 .4005 .43533 .39749 .42906 .39056 Mtetra
.642 .74 .92 r
.42906 .39056 .43533 .39749 .44611 .39409 .43986 .38727 Mtetra
.65 .747 .92 r
.43986 .38727 .44611 .39409 .45693 .39054 .45071 .38375 Mtetra
.654 .75 .92 r
.45071 .38375 .45693 .39054 .4678 .3869 .4616 .38011 Mtetra
.656 .751 .92 r
.4616 .38011 .4678 .3869 .47871 .3832 .47254 .37641 Mtetra
.658 .753 .92 r
.47254 .37641 .47871 .3832 .48967 .37945 .48353 .37264 Mtetra
.659 .753 .92 r
.48353 .37264 .48967 .37945 .50067 .37567 .49456 .36884 Mtetra
.659 .754 .92 r
.49456 .36884 .50067 .37567 .51171 .37187 .50563 .36501 Mtetra
.50563 .36501 .51171 .37187 .5228 .36806 .51675 .36117 Mtetra
.51675 .36117 .5228 .36806 .53394 .36424 .52791 .35732 Mtetra
.658 .753 .92 r
.52791 .35732 .53394 .36424 .54511 .36041 .53912 .35346 Mtetra
.53912 .35346 .54511 .36041 .55634 .35657 .55038 .34959 Mtetra
.55038 .34959 .55634 .35657 .5676 .35272 .56167 .34571 Mtetra
.56167 .34571 .5676 .35272 .57892 .34886 .57302 .34182 Mtetra
.57302 .34182 .57892 .34886 .59028 .34499 .58441 .33792 Mtetra
.58441 .33792 .59028 .34499 .60168 .3411 .59585 .334 Mtetra
.59585 .334 .60168 .3411 .61314 .3372 .60733 .33007 Mtetra
.657 .753 .92 r
.60733 .33007 .61314 .3372 .62464 .33329 .61886 .32613 Mtetra
.61886 .32613 .62464 .33329 .63618 .32936 .63044 .32217 Mtetra
.63044 .32217 .63618 .32936 .64778 .32542 .64207 .31819 Mtetra
.657 .752 .92 r
.64207 .31819 .64778 .32542 .65942 .32146 .65374 .31421 Mtetra
.65374 .31421 .65942 .32146 .67111 .31749 .66547 .3102 Mtetra
.66547 .3102 .67111 .31749 .68285 .3135 .67724 .30618 Mtetra
.67724 .30618 .68285 .3135 .69463 .3095 .68906 .30215 Mtetra
.68906 .30215 .69463 .3095 .70647 .30548 .70093 .2981 Mtetra
.70093 .2981 .70647 .30548 .71836 .30145 .71285 .29403 Mtetra
.71285 .29403 .71836 .30145 .73029 .2974 .72482 .28995 Mtetra
.72482 .28995 .73029 .2974 .74228 .29333 .73684 .28585 Mtetra
.73684 .28585 .74228 .29333 .75431 .28924 .74891 .28174 Mtetra
.74891 .28174 .75431 .28924 .7664 .28514 .76103 .2776 Mtetra
.76103 .2776 .7664 .28514 .77853 .28103 .7732 .27345 Mtetra
.7732 .27345 .77853 .28103 .79072 .27689 .78543 .26929 Mtetra
.78543 .26929 .79072 .27689 .80296 .27274 .79771 .2651 Mtetra
.568 .699 .93 r
.14567 .47861 .15256 .48547 .1618 .4866 .15522 .47718 Mtetra
.831 .705 .725 r
.15522 .47718 .1618 .4866 .17238 .47589 .16644 .46073 Mtetra
.201 .3 .743 r
.16644 .46073 .17238 .47589 .18195 .47479 .17513 .46786 Mtetra
.591 .706 .923 r
.17513 .46786 .18195 .47479 .19163 .47305 .18484 .46597 Mtetra
.499 .667 .938 r
.18484 .46597 .19163 .47305 .20873 .39623 .19443 .46568 Mtetra
.445 .188 .429 r
.19443 .46568 .20873 .39623 .2117 .46365 .20505 .45554 Mtetra
.536 .65 .908 r
.20505 .45554 .2117 .46365 .22152 .4617 .21476 .45485 Mtetra
.603 .716 .924 r
.21476 .45485 .22152 .4617 .23138 .45987 .22467 .45267 Mtetra
.469 .651 .939 r
.22467 .45267 .23138 .45987 .24318 .43614 .23441 .45284 Mtetra
.05 0 .036 r
.23441 .45284 .24318 .43614 .25174 .45017 .24513 .44229 Mtetra
.558 .668 .911 r
.24513 .44229 .25174 .45017 .26175 .44797 .25507 .44112 Mtetra
.614 .722 .923 r
.25507 .44112 .26175 .44797 .27182 .44562 .26516 .43865 Mtetra
.58 .707 .929 r
.26516 .43865 .27182 .44562 .28159 .4479 .27525 .43688 Mtetra
.798 .686 .742 r
.27525 .43688 .28159 .4479 .29248 .43543 .28622 .42369 Mtetra
.387 .484 .837 r
.28622 .42369 .29248 .43543 .30263 .43365 .29604 .42664 Mtetra
.616 .72 .92 r
.29604 .42664 .30263 .43365 .31289 .43091 .3063 .42409 Mtetra
.626 .731 .922 r
.3063 .42409 .31289 .43091 .32319 .42829 .31663 .42129 Mtetra
.595 .715 .928 r
.31663 .42129 .32319 .42829 .33333 .42896 .32696 .41918 Mtetra
.841 .716 .726 r
.32696 .41918 .33333 .42896 .34422 .41756 .3382 .40229 Mtetra
.281 .356 .763 r
.3382 .40229 .34422 .41756 .35459 .41584 .34811 .40871 Mtetra
.62 .722 .919 r
.34811 .40871 .35459 .41584 .36507 .41288 .3586 .40603 Mtetra
.638 .738 .921 r
.3586 .40603 .36507 .41288 .37561 .40971 .36916 .4029 Mtetra
.64 .74 .921 r
.36916 .4029 .37561 .40971 .38619 .40657 .37977 .39968 Mtetra
.634 .737 .922 r
.37977 .39968 .38619 .40657 .3968 .40381 .39041 .39661 Mtetra
.582 .708 .929 r
.39041 .39661 .3968 .40381 .40715 .40953 .40106 .39471 Mtetra
.753 .632 .726 r
.40106 .39471 .40715 .40953 .41834 .39297 .41211 .3829 Mtetra
.491 .584 .876 r
.41211 .3829 .41834 .39297 .42906 .39056 .42275 .38341 Mtetra
.632 .731 .919 r
.42275 .38341 .42906 .39056 .43986 .38727 .43357 .38034 Mtetra
.647 .744 .92 r
.43357 .38034 .43986 .38727 .45071 .38375 .44444 .37688 Mtetra
.652 .748 .92 r
.44444 .37688 .45071 .38375 .4616 .38011 .45536 .37326 Mtetra
.655 .751 .92 r
.45536 .37326 .4616 .38011 .47254 .37641 .46633 .36955 Mtetra
.657 .752 .92 r
.46633 .36955 .47254 .37641 .48353 .37264 .47735 .36578 Mtetra
.658 .753 .92 r
.47735 .36578 .48353 .37264 .49456 .36884 .4884 .36196 Mtetra
.659 .754 .92 r
.4884 .36196 .49456 .36884 .50563 .36501 .49951 .35811 Mtetra
.49951 .35811 .50563 .36501 .51675 .36117 .51066 .35423 Mtetra
.51066 .35423 .51675 .36117 .52791 .35732 .52185 .35035 Mtetra
.52185 .35035 .52791 .35732 .53912 .35346 .53309 .34646 Mtetra
.658 .753 .92 r
.53309 .34646 .53912 .35346 .55038 .34959 .54437 .34256 Mtetra
.54437 .34256 .55038 .34959 .56167 .34571 .5557 .33864 Mtetra
.5557 .33864 .56167 .34571 .57302 .34182 .56707 .33472 Mtetra
.56707 .33472 .57302 .34182 .58441 .33792 .5785 .33079 Mtetra
.5785 .33079 .58441 .33792 .59585 .334 .58996 .32684 Mtetra
.58996 .32684 .59585 .334 .60733 .33007 .60148 .32288 Mtetra
.657 .753 .92 r
.60148 .32288 .60733 .33007 .61886 .32613 .61304 .31891 Mtetra
.61304 .31891 .61886 .32613 .63044 .32217 .62466 .31492 Mtetra
.62466 .31492 .63044 .32217 .64207 .31819 .63632 .31091 Mtetra
.63632 .31091 .64207 .31819 .65374 .31421 .64802 .30689 Mtetra
.657 .752 .92 r
.64802 .30689 .65374 .31421 .66547 .3102 .65978 .30286 Mtetra
.65978 .30286 .66547 .3102 .67724 .30618 .67159 .29881 Mtetra
.67159 .29881 .67724 .30618 .68906 .30215 .68344 .29474 Mtetra
.68344 .29474 .68906 .30215 .70093 .2981 .69535 .29066 Mtetra
.69535 .29066 .70093 .2981 .71285 .29403 .7073 .28656 Mtetra
.7073 .28656 .71285 .29403 .72482 .28995 .71931 .28245 Mtetra
.71931 .28245 .72482 .28995 .73684 .28585 .73136 .27831 Mtetra
.73136 .27831 .73684 .28585 .74891 .28174 .74347 .27417 Mtetra
.74347 .27417 .74891 .28174 .76103 .2776 .75563 .27 Mtetra
.75563 .27 .76103 .2776 .7732 .27345 .76783 .26582 Mtetra
.76783 .26582 .7732 .27345 .78543 .26929 .7801 .26162 Mtetra
.7801 .26162 .78543 .26929 .79771 .2651 .79241 .2574 Mtetra
.58 .699 .924 r
.13876 .47159 .14567 .47861 .15522 .47718 .14834 .46993 Mtetra
.396 .615 .938 r
.14834 .46993 .15522 .47718 .16644 .46073 .15766 .47102 Mtetra
0 0 0 r
.15766 .47102 .16644 .46073 .17513 .46786 .16833 .46022 Mtetra
.556 .672 .915 r
.16833 .46022 .17513 .46786 .18484 .46597 .17797 .45907 Mtetra
.584 .707 .927 r
.17797 .45907 .18484 .46597 .19443 .46568 .18774 .45728 Mtetra
.924 .704 .587 r
.18774 .45728 .19443 .46568 .20505 .45554 .20507 .3801 Mtetra
0 0 .272 r
.20507 .3801 .20505 .45554 .21476 .45485 .20797 .44774 Mtetra
.595 .706 .921 r
.20797 .44774 .21476 .45485 .22467 .45267 .21788 .44573 Mtetra
.587 .71 .928 r
.21788 .44573 .22467 .45267 .23441 .45284 .22782 .44385 Mtetra
.873 .72 .688 r
.22782 .44385 .23441 .45284 .24513 .44229 .23974 .41998 Mtetra
.057 .12 .614 r
.23974 .41998 .24513 .44229 .25507 .44112 .24835 .43402 Mtetra
.604 .712 .92 r
.24835 .43402 .25507 .44112 .26516 .43865 .25845 .43175 Mtetra
.61 .722 .925 r
.25845 .43175 .26516 .43865 .27525 .43688 .2686 .42934 Mtetra
.311 .564 .927 r
.2686 .42934 .27525 .43688 .28622 .42369 .27844 .43158 Mtetra
.615 .878 .545 r
.27844 .43158 .28622 .42369 .29604 .42664 .28944 .41901 Mtetra
.585 .691 .915 r
.28944 .41901 .29604 .42664 .3063 .42409 .29968 .41718 Mtetra
.625 .729 .921 r
.29968 .41718 .3063 .42409 .31663 .42129 .31002 .41438 Mtetra
.619 .728 .924 r
.31002 .41438 .31663 .42129 .32696 .41918 .32041 .41169 Mtetra
.44 .634 .937 r
.32041 .41169 .32696 .41918 .3382 .40229 .33064 .41231 Mtetra
0 0 0 r
.33064 .41231 .3382 .40229 .34811 .40871 .34163 .40082 Mtetra
.581 .685 .912 r
.34163 .40082 .34811 .40871 .3586 .40603 .35209 .39904 Mtetra
.632 .733 .92 r
.35209 .39904 .3586 .40603 .36916 .4029 .36267 .39601 Mtetra
.64 .74 .921 r
.36267 .39601 .36916 .4029 .37977 .39968 .3733 .39278 Mtetra
.638 .739 .922 r
.3733 .39278 .37977 .39968 .39041 .39661 .38397 .38957 Mtetra
.622 .73 .924 r
.38397 .38957 .39041 .39661 .40106 .39471 .39468 .38675 Mtetra
.033 .379 .844 r
.39468 .38675 .40106 .39471 .41211 .3829 .40511 .39244 Mtetra
.642 .844 .447 r
.40511 .39244 .41211 .3829 .42275 .38341 .41641 .37576 Mtetra
.607 .707 .915 r
.41641 .37576 .42275 .38341 .43357 .38034 .42723 .37329 Mtetra
.642 .74 .92 r
.42723 .37329 .43357 .38034 .44444 .37688 .43813 .36992 Mtetra
.65 .747 .92 r
.43813 .36992 .44444 .37688 .45536 .37326 .44908 .36633 Mtetra
.654 .75 .92 r
.44908 .36633 .45536 .37326 .46633 .36955 .46007 .36263 Mtetra
.656 .751 .92 r
.46007 .36263 .46633 .36955 .47735 .36578 .47111 .35885 Mtetra
.658 .753 .92 r
.47111 .35885 .47735 .36578 .4884 .36196 .4822 .35502 Mtetra
.659 .753 .92 r
.4822 .35502 .4884 .36196 .49951 .35811 .49333 .35114 Mtetra
.659 .754 .92 r
.49333 .35114 .49951 .35811 .51066 .35423 .50451 .34725 Mtetra
.50451 .34725 .51066 .35423 .52185 .35035 .51573 .34333 Mtetra
.51573 .34333 .52185 .35035 .53309 .34646 .527 .3394 Mtetra
.658 .753 .92 r
.527 .3394 .53309 .34646 .54437 .34256 .53832 .33547 Mtetra
.53832 .33547 .54437 .34256 .5557 .33864 .54968 .33153 Mtetra
.54968 .33153 .5557 .33864 .56707 .33472 .56108 .32757 Mtetra
.56108 .32757 .56707 .33472 .5785 .33079 .57254 .32361 Mtetra
.57254 .32361 .5785 .33079 .58996 .32684 .58404 .31963 Mtetra
.58404 .31963 .58996 .32684 .60148 .32288 .59559 .31564 Mtetra
.59559 .31564 .60148 .32288 .61304 .31891 .60718 .31163 Mtetra
.657 .753 .92 r
.60718 .31163 .61304 .31891 .62466 .31492 .61883 .30761 Mtetra
.61883 .30761 .62466 .31492 .63632 .31091 .63052 .30357 Mtetra
.63052 .30357 .63632 .31091 .64802 .30689 .64226 .29952 Mtetra
.657 .752 .92 r
.64226 .29952 .64802 .30689 .65978 .30286 .65405 .29546 Mtetra
.65405 .29546 .65978 .30286 .67159 .29881 .66589 .29137 Mtetra
.66589 .29137 .67159 .29881 .68344 .29474 .67778 .28728 Mtetra
.67778 .28728 .68344 .29474 .69535 .29066 .68972 .28316 Mtetra
.68972 .28316 .69535 .29066 .7073 .28656 .70171 .27903 Mtetra
.70171 .27903 .7073 .28656 .71931 .28245 .71375 .27488 Mtetra
.71375 .27488 .71931 .28245 .73136 .27831 .72584 .27072 Mtetra
.72584 .27072 .73136 .27831 .74347 .27417 .73798 .26654 Mtetra
.73798 .26654 .74347 .27417 .75563 .27 .75018 .26234 Mtetra
.75018 .26234 .75563 .27 .76783 .26582 .76242 .25813 Mtetra
.76242 .25813 .76783 .26582 .7801 .26162 .77472 .25389 Mtetra
.77472 .25389 .7801 .26162 .79241 .2574 .78707 .24964 Mtetra
.532 .653 .912 r
.13191 .46363 .13876 .47159 .14834 .46993 .14138 .46296 Mtetra
.568 .699 .929 r
.14138 .46296 .14834 .46993 .15766 .47102 .151 .46147 Mtetra
.832 .706 .726 r
.151 .46147 .15766 .47102 .16833 .46022 .16234 .44491 Mtetra
.198 .299 .742 r
.16234 .44491 .16833 .46022 .17797 .45907 .17108 .45202 Mtetra
.591 .706 .923 r
.17108 .45202 .17797 .45907 .18774 .45728 .18087 .45008 Mtetra
.5 .667 .938 r
.18087 .45008 .18774 .45728 .20507 .3801 .19054 .44974 Mtetra
.44 .181 .424 r
.19054 .44974 .20507 .3801 .20797 .44774 .20125 .43951 Mtetra
.536 .65 .908 r
.20125 .43951 .20797 .44774 .21788 .44573 .21104 .43877 Mtetra
.603 .716 .924 r
.21104 .43877 .21788 .44573 .22782 .44385 .22103 .43653 Mtetra
.469 .651 .939 r
.22103 .43653 .22782 .44385 .23974 .41998 .23085 .43665 Mtetra
.036 0 .022 r
.23085 .43665 .23974 .41998 .24835 .43402 .24167 .42601 Mtetra
.558 .668 .911 r
.24167 .42601 .24835 .43402 .25845 .43175 .25169 .42479 Mtetra
.614 .722 .923 r
.25169 .42479 .25845 .43175 .2686 .42934 .26187 .42225 Mtetra
.58 .707 .929 r
.26187 .42225 .2686 .42934 .27844 .43158 .27204 .42043 Mtetra
.798 .687 .742 r
.27204 .42043 .27844 .43158 .28944 .41901 .28312 .40714 Mtetra
.386 .484 .837 r
.28312 .40714 .28944 .41901 .29968 .41718 .29301 .41004 Mtetra
.616 .72 .92 r
.29301 .41004 .29968 .41718 .31002 .41438 .30337 .40744 Mtetra
.626 .731 .922 r
.30337 .40744 .31002 .41438 .32041 .41169 .31379 .40458 Mtetra
.595 .715 .928 r
.31379 .40458 .32041 .41169 .33064 .41231 .32421 .4024 Mtetra
.841 .717 .726 r
.32421 .4024 .33064 .41231 .34163 .40082 .33555 .38539 Mtetra
.279 .355 .763 r
.33555 .38539 .34163 .40082 .35209 .39904 .34555 .39179 Mtetra
.62 .722 .919 r
.34555 .39179 .35209 .39904 .36267 .39601 .35613 .38904 Mtetra
.638 .738 .921 r
.35613 .38904 .36267 .39601 .3733 .39278 .36678 .38584 Mtetra
.64 .74 .921 r
.36678 .38584 .3733 .39278 .38397 .38957 .37748 .38256 Mtetra
.634 .737 .922 r
.37748 .38256 .38397 .38957 .39468 .38675 .38822 .37942 Mtetra
.582 .708 .929 r
.38822 .37942 .39468 .38675 .40511 .39244 .39896 .37746 Mtetra
.754 .633 .726 r
.39896 .37746 .40511 .39244 .41641 .37576 .41012 .36555 Mtetra
.491 .584 .876 r
.41012 .36555 .41641 .37576 .42723 .37329 .42086 .36601 Mtetra
.632 .731 .919 r
.42086 .36601 .42723 .37329 .43813 .36992 .43177 .36287 Mtetra
.647 .744 .92 r
.43177 .36287 .43813 .36992 .44908 .36633 .44274 .35933 Mtetra
.652 .748 .92 r
.44274 .35933 .44908 .36633 .46007 .36263 .45377 .35565 Mtetra
.655 .751 .92 r
.45377 .35565 .46007 .36263 .47111 .35885 .46484 .35187 Mtetra
.657 .752 .92 r
.46484 .35187 .47111 .35885 .4822 .35502 .47595 .34802 Mtetra
.658 .753 .92 r
.47595 .34802 .4822 .35502 .49333 .35114 .48712 .34413 Mtetra
.659 .754 .92 r
.48712 .34413 .49333 .35114 .50451 .34725 .49832 .3402 Mtetra
.49832 .3402 .50451 .34725 .51573 .34333 .50958 .33626 Mtetra
.50958 .33626 .51573 .34333 .527 .3394 .52087 .3323 Mtetra
.52087 .3323 .527 .3394 .53832 .33547 .53222 .32833 Mtetra
.658 .753 .92 r
.53222 .32833 .53832 .33547 .54968 .33153 .54361 .32436 Mtetra
.54361 .32436 .54968 .33153 .56108 .32757 .55505 .32037 Mtetra
.55505 .32037 .56108 .32757 .57254 .32361 .56653 .31637 Mtetra
.56653 .31637 .57254 .32361 .58404 .31963 .57807 .31236 Mtetra
.57807 .31236 .58404 .31963 .59559 .31564 .58965 .30834 Mtetra
.58965 .30834 .59559 .31564 .60718 .31163 .60127 .3043 Mtetra
.657 .753 .92 r
.60127 .3043 .60718 .31163 .61883 .30761 .61295 .30025 Mtetra
.61295 .30025 .61883 .30761 .63052 .30357 .62468 .29618 Mtetra
.62468 .29618 .63052 .30357 .64226 .29952 .63645 .2921 Mtetra
.63645 .2921 .64226 .29952 .65405 .29546 .64828 .288 Mtetra
.657 .752 .92 r
.64828 .288 .65405 .29546 .66589 .29137 .66015 .28388 Mtetra
.66015 .28388 .66589 .29137 .67778 .28728 .67207 .27975 Mtetra
.67207 .27975 .67778 .28728 .68972 .28316 .68405 .27561 Mtetra
.68405 .27561 .68972 .28316 .70171 .27903 .69607 .27144 Mtetra
.69607 .27144 .70171 .27903 .71375 .27488 .70815 .26726 Mtetra
.70815 .26726 .71375 .27488 .72584 .27072 .72027 .26307 Mtetra
.72027 .26307 .72584 .27072 .73798 .26654 .73245 .25885 Mtetra
.73245 .25885 .73798 .26654 .75018 .26234 .74468 .25462 Mtetra
.74468 .25462 .75018 .26234 .76242 .25813 .75697 .25037 Mtetra
.75697 .25037 .76242 .25813 .77472 .25389 .7693 .24611 Mtetra
.7693 .24611 .77472 .25389 .78707 .24964 .78169 .24182 Mtetra
0 0 .428 r
.12802 .431 .13191 .46363 .14138 .46296 .13439 .45583 Mtetra
.58 .699 .924 r
.13439 .45583 .14138 .46296 .151 .46147 .14405 .45411 Mtetra
.397 .615 .938 r
.14405 .45411 .151 .46147 .16234 .44491 .15344 .45516 Mtetra
0 0 0 r
.15344 .45516 .16234 .44491 .17108 .45202 .16421 .44426 Mtetra
.556 .672 .915 r
.16421 .44426 .17108 .45202 .18087 .45008 .17393 .44306 Mtetra
.584 .707 .927 r
.17393 .44306 .18087 .45008 .19054 .44974 .18377 .44121 Mtetra
.925 .705 .586 r
.18377 .44121 .19054 .44974 .20125 .43951 .20134 .36368 Mtetra
0 0 .266 r
.20134 .36368 .20125 .43951 .21104 .43877 .20418 .43154 Mtetra
.595 .706 .921 r
.20418 .43154 .21104 .43877 .22103 .43653 .21416 .42948 Mtetra
.587 .71 .928 r
.21416 .42948 .22103 .43653 .23085 .43665 .22419 .42753 Mtetra
.874 .721 .688 r
.22419 .42753 .23085 .43665 .24167 .42601 .23623 .40352 Mtetra
.052 .117 .612 r
.23623 .40352 .24167 .42601 .25169 .42479 .2449 .41756 Mtetra
.604 .712 .92 r
.2449 .41756 .25169 .42479 .26187 .42225 .25508 .41524 Mtetra
.61 .722 .925 r
.25508 .41524 .26187 .42225 .27204 .42043 .26532 .41277 Mtetra
.313 .565 .927 r
.26532 .41277 .27204 .42043 .28312 .40714 .27524 .41497 Mtetra
.626 .886 .556 r
.27524 .41497 .28312 .40714 .29301 .41004 .28634 .4023 Mtetra
.585 .691 .915 r
.28634 .4023 .29301 .41004 .30337 .40744 .29667 .4004 Mtetra
.625 .729 .921 r
.29667 .4004 .30337 .40744 .31379 .40458 .3071 .39754 Mtetra
.619 .728 .924 r
.3071 .39754 .31379 .40458 .32421 .4024 .31758 .39479 Mtetra
.44 .634 .937 r
.31758 .39479 .32421 .4024 .33555 .38539 .3279 .39536 Mtetra
0 0 0 r
.3279 .39536 .33555 .38539 .34555 .39179 .339 .38376 Mtetra
.581 .685 .912 r
.339 .38376 .34555 .39179 .35613 .38904 .34955 .38193 Mtetra
.632 .733 .92 r
.34955 .38193 .35613 .38904 .36678 .38584 .36022 .37883 Mtetra
.64 .74 .921 r
.36022 .37883 .36678 .38584 .37748 .38256 .37094 .37553 Mtetra
.638 .739 .922 r
.37094 .37553 .37748 .38256 .38822 .37942 .38171 .37225 Mtetra
.622 .73 .924 r
.38171 .37225 .38822 .37942 .39896 .37746 .39251 .36937 Mtetra
.038 .381 .845 r
.39251 .36937 .39896 .37746 .41012 .36555 .40304 .37503 Mtetra
.651 .851 .457 r
.40304 .37503 .41012 .36555 .42086 .36601 .41445 .35822 Mtetra
.607 .707 .915 r
.41445 .35822 .42086 .36601 .43177 .36287 .42537 .35568 Mtetra
.642 .74 .92 r
.42537 .35568 .43177 .36287 .44274 .35933 .43636 .35225 Mtetra
.65 .747 .92 r
.43636 .35225 .44274 .35933 .45377 .35565 .44741 .34859 Mtetra
.654 .75 .92 r
.44741 .34859 .45377 .35565 .46484 .35187 .45851 .34481 Mtetra
.656 .751 .92 r
.45851 .34481 .46484 .35187 .47595 .34802 .46966 .34096 Mtetra
.658 .753 .92 r
.46966 .34096 .47595 .34802 .48712 .34413 .48085 .33705 Mtetra
.659 .753 .92 r
.48085 .33705 .48712 .34413 .49832 .3402 .49209 .33311 Mtetra
.659 .754 .92 r
.49209 .33311 .49832 .3402 .50958 .33626 .50337 .32913 Mtetra
.50337 .32913 .50958 .33626 .52087 .3323 .5147 .32514 Mtetra
.5147 .32514 .52087 .3323 .53222 .32833 .52607 .32114 Mtetra
.658 .753 .92 r
.52607 .32114 .53222 .32833 .54361 .32436 .5375 .31713 Mtetra
.5375 .31713 .54361 .32436 .55505 .32037 .54897 .31311 Mtetra
.54897 .31311 .55505 .32037 .56653 .31637 .56048 .30908 Mtetra
.56048 .30908 .56653 .31637 .57807 .31236 .57205 .30504 Mtetra
.57205 .30504 .57807 .31236 .58965 .30834 .58366 .30098 Mtetra
.58366 .30098 .58965 .30834 .60127 .3043 .59532 .29691 Mtetra
.59532 .29691 .60127 .3043 .61295 .30025 .60703 .29283 Mtetra
.657 .753 .92 r
.60703 .29283 .61295 .30025 .62468 .29618 .61879 .28873 Mtetra
.61879 .28873 .62468 .29618 .63645 .2921 .6306 .28461 Mtetra
.6306 .28461 .63645 .2921 .64828 .288 .64246 .28048 Mtetra
.657 .752 .92 r
.64246 .28048 .64828 .288 .66015 .28388 .65436 .27633 Mtetra
.65436 .27633 .66015 .28388 .67207 .27975 .66632 .27217 Mtetra
.66632 .27217 .67207 .27975 .68405 .27561 .67833 .26799 Mtetra
.67833 .26799 .68405 .27561 .69607 .27144 .69039 .26379 Mtetra
.69039 .26379 .69607 .27144 .70815 .26726 .7025 .25958 Mtetra
.7025 .25958 .70815 .26726 .72027 .26307 .71466 .25535 Mtetra
.71466 .25535 .72027 .26307 .73245 .25885 .72688 .2511 Mtetra
.72688 .2511 .73245 .25885 .74468 .25462 .73915 .24684 Mtetra
.73915 .24684 .74468 .25462 .75697 .25037 .75147 .24256 Mtetra
.75147 .24256 .75697 .25037 .7693 .24611 .76384 .23825 Mtetra
.76384 .23825 .7693 .24611 .78169 .24182 .77627 .23394 Mtetra
.245 0 .224 r
.1168 .45789 .12802 .431 .13439 .45583 .12746 .44774 Mtetra
.532 .653 .912 r
.12746 .44774 .13439 .45583 .14405 .45411 .13701 .44702 Mtetra
.568 .699 .929 r
.13701 .44702 .14405 .45411 .15344 .45516 .14671 .44548 Mtetra
.832 .707 .726 r
.14671 .44548 .15344 .45516 .16421 .44426 .15816 .4288 Mtetra
.195 .297 .742 r
.15816 .4288 .16421 .44426 .17393 .44306 .16695 .4359 Mtetra
.591 .706 .923 r
.16695 .4359 .17393 .44306 .18377 .44121 .17682 .4339 Mtetra
.5 .667 .937 r
.17682 .4339 .18377 .44121 .20134 .36368 .18657 .43351 Mtetra
.434 .174 .418 r
.18657 .43351 .20134 .36368 .20418 .43154 .19738 .42319 Mtetra
.536 .65 .908 r
.19738 .42319 .20418 .43154 .21416 .42948 .20725 .4224 Mtetra
.603 .716 .924 r
.20725 .4224 .21416 .42948 .22419 .42753 .21732 .42009 Mtetra
.47 .651 .938 r
.21732 .42009 .22419 .42753 .23623 .40352 .22722 .42017 Mtetra
.021 0 .007 r
.22722 .42017 .23623 .40352 .2449 .41756 .23814 .40943 Mtetra
.558 .668 .911 r
.23814 .40943 .2449 .41756 .25508 .41524 .24825 .40815 Mtetra
.614 .722 .923 r
.24825 .40815 .25508 .41524 .26532 .41277 .25851 .40556 Mtetra
.58 .707 .929 r
.25851 .40556 .26532 .41277 .27524 .41497 .26877 .40368 Mtetra
.799 .687 .742 r
.26877 .40368 .27524 .41497 .28634 .4023 .27995 .39027 Mtetra
.385 .483 .837 r
.27995 .39027 .28634 .4023 .29667 .4004 .28993 .39314 Mtetra
.616 .72 .92 r
.28993 .39314 .29667 .4004 .3071 .39754 .30038 .39047 Mtetra
.626 .731 .922 r
.30038 .39047 .3071 .39754 .31758 .39479 .31088 .38754 Mtetra
.595 .715 .928 r
.31088 .38754 .31758 .39479 .3279 .39536 .3214 .38531 Mtetra
.842 .718 .726 r
.3214 .38531 .3279 .39536 .339 .38376 .33286 .36817 Mtetra
.277 .354 .763 r
.33286 .36817 .339 .38376 .34955 .38193 .34293 .37455 Mtetra
.62 .722 .919 r
.34293 .37455 .34955 .38193 .36022 .37883 .35361 .37173 Mtetra
.638 .738 .921 r
.35361 .37173 .36022 .37883 .37094 .37553 .36436 .36846 Mtetra
.64 .74 .921 r
.36436 .36846 .37094 .37553 .38171 .37225 .37515 .36511 Mtetra
.634 .737 .922 r
.37515 .36511 .38171 .37225 .39251 .36937 .38599 .36191 Mtetra
.582 .708 .929 r
.38599 .36191 .39251 .36937 .40304 .37503 .39683 .35988 Mtetra
.754 .633 .727 r
.39683 .35988 .40304 .37503 .41445 .35822 .40809 .34787 Mtetra
.49 .584 .876 r
.40809 .34787 .41445 .35822 .42537 .35568 .41892 .34827 Mtetra
.632 .731 .919 r
.41892 .34827 .42537 .35568 .43636 .35225 .42994 .34506 Mtetra
.647 .744 .92 r
.42994 .34506 .43636 .35225 .44741 .34859 .44101 .34145 Mtetra
.652 .748 .92 r
.44101 .34145 .44741 .34859 .45851 .34481 .45214 .33769 Mtetra
.655 .751 .92 r
.45214 .33769 .45851 .34481 .46966 .34096 .46331 .33384 Mtetra
.657 .752 .92 r
.46331 .33384 .46966 .34096 .48085 .33705 .47453 .32992 Mtetra
.658 .753 .92 r
.47453 .32992 .48085 .33705 .49209 .33311 .4858 .32595 Mtetra
.659 .754 .92 r
.4858 .32595 .49209 .33311 .50337 .32913 .49711 .32195 Mtetra
.49711 .32195 .50337 .32913 .5147 .32514 .50848 .31793 Mtetra
.50848 .31793 .5147 .32514 .52607 .32114 .51988 .3139 Mtetra
.51988 .3139 .52607 .32114 .5375 .31713 .53134 .30985 Mtetra
.658 .753 .92 r
.53134 .30985 .5375 .31713 .54897 .31311 .54284 .3058 Mtetra
.54284 .3058 .54897 .31311 .56048 .30908 .55438 .30173 Mtetra
.55438 .30173 .56048 .30908 .57205 .30504 .56598 .29766 Mtetra
.56598 .29766 .57205 .30504 .58366 .30098 .57763 .29357 Mtetra
.57763 .29357 .58366 .30098 .59532 .29691 .58932 .28947 Mtetra
.58932 .28947 .59532 .29691 .60703 .29283 .60106 .28535 Mtetra
.657 .753 .92 r
.60106 .28535 .60703 .29283 .61879 .28873 .61286 .28122 Mtetra
.61286 .28122 .61879 .28873 .6306 .28461 .6247 .27707 Mtetra
.6247 .27707 .6306 .28461 .64246 .28048 .63659 .2729 Mtetra
.63659 .2729 .64246 .28048 .65436 .27633 .64853 .26872 Mtetra
.657 .752 .92 r
.64853 .26872 .65436 .27633 .66632 .27217 .66053 .26453 Mtetra
.66053 .26453 .66632 .27217 .67833 .26799 .67257 .26032 Mtetra
.67257 .26032 .67833 .26799 .69039 .26379 .68466 .25609 Mtetra
.68466 .25609 .69039 .26379 .7025 .25958 .69681 .25184 Mtetra
.69681 .25184 .7025 .25958 .71466 .25535 .70901 .24757 Mtetra
.70901 .24757 .71466 .25535 .72688 .2511 .72126 .24329 Mtetra
.72126 .24329 .72688 .2511 .73915 .24684 .73357 .23899 Mtetra
.73357 .23899 .73915 .24684 .75147 .24256 .74592 .23468 Mtetra
.74592 .23468 .75147 .24256 .76384 .23825 .75833 .23034 Mtetra
.75833 .23034 .76384 .23825 .77627 .23394 .7708 .22599 Mtetra
.89 .712 .654 r
.10988 .44911 .1168 .45789 .12746 .44774 .12356 .41489 Mtetra
0 0 .424 r
.12356 .41489 .12746 .44774 .13701 .44702 .12994 .43977 Mtetra
.58 .699 .924 r
.12994 .43977 .13701 .44702 .14671 .44548 .13968 .438 Mtetra
.398 .615 .938 r
.13968 .438 .14671 .44548 .15816 .4288 .14914 .439 Mtetra
0 0 0 r
.14914 .439 .15816 .4288 .16695 .4359 .16001 .42801 Mtetra
.556 .672 .916 r
.16001 .42801 .16695 .4359 .17682 .4339 .16981 .42676 Mtetra
.584 .707 .927 r
.16981 .42676 .17682 .4339 .18657 .43351 .17973 .42485 Mtetra
.926 .705 .584 r
.17973 .42485 .18657 .43351 .19738 .42319 .19754 .34697 Mtetra
0 0 .259 r
.19754 .34697 .19738 .42319 .20725 .4224 .20031 .41504 Mtetra
.595 .706 .921 r
.20031 .41504 .20725 .4224 .21732 .42009 .21038 .41292 Mtetra
.587 .71 .928 r
.21038 .41292 .21732 .42009 .22722 .42017 .22049 .41092 Mtetra
.875 .721 .688 r
.22049 .41092 .22722 .42017 .23814 .40943 .23266 .38675 Mtetra
.048 .114 .61 r
.23266 .38675 .23814 .40943 .24825 .40815 .24138 .4008 Mtetra
.604 .712 .921 r
.24138 .4008 .24825 .40815 .25851 .40556 .25165 .39842 Mtetra
.61 .722 .925 r
.25165 .39842 .25851 .40556 .26877 .40368 .26198 .39589 Mtetra
.315 .565 .927 r
.26198 .39589 .26877 .40368 .27995 .39027 .27198 .39804 Mtetra
.636 .893 .566 r
.27198 .39804 .27995 .39027 .28993 .39314 .28319 .38526 Mtetra
.585 .691 .915 r
.28319 .38526 .28993 .39314 .30038 .39047 .2936 .3833 Mtetra
.625 .729 .922 r
.2936 .3833 .30038 .39047 .31088 .38754 .30413 .38038 Mtetra
.62 .728 .924 r
.30413 .38038 .31088 .38754 .3214 .38531 .3147 .37756 Mtetra
.441 .634 .937 r
.3147 .37756 .3214 .38531 .33286 .36817 .32511 .37808 Mtetra
0 0 0 r
.32511 .37808 .33286 .36817 .34293 .37455 .33631 .36639 Mtetra
.581 .685 .912 r
.33631 .36639 .34293 .37455 .35361 .37173 .34695 .36449 Mtetra
.632 .733 .92 r
.34695 .36449 .35361 .37173 .36436 .36846 .35772 .36132 Mtetra
.64 .74 .921 r
.35772 .36132 .36436 .36846 .37515 .36511 .36854 .35796 Mtetra
.638 .739 .922 r
.36854 .35796 .37515 .36511 .38599 .36191 .37941 .35461 Mtetra
.622 .73 .924 r
.37941 .35461 .38599 .36191 .39683 .35988 .39031 .35165 Mtetra
.043 .384 .847 r
.39031 .35165 .39683 .35988 .40809 .34787 .40092 .35728 Mtetra
.66 .858 .467 r
.40092 .35728 .40809 .34787 .41892 .34827 .41245 .34035 Mtetra
.607 .707 .915 r
.41245 .34035 .41892 .34827 .42994 .34506 .42347 .33774 Mtetra
.642 .74 .92 r
.42347 .33774 .42994 .34506 .44101 .34145 .43457 .33423 Mtetra
.65 .747 .92 r
.43457 .33423 .44101 .34145 .45214 .33769 .44572 .3305 Mtetra
.654 .75 .92 r
.44572 .3305 .45214 .33769 .46331 .33384 .45692 .32665 Mtetra
.656 .751 .92 r
.45692 .32665 .46331 .33384 .47453 .32992 .46817 .32272 Mtetra
.658 .753 .92 r
.46817 .32272 .47453 .32992 .4858 .32595 .47947 .31874 Mtetra
.659 .753 .92 r
.47947 .31874 .4858 .32595 .49711 .32195 .49081 .31472 Mtetra
.659 .754 .92 r
.49081 .31472 .49711 .32195 .50848 .31793 .5022 .31067 Mtetra
.5022 .31067 .50848 .31793 .51988 .3139 .51364 .3066 Mtetra
.51364 .3066 .51988 .3139 .53134 .30985 .52513 .30252 Mtetra
.658 .753 .92 r
.52513 .30252 .53134 .30985 .54284 .3058 .53666 .29843 Mtetra
.53666 .29843 .54284 .3058 .55438 .30173 .54824 .29433 Mtetra
.54824 .29433 .55438 .30173 .56598 .29766 .55987 .29022 Mtetra
.55987 .29022 .56598 .29766 .57763 .29357 .57155 .2861 Mtetra
.57155 .2861 .57763 .29357 .58932 .28947 .58327 .28196 Mtetra
.58327 .28196 .58932 .28947 .60106 .28535 .59505 .27781 Mtetra
.59505 .27781 .60106 .28535 .61286 .28122 .60688 .27365 Mtetra
.657 .753 .92 r
.60688 .27365 .61286 .28122 .6247 .27707 .61875 .26947 Mtetra
.61875 .26947 .6247 .27707 .63659 .2729 .63068 .26527 Mtetra
.63068 .26527 .63659 .2729 .64853 .26872 .64265 .26106 Mtetra
.657 .752 .92 r
.64265 .26106 .64853 .26872 .66053 .26453 .65468 .25683 Mtetra
.65468 .25683 .66053 .26453 .67257 .26032 .66676 .25258 Mtetra
.66676 .25258 .67257 .26032 .68466 .25609 .67889 .24832 Mtetra
.67889 .24832 .68466 .25609 .69681 .25184 .69108 .24403 Mtetra
.69108 .24403 .69681 .25184 .70901 .24757 .70331 .23974 Mtetra
.70331 .23974 .70901 .24757 .72126 .24329 .7156 .23542 Mtetra
.7156 .23542 .72126 .24329 .73357 .23899 .72794 .23109 Mtetra
.72794 .23109 .73357 .23899 .74592 .23468 .74034 .22673 Mtetra
.74034 .22673 .74592 .23468 .75833 .23034 .75278 .22236 Mtetra
.75278 .22236 .75833 .23034 .7708 .22599 .76529 .21798 Mtetra
.465 .65 .939 r
.10274 .44172 .10988 .44911 .12356 .41489 .11217 .44181 Mtetra
.234 0 .213 r
.11217 .44181 .12356 .41489 .12994 .43977 .12294 .43156 Mtetra
.532 .653 .912 r
.12294 .43156 .12994 .43977 .13968 .438 .13256 .43079 Mtetra
.568 .699 .929 r
.13256 .43079 .13968 .438 .14914 .439 .14233 .4292 Mtetra
.833 .708 .726 r
.14233 .4292 .14914 .439 .16001 .42801 .1539 .4124 Mtetra
.192 .295 .741 r
.1539 .4124 .16001 .42801 .16981 .42676 .16275 .41947 Mtetra
.591 .706 .923 r
.16275 .41947 .16981 .42676 .17973 .42485 .1727 .41742 Mtetra
.5 .667 .937 r
.1727 .41742 .17973 .42485 .19754 .34697 .18253 .41698 Mtetra
.429 .167 .413 r
.18253 .41698 .19754 .34697 .20031 .41504 .19344 .40656 Mtetra
.536 .65 .908 r
.19344 .40656 .20031 .41504 .21038 .41292 .20339 .40572 Mtetra
.603 .716 .924 r
.20339 .40572 .21038 .41292 .22049 .41092 .21355 .40335 Mtetra
.47 .651 .938 r
.21355 .40335 .22049 .41092 .23266 .38675 .22353 .40337 Mtetra
.006 0 0 r
.22353 .40337 .23266 .38675 .24138 .4008 .23455 .39255 Mtetra
.558 .668 .911 r
.23455 .39255 .24138 .4008 .25165 .39842 .24474 .3912 Mtetra
.614 .722 .923 r
.24474 .3912 .25165 .39842 .26198 .39589 .2551 .38855 Mtetra
.581 .707 .929 r
.2551 .38855 .26198 .39589 .27198 .39804 .26544 .3866 Mtetra
.799 .688 .742 r
.26544 .3866 .27198 .39804 .28319 .38526 .27673 .37309 Mtetra
.384 .483 .837 r
.27673 .37309 .28319 .38526 .2936 .3833 .28679 .37592 Mtetra
.616 .72 .92 r
.28679 .37592 .2936 .3833 .30413 .38038 .29733 .37318 Mtetra
.626 .731 .922 r
.29733 .37318 .30413 .38038 .3147 .37756 .30793 .37019 Mtetra
.595 .715 .928 r
.30793 .37019 .3147 .37756 .32511 .37808 .31853 .36789 Mtetra
.843 .719 .726 r
.31853 .36789 .32511 .37808 .33631 .36639 .33011 .35063 Mtetra
.274 .353 .762 r
.33011 .35063 .33631 .36639 .34695 .36449 .34026 .35697 Mtetra
.62 .722 .919 r
.34026 .35697 .34695 .36449 .35772 .36132 .35104 .35409 Mtetra
.638 .738 .921 r
.35104 .35409 .35772 .36132 .36854 .35796 .36188 .35075 Mtetra
.64 .74 .921 r
.36188 .35075 .36854 .35796 .37941 .35461 .37278 .34733 Mtetra
.634 .737 .922 r
.37278 .34733 .37941 .35461 .39031 .35165 .38371 .34406 Mtetra
.582 .708 .929 r
.38371 .34406 .39031 .35165 .40092 .35728 .39465 .34197 Mtetra
.754 .634 .727 r
.39465 .34197 .40092 .35728 .41245 .34035 .40602 .32984 Mtetra
.49 .584 .876 r
.40602 .32984 .41245 .34035 .42347 .33774 .41695 .33019 Mtetra
.632 .731 .919 r
.41695 .33019 .42347 .33774 .43457 .33423 .42807 .32691 Mtetra
.647 .744 .92 r
.42807 .32691 .43457 .33423 .44572 .3305 .43925 .32323 Mtetra
.652 .748 .92 r
.43925 .32323 .44572 .3305 .45692 .32665 .45048 .31939 Mtetra
.655 .751 .92 r
.45048 .31939 .45692 .32665 .46817 .32272 .46176 .31546 Mtetra
.657 .752 .92 r
.46176 .31546 .46817 .32272 .47947 .31874 .47309 .31147 Mtetra
.658 .753 .92 r
.47309 .31147 .47947 .31874 .49081 .31472 .48446 .30742 Mtetra
.659 .754 .92 r
.48446 .30742 .49081 .31472 .5022 .31067 .49588 .30334 Mtetra
.49588 .30334 .5022 .31067 .51364 .3066 .50735 .29924 Mtetra
.50735 .29924 .51364 .3066 .52513 .30252 .51887 .29513 Mtetra
.51887 .29513 .52513 .30252 .53666 .29843 .53043 .29101 Mtetra
.658 .753 .92 r
.53043 .29101 .53666 .29843 .54824 .29433 .54205 .28687 Mtetra
.54205 .28687 .54824 .29433 .55987 .29022 .55371 .28273 Mtetra
.55371 .28273 .55987 .29022 .57155 .2861 .56542 .27857 Mtetra
.56542 .27857 .57155 .2861 .58327 .28196 .57718 .2744 Mtetra
.57718 .2744 .58327 .28196 .59505 .27781 .58899 .27022 Mtetra
.58899 .27022 .59505 .27781 .60688 .27365 .60085 .26602 Mtetra
.657 .753 .92 r
.60085 .26602 .60688 .27365 .61875 .26947 .61276 .26181 Mtetra
.61276 .26181 .61875 .26947 .63068 .26527 .62472 .25757 Mtetra
.62472 .25757 .63068 .26527 .64265 .26106 .63673 .25333 Mtetra
.63673 .25333 .64265 .26106 .65468 .25683 .64879 .24906 Mtetra
.657 .752 .92 r
.64879 .24906 .65468 .25683 .66676 .25258 .66091 .24478 Mtetra
.66091 .24478 .66676 .25258 .67889 .24832 .67308 .24048 Mtetra
.67308 .24048 .67889 .24832 .69108 .24403 .6853 .23617 Mtetra
.6853 .23617 .69108 .24403 .70331 .23974 .69757 .23184 Mtetra
.69757 .23184 .70331 .23974 .7156 .23542 .70989 .22748 Mtetra
.70989 .22748 .7156 .23542 .72794 .23109 .72227 .22312 Mtetra
.72227 .22312 .72794 .23109 .74034 .22673 .7347 .21873 Mtetra
.7347 .21873 .74034 .22673 .75278 .22236 .74719 .21432 Mtetra
.74719 .21432 .75278 .22236 .76529 .21798 .75973 .2099 Mtetra
.566 .696 .928 r
.09553 .43445 .10274 .44172 .11217 .44181 .10518 .4329 Mtetra
.891 .713 .654 r
.10518 .4329 .11217 .44181 .12294 .43156 .11902 .39849 Mtetra
0 0 .419 r
.11902 .39849 .12294 .43156 .13256 .43079 .12541 .42342 Mtetra
.58 .699 .924 r
.12541 .42342 .13256 .43079 .14233 .4292 .13522 .4216 Mtetra
.399 .615 .938 r
.13522 .4216 .14233 .4292 .1539 .4124 .14476 .42255 Mtetra
0 0 0 r
.14476 .42255 .1539 .4124 .16275 .41947 .15573 .41147 Mtetra
.556 .672 .916 r
.15573 .41147 .16275 .41947 .1727 .41742 .16561 .41016 Mtetra
.584 .707 .927 r
.16561 .41016 .1727 .41742 .18253 .41698 .17561 .40819 Mtetra
.927 .706 .583 r
.17561 .40819 .18253 .41698 .19344 .40656 .19368 .32995 Mtetra
0 0 .253 r
.19368 .32995 .19344 .40656 .20339 .40572 .19638 .39824 Mtetra
.595 .706 .921 r
.19638 .39824 .20339 .40572 .21355 .40335 .20653 .39605 Mtetra
.587 .71 .928 r
.20653 .39605 .21355 .40335 .22353 .40337 .21672 .39399 Mtetra
.876 .722 .687 r
.21672 .39399 .22353 .40337 .23455 .39255 .22902 .36967 Mtetra
.043 .11 .609 r
.22902 .36967 .23455 .39255 .24474 .3912 .2378 .38373 Mtetra
.604 .712 .921 r
.2378 .38373 .24474 .3912 .2551 .38855 .24816 .38128 Mtetra
.61 .722 .925 r
.24816 .38128 .2551 .38855 .26544 .3866 .25857 .37868 Mtetra
.316 .566 .927 r
.25857 .37868 .26544 .3866 .27673 .37309 .26866 .38079 Mtetra
.647 .901 .577 r
.26866 .38079 .27673 .37309 .28679 .37592 .27998 .36791 Mtetra
.585 .691 .915 r
.27998 .36791 .28679 .37592 .29733 .37318 .29048 .36589 Mtetra
.625 .729 .922 r
.29048 .36589 .29733 .37318 .30793 .37019 .3011 .36289 Mtetra
.62 .728 .924 r
.3011 .36289 .30793 .37019 .31853 .36789 .31176 .36001 Mtetra
.442 .634 .937 r
.31176 .36001 .31853 .36789 .33011 .35063 .32226 .36048 Mtetra
0 0 0 r
.32226 .36048 .33011 .35063 .34026 .35697 .33357 .34867 Mtetra
.581 .685 .912 r
.33357 .34867 .34026 .35697 .35104 .35409 .34431 .34671 Mtetra
.632 .733 .92 r
.34431 .34671 .35104 .35409 .36188 .35075 .35517 .34348 Mtetra
.64 .74 .921 r
.35517 .34348 .36188 .35075 .37278 .34733 .3661 .34004 Mtetra
.638 .739 .922 r
.3661 .34004 .37278 .34733 .38371 .34406 .37706 .33662 Mtetra
.622 .73 .924 r
.37706 .33662 .38371 .34406 .39465 .34197 .38806 .33359 Mtetra
.048 .386 .848 r
.38806 .33359 .39465 .34197 .40602 .32984 .39877 .33918 Mtetra
.669 .865 .476 r
.39877 .33918 .40602 .32984 .41695 .33019 .41041 .32212 Mtetra
.607 .707 .915 r
.41041 .32212 .41695 .33019 .42807 .32691 .42153 .31944 Mtetra
.642 .74 .92 r
.42153 .31944 .42807 .32691 .43925 .32323 .43273 .31587 Mtetra
.65 .747 .92 r
.43273 .31587 .43925 .32323 .45048 .31939 .44399 .31206 Mtetra
.654 .75 .92 r
.44399 .31206 .45048 .31939 .46176 .31546 .4553 .30813 Mtetra
.656 .751 .92 r
.4553 .30813 .46176 .31546 .47309 .31147 .46666 .30413 Mtetra
.658 .753 .92 r
.46666 .30413 .47309 .31147 .48446 .30742 .47806 .30007 Mtetra
.659 .753 .92 r
.47806 .30007 .48446 .30742 .49588 .30334 .48951 .29596 Mtetra
.659 .754 .92 r
.48951 .29596 .49588 .30334 .50735 .29924 .50102 .29183 Mtetra
.50102 .29183 .50735 .29924 .51887 .29513 .51256 .28769 Mtetra
.51256 .28769 .51887 .29513 .53043 .29101 .52416 .28353 Mtetra
.658 .753 .92 r
.52416 .28353 .53043 .29101 .54205 .28687 .53581 .27936 Mtetra
.53581 .27936 .54205 .28687 .55371 .28273 .5475 .27518 Mtetra
.5475 .27518 .55371 .28273 .56542 .27857 .55924 .27099 Mtetra
.55924 .27099 .56542 .27857 .57718 .2744 .57104 .26678 Mtetra
.57104 .26678 .57718 .2744 .58899 .27022 .58288 .26257 Mtetra
.58288 .26257 .58899 .27022 .60085 .26602 .59477 .25833 Mtetra
.59477 .25833 .60085 .26602 .61276 .26181 .60672 .25408 Mtetra
.657 .753 .92 r
.60672 .25408 .61276 .26181 .62472 .25757 .61871 .24982 Mtetra
.61871 .24982 .62472 .25757 .63673 .25333 .63076 .24554 Mtetra
.63076 .24554 .63673 .25333 .64879 .24906 .64286 .24124 Mtetra
.657 .752 .92 r
.64286 .24124 .64879 .24906 .66091 .24478 .65501 .23692 Mtetra
.65501 .23692 .66091 .24478 .67308 .24048 .66721 .23259 Mtetra
.66721 .23259 .67308 .24048 .6853 .23617 .67947 .22824 Mtetra
.67947 .22824 .6853 .23617 .69757 .23184 .69178 .22387 Mtetra
.69178 .22387 .69757 .23184 .70989 .22748 .70414 .21949 Mtetra
.70414 .21949 .70989 .22748 .72227 .22312 .71655 .21508 Mtetra
.71655 .21508 .72227 .22312 .7347 .21873 .72902 .21066 Mtetra
.72902 .21066 .7347 .21873 .74719 .21432 .74155 .20622 Mtetra
.74155 .20622 .74719 .21432 .75973 .2099 .75413 .20176 Mtetra
.558 .681 .921 r
.08832 .42677 .09553 .43445 .10518 .4329 .09796 .42539 Mtetra
.466 .65 .939 r
.09796 .42539 .10518 .4329 .11902 .39849 .10746 .42542 Mtetra
.223 0 .202 r
.10746 .42542 .11902 .39849 .12541 .42342 .11833 .41509 Mtetra
.532 .653 .912 r
.11833 .41509 .12541 .42342 .13522 .4216 .12803 .41426 Mtetra
.568 .699 .929 r
.12803 .41426 .13522 .4216 .14476 .42255 .13788 .41261 Mtetra
.834 .708 .726 r
.13788 .41261 .14476 .42255 .15573 .41147 .14956 .39569 Mtetra
.189 .294 .741 r
.14956 .39569 .15573 .41147 .16561 .41016 .15848 .40274 Mtetra
.591 .706 .923 r
.15848 .40274 .16561 .41016 .17561 .40819 .16851 .40063 Mtetra
.5 .667 .937 r
.16851 .40063 .17561 .40819 .19368 .32995 .17842 .40014 Mtetra
.423 .159 .407 r
.17842 .40014 .19368 .32995 .19638 .39824 .18943 .38962 Mtetra
.536 .65 .908 r
.18943 .38962 .19638 .39824 .20653 .39605 .19946 .38872 Mtetra
.603 .716 .924 r
.19946 .38872 .20653 .39605 .21672 .39399 .2097 .3863 Mtetra
.471 .651 .938 r
.2097 .3863 .21672 .39399 .22902 .36967 .21976 .38626 Mtetra
0 0 0 r
.21976 .38626 .22902 .36967 .2378 .38373 .23089 .37534 Mtetra
.558 .668 .911 r
.23089 .37534 .2378 .38373 .24816 .38128 .24117 .37393 Mtetra
.614 .722 .923 r
.24117 .37393 .24816 .38128 .25857 .37868 .25161 .37121 Mtetra
.581 .707 .929 r
.25161 .37121 .25857 .37868 .26866 .38079 .26205 .36921 Mtetra
.8 .689 .742 r
.26205 .36921 .26866 .38079 .27998 .36791 .27345 .35559 Mtetra
.382 .482 .837 r
.27345 .35559 .27998 .36791 .29048 .36589 .28359 .35837 Mtetra
.616 .721 .92 r
.28359 .35837 .29048 .36589 .3011 .36289 .29422 .35556 Mtetra
.626 .731 .922 r
.29422 .35556 .3011 .36289 .31176 .36001 .30492 .3525 Mtetra
.595 .715 .927 r
.30492 .3525 .31176 .36001 .32226 .36048 .31562 .35014 Mtetra
.844 .72 .726 r
.31562 .35014 .32226 .36048 .33357 .34867 .32731 .33275 Mtetra
.272 .351 .762 r
.32731 .33275 .33357 .34867 .34431 .34671 .33755 .33906 Mtetra
.62 .722 .919 r
.33755 .33906 .34431 .34671 .35517 .34348 .34842 .33611 Mtetra
.638 .738 .921 r
.34842 .33611 .35517 .34348 .3661 .34004 .35936 .3327 Mtetra
.64 .74 .921 r
.35936 .3327 .3661 .34004 .37706 .33662 .37036 .32921 Mtetra
.634 .737 .922 r
.37036 .32921 .37706 .33662 .38806 .33359 .38139 .32586 Mtetra
.582 .708 .929 r
.38139 .32586 .38806 .33359 .39877 .33918 .39243 .3237 Mtetra
.755 .634 .727 r
.39243 .3237 .39877 .33918 .41041 .32212 .40391 .31147 Mtetra
.489 .584 .877 r
.40391 .31147 .41041 .32212 .42153 .31944 .41495 .31176 Mtetra
.632 .731 .919 r
.41495 .31176 .42153 .31944 .43273 .31587 .42617 .3084 Mtetra
.647 .744 .92 r
.42617 .3084 .43273 .31587 .44399 .31206 .43745 .30464 Mtetra
.652 .748 .92 r
.43745 .30464 .44399 .31206 .4553 .30813 .44879 .30073 Mtetra
.655 .751 .92 r
.44879 .30073 .4553 .30813 .46666 .30413 .46018 .29672 Mtetra
.657 .752 .92 r
.46018 .29672 .46666 .30413 .47806 .30007 .47161 .29265 Mtetra
.658 .753 .92 r
.47161 .29265 .47806 .30007 .48951 .29596 .4831 .28852 Mtetra
.659 .754 .92 r
.4831 .28852 .48951 .29596 .50102 .29183 .49463 .28437 Mtetra
.49463 .28437 .50102 .29183 .51256 .28769 .50621 .28019 Mtetra
.50621 .28019 .51256 .28769 .52416 .28353 .51784 .27599 Mtetra
.51784 .27599 .52416 .28353 .53581 .27936 .52952 .27179 Mtetra
.658 .753 .92 r
.52952 .27179 .53581 .27936 .5475 .27518 .54124 .26757 Mtetra
.54124 .26757 .5475 .27518 .55924 .27099 .55302 .26335 Mtetra
.55302 .26335 .55924 .27099 .57104 .26678 .56485 .25911 Mtetra
.56485 .25911 .57104 .26678 .58288 .26257 .57672 .25485 Mtetra
.57672 .25485 .58288 .26257 .59477 .25833 .58865 .25058 Mtetra
.58865 .25058 .59477 .25833 .60672 .25408 .60063 .2463 Mtetra
.657 .753 .92 r
.60063 .2463 .60672 .25408 .61871 .24982 .61266 .242 Mtetra
.61266 .242 .61871 .24982 .63076 .24554 .62474 .23768 Mtetra
.62474 .23768 .63076 .24554 .64286 .24124 .63688 .23335 Mtetra
.63688 .23335 .64286 .24124 .65501 .23692 .64906 .229 Mtetra
.657 .752 .92 r
.64906 .229 .65501 .23692 .66721 .23259 .6613 .22463 Mtetra
.6613 .22463 .66721 .23259 .67947 .22824 .67359 .22025 Mtetra
.67359 .22025 .67947 .22824 .69178 .22387 .68594 .21584 Mtetra
.68594 .21584 .69178 .22387 .70414 .21949 .69834 .21142 Mtetra
.69834 .21142 .70414 .21949 .71655 .21508 .71079 .20698 Mtetra
.71079 .20698 .71655 .21508 .72902 .21066 .7233 .20252 Mtetra
.7233 .20252 .72902 .21066 .74155 .20622 .73586 .19804 Mtetra
.73586 .19804 .74155 .20622 .75413 .20176 .74848 .19355 Mtetra
.389 .517 .865 r
.08148 .41601 .08832 .42677 .09796 .42539 .09067 .418 Mtetra
.566 .696 .928 r
.09067 .418 .09796 .42539 .10746 .42542 .10039 .41639 Mtetra
.892 .714 .653 r
.10039 .41639 .10746 .42542 .11833 .41509 .1144 .38179 Mtetra
0 0 .415 r
.1144 .38179 .11833 .41509 .12803 .41426 .1208 .40677 Mtetra
.58 .699 .924 r
.1208 .40677 .12803 .41426 .13788 .41261 .13069 .40488 Mtetra
.4 .615 .938 r
.13069 .40488 .13788 .41261 .14956 .39569 .1403 .40579 Mtetra
0 0 0 r
.1403 .40579 .14956 .39569 .15848 .40274 .15137 .39461 Mtetra
.556 .672 .916 r
.15137 .39461 .15848 .40274 .16851 .40063 .16133 .39324 Mtetra
.584 .707 .927 r
.16133 .39324 .16851 .40063 .17842 .40014 .17142 .39122 Mtetra
.929 .707 .581 r
.17142 .39122 .17842 .40014 .18943 .38962 .18974 .31262 Mtetra
0 0 .247 r
.18974 .31262 .18943 .38962 .19946 .38872 .19237 .38111 Mtetra
.595 .706 .921 r
.19237 .38111 .19946 .38872 .2097 .3863 .20261 .37887 Mtetra
.587 .71 .928 r
.20261 .37887 .2097 .3863 .21976 .38626 .21288 .37674 Mtetra
.877 .723 .687 r
.21288 .37674 .21976 .38626 .23089 .37534 .22532 .35227 Mtetra
.038 .106 .607 r
.22532 .35227 .23089 .37534 .24117 .37393 .23415 .36633 Mtetra
.604 .712 .921 r
.23415 .36633 .24117 .37393 .25161 .37121 .24459 .36381 Mtetra
.61 .722 .925 r
.24459 .36381 .25161 .37121 .26205 .36921 .2551 .36115 Mtetra
.318 .566 .927 r
.2551 .36115 .26205 .36921 .27345 .35559 .26527 .36321 Mtetra
.656 .908 .587 r
.26527 .36321 .27345 .35559 .28359 .35837 .2767 .35022 Mtetra
.585 .692 .915 r
.2767 .35022 .28359 .35837 .29422 .35556 .28729 .34813 Mtetra
.625 .729 .922 r
.28729 .34813 .29422 .35556 .30492 .3525 .29801 .34507 Mtetra
.62 .728 .924 r
.29801 .34507 .30492 .3525 .31562 .35014 .30877 .34212 Mtetra
.443 .634 .937 r
.30877 .34212 .31562 .35014 .32731 .33275 .31936 .34253 Mtetra
0 0 0 r
.31936 .34253 .32731 .33275 .33755 .33906 .33078 .33062 Mtetra
.581 .685 .912 r
.33078 .33062 .33755 .33906 .34842 .33611 .34162 .32859 Mtetra
.632 .733 .92 r
.34162 .32859 .34842 .33611 .35936 .3327 .35258 .32529 Mtetra
.64 .74 .921 r
.35258 .32529 .35936 .3327 .37036 .32921 .3636 .32177 Mtetra
.638 .739 .922 r
.3636 .32177 .37036 .32921 .38139 .32586 .37467 .31828 Mtetra
.622 .73 .924 r
.37467 .31828 .38139 .32586 .39243 .3237 .38577 .31518 Mtetra
.052 .389 .849 r
.38577 .31518 .39243 .3237 .40391 .31147 .39657 .32073 Mtetra
.678 .872 .485 r
.39657 .32073 .40391 .31147 .41495 .31176 .40833 .30354 Mtetra
.607 .707 .915 r
.40833 .30354 .41495 .31176 .42617 .3084 .41955 .30079 Mtetra
.642 .74 .92 r
.41955 .30079 .42617 .3084 .43745 .30464 .43086 .29714 Mtetra
.65 .747 .92 r
.43086 .29714 .43745 .30464 .44879 .30073 .44223 .29325 Mtetra
.654 .75 .92 r
.44223 .29325 .44879 .30073 .46018 .29672 .45364 .28924 Mtetra
.656 .751 .92 r
.45364 .28924 .46018 .29672 .47161 .29265 .46511 .28516 Mtetra
.658 .753 .92 r
.46511 .28516 .47161 .29265 .4831 .28852 .47663 .28102 Mtetra
.659 .753 .92 r
.47663 .28102 .4831 .28852 .49463 .28437 .48819 .27684 Mtetra
.659 .754 .92 r
.48819 .27684 .49463 .28437 .50621 .28019 .4998 .27263 Mtetra
.4998 .27263 .50621 .28019 .51784 .27599 .51146 .2684 Mtetra
.51146 .2684 .51784 .27599 .52952 .27179 .52317 .26416 Mtetra
.658 .753 .92 r
.52317 .26416 .52952 .27179 .54124 .26757 .53494 .25991 Mtetra
.53494 .25991 .54124 .26757 .55302 .26335 .54675 .25564 Mtetra
.54675 .25564 .55302 .26335 .56485 .25911 .55861 .25137 Mtetra
.55861 .25137 .56485 .25911 .57672 .25485 .57052 .24708 Mtetra
.57052 .24708 .57672 .25485 .58865 .25058 .58248 .24278 Mtetra
.58248 .24278 .58865 .25058 .60063 .2463 .59449 .23846 Mtetra
.59449 .23846 .60063 .2463 .61266 .242 .60656 .23412 Mtetra
.657 .753 .92 r
.60656 .23412 .61266 .242 .62474 .23768 .61867 .22977 Mtetra
.61867 .22977 .62474 .23768 .63688 .23335 .63084 .2254 Mtetra
.63084 .2254 .63688 .23335 .64906 .229 .64307 .22102 Mtetra
.657 .752 .92 r
.64307 .22102 .64906 .229 .6613 .22463 .65534 .21661 Mtetra
.65534 .21661 .6613 .22463 .67359 .22025 .66767 .21219 Mtetra
.66767 .21219 .67359 .22025 .68594 .21584 .68005 .20775 Mtetra
.68005 .20775 .68594 .21584 .69834 .21142 .69249 .20329 Mtetra
.69249 .20329 .69834 .21142 .71079 .20698 .70498 .19882 Mtetra
.70498 .19882 .71079 .20698 .7233 .20252 .71753 .19432 Mtetra
.71753 .19432 .7233 .20252 .73586 .19804 .73013 .18981 Mtetra
.73013 .18981 .73586 .19804 .74848 .19355 .74279 .18527 Mtetra
.786 .972 .678 r
.07198 .42404 .08148 .41601 .09067 .418 .08338 .41019 Mtetra
.558 .681 .921 r
.08338 .41019 .09067 .418 .10039 .41639 .09309 .40875 Mtetra
.466 .65 .939 r
.09309 .40875 .10039 .41639 .1144 .38179 .10267 .40874 Mtetra
.212 0 .191 r
.10267 .40874 .1144 .38179 .1208 .40677 .11364 .39831 Mtetra
.532 .653 .912 r
.11364 .39831 .1208 .40677 .13069 .40488 .12341 .39743 Mtetra
.568 .699 .929 r
.12341 .39743 .13069 .40488 .1403 .40579 .13334 .39571 Mtetra
.835 .709 .726 r
.13334 .39571 .1403 .40579 .15137 .39461 .14514 .37868 Mtetra
.187 .292 .74 r
.14514 .37868 .15137 .39461 .16133 .39324 .15412 .3857 Mtetra
.591 .706 .923 r
.15412 .3857 .16133 .39324 .17142 .39122 .16424 .38353 Mtetra
.501 .667 .937 r
.16424 .38353 .17142 .39122 .18974 .31262 .17422 .38298 Mtetra
.417 .151 .401 r
.17422 .38298 .18974 .31262 .19237 .38111 .18534 .37237 Mtetra
.535 .65 .908 r
.18534 .37237 .19237 .38111 .20261 .37887 .19546 .37141 Mtetra
.603 .716 .924 r
.19546 .37141 .20261 .37887 .21288 .37674 .20579 .36892 Mtetra
.471 .651 .938 r
.20579 .36892 .21288 .37674 .22532 .35227 .21593 .36883 Mtetra
0 0 0 r
.21593 .36883 .22532 .35227 .23415 .36633 .22716 .3578 Mtetra
.558 .668 .912 r
.22716 .3578 .23415 .36633 .24459 .36381 .23753 .35634 Mtetra
.614 .722 .923 r
.23753 .35634 .24459 .36381 .2551 .36115 .24806 .35355 Mtetra
.581 .707 .929 r
.24806 .35355 .2551 .36115 .26527 .36321 .25859 .35148 Mtetra
.801 .69 .742 r
.25859 .35148 .26527 .36321 .2767 .35022 .27011 .33775 Mtetra
.381 .482 .837 r
.27011 .33775 .2767 .35022 .28729 .34813 .28033 .34048 Mtetra
.616 .721 .92 r
.28033 .34048 .28729 .34813 .29801 .34507 .29105 .33761 Mtetra
.626 .731 .922 r
.29105 .33761 .29801 .34507 .30877 .34212 .30185 .33448 Mtetra
.595 .715 .927 r
.30185 .33448 .30877 .34212 .31936 .34253 .31264 .33204 Mtetra
.845 .72 .726 r
.31264 .33204 .31936 .34253 .33078 .33062 .32445 .31453 Mtetra
.27 .35 .762 r
.32445 .31453 .33078 .33062 .34162 .32859 .33478 .3208 Mtetra
.62 .722 .919 r
.33478 .3208 .34162 .32859 .35258 .32529 .34575 .31778 Mtetra
.638 .738 .921 r
.34575 .31778 .35258 .32529 .3636 .32177 .35679 .31429 Mtetra
.64 .74 .921 r
.35679 .31429 .3636 .32177 .37467 .31828 .36789 .31073 Mtetra
.634 .737 .922 r
.36789 .31073 .37467 .31828 .38577 .31518 .37903 .3073 Mtetra
.583 .708 .929 r
.37903 .3073 .38577 .31518 .39657 .32073 .39017 .30507 Mtetra
.755 .635 .727 r
.39017 .30507 .39657 .32073 .40833 .30354 .40176 .29273 Mtetra
.489 .584 .877 r
.40176 .29273 .40833 .30354 .41955 .30079 .4129 .29296 Mtetra
.632 .731 .919 r
.4129 .29296 .41955 .30079 .43086 .29714 .42423 .28952 Mtetra
.647 .744 .92 r
.42423 .28952 .43086 .29714 .44223 .29325 .43562 .28569 Mtetra
.652 .748 .92 r
.43562 .28569 .44223 .29325 .45364 .28924 .44706 .28169 Mtetra
.655 .751 .92 r
.44706 .28169 .45364 .28924 .46511 .28516 .45856 .27761 Mtetra
.657 .752 .92 r
.45856 .27761 .46511 .28516 .47663 .28102 .47011 .27345 Mtetra
.658 .753 .92 r
.47011 .27345 .47663 .28102 .48819 .27684 .4817 .26925 Mtetra
.659 .754 .92 r
.4817 .26925 .48819 .27684 .4998 .27263 .49335 .26501 Mtetra
.49335 .26501 .4998 .27263 .51146 .2684 .50504 .26074 Mtetra
.50504 .26074 .51146 .2684 .52317 .26416 .51678 .25647 Mtetra
.51678 .25647 .52317 .26416 .53494 .25991 .52858 .25218 Mtetra
.658 .753 .92 r
.52858 .25218 .53494 .25991 .54675 .25564 .54042 .24788 Mtetra
.54042 .24788 .54675 .25564 .55861 .25137 .55232 .24357 Mtetra
.55232 .24357 .55861 .25137 .57052 .24708 .56426 .23924 Mtetra
.56426 .23924 .57052 .24708 .58248 .24278 .57626 .2349 Mtetra
.57626 .2349 .58248 .24278 .59449 .23846 .5883 .23055 Mtetra
.5883 .23055 .59449 .23846 .60656 .23412 .60041 .22618 Mtetra
.657 .753 .92 r
.60041 .22618 .60656 .23412 .61867 .22977 .61256 .22179 Mtetra
.61256 .22179 .61867 .22977 .63084 .2254 .62476 .21739 Mtetra
.62476 .21739 .63084 .2254 .64307 .22102 .63702 .21297 Mtetra
.63702 .21297 .64307 .22102 .65534 .21661 .64933 .20853 Mtetra
.657 .752 .92 r
.64933 .20853 .65534 .21661 .66767 .21219 .6617 .20407 Mtetra
.6617 .20407 .66767 .21219 .68005 .20775 .67412 .19959 Mtetra
.67412 .19959 .68005 .20775 .69249 .20329 .6866 .1951 Mtetra
.6866 .1951 .69249 .20329 .70498 .19882 .69913 .19058 Mtetra
.69913 .19058 .70498 .19882 .71753 .19432 .71171 .18605 Mtetra
.71171 .18605 .71753 .19432 .73013 .18981 .72435 .1815 Mtetra
.72435 .1815 .73013 .18981 .74279 .18527 .73705 .17693 Mtetra
.766 .654 .738 r
.06532 .41108 .07198 .42404 .08338 .41019 .07646 .39929 Mtetra
.388 .516 .866 r
.07646 .39929 .08338 .41019 .09309 .40875 .08571 .40123 Mtetra
.567 .696 .928 r
.08571 .40123 .09309 .40875 .10267 .40874 .09552 .39957 Mtetra
.893 .714 .652 r
.09552 .39957 .10267 .40874 .11364 .39831 .10969 .36478 Mtetra
0 0 .41 r
.10969 .36478 .11364 .39831 .12341 .39743 .1161 .3898 Mtetra
.58 .699 .924 r
.1161 .3898 .12341 .39743 .13334 .39571 .12607 .38786 Mtetra
.401 .616 .938 r
.12607 .38786 .13334 .39571 .14514 .37868 .13575 .38871 Mtetra
0 0 0 r
.13575 .38871 .14514 .37868 .15412 .3857 .14693 .37743 Mtetra
.556 .672 .916 r
.14693 .37743 .15412 .3857 .16424 .38353 .15698 .37601 Mtetra
.584 .707 .927 r
.15698 .37601 .16424 .38353 .17422 .38298 .16715 .37392 Mtetra
.93 .707 .58 r
.16715 .37392 .17422 .38298 .18534 .37237 .18573 .29497 Mtetra
0 0 .24 r
.18573 .29497 .18534 .37237 .19546 .37141 .18828 .36367 Mtetra
.594 .706 .921 r
.18828 .36367 .19546 .37141 .20579 .36892 .19861 .36135 Mtetra
.587 .71 .928 r
.19861 .36135 .20579 .36892 .21593 .36883 .20897 .35916 Mtetra
.878 .724 .687 r
.20897 .35916 .21593 .36883 .22716 .3578 .22154 .33454 Mtetra
.033 .103 .605 r
.22154 .33454 .22716 .3578 .23753 .35634 .23043 .34859 Mtetra
.604 .712 .921 r
.23043 .34859 .23753 .35634 .24806 .35355 .24097 .34601 Mtetra
.61 .722 .924 r
.24097 .34601 .24806 .35355 .25859 .35148 .25156 .34328 Mtetra
.32 .567 .927 r
.25156 .34328 .25859 .35148 .27011 .33775 .26182 .3453 Mtetra
.666 .914 .597 r
.26182 .3453 .27011 .33775 .28033 .34048 .27336 .33219 Mtetra
.585 .692 .915 r
.27336 .33219 .28033 .34048 .29105 .33761 .28405 .33004 Mtetra
.625 .729 .922 r
.28405 .33004 .29105 .33761 .30185 .33448 .29486 .3269 Mtetra
.62 .728 .924 r
.29486 .3269 .30185 .33448 .31264 .33204 .30572 .32388 Mtetra
.443 .634 .936 r
.30572 .32388 .31264 .33204 .32445 .31453 .3164 .32423 Mtetra
0 0 0 r
.3164 .32423 .32445 .31453 .33478 .3208 .32793 .31222 Mtetra
.581 .685 .912 r
.32793 .31222 .33478 .3208 .34575 .31778 .33887 .31012 Mtetra
.632 .733 .92 r
.33887 .31012 .34575 .31778 .35679 .31429 .34993 .30674 Mtetra
.64 .74 .921 r
.34993 .30674 .35679 .31429 .36789 .31073 .36106 .30315 Mtetra
.638 .739 .922 r
.36106 .30315 .36789 .31073 .37903 .3073 .37223 .29958 Mtetra
.622 .73 .924 r
.37223 .29958 .37903 .3073 .39017 .30507 .38343 .2964 Mtetra
.057 .391 .851 r
.38343 .2964 .39017 .30507 .40176 .29273 .39433 .30191 Mtetra
.687 .878 .494 r
.39433 .30191 .40176 .29273 .4129 .29296 .40621 .2846 Mtetra
.607 .707 .915 r
.40621 .2846 .4129 .29296 .42423 .28952 .41754 .28177 Mtetra
.642 .74 .92 r
.41754 .28177 .42423 .28952 .43562 .28569 .42896 .27804 Mtetra
.65 .747 .92 r
.42896 .27804 .43562 .28569 .44706 .28169 .44043 .27407 Mtetra
.654 .75 .92 r
.44043 .27407 .44706 .28169 .45856 .27761 .45196 .26998 Mtetra
.656 .751 .92 r
.45196 .26998 .45856 .27761 .47011 .27345 .46354 .26582 Mtetra
.658 .753 .92 r
.46354 .26582 .47011 .27345 .4817 .26925 .47516 .26159 Mtetra
.659 .753 .92 r
.47516 .26159 .4817 .26925 .49335 .26501 .48684 .25733 Mtetra
.659 .754 .92 r
.48684 .25733 .49335 .26501 .50504 .26074 .49857 .25303 Mtetra
.49857 .25303 .50504 .26074 .51678 .25647 .51034 .24872 Mtetra
.51034 .24872 .51678 .25647 .52858 .25218 .52217 .24439 Mtetra
.658 .753 .92 r
.52217 .24439 .52858 .25218 .54042 .24788 .53405 .24006 Mtetra
.53405 .24006 .54042 .24788 .55232 .24357 .54597 .23571 Mtetra
.54597 .23571 .55232 .24357 .56426 .23924 .55795 .23135 Mtetra
.55795 .23135 .56426 .23924 .57626 .2349 .56999 .22697 Mtetra
.56999 .22697 .57626 .2349 .5883 .23055 .58207 .22258 Mtetra
.58207 .22258 .5883 .23055 .60041 .22618 .5942 .21817 Mtetra
.5942 .21817 .60041 .22618 .61256 .22179 .60639 .21375 Mtetra
.657 .753 .92 r
.60639 .21375 .61256 .22179 .62476 .21739 .61863 .20931 Mtetra
.61863 .20931 .62476 .21739 .63702 .21297 .63093 .20485 Mtetra
.63093 .20485 .63702 .21297 .64933 .20853 .64328 .20037 Mtetra
.657 .752 .92 r
.64328 .20037 .64933 .20853 .6617 .20407 .65568 .19588 Mtetra
.65568 .19588 .6617 .20407 .67412 .19959 .66814 .19137 Mtetra
.66814 .19137 .67412 .19959 .6866 .1951 .68065 .18683 Mtetra
.68065 .18683 .6866 .1951 .69913 .19058 .69322 .18228 Mtetra
.69322 .18228 .69913 .19058 .71171 .18605 .70584 .17771 Mtetra
.70584 .17771 .71171 .18605 .72435 .1815 .71852 .17312 Mtetra
.71852 .17312 .72435 .1815 .73705 .17693 .73126 .16851 Mtetra
.043 .403 .857 r
.05793 .40302 .06532 .41108 .07646 .39929 .06683 .40726 Mtetra
.792 .974 .685 r
.06683 .40726 .07646 .39929 .08571 .40123 .07834 .39329 Mtetra
.558 .681 .921 r
.07834 .39329 .08571 .40123 .09552 .39957 .08813 .3918 Mtetra
.466 .65 .939 r
.08813 .3918 .09552 .39957 .10969 .36478 .09778 .39173 Mtetra
.2 0 .178 r
.09778 .39173 .10969 .36478 .1161 .3898 .10885 .38121 Mtetra
.531 .653 .913 r
.10885 .38121 .1161 .3898 .12607 .38786 .11871 .38027 Mtetra
.568 .699 .929 r
.11871 .38027 .12607 .38786 .13575 .38871 .12872 .3785 Mtetra
.835 .71 .726 r
.12872 .3785 .13575 .38871 .14693 .37743 .14064 .36134 Mtetra
.184 .29 .74 r
.14064 .36134 .14693 .37743 .15698 .37601 .14968 .36834 Mtetra
.591 .706 .923 r
.14968 .36834 .15698 .37601 .16715 .37392 .15988 .3661 Mtetra
.501 .667 .937 r
.15988 .3661 .16715 .37392 .18573 .29497 .16995 .36549 Mtetra
.411 .143 .394 r
.16995 .36549 .18573 .29497 .18828 .36367 .18117 .35478 Mtetra
.535 .65 .908 r
.18117 .35478 .18828 .36367 .19861 .36135 .19137 .35376 Mtetra
.603 .716 .924 r
.19137 .35376 .19861 .36135 .20897 .35916 .20179 .3512 Mtetra
.472 .651 .938 r
.20179 .3512 .20897 .35916 .22154 .33454 .21202 .35106 Mtetra
0 0 0 r
.21202 .35106 .22154 .33454 .23043 .34859 .22336 .33993 Mtetra
.557 .668 .912 r
.22336 .33993 .23043 .34859 .24097 .34601 .23382 .3384 Mtetra
.614 .722 .923 r
.23382 .3384 .24097 .34601 .25156 .34328 .24445 .33554 Mtetra
.581 .707 .929 r
.24445 .33554 .25156 .34328 .26182 .3453 .25506 .3334 Mtetra
.801 .69 .743 r
.25506 .3334 .26182 .3453 .27336 .33219 .2667 .31956 Mtetra
.38 .481 .837 r
.2667 .31956 .27336 .33219 .28405 .33004 .27701 .32224 Mtetra
.616 .721 .92 r
.27701 .32224 .28405 .33004 .29486 .3269 .28783 .3193 Mtetra
.626 .731 .922 r
.28783 .3193 .29486 .3269 .30572 .32388 .29872 .31609 Mtetra
.595 .715 .927 r
.29872 .31609 .30572 .32388 .3164 .32423 .30961 .31359 Mtetra
.846 .721 .726 r
.30961 .31359 .3164 .32423 .32793 .31222 .32154 .29595 Mtetra
.268 .349 .762 r
.32154 .29595 .32793 .31222 .33887 .31012 .33195 .30218 Mtetra
.62 .722 .919 r
.33195 .30218 .33887 .31012 .34993 .30674 .34302 .29909 Mtetra
.638 .738 .921 r
.34302 .29909 .34993 .30674 .36106 .30315 .35417 .29552 Mtetra
.64 .74 .921 r
.35417 .29552 .36106 .30315 .37223 .29958 .36537 .29188 Mtetra
.634 .737 .922 r
.36537 .29188 .37223 .29958 .38343 .2964 .37662 .28838 Mtetra
.583 .708 .929 r
.37662 .28838 .38343 .2964 .39433 .30191 .38786 .28608 Mtetra
.756 .635 .727 r
.38786 .28608 .39433 .30191 .40621 .2846 .39957 .27363 Mtetra
.488 .584 .877 r
.39957 .27363 .40621 .2846 .41754 .28177 .41081 .27378 Mtetra
.632 .731 .919 r
.41081 .27378 .41754 .28177 .42896 .27804 .42225 .27027 Mtetra
.647 .744 .92 r
.42225 .27027 .42896 .27804 .44043 .27407 .43375 .26636 Mtetra
.652 .748 .92 r
.43375 .26636 .44043 .27407 .45196 .26998 .4453 .26228 Mtetra
.655 .751 .92 r
.4453 .26228 .45196 .26998 .46354 .26582 .45691 .25811 Mtetra
.657 .752 .92 r
.45691 .25811 .46354 .26582 .47516 .26159 .46857 .25387 Mtetra
.658 .753 .92 r
.46857 .25387 .47516 .26159 .48684 .25733 .48028 .24958 Mtetra
.659 .754 .92 r
.48028 .24958 .48684 .25733 .49857 .25303 .49204 .24526 Mtetra
.49204 .24526 .49857 .25303 .51034 .24872 .50385 .24091 Mtetra
.50385 .24091 .51034 .24872 .52217 .24439 .51571 .23655 Mtetra
.51571 .23655 .52217 .24439 .53405 .24006 .52762 .23217 Mtetra
.658 .753 .92 r
.52762 .23217 .53405 .24006 .54597 .23571 .53958 .22779 Mtetra
.53958 .22779 .54597 .23571 .55795 .23135 .5516 .22339 Mtetra
.5516 .22339 .55795 .23135 .56999 .22697 .56366 .21897 Mtetra
.56366 .21897 .56999 .22697 .58207 .22258 .57578 .21455 Mtetra
.57578 .21455 .58207 .22258 .5942 .21817 .58795 .2101 Mtetra
.58795 .2101 .5942 .21817 .60639 .21375 .60018 .20564 Mtetra
.657 .753 .92 r
.60018 .20564 .60639 .21375 .61863 .20931 .61245 .20116 Mtetra
.61245 .20116 .61863 .20931 .63093 .20485 .62479 .19667 Mtetra
.62479 .19667 .63093 .20485 .64328 .20037 .63717 .19216 Mtetra
.63717 .19216 .64328 .20037 .65568 .19588 .64961 .18762 Mtetra
.657 .752 .92 r
.64961 .18762 .65568 .19588 .66814 .19137 .66211 .18307 Mtetra
.66211 .18307 .66814 .19137 .68065 .18683 .67466 .1785 Mtetra
.67466 .1785 .68065 .18683 .69322 .18228 .68727 .17392 Mtetra
.68727 .17392 .69322 .18228 .70584 .17771 .69993 .16931 Mtetra
.69993 .16931 .70584 .17771 .71852 .17312 .71265 .16468 Mtetra
.71265 .16468 .71852 .17312 .73126 .16851 .72542 .16003 Mtetra
.539 .684 .932 r
.05042 .39537 .05793 .40302 .06683 .40726 .0601 .39415 Mtetra
.766 .654 .738 r
.0601 .39415 .06683 .40726 .07834 .39329 .07134 .38226 Mtetra
.387 .516 .866 r
.07134 .38226 .07834 .39329 .08813 .3918 .08066 .38416 Mtetra
.567 .696 .928 r
.08066 .38416 .08813 .3918 .09778 .39173 .09055 .38243 Mtetra
.895 .715 .652 r
.09055 .38243 .09778 .39173 .10885 .38121 .10489 .34745 Mtetra
0 0 .405 r
.10489 .34745 .10885 .38121 .11871 .38027 .11131 .37252 Mtetra
.58 .699 .924 r
.11131 .37252 .11871 .38027 .12872 .3785 .12136 .37051 Mtetra
.401 .616 .937 r
.12136 .37051 .12872 .3785 .14064 .36134 .13112 .37131 Mtetra
0 0 0 r
.13112 .37131 .14064 .36134 .14968 .36834 .14241 .35993 Mtetra
.556 .672 .916 r
.14241 .35993 .14968 .36834 .15988 .3661 .15254 .35844 Mtetra
.584 .707 .927 r
.15254 .35844 .15988 .3661 .16995 .36549 .16279 .35629 Mtetra
.931 .708 .578 r
.16279 .35629 .16995 .36549 .18117 .35478 .18164 .27699 Mtetra
0 0 .234 r
.18164 .27699 .18117 .35478 .19137 .35376 .18411 .34588 Mtetra
.594 .706 .921 r
.18411 .34588 .19137 .35376 .20179 .3512 .19453 .3435 Mtetra
.587 .71 .928 r
.19453 .3435 .20179 .3512 .21202 .35106 .20498 .34125 Mtetra
.879 .725 .686 r
.20498 .34125 .21202 .35106 .22336 .33993 .21769 .31647 Mtetra
.028 .099 .603 r
.21769 .31647 .22336 .33993 .23382 .3384 .22664 .33052 Mtetra
.604 .712 .921 r
.22664 .33052 .23382 .3384 .24445 .33554 .23727 .32787 Mtetra
.61 .722 .924 r
.23727 .32787 .24445 .33554 .25506 .3334 .24796 .32507 Mtetra
.321 .567 .927 r
.24796 .32507 .25506 .3334 .2667 .31956 .2583 .32703 Mtetra
.676 .921 .606 r
.2583 .32703 .2667 .31956 .27701 .32224 .26996 .31381 Mtetra
.585 .692 .915 r
.26996 .31381 .27701 .32224 .28783 .3193 .28074 .31159 Mtetra
.625 .729 .922 r
.28074 .31159 .28783 .3193 .29872 .31609 .29165 .30838 Mtetra
.62 .728 .924 r
.29165 .30838 .29872 .31609 .30961 .31359 .30261 .30529 Mtetra
.444 .635 .936 r
.30261 .30529 .30961 .31359 .32154 .29595 .31338 .30557 Mtetra
0 0 0 r
.31338 .30557 .32154 .29595 .33195 .30218 .32503 .29345 Mtetra
.581 .685 .912 r
.32503 .29345 .33195 .30218 .34302 .29909 .33607 .29128 Mtetra
.632 .733 .92 r
.33607 .29128 .34302 .29909 .35417 .29552 .34723 .28782 Mtetra
.64 .74 .921 r
.34723 .28782 .35417 .29552 .36537 .29188 .35846 .28416 Mtetra
.638 .739 .922 r
.35846 .28416 .36537 .29188 .37662 .28838 .36974 .28051 Mtetra
.622 .73 .924 r
.36974 .28051 .37662 .28838 .38786 .28608 .38105 .27725 Mtetra
.062 .394 .852 r
.38105 .27725 .38786 .28608 .39957 .27363 .39204 .28272 Mtetra
.695 .884 .503 r
.39204 .28272 .39957 .27363 .41081 .27378 .40405 .26527 Mtetra
.607 .707 .915 r
.40405 .26527 .41081 .27378 .42225 .27027 .41549 .26237 Mtetra
.642 .74 .92 r
.41549 .26237 .42225 .27027 .43375 .26636 .42701 .25855 Mtetra
.65 .747 .92 r
.42701 .25855 .43375 .26636 .4453 .26228 .4386 .2545 Mtetra
.654 .75 .92 r
.4386 .2545 .4453 .26228 .45691 .25811 .45024 .25033 Mtetra
.656 .751 .92 r
.45024 .25033 .45691 .25811 .46857 .25387 .46193 .24608 Mtetra
.658 .753 .92 r
.46193 .24608 .46857 .25387 .48028 .24958 .47367 .24177 Mtetra
.659 .753 .92 r
.47367 .24177 .48028 .24958 .49204 .24526 .48546 .23742 Mtetra
.659 .754 .92 r
.48546 .23742 .49204 .24526 .50385 .24091 .4973 .23304 Mtetra
.4973 .23304 .50385 .24091 .51571 .23655 .5092 .22864 Mtetra
.5092 .22864 .51571 .23655 .52762 .23217 .52114 .22423 Mtetra
.658 .753 .92 r
.52114 .22423 .52762 .23217 .53958 .22779 .53314 .2198 Mtetra
.53314 .2198 .53958 .22779 .5516 .22339 .54519 .21536 Mtetra
.54519 .21536 .5516 .22339 .56366 .21897 .55729 .21091 Mtetra
.55729 .21091 .56366 .21897 .57578 .21455 .56944 .20645 Mtetra
.56944 .20645 .57578 .21455 .58795 .2101 .58165 .20197 Mtetra
.58165 .20197 .58795 .2101 .60018 .20564 .59391 .19747 Mtetra
.59391 .19747 .60018 .20564 .61245 .20116 .60622 .19295 Mtetra
.657 .753 .92 r
.60622 .19295 .61245 .20116 .62479 .19667 .61859 .18842 Mtetra
.61859 .18842 .62479 .19667 .63717 .19216 .63102 .18387 Mtetra
.63102 .18387 .63717 .19216 .64961 .18762 .64349 .1793 Mtetra
.657 .752 .92 r
.64349 .1793 .64961 .18762 .66211 .18307 .65603 .17471 Mtetra
.65603 .17471 .66211 .18307 .67466 .1785 .66862 .17011 Mtetra
.66862 .17011 .67466 .1785 .68727 .17392 .68126 .16548 Mtetra
.68126 .16548 .68727 .17392 .69993 .16931 .69396 .16083 Mtetra
.69396 .16083 .69993 .16931 .71265 .16468 .70672 .15617 Mtetra
.70672 .15617 .71265 .16468 .72542 .16003 .71954 .15148 Mtetra
.556 .683 .924 r
.04289 .38745 .05042 .39537 .0601 .39415 .05262 .38595 Mtetra
.047 .405 .858 r
.05262 .38595 .0601 .39415 .07134 .38226 .06158 .39016 Mtetra
.798 .977 .691 r
.06158 .39016 .07134 .38226 .08066 .38416 .0732 .37609 Mtetra
.558 .681 .921 r
.0732 .37609 .08066 .38416 .09055 .38243 .08307 .37453 Mtetra
.467 .65 .938 r
.08307 .37453 .09055 .38243 .10489 .34745 .0928 .37441 Mtetra
.188 0 .166 r
.0928 .37441 .10489 .34745 .11131 .37252 .10398 .36379 Mtetra
.531 .653 .913 r
.10398 .36379 .11131 .37252 .12136 .37051 .11391 .36279 Mtetra
.569 .699 .929 r
.11391 .36279 .12136 .37051 .13112 .37131 .12401 .36095 Mtetra
.836 .711 .726 r
.12401 .36095 .13112 .37131 .14241 .35993 .13605 .34367 Mtetra
.181 .288 .739 r
.13605 .34367 .14241 .35993 .15254 .35844 .14515 .35064 Mtetra
.591 .706 .923 r
.14515 .35064 .15254 .35844 .16279 .35629 .15544 .34833 Mtetra
.501 .667 .937 r
.15544 .34833 .16279 .35629 .18164 .27699 .16559 .34766 Mtetra
.405 .135 .388 r
.16559 .34766 .18164 .27699 .18411 .34588 .17692 .33686 Mtetra
.535 .65 .909 r
.17692 .33686 .18411 .34588 .19453 .3435 .18721 .33577 Mtetra
.603 .716 .924 r
.18721 .33577 .19453 .3435 .20498 .34125 .19772 .33315 Mtetra
.472 .652 .938 r
.19772 .33315 .20498 .34125 .21769 .31647 .20804 .33294 Mtetra
0 0 0 r
.20804 .33294 .21769 .31647 .22664 .33052 .21949 .32171 Mtetra
.557 .668 .912 r
.21949 .32171 .22664 .33052 .23727 .32787 .23004 .32011 Mtetra
.614 .722 .923 r
.23004 .32011 .23727 .32787 .24796 .32507 .24076 .31718 Mtetra
.581 .707 .929 r
.24076 .31718 .24796 .32507 .2583 .32703 .25147 .31498 Mtetra
.802 .691 .743 r
.25147 .31498 .2583 .32703 .26996 .31381 .26322 .30102 Mtetra
.379 .481 .838 r
.26322 .30102 .26996 .31381 .28074 .31159 .27362 .30365 Mtetra
.616 .721 .92 r
.27362 .30365 .28074 .31159 .29165 .30838 .28454 .30063 Mtetra
.626 .731 .922 r
.28454 .30063 .29165 .30838 .30261 .30529 .29553 .29735 Mtetra
.595 .715 .927 r
.29553 .29735 .30261 .30529 .31338 .30557 .30652 .29477 Mtetra
.846 .722 .726 r
.30652 .29477 .31338 .30557 .32503 .29345 .31857 .277 Mtetra
.266 .348 .761 r
.31857 .277 .32503 .29345 .33607 .29128 .32907 .28319 Mtetra
.62 .722 .919 r
.32907 .28319 .33607 .29128 .34723 .28782 .34025 .28002 Mtetra
.638 .738 .921 r
.34025 .28002 .34723 .28782 .35846 .28416 .3515 .27638 Mtetra
.64 .74 .921 r
.3515 .27638 .35846 .28416 .36974 .28051 .36281 .27266 Mtetra
.634 .737 .922 r
.36281 .27266 .36974 .28051 .38105 .27725 .37416 .26908 Mtetra
.583 .708 .929 r
.37416 .26908 .38105 .27725 .39204 .28272 .38551 .2667 Mtetra
.756 .636 .727 r
.38551 .2667 .39204 .28272 .40405 .26527 .39734 .25413 Mtetra
.488 .584 .877 r
.39734 .25413 .40405 .26527 .41549 .26237 .40868 .25423 Mtetra
.632 .731 .919 r
.40868 .25423 .41549 .26237 .42701 .25855 .42023 .25063 Mtetra
.647 .744 .92 r
.42023 .25063 .42701 .25855 .4386 .2545 .43184 .24663 Mtetra
.652 .748 .92 r
.43184 .24663 .4386 .2545 .45024 .25033 .44351 .24247 Mtetra
.655 .751 .92 r
.44351 .24247 .45024 .25033 .46193 .24608 .45523 .23822 Mtetra
.657 .752 .92 r
.45523 .23822 .46193 .24608 .47367 .24177 .467 .23389 Mtetra
.658 .753 .92 r
.467 .23389 .47367 .24177 .48546 .23742 .47883 .22952 Mtetra
.659 .754 .92 r
.47883 .22952 .48546 .23742 .4973 .23304 .49071 .2251 Mtetra
.49071 .2251 .4973 .23304 .5092 .22864 .50263 .22067 Mtetra
.50263 .22067 .5092 .22864 .52114 .22423 .51461 .21622 Mtetra
.51461 .21622 .52114 .22423 .53314 .2198 .52664 .21175 Mtetra
.658 .753 .92 r
.52664 .21175 .53314 .2198 .54519 .21536 .53873 .20728 Mtetra
.53873 .20728 .54519 .21536 .55729 .21091 .55086 .20279 Mtetra
.55086 .20279 .55729 .21091 .56944 .20645 .56305 .19828 Mtetra
.56305 .19828 .56944 .20645 .58165 .20197 .5753 .19377 Mtetra
.5753 .19377 .58165 .20197 .59391 .19747 .58759 .18923 Mtetra
.58759 .18923 .59391 .19747 .60622 .19295 .59994 .18468 Mtetra
.657 .753 .92 r
.59994 .18468 .60622 .19295 .61859 .18842 .61235 .18011 Mtetra
.61235 .18011 .61859 .18842 .63102 .18387 .62481 .17552 Mtetra
.62481 .17552 .63102 .18387 .64349 .1793 .63733 .17091 Mtetra
.63733 .17091 .64349 .1793 .65603 .17471 .6499 .16628 Mtetra
.657 .752 .92 r
.6499 .16628 .65603 .17471 .66862 .17011 .66252 .16164 Mtetra
.66252 .16164 .66862 .17011 .68126 .16548 .67521 .15697 Mtetra
.67521 .15697 .68126 .16548 .69396 .16083 .68795 .15229 Mtetra
.68795 .15229 .69396 .16083 .70672 .15617 .70075 .14758 Mtetra
.70075 .14758 .70672 .15617 .71954 .15148 .71361 .14285 Mtetra
.444 .577 .892 r
.03562 .37751 .04289 .38745 .05262 .38595 .04502 .37818 Mtetra
.539 .684 .932 r
.04502 .37818 .05262 .38595 .06158 .39016 .05478 .3769 Mtetra
.767 .655 .738 r
.05478 .3769 .06158 .39016 .0732 .37609 .06613 .3649 Mtetra
.386 .516 .866 r
.06613 .3649 .0732 .37609 .08307 .37453 .07552 .36676 Mtetra
.567 .696 .928 r
.07552 .36676 .08307 .37453 .0928 .37441 .08549 .36496 Mtetra
.896 .716 .651 r
.08549 .36496 .0928 .37441 .10398 .36379 .1 .32979 Mtetra
0 0 .401 r
.1 .32979 .10398 .36379 .11391 .36279 .10643 .3549 Mtetra
.58 .699 .924 r
.10643 .3549 .11391 .36279 .12401 .36095 .11657 .35283 Mtetra
.402 .616 .937 r
.11657 .35283 .12401 .36095 .13605 .34367 .1264 .35358 Mtetra
0 0 0 r
.1264 .35358 .13605 .34367 .14515 .35064 .1378 .34209 Mtetra
.555 .672 .916 r
.1378 .34209 .14515 .35064 .15544 .34833 .14801 .34054 Mtetra
.584 .707 .927 r
.14801 .34054 .15544 .34833 .16559 .34766 .15835 .33832 Mtetra
.932 .708 .577 r
.15835 .33832 .16559 .34766 .17692 .33686 .17748 .25866 Mtetra
0 0 .227 r
.17748 .25866 .17692 .33686 .18721 .33577 .17987 .32776 Mtetra
.594 .706 .921 r
.17987 .32776 .18721 .33577 .19772 .33315 .19037 .32531 Mtetra
.587 .71 .928 r
.19037 .32531 .19772 .33315 .20804 .33294 .20092 .32298 Mtetra
.88 .726 .686 r
.20092 .32298 .20804 .33294 .21949 .32171 .21377 .29805 Mtetra
.023 .096 .601 r
.21377 .29805 .21949 .32171 .23004 .32011 .22277 .31209 Mtetra
.604 .712 .921 r
.22277 .31209 .23004 .32011 .24076 .31718 .23349 .30937 Mtetra
.61 .722 .924 r
.23349 .30937 .24076 .31718 .25147 .31498 .24428 .30649 Mtetra
.323 .568 .927 r
.24428 .30649 .25147 .31498 .26322 .30102 .25471 .3084 Mtetra
.685 .927 .616 r
.25471 .3084 .26322 .30102 .27362 .30365 .26649 .29507 Mtetra
.585 .692 .915 r
.26649 .29507 .27362 .30365 .28454 .30063 .27737 .29278 Mtetra
.625 .729 .922 r
.27737 .29278 .28454 .30063 .29553 .29735 .28838 .28949 Mtetra
.62 .728 .924 r
.28838 .28949 .29553 .29735 .30652 .29477 .29943 .28632 Mtetra
.445 .635 .936 r
.29943 .28632 .30652 .29477 .31857 .277 .31031 .28654 Mtetra
0 0 0 r
.31031 .28654 .31857 .277 .32907 .28319 .32207 .27431 Mtetra
.58 .685 .912 r
.32207 .27431 .32907 .28319 .34025 .28002 .33321 .27207 Mtetra
.632 .733 .92 r
.33321 .27207 .34025 .28002 .3515 .27638 .34448 .26853 Mtetra
.64 .74 .921 r
.34448 .26853 .3515 .27638 .36281 .27266 .35582 .26478 Mtetra
.638 .739 .922 r
.35582 .26478 .36281 .27266 .37416 .26908 .3672 .26105 Mtetra
.622 .73 .924 r
.3672 .26105 .37416 .26908 .38551 .2667 .37862 .25772 Mtetra
.066 .396 .853 r
.37862 .25772 .38551 .2667 .39734 .25413 .38971 .26313 Mtetra
.704 .89 .512 r
.38971 .26313 .39734 .25413 .40868 .25423 .40184 .24555 Mtetra
.607 .707 .915 r
.40184 .24555 .40868 .25423 .42023 .25063 .41339 .24257 Mtetra
.642 .74 .92 r
.41339 .24257 .42023 .25063 .43184 .24663 .42503 .23867 Mtetra
.65 .747 .92 r
.42503 .23867 .43184 .24663 .44351 .24247 .43673 .23453 Mtetra
.654 .75 .92 r
.43673 .23453 .44351 .24247 .45523 .23822 .44848 .23028 Mtetra
.656 .751 .92 r
.44848 .23028 .45523 .23822 .467 .23389 .46029 .22594 Mtetra
.658 .753 .92 r
.46029 .22594 .467 .23389 .47883 .22952 .47214 .22154 Mtetra
.659 .753 .92 r
.47214 .22154 .47883 .22952 .49071 .2251 .48405 .2171 Mtetra
.659 .754 .92 r
.48405 .2171 .49071 .2251 .50263 .22067 .49602 .21263 Mtetra
.49602 .21263 .50263 .22067 .51461 .21622 .50803 .20815 Mtetra
.50803 .20815 .51461 .21622 .52664 .21175 .5201 .20364 Mtetra
.658 .753 .92 r
.5201 .20364 .52664 .21175 .53873 .20728 .53221 .19913 Mtetra
.53221 .19913 .53873 .20728 .55086 .20279 .54439 .1946 Mtetra
.54439 .1946 .55086 .20279 .56305 .19828 .55661 .19006 Mtetra
.55661 .19006 .56305 .19828 .5753 .19377 .56889 .1855 Mtetra
.56889 .1855 .5753 .19377 .58759 .18923 .58122 .18092 Mtetra
.58122 .18092 .58759 .18923 .59994 .18468 .59361 .17633 Mtetra
.59361 .17633 .59994 .18468 .61235 .18011 .60605 .17172 Mtetra
.657 .753 .92 r
.60605 .17172 .61235 .18011 .62481 .17552 .61855 .1671 Mtetra
.61855 .1671 .62481 .17552 .63733 .17091 .63111 .16245 Mtetra
.63111 .16245 .63733 .17091 .6499 .16628 .64372 .15778 Mtetra
.657 .752 .92 r
.64372 .15778 .6499 .16628 .66252 .16164 .65638 .1531 Mtetra
.65638 .1531 .66252 .16164 .67521 .15697 .66911 .14839 Mtetra
.66911 .14839 .67521 .15697 .68795 .15229 .68189 .14367 Mtetra
.68189 .14367 .68795 .15229 .70075 .14758 .69473 .13892 Mtetra
.69473 .13892 .70075 .14758 .71361 .14285 .70762 .13416 Mtetra
.843 .956 .613 r
.02486 .38962 .03562 .37751 .04502 .37818 .03741 .37013 Mtetra
.556 .683 .924 r
.03741 .37013 .04502 .37818 .05478 .3769 .04721 .36857 Mtetra
.05 .407 .859 r
.04721 .36857 .05478 .3769 .06613 .3649 .05623 .37273 Mtetra
.803 .979 .697 r
.05623 .37273 .06613 .3649 .07552 .36676 .06797 .35855 Mtetra
.558 .681 .921 r
.06797 .35855 .07552 .36676 .08549 .36496 .07792 .35693 Mtetra
.467 .65 .938 r
.07792 .35693 .08549 .36496 .1 .32979 .08773 .35675 Mtetra
.175 0 .153 r
.08773 .35675 .1 .32979 .10643 .3549 .09901 .34603 Mtetra
.531 .653 .913 r
.09901 .34603 .10643 .3549 .11657 .35283 .10903 .34497 Mtetra
.569 .699 .929 r
.10903 .34497 .11657 .35283 .1264 .35358 .11921 .34307 Mtetra
.837 .712 .726 r
.11921 .34307 .1264 .35358 .1378 .34209 .13138 .32566 Mtetra
.178 .286 .739 r
.13138 .32566 .1378 .34209 .14801 .34054 .14054 .3326 Mtetra
.591 .706 .923 r
.14054 .3326 .14801 .34054 .15835 .33832 .15092 .33022 Mtetra
.502 .667 .937 r
.15092 .33022 .15835 .33832 .17748 .25866 .16115 .32949 Mtetra
.398 .127 .381 r
.16115 .32949 .17748 .25866 .17987 .32776 .1726 .31858 Mtetra
.535 .65 .909 r
.1726 .31858 .17987 .32776 .19037 .32531 .18297 .31743 Mtetra
.603 .716 .924 r
.18297 .31743 .19037 .32531 .20092 .32298 .19357 .31474 Mtetra
.473 .652 .937 r
.19357 .31474 .20092 .32298 .21377 .29805 .20398 .31447 Mtetra
0 0 0 r
.20398 .31447 .21377 .29805 .22277 .31209 .21554 .30313 Mtetra
.557 .668 .912 r
.21554 .30313 .22277 .31209 .23349 .30937 .22618 .30147 Mtetra
.614 .722 .923 r
.22618 .30147 .23349 .30937 .24428 .30649 .237 .29846 Mtetra
.581 .707 .929 r
.237 .29846 .24428 .30649 .25471 .3084 .24781 .29619 Mtetra
.802 .692 .743 r
.24781 .29619 .25471 .3084 .26649 .29507 .25968 .28211 Mtetra
.378 .48 .838 r
.25968 .28211 .26649 .29507 .27737 .29278 .27016 .28469 Mtetra
.616 .721 .92 r
.27016 .28469 .27737 .29278 .28838 .28949 .28118 .28159 Mtetra
.626 .731 .922 r
.28118 .28159 .28838 .28949 .29943 .28632 .29227 .27824 Mtetra
.595 .715 .927 r
.29227 .27824 .29943 .28632 .31031 .28654 .30336 .27558 Mtetra
.847 .723 .726 r
.30336 .27558 .31031 .28654 .32207 .27431 .31555 .25768 Mtetra
.263 .346 .761 r
.31555 .25768 .32207 .27431 .33321 .27207 .32613 .26383 Mtetra
.62 .722 .919 r
.32613 .26383 .33321 .27207 .34448 .26853 .33741 .26057 Mtetra
.638 .738 .921 r
.33741 .26057 .34448 .26853 .35582 .26478 .34877 .25685 Mtetra
.64 .74 .921 r
.34877 .25685 .35582 .26478 .3672 .26105 .36019 .25305 Mtetra
.634 .737 .922 r
.36019 .25305 .3672 .26105 .37862 .25772 .37165 .24939 Mtetra
.583 .708 .929 r
.37165 .24939 .37862 .25772 .38971 .26313 .3831 .24693 Mtetra
.756 .636 .727 r
.3831 .24693 .38971 .26313 .40184 .24555 .39506 .23425 Mtetra
.487 .584 .877 r
.39506 .23425 .40184 .24555 .41339 .24257 .4065 .23427 Mtetra
.632 .731 .919 r
.4065 .23427 .41339 .24257 .42503 .23867 .41816 .23059 Mtetra
.647 .744 .92 r
.41816 .23059 .42503 .23867 .43673 .23453 .42989 .22651 Mtetra
.652 .748 .92 r
.42989 .22651 .43673 .23453 .44848 .23028 .44168 .22226 Mtetra
.655 .751 .92 r
.44168 .22226 .44848 .23028 .46029 .22594 .45351 .21792 Mtetra
.657 .752 .92 r
.45351 .21792 .46029 .22594 .47214 .22154 .46541 .2135 Mtetra
.658 .753 .92 r
.46541 .2135 .47214 .22154 .48405 .2171 .47735 .20904 Mtetra
.659 .754 .92 r
.47735 .20904 .48405 .2171 .49602 .21263 .48935 .20453 Mtetra
.48935 .20453 .49602 .21263 .50803 .20815 .50139 .20001 Mtetra
.50139 .20001 .50803 .20815 .5201 .20364 .51349 .19547 Mtetra
.51349 .19547 .5201 .20364 .53221 .19913 .52565 .19091 Mtetra
.658 .753 .92 r
.52565 .19091 .53221 .19913 .54439 .1946 .53786 .18634 Mtetra
.53786 .18634 .54439 .1946 .55661 .19006 .55012 .18176 Mtetra
.55012 .18176 .55661 .19006 .56889 .1855 .56243 .17716 Mtetra
.56243 .17716 .56889 .1855 .58122 .18092 .5748 .17255 Mtetra
.5748 .17255 .58122 .18092 .59361 .17633 .58723 .16792 Mtetra
.58723 .16792 .59361 .17633 .60605 .17172 .59971 .16327 Mtetra
.657 .753 .92 r
.59971 .16327 .60605 .17172 .61855 .1671 .61224 .1586 Mtetra
.61224 .1586 .61855 .1671 .63111 .16245 .62483 .15392 Mtetra
.62483 .15392 .63111 .16245 .64372 .15778 .63748 .14921 Mtetra
.63748 .14921 .64372 .15778 .65638 .1531 .65019 .14449 Mtetra
.657 .752 .92 r
.65019 .14449 .65638 .1531 .66911 .14839 .66295 .13974 Mtetra
.66295 .13974 .66911 .14839 .68189 .14367 .67577 .13498 Mtetra
.67577 .13498 .68189 .14367 .69473 .13892 .68865 .13019 Mtetra
.68865 .13019 .69473 .13892 .70762 .13416 .70159 .12539 Mtetra
.716 .584 .706 r
.01881 .37096 .02486 .38962 .03741 .37013 .03004 .36005 Mtetra
.444 .577 .892 r
.03004 .36005 .03741 .37013 .04721 .36857 .03952 .36066 Mtetra
.539 .684 .932 r
.03952 .36066 .04721 .36857 .05623 .37273 .04936 .35932 Mtetra
.767 .655 .739 r
.04936 .35932 .05623 .37273 .06797 .35855 .06082 .34722 Mtetra
.385 .516 .866 r
.06082 .34722 .06797 .35855 .07792 .35693 .07028 .34902 Mtetra
.567 .696 .928 r
.07028 .34902 .07792 .35693 .08773 .35675 .08033 .34716 Mtetra
.897 .717 .65 r
.08033 .34716 .08773 .35675 .09901 .34603 .09502 .31179 Mtetra
0 0 .396 r
.09502 .31179 .09901 .34603 .10903 .34497 .10145 .33694 Mtetra
.58 .699 .924 r
.10145 .33694 .10903 .34497 .11921 .34307 .11168 .3348 Mtetra
.403 .616 .937 r
.11168 .3348 .11921 .34307 .13138 .32566 .12159 .3355 Mtetra
.503 .817 .499 r
.12159 .3355 .13138 .32566 .14054 .3326 .1331 .32391 Mtetra
.555 .673 .916 r
.1331 .32391 .14054 .3326 .15092 .33022 .1434 .32229 Mtetra
.584 .707 .927 r
.1434 .32229 .15092 .33022 .16115 .32949 .15383 .32 Mtetra
.933 .709 .575 r
.15383 .32 .16115 .32949 .1726 .31858 .17324 .23999 Mtetra
0 0 .22 r
.17324 .23999 .1726 .31858 .18297 .31743 .17554 .30927 Mtetra
.594 .706 .921 r
.17554 .30927 .18297 .31743 .19357 .31474 .18614 .30675 Mtetra
.587 .71 .928 r
.18614 .30675 .19357 .31474 .20398 .31447 .19677 .30436 Mtetra
.881 .727 .686 r
.19677 .30436 .20398 .31447 .21554 .30313 .20977 .27927 Mtetra
.018 .092 .599 r
.20977 .27927 .21554 .30313 .22618 .30147 .21883 .2933 Mtetra
.604 .712 .921 r
.21883 .2933 .22618 .30147 .237 .29846 .22965 .2905 Mtetra
.61 .722 .924 r
.22965 .2905 .237 .29846 .24781 .29619 .24053 .28755 Mtetra
.324 .568 .927 r
.24053 .28755 .24781 .29619 .25968 .28211 .25105 .2894 Mtetra
.694 .933 .625 r
.25105 .2894 .25968 .28211 .27016 .28469 .26295 .27596 Mtetra
.584 .692 .916 r
.26295 .27596 .27016 .28469 .28118 .28159 .27393 .27359 Mtetra
.625 .729 .922 r
.27393 .27359 .28118 .28159 .29227 .27824 .28504 .27022 Mtetra
.62 .728 .924 r
.28504 .27022 .29227 .27824 .30336 .27558 .2962 .26697 Mtetra
.445 .635 .936 r
.2962 .26697 .30336 .27558 .31555 .25768 .30717 .26713 Mtetra
0 0 0 r
.30717 .26713 .31555 .25768 .32613 .26383 .31905 .25478 Mtetra
.58 .685 .913 r
.31905 .25478 .32613 .26383 .33741 .26057 .33029 .25246 Mtetra
.632 .733 .92 r
.33029 .25246 .33741 .26057 .34877 .25685 .34167 .24885 Mtetra
.64 .74 .921 r
.34167 .24885 .34877 .25685 .36019 .25305 .35312 .24501 Mtetra
.638 .739 .922 r
.35312 .24501 .36019 .25305 .37165 .24939 .36461 .2412 Mtetra
.622 .73 .924 r
.36461 .2412 .37165 .24939 .3831 .24693 .37614 .23779 Mtetra
.071 .398 .855 r
.37614 .23779 .3831 .24693 .39506 .23425 .38733 .24315 Mtetra
.712 .896 .521 r
.38733 .24315 .39506 .23425 .4065 .23427 .39959 .22543 Mtetra
.607 .708 .915 r
.39959 .22543 .4065 .23427 .41816 .23059 .41125 .22237 Mtetra
.642 .74 .92 r
.41125 .22237 .41816 .23059 .42989 .22651 .423 .21838 Mtetra
.65 .747 .92 r
.423 .21838 .42989 .22651 .44168 .22226 .43482 .21416 Mtetra
.654 .75 .92 r
.43482 .21416 .44168 .22226 .45351 .21792 .44669 .20981 Mtetra
.656 .751 .92 r
.44669 .20981 .45351 .21792 .46541 .2135 .45861 .20539 Mtetra
.658 .753 .92 r
.45861 .20539 .46541 .2135 .47735 .20904 .47059 .2009 Mtetra
.659 .753 .92 r
.47059 .2009 .47735 .20904 .48935 .20453 .48262 .19637 Mtetra
.659 .754 .92 r
.48262 .19637 .48935 .20453 .50139 .20001 .4947 .19181 Mtetra
.4947 .19181 .50139 .20001 .51349 .19547 .50684 .18722 Mtetra
.50684 .18722 .51349 .19547 .52565 .19091 .51903 .18263 Mtetra
.658 .753 .92 r
.51903 .18263 .52565 .19091 .53786 .18634 .53127 .17802 Mtetra
.53127 .17802 .53786 .18634 .55012 .18176 .54357 .1734 Mtetra
.54357 .1734 .55012 .18176 .56243 .17716 .55592 .16876 Mtetra
.55592 .16876 .56243 .17716 .5748 .17255 .56833 .16411 Mtetra
.56833 .16411 .5748 .17255 .58723 .16792 .58079 .15944 Mtetra
.58079 .15944 .58723 .16792 .59971 .16327 .5933 .15475 Mtetra
.5933 .15475 .59971 .16327 .61224 .1586 .60588 .15004 Mtetra
.657 .753 .92 r
.60588 .15004 .61224 .1586 .62483 .15392 .61851 .14532 Mtetra
.61851 .14532 .62483 .15392 .63748 .14921 .6312 .14057 Mtetra
.6312 .14057 .63748 .14921 .65019 .14449 .64394 .13581 Mtetra
.657 .752 .92 r
.64394 .13581 .65019 .14449 .66295 .13974 .65674 .13102 Mtetra
.65674 .13102 .66295 .13974 .67577 .13498 .6696 .12622 Mtetra
.6696 .12622 .67577 .13498 .68865 .13019 .68252 .12139 Mtetra
.68252 .12139 .68865 .13019 .70159 .12539 .6955 .11654 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05eoo`0GD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBo@0GOol00`00
Oomoo`17Ool008Moo`<006=oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aB
o5;mD_`005;lD_d00U;l5goo00<007ooOol0AWoo0025Ool2001ROol085;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_dFOol00`00Oomoo`16
Ool0089oo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`00e;mD_aoo`0FOol00`00Oomoo`15Ool0081oo`8006=oo`0UD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_`05goo00<007ooOol0A7oo001mOol3001QOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo003D_eB
o7oo01Eoo`03001oogoo04Aoo`00Ngoo0P000Woo00<007ooOol0GGoo02aBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;m5goo00<007ooOol0@goo001hOol3001ROol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@0GOol00`00Oomoo`12Ool007Ioo`80065oo`0dD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`12Ool007=oo`<0065oo`9Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo004D_eBo5;lD_`GOol00`00Oomoo`11Ool0075o
o`80069oo`0iD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;l01Eoo`03001oo`00049oo`00KWoo0`00H7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomoo`10Ool006]oo`<0065o
o`10D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_dGOol00`00Oomoo`0oOol006Uoo`8000=oo`03001oogoo05]oo`03D_aBoE;l009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aB
o5;lD_d00U;l5Woo00<007ooOol0?goo001VOol3001OOol0BE;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m01Ioo`03001oogoo03ioo`00I7oo0P00H7oo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l5Woo00<007ooOol0?Goo001QOol3001POol0Ce;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m01Eoo`03001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P00Ggoo00=Bo5;mD_`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol0
9Woo00<007ooOol04goo000dOol00`00Oomoo`02Ool00`00Oomoo`0POol3001POol0EE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo02Eoo`03
001oogoo01=oo`00>Goo00<007ooOol07Woo0P000Woo00<007ooOol0G7oo0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;m
D_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Eoo`03001oogoo02Aoo`03
001oo`0001Aoo`00;7oo1P001goo00<007ooOol06goo0`00Ggoo05aBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Woo00<007ooOol08goo
00<007oo000057oo000eOol4000LOol2001POol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0FOol00`00Oomoo`0QOol01@00
Oomoogoo00004goo000eOol00`00Oomoo`0JOol3001POol0HU;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol2000S
Ool01@00Oomoogoo00004goo000eOol00`00Oomoo`0GOol3001OOol2D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d05Goo00<007ooOol07goo0`0000Aoo`000000019oo`00=Goo1@004goo0P00H7oo06UB
o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol0=goo001:Ool300000goo001o
o`1MOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009B
o003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol027oo
1000:goo0018Ool2001OOol0L4klD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m5Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0:7oo0015Ool3001MOol015;lC_aB
oDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`FOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004=oo`8005aoo`1iB[a>gDZlC]e:_5;mC]aBoDkL
D_e>o5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol0:7oo0010Ool3001MOol2Fi000dZlB]a:g002C]`015;lC_aBoDkL
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l5Woo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol0:7oo000nOol2001POol0O5^@Efm>gDZlC]e:_4kMC]aBoDkLD_e>
g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol0:7oo000kOol4001POol01E^@FfmKT5^@C_d00dkL00I>oDklD_aB
o5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;m
D_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0DOol00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003Uoo`8000Aoo`03001oogoo05aoo`20Fi1N
MUjG>S/nFcXkC_e>g5;mC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo1Eoo`03001oogoo00=oo`@002]oo`00=Woo0`00IGoo0eif00DnFcXk?U/jFdkm
00=>g005C_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
01=oo`800003Ool007oo039oo`00<goo0`00H7oo08U>oD[LC_e>g4km1GX9V`EjGYMNMV:GGWHnFcXk
?U/j>e;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m01Eoo`03001oogoo035oo`00<Goo0P008goo00=fdGooOol0>Goo00]>o5;mC]a>oDklC]e>
g4kMC]`5VPEj00ENMP0:B[a>g4ZlB]a:_5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00800003D_aBoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Eoo`03001oogoo031oo`00;Woo0`009Goo00=f
dWooOol0=Goo07=BoDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oDkLGYMNMV:GGWINUeM_Fi1:_4kMB[a>
gDkLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@0300007E;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d05Goo00<007ooOol0;goo000/Ool4000VOol00gJaOomoo`0aOol3C]`03dkmC]a>o4klD_e>
g4kmC_aBoDkLC_e>g4[MA[a:g@05GWH02U^@Efm:g4ZlC]a:_4[LD_aBoDkl0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d00000001Bo@03D_`01E;m001Bo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol0;goo000Z
Ool2000ZOol00gKBOomoo`0^Ool0M4JLB[e6_4ZlC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJl
B]e6_4[MGWINUeifFi1GKe^@EfmBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d3000095;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02ioo`00:Woo0P00:Goo0WKA
;goo0P0000A6_4ZlA[a:_0=>g00;C_e>g4klC_aBoDkLC_e>g4kmC]a>o@02B]d00dJlGWINMP02GWH0
13iK>U/nFcXk0TkL00E>oDkLC]aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000
001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoE;lD_`05Goo00<007ooOol0;Woo000@Ool50003Ool40004Ool40006Ool0
0`00Ool0000XOol00g:aM]9oo`0]Ool0LF[F8EP004ZlAYa:_DJlB[a>g5;mC]aBoDkLD_e>g5;mC]aB
oDkLC_e:g4km1GY:gDJlHYMNMUjGGWHnFcXk?U]>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`00`0002YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0]Ool0019o
o`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool200000goo001o
o`0VOol00gKBM[5oo`0/Ool00cImJ]IZeP027EL04dkMC]a>g4kLC]e>g4klC]aBoDkLC_e>o5;mC]a>
oDkLC]e>g4kM0085VPANMP09>S/nFcYK?U]>g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m
D_`30003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01Eoo`03001oogoo02aoo`004Woo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`8000=oo`03001oogoo
02Aoo`03L[5fdRa[02]oo`1]=WaZmf[FJ]HMEb5H7EM>gD[LC]e:g5;mC]aBoDkLD_e>g5;mC]aBoDkL
C_e>g4kmB]a>oEifGYMNMV:GGWINUdZlC]e:_4kMC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`00
039Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol0;7oo0007
Ool60005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol08Woo00Af/GKAM]4`JbAoo`04C]a>gDkLC]d3=Wd4J]H01B5G7ELMEdkL
C]d00dkL00YBoDkLC_a>o5;mC]a>oDklD_e>g0=:g@03A[aNMUif00=NMP9GK`05B[a:g4ZlC]a:_002
D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo000008000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo7oo01Aoo`03001oogoo02]oo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo025oo`04M]9b/GKB;6/POol02dkm
B]a>oDkLC_e:g4kmB]a>oCIl>Yd00f[F06AZmf[F8EPMEb5HC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;m
C]aBoDkLB]e6_4[MA[aRUeifGYMGKe^?EfmGSdkLD_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0<0000iD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03001oo`0002ao
o`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`8000Io
o`80025oo`04M]5fdWJa00HLOol2B[`034JlB[a:_4kMC]a>gDkLC]e>g4kMC]a>g@IZeP06A[a:_4Jl
B[a>g4km0dkL00YBoDkLC_a>o5;mC]a>oDkLC_e>g0=:g@ANMP04>S/nFcYK?U/3C]`01DkmC_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`30003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;l
D_eBo1Aoo`03001oogoo02Yoo`0047oo0`0017oo00<007ooOol00Woo00@007ooOol000Aoo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo01ioo`04M]9b/GKB00HKOol04UNBFk=6_4ZmA[a:gDkL
C_e:g4kmC]a:gDZlB]e:g4[MJ]IZm`9ZeP1M7EL004JlB[a6W4ZmA[aBoDkLD_e>g5;mC]aBoDkLD_e>
g5;mC]a>oD[L1I]6_4[MGWIRUeif?U/j>ciK>S]>oDkLD_e>g4kmC]aBoDklD_e>g5;mD_aBoDkLD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00<00010D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0Y
Ool0019oo`03001oogoo00=oo`@000Aoo`@000Eoo`03001oogoo00Qoo`03001oogoo01aoo`07M]9f
/GKAM]401Woo?Yd02Goo00<4DWooOol037oo15Nc0TZl00U6_4ZlC]a>oDkLC]e>g4[MB]`00T[M1F[F
00@MEb5GC]a>g@=>g006D_e>g4klC]aBoDkL0Tkl00M>gDkLC]e>g4kM1GX5VP05GWH02CiK>S/nFcYK
D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_`00002
0003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m01Eoo`03001oogoo02Qoo`00:7oo00<007ooOol02Woo00<007oo
Ool06goo00Mb/GKBL[5fdP06Ool/J`08Ool00g;eK]Eoo`0<Ool04eNBI]MR]Rgj;MT]nT[LC]e:g4kM
C]a>oDkLC_e>g4[MB[a:gD[L009ZeP1IJ]MZeR5H7ELQN4[LC]e:g4kMC]aBoDkLD_e>g5;mC]aBoDkL
C_e:g4kmC]a>oEifHYMNMUjGGWIRUdZlC]e:_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@020000Ae;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007oo
Ool0:7oo000XOol3000;Ool00`00Oomoo`0JOol2M]401GKBM[401Woo<6`027oo0VkE00<0DWooOol0
2Goo00@V?FJgH[MV]`@]fP03C]a>gD[L009>g004C_e>g4kMC]`3=Wd4J]H00aeG8ELME`02C]`01TkM
C]a>g4klD_e>g09>o006D_e>g4kmC_aBoDJl0T[M1Eif0UM_00M:_4kLB[a:g4klD_e>g002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009
D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;l
D_aBo1Eoo`03001oogoo02Moo`00:7oo00<007ooOol037oo00<007ooOol06Goo00Mb/GKBL[5fdP06
Ool`J`07Ool016kEK_E^e0AC17oo01a:g4kMB]a>gD[L:SdV?2YMH[IV]f:fI]L]fBgj;MU>gD[LC]e:
g4kMB]a>oD[LC_e:g3JM=WaZe`=ZeP1AJ]LMEb5H7EMBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
D_e6_4[MA[aNUeifHYMNMUM_DfiGKdZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m00<0001>D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol0
9Woo000XOol00`00Oomoo`0=Ool00`00Oomoo`0GOol00gKAM]9f/@02M]400`06;6/`J`07Ool3K]D0
101B159:g4[M0d[L00=>gD[LC]d00RHm00ER]fJgI[MV]f:g00@]fP0:C]e>g4kMC]a>gDkLC]e>g4kM
C]`6J]H014ZlA[a:_4Jl0TkL00I>oDkLC]a>o5;mC]`2C_`01dkmC]a>oDkLB]e6_4[M00=NMPEGK`07
C]a>oDkLC]aBo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol002Qoo`8000moo`03001oogoo
01Ioo`08M]9b/GKBL[5fdP06<6//J`Ioo`0TK_E^e7;eK]E^m@0b15=:_4kMB[a>gDZlC]e:g4kMH[IV
]f:fI]MR]UNcDi9:gDJlB[e6_4kmC]a>oD[LC_e:g4[MB[a:gD[L0V[F04eZef[F000004ZmA[a:_4JL
D_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[aRUeifEfmNMV:G>S/nFcXk?U]>g4kmC]aBoDkl
D_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;m00<0001FD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo02Eoo`00:7oo00<007ooOol03goo00<007ooOol05Goo
00Qf/GKAM]5fdWJa00H`Jc1/1Woo1FkE00/4DP1B159>g4kMB]a>gDkLB]e6_4[M009V]`05H[MV]eNc
Ek=GTP03B[`01TJlC]e>g4kmC]a>g@9:g@03B]a:gF[F00=ZeP0;7EL004JlB[a6_4ZlA[a>o4kLD_e>
g002C_`02U;mC]a>o4kLC]e>g4kMC]a:gDJl15if0ciK00Dj>ciKC_aBoDkL009Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aB
o0030002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@02D_`EOol00`00Oomoo`0TOol002Qoo`03001oogoo011oo`03001oogoo01Aoo`09M]9b/GKBL[5f
dP06<6``Jc2<00Aoo`0VK]AbmFkEK_E^e7;e@Ya6_4:LA[e:g4kMB]a>gDJlB]e6_4[MH[IV]f:fI[L]
fBgj;MU>gD[LC]e:g4kmC]a>oDkLB]e:g4[MB[a:g@=ZeP15J]LMEb5HB]a>gD[LC]e:g5;mC]aBoDkL
D_e>g5;mC]aBoDkLC_e:g4km1GX5VUifHYMNMUjGGWI>gDZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkl
D_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m00<0001M
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m01=oo`8002Ioo`009goo00<007ooOol04Woo00<007ooOol04Woo0WKA00IfdWJaM]5fd@06
;6/2<6/00d[MB[a:g@02B]d5K]D00`ABAYa6_002AY`01dkLC]e:g4kMA[e:gDJl00=V]`05H[L]fRgJ
;OX]fP02C]`01TkMB]a>gDkLC_e>g0=:g@03B]`fOF[F009ZeP038ELMEb5H00=>g006C]e>g4klC_aB
oDkL0Tkl00MBoDkLC_e>g4kMC]a>g@05GWH02UM_Dfi:g4ZlC]a:_5;lC_aBoDkl0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`00`000U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo1Aoo`03001oogoo02=oo`009goo0`004goo00<007ooOol04Goo019b/GKBL[5fdW:aM]80
1T[MB[a:gDZlB]e6_4[MA[a^mFkDL_D2K]D08P1BA[e2W4Jl@Ya6_D[LC]e:g4kM9S`Z?BHlI[MR]VJg
H[HanRgI;OY:g4kMB]a>gD[LC_e:g4kmB]`jWCIm=YeZeV[G0f[F03dQN1eG8EQ>g5;mC]a>oDkLD_e>
g5;mC]aBoDkLD_e>g5;mA[a:gDJlHYMNMUjGGWIRUe=^Efm:_4kMB[a>gDZlD_e>g5;mC]aBoDklD_e>
g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7@030000I5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l5Goo00<007ooOol08Woo000WOol00`00Oomoo`0DOol00`00Oomoo`0@Ool01WKBM[5f
dGKAM]9f/@801P06B]e:_4[LB[a:gDZl0T[M16kE00D4DP1BB]a:g4[M00=:g003C]e:g4kM008V?@04
H[MV]fJgI[L3;MX02bgjC]a>gDkLC]e>g4kMC]a>gDkLC]d01V[F00A6_4ZlA[a:_0=>g00;C_e>g4kl
C_aBoDkLC_a>g4kmC]a>o@02B]d024JlGWINMUifDfiGKeM^Efl3C]`01TkmC]aBo5;lD_e>o09Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo080009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006
D_eBo5;lD_aBoE;l57oo00<007ooOol08Woo000EOol40004Ool40006Ool00`00Oomoo`0EOol00`00
Oomoo`0?Ool01W:aM]9b/GKBL[5fdP801P08B[a:gDZlB]e:_4[MA[a:g@9^e@0RK]AbmFkE1580DTkM
B[a>gDZlC]e:g4kMB]a>gF:fI[MR]VJgH[IV]dJlB]e6_4ZmB]a>oDkLC_e:g4[MB]a:gDZlB]d3J]H0
>V[G000004JLB[e6_4ZlC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]eNMV:GDfiNUeif?U/j
>ciKC]aBoDkLC_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l0`00
06YBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo025oo`0057oo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo019oo`04K]@037ooOol2000>Ool0
1GJaM]5fdGKBM[400WKA0`0600E:g4[MB]a:gD[L008jW@E^e@84DP0:059:g4[LB]e:g4[MA[e:gDJl
B]d2I[L01F:gI[MGTUNcA[`00dZl00E6_4kMC]a>oDkL00=:g@03B]aZeV[F009ZeP0<8EL004ZlA[a:
_4JlB[a>g4klC]aBoDkL0Tkl00MBoDkLC]e>g4kMC]a>g@02B]d4GWH02CXk?U/nFciKC]aBo4klD_e>
g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0<00003D_aBoE;l009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0COol00`00Oomoo`0POol001Uoo`04001oogoo0004
Ool00`00Oomoo`03Ool2000COol00g;D00]oo`03Ool00`00Oomoo`0;Ool04gKBL[5fdW:aM]9b/GKB
L[52W49l@Ya:g4kMB[a>gCYmK]E^e7;e009^e@0RK]@4D`1B1580DTkMB]a>gD[LB]e6_4[MA[aV]f:f
I[MR]S7j;MT]nT[LC]e:g4kMB]a>oDkLC_e:_4[MB]a:gDZlJ]L3J]H0<R5h7EM>gD[LC]e:g4kMC]aB
oDkLD_e>g5;mC]aBoDkLC_e>g4kmB]`5V`EjGYMNMV:GGWINUdZlC]e:_4kMC]aBoDkLD_e>g5;mC_aB
oDkLD_eBo5;mC_aBoE;lD_eBo5;mD_`30000LU;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoAAoo`03001oogoo021oo`0037oo1P001goo00@007ooOol000Aoo`03001o
ogoo009oo`03001oogoo019oo`9be00300aoogoo00=oo`03001oogoo00Aoo`03AYa6_4JL0096_004
B]e:_GKBM[42M]400gKBM[5fd@04@Y`014[LB]e:g4[M1VkE00d4DTJLAYa6_4JLC]e>g4kMB]a:gDJm
B]e6_003I[L01F:g;MX]fRgjB]`00TkL00I>gDkLC]e>g4kmB]`3B]d01CImJ]IZeV[F7EL00R5G00I>
gDkLC]a>g4kMC]`2C_`02U;mC]a>oDklD_e>g4kMC]a>gDkL1Eif00ECKUM^B[a:g4Zl009>g003D_a>
o5;m00=Bo005D_eBo5;lD_aBo@03D_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo01moo`005Goo10000goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol04Woo00=^/g;D00/01Woo01d007ooOomoocm?4AHo;d:L
A[e2W4JmA[a:gDJlM]9b/GKBL[5fdW:a00M:_4[MB[a:gDJlB]e6_4[M009^e@0SK]AbmFkE15=2W4Jm
@Ya6_4:LC]e:g4kMB]`ZGBHl:SdV?6JgH[IV]bgI<OX]fDkMB]a>gD[LC]e:g4kmB]a>oCIl>YdfO@02
J]H0;V[GJ]IZeQeG8GPMEdkmC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eNMV:GGWINUeif
EfmCCTkMB[a>gDZlC]e>g5;mC]aBoDkLD_e>o5;mC]aBoE;l0`0007UBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0OOol0
01Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`80019oo`9be003K]Abe00<00Io
o`03001oogoo009ZeP055AM6_4JLA[a6W002A[`014[MB[efdWJa0WKA00MfdP0600I:_4[MB[a:g002
B]d00dZlK]E^e@03K]D21583B]`01T[MB]a>gD[LC]e:g08V?@03I[MR]fJg009V]`<]fP0:C]e>g4kM
C]a>gDkLC]e>g4kMC]`6J]H01DZlA[a:_4JlC_d00dkL00eBoDkLC_a>o5;mC]a>oDkLC_e6_4[MA]e:
g@03GWH01EM^DdiCKU=^C_d00dkL00E>oDklD_aBo5;m00=Bo0<00003D_aBoE;l009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;m
D_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l57oo00<0
07ooOol07Woo000EOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0A
Ool01G;DK]=be6jc00`01goo01d006JfJ]IV]QDg4AI:gDJlB]e:_4[M?YafdW:aM]9b/GKBL[401`06
B]e:_4[MB[a:gDJlB]e6_7;e009^e@0RK]Abm@AB15=:_4kMB[a>gD[LC]e:g4kMB]aV]f:fI[MR]VJg
H[I:_DJlB]e6_4kmB]a>oDkLC_e:_4[MB]a:gDZlJ]L3J]H2000094ZlAYa:_DkLC_e>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLD_e6_4[MA[aNUeifHYMNMSiK>S/nFcXkC_e>g5;mC]a>oDkLD_e>o0<00021D_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01eoo`005Goo1@000goo10001Goo00<007ooOol047oo
00=be6kDL]@00W;D00H02dZmA[a:_DJlB[d2<Wd4J]H02A4F5ALE5d[MB[a:gDZl?Yef/@02M]400gKB
M[5fd@0300H01D[MB]a:gD[LB]d00SZM1FkE0`AB0d[L00I:gDJlB]e6_D[MA[`3I[L01F:gDi9CTTZl
A[`00dZl00E>g4kMC]a>oD[L00=:g@AZeP0=7EL004JlB[a6_4ZlC]aBoDkLC_a>g5;mC]`00Tkl00QB
oDkLC]e>g4kM1GY:gDKM0eif0SiK00Lj>ciK?U]BoDkLD_a>o00300000e;lD_eBo002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo5;l01=oo`8001moo`009Woo00<007ooOol047oo02Q^dg;DK[=be6kC00`02d[MA[a:gDJl
<WdbGF[FI[IZefJfJ]HA5QDg4AHE5dJlB]e:_7KBL[5fdW:aM]9b/GKB@Wa2W49lC]e:g4kMB[`jW@9^
e@18K]AbmFkEK]D0DPAc1584Dd[LC]e:g4kMA[a:gDJlB]eR]VJgH[IV]f:f<OX]fDkMB]a>gD[LC]e>
g4kmC]a:gDZlB]e:g4[MJ]IZef[F8EPMEb5hB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e>
g4km1GX5VeifGYMNMV:GB[a>gDZlC]e:_5;m0P0008Q>g5;mC]aBoDklD_e>o5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoAAoo`03001oogoo01aoo`009Goo00<007oo000047oo00I^e7;DL]Abe6kDL]@200`01@0;B[e6
_4ZmA[`01V[F00A6_4JLA[a6W096_004B]e:_GKBM[42M]400gKBM[52W004@Y`00d[LB]e:g007K]D3
AY`02TJlB]a>gDkLC]e:g4[MA[e:gF:g0fJg0bgJ00Y>gD[LC]a>g4kmC]a>gDkLB]e:g09:g@AZeP05
8EPMEb5GC]a>g@03C]`03E;mC]a>o4klD_e>g4kmC_aBoDkLC]e>g4kM00ENMP03Ddi:_4kL00<00005
D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol01goo1@003goo
000UOol2000AOol0:g;DK[=be6kCL]A^/`0<00/0300;B]e6_4KMA[aZefJfJ]IV]V[G4AI6_D:LA[e2
W4[MA[a:gG:aM]9b/GKBL[5fdP06B]e:_4[MB[a:gDJlB]e6_7;e009^e@0RK]A^mFkE17=2W4Jm@Ya6
_4[LC]e:g4kMB]`ZGBHl9SeR]VJgH[IV]bgI<OY:g4kMB]a>gD[LC_e:g4kmB]`fWCIl>Yd3J]H06f[G
7ELQF1eG8GQ>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlGYMNMV:GGWICKP030000STkM
B[a>gDkLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007ooOol01goo00D0
07ooOomoo`0000moo`009Goo00<007ooOol02Goo00IRUejF;Q/]ndJmA[`2A[d00g;DK]Abe002L]@0
0fkD@Ya2W002@Y`3A[d3J]H03S9mJ]IZeQDGA[a6W4JlAYa:gDJlB]efdGKBM[42M]401P0700I:g4Zl
B]e:_0=:g@03B[a^eFkE00=^e@84DP=:g007B]e:g4kMB]a>gBHl9Sd00VJg00AR]VJgI[L]nP8]fP0:
C]a>gDkLC]e>g4kMC]a>gDkLC]d6J]H01TJlB[a6_4ZlC]a>o@9>g00>C_aBoDkLC_a>g4kmC]a>oDkL
B]e6_4[MA]eNMP<00005DfiCCU=>C]a>o@02C]`00e;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006
D_eBo5;lD_aBoE;l57oo00<007ooOol01goo00<007ooOol047oo000UOol00`00Oomoo`08Ool04F:G
GYIRUbgj<Q/]nTKMA[a:gDJlL]A^/g;DK]=be6jc@Yd00T:L028nO4[MA[a6gFJf<WeV]V[FI[HE=a4F
B]e6_4[MB[`n_G:aM]9b/GKBL[5fdP0600L01T[MB[a:gDZlB]e6_4[MA[a^m@9^e@0RK]A^m@AB17=:
_4kMB[a>gD[LC]e:g4kMH[IV]f:fI[MR]U>BDi5:_DJlB]e>g4kmB]a>oDkLB]e:_4[MB]a:gF[FJ]L2
J]H200004TJlB[a6W5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a:g@<0002FGYMNMV:G>S/nFcXk
?U]>g4kmC]aBoDklD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007ooOol0
1goo00<007ooOol03goo000UOol20008Ool02f:GGYIRUejGHYL]nRhK;O]6_DJlA[d00W;D00U^e7;D
L]Abe00<B[e6_4ZmA[`00c9m16[F00TE5QDG5AM:gDZlB]e:_7KBM[400WKA00YfdWJa00H01P0700I:
gD[LB]e:g0<jW@E^e@<4DP=:g006B]e6_4[MA[e:gF:f0VJg0e>B0TZl00U6_4ZlB[a>oDkLC]e>g4[M
B]`00T[M0f[F00/QEb5H001:_4JlB[a6_4klC]aBoDkL009>o005D_e>g4klC_a>g@0300000`EjA[a:
g@03GWH3?U/01CXk?U]>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;m
Oomoo`0BOol00`00Oomoo`08Ool00`00Oomoo`0>Ool002Eoo`03001oogoo00Ioo`0eHYMNUV:GGWIR
UejF<Q/]nS8K;OY6gDJlB]e^dg;DK[=be6kC00`02d[MA[a:gDJl<Wd^GF[FI[IZefJfJ]HA5QDg4AI:
gDJlB]e6_7KBL[5fdW:aM]9b/D:L@Wa2W49lC]e:g4kMB[a>g@02K]D0=6kDK_E^eFkE@Ya6_D:LA[a:
g4kMB]a:gDJlB]e6_6JgH[IV]f:fI[L]fC7jB]a>gD[LC]e:g4kmC]a>oD[LB]e:_4[MB]aZeVKFJ]LM
Eb5h7EM>gD[LC]e:g5;mC]aBoDkLD_e>g5;m0`0009e>oD[LC_d5NPFJGWIRUeifGYMNMTkMB[a>gDZl
C]e>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0DOol00`00Oomoo`08
Ool00`00Oomoo`0=Ool002Eoo`03001oogoo00=oo`=2_@05GYIRUejGHYMNUP02ImD01TJmA[a6_4Jl
>Ye^e0=be009K]Abe00<00a6_4ZmA[a:_DJl00IZeP0>A[a6W4JlAYa:gDJlB]e:_GKBM[5fdWJaM]9f
/@A2W0=:g@03B[a:gFkE00A^e@0A17=6W4JLAYa>gD[LC]e>g4kMA[a:gDJmI[MR]VJgH[L]nP02;MX0
0dkLC]e:g002C]`00dkmC]a>g@02B]d00d[LB]eZeP02J]H28EL01R5H8EM>g4kLC]e>g09>o00;D_d0
0000001BoDkLC_e>o4kMC]a>g@05GWH02U=>Dde:g4ZlC]a:_5;lC_aBoDkl0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`03Ool01@00Oomoogoo00003goo000TOol0@@00
OomooeHeFUHf>cIL=S]6_D:l@[eNMV:GGYIWmV?EIoISeDJm@Ya6_D:LL]A^/g;DK]=be6jc00`02`0<
A[a:gDJlA]e6_6[GI[IZeVJf5CL004Jm@Ya6_DJlB]e6_4[MA[afdW:aM]9b/GKB00I:gDZlB]e:_4[M
A[a:gDJlK_D00VkE029^e6ke1596_4:LA[e2W4kMB]a>gD[LC]dV?2Xm9SaV]f:fI[MR]Rgj;MU>gD[L
C]e:g4kMB]a>oD[LC_dfOCJM=WaZe`9ZeP08I]HQN1eG8GPMEe;mC]a>o@<0002TD_e>g5;mC]aBoDkL
D_e>g4[MA[aRUeifGYMNMV:GCdeCCTZlC]e:_4kMB[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00Aoo`<0011oo`0097oo00T005YFFUEJEUXe=S`f>cIL
=S/00T:m00YRUejFHYMWeF:GGYH^6bgkA[e6_096_@03L]A^e7;D009be005K]A2W4:L@Ya6_003A[d2
J]H00c9mJ]IV]P025AL00dJlAYa6_003?Yd037KBM[5fdWJaM]9f/@0700I:g4ZlB]e:_0=:g@03B[a^
eFkE009^e@84DP0LB]e:g4[LB]a>gD[LC]e:g2Hm9SaV]f:gI[MR]VJg;MX]nRgJC]e>g4kMC]a>gDkL
C]e>g4kMC]`5J]H01DJlB[a6_4ZlA[`00P0000i>oDkLC]a>o5;mC]a>o4kLC_e>g4kmA]e:gDJl0eif
00ACCE=>DdeCCP=>g006C_e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004
D_eBo5;lD_`AOol200000goo001oo`0GOol002Aoo`0O001F=EYFFSEJEUHeA[e2W4Jm@Ya6_D:lHYL5
VV:GGYIRUbgj<Q/]nTKMA[a:gFkCL]A^/g;DK]=be00;@Yd00T:L028nO4[MA[a6gBiLJ]MV]V[F4AHE
=aDFB]e6_4[M?Ydn_G:aM]9b/GKBL[5fdP0600L01T[MB[a:gDZlB]e6_4[MK]A^m@9^e@0UK]@4L`AB
C]e:_4kMB[a>gD[LC]e:g6JgH[IV]f:fI[M?LE>BA[a:_DJlC_e>g4kmB]a>oD[LB]e:_4[MB]aZeVKF
J]LMEb5hAY`00`000:]>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a:gEifHYM?CEjFGWHnFcXk
?U]>g5;mC]a>oDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo
00<007ooOol05Goo000JOol40006Ool02`00FUIJ=EYFFUE[df^bA[e6_4JmA[`00PFJ00iRUejFHYMN
UV:G;OX^6bgkA[e6_4Jm>Yebe6kD0W;D0P0<00A:_DJlB[e6_08bO@03J]IV]V[F009ZeP0=5AHE5aDG
B]e:_4[MB[afdWJaM]9f/GKBM[4014:L00A:gD[LB]e:g08jW@E^e@<4DP0>C]e:g4kMC]a>gDJlB]e6
_FJgH[IV]e>ADi9?T@=:_006A[a:_4kLC_e>g4kM0T[M00=:g4[MJ]H00V[F0`0000TQEdZlA[a:_4kL
C_a>g5;mC]`00Tkl00UBoDkLC]e>g4kMC]a>gDKMB]d015if00Tj>ciK?U/nFdkLD_a>o5;mC]`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4goo00<007ooOol05Goo000I
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0@@00FSEJEUHeFUI[/V_CIk96_D:LA[e2W6:GGYIRUeif
HYMNUTJm@Ya6_D:L>YdfOCZMK]=be6jcL]A^d`0<00]:gDJlB]d^G39mI[IZeVJfJ]MV]QDg4AHE=aDF
B]e6_4[MA[afdW:aM]9b/GKBL[52W49l@Ya2O4kMB]a>gDZlK_D00VkE025^e6keK]E6_4:LA[e2W4kM
B]a>gD[LB]e6_4[MH[IV]f:fI[MR]S7j;MU>gD[LC]e:g4kMC]a>oDkLC_e:g4[MB[`00`000;=V]R5h
7ELQN1eGC]e:g4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmB]a>oEifGYINMV:GGWINUTZlC]e:_4kM
C]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03
001oogoo01Aoo`006Goo00<007ooOol00Woo00<007ooOol00goo00D005YFFUEJEV^b009oo`03=U`f
>d:m0092_@08GYIRUejFHYMNUVOEHmE6_@=6_003>Ye^e7;D009be003K]Abe00<00803004B[e6_4Zm
I[H3J]H046Jf000004JlAYa6_4JLB]e6_4[MM[5fdW:aM]9f/GKB1D:L0d[M00=:_6kEK]D00fkE01<4
DTJlAYa6W4kLC]e:g4kMC]a:gDJlB]eR]fJgH[IV]bgJ;OX]fP02C]`01TkMB]a>g4kLC]e>g0<00003
=WeZeV[F009ZeP8QE`068EQ>g4kLC]a>gDkL0Tkl00YBoDkLC_e>o5;mC]a:gDKMB]e6_0ENMP07CdeC
CDZlB]a:_4kLC_`00U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
2E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eB
o5;l01Aoo`03001oogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooESEJEV^b
00=oo`0H=S/fG3HkA[e2_4:mGWIRUejFIoESeFOe@Ya6_D:LA[e2W7;DK[=be6kCL]A^/d:M0T:L028n
O4[MA[a6gFJfJ]MV]V[FI[HE=`00A[e2W4Jm@Ya:gDJlB]eb/GKBL[5fdW:a00M:_4[MB[a:gDZlB]e6
_4[MK]A^m@9^e@0IK]@4L`ABA[a2W4JmB]a>gD[LC]e:g2Hm9SaV]f:fI[MR]VJg;MTanRgIC_e>g4km
B]`00`0000I:g4km=WdfWFJfJ]L2J]H0/QeG8GPMEb5hC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a:
gDJlB]e6_6:GGWINUTm=Ddi?CE=>C]aBoDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m4goo00<007ooOol04goo000IOol00`00Oomoo`02Ool00`00Oomo
o`02Ool01000OomooeXe1Goo00<f>cIL=S/00T:m00MRUejFHYMNUV:G;OX^6`02A[d01DJlA[e6_G;D
K]@00g;D00E^e4:L@Ya2W4Jl00=6_@05I[IZeV[FJ]IV]P025AL02d[MB[a:gDZl?Yeb/GKBM[5fdW:a
M]800P0700E:_4[LB[a:gDZl00=:g@08>Ye^eFkEK]D4DPAb159:g@=:g00:C]e:g4kMB]aV]f:fI[MR
]fJgH[H3B[`02TJl00000000C]a>gDkLC]e>g4kM16[F0P0000A6_4ZlA[a:_0=>g00=C_e>g4klC_aB
oDkLC_e>g4kmC]a>oDKMB]d015if00@j>ciK?U/nF`=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01=oo`03001oogoo019oo`006Goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol01Woo01U6_D:LA[e2W4Jm@[aRU`EjHYMNUV:G;OXb6dJlA]e6
_4[MK]=be6jcL]A^/g;D00a2W@02@Y`05DJlB]e6_4KM;UeZefJfJ]HA5QDg5AI:gDJlB]dnWGKBL[5f
dW:aM]9b/@0300L02DZlC]e:g4kMB[`jWCYmK]E^e003K]D04@AB17=:_4kMB[a>gDZlB]e6_4[MA[aV
]f:fI[MR]U>ACg400`0000Y6_4kmC]a>oD[LB]e:g4[MB[a:g@9ZeP2eI[HQN000B[a6W4ZmA[a:_4kL
D_e>g5;mC]aBoDkLD_e>g4kmC]a>oD[LC_e6_4[MGWINUeif?U/j>ciK>S]>oDkLD_e>g5;mC]aBoDkl
D_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol04Goo
000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool20008Ool014JmA[a6_DJl0PFJ011RUejFHYMNUS8K
;OX^6bgkA[e6_4JmK]Abe6kDL]A^e0803004B[e6_4Zm<Ud2<Wd00f[FI[IZeP02J]H03ADF5AM:_4[M
B[a:gGJaM]9b/GKBM[5fdW:a00=2W004B]a:gD[LB]d2>Yd5K]D03PAc1584LTkLC]e:g4kMC]a:gDJl
B]eR]fJgH[H300002DJlB[a:_4ZlA[a>gDkLC_e>g003B]d00d[LJ]IZeP02J]H28EL04TkMC]a>g4kL
C]e>g4klC]aBoDkLC_e>o5;mC]a>gDkLC]e>g085NPANMP09?U/j>ciK?U]BoDkLD_a>o5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l4goo00<007ooOol04Goo
000JOol40005Ool00`00Oomoo`08Ool05DJm@Ya6_D:LHYMNUV:GGWIRUejFA[e2W4Jm@Y`jWCImL]A^
/g;DK[=be00200`08DJlB]e6_4[MA[aZefJfJ]IV]V[GI[HE=a4F5CM6_4[MA[a:gG:aM]9b/GKBL[5f
dT9lAYa2O4:LB[a>gD[LC]e^e003K]D03VkDK]D4DTJl@Ya6_D[LC]e:g4kMB]a:gDJlB]d200004V:F
I[L]fC7jB]a>gD[LC]e:g4kmC]a>oDkLB]e:g4[MB[aZe`9ZeP0F7ELQN25GC]e:g4kMB]aBoDkLD_e>
g5;mC]aBoDkLD_e:g4kmC]a>oD[LGYL3GWH0VejGB[a>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC_aBoDkl
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04Woo0`004Woo0005Ool200000goo
0000000IOol00`00Oomoo`09Ool4@[d016:GGYIRUejF0V?E00Y6_DJlA[`jWG;DK]Abe6kDL]A^e0<0
3005A[a6_DJmA[e6_003J]H046Jf5AL004JlAYa6_4ZmB]e6_4[MM[5fdW:aM]9f/P0714:L00A:_4[M
B]e:g@E^e@0317=6W4Jl00=6W003C]e:g4kM00<000049SeR]fJgH[H2;MX02RgjB]a>g4kLC]e:g4kM
C]a>gDkL0SIm1F[F0b5G00I>gDkLC]a>g5;mC]`2C_`02E;mC]a>oDklD_e6_4[MA]e:g@04GWH2Cdd0
1dZlC]a:_4[LB[aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eoogoo015oo`03001oogoo011oo`0017oo00<007ooOol00P006Woo00<007ooOol0
2Woo01E6_D:l@[eNMV:GGYIWeF?DIoESeDJm@Ya6_FjcL]A^/g;DK[=be6jc@Yd00T:L01I6_4[MA[a6
gFJfJ]MV]V[FI[HE=d:LA[e2W4JmA[a:gDJlB]eb/GKBL[5fdP801`09B[a:gDZlB]e6_4[MA[a^eFkD
00=^e@061584LdZlC]e:_4kM0`0001E>gBHl9SeRUVJgH[IV]f:F<OX]fC7jB]a>oDkLC_e:g4kmB]a>
oCIl=Yd00V[F0;QV]V[GJ]HQN1eG8GPQEdkmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlB]eN
MUjGGWI?CDl]Dde>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoA=oo`03001oogoo00moo`0017oo00D007ooOomoo`0001Uoo`<000ao
o`=2_@0AGYISeEjFHYL]nRhK;O]6_DJlA[e^e7;DK]Abe6kDL]A^e004@Y`3A[d02VJfJ]IZeV[F5AHE
5dZlB]e:_4[M0SjM00Eb/GKBM[9fdW:a00<01`05B[a:g4ZlB]e:_002B]d5K]D00`AB17<000020002
B]`02TkMB]a>gF:gI[MR]VJgH[MV]dJl0dZl0dkL00E>gDkLC]e>g4kM00EZeP800005B[a6_4ZlA[a>
o@03C]`035;mC]a>o4klD_e>g4kmC]a>oDJlB]e6g@ANMP05?U/j>ciKC]a>o@03C]`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
00000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d04goo00<007oo
Ool03Woo0004Ool01@00Oomoogoo00006Goo00<007ooOol03Goo02/5V`FJHYMNMV:GGYHb6bgj<Q/]
nTKMA[a:gFjcL]A^/g;DK[Abe00<B]e6_4[MA[`bOBiMJ]IV]V[GI[HE=aDF5CM:_4[MA[a:gCjMM]9b
/GKBL[5fdP0400L01TZlC]e:g4kM>WdjW@9^e@03J]E^e@000080000M17<4DTkMB[a>gDJlB]e6_4[M
H[IV]f:FI[M?L4nAA[a:_DJlB[e6_4kmC]a>oDkLB]e:g4[MI[IZe`02J]H05aeG0016_4ZlAYa:_DJl
D_e>g5;mC]aBoDkLD_e>g5;mB]a>oDkLC_d1ND[MA[`00Uif09iNUcXk?U/j>ciKC]aBoDkLD_e>g5;m
C]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l4goo00<0
07ooOol03Woo0004Ool01@00Oomoogoo00006Goo00<007ooOol03Woo019RUejFHYMNUV:GGYHb6bgj
;Q/]ndJmA[a6_FkDL]A^e7;DK]@200`01DZmA[a:_C9M<Wd00V[F011V]V[FJ]HE=aDF5AM:_4[MB[a:
gGJbM]9b/GKBM[9fdPA2W004B]a:gD[LB]d2K]D300000fkEAYa6_003AY`03TkMB]a>gDJmB]e6_6Jg
H[MV]f:fI[L]fRgjB]`2C]`01TkMB]a>gDkLC_e:g0=:g@AZeP8QE`03C]a>gDkL009>g00<D_e>g4kl
C]aBoDkLC_e>o5;mC]a>gDkL0PEj1Eif00Y:_4kLB[a:g4klD_e>g5;lC_aBo@=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo00eoo`00
0goo0P000Woo0P006Goo00<007ooOol03goo035RUejFHYMNMVOEHmA6_D:LA[e2W3ZMK[=be6jdL]A^
/g;D00`03DJlB]e6_4[MI[IZefJfJ]IV]V[G@Ya6_D:LA[e6_4[MA[a:gG:aM]9b/GKBL[5fdT9lAYa2
O4:LA[a:g@030003K]D0=f[E17=2W4Jl@Ya6_D[LC]e:g4kMA[a:gDJlI[MR]VJgHYHanRgI<OY:g4kM
B]a>gDkLC_e>g4kmB[a:gD[LB]eV]V[GJ]HQN1eG8GQ:g4kMB]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;m
B]a>oDkL009NMP2RGYMNMUifBba?CDZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l4goo00<007ooOol037oo000ROol2000@
Ool01EjFHYMNUV:GHm@00V?E00Y6_DJlA[a6_7;DK]Abe6kDL]A^e0<03005A[a6_DJmA[eV]P03J]H0
4VJf0016W4JlAYa6_4ZmB]e6_4[MM[9fdW:aM]9f/P07B[a:g0<000=:g@E^e@96W007A[a6W4JLB]a>
gD[LC]d00RHm00DV?6JgH[MV]f:f008]fP09;OY:g4kLC]a>gDkLC]e>g4kM008fO@EZeP058GPQEb5G
C]a>o@03C]`035;mC]a>o4klC_e>g4kmC]a>oDJmB]e6g@=NMP0;Cbe?CDl/Cde:_4kLB[a:g5;lD_e>
o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aB
o00COol00`00Oomoo`0<Ool0029oo`03001oogoo011oo`03GWIRUf?D009oo`0=<Q/]nTKMA[a6gDJl
L]A^/g;DK[Abe6jc@Yd00T:L01I6_4[MA[aZeVJf<WeV]V[F5AHI=d:LA[e2W4Jm?Ydn_G:aM]9b/GKB
L[5fdP<00008B]e:_4[MA[a:gDJlB]djO@=^e@0N159>gDZlC]e:_4kMB]a>gD[L9SdV?6JgHYIV]f:f
I[M6_4ZmA[a:_D[LC_e>g4kmB]a>oD[LC_eV]V[G0V[F01IV]V[GA[a:_4JLB[e>g4kmC]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4[MA[a:g@=NMP2QGYMNMSiK>SXnFdkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol00`00Oomoo`0;
Ool0025oo`03001oogoo015oo`03HYMNUWoo009oo`0<;OX^6bgkA[e6_4JmK]Abe6kDL]A^e7;D14:L
00E6_4JmA[dbOFJf00=ZeP0;5AHE5dZlB]e:_4[M?YefdW:aM]9f/P02000300L014[LB]e:g4[M0cZM
16kE00D4L`ABB]a:g4[M00=:g00:C]e:g6JgH[MV]f:fI[M?L4maA[`3B[`3C]`00dkMB]a:g@02B]d4
J]H03B5G0016_4ZlA[a:_4JlD_e>g4klC]aBoDkL009>o007D_e>g4kmC]a:gDJmB]d015if0SiK00@j
>dkLC]a>o@9>g003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo019oo`8000aoo`008Goo00<007oo00005goo01l]nS8K;OY6gDJlA]e^
]7;DK[=be6jd00e6_4[MA[a:gBiM<Wd^GF[FI[IZefJf5CLE5QTgB[a:gDJlB]eb/@03000037:aM]9b
/DJL@Wa2W4ZlC]e:g4kM>WdjW@9^e@0RJ]E^e@AB17<4DPAcB]a>gD[LC]e6_4[MA[aV]f:fI[M;L4ma
Bg1:_DJlB[e6_4ZmC]a>oDkLC_e:_4[MB]aZeVJf=Yd2J]H05R5G8GQ:g4kMB]a>gD[LD_e>g5;mC]aB
oDkLD_e>g5;mB]a>oDkL1GX1FEjG0eif0:1NUcXk?U/j>U;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1=oo`03001oogoo00Yo
o`008Goo0P0067oo00A6_DJlA[a6_08jW@0<L]A^e7;DK]Abe00<00e6_4ZmA[a:_DJl0f[F00MV]V[F
J]HE=aDF5AM:_@0300001WJbM]9b/GKBL[9fdP=2W005B]e:g4[MB]a:g@05K]D00`AcAYa6_002AY`0
2dkLC]e:g4kMA[e:gF:fI[M?L6JgH[H00RgJ00Y>gD[LC]a>g4kMC]a>gDkLC_e:g09:g@05=WeZeV[F
J]HQN0028EL00dkLC]e>g002C]`035;mC]a>o4klD_e>g4kmC_a>gDkLC]e>g0INMP08B]a:_4kLB[aB
o4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lOol04Goo0P002goo000?Ool40004Ool40006Ool00`00Oomoo`0HOol05dJm@Ya6
_CYmL]A^/g;DK[Abe6jc00d0300=A[a:gDJlA]e6_6[GI[IZeVJf6CL0100001=6_4[MA[afdW:aM]9b
/GKBL[40249lAYa2O4[MA[a:gDJlB]eZe@03K]D07V[E17=2W4Jl@Ya6_D[LC]e:g4kM9S`V?B8lI[MR
]VJg;MTanRgIC]e:g4kMB]a>gD[LC_e:g4km=WdfW@9ZeP0FI[IZef[F8GPQEb5hC]a>oDkLD_e>g5;m
C]aBoDkLD_e>g5;mC]a:gDJlB]d3GWH0Y5jGGWI?CD//C]e:_4kMB[aBoDkLD_e>g5;mC_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`>Ool30000
0goo001oo`0:Ool000ioo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomo
o`0IOol02TJmA[a6_6kDL]A^e7;DK]Abe6kD0d:L00E6_4JmA[e6_FJf009ZeP<0000CAYa6_4JLA[a:
_D[MA[afdW:bM]9b/WKB00L024ZlB]a:_4[MB[`00T[M1FkE00@4LPAcB]a:g@=:g009C]e:g2Hm9SeV
]f:fI[MR]fJg00<]fP08C]e>g4kLC]a>gDkLC]e>g08fO@EZeP06A[a:_4JlB[a>g4km0TkL00a>o5;m
C]a>o4kLC_e>g4kmC]a:gDJmB]d3GWH014l/Bba?;D//0TkL00I>oDkLD_aBo5;mC_`2D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aB
o5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00Yoo`@0
00Aoo`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03001oogoo00=oo`8001]oo`0;A]e6_4KM
K[Abe6jcL]A^]7;DK[=2W@02@Y`00d9lB]e6_00300006fJfJ]HE5QTgB[a:gDJlB]dnWGKBL[5fdW:a
M]9b/@0800M:gDZlB]e:_4[MA[a:gDJlK]EZe@02K]D07`Ac1584LdZlC]e:_4kMB]a>gD[LI[MR]VJg
HYIV]d]@Cg16_4ZmA[a>oD[LC_e>g4kmB]a>oD[LJ]IV]V[G009ZeP0F8EL004JlB[a6W5;mC]a>oDkL
D_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlGYL3GWH0XciK>S/nFcXjD_e>g4kmC]aBoDklD_e>g5;mD_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00Io
o`<000Qoo`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03001oogoo009oo`8001eoo`05A[e6
_4JmK]Abe003K]@017;D00a:_DJl0`0001XbOF[FI[IZeVJfJ]HE5QDgB[a:gDZlB]eb/WKBL[9fdW:b
M]801`0800M:gD[LB]e:g4[M0SZM16kE0PAc00`4LPAcB]a:gD[LB]e6_D[MA[aV]f:gI[L3Bg000dZl
A[a:_002B[`01DkLC]e>g4kmB]`00T[M1F[F00TQEdZlA[a:_4JlC_a>g5;mC]`00Tkl00YBoDkLC_a>
g4kMC]a>gDkLB]e6_@=NMP09>S/nFciK?U/j>e;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`3Ool3000<Ool00`00Oomo
o`08Ool000moo`@000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo01eoo`08A]e6_4KM
K[Abe6jcL]A^]0<0000OA[a:gBiM<WeV]V[FI[IZefJf5CLE5QTgA[a:gDJlB]eb/GKBL[5fdW:aM]92
O4JL@Wa>gDZlC]e:g4kMJ]D00fkE01iZeDJm@Ya6_4:LA[e:g4kMB]a:gDJlB]eRUVJgH[IV]f:F<OX]
fDkMB]a>gD[LC]e>g4kmC]a>oDZlB]d2J]H05fJfJ]MV]R5h8EM>gD[LC]e:g5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e:g4kmC]`00Uif0:INUeifGWI:_4kMB[a>gDZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo08000moo`03
001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
7Woo00@jWFkDK]A^e0<0000;00`03@0<B[e6_4ZmI[IZeVJfJ]IV]P02000034JlAYa6_4ZmB]e6_4[M
L[9fdW:bM]9b/PE2W004B[a:gD[MB]d5K]D2AY`03DJlAYa>gDkLC]e:g4[MA[e:gF:fI[MR]fJg00<]
fP09C]e:g4kLC]a>gDkLC]e>g4kM008fO@EZeP068GPQEdkLC]a>gDkL0Tkl00]BoDkLC_a>o5;mC]a>
oDKMB]e6_D[M00ANMP9;;005B[a:g4ZlC]a:_002D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo000
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo11oo`03001oogoo00Qo
o`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07goo00Mbe000
001^]7;DK[=2W@02@Y`08D9lB]e6_4KMI[IZefJfJ]HE5P00@Ya6_D:LA[e6_4[MA[a:gG:aM]9b/GKB
00M:gDZlB]e:_4[MA[a:gDJlK]EZe@03K]D0=PAB17=2W4Jl@Ya>gD[LC]e:g2Hm9SaV]f:FI[MR]VJg
;MTanRgIC_e:g4kmC]a>oD[LC_e:g3JM=WeZefJfJ]IV]V[G8ELQN25GD_e>g4kmC]aBoDkLD_e>g5;m
C]aBoDkLD_e6_4[MA[a:g@=NMP2VCba;;4l/C]aBoDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`?Ool00`00
Oomoo`08Ool000moo`D000=oo`@000Eoo`8001ioo`<00004L]A^e6kDK]@2Ool3@Y`03TJlA[e6_F[F
I[HbOFJfJ]HE5QDgB[a:gDZlB]d2?Yd01G:bM]9b/WKBL[800P0800I:gDZlB]a:_4[MB[`2B]d4K]D0
4PAc1784Ld[LB]e:g4kMB]a>gD[LI[MR]fJgH[IV]f:gB[a6_09:_008C]e>g4kLC]a>gDkLC]e>g0EZ
eP800003A[a:_4Jl009>g00>C_e>g4klC_aBoDkLC_a>g4kmC]a>oDKMB]e6_@ANMP<nF`=>g005C_e>
g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00U;l3goo00<007ooOol027oo000POol00`00Oomoo`0JOol30003Ool00fjdL]Ao
o`03Ool08P0<@Ye2W4:LA[a:gDJl<WeV]V[GI[HI=aDF6CM:_4[MA[a:gCjMM]9b/GKBL[5fdP0700P0
1dkMB[a>gD[LC]djOCZM0VkE03YZeFkEK]D4L`ABC]e:_4kMB[a:gDJlB]e6_6JgH[IV]f:FBg1;CdZm
A[a:_DJlC_e:g4kmC]a:gDZlB]e:g6[FI[IZefJf8GP004ZmA[a:_4JLD_e>g5;mC]aBoDkLD_e>g5;m
C]a>oD[LC_d1FD[MA[aNU`9NMP2V>SXnFcXk?U]>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d>Ool00`00
Oomoo`08Ool0021oo`03001oogoo01Moo`<000aoo`0600d034ZmA[a:_BiM0S9m015ZeVJfJ]IV]QDg
5AHE=dZlB]e:_4[ML[9fdW:bM]9b/WKB00=2W005B]e:g4[MB]a:g@06K]D217<04@AbC]e>g4kMB]a:
gDJmB]eR]VJgH[MV]f:f;OX]fTkMB]`00TkL00M>oDkLC]e>g4[MB]a:g@05J]H02R5h8EM>g4kLC]e>
g4klC]aBoDkL0Tkl00IBoDkLC_e>g4kMC]`20GX5GWH00dZlB]a:_002C]`015;lC_aBoDkL0U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo5;l00eoo`03001oogoo00Qoo`007goo00<007ooOol05Goo0`003goo02<0300=A[a:gDJl
B]e6_6[GI[IZeVJfJ]M2W4Jm@Ya6_DJlB]e6_4[ML[5fdW:aM]9b/D:L@Wa6W49l@Ya6_4[MA[a:gF[E
00=^e@0fJ[D4Ld:LA[a2W4kMB]a>gD[LB]e6_4[MHYIV]f:fI[L]fC7j;MU>gD[LC]e:g4kmC]a>oDkL
B]e:_4[M=WeZeVJfJ]LQEb5h8EM>gD[LC]e:g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g5jG0eif0:UN
Ud/;Bba:_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0=Ool00`00Oomoo`07Ool001moo`80
01=oo`<0019oo`<03@0MA[a6_DJmA[e6_6[FI[IZeVJf5CM6W4JlAYa6_4JLB]e6_4[ML[9fdW:bM]9b
/T[MB[a:g4ZlB]e:_002B]d5K]D02@AcAYa6W4JlAYa>gD[LC]e:g0029Sd02VJgH[IR]f:gI[L]fRgj
;MY>gD[L0TkL00A>gDkLC]e>g08fO@AZeP048GLQEb5h8EL2C]`03TkmC]a>o4klD_e>g4klC]a>oDkL
C_e6gD[MA[d3GWH02D/[Bba;;4//B[a:g4ZlD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0
37oo00<007ooOol01goo000OOol00`00Oomoo`0?Ool3000FOol094:M@Ya2W4JlB]e6_4KMI[IZefJf
J]IV]QTgB[a:gDJlB]e:_3jmL[5fdW:aM]9b/GKB00Q:gDZlB]e:_4[MA[a:gDJl>YeZ]@9^e@0P17<4
LTkMB[a>gDZlC]e:g4kMB]aV]f:fI[MRUVJgH[I:_DJlB[e6_4kmB]a>oDkLC_e:g4kmB]aZeVJfJ]MV
]P80000EB[e6_4ZlAYaBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]eNMUjG009NMP2Y>SXnFcXk
?U]>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`037oo00<007ooOol01goo000OOol00`00Oomo
o`0<Ool3000KOol3@Y`3A[d04BiMJ]IV]V[F5ALE=dZlB]e:_4[M?YefdW:bM]9b/WKBL[800`0800A:
g4[MB]a:g@8jW@E^e@84L`9:g006B]e:g4[MA[e:gDJm0V:g00UV]f:fBdm7CdZlA[a:_4kLC]d00dkL
00A:gD[LB]e:g@=ZeP0;8ELQN000B[a6_4ZlA[a>o4kLD_e>g002C_`02E;mC]a>o4kLC]e>g4kMA]e:
g@03GWH01CiK?S/nFciKC_d00dkL00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`0
05;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0:Ool00`00Oomo
o`07Ool001moo`03001oogoo00Uoo`<001moo`0OA[a:gDJl<Wd^GF[FI[IZefJfJ]HE5QTg5AI:gDJl
B]eb/GKBL[5fdW:aM]9b/DJL@Wa2W4ZlC]e:g3ZM=Wd00fkE03MZ]FkE1784L`AbC]e:g4kMB]a:gDJl
B]eRUVJgH[IV]f:F<OX]fDZmA[a:_DkLC_e>g4kmC]a:gDZlB]eV]V[FI[IZeb5G8GPQEdkMB]a>gD[L
D_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[L1GX1F@02GWH0[5jGGWHnFcXj?U/j>e;mC]aBoDkLD_e>g5;m
C_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l2Woo00<007ooOol01goo000OOol20008Ool2000ROol05dZmA[a:_DJl
J]IV]V[FI[IZeVJfA[a6W4JlAYa:gDJlB]eb/WKBL[9f/W:bM]8014:L00=:g4[MB]`01VkE00`4LdJL
A[a6W4kMC]a>gD[LB]e6_D[MH[H2H[L01VJg;MX]nRgJC]e:g09>g007C_e>g4kMC]a:gD[LB]d00f[F
00@QMb5G8GPQE`9>g00>C]e>g4klC_aBoDkLC_e>o5;mC]a>oDkLC]e>g0ENMP0:001>g4ZlB]a:_5;m
C]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`08Ool00`00Oomoo`07Ool001ioo`03001oogoo
00Eoo`<002Eoo`1IB]e6_4KMA[aZefJfJ]IV]QTg0016_D:LA[e6_4[MA[afdW:aM]9b/GKBL[8024Zl
B]e:_4[MA[a:gDJlK]EZ]FkEJ]E^e@AbA[e6W4Jl@Ya>gD[LC]e:g2Hm8S`V?F:FI[MR]VJg;MTanT[L
C]e:g4kMB]a>oD[LC_e:g3JM<WeZefJfJ]IV]REh8ELQN25GD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkL
D_e6_4[MGWINU`02GWH20000ZTZlC]e:_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d:
Ool00`00Oomoo`06Ool001ioo`03001oogoo009oo`<002Uoo`=6_@05I[IZeVJfJ]IV]P025CL02dJl
AYa6_4ZmB]e6_7JbL[9fdW:bM[800P0800I:_4[LB[a:gDZlB]d5K]D217<2B]`02T[MB]a>gD[LC]dV
?2HmH[MV]f:f0V:g00DanRgJ;OY>g4kM00=>g004C]e>g4kMC]`5J]H01DJlB[a6_4ZlA[`00TkL00e>
oDkLC_a>o5;mC]a>oDkLC_e>g4[MA]e:g@04GWH013hk?U]>g4km0dkL00EBoDklD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00ABoE;lD_aBo0Yoo`03001oogoo00Ioo`007Woo00<007oo00000P00;Goo01A:gDJlA]d^GF[G
I[IZeQDF6CLE5T[MA[a:gCjMM]9b/GKBL[9fdW:a0`0803m:_4kMB]a>gCIm>YeZeFkEJ[E^eF[E27<4
LTkMB[a>gDZlC]e:g4kMHYIV]f:fI[MRUT]?Adm:_DJlB[e>g4kmB]a>oDkLB]e:_4[MB]aZeVJfJ]LQ
E`00AYa:_DJlB[a6W5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[`00Uif0:iNUeif?U/j>SiKC]a>
oDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`9Ool00`00Oomoo`06Ool001ioo`<0031o
o`8bO@06J]IV]V[FI[IZeQDG0QDg00Y:gDZlB]eb/WKBL[9f/W:bM]9b/P=2W003B]a:gD[L008jW@E^
e@<4L`08C]e>g4kMB]a:gDJmB]eR]P9R]`0?I[MR]S7j;MY:_4JlB[a>g4kmC]a>gDkLB]e:g4[M00AZ
eP038ELQN4kL009>g00@C]e>g4klC]aBoDkLC_e>o5;mC]a>gDkLC]e>g4[MA]d4GWH02CiK?S/nFdkl
D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0Qoo`03001oogoo00Ioo`0017oo1@000goo
100017oo10001goo00<007ooOol0<7oo05EZefJfJ]IV]V[GI[I6_D:LA[e2W4[MA[a:gG:bM]9b/GKB
L[9fdT9lAYa2O4:LB[a>gD[LK]EZ]FkEJ]E^eFZe29=6W4Jl@Ya>gD[LC]e:g4[MA[aV]f:FI[MRUVJg
;MTanRgIC]e:g4kMC]a>oDkLC_e>g4[MB[a:gFJfJ]IV]REh8ELUN4[LC]e:g4kMB]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4kmB]aNU`03GWH20000[4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l1goo00<007ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol01Goo0P00<Goo00mZeVJfJ]IV]QTg0016_4JLA[a:_D[MA[af/W:bM]800g:b
00H024ZlB]a:_4[MB[`2B]d5K]D02@AcAYa6W4JlAYa>gD[LC]e:g0039Sd02F:fH[MR]fJg;MXanTkL
C]e:g002C]`014kMC]a>gDkL0SIm16[F00<QMb5G8GP00dkL00e>oDkLC_a>o5;mC]a>oDkLC_e>g4[M
A]e:g@04GWH200001dZlC]a:_4[LD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0
1goo00<007ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol01goo00<007ooOol0;Woo00=V]V[GOol00Woo04hI=aDFA[e2W4JmA[a:gDJlM]9b/WKBL[5f
dP0800U:_4[MB[a:gDJlB]eZeFkEJ[E^eF[E29<4LTkMB[a>gDZlC]e:g4kM8Q`V?F:FI[MRUVJgHYHa
nRgI<OY>g4kmB]a>oD[LC_e:g4kmB]aZeVJfJ]MV]V[FAYa:_DJlB[a>g5;mC]a>oDkLD_e>g5;mC]aB
oDkLD_e6_4[MA[`2GWH0/EjGGWINMSXj?U]>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@06Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`08Ool00`00Oomoo`0bOol021DG6CLE=d[MB[a:gCjMM]83L[800gKBL[80
200200P014[LB]e:g4[M0SZM1FkE00X8L`AcB]a:g4[MB]a>gD[LC]eR]P9R]`09I[MR]TM?Adi:_4Jl
B[a>g4kM009>g09:g@03B]a:gD[M00=ZeP0;8GL004JlB[a6_4ZlC]a>o4kLD_e>g002C_`02U;mC]a>
oDkLC_e6_D[MA]eNMP000Uif00DnFchk?U]>g4km009>g003D_aBoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lOol01Woo00<007ooOol01Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol02Goo00<007ooOol0<Woo04hE5QTg5AI:gDJlB]eb/WKBL[5fdW:b
M]9b/DJL@Wa2W4ZlC]e:g3ZM=We^eF[EK]EZ]FkE1788T`AbC]e:g4kMB]a:gDJlB]eRUVJgHYIV]f:F
<OX]fDZmA[a:_DkLC_e>g4kmB]a:gDZlB]eV]V[FI[IZeb5G9GQ:g4kMB]a>gDkLD_e>g5;mC]aBoDkL
D_e>g4kmC]a>oDJlB]d3GWH0/5jGGWHnFcXj?U]>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`6Ool00`00Oomoo`05Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0:Ool2000bOol02DJlAYa6_4JLB]e6_4[ML[9fdP03L[800gKB@Ya2W002
@Y`00d[LB]e:g006K]D030QcAYa6_4JLC]e>g4kMB]a:gDJmI[MR]P9R]`06I[L]fS7j;MY>gD[L0TkL
00=>oDkLC]d00T[M00=:g4[MJ]H00V[F0R5g00HUN4kLC]a>g4kMC]`2C_`02E;mC]a>oDklD_e>g4kM
C]a>g@05GWH02000B[a>g4ZlB]a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo7oo00Aoo`03001oogoo00Eoo`0017oo0`0017oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00aoo`03001oogoo031oo`1@A[e2W4JmA[a:gDJlB]eb/WKBL[5fdW:b00U:_4[MB[a:
gDJlB]e6_6kEJ[E^eF[EK]D4LTJmAYa6_4:LC]e:g4kMB]`V?B8l9SeRUVJgHYIV]bgI<OY:g4kMB]a>
gD[LC_e:g4km=WdfWFJfJ]MV]V[FI[HUN25G9GQ>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:
gEifGYMNMP<0002_B[a>gDZlC]e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`017oo00<007ooOol01Goo0006Ool00`00Oomoo`03Ool40004Ool4000@Ool00`00Oomoo`0`Ool0
2DJlAYa6_4ZmB]e6_4[ML[9fdP02L[80200800U:_4[LB[a:gDZlB]d5K]D03PRC17=:g4[LB]e:g4kM
B]a>gB8l9SeR]fJgH[H2H[L01C7j;MXanTkLC]d00dkL00=>gDkLC]d01V[F00A6_4ZlA[a:_0=>g00<
C_e>g4klC_aBoDkLC_e>g4kmA[e:gDKM15if00DnFchkC]a>g4km009>g003D_aBoDkl009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`02Ool00`00Oomoo`05Ool002Uoo`03001oogoo
031oo`3oB]e6_4[M?Ydn_G:aM]9b/WKBL[402@0800U:_4kMB]a>gCIm>YeZeFkEJ[E^eF[E29<4LTkM
B[a>gDZlC]e:g4kMHYIV]f:FI[MRUTM?@bi:_DJlB[e>g4kmB]a>oD[LB]e:_4[MI[IZeVJfJ]MV]P00
AYa:_DJlB[a>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[aNMUYfGYLj>ciK>SYBoDkLC_e>g5;m
C_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m005Bo05Bo@=oo`03001oogoo00Eoo`00
:Woo00<007ooOol0<7oo00E:gDZlB]e:_7KB00=b/P03M]9b/T:L0092W003B]a:gD[L008jW@E^e@0;
17<8T`AcC]e>g4kMB]a:gDJmB]eR]P02H[L016JgH[HanRgJ0dZl00A>g4kmC]a>g@9:g@08B]aZeV[F
J]IV]V[F8GLUN0=>g00?C]e>g4klC]aBoDkLC_e>o5;mC]a>gDkLC]d1F@5J00ANMP8nF`05?S]Bo4kl
D_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`3Ool00`00Oomoo`05Ool0
02]oo`80035oo`1;B]e6_4[MA[afdW:aM]9b/WKB@Wa6W49l@Ya:_4kMB]a^eFZeK]EZeFkEJ[D8TdJL
A[a2W4kMB]a>gD[LB]e6_6JgHYIV]f:FI[L]fC7j;MU>gD[LC]e>g4kmC]a>oD[LB]e:_3JMI[IZeVJf
J]LQEbEhB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_eJMUjG009NMP80002aB[a>gDZlD_e>
g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00=oo`03001oogoo00Ao
o`00;Goo00<007ooOol0<7oo00A6_4[MB[efdP=b/P0600U:_4[LB[a:gDZl0T[M1FkE00T4L`QcAYa6
_4JLC]e:g4kMB]`00RHm00YV]f:fH[MR]fJg;MXanRgJC]e:g09>g003C]e>g4kM008fO@05I[IZeV[F
J]IV]P028GL01REhC]a>g4kLC_e>g09>o009D_e>g4kmC]a>oDkLB]e6gD[M00=NMP<00003B[a>g4Zl
009Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;l
D_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l0Woo00<007oo
Ool017oo000^Ool00`00Oomoo`0`Ool0<cZMM]9b/WKBL[5fdP0800U:_4[MB[a:gDJlB]e6_3ZMJ[E^
eF[E29<4LPRCB[a>gDZlC]e:g4kMB]aV]f:FI[MRUVJgHYI:_DJlB[e6_4kmB]a>oD[LC_e:g4kmI[IZ
eVJfJ]MV]P020000c4ZmA[a:_4kLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDJlB]e6_5ifFWINMeif?U/j
>SiKC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lOol0
00Ioo`00;goo00<007ooOol0;goo00HnWG:bL[9b/WKBL[8300T014[LB]e:g4[M0SZM1FkE00X8T`Ac
B]a:g4[MB]a:gDJmB]e6_@9R]`04I[MR]T<^@bh4B[`00dkMC]a>g002B]d04D[LB]eZeV[FI[IZeR5g
0016_4ZlA[a:_4kLC_a>g5;mC]`00Tkl00QBoDkLC]e>g4kM0EU:gDKM0eif0SiK00Dn>ciKC_aBoDkL
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;l
D_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo7oo00001Woo000`
Ool2000`Ool017KBL[5fdW:b0Woo0456W49l@Ya:_4kMB]a>gDZlK]EZeFkEJ[E^e@Ac29<4LTkMB]a>
gD[LB]e6_4[MHYIV]f:FI[MRUS7j;MU>gD[LC]e:g4kmC]a>oD[LB]e:_6[GI[IZeVJf9GPQEbEhB]a>
gD[LC]e>g5;mC]aBoDkLD_e>g5;mB]a>oDkL0GX1FEig009NMP2gFWINMdZlC]e:_4kMC]aBoDkLD_e>
o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001B
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0000Ioo`00<Woo00<007oo
Ool0;Woo00=fdW:bOol00Woo14:L00E:_4[MB]e:gDZl00=^e@0=J]D8TdJLA[a6W4kMC]a>gD[LB]e6
_D[MH[H00V:g00IV]bgJ<OX]fTkMB]`2C]`00dkmC]a>g@02B]d024[LJ]IZeV[FI[HUMb5g9GP3C]`0
34kMC]a>o4klD_e>g4kmC_aBoDkLC]e>g0ENMP800007B[a>g4ZlB]aBo5;mC_`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l0goo00<007ooOol017oo000cOol00`00Oomoo`0bOol0
@`09B[a:gDZlB]e6_4[MA[a:gFZeK]EZ]FkE17<8TdJLA[a2W4kMB]a>gD[L9SdR?6JgHYIV]f:FI[L]
fC7j;MU>oD[LC_e>g4kmB]a>oCIm=YeV]V[GI[IZeR5G9GPQEdkmC]aBoDkLC_e>g5;mC]aBoDkLD_e>
g5;mA[a:gDJlGWIJMUig00<0002^D_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l1Woo00<007ooOol00goo000dOol00`00Oomoo`0aOol200T01DZlB]a:_4[MB[`00d[M
00eZeFkEK]D8T`Qc29=:g4[MB]a>gD[LC]e:g002H[L016JgH[IR]f:g14Zl00M>gDkLC]a>g4kMC]a>
g@02J]H026JfJ]HQM`00A[a:_4JlC_d3C]`02dkmC]a>o4klD_e>g4kmC]a>oDJmB]d015if0SiK00@n
>dkLC]a>o@9>g003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol01Woo00<007oo
Ool00goo000eOol2000aOol0700900P02DZlC]e:g4kM=WdjWFZeK]EZ]FkEJ[D8T`Ac29=:_4kMB[a:
gDJlB]e6_6JgHYIV]f:F0P0002=:_DJlB[e6_4kmC]a>oDkLB]e:_4[MI[IZeVJfJ]LQEbEhAYa:_DJl
D_e>g5;mC]aBoDkLD_e>g5;mB]a>oDkLC_e6_4[M009NMP2/FWHnFcXk?U/j>U;mC]aBoDkLD_e>o5;m
C]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_d;Ool00`00Oomoo`03Ool003Moo`03001oogoo02moo`=2W005B]a:
gD[LB]e:g003K]D016[EK]E6W4Jl0TJL00m>g4kMB]a:gDJmB]eR]V:g001V]bgJ<OXafTkMB]`00TkL
00I>oDkLC]e>g4[MB]`3J]H016Jf9GLQMbEh0dkL00eBoDkLC_a>g5;mC]a>oDklD_e>g4kMC]a>g@05
GWH024[LB[a>g4ZlD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l3goo00<007ooOol00goo000hOol0
0`00Oomoo`0_Ool0@TJL@Wa2W4JlB]e6_4[MA[a^eFZeK]EZ]@RCAYa6_4:LA[a:g4kMB]a:gDJlB]dR
76JgHYIV]bgI<OX]fDkMB]a>gD[LC_e:g4kmB]`fWC9mJ]MV]V[FI[HUN25G9GQ:g4kMB]aBoDkLD_e>
g5;mC]aBoDkLD_e6_4[MA[aNMUYfGWMNMP80002RC]e:_4kMB[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@004Woo00<0
07ooOol00goo000iOol00`00Oomoo`0_Ool014[LB[a:gDZl0d[M00QZeFkEK]E^e@Qc29=:g4[M0d[L
00I>gD[L9SdR?FJgH[H2H[L01C7j;MXanS7JC]d00dkL00I>gDkLC]e>g6[FI[H3J]H014JlB[a6_4Zl
0dkL00aBoDkLC_a>o5;mC]a>oDkLC_e6_D[MA]d3GWH30002C]`01TkmC]aBo5;lD_e>o09Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00Aoo`03001o
ogoo00moo`03001oogoo00=oo`00>Woo0P00<7oo01Q:gDZlB]e:_4[MA[a:gFZeK]EZ]FkE17<8TdZl
C]e:_4kMB]a>gD[LI[MRUVJgHYH200008dZlA[a:_DJlC_e:g4kmC]a:gDZlB]e:g6[FI[IZefJf0016
W4ZmA[a:_4kLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]d00Uif09eJMUig>S/nFcXjD_e>g4kmC]aB
oDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo008Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool003aoo`03001oogoo02ioo`05B]e:g4[MB]`jW@02K]D03F[E
K]E^e@RC27<8TdkLC]e:g4kMA[e:gDJm009R]`04I[MR]S7j<MX4B[`01dkmC]a>gDkLB]e:g4[M009Z
eP04I[IZeREg9GP3C]`01TkMC]a>o4kLD_e>g09>o007C]e>g4kMC]a>gDJmB]d015if0SiK00Dn>e;l
C_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`<Ool0
0`00Oomoo`0?Ool00`00Oomoo`02Ool003eoo`03001oogoo02moo`0lB]a>gDZlK]EZ]FkEJ[E^e@Qc
A[a2W4JlB]a>gD[LC]e6_4[MHYIV]f:FI[L]fC7j;MU>gD[LC]e:g4kmC]a>oDkLB]e:_4[MI[IZeVJf
J]LQEbEhB]a>gD[LC]e>g5;mC]aBoDkLD_e>g4kmB]a>oDkLC_eJMUig0Uif0P00099:_4kLB[aBoDkL
D_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m4Goo00<007ooOol03Woo00<0
07ooOol00Woo000nOol00`00Oomoo`0_Ool2B]d024ZlK]E^eFkEJ]D8TdJLA[`2AY`01d[LC]e:g4kM
8SdV?F:f009R]`06I[L]fS7j<MY>gD[L0TkL00A>gDkLC]e>g08fO@=ZeP04I[HUMbEg9GP3C]`034km
C]a>o4klD_e>g4kmC_a:gDJmB]e6g@=NMP<00004B]a:_4kLB[`2D_`01E;mC_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m01Uoo`03001oogoo00eoo`03001oogoo009oo`00?goo00<007ooOol0;goo02E6_4[M
A[a^eFZeK]D8L`RDB[a>gDZlC]e:g4kMB]a>gF:FI[MRUVJgHYI:_4JlB[e6_4kmB]a>oD[LC_e:g4km
B]aZeVJfJ]MV]P020000WdZmA[a:_4kLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDJlB]e6_5ifFWINMchk
?U/j>U;mC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0LOol00`00Oomoo`0=Ool00`00Oomoo`02
Ool0041oo`80031oo`03>Ye^eF[E00=^e@88T`0;B]a:gD[LB]a6_D[MA[e:gF:gI[MR]P020004B[`0
0dkMC]a>g002B]d04D[LB]eZeV[FI[IZeREg0016_4ZlA[a:_4kLC_a>g5;mC]`00Tkl00MBoDkLC]e>
g4kMA[e:g@03GWH3?U/01ChkC]a>g4kmC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m021oo`03001oogoo00aoo`03
001oogoo009oo`00@Woo00<007ooOol0;Woo03QZ]FkEJ[E^eFZe29<8L`RDB]a>gD[LC]e6_4[MA[aV
]f:FI[MRUS7j;MU>gD[LC]e:g4kmC]a>oD[LB]e:_4[MI[IZeVJfJ]LQEbEhB]a>gD[LC]e>g5;mC]aB
oDkLD_e>g5;mB]a>oDkL0EX1FEig0Uif08=JMTkMB[a>g4ZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l02Eoo`03001oogoo
00]oo`03001oogoo009oo`00@goo00<007ooOol0;Woo0VkE00AZeGoo29=6_096W007C]a>gD[LC]e6
_D[MA[d00f:g00D]fS7j<MY>gD[L009>g003C_e>g4kM009:g@05B]`fOFJfJ]IV]P029GL01REhC]a>
g4kLC]e>g09>o008D_e>g4kmC_aBoDkLC]e>g0ANMP800004B]a:_4kLB[`2D_`01E;mC_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`XOol00`00Oomoo`0;
Ool00`00Oomoo`02Ool004Aoo`03001oogoo02eoo`0iK]EZ]GooOol<U0RCA[a2W4JlB]a>gD[LC]dR
?2HmHYIV]f:FI[L]fC7j;MU>oD[LC_e>g4kmB]a>oC9m=YeV]V[GI[IZeR5G9GPQEbEhC]aBoDkLC_e>
g5;mC]aBoDkLD_e>g5;mA[a:gDJlGWIJMUig00<0001iD_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0;Goo00<007ooOol02goo00<007ooOol0
0Goo0015Ool2000bOol229<01d[MB]a:g4[LC]e:g4kM009R]`04HYIR]`000003B[`04DkMC]a>g4kL
C]e>g4kMI[IZeVJfJ]IV]P00A[a:_4JlB[`00dkL00]>oDkLC_a>o5;mC]a>oDkLC_e6_D[M00ANMP8n
F`05?S]>g4kLC_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009B
o35oo`03001oogoo00Yoo`03001oogoo005oo`00Agoo00<007ooOol0;goo0388L`bD29=>gD[LC]e:
g4[MA[a:gF:FI[MRUVJg001:_4JlB[e6_4kmC]a>oDkLB]e:_4[MI[IZeVJfJ]LQEbEhAYa:_DJlD_e>
g5;mC]aBoDkLD_e>g5;mB]a>oDkLC_e6_4[M0Uif07IJMUig?S/nFcXjD_e>g5;mC]aBoDklD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoCEoo`03001oogoo00Uoo`03001oogoo005oo`00B7oo
00<007ooOol0;goo0dJL00I>gD[LC]e>g4[MA[d3H[L01F:F<OXanTkMB]`00TkL00e>oDkLC]e>g4[M
B]a:gFJfJ]IV]V[F9GLUN003C]`03DkMC]a>o4kLD_e>g4kmC_aBoDkLC]e>g4kM00ANMP800007B[a>
g4ZlD_a>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`iOol00`00Oomoo`09Ool00`00
Oomoo`01Ool004Uoo`03001oogoo02ioo`0cA[a2W4JlAYa>gD[LC]e:g2Hm8QaV]f:FI[MRUS7j;MTa
nT[LC]e:g4kmB]a>oD[L=YdbOF[GI[IZeVJf9GPQEbEhC]aBoDkLC_e>g5;mC]aBoDkLD_e>g4[MA[a:
gDJlGWIJMUig00<0001/C]e:_4kLB[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l?Goo00<007oo
Ool027oo00<007ooOol00Goo001:Ool2000_Ool02T[MB]a:g4[LC]e:g4kMB]aR]f:F0f:g14Zl0dkL
00e>gDkLC]e>g6[FI[IZeVJf9GP004ZlA[a:_003C]`034kmC]a>o4klD_e>g4kmC]a>oDJmB]e6g@=N
MP8nF`05?S]>g4kLC_e>g002D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`10Ool00`00Oomoo`07Ool00`00
Oomoo`01Ool004aoo`03001oogoo02ioo`0:B[a>gDZlB]e6_4[MA[aV]f:FI[L200008TJlB[e6_4Zl
B]a>oDkLB]e:_4[MB]aZeVJfJ]MV]REhAYa:_DJlB[a>g5;mC]aBoDkLD_e>g5;mB]a>oDkLC_e6_4[M
0Uif06QJMSiK?S/nFcXjD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mAWoo00<007ooOol01Woo00<007ooOol00Goo
001=Ool00`00Oomoo`0^Ool01T[LC]e>g4[MA[e:g@9R]`05HYIR]c7j<OY:g002C]`03DkMC]a>gDkL
B]e:g4[MI[IZeVJfJ]HUMbEh00=>g00<C]e>g4klC]aBoDkLC_e>o5;mC]a>gDkL0P5I15if00Q:g4Zl
C]a:_5;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mOomoo`17Ool00`00Oomoo`07Ool10001Ool1Ool004ioo`03001oogoo02io
o`0_B]a>gD[LB]e6_4[MHYIV]f:F<OX]fC7jB]a>gD[LC]e>g4kmC]a:gDZlB]eV]V[FI[IZeb5G9GPQ
EdkMB]a>gDkLD_e>g5;mC]aBoDkLD_e:g4kmC]aNMUYfGWMNMP020000GdkMB[a>g4ZlD_e>g5;mC]aB
oDklD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0CGoo00<0
07ooOol01Woo0@000Goo0Goo001?Ool2000_Ool01D[LC]e:g28m8S`00f:g00ARUS7j<OXanP=>g004
C]e>g4kMC]`2=Wd026[FI[IZeVJfB[a6_4ZlA[`2C]`034kmC]a>o4klD_e>g4kmC]a>oDJmB]e6g@AN
MP8nF`9>g006C_e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo59oo`03001oogoo00Eoo`40005oo`5oo`00DGoo00<007ooOol0;Goo00M:g4kMB]aV]f:FI[MR
UP0200008DZmA[a:_4[LC_e>g4kmB]a>oD[LJ]IV]V[GI[HUN000B[e6_4ZlAYaBoDkLC_e>g5;mC]aB
oDkLD_e>g5;mA[a:g@02GWH0FeYfGWLn>ciK>SYBoDkLC_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l05Eoo`03001oogoo00Eoo`40005oo`5oo`00DWoo00<007ooOol0
;Goo00E6_D[MA[eR]f:F009R]`03<OXafDZl009:_005C]a>gDkLC_e:g002B]d01V[FI[IZeVJf9GPU
M`9>g006C]e>g4klC]aBoDkL0Tkl00MBoDkLC]e>g4kMA[e:g@04GWH3?U/015;lC_aBoDkL0U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo5Uoo`03001oogoo00Aoo`40005oo`5oo`00Dgoo
00<007ooOol0;Goo02Y6_4[MHYIV]f:FI[L]fC7j;MU>gD[LC]e:g4kmC]a>oDZlB]e:g6[FI[IZebEg
9GPQEdkMB]a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmB]a>oEYfGWL2GWH20000DDZlC]a:_4kMC]aBoDkL
D_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo01MOol00`00Oomoo`03Ool10001Ool1Ool005Aoo`03
001oogoo02eoo`068S`R?F:gH[MRUV:g0S7j014afDkLC]a>gDkLC]e>g4kM<WeZeVJfJ]IV]REh9GLU
N2Eg009>g00<C_e>g4klC_aBoDkLC_e>g4kmC]a:gDKM0eif0`000TkL00I>oDkLC]aBo5;mC_`2D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eBo5;l069oo`03001oogoo00=oo`40005oo`00EGoo0P00;Woo07IRUVJgHYIV]f:F
B[e6_4ZlA[a>oDkLC_e:g4kmB]aZeVJfJ]MV]V[F001:_DJlB[a6W5;mC]a>oDkLD_e>g5;mC]aBoDkL
D_e6_4[MA[aNMUYfGWLn>ciK>SYBoDkLC_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoFEoo`03001oogoo00=o
o`40005oo`00Egoo00<007ooOol0:goo00IR]f:FH[MR]c7j0003B[`01DkLC]e>g4kmB]`00T[M00IZ
eVJfJ]IV]REh9GL3B[`01DkLC_a>g5;mC]`00Tkl00MBoDkLC]e>g4kMA[e:g@04GWH3?U/015;lC_aB
oDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004
D_eBo5;lD_a/Ool00`00Oomoo`02Ool10001Ool005Qoo`03001oogoo02]oo`0WI[MoogooOolanT[L
C]e:g4kMC]a>oDkLC_e:_4[MI[IZeVJfJ]MV]REh8EM>gD[LC]e:g5;mC]aBoDkLD_e>g5;mB]a>oD[L
C_eJMUig009NMP800010B[a>g4ZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eaOol01@00Oomoogoo00000Goo001IOol00`00Oomoo`0^Ool2
<OX04C7IC]a>g4kMC]a>gDkLC]dbOCImI[IZeVJfJ]HUMbEh9GL00TkL00e>oDkLC_a>o5;mC]a>oDkl
D_e6_D[MA]e:g@03GWH300000dZlC]a:_002D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00U;lMGoo00@007ooOol0005oo`00FWoo0P00;Woo065:_DJlB[a6_4km
C]a>oD[LC_e:g4kmI[IZefJfJ]HQE`00A[a:_4JLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLB]e6_5if
FWINMeif?U/j>SiKC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@1hOol01000Oomoo`000Goo001LOol00`00Oomoo`0/Ool4B[`2C]`00dkMB]a:g@02B]d01VJf
J]IV]V[F9GLUN09:_005A[a>o4kLD_e>g002C_`025;mC]a>gDkLC]e>g4[MA]d3GWH4?U/00dklD_e>
g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_alOol00`00Ool00001Ool005eo
o`03001oogoo02aoo`0QC]e:g4kMB]a>oDkLC_e>g4[MB]aZeVJfJ]MV]REh8ELUN4[LC]e:g5;mC]aB
oDkLD_e>g5;mC]a>oD[LC_e:g5ig009NMP0fFWINMdZlC]a:_4kMC]aBoDkLD_e>o5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mP7oo0@000Goo0@00001NOol00`00Oomoo`0/Ool2C]`01TkMB]a>gDkLC]e>
g08fO@0:J]IV]V[FI[HUN2Eg9GQ>g4kMC]`2C_`02E;mC]a>o4klD_e>g4[MA]e:g@04GWH200000dZl
C]a:_002D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Aoo`800000Ggoo0P00;Goo051>oDkL
C_e:g4kmB]a>oD[LJ]MV]V[FI[IZedJlB[a6W4ZmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4[MA[aNMUYf
GWMNMSiK>SYBoDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lR7oo0P00001QOol00`00Oomoo`0/Ool0
0dkLC]e>g003B]d01T[LJ]IV]V[F9GLUN09:_005A[a:_4kLD_e>g002C_`025;mC]a>oDkLC_e6_D[M
A]d3GWH4?U/00dkLC_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0RWoo0P00001ROol00`00Oomoo`0/Ool074kL
C_e>g4kmB]a:gFJfJ]MV]V[F9GLUN4[LC]e:g4kMC]aBoDkLD_e>g5;mC]a>oD[LC_e6_4[M0Uif02UJ
EUigB[a>g4ZlC]e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l08Yoo`@0009oo`00Hgoo00<007ooOol0;7oo00A>g4kMC]a>g@8f
O@=V]P069GPUMbEhC]a>gDkL0Tkl00UBoDkLC_e>o5;mC]a>gDkLC]d015if0P0000M:_4kLB[a:g5;l
D_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_b<Ool4
0006Ool006Aoo`8002eoo`0LB]a>oD[LC_eV]V[FI[IZedJlB[a6W4ZlC]a>oDkLD_e>g5;mC]aBoDkL
D_e>g4[MA[a:gEYFGWL2GWH07SXj?U]>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7H]oo`@000Yoo`00IWoo00<007ooOol0:goo0T[M00I:g6JfI[IZeVJf
9GP2B[`01DJlB[a>g5;mC]`00Tkl00QBoDkLC_a>g4kmC]a:gDKM15if13iK00E>oDkLC]aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lRWoo10003Woo001WOol00`00Oomoo`0[Ool0
=4[LB]e:_6[GI[IZeREg9GQ:g4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a:gDJlGWIJEUigGWI>
g4ZlC]e:_5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mRWoo0`004Woo001XOol0
0`00Oomoo`0ZOol3B]d3I[H01F[F9GLUN2EgC]d00TkL00=>o5;mC]`00Tkl00IBoDkLC_e>g4kMC]`4
GWH200001TkLB[a:g5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo029Ool4000EOol006Uo
o`8002aoo`0HI[IZeVJfJ]MV]TZlAYa:_4JlC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]eJEUig0Uif
018j>SiKC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_f8Ool4000IOol006]oo`03001oogoo
02Yoo`07I[IZeVJfOol004ZlA[`00TZl00eBoDkLC_a>g5;mC]a>o4kLC_e>g4[MA]e:g@03GWH4?U/0
1DkmC]a>g5;lD_d00e;l00=BoE;lD_`0Qgoo10007Goo001/Ool00`00Oomoo`0YOol08V[GI[Ioogoo
:GPUMdkMB]a>gD[LD_e>g5;mC]aBoDkLD_e:g4kmB]a:gDJlGWIJEUigGWI>g4ZlC]e:_5;mC]aBoDkL
RGoo10008Goo001]Ool00`00Oomoo`0]Ool00bEh9GLUN003C]`02U;mC]a>o4klD_e>g4kmC]a>gDkL
15if0P0000A>g4ZlB]a:_8Uoo`<002Eoo`00KWoo00<007ooOol0;7oo0196W4ZlA[a:_4kLD_e>g5;m
C]aBoDkLD_e>g5;mA[a:gDJlGWL2GWJ;Ool4000XOol006moo`8002eoo`09A[a:_4ZlD_e>g4klC]aB
oDkL009>o005C_e>g4kmA]e:g@02GWJ8Ool4000/Ool0075oo`03001oogoo02Yoo`0BC]e:g4kMB]aB
oDkLD_e>g5;mC]aBoDkLC_e:g4kmA[a:gEYFQ7oo1000<7oo001bOol00`00Oomoo`0[Ool3C]`02e;m
C]a>o4klD_e>g4kmC_a>gDkLC]d0PWoo1000=7oo001cOol00`00Oomoo`0[Ool01dkLD_e>g4kmC]aB
oDkL08Aoo`@003Qoo`00M7oo0P00;7oo00<007ooOol0Q7oo0`00?7oo001fOol00`00Oomoo`0YOol0
0`00Oomoo`20Ool4000oOol007Moo`03001oogoo02Qoo`03001oogoo07aoo`@004=oo`00N7oo00<0
07ooOol09goo00<007ooOol0N7oo1000Agoo001iOol2000WOol00`00Oomoo`1dOol4001;Ool007]o
o`03001oogoo02Aoo`03001oogoo075oo`<004moo`00O7oo00<007ooOol08goo00<007ooOol0KGoo
1000DWoo001mOol00`00Oomoo`0ROol00`00Oomoo`1YOol4001FOol007ioo`80029oo`03001oogoo
06Eoo`@005Yoo`00P7oo00<007ooOol07goo00<007ooOol0HGoo1000GWoo0021Ool00`00Oomoo`0N
Ool00`00Oomoo`1NOol3001ROol0089oo`03001oogoo01eoo`03001oogoo05Yoo`@006Eoo`00Pgoo
00<007ooOol077oo00<007ooOol0EWoo1000JGoo0024Ool2000LOol00`00Oomoo`1BOol4001]Ool0
08Ioo`03001oogoo01Uoo`03001oogoo04ioo`@0075oo`00Qgoo00<007ooOol067oo00<007ooOol0
Bgoo0`00MGoo0028Ool00`00Oomoo`0GOol00`00Oomoo`17Ool4001hOol008Uoo`8001Moo`03001o
ogoo04=oo`@007aoo`00Rgoo00<007ooOol057oo00<007ooOol0?goo1000P7oo002<Ool00`00Oomo
o`0BOol00`00Oomoo`0lOol40024Ool008eoo`03001oogoo015oo`03001oogoo03Uoo`<008Qoo`00
SWoo0P004Goo00<007ooOol0=Goo1000Rgoo002@Ool00`00Oomoo`0>Ool00`00Oomoo`0aOol4002?
Ool0095oo`03001oogoo00eoo`03001oogoo02eoo`@009=oo`00TWoo00<007ooOol037oo00<007oo
Ool0:Goo1000Ugoo002COol2000<Ool00`00Oomoo`0UOol4002KOol009Eoo`03001oogoo00Uoo`03
001oogoo029oo`<009moo`00UWoo00<007ooOol027oo00<007ooOol07Woo1000XWoo002GOol00`00
Oomoo`07Ool00`00Oomoo`0JOol4002VOol009Qoo`03001oogoo00Ioo`03001oogoo01Ioo`@00:Yo
o`00VGoo0P001Woo00<007ooOol04Woo1000[Woo002KOol00`00Oomoo`03Ool00`00Oomoo`0?Ool3
002bOol009aoo`03001oogoo009oo`03001oogoo00]oo`@00;Eoo`00WGoo00D007ooOomoo`0000Uo
o`@00;Uoo`00WWoo0P0000=oo`00Ool017oo1000_Goo002POol200000goo000000020031Ool00:5o
o`800<Eoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.55 .648 .899 r
.39647 .69421 .40173 .70068 .41062 .69917 .40532 .69414 Mtetra
.629 .73 .92 r
.40532 .69414 .41062 .69917 .41956 .6971 .41427 .69221 Mtetra
.639 .739 .921 r
.41427 .69221 .41956 .6971 .42853 .69492 .42326 .69005 Mtetra
.639 .74 .921 r
.42326 .69005 .42853 .69492 .43753 .69284 .43228 .68787 Mtetra
.627 .733 .924 r
.43228 .68787 .43753 .69284 .44655 .69146 .44133 .68595 Mtetra
.443 .64 .94 r
.44133 .68595 .44655 .69146 .45587 .67642 .45035 .6871 Mtetra
.008 0 .025 r
.45035 .6871 .45587 .67642 .46479 .68303 .45962 .67715 Mtetra
.59 .687 .909 r
.45962 .67715 .46479 .68303 .47391 .68115 .46874 .67613 Mtetra
.64 .737 .919 r
.46874 .67613 .47391 .68115 .48307 .67881 .47792 .67392 Mtetra
.649 .746 .92 r
.47792 .67392 .48307 .67881 .49227 .67632 .48713 .67147 Mtetra
.653 .749 .92 r
.48713 .67147 .49227 .67632 .50149 .67375 .49638 .66891 Mtetra
.656 .751 .92 r
.49638 .66891 .50149 .67375 .51075 .67111 .50565 .66629 Mtetra
.657 .753 .92 r
.50565 .66629 .51075 .67111 .52004 .66844 .51496 .66361 Mtetra
.658 .753 .92 r
.51496 .66361 .52004 .66844 .52936 .66574 .5243 .6609 Mtetra
.659 .754 .92 r
.5243 .6609 .52936 .66574 .53871 .66303 .53367 .65817 Mtetra
.53367 .65817 .53871 .66303 .54809 .6603 .54308 .65543 Mtetra
.54308 .65543 .54809 .6603 .5575 .65758 .55251 .65269 Mtetra
.55251 .65269 .5575 .65758 .56695 .65485 .56198 .64994 Mtetra
.658 .753 .92 r
.56198 .64994 .56695 .65485 .57643 .65212 .57148 .64719 Mtetra
.57148 .64719 .57643 .65212 .58594 .64939 .58101 .64444 Mtetra
.58101 .64444 .58594 .64939 .59548 .64665 .59057 .64168 Mtetra
.59057 .64168 .59548 .64665 .60505 .6439 .60017 .63891 Mtetra
.60017 .63891 .60505 .6439 .61466 .64115 .6098 .63614 Mtetra
.6098 .63614 .61466 .64115 .6243 .63838 .61946 .63336 Mtetra
.657 .753 .92 r
.61946 .63336 .6243 .63838 .63398 .63562 .62916 .63057 Mtetra
.62916 .63057 .63398 .63562 .64368 .63284 .63889 .62778 Mtetra
.63889 .62778 .64368 .63284 .65342 .63005 .64865 .62497 Mtetra
.64865 .62497 .65342 .63005 .6632 .62726 .65845 .62216 Mtetra
.657 .752 .92 r
.65845 .62216 .6632 .62726 .67301 .62446 .66828 .61934 Mtetra
.66828 .61934 .67301 .62446 .68285 .62165 .67815 .61651 Mtetra
.67815 .61651 .68285 .62165 .69272 .61883 .68805 .61367 Mtetra
.68805 .61367 .69272 .61883 .70263 .616 .69798 .61083 Mtetra
.69798 .61083 .70263 .616 .71258 .61316 .70795 .60797 Mtetra
.70795 .60797 .71258 .61316 .72256 .61031 .71796 .6051 Mtetra
.71796 .6051 .72256 .61031 .73258 .60746 .728 .60223 Mtetra
.728 .60223 .73258 .60746 .74263 .60459 .73807 .59935 Mtetra
.73807 .59935 .74263 .60459 .75271 .60172 .74818 .59645 Mtetra
.74818 .59645 .75271 .60172 .76283 .59883 .75833 .59355 Mtetra
.75833 .59355 .76283 .59883 .77299 .59594 .76851 .59064 Mtetra
.76851 .59064 .77299 .59594 .78318 .59304 .77873 .58771 Mtetra
.77873 .58771 .78318 .59304 .79341 .59012 .78898 .58478 Mtetra
.78898 .58478 .79341 .59012 .80368 .5872 .79928 .58184 Mtetra
.79928 .58184 .80368 .5872 .81398 .58427 .8096 .57888 Mtetra
.8096 .57888 .81398 .58427 .82432 .58132 .81997 .57592 Mtetra
.81997 .57592 .82432 .58132 .83469 .57837 .83037 .57295 Mtetra
.83037 .57295 .83469 .57837 .8451 .5754 .84081 .56996 Mtetra
.84081 .56996 .8451 .5754 .85555 .57243 .85129 .56697 Mtetra
.85129 .56697 .85555 .57243 .86604 .56945 .8618 .56397 Mtetra
.8618 .56397 .86604 .56945 .87656 .56645 .87235 .56095 Mtetra
.87235 .56095 .87656 .56645 .88713 .56345 .88294 .55793 Mtetra
.88294 .55793 .88713 .56345 .89773 .56043 .89357 .55489 Mtetra
.89357 .55489 .89773 .56043 .90837 .5574 .90424 .55184 Mtetra
.90424 .55184 .90837 .5574 .91904 .55437 .91494 .54879 Mtetra
.91494 .54879 .91904 .55437 .92976 .55132 .92569 .54572 Mtetra
.92569 .54572 .92976 .55132 .94051 .54826 .93647 .54264 Mtetra
.93647 .54264 .94051 .54826 .95131 .54519 .9473 .53955 Mtetra
.9473 .53955 .95131 .54519 .96214 .54211 .95816 .53645 Mtetra
.95816 .53645 .96214 .54211 .97302 .53902 .96906 .53334 Mtetra
.96906 .53334 .97302 .53902 .98393 .53592 .98 .53021 Mtetra
0 0 .27 r
.38682 .80221 .39647 .69421 .40532 .69414 .4 .6888 Mtetra
.612 .713 .917 r
.4 .6888 .40532 .69414 .41427 .69221 .40896 .68725 Mtetra
.636 .736 .92 r
.40896 .68725 .41427 .69221 .42326 .69005 .41796 .68514 Mtetra
.64 .74 .921 r
.41796 .68514 .42326 .69005 .43228 .68787 .427 .68293 Mtetra
.636 .738 .922 r
.427 .68293 .43228 .68787 .44133 .68595 .43607 .68081 Mtetra
.602 .72 .928 r
.43607 .68081 .44133 .68595 .45035 .6871 .44516 .6794 Mtetra
.832 .706 .725 r
.44516 .6794 .45035 .6871 .45962 .67715 .45456 .66425 Mtetra
.34 .39 .768 r
.45456 .66425 .45962 .67715 .46874 .67613 .46354 .67087 Mtetra
.627 .725 .918 r
.46354 .67087 .46874 .67613 .47792 .67392 .47273 .66895 Mtetra
.646 .743 .92 r
.47273 .66895 .47792 .67392 .48713 .67147 .48196 .66657 Mtetra
.652 .748 .92 r
.48196 .66657 .48713 .67147 .49638 .66891 .49123 .66404 Mtetra
.655 .75 .92 r
.49123 .66404 .49638 .66891 .50565 .66629 .50053 .66142 Mtetra
.657 .752 .92 r
.50053 .66142 .50565 .66629 .51496 .66361 .50985 .65875 Mtetra
.658 .753 .92 r
.50985 .65875 .51496 .66361 .5243 .6609 .51922 .65603 Mtetra
.659 .754 .92 r
.51922 .65603 .5243 .6609 .53367 .65817 .52861 .65329 Mtetra
.52861 .65329 .53367 .65817 .54308 .65543 .53803 .65053 Mtetra
.53803 .65053 .54308 .65543 .55251 .65269 .54749 .64777 Mtetra
.54749 .64777 .55251 .65269 .56198 .64994 .55698 .645 Mtetra
.658 .753 .92 r
.55698 .645 .56198 .64994 .57148 .64719 .5665 .64223 Mtetra
.5665 .64223 .57148 .64719 .58101 .64444 .57605 .63946 Mtetra
.57605 .63946 .58101 .64444 .59057 .64168 .58564 .63668 Mtetra
.58564 .63668 .59057 .64168 .60017 .63891 .59526 .63389 Mtetra
.59526 .63389 .60017 .63891 .6098 .63614 .60491 .6311 Mtetra
.60491 .6311 .6098 .63614 .61946 .63336 .6146 .6283 Mtetra
.657 .753 .92 r
.6146 .6283 .61946 .63336 .62916 .63057 .62432 .6255 Mtetra
.62432 .6255 .62916 .63057 .63889 .62778 .63407 .62268 Mtetra
.63407 .62268 .63889 .62778 .64865 .62497 .64386 .61986 Mtetra
.64386 .61986 .64865 .62497 .65845 .62216 .65368 .61703 Mtetra
.657 .752 .92 r
.65368 .61703 .65845 .62216 .66828 .61934 .66353 .61419 Mtetra
.66353 .61419 .66828 .61934 .67815 .61651 .67342 .61134 Mtetra
.67342 .61134 .67815 .61651 .68805 .61367 .68334 .60849 Mtetra
.68334 .60849 .68805 .61367 .69798 .61083 .6933 .60562 Mtetra
.6933 .60562 .69798 .61083 .70795 .60797 .7033 .60275 Mtetra
.7033 .60275 .70795 .60797 .71796 .6051 .71333 .59986 Mtetra
.71333 .59986 .71796 .6051 .728 .60223 .72339 .59697 Mtetra
.72339 .59697 .728 .60223 .73807 .59935 .73349 .59406 Mtetra
.73349 .59406 .73807 .59935 .74818 .59645 .74363 .59115 Mtetra
.74363 .59115 .74818 .59645 .75833 .59355 .7538 .58823 Mtetra
.7538 .58823 .75833 .59355 .76851 .59064 .76401 .5853 Mtetra
.76401 .5853 .76851 .59064 .77873 .58771 .77425 .58235 Mtetra
.77425 .58235 .77873 .58771 .78898 .58478 .78453 .5794 Mtetra
.78453 .5794 .78898 .58478 .79928 .58184 .79485 .57644 Mtetra
.79485 .57644 .79928 .58184 .8096 .57888 .8052 .57347 Mtetra
.8052 .57347 .8096 .57888 .81997 .57592 .81559 .57048 Mtetra
.81559 .57048 .81997 .57592 .83037 .57295 .82602 .56749 Mtetra
.82602 .56749 .83037 .57295 .84081 .56996 .83649 .56449 Mtetra
.83649 .56449 .84081 .56996 .85129 .56697 .84699 .56147 Mtetra
.84699 .56147 .85129 .56697 .8618 .56397 .85753 .55845 Mtetra
.85753 .55845 .8618 .56397 .87235 .56095 .86811 .55541 Mtetra
.86811 .55541 .87235 .56095 .88294 .55793 .87873 .55237 Mtetra
.87873 .55237 .88294 .55793 .89357 .55489 .88939 .54931 Mtetra
.88939 .54931 .89357 .55489 .90424 .55184 .90008 .54624 Mtetra
.90008 .54624 .90424 .55184 .91494 .54879 .91082 .54317 Mtetra
.91082 .54317 .91494 .54879 .92569 .54572 .92159 .54008 Mtetra
.92159 .54008 .92569 .54572 .93647 .54264 .9324 .53698 Mtetra
.9324 .53698 .93647 .54264 .9473 .53955 .94326 .53387 Mtetra
.94326 .53387 .9473 .53955 .95816 .53645 .95415 .53074 Mtetra
.95415 .53074 .95816 .53645 .96906 .53334 .96508 .52761 Mtetra
.96508 .52761 .96906 .53334 .98 .53021 .97605 .52447 Mtetra
.6 .406 .59 r
.38547 .69132 .38682 .80221 .4 .6888 .3947 .68225 Mtetra
.55 .648 .899 r
.3947 .68225 .4 .6888 .40896 .68725 .40361 .68215 Mtetra
.629 .73 .92 r
.40361 .68215 .40896 .68725 .41796 .68514 .41263 .68018 Mtetra
.639 .739 .921 r
.41263 .68018 .41796 .68514 .427 .68293 .42169 .67798 Mtetra
.639 .74 .921 r
.42169 .67798 .427 .68293 .43607 .68081 .43078 .67576 Mtetra
.627 .733 .924 r
.43078 .67576 .43607 .68081 .44516 .6794 .43989 .67381 Mtetra
.444 .64 .94 r
.43989 .67381 .44516 .6794 .45456 .66425 .44898 .67494 Mtetra
0 0 .013 r
.44898 .67494 .45456 .66425 .46354 .67087 .45832 .66491 Mtetra
.59 .687 .909 r
.45832 .66491 .46354 .67087 .47273 .66895 .46752 .66385 Mtetra
.639 .737 .919 r
.46752 .66385 .47273 .66895 .48196 .66657 .47676 .66161 Mtetra
.649 .746 .92 r
.47676 .66161 .48196 .66657 .49123 .66404 .48605 .65911 Mtetra
.653 .749 .92 r
.48605 .65911 .49123 .66404 .50053 .66142 .49537 .65651 Mtetra
.656 .751 .92 r
.49537 .65651 .50053 .66142 .50985 .65875 .50472 .65385 Mtetra
.657 .753 .92 r
.50472 .65385 .50985 .65875 .51922 .65603 .5141 .65113 Mtetra
.658 .753 .92 r
.5141 .65113 .51922 .65603 .52861 .65329 .52351 .64837 Mtetra
.659 .754 .92 r
.52351 .64837 .52861 .65329 .53803 .65053 .53296 .6456 Mtetra
.53296 .6456 .53803 .65053 .54749 .64777 .54244 .64282 Mtetra
.54244 .64282 .54749 .64777 .55698 .645 .55195 .64003 Mtetra
.55195 .64003 .55698 .645 .5665 .64223 .56149 .63724 Mtetra
.658 .753 .92 r
.56149 .63724 .5665 .64223 .57605 .63946 .57106 .63444 Mtetra
.57106 .63444 .57605 .63946 .58564 .63668 .58067 .63165 Mtetra
.58067 .63165 .58564 .63668 .59526 .63389 .59031 .62884 Mtetra
.59031 .62884 .59526 .63389 .60491 .6311 .59999 .62603 Mtetra
.59999 .62603 .60491 .6311 .6146 .6283 .6097 .62321 Mtetra
.6097 .62321 .6146 .6283 .62432 .6255 .61944 .62039 Mtetra
.657 .753 .92 r
.61944 .62039 .62432 .6255 .63407 .62268 .62922 .61756 Mtetra
.62922 .61756 .63407 .62268 .64386 .61986 .63903 .61472 Mtetra
.63903 .61472 .64386 .61986 .65368 .61703 .64887 .61187 Mtetra
.64887 .61187 .65368 .61703 .66353 .61419 .65875 .60901 Mtetra
.657 .752 .92 r
.65875 .60901 .66353 .61419 .67342 .61134 .66866 .60614 Mtetra
.66866 .60614 .67342 .61134 .68334 .60849 .67861 .60327 Mtetra
.67861 .60327 .68334 .60849 .6933 .60562 .68859 .60038 Mtetra
.68859 .60038 .6933 .60562 .7033 .60275 .69861 .59749 Mtetra
.69861 .59749 .7033 .60275 .71333 .59986 .70866 .59458 Mtetra
.70866 .59458 .71333 .59986 .72339 .59697 .71875 .59167 Mtetra
.71875 .59167 .72339 .59697 .73349 .59406 .72888 .58875 Mtetra
.72888 .58875 .73349 .59406 .74363 .59115 .73904 .58582 Mtetra
.73904 .58582 .74363 .59115 .7538 .58823 .74924 .58287 Mtetra
.74924 .58287 .7538 .58823 .76401 .5853 .75947 .57992 Mtetra
.75947 .57992 .76401 .5853 .77425 .58235 .76974 .57696 Mtetra
.76974 .57696 .77425 .58235 .78453 .5794 .78005 .57399 Mtetra
.78005 .57399 .78453 .5794 .79485 .57644 .79039 .57101 Mtetra
.79039 .57101 .79485 .57644 .8052 .57347 .80077 .56801 Mtetra
.80077 .56801 .8052 .57347 .81559 .57048 .81119 .56501 Mtetra
.81119 .56501 .81559 .57048 .82602 .56749 .82164 .562 Mtetra
.82164 .562 .82602 .56749 .83649 .56449 .83214 .55897 Mtetra
.83214 .55897 .83649 .56449 .84699 .56147 .84267 .55594 Mtetra
.84267 .55594 .84699 .56147 .85753 .55845 .85324 .55289 Mtetra
.85324 .55289 .85753 .55845 .86811 .55541 .86384 .54984 Mtetra
.86384 .54984 .86811 .55541 .87873 .55237 .87449 .54677 Mtetra
.87449 .54677 .87873 .55237 .88939 .54931 .88517 .5437 Mtetra
.88517 .5437 .88939 .54931 .90008 .54624 .8959 .54061 Mtetra
.8959 .54061 .90008 .54624 .91082 .54317 .90666 .53751 Mtetra
.90666 .53751 .91082 .54317 .92159 .54008 .91746 .5344 Mtetra
.91746 .5344 .92159 .54008 .9324 .53698 .92831 .53128 Mtetra
.92831 .53128 .9324 .53698 .94326 .53387 .93919 .52815 Mtetra
.93919 .52815 .94326 .53387 .95415 .53074 .95011 .525 Mtetra
.95011 .525 .95415 .53074 .96508 .52761 .96107 .52185 Mtetra
.96107 .52185 .96508 .52761 .97605 .52447 .97208 .51868 Mtetra
.946 .665 .475 r
.3801 .68489 .38547 .69132 .3947 .68225 .38491 .7907 Mtetra
0 0 .264 r
.38491 .7907 .3947 .68225 .40361 .68215 .39825 .67673 Mtetra
.612 .713 .917 r
.39825 .67673 .40361 .68215 .41263 .68018 .40727 .67515 Mtetra
.636 .736 .92 r
.40727 .67515 .41263 .68018 .42169 .67798 .41634 .673 Mtetra
.64 .74 .921 r
.41634 .673 .42169 .67798 .43078 .67576 .42545 .67075 Mtetra
.636 .738 .922 r
.42545 .67075 .43078 .67576 .43989 .67381 .43459 .66859 Mtetra
.602 .72 .928 r
.43459 .66859 .43989 .67381 .44898 .67494 .44374 .66714 Mtetra
.833 .707 .725 r
.44374 .66714 .44898 .67494 .45832 .66491 .45322 .6519 Mtetra
.338 .389 .767 r
.45322 .6519 .45832 .66491 .46752 .66385 .46227 .65852 Mtetra
.627 .725 .918 r
.46227 .65852 .46752 .66385 .47676 .66161 .47153 .65656 Mtetra
.646 .743 .92 r
.47153 .65656 .47676 .66161 .48605 .65911 .48084 .65413 Mtetra
.652 .748 .92 r
.48084 .65413 .48605 .65911 .49537 .65651 .49017 .65156 Mtetra
.655 .75 .92 r
.49017 .65156 .49537 .65651 .50472 .65385 .49954 .6489 Mtetra
.657 .752 .92 r
.49954 .6489 .50472 .65385 .5141 .65113 .50895 .64618 Mtetra
.658 .753 .92 r
.50895 .64618 .5141 .65113 .52351 .64837 .51838 .64343 Mtetra
.659 .754 .92 r
.51838 .64343 .52351 .64837 .53296 .6456 .52785 .64064 Mtetra
.52785 .64064 .53296 .6456 .54244 .64282 .53735 .63784 Mtetra
.53735 .63784 .54244 .64282 .55195 .64003 .54688 .63503 Mtetra
.54688 .63503 .55195 .64003 .56149 .63724 .55645 .63222 Mtetra
.658 .753 .92 r
.55645 .63222 .56149 .63724 .57106 .63444 .56604 .6294 Mtetra
.56604 .6294 .57106 .63444 .58067 .63165 .57567 .62658 Mtetra
.57567 .62658 .58067 .63165 .59031 .62884 .58534 .62376 Mtetra
.58534 .62376 .59031 .62884 .59999 .62603 .59503 .62093 Mtetra
.59503 .62093 .59999 .62603 .6097 .62321 .60477 .61809 Mtetra
.60477 .61809 .6097 .62321 .61944 .62039 .61453 .61525 Mtetra
.657 .753 .92 r
.61453 .61525 .61944 .62039 .62922 .61756 .62433 .6124 Mtetra
.62433 .6124 .62922 .61756 .63903 .61472 .63416 .60954 Mtetra
.63416 .60954 .63903 .61472 .64887 .61187 .64403 .60667 Mtetra
.64403 .60667 .64887 .61187 .65875 .60901 .65393 .60379 Mtetra
.657 .752 .92 r
.65393 .60379 .65875 .60901 .66866 .60614 .66387 .60091 Mtetra
.66387 .60091 .66866 .60614 .67861 .60327 .67384 .59801 Mtetra
.67384 .59801 .67861 .60327 .68859 .60038 .68385 .59511 Mtetra
.68385 .59511 .68859 .60038 .69861 .59749 .69389 .59219 Mtetra
.69389 .59219 .69861 .59749 .70866 .59458 .70397 .58927 Mtetra
.70397 .58927 .70866 .59458 .71875 .59167 .71408 .58634 Mtetra
.71408 .58634 .71875 .59167 .72888 .58875 .72423 .5834 Mtetra
.72423 .5834 .72888 .58875 .73904 .58582 .73442 .58044 Mtetra
.73442 .58044 .73904 .58582 .74924 .58287 .74464 .57748 Mtetra
.74464 .57748 .74924 .58287 .75947 .57992 .7549 .57451 Mtetra
.7549 .57451 .75947 .57992 .76974 .57696 .7652 .57153 Mtetra
.7652 .57153 .76974 .57696 .78005 .57399 .77553 .56854 Mtetra
.77553 .56854 .78005 .57399 .79039 .57101 .7859 .56554 Mtetra
.7859 .56554 .79039 .57101 .80077 .56801 .79631 .56252 Mtetra
.79631 .56252 .80077 .56801 .81119 .56501 .80675 .5595 Mtetra
.80675 .5595 .81119 .56501 .82164 .562 .81723 .55647 Mtetra
.81723 .55647 .82164 .562 .83214 .55897 .82776 .55342 Mtetra
.82776 .55342 .83214 .55897 .84267 .55594 .83831 .55037 Mtetra
.83831 .55037 .84267 .55594 .85324 .55289 .84891 .5473 Mtetra
.84891 .5473 .85324 .55289 .86384 .54984 .85955 .54423 Mtetra
.85955 .54423 .86384 .54984 .87449 .54677 .87022 .54114 Mtetra
.87022 .54114 .87449 .54677 .88517 .5437 .88093 .53804 Mtetra
.88093 .53804 .88517 .5437 .8959 .54061 .89169 .53493 Mtetra
.89169 .53493 .8959 .54061 .90666 .53751 .90248 .53181 Mtetra
.90248 .53181 .90666 .53751 .91746 .5344 .91331 .52868 Mtetra
.91331 .52868 .91746 .5344 .92831 .53128 .92418 .52554 Mtetra
.92418 .52554 .92831 .53128 .93919 .52815 .93509 .52239 Mtetra
.93509 .52239 .93919 .52815 .95011 .525 .94605 .51922 Mtetra
.94605 .51922 .95011 .525 .96107 .52185 .95704 .51604 Mtetra
.95704 .51604 .96107 .52185 .97208 .51868 .96807 .51286 Mtetra
.535 .686 .936 r
.37467 .67947 .3801 .68489 .38491 .7907 .38359 .67924 Mtetra
.599 .404 .589 r
.38359 .67924 .38491 .7907 .39825 .67673 .39289 .6701 Mtetra
.55 .648 .899 r
.39289 .6701 .39825 .67673 .40727 .67515 .40187 .66997 Mtetra
.629 .73 .92 r
.40187 .66997 .40727 .67515 .41634 .673 .41096 .66796 Mtetra
.639 .739 .921 r
.41096 .66796 .41634 .673 .42545 .67075 .42009 .66572 Mtetra
.639 .74 .921 r
.42009 .66572 .42545 .67075 .43459 .66859 .42925 .66346 Mtetra
.627 .733 .924 r
.42925 .66346 .43459 .66859 .44374 .66714 .43843 .66147 Mtetra
.445 .64 .94 r
.43843 .66147 .44374 .66714 .45322 .6519 .44759 .66257 Mtetra
0 0 .001 r
.44759 .66257 .45322 .6519 .46227 .65852 .45701 .65247 Mtetra
.59 .687 .909 r
.45701 .65247 .46227 .65852 .47153 .65656 .46627 .65138 Mtetra
.639 .737 .919 r
.46627 .65138 .47153 .65656 .48084 .65413 .47559 .64909 Mtetra
.649 .746 .92 r
.47559 .64909 .48084 .65413 .49017 .65156 .48495 .64656 Mtetra
.653 .749 .92 r
.48495 .64656 .49017 .65156 .49954 .6489 .49434 .64391 Mtetra
.656 .751 .92 r
.49434 .64391 .49954 .6489 .50895 .64618 .50376 .6412 Mtetra
.657 .753 .92 r
.50376 .6412 .50895 .64618 .51838 .64343 .51322 .63844 Mtetra
.658 .753 .92 r
.51322 .63844 .51838 .64343 .52785 .64064 .52271 .63564 Mtetra
.659 .754 .92 r
.52271 .63564 .52785 .64064 .53735 .63784 .53223 .63283 Mtetra
.53223 .63283 .53735 .63784 .54688 .63503 .54178 .63 Mtetra
.54178 .63 .54688 .63503 .55645 .63222 .55137 .62717 Mtetra
.55137 .62717 .55645 .63222 .56604 .6294 .56099 .62433 Mtetra
.658 .753 .92 r
.56099 .62433 .56604 .6294 .57567 .62658 .57064 .62149 Mtetra
.57064 .62149 .57567 .62658 .58534 .62376 .58033 .61864 Mtetra
.58033 .61864 .58534 .62376 .59503 .62093 .59005 .6158 Mtetra
.59005 .6158 .59503 .62093 .60477 .61809 .5998 .61294 Mtetra
.5998 .61294 .60477 .61809 .61453 .61525 .60959 .61008 Mtetra
.60959 .61008 .61453 .61525 .62433 .6124 .61941 .6072 Mtetra
.657 .753 .92 r
.61941 .6072 .62433 .6124 .63416 .60954 .62927 .60433 Mtetra
.62927 .60433 .63416 .60954 .64403 .60667 .63916 .60144 Mtetra
.63916 .60144 .64403 .60667 .65393 .60379 .64909 .59854 Mtetra
.64909 .59854 .65393 .60379 .66387 .60091 .65905 .59564 Mtetra
.657 .752 .92 r
.65905 .59564 .66387 .60091 .67384 .59801 .66904 .59272 Mtetra
.66904 .59272 .67384 .59801 .68385 .59511 .67908 .5898 Mtetra
.67908 .5898 .68385 .59511 .69389 .59219 .68914 .58687 Mtetra
.68914 .58687 .69389 .59219 .70397 .58927 .69925 .58392 Mtetra
.69925 .58392 .70397 .58927 .71408 .58634 .70939 .58097 Mtetra
.70939 .58097 .71408 .58634 .72423 .5834 .71956 .57801 Mtetra
.71956 .57801 .72423 .5834 .73442 .58044 .72977 .57504 Mtetra
.72977 .57504 .73442 .58044 .74464 .57748 .74002 .57206 Mtetra
.74002 .57206 .74464 .57748 .7549 .57451 .75031 .56907 Mtetra
.75031 .56907 .7549 .57451 .7652 .57153 .76063 .56606 Mtetra
.76063 .56606 .7652 .57153 .77553 .56854 .77099 .56305 Mtetra
.77099 .56305 .77553 .56854 .7859 .56554 .78138 .56003 Mtetra
.78138 .56003 .7859 .56554 .79631 .56252 .79182 .557 Mtetra
.79182 .557 .79631 .56252 .80675 .5595 .80229 .55395 Mtetra
.80229 .55395 .80675 .5595 .81723 .55647 .8128 .5509 Mtetra
.8128 .5509 .81723 .55647 .82776 .55342 .82335 .54784 Mtetra
.82335 .54784 .82776 .55342 .83831 .55037 .83393 .54476 Mtetra
.83393 .54476 .83831 .55037 .84891 .5473 .84456 .54167 Mtetra
.84456 .54167 .84891 .5473 .85955 .54423 .85522 .53858 Mtetra
.85522 .53858 .85955 .54423 .87022 .54114 .86592 .53547 Mtetra
.86592 .53547 .87022 .54114 .88093 .53804 .87666 .53235 Mtetra
.87666 .53235 .88093 .53804 .89169 .53493 .88745 .52922 Mtetra
.88745 .52922 .89169 .53493 .90248 .53181 .89827 .52608 Mtetra
.89827 .52608 .90248 .53181 .91331 .52868 .90913 .52293 Mtetra
.90913 .52293 .91331 .52868 .92418 .52554 .92003 .51976 Mtetra
.92003 .51976 .92418 .52554 .93509 .52239 .93097 .51659 Mtetra
.93097 .51659 .93509 .52239 .94605 .51922 .94195 .5134 Mtetra
.94195 .5134 .94605 .51922 .95704 .51604 .95297 .5102 Mtetra
.95297 .5102 .95704 .51604 .96807 .51286 .96404 .50699 Mtetra
.607 .722 .926 r
.36919 .67426 .37467 .67947 .38359 .67924 .37818 .67272 Mtetra
.947 .665 .472 r
.37818 .67272 .38359 .67924 .39289 .6701 .38296 .779 Mtetra
0 0 .259 r
.38296 .779 .39289 .6701 .40187 .66997 .39646 .66447 Mtetra
.612 .713 .917 r
.39646 .66447 .40187 .66997 .41096 .66796 .40555 .66285 Mtetra
.636 .736 .92 r
.40555 .66285 .41096 .66796 .42009 .66572 .41469 .66066 Mtetra
.64 .74 .921 r
.41469 .66066 .42009 .66572 .42925 .66346 .42387 .65837 Mtetra
.636 .738 .922 r
.42387 .65837 .42925 .66346 .43843 .66147 .43308 .65617 Mtetra
.602 .72 .928 r
.43308 .65617 .43843 .66147 .44759 .66257 .44231 .65468 Mtetra
.833 .707 .725 r
.44231 .65468 .44759 .66257 .45701 .65247 .45187 .63934 Mtetra
.336 .388 .767 r
.45187 .63934 .45701 .65247 .46627 .65138 .46098 .64596 Mtetra
.627 .725 .918 r
.46098 .64596 .46627 .65138 .47559 .64909 .47032 .64396 Mtetra
.646 .743 .92 r
.47032 .64396 .47559 .64909 .48495 .64656 .47969 .6415 Mtetra
.652 .748 .92 r
.47969 .6415 .48495 .64656 .49434 .64391 .4891 .63888 Mtetra
.655 .75 .92 r
.4891 .63888 .49434 .64391 .50376 .6412 .49855 .63618 Mtetra
.657 .752 .92 r
.49855 .63618 .50376 .6412 .51322 .63844 .50802 .63342 Mtetra
.658 .753 .92 r
.50802 .63342 .51322 .63844 .52271 .63564 .51753 .63061 Mtetra
.659 .754 .92 r
.51753 .63061 .52271 .63564 .53223 .63283 .52708 .62778 Mtetra
.52708 .62778 .53223 .63283 .54178 .63 .53665 .62494 Mtetra
.53665 .62494 .54178 .63 .55137 .62717 .54626 .62208 Mtetra
.54626 .62208 .55137 .62717 .56099 .62433 .5559 .61922 Mtetra
.658 .753 .92 r
.5559 .61922 .56099 .62433 .57064 .62149 .56558 .61636 Mtetra
.56558 .61636 .57064 .62149 .58033 .61864 .57529 .6135 Mtetra
.57529 .6135 .58033 .61864 .59005 .6158 .58503 .61063 Mtetra
.58503 .61063 .59005 .6158 .5998 .61294 .59481 .60775 Mtetra
.59481 .60775 .5998 .61294 .60959 .61008 .60462 .60487 Mtetra
.60462 .60487 .60959 .61008 .61941 .6072 .61446 .60198 Mtetra
.657 .753 .92 r
.61446 .60198 .61941 .6072 .62927 .60433 .62434 .59908 Mtetra
.62434 .59908 .62927 .60433 .63916 .60144 .63426 .59617 Mtetra
.63426 .59617 .63916 .60144 .64909 .59854 .64421 .59326 Mtetra
.64421 .59326 .64909 .59854 .65905 .59564 .6542 .59033 Mtetra
.657 .752 .92 r
.6542 .59033 .65905 .59564 .66904 .59272 .66422 .5874 Mtetra
.66422 .5874 .66904 .59272 .67908 .5898 .67427 .58446 Mtetra
.67427 .58446 .67908 .5898 .68914 .58687 .68436 .5815 Mtetra
.68436 .5815 .68914 .58687 .69925 .58392 .69449 .57854 Mtetra
.69449 .57854 .69925 .58392 .70939 .58097 .70466 .57557 Mtetra
.70466 .57557 .70939 .58097 .71956 .57801 .71486 .57259 Mtetra
.71486 .57259 .71956 .57801 .72977 .57504 .72509 .5696 Mtetra
.72509 .5696 .72977 .57504 .74002 .57206 .73537 .5666 Mtetra
.73537 .5666 .74002 .57206 .75031 .56907 .74568 .56358 Mtetra
.74568 .56358 .75031 .56907 .76063 .56606 .75603 .56056 Mtetra
.75603 .56056 .76063 .56606 .77099 .56305 .76641 .55753 Mtetra
.76641 .55753 .77099 .56305 .78138 .56003 .77683 .55449 Mtetra
.77683 .55449 .78138 .56003 .79182 .557 .78729 .55143 Mtetra
.78729 .55143 .79182 .557 .80229 .55395 .79779 .54837 Mtetra
.79779 .54837 .80229 .55395 .8128 .5509 .80833 .5453 Mtetra
.80833 .5453 .8128 .5509 .82335 .54784 .81891 .54221 Mtetra
.81891 .54221 .82335 .54784 .83393 .54476 .82952 .53911 Mtetra
.82952 .53911 .83393 .54476 .84456 .54167 .84017 .53601 Mtetra
.84017 .53601 .84456 .54167 .85522 .53858 .85086 .53289 Mtetra
.85086 .53289 .85522 .53858 .86592 .53547 .86159 .52976 Mtetra
.86159 .52976 .86592 .53547 .87666 .53235 .87237 .52662 Mtetra
.87237 .52662 .87666 .53235 .88745 .52922 .88318 .52347 Mtetra
.88318 .52347 .88745 .52922 .89827 .52608 .89403 .5203 Mtetra
.89403 .5203 .89827 .52608 .90913 .52293 .90492 .51713 Mtetra
.90492 .51713 .90913 .52293 .92003 .51976 .91585 .51394 Mtetra
.91585 .51394 .92003 .51976 .93097 .51659 .92682 .51075 Mtetra
.92682 .51075 .93097 .51659 .94195 .5134 .93783 .50754 Mtetra
.93783 .50754 .94195 .5134 .95297 .5102 .94888 .50432 Mtetra
.94888 .50432 .95297 .5102 .96404 .50699 .95998 .50109 Mtetra
.623 .73 .923 r
.36367 .66911 .36919 .67426 .37818 .67272 .3727 .66722 Mtetra
.535 .686 .936 r
.3727 .66722 .37818 .67272 .38296 .779 .38168 .66696 Mtetra
.598 .402 .587 r
.38168 .66696 .38296 .779 .39646 .66447 .39106 .65775 Mtetra
.549 .648 .899 r
.39106 .65775 .39646 .66447 .40555 .66285 .40011 .65759 Mtetra
.629 .73 .92 r
.40011 .65759 .40555 .66285 .41469 .66066 .40927 .65555 Mtetra
.639 .739 .921 r
.40927 .65555 .41469 .66066 .42387 .65837 .41846 .65326 Mtetra
.639 .74 .921 r
.41846 .65326 .42387 .65837 .43308 .65617 .42769 .65097 Mtetra
.627 .733 .924 r
.42769 .65097 .43308 .65617 .44231 .65468 .43695 .64893 Mtetra
.445 .64 .94 r
.43695 .64893 .44231 .65468 .45187 .63934 .44617 .65001 Mtetra
0 0 0 r
.44617 .65001 .45187 .63934 .46098 .64596 .45567 .63983 Mtetra
.59 .687 .909 r
.45567 .63983 .46098 .64596 .47032 .64396 .46501 .6387 Mtetra
.639 .737 .919 r
.46501 .6387 .47032 .64396 .47969 .6415 .4744 .63637 Mtetra
.649 .746 .92 r
.4744 .63637 .47969 .6415 .4891 .63888 .48383 .6338 Mtetra
.653 .749 .92 r
.48383 .6338 .4891 .63888 .49855 .63618 .4933 .63111 Mtetra
.656 .751 .92 r
.4933 .63111 .49855 .63618 .50802 .63342 .50279 .62835 Mtetra
.657 .753 .92 r
.50279 .62835 .50802 .63342 .51753 .63061 .51233 .62554 Mtetra
.658 .753 .92 r
.51233 .62554 .51753 .63061 .52708 .62778 .52189 .6227 Mtetra
.659 .754 .92 r
.52189 .6227 .52708 .62778 .53665 .62494 .53149 .61984 Mtetra
.53149 .61984 .53665 .62494 .54626 .62208 .54112 .61697 Mtetra
.54112 .61697 .54626 .62208 .5559 .61922 .55078 .61409 Mtetra
.55078 .61409 .5559 .61922 .56558 .61636 .56048 .61121 Mtetra
.658 .753 .92 r
.56048 .61121 .56558 .61636 .57529 .6135 .57021 .60832 Mtetra
.57021 .60832 .57529 .6135 .58503 .61063 .57998 .60543 Mtetra
.57998 .60543 .58503 .61063 .59481 .60775 .58978 .60253 Mtetra
.58978 .60253 .59481 .60775 .60462 .60487 .59961 .59963 Mtetra
.59961 .59963 .60462 .60487 .61446 .60198 .60948 .59672 Mtetra
.60948 .59672 .61446 .60198 .62434 .59908 .61939 .5938 Mtetra
.657 .753 .92 r
.61939 .5938 .62434 .59908 .63426 .59617 .62933 .59087 Mtetra
.62933 .59087 .63426 .59617 .64421 .59326 .6393 .58794 Mtetra
.6393 .58794 .64421 .59326 .6542 .59033 .64931 .58499 Mtetra
.64931 .58499 .6542 .59033 .66422 .5874 .65935 .58204 Mtetra
.657 .752 .92 r
.65935 .58204 .66422 .5874 .67427 .58446 .66944 .57908 Mtetra
.66944 .57908 .67427 .58446 .68436 .5815 .67955 .57611 Mtetra
.67955 .57611 .68436 .5815 .69449 .57854 .68971 .57312 Mtetra
.68971 .57312 .69449 .57854 .70466 .57557 .69989 .57013 Mtetra
.69989 .57013 .70466 .57557 .71486 .57259 .71012 .56713 Mtetra
.71012 .56713 .71486 .57259 .72509 .5696 .72038 .56412 Mtetra
.72038 .56412 .72509 .5696 .73537 .5666 .73068 .5611 Mtetra
.73068 .5611 .73537 .5666 .74568 .56358 .74102 .55806 Mtetra
.74102 .55806 .74568 .56358 .75603 .56056 .75139 .55502 Mtetra
.75139 .55502 .75603 .56056 .76641 .55753 .76181 .55197 Mtetra
.76181 .55197 .76641 .55753 .77683 .55449 .77226 .54891 Mtetra
.77226 .54891 .77683 .55449 .78729 .55143 .78274 .54583 Mtetra
.78274 .54583 .78729 .55143 .79779 .54837 .79327 .54275 Mtetra
.79327 .54275 .79779 .54837 .80833 .5453 .80383 .53965 Mtetra
.80383 .53965 .80833 .5453 .81891 .54221 .81444 .53655 Mtetra
.81444 .53655 .81891 .54221 .82952 .53911 .82508 .53343 Mtetra
.82508 .53343 .82952 .53911 .84017 .53601 .83576 .5303 Mtetra
.83576 .5303 .84017 .53601 .85086 .53289 .84648 .52716 Mtetra
.84648 .52716 .85086 .53289 .86159 .52976 .85724 .52401 Mtetra
.85724 .52401 .86159 .52976 .87237 .52662 .86804 .52085 Mtetra
.86804 .52085 .87237 .52662 .88318 .52347 .87888 .51768 Mtetra
.87888 .51768 .88318 .52347 .89403 .5203 .88976 .51449 Mtetra
.88976 .51449 .89403 .5203 .90492 .51713 .90068 .5113 Mtetra
.90068 .5113 .90492 .51713 .91585 .51394 .91164 .50809 Mtetra
.91164 .50809 .91585 .51394 .92682 .51075 .92264 .50487 Mtetra
.92264 .50487 .92682 .51075 .93783 .50754 .93368 .50164 Mtetra
.93368 .50164 .93783 .50754 .94888 .50432 .94476 .49839 Mtetra
.94476 .49839 .94888 .50432 .95998 .50109 .95589 .49514 Mtetra
.627 .731 .922 r
.35812 .66392 .36367 .66911 .3727 .66722 .36717 .66194 Mtetra
.607 .722 .926 r
.36717 .66194 .3727 .66722 .38168 .66696 .37623 .66036 Mtetra
.948 .665 .469 r
.37623 .66036 .38168 .66696 .39106 .65775 .38098 .76711 Mtetra
0 0 .253 r
.38098 .76711 .39106 .65775 .40011 .65759 .39465 .65201 Mtetra
.612 .713 .917 r
.39465 .65201 .40011 .65759 .40927 .65555 .40381 .65035 Mtetra
.636 .736 .92 r
.40381 .65035 .40927 .65555 .41846 .65326 .41302 .64812 Mtetra
.64 .74 .921 r
.41302 .64812 .41846 .65326 .42769 .65097 .42227 .64579 Mtetra
.636 .738 .922 r
.42227 .64579 .42769 .65097 .43695 .64893 .43155 .64355 Mtetra
.602 .72 .927 r
.43155 .64355 .43695 .64893 .44617 .65001 .44085 .64203 Mtetra
.834 .708 .725 r
.44085 .64203 .44617 .65001 .45567 .63983 .45049 .62659 Mtetra
.335 .387 .767 r
.45049 .62659 .45567 .63983 .46501 .6387 .45967 .6332 Mtetra
.627 .725 .918 r
.45967 .6332 .46501 .6387 .4744 .63637 .46908 .63116 Mtetra
.646 .743 .92 r
.46908 .63116 .4744 .63637 .48383 .6338 .47853 .62865 Mtetra
.652 .748 .92 r
.47853 .62865 .48383 .6338 .4933 .63111 .48801 .62599 Mtetra
.655 .75 .92 r
.48801 .62599 .4933 .63111 .50279 .62835 .49753 .62324 Mtetra
.657 .752 .92 r
.49753 .62324 .50279 .62835 .51233 .62554 .50709 .62044 Mtetra
.658 .753 .92 r
.50709 .62044 .51233 .62554 .52189 .6227 .51667 .61759 Mtetra
.659 .754 .92 r
.51667 .61759 .52189 .6227 .53149 .61984 .52629 .61471 Mtetra
.52629 .61471 .53149 .61984 .54112 .61697 .53595 .61182 Mtetra
.53595 .61182 .54112 .61697 .55078 .61409 .54563 .60892 Mtetra
.54563 .60892 .55078 .61409 .56048 .61121 .55535 .60602 Mtetra
.658 .753 .92 r
.55535 .60602 .56048 .61121 .57021 .60832 .56511 .60311 Mtetra
.56511 .60311 .57021 .60832 .57998 .60543 .5749 .6002 Mtetra
.5749 .6002 .57998 .60543 .58978 .60253 .58472 .59728 Mtetra
.58472 .59728 .58978 .60253 .59961 .59963 .59458 .59436 Mtetra
.59458 .59436 .59961 .59963 .60948 .59672 .60447 .59143 Mtetra
.60447 .59143 .60948 .59672 .61939 .5938 .6144 .58849 Mtetra
.657 .753 .92 r
.6144 .58849 .61939 .5938 .62933 .59087 .62436 .58554 Mtetra
.62436 .58554 .62933 .59087 .6393 .58794 .63436 .58259 Mtetra
.63436 .58259 .6393 .58794 .64931 .58499 .64439 .57962 Mtetra
.64439 .57962 .64931 .58499 .65935 .58204 .65446 .57665 Mtetra
.657 .752 .92 r
.65446 .57665 .65935 .58204 .66944 .57908 .66457 .57366 Mtetra
.66457 .57366 .66944 .57908 .67955 .57611 .67471 .57067 Mtetra
.67471 .57067 .67955 .57611 .68971 .57312 .68489 .56767 Mtetra
.68489 .56767 .68971 .57312 .69989 .57013 .6951 .56466 Mtetra
.6951 .56466 .69989 .57013 .71012 .56713 .70535 .56164 Mtetra
.70535 .56164 .71012 .56713 .72038 .56412 .71564 .5586 Mtetra
.71564 .5586 .72038 .56412 .73068 .5611 .72597 .55556 Mtetra
.72597 .55556 .73068 .5611 .74102 .55806 .73633 .55251 Mtetra
.73633 .55251 .74102 .55806 .75139 .55502 .74673 .54945 Mtetra
.74673 .54945 .75139 .55502 .76181 .55197 .75717 .54637 Mtetra
.75717 .54637 .76181 .55197 .77226 .54891 .76765 .54329 Mtetra
.76765 .54329 .77226 .54891 .78274 .54583 .77816 .54019 Mtetra
.77816 .54019 .78274 .54583 .79327 .54275 .78871 .53709 Mtetra
.78871 .53709 .79327 .54275 .80383 .53965 .7993 .53397 Mtetra
.7993 .53397 .80383 .53965 .81444 .53655 .80994 .53084 Mtetra
.80994 .53084 .81444 .53655 .82508 .53343 .82061 .52771 Mtetra
.82061 .52771 .82508 .53343 .83576 .5303 .83131 .52456 Mtetra
.83131 .52456 .83576 .5303 .84648 .52716 .84206 .5214 Mtetra
.84206 .5214 .84648 .52716 .85724 .52401 .85285 .51822 Mtetra
.85285 .51822 .85724 .52401 .86804 .52085 .86368 .51504 Mtetra
.86368 .51504 .86804 .52085 .87888 .51768 .87455 .51184 Mtetra
.87455 .51184 .87888 .51768 .88976 .51449 .88546 .50864 Mtetra
.88546 .50864 .88976 .51449 .90068 .5113 .89641 .50542 Mtetra
.89641 .50542 .90068 .5113 .91164 .50809 .9074 .50219 Mtetra
.9074 .50219 .91164 .50809 .92264 .50487 .91843 .49895 Mtetra
.91843 .49895 .92264 .50487 .93368 .50164 .9295 .49569 Mtetra
.9295 .49569 .93368 .50164 .94476 .49839 .94062 .49243 Mtetra
.94062 .49243 .94476 .49839 .95589 .49514 .95177 .48915 Mtetra
.623 .727 .921 r
.35254 .65862 .35812 .66392 .36717 .66194 .3616 .65671 Mtetra
.623 .73 .923 r
.3616 .65671 .36717 .66194 .37623 .66036 .37069 .65478 Mtetra
.535 .686 .936 r
.37069 .65478 .37623 .66036 .38098 .76711 .37975 .65449 Mtetra
.596 .4 .586 r
.37975 .65449 .38098 .76711 .39465 .65201 .3892 .64521 Mtetra
.549 .648 .899 r
.3892 .64521 .39465 .65201 .40381 .65035 .39832 .64501 Mtetra
.629 .73 .92 r
.39832 .64501 .40381 .65035 .41302 .64812 .40754 .64293 Mtetra
.639 .739 .921 r
.40754 .64293 .41302 .64812 .42227 .64579 .41681 .6406 Mtetra
.639 .74 .921 r
.41681 .6406 .42227 .64579 .43155 .64355 .42611 .63827 Mtetra
.627 .733 .924 r
.42611 .63827 .43155 .64355 .44085 .64203 .43544 .63619 Mtetra
.446 .64 .94 r
.43544 .63619 .44085 .64203 .45049 .62659 .44474 .63724 Mtetra
0 0 0 r
.44474 .63724 .45049 .62659 .45967 .6332 .45431 .62698 Mtetra
.59 .687 .909 r
.45431 .62698 .45967 .6332 .46908 .63116 .46372 .62582 Mtetra
.639 .737 .919 r
.46372 .62582 .46908 .63116 .47853 .62865 .47319 .62344 Mtetra
.649 .746 .92 r
.47319 .62344 .47853 .62865 .48801 .62599 .48269 .62082 Mtetra
.653 .749 .92 r
.48269 .62082 .48801 .62599 .49753 .62324 .49224 .61809 Mtetra
.656 .751 .92 r
.49224 .61809 .49753 .62324 .50709 .62044 .50181 .61529 Mtetra
.657 .753 .92 r
.50181 .61529 .50709 .62044 .51667 .61759 .51142 .61244 Mtetra
.658 .753 .92 r
.51142 .61244 .51667 .61759 .52629 .61471 .52106 .60955 Mtetra
.659 .754 .92 r
.52106 .60955 .52629 .61471 .53595 .61182 .53074 .60664 Mtetra
.53074 .60664 .53595 .61182 .54563 .60892 .54045 .60372 Mtetra
.54045 .60372 .54563 .60892 .55535 .60602 .55019 .6008 Mtetra
.55019 .6008 .55535 .60602 .56511 .60311 .55997 .59787 Mtetra
.658 .753 .92 r
.55997 .59787 .56511 .60311 .5749 .6002 .56978 .59493 Mtetra
.56978 .59493 .5749 .6002 .58472 .59728 .57963 .59199 Mtetra
.57963 .59199 .58472 .59728 .59458 .59436 .58951 .58905 Mtetra
.58951 .58905 .59458 .59436 .60447 .59143 .59942 .5861 Mtetra
.59942 .5861 .60447 .59143 .6144 .58849 .60937 .58314 Mtetra
.60937 .58314 .6144 .58849 .62436 .58554 .61936 .58017 Mtetra
.657 .753 .92 r
.61936 .58017 .62436 .58554 .63436 .58259 .62938 .5772 Mtetra
.62938 .5772 .63436 .58259 .64439 .57962 .63944 .57421 Mtetra
.63944 .57421 .64439 .57962 .65446 .57665 .64954 .57122 Mtetra
.64954 .57122 .65446 .57665 .66457 .57366 .65967 .56822 Mtetra
.657 .752 .92 r
.65967 .56822 .66457 .57366 .67471 .57067 .66983 .5652 Mtetra
.66983 .5652 .67471 .57067 .68489 .56767 .68004 .56218 Mtetra
.68004 .56218 .68489 .56767 .6951 .56466 .69028 .55915 Mtetra
.69028 .55915 .6951 .56466 .70535 .56164 .70055 .55611 Mtetra
.70055 .55611 .70535 .56164 .71564 .5586 .71087 .55305 Mtetra
.71087 .55305 .71564 .5586 .72597 .55556 .72122 .54999 Mtetra
.72122 .54999 .72597 .55556 .73633 .55251 .73161 .54692 Mtetra
.73161 .54692 .73633 .55251 .74673 .54945 .74204 .54383 Mtetra
.74204 .54383 .74673 .54945 .75717 .54637 .7525 .54074 Mtetra
.7525 .54074 .75717 .54637 .76765 .54329 .763 .53763 Mtetra
.763 .53763 .76765 .54329 .77816 .54019 .77355 .53452 Mtetra
.77355 .53452 .77816 .54019 .78871 .53709 .78413 .53139 Mtetra
.78413 .53139 .78871 .53709 .7993 .53397 .79475 .52825 Mtetra
.79475 .52825 .7993 .53397 .80994 .53084 .8054 .5251 Mtetra
.8054 .5251 .80994 .53084 .82061 .52771 .8161 .52194 Mtetra
.8161 .52194 .82061 .52771 .83131 .52456 .82684 .51877 Mtetra
.82684 .51877 .83131 .52456 .84206 .5214 .83762 .51559 Mtetra
.83762 .51559 .84206 .5214 .85285 .51822 .84843 .5124 Mtetra
.84843 .5124 .85285 .51822 .86368 .51504 .85929 .50919 Mtetra
.85929 .50919 .86368 .51504 .87455 .51184 .87019 .50597 Mtetra
.87019 .50597 .87455 .51184 .88546 .50864 .88113 .50274 Mtetra
.88113 .50274 .88546 .50864 .89641 .50542 .89211 .4995 Mtetra
.89211 .4995 .89641 .50542 .9074 .50219 .90313 .49625 Mtetra
.90313 .49625 .9074 .50219 .91843 .49895 .91419 .49299 Mtetra
.91419 .49299 .91843 .49895 .9295 .49569 .92529 .48971 Mtetra
.92529 .48971 .9295 .49569 .94062 .49243 .93644 .48642 Mtetra
.93644 .48642 .94062 .49243 .95177 .48915 .94763 .48312 Mtetra
.61 .714 .919 r
.34694 .65306 .35254 .65862 .3616 .65671 .356 .65144 Mtetra
.627 .731 .922 r
.356 .65144 .3616 .65671 .37069 .65478 .36511 .64942 Mtetra
.607 .722 .926 r
.36511 .64942 .37069 .65478 .37975 .65449 .37424 .6478 Mtetra
.949 .665 .467 r
.37424 .6478 .37975 .65449 .3892 .64521 .37896 .75502 Mtetra
0 0 .247 r
.37896 .75502 .3892 .64521 .39832 .64501 .39281 .63935 Mtetra
.612 .713 .917 r
.39281 .63935 .39832 .64501 .40754 .64293 .40203 .63766 Mtetra
.636 .736 .92 r
.40203 .63766 .40754 .64293 .41681 .6406 .41132 .63538 Mtetra
.64 .74 .921 r
.41132 .63538 .41681 .6406 .42611 .63827 .42064 .63301 Mtetra
.636 .738 .922 r
.42064 .63301 .42611 .63827 .43544 .63619 .42999 .63072 Mtetra
.602 .72 .927 r
.42999 .63072 .43544 .63619 .44474 .63724 .43937 .62916 Mtetra
.835 .709 .725 r
.43937 .62916 .44474 .63724 .45431 .62698 .44908 .61362 Mtetra
.333 .386 .767 r
.44908 .61362 .45431 .62698 .46372 .62582 .45834 .62023 Mtetra
.627 .725 .918 r
.45834 .62023 .46372 .62582 .47319 .62344 .46782 .61815 Mtetra
.646 .743 .92 r
.46782 .61815 .47319 .62344 .48269 .62082 .47734 .6156 Mtetra
.652 .748 .92 r
.47734 .6156 .48269 .62082 .49224 .61809 .4869 .61289 Mtetra
.655 .75 .92 r
.4869 .61289 .49224 .61809 .50181 .61529 .4965 .6101 Mtetra
.657 .752 .92 r
.4965 .6101 .50181 .61529 .51142 .61244 .50613 .60725 Mtetra
.658 .753 .92 r
.50613 .60725 .51142 .61244 .52106 .60955 .5158 .60435 Mtetra
.659 .754 .92 r
.5158 .60435 .52106 .60955 .53074 .60664 .52549 .60143 Mtetra
.52549 .60143 .53074 .60664 .54045 .60372 .53523 .59849 Mtetra
.53523 .59849 .54045 .60372 .55019 .6008 .54499 .59554 Mtetra
.54499 .59554 .55019 .6008 .55997 .59787 .55479 .59259 Mtetra
.658 .753 .92 r
.55479 .59259 .55997 .59787 .56978 .59493 .56463 .58963 Mtetra
.56463 .58963 .56978 .59493 .57963 .59199 .5745 .58667 Mtetra
.5745 .58667 .57963 .59199 .58951 .58905 .5844 .58371 Mtetra
.5844 .58371 .58951 .58905 .59942 .5861 .59434 .58074 Mtetra
.59434 .58074 .59942 .5861 .60937 .58314 .60432 .57776 Mtetra
.60432 .57776 .60937 .58314 .61936 .58017 .61433 .57477 Mtetra
.657 .753 .92 r
.61433 .57477 .61936 .58017 .62938 .5772 .62437 .57177 Mtetra
.62437 .57177 .62938 .5772 .63944 .57421 .63446 .56877 Mtetra
.63446 .56877 .63944 .57421 .64954 .57122 .64458 .56575 Mtetra
.64458 .56575 .64954 .57122 .65967 .56822 .65473 .56273 Mtetra
.657 .752 .92 r
.65473 .56273 .65967 .56822 .66983 .5652 .66492 .5597 Mtetra
.66492 .5597 .66983 .5652 .68004 .56218 .67515 .55665 Mtetra
.67515 .55665 .68004 .56218 .69028 .55915 .68542 .5536 Mtetra
.68542 .5536 .69028 .55915 .70055 .55611 .69572 .55054 Mtetra
.69572 .55054 .70055 .55611 .71087 .55305 .70606 .54746 Mtetra
.70606 .54746 .71087 .55305 .72122 .54999 .71644 .54438 Mtetra
.71644 .54438 .72122 .54999 .73161 .54692 .72685 .54129 Mtetra
.72685 .54129 .73161 .54692 .74204 .54383 .73731 .53818 Mtetra
.73731 .53818 .74204 .54383 .7525 .54074 .7478 .53507 Mtetra
.7478 .53507 .7525 .54074 .763 .53763 .75833 .53194 Mtetra
.75833 .53194 .763 .53763 .77355 .53452 .7689 .5288 Mtetra
.7689 .5288 .77355 .53452 .78413 .53139 .77951 .52565 Mtetra
.77951 .52565 .78413 .53139 .79475 .52825 .79016 .52249 Mtetra
.79016 .52249 .79475 .52825 .8054 .5251 .80084 .51932 Mtetra
.80084 .51932 .8054 .5251 .8161 .52194 .81157 .51614 Mtetra
.81157 .51614 .8161 .52194 .82684 .51877 .82233 .51295 Mtetra
.82233 .51295 .82684 .51877 .83762 .51559 .83314 .50974 Mtetra
.83314 .50974 .83762 .51559 .84843 .5124 .84399 .50653 Mtetra
.84399 .50653 .84843 .5124 .85929 .50919 .85487 .5033 Mtetra
.85487 .5033 .85929 .50919 .87019 .50597 .8658 .50006 Mtetra
.8658 .50006 .87019 .50597 .88113 .50274 .87677 .49681 Mtetra
.87677 .49681 .88113 .50274 .89211 .4995 .88778 .49355 Mtetra
.88778 .49355 .89211 .4995 .90313 .49625 .89883 .49027 Mtetra
.89883 .49027 .90313 .49625 .91419 .49299 .90992 .48698 Mtetra
.90992 .48698 .91419 .49299 .92529 .48971 .92106 .48369 Mtetra
.92106 .48369 .92529 .48971 .93644 .48642 .93223 .48037 Mtetra
.93223 .48037 .93644 .48642 .94763 .48312 .94345 .47705 Mtetra
.56 .664 .907 r
.34136 .64657 .34694 .65306 .356 .65144 .35037 .64606 Mtetra
.623 .727 .921 r
.35037 .64606 .356 .65144 .36511 .64942 .35949 .6441 Mtetra
.623 .73 .923 r
.35949 .6441 .36511 .64942 .37424 .6478 .36865 .64214 Mtetra
.535 .686 .936 r
.36865 .64214 .37424 .6478 .37896 .75502 .37778 .64181 Mtetra
.595 .398 .584 r
.37778 .64181 .37896 .75502 .39281 .63935 .38731 .63246 Mtetra
.549 .648 .9 r
.38731 .63246 .39281 .63935 .40203 .63766 .39649 .63223 Mtetra
.629 .73 .92 r
.39649 .63223 .40203 .63766 .41132 .63538 .40579 .63011 Mtetra
.639 .739 .921 r
.40579 .63011 .41132 .63538 .42064 .63301 .41513 .62774 Mtetra
.639 .74 .921 r
.41513 .62774 .42064 .63301 .42999 .63072 .42451 .62536 Mtetra
.627 .733 .923 r
.42451 .62536 .42999 .63072 .43937 .62916 .43391 .62324 Mtetra
.447 .641 .939 r
.43391 .62324 .43937 .62916 .44908 .61362 .44328 .62426 Mtetra
0 0 0 r
.44328 .62426 .44908 .61362 .45834 .62023 .45293 .61393 Mtetra
.59 .687 .909 r
.45293 .61393 .45834 .62023 .46782 .61815 .46241 .61272 Mtetra
.639 .737 .919 r
.46241 .61272 .46782 .61815 .47734 .6156 .47196 .61031 Mtetra
.649 .746 .92 r
.47196 .61031 .47734 .6156 .4869 .61289 .48154 .60764 Mtetra
.653 .749 .92 r
.48154 .60764 .4869 .61289 .4965 .6101 .49116 .60486 Mtetra
.656 .751 .92 r
.49116 .60486 .4965 .6101 .50613 .60725 .50081 .60201 Mtetra
.657 .753 .92 r
.50081 .60201 .50613 .60725 .5158 .60435 .5105 .59911 Mtetra
.658 .753 .92 r
.5105 .59911 .5158 .60435 .52549 .60143 .52022 .59618 Mtetra
.659 .754 .92 r
.52022 .59618 .52549 .60143 .53523 .59849 .52997 .59322 Mtetra
.52997 .59322 .53523 .59849 .54499 .59554 .53976 .59025 Mtetra
.53976 .59025 .54499 .59554 .55479 .59259 .54958 .58728 Mtetra
.54958 .58728 .55479 .59259 .56463 .58963 .55944 .5843 Mtetra
.658 .753 .92 r
.55944 .5843 .56463 .58963 .5745 .58667 .56934 .58132 Mtetra
.56934 .58132 .5745 .58667 .5844 .58371 .57926 .57833 Mtetra
.57926 .57833 .5844 .58371 .59434 .58074 .58923 .57534 Mtetra
.58923 .57534 .59434 .58074 .60432 .57776 .59923 .57234 Mtetra
.59923 .57234 .60432 .57776 .61433 .57477 .60926 .56933 Mtetra
.60926 .56933 .61433 .57477 .62437 .57177 .61933 .56631 Mtetra
.657 .753 .92 r
.61933 .56631 .62437 .57177 .63446 .56877 .62944 .56329 Mtetra
.62944 .56329 .63446 .56877 .64458 .56575 .63958 .56025 Mtetra
.63958 .56025 .64458 .56575 .65473 .56273 .64976 .55721 Mtetra
.64976 .55721 .65473 .56273 .66492 .5597 .65998 .55415 Mtetra
.657 .752 .92 r
.65998 .55415 .66492 .5597 .67515 .55665 .67024 .55109 Mtetra
.67024 .55109 .67515 .55665 .68542 .5536 .68053 .54802 Mtetra
.68053 .54802 .68542 .5536 .69572 .55054 .69086 .54493 Mtetra
.69086 .54493 .69572 .55054 .70606 .54746 .70122 .54184 Mtetra
.70122 .54184 .70606 .54746 .71644 .54438 .71163 .53873 Mtetra
.71163 .53873 .71644 .54438 .72685 .54129 .72207 .53562 Mtetra
.72207 .53562 .72685 .54129 .73731 .53818 .73255 .53249 Mtetra
.73255 .53249 .73731 .53818 .7478 .53507 .74307 .52935 Mtetra
.74307 .52935 .7478 .53507 .75833 .53194 .75363 .52621 Mtetra
.75363 .52621 .75833 .53194 .7689 .5288 .76422 .52305 Mtetra
.76422 .52305 .7689 .5288 .77951 .52565 .77486 .51988 Mtetra
.77486 .51988 .77951 .52565 .79016 .52249 .78553 .5167 Mtetra
.78553 .5167 .79016 .52249 .80084 .51932 .79625 .5135 Mtetra
.79625 .5135 .80084 .51932 .81157 .51614 .807 .5103 Mtetra
.807 .5103 .81157 .51614 .82233 .51295 .8178 .50708 Mtetra
.8178 .50708 .82233 .51295 .83314 .50974 .82863 .50386 Mtetra
.82863 .50386 .83314 .50974 .84399 .50653 .83951 .50062 Mtetra
.83951 .50062 .84399 .50653 .85487 .5033 .85042 .49737 Mtetra
.85042 .49737 .85487 .5033 .8658 .50006 .86138 .49411 Mtetra
.86138 .49411 .8658 .50006 .87677 .49681 .87238 .49083 Mtetra
.87238 .49083 .87677 .49681 .88778 .49355 .88342 .48755 Mtetra
.88342 .48755 .88778 .49355 .89883 .49027 .8945 .48425 Mtetra
.8945 .48425 .89883 .49027 .90992 .48698 .90562 .48094 Mtetra
.90562 .48094 .90992 .48698 .92106 .48369 .91679 .47762 Mtetra
.91679 .47762 .92106 .48369 .93223 .48037 .928 .47428 Mtetra
.928 .47428 .93223 .48037 .94345 .47705 .93925 .47094 Mtetra
.048 .062 .551 r
.33697 .61745 .34136 .64657 .35037 .64606 .34472 .64042 Mtetra
.61 .714 .919 r
.34472 .64042 .35037 .64606 .35949 .6441 .35384 .63875 Mtetra
.627 .731 .922 r
.35384 .63875 .35949 .6441 .36865 .64214 .36302 .6367 Mtetra
.607 .722 .926 r
.36302 .6367 .36865 .64214 .37778 .64181 .37222 .63504 Mtetra
.949 .665 .464 r
.37222 .63504 .37778 .64181 .38731 .63246 .37692 .74272 Mtetra
0 0 .24 r
.37692 .74272 .38731 .63246 .39649 .63223 .39093 .62649 Mtetra
.612 .714 .917 r
.39093 .62649 .39649 .63223 .40579 .63011 .40023 .62475 Mtetra
.636 .736 .92 r
.40023 .62475 .40579 .63011 .41513 .62774 .40959 .62243 Mtetra
.64 .74 .921 r
.40959 .62243 .41513 .62774 .42451 .62536 .41899 .62002 Mtetra
.636 .738 .922 r
.41899 .62002 .42451 .62536 .43391 .62324 .42841 .61769 Mtetra
.602 .72 .927 r
.42841 .61769 .43391 .62324 .44328 .62426 .43786 .61609 Mtetra
.836 .71 .725 r
.43786 .61609 .44328 .62426 .45293 .61393 .44766 .60045 Mtetra
.331 .385 .767 r
.44766 .60045 .45293 .61393 .46241 .61272 .45698 .60705 Mtetra
.627 .725 .918 r
.45698 .60705 .46241 .61272 .47196 .61031 .46654 .60492 Mtetra
.646 .743 .92 r
.46654 .60492 .47196 .61031 .48154 .60764 .47614 .60233 Mtetra
.652 .748 .92 r
.47614 .60233 .48154 .60764 .49116 .60486 .48578 .59958 Mtetra
.655 .75 .92 r
.48578 .59958 .49116 .60486 .50081 .60201 .49545 .59673 Mtetra
.657 .752 .92 r
.49545 .59673 .50081 .60201 .5105 .59911 .50516 .59383 Mtetra
.658 .753 .92 r
.50516 .59383 .5105 .59911 .52022 .59618 .51491 .59089 Mtetra
.659 .754 .92 r
.51491 .59089 .52022 .59618 .52997 .59322 .52468 .58792 Mtetra
.52468 .58792 .52997 .59322 .53976 .59025 .53449 .58493 Mtetra
.53449 .58493 .53976 .59025 .54958 .58728 .54434 .58194 Mtetra
.54434 .58194 .54958 .58728 .55944 .5843 .55422 .57894 Mtetra
.658 .753 .92 r
.55422 .57894 .55944 .5843 .56934 .58132 .56414 .57593 Mtetra
.56414 .57593 .56934 .58132 .57926 .57833 .57409 .57292 Mtetra
.57409 .57292 .57926 .57833 .58923 .57534 .58408 .56991 Mtetra
.58408 .56991 .58923 .57534 .59923 .57234 .5941 .56688 Mtetra
.5941 .56688 .59923 .57234 .60926 .56933 .60416 .56386 Mtetra
.60416 .56386 .60926 .56933 .61933 .56631 .61426 .56082 Mtetra
.657 .753 .92 r
.61426 .56082 .61933 .56631 .62944 .56329 .62439 .55777 Mtetra
.62439 .55777 .62944 .56329 .63958 .56025 .63456 .55471 Mtetra
.63456 .55471 .63958 .56025 .64976 .55721 .64476 .55165 Mtetra
.64476 .55165 .64976 .55721 .65998 .55415 .65501 .54857 Mtetra
.657 .752 .92 r
.65501 .54857 .65998 .55415 .67024 .55109 .66529 .54549 Mtetra
.66529 .54549 .67024 .55109 .68053 .54802 .6756 .54239 Mtetra
.6756 .54239 .68053 .54802 .69086 .54493 .68596 .53929 Mtetra
.68596 .53929 .69086 .54493 .70122 .54184 .69635 .53617 Mtetra
.69635 .53617 .70122 .54184 .71163 .53873 .70678 .53305 Mtetra
.70678 .53305 .71163 .53873 .72207 .53562 .71725 .52991 Mtetra
.71725 .52991 .72207 .53562 .73255 .53249 .72776 .52676 Mtetra
.72776 .52676 .73255 .53249 .74307 .52935 .7383 .5236 Mtetra
.7383 .5236 .74307 .52935 .75363 .52621 .74889 .52043 Mtetra
.74889 .52043 .75363 .52621 .76422 .52305 .75951 .51725 Mtetra
.75951 .51725 .76422 .52305 .77486 .51988 .77018 .51406 Mtetra
.77018 .51406 .77486 .51988 .78553 .5167 .78088 .51086 Mtetra
.78088 .51086 .78553 .5167 .79625 .5135 .79162 .50764 Mtetra
.79162 .50764 .79625 .5135 .807 .5103 .80241 .50442 Mtetra
.80241 .50442 .807 .5103 .8178 .50708 .81323 .50118 Mtetra
.81323 .50118 .8178 .50708 .82863 .50386 .82409 .49793 Mtetra
.82409 .49793 .82863 .50386 .83951 .50062 .835 .49467 Mtetra
.835 .49467 .83951 .50062 .85042 .49737 .84594 .4914 Mtetra
.84594 .4914 .85042 .49737 .86138 .49411 .85693 .48811 Mtetra
.85693 .48811 .86138 .49411 .87238 .49083 .86796 .48482 Mtetra
.86796 .48482 .87238 .49083 .88342 .48755 .87903 .48151 Mtetra
.87903 .48151 .88342 .48755 .8945 .48425 .89014 .47819 Mtetra
.89014 .47819 .8945 .48425 .90562 .48094 .90129 .47485 Mtetra
.90129 .47485 .90562 .48094 .91679 .47762 .91249 .47151 Mtetra
.91249 .47151 .91679 .47762 .928 .47428 .92373 .46815 Mtetra
.92373 .46815 .928 .47428 .93925 .47094 .93501 .46478 Mtetra
.376 .101 .363 r
.32954 .64321 .33697 .61745 .34472 .64042 .33908 .63384 Mtetra
.56 .664 .907 r
.33908 .63384 .34472 .64042 .35384 .63875 .34816 .63329 Mtetra
.623 .727 .921 r
.34816 .63329 .35384 .63875 .36302 .6367 .35735 .6313 Mtetra
.623 .73 .923 r
.35735 .6313 .36302 .6367 .37222 .63504 .36658 .62929 Mtetra
.535 .686 .936 r
.36658 .62929 .37222 .63504 .37692 .74272 .37578 .62893 Mtetra
.593 .396 .583 r
.37578 .62893 .37692 .74272 .39093 .62649 .38539 .6195 Mtetra
.549 .648 .9 r
.38539 .6195 .39093 .62649 .40023 .62475 .39464 .61924 Mtetra
.629 .73 .92 r
.39464 .61924 .40023 .62475 .40959 .62243 .40401 .61708 Mtetra
.639 .739 .921 r
.40401 .61708 .40959 .62243 .41899 .62002 .41343 .61466 Mtetra
.639 .74 .921 r
.41343 .61466 .41899 .62002 .42841 .61769 .42288 .61224 Mtetra
.627 .733 .923 r
.42288 .61224 .42841 .61769 .43786 .61609 .43235 .61008 Mtetra
.448 .641 .939 r
.43235 .61008 .43786 .61609 .44766 .60045 .44179 .61107 Mtetra
0 0 0 r
.44179 .61107 .44766 .60045 .45698 .60705 .45153 .60066 Mtetra
.59 .687 .909 r
.45153 .60066 .45698 .60705 .46654 .60492 .46109 .59941 Mtetra
.639 .737 .919 r
.46109 .59941 .46654 .60492 .47614 .60233 .47071 .59695 Mtetra
.649 .746 .92 r
.47071 .59695 .47614 .60233 .48578 .59958 .48037 .59424 Mtetra
.653 .749 .92 r
.48037 .59424 .48578 .59958 .49545 .59673 .49006 .59141 Mtetra
.656 .751 .92 r
.49006 .59141 .49545 .59673 .50516 .59383 .49979 .58851 Mtetra
.657 .753 .92 r
.49979 .58851 .50516 .59383 .51491 .59089 .50956 .58557 Mtetra
.658 .753 .92 r
.50956 .58557 .51491 .59089 .52468 .58792 .51936 .58258 Mtetra
.659 .754 .92 r
.51936 .58258 .52468 .58792 .53449 .58493 .52919 .57958 Mtetra
.52919 .57958 .53449 .58493 .54434 .58194 .53906 .57656 Mtetra
.53906 .57656 .54434 .58194 .55422 .57894 .54897 .57354 Mtetra
.54897 .57354 .55422 .57894 .56414 .57593 .55891 .57051 Mtetra
.658 .753 .92 r
.55891 .57051 .56414 .57593 .57409 .57292 .56889 .56748 Mtetra
.56889 .56748 .57409 .57292 .58408 .56991 .5789 .56444 Mtetra
.5789 .56444 .58408 .56991 .5941 .56688 .58894 .5614 Mtetra
.58894 .5614 .5941 .56688 .60416 .56386 .59903 .55834 Mtetra
.59903 .55834 .60416 .56386 .61426 .56082 .60915 .55528 Mtetra
.60915 .55528 .61426 .56082 .62439 .55777 .61931 .55222 Mtetra
.657 .753 .92 r
.61931 .55222 .62439 .55777 .63456 .55471 .6295 .54914 Mtetra
.6295 .54914 .63456 .55471 .64476 .55165 .63973 .54605 Mtetra
.63973 .54605 .64476 .55165 .65501 .54857 .65 .54296 Mtetra
.65 .54296 .65501 .54857 .66529 .54549 .6603 .53985 Mtetra
.657 .752 .92 r
.6603 .53985 .66529 .54549 .6756 .54239 .67065 .53673 Mtetra
.67065 .53673 .6756 .54239 .68596 .53929 .68103 .53361 Mtetra
.68103 .53361 .68596 .53929 .69635 .53617 .69145 .53047 Mtetra
.69145 .53047 .69635 .53617 .70678 .53305 .7019 .52732 Mtetra
.7019 .52732 .70678 .53305 .71725 .52991 .7124 .52416 Mtetra
.7124 .52416 .71725 .52991 .72776 .52676 .72293 .52099 Mtetra
.72293 .52099 .72776 .52676 .7383 .5236 .73351 .51781 Mtetra
.73351 .51781 .7383 .5236 .74889 .52043 .74412 .51462 Mtetra
.74412 .51462 .74889 .52043 .75951 .51725 .75477 .51142 Mtetra
.75477 .51142 .75951 .51725 .77018 .51406 .76546 .50821 Mtetra
.76546 .50821 .77018 .51406 .78088 .51086 .7762 .50498 Mtetra
.7762 .50498 .78088 .51086 .79162 .50764 .78697 .50174 Mtetra
.78697 .50174 .79162 .50764 .80241 .50442 .79778 .4985 Mtetra
.79778 .4985 .80241 .50442 .81323 .50118 .80863 .49524 Mtetra
.80863 .49524 .81323 .50118 .82409 .49793 .81952 .49196 Mtetra
.81952 .49196 .82409 .49793 .835 .49467 .83046 .48868 Mtetra
.83046 .48868 .835 .49467 .84594 .4914 .84143 .48538 Mtetra
.84143 .48538 .84594 .4914 .85693 .48811 .85245 .48208 Mtetra
.85245 .48208 .85693 .48811 .86796 .48482 .86351 .47876 Mtetra
.86351 .47876 .86796 .48482 .87903 .48151 .87461 .47542 Mtetra
.87461 .47542 .87903 .48151 .89014 .47819 .88575 .47208 Mtetra
.88575 .47208 .89014 .47819 .90129 .47485 .89694 .46872 Mtetra
.89694 .46872 .90129 .47485 .91249 .47151 .90816 .46535 Mtetra
.90816 .46535 .91249 .47151 .92373 .46815 .91943 .46197 Mtetra
.91943 .46197 .92373 .46815 .93501 .46478 .93075 .45858 Mtetra
.888 .712 .657 r
.32388 .63596 .32954 .64321 .33908 .63384 .33467 .60454 Mtetra
.043 .058 .549 r
.33467 .60454 .33908 .63384 .34816 .63329 .34245 .62757 Mtetra
.61 .714 .919 r
.34245 .62757 .34816 .63329 .35735 .6313 .35165 .62586 Mtetra
.627 .731 .922 r
.35165 .62586 .35735 .6313 .36658 .62929 .3609 .62376 Mtetra
.607 .722 .926 r
.3609 .62376 .36658 .62929 .37578 .62893 .37017 .62207 Mtetra
.95 .665 .461 r
.37017 .62207 .37578 .62893 .38539 .6195 .37484 .73022 Mtetra
0 0 .234 r
.37484 .73022 .38539 .6195 .39464 .61924 .38903 .61341 Mtetra
.612 .714 .917 r
.38903 .61341 .39464 .61924 .40401 .61708 .3984 .61163 Mtetra
.636 .736 .92 r
.3984 .61163 .40401 .61708 .41343 .61466 .40783 .60927 Mtetra
.64 .74 .921 r
.40783 .60927 .41343 .61466 .42288 .61224 .4173 .60681 Mtetra
.636 .738 .922 r
.4173 .60681 .42288 .61224 .43235 .61008 .4268 .60444 Mtetra
.602 .72 .927 r
.4268 .60444 .43235 .61008 .44179 .61107 .43632 .60279 Mtetra
.836 .71 .725 r
.43632 .60279 .44179 .61107 .45153 .60066 .44621 .58705 Mtetra
.33 .384 .767 r
.44621 .58705 .45153 .60066 .46109 .59941 .4556 .59365 Mtetra
.627 .725 .918 r
.4556 .59365 .46109 .59941 .47071 .59695 .46524 .59148 Mtetra
.646 .743 .92 r
.46524 .59148 .47071 .59695 .48037 .59424 .47492 .58884 Mtetra
.652 .748 .92 r
.47492 .58884 .48037 .59424 .49006 .59141 .48463 .58603 Mtetra
.655 .75 .92 r
.48463 .58603 .49006 .59141 .49979 .58851 .49439 .58315 Mtetra
.657 .752 .92 r
.49439 .58315 .49979 .58851 .50956 .58557 .50418 .5802 Mtetra
.658 .753 .92 r
.50418 .5802 .50956 .58557 .51936 .58258 .514 .57721 Mtetra
.659 .754 .92 r
.514 .57721 .51936 .58258 .52919 .57958 .52386 .57419 Mtetra
.52386 .57419 .52919 .57958 .53906 .57656 .53375 .57115 Mtetra
.53375 .57115 .53906 .57656 .54897 .57354 .54368 .5681 Mtetra
.54368 .5681 .54897 .57354 .55891 .57051 .55364 .56505 Mtetra
.658 .753 .92 r
.55364 .56505 .55891 .57051 .56889 .56748 .56364 .562 Mtetra
.56364 .562 .56889 .56748 .5789 .56444 .57368 .55894 Mtetra
.57368 .55894 .5789 .56444 .58894 .5614 .58375 .55587 Mtetra
.58375 .55587 .58894 .5614 .59903 .55834 .59386 .5528 Mtetra
.59386 .5528 .59903 .55834 .60915 .55528 .60401 .54972 Mtetra
.60401 .54972 .60915 .55528 .61931 .55222 .61419 .54663 Mtetra
.657 .753 .92 r
.61419 .54663 .61931 .55222 .6295 .54914 .62441 .54353 Mtetra
.62441 .54353 .6295 .54914 .63973 .54605 .63466 .54042 Mtetra
.63466 .54042 .63973 .54605 .65 .54296 .64496 .5373 Mtetra
.64496 .5373 .65 .54296 .6603 .53985 .65529 .53417 Mtetra
.657 .752 .92 r
.65529 .53417 .6603 .53985 .67065 .53673 .66566 .53104 Mtetra
.66566 .53104 .67065 .53673 .68103 .53361 .67606 .52789 Mtetra
.67606 .52789 .68103 .53361 .69145 .53047 .68651 .52473 Mtetra
.68651 .52473 .69145 .53047 .7019 .52732 .69699 .52156 Mtetra
.69699 .52156 .7019 .52732 .7124 .52416 .70751 .51838 Mtetra
.70751 .51838 .7124 .52416 .72293 .52099 .71808 .51519 Mtetra
.71808 .51519 .72293 .52099 .73351 .51781 .72868 .51199 Mtetra
.72868 .51199 .73351 .51781 .74412 .51462 .73932 .50877 Mtetra
.73932 .50877 .74412 .51462 .75477 .51142 .75 .50555 Mtetra
.75 .50555 .75477 .51142 .76546 .50821 .76072 .50231 Mtetra
.76072 .50231 .76546 .50821 .7762 .50498 .77148 .49906 Mtetra
.77148 .49906 .7762 .50498 .78697 .50174 .78228 .4958 Mtetra
.78228 .4958 .78697 .50174 .79778 .4985 .79312 .49253 Mtetra
.79312 .49253 .79778 .4985 .80863 .49524 .804 .48925 Mtetra
.804 .48925 .80863 .49524 .81952 .49196 .81492 .48595 Mtetra
.81492 .48595 .81952 .49196 .83046 .48868 .82589 .48265 Mtetra
.82589 .48265 .83046 .48868 .84143 .48538 .83689 .47933 Mtetra
.83689 .47933 .84143 .48538 .85245 .48208 .84794 .476 Mtetra
.84794 .476 .85245 .48208 .86351 .47876 .85903 .47265 Mtetra
.85903 .47265 .86351 .47876 .87461 .47542 .87016 .4693 Mtetra
.87016 .4693 .87461 .47542 .88575 .47208 .88133 .46593 Mtetra
.88133 .46593 .88575 .47208 .89694 .46872 .89255 .46255 Mtetra
.89255 .46255 .89694 .46872 .90816 .46535 .90381 .45916 Mtetra
.90381 .45916 .90816 .46535 .91943 .46197 .91511 .45575 Mtetra
.91511 .45575 .91943 .46197 .93075 .45858 .92645 .45233 Mtetra
.493 .666 .939 r
.31811 .63008 .32388 .63596 .33467 .60454 .32715 .63034 Mtetra
.37 .093 .357 r
.32715 .63034 .33467 .60454 .34245 .62757 .33676 .6209 Mtetra
.56 .664 .907 r
.33676 .6209 .34245 .62757 .35165 .62586 .34591 .62032 Mtetra
.623 .727 .921 r
.34591 .62032 .35165 .62586 .3609 .62376 .35518 .61828 Mtetra
.623 .73 .923 r
.35518 .61828 .3609 .62376 .37017 .62207 .36448 .61623 Mtetra
.536 .686 .936 r
.36448 .61623 .37017 .62207 .37484 .73022 .37374 .61584 Mtetra
.592 .393 .581 r
.37374 .61584 .37484 .73022 .38903 .61341 .38343 .60633 Mtetra
.549 .648 .9 r
.38343 .60633 .38903 .61341 .3984 .61163 .39276 .60604 Mtetra
.629 .73 .92 r
.39276 .60604 .3984 .61163 .40783 .60927 .4022 .60383 Mtetra
.639 .739 .921 r
.4022 .60383 .40783 .60927 .4173 .60681 .41169 .60137 Mtetra
.639 .74 .921 r
.41169 .60137 .4173 .60681 .4268 .60444 .42122 .5989 Mtetra
.627 .733 .923 r
.42122 .5989 .4268 .60444 .43632 .60279 .43077 .5967 Mtetra
.448 .641 .939 r
.43077 .5967 .43632 .60279 .44621 .58705 .44028 .59765 Mtetra
0 0 0 r
.44028 .59765 .44621 .58705 .4556 .59365 .4501 .58716 Mtetra
.59 .688 .909 r
.4501 .58716 .4556 .59365 .46524 .59148 .45974 .58588 Mtetra
.639 .737 .919 r
.45974 .58588 .46524 .59148 .47492 .58884 .46943 .58337 Mtetra
.649 .746 .92 r
.46943 .58337 .47492 .58884 .48463 .58603 .47917 .58061 Mtetra
.653 .749 .92 r
.47917 .58061 .48463 .58603 .49439 .58315 .48895 .57773 Mtetra
.656 .751 .92 r
.48895 .57773 .49439 .58315 .50418 .5802 .49876 .57479 Mtetra
.657 .753 .92 r
.49876 .57479 .50418 .5802 .514 .57721 .5086 .57179 Mtetra
.658 .753 .92 r
.5086 .57179 .514 .57721 .52386 .57419 .51849 .56876 Mtetra
.659 .754 .92 r
.51849 .56876 .52386 .57419 .53375 .57115 .5284 .5657 Mtetra
.5284 .5657 .53375 .57115 .54368 .5681 .53836 .56263 Mtetra
.53836 .56263 .54368 .5681 .55364 .56505 .54834 .55956 Mtetra
.54834 .55956 .55364 .56505 .56364 .562 .55837 .55648 Mtetra
.658 .753 .92 r
.55837 .55648 .56364 .562 .57368 .55894 .56843 .5534 Mtetra
.56843 .5534 .57368 .55894 .58375 .55587 .57852 .55031 Mtetra
.57852 .55031 .58375 .55587 .59386 .5528 .58866 .54721 Mtetra
.58866 .54721 .59386 .5528 .60401 .54972 .59883 .54411 Mtetra
.59883 .54411 .60401 .54972 .61419 .54663 .60903 .541 Mtetra
.60903 .541 .61419 .54663 .62441 .54353 .61928 .53788 Mtetra
.657 .753 .92 r
.61928 .53788 .62441 .54353 .63466 .54042 .62956 .53475 Mtetra
.62956 .53475 .63466 .54042 .64496 .5373 .63988 .53161 Mtetra
.63988 .53161 .64496 .5373 .65529 .53417 .65024 .52846 Mtetra
.65024 .52846 .65529 .53417 .66566 .53104 .66063 .5253 Mtetra
.657 .752 .92 r
.66063 .5253 .66566 .53104 .67606 .52789 .67106 .52213 Mtetra
.67106 .52213 .67606 .52789 .68651 .52473 .68154 .51895 Mtetra
.68154 .51895 .68651 .52473 .69699 .52156 .69205 .51576 Mtetra
.69205 .51576 .69699 .52156 .70751 .51838 .7026 .51255 Mtetra
.7026 .51255 .70751 .51838 .71808 .51519 .71319 .50934 Mtetra
.71319 .50934 .71808 .51519 .72868 .51199 .72381 .50612 Mtetra
.72381 .50612 .72868 .51199 .73932 .50877 .73448 .50288 Mtetra
.73448 .50288 .73932 .50877 .75 .50555 .74519 .49963 Mtetra
.74519 .49963 .75 .50555 .76072 .50231 .75594 .49637 Mtetra
.75594 .49637 .76072 .50231 .77148 .49906 .76673 .4931 Mtetra
.76673 .4931 .77148 .49906 .78228 .4958 .77755 .48982 Mtetra
.77755 .48982 .78228 .4958 .79312 .49253 .78842 .48653 Mtetra
.78842 .48653 .79312 .49253 .804 .48925 .79934 .48322 Mtetra
.79934 .48322 .804 .48925 .81492 .48595 .81029 .4799 Mtetra
.81029 .4799 .81492 .48595 .82589 .48265 .82128 .47657 Mtetra
.82128 .47657 .82589 .48265 .83689 .47933 .83232 .47323 Mtetra
.83232 .47323 .83689 .47933 .84794 .476 .84339 .46988 Mtetra
.84339 .46988 .84794 .476 .85903 .47265 .85451 .46651 Mtetra
.85451 .46651 .85903 .47265 .87016 .4693 .86567 .46313 Mtetra
.86567 .46313 .87016 .4693 .88133 .46593 .87688 .45974 Mtetra
.87688 .45974 .88133 .46593 .89255 .46255 .88813 .45633 Mtetra
.88813 .45633 .89255 .46255 .90381 .45916 .89942 .45291 Mtetra
.89942 .45291 .90381 .45916 .91511 .45575 .91075 .44948 Mtetra
.91075 .44948 .91511 .45575 .92645 .45233 .92213 .44604 Mtetra
.596 .715 .927 r
.31229 .62447 .31811 .63008 .32715 .63034 .32144 .623 Mtetra
.889 .713 .657 r
.32144 .623 .32715 .63034 .33676 .6209 .33232 .59141 Mtetra
.038 .054 .547 r
.33232 .59141 .33676 .6209 .34591 .62032 .34015 .61451 Mtetra
.61 .714 .919 r
.34015 .61451 .34591 .62032 .35518 .61828 .34942 .61276 Mtetra
.627 .731 .922 r
.34942 .61276 .35518 .61828 .36448 .61623 .35874 .61062 Mtetra
.607 .722 .926 r
.35874 .61062 .36448 .61623 .37374 .61584 .36808 .60888 Mtetra
.951 .664 .458 r
.36808 .60888 .37374 .61584 .38343 .60633 .37272 .71751 Mtetra
0 0 .228 r
.37272 .71751 .38343 .60633 .39276 .60604 .38709 .60012 Mtetra
.612 .714 .917 r
.38709 .60012 .39276 .60604 .4022 .60383 .39654 .5983 Mtetra
.636 .736 .92 r
.39654 .5983 .4022 .60383 .41169 .60137 .40605 .59589 Mtetra
.64 .74 .921 r
.40605 .59589 .41169 .60137 .42122 .5989 .41559 .59338 Mtetra
.636 .738 .922 r
.41559 .59338 .42122 .5989 .43077 .5967 .42517 .59096 Mtetra
.602 .72 .927 r
.42517 .59096 .43077 .5967 .44028 .59765 .43477 .58928 Mtetra
.837 .711 .725 r
.43477 .58928 .44028 .59765 .4501 .58716 .44474 .57343 Mtetra
.328 .383 .767 r
.44474 .57343 .4501 .58716 .45974 .58588 .4542 .58002 Mtetra
.627 .725 .918 r
.4542 .58002 .45974 .58588 .46943 .58337 .46392 .57781 Mtetra
.646 .743 .92 r
.46392 .57781 .46943 .58337 .47917 .58061 .47367 .57512 Mtetra
.652 .748 .92 r
.47367 .57512 .47917 .58061 .48895 .57773 .48347 .57227 Mtetra
.655 .75 .92 r
.48347 .57227 .48895 .57773 .49876 .57479 .4933 .56933 Mtetra
.657 .752 .92 r
.4933 .56933 .49876 .57479 .5086 .57179 .50317 .56633 Mtetra
.658 .753 .92 r
.50317 .56633 .5086 .57179 .51849 .56876 .51308 .56329 Mtetra
.659 .754 .92 r
.51308 .56329 .51849 .56876 .5284 .5657 .52302 .56022 Mtetra
.52302 .56022 .5284 .5657 .53836 .56263 .533 .55713 Mtetra
.533 .55713 .53836 .56263 .54834 .55956 .54301 .55403 Mtetra
.54301 .55403 .54834 .55956 .55837 .55648 .55306 .55093 Mtetra
.658 .753 .92 r
.55306 .55093 .55837 .55648 .56843 .5534 .56314 .54782 Mtetra
.56314 .54782 .56843 .5534 .57852 .55031 .57326 .54471 Mtetra
.57326 .54471 .57852 .55031 .58866 .54721 .58342 .54159 Mtetra
.58342 .54159 .58866 .54721 .59883 .54411 .59361 .53847 Mtetra
.59361 .53847 .59883 .54411 .60903 .541 .60385 .53533 Mtetra
.60385 .53533 .60903 .541 .61928 .53788 .61411 .53219 Mtetra
.657 .753 .92 r
.61411 .53219 .61928 .53788 .62956 .53475 .62442 .52904 Mtetra
.62442 .52904 .62956 .53475 .63988 .53161 .63477 .52588 Mtetra
.63477 .52588 .63988 .53161 .65024 .52846 .64515 .52271 Mtetra
.64515 .52271 .65024 .52846 .66063 .5253 .65557 .51952 Mtetra
.657 .752 .92 r
.65557 .51952 .66063 .5253 .67106 .52213 .66603 .51633 Mtetra
.66603 .51633 .67106 .52213 .68154 .51895 .67653 .51313 Mtetra
.67653 .51313 .68154 .51895 .69205 .51576 .68707 .50991 Mtetra
.68707 .50991 .69205 .51576 .7026 .51255 .69764 .50669 Mtetra
.69764 .50669 .7026 .51255 .71319 .50934 .70826 .50345 Mtetra
.70826 .50345 .71319 .50934 .72381 .50612 .71892 .50021 Mtetra
.71892 .50021 .72381 .50612 .73448 .50288 .72961 .49695 Mtetra
.72961 .49695 .73448 .50288 .74519 .49963 .74035 .49368 Mtetra
.74035 .49368 .74519 .49963 .75594 .49637 .75113 .4904 Mtetra
.75113 .4904 .75594 .49637 .76673 .4931 .76194 .4871 Mtetra
.76194 .4871 .76673 .4931 .77755 .48982 .7728 .4838 Mtetra
.7728 .4838 .77755 .48982 .78842 .48653 .7837 .48048 Mtetra
.7837 .48048 .78842 .48653 .79934 .48322 .79464 .47715 Mtetra
.79464 .47715 .79934 .48322 .81029 .4799 .80562 .47381 Mtetra
.80562 .47381 .81029 .4799 .82128 .47657 .81664 .47045 Mtetra
.81664 .47045 .82128 .47657 .83232 .47323 .82771 .46709 Mtetra
.82771 .46709 .83232 .47323 .84339 .46988 .83882 .46371 Mtetra
.83882 .46371 .84339 .46988 .85451 .46651 .84997 .46032 Mtetra
.84997 .46032 .85451 .46651 .86567 .46313 .86116 .45692 Mtetra
.86116 .45692 .86567 .46313 .87688 .45974 .87239 .4535 Mtetra
.87239 .4535 .87688 .45974 .88813 .45633 .88367 .45007 Mtetra
.88367 .45007 .88813 .45633 .89942 .45291 .895 .44663 Mtetra
.895 .44663 .89942 .45291 .91075 .44948 .90636 .44317 Mtetra
.90636 .44317 .91075 .44948 .92213 .44604 .91777 .43971 Mtetra
.613 .723 .924 r
.30642 .61888 .31229 .62447 .32144 .623 .31561 .61704 Mtetra
.494 .666 .939 r
.31561 .61704 .32144 .623 .33232 .59141 .32471 .61727 Mtetra
.363 .085 .351 r
.32471 .61727 .33232 .59141 .34015 .61451 .33441 .60775 Mtetra
.56 .664 .907 r
.33441 .60775 .34015 .61451 .34942 .61276 .34363 .60713 Mtetra
.623 .727 .921 r
.34363 .60713 .34942 .61276 .35874 .61062 .35296 .60505 Mtetra
.623 .73 .923 r
.35296 .60505 .35874 .61062 .36808 .60888 .36234 .60296 Mtetra
.536 .686 .936 r
.36234 .60296 .36808 .60888 .37272 .71751 .37168 .60252 Mtetra
.59 .391 .579 r
.37168 .60252 .37272 .71751 .38709 .60012 .38144 .59294 Mtetra
.548 .648 .9 r
.38144 .59294 .38709 .60012 .39654 .5983 .39085 .59261 Mtetra
.629 .73 .92 r
.39085 .59261 .39654 .5983 .40605 .59589 .40036 .59036 Mtetra
.639 .739 .921 r
.40036 .59036 .40605 .59589 .41559 .59338 .40993 .58785 Mtetra
.639 .74 .921 r
.40993 .58785 .41559 .59338 .42517 .59096 .41953 .58534 Mtetra
.627 .733 .923 r
.41953 .58534 .42517 .59096 .43477 .58928 .42916 .58309 Mtetra
.449 .641 .939 r
.42916 .58309 .43477 .58928 .44474 .57343 .43875 .58401 Mtetra
0 0 0 r
.43875 .58401 .44474 .57343 .4542 .58002 .44865 .57344 Mtetra
.59 .688 .91 r
.44865 .57344 .4542 .58002 .46392 .57781 .45836 .57211 Mtetra
.639 .737 .919 r
.45836 .57211 .46392 .57781 .47367 .57512 .46814 .56955 Mtetra
.649 .746 .92 r
.46814 .56955 .47367 .57512 .48347 .57227 .47796 .56675 Mtetra
.653 .749 .92 r
.47796 .56675 .48347 .57227 .4933 .56933 .48781 .56382 Mtetra
.656 .751 .92 r
.48781 .56382 .4933 .56933 .50317 .56633 .49771 .56083 Mtetra
.657 .753 .92 r
.49771 .56083 .50317 .56633 .51308 .56329 .50763 .55778 Mtetra
.658 .753 .92 r
.50763 .55778 .51308 .56329 .52302 .56022 .5176 .55469 Mtetra
.659 .754 .92 r
.5176 .55469 .52302 .56022 .533 .55713 .5276 .55159 Mtetra
.5276 .55159 .533 .55713 .54301 .55403 .53763 .54847 Mtetra
.53763 .54847 .54301 .55403 .55306 .55093 .54771 .54534 Mtetra
.54771 .54534 .55306 .55093 .56314 .54782 .55782 .54221 Mtetra
.658 .753 .92 r
.55782 .54221 .56314 .54782 .57326 .54471 .56796 .53908 Mtetra
.56796 .53908 .57326 .54471 .58342 .54159 .57814 .53593 Mtetra
.57814 .53593 .58342 .54159 .59361 .53847 .58836 .53279 Mtetra
.58836 .53279 .59361 .53847 .60385 .53533 .59862 .52963 Mtetra
.59862 .52963 .60385 .53533 .61411 .53219 .60892 .52646 Mtetra
.60892 .52646 .61411 .53219 .62442 .52904 .61925 .52329 Mtetra
.657 .753 .92 r
.61925 .52329 .62442 .52904 .63477 .52588 .62962 .52011 Mtetra
.62962 .52011 .63477 .52588 .64515 .52271 .64003 .51691 Mtetra
.64003 .51691 .64515 .52271 .65557 .51952 .65048 .51371 Mtetra
.65048 .51371 .65557 .51952 .66603 .51633 .66096 .51049 Mtetra
.657 .752 .92 r
.66096 .51049 .66603 .51633 .67653 .51313 .67149 .50727 Mtetra
.67149 .50727 .67653 .51313 .68707 .50991 .68205 .50403 Mtetra
.68205 .50403 .68707 .50991 .69764 .50669 .69266 .50078 Mtetra
.69266 .50078 .69764 .50669 .70826 .50345 .7033 .49753 Mtetra
.7033 .49753 .70826 .50345 .71892 .50021 .71399 .49426 Mtetra
.71399 .49426 .71892 .50021 .72961 .49695 .72471 .49097 Mtetra
.72471 .49097 .72961 .49695 .74035 .49368 .73547 .48768 Mtetra
.73547 .48768 .74035 .49368 .75113 .4904 .74628 .48438 Mtetra
.74628 .48438 .75113 .4904 .76194 .4871 .75712 .48106 Mtetra
.75712 .48106 .76194 .4871 .7728 .4838 .76801 .47773 Mtetra
.76801 .47773 .7728 .4838 .7837 .48048 .77894 .47439 Mtetra
.77894 .47439 .7837 .48048 .79464 .47715 .78991 .47104 Mtetra
.78991 .47104 .79464 .47715 .80562 .47381 .80092 .46767 Mtetra
.80092 .46767 .80562 .47381 .81664 .47045 .81197 .46429 Mtetra
.81197 .46429 .81664 .47045 .82771 .46709 .82307 .4609 Mtetra
.82307 .4609 .82771 .46709 .83882 .46371 .83421 .4575 Mtetra
.83421 .4575 .83882 .46371 .84997 .46032 .84539 .45409 Mtetra
.84539 .45409 .84997 .46032 .86116 .45692 .85661 .45066 Mtetra
.85661 .45066 .86116 .45692 .87239 .4535 .86788 .44722 Mtetra
.86788 .44722 .87239 .4535 .88367 .45007 .87919 .44376 Mtetra
.87919 .44376 .88367 .45007 .895 .44663 .89054 .4403 Mtetra
.89054 .4403 .895 .44663 .90636 .44317 .90194 .43682 Mtetra
.90194 .43682 .90636 .44317 .91777 .43971 .91338 .43333 Mtetra
.613 .72 .922 r
.30052 .61318 .30642 .61888 .31561 .61704 .30973 .61134 Mtetra
.596 .715 .927 r
.30973 .61134 .31561 .61704 .32471 .61727 .31895 .60982 Mtetra
.89 .713 .656 r
.31895 .60982 .32471 .61727 .33441 .60775 .32994 .57806 Mtetra
.033 .05 .544 r
.32994 .57806 .33441 .60775 .34363 .60713 .33781 .60123 Mtetra
.61 .714 .919 r
.33781 .60123 .34363 .60713 .35296 .60505 .34715 .59944 Mtetra
.627 .731 .922 r
.34715 .59944 .35296 .60505 .36234 .60296 .35655 .59725 Mtetra
.607 .722 .926 r
.35655 .59725 .36234 .60296 .37168 .60252 .36596 .59547 Mtetra
.952 .664 .455 r
.36596 .59547 .37168 .60252 .38144 .59294 .37056 .70457 Mtetra
0 0 .222 r
.37056 .70457 .38144 .59294 .39085 .59261 .38513 .5866 Mtetra
.612 .714 .917 r
.38513 .5866 .39085 .59261 .40036 .59036 .39465 .58474 Mtetra
.636 .736 .921 r
.39465 .58474 .40036 .59036 .40993 .58785 .40423 .58228 Mtetra
.64 .74 .921 r
.40423 .58228 .40993 .58785 .41953 .58534 .41385 .57973 Mtetra
.636 .738 .922 r
.41385 .57973 .41953 .58534 .42916 .58309 .42351 .57726 Mtetra
.602 .72 .927 r
.42351 .57726 .42916 .58309 .43875 .58401 .43318 .57554 Mtetra
.838 .712 .725 r
.43318 .57554 .43875 .58401 .44865 .57344 .44324 .55958 Mtetra
.326 .382 .767 r
.44324 .55958 .44865 .57344 .45836 .57211 .45278 .56616 Mtetra
.627 .725 .918 r
.45278 .56616 .45836 .57211 .46814 .56955 .46257 .5639 Mtetra
.646 .743 .92 r
.46257 .5639 .46814 .56955 .47796 .56675 .47241 .56116 Mtetra
.652 .748 .92 r
.47241 .56116 .47796 .56675 .48781 .56382 .48229 .55826 Mtetra
.655 .75 .92 r
.48229 .55826 .48781 .56382 .49771 .56083 .4922 .55528 Mtetra
.657 .752 .92 r
.4922 .55528 .49771 .56083 .50763 .55778 .50215 .55223 Mtetra
.658 .753 .92 r
.50215 .55223 .50763 .55778 .5176 .55469 .51214 .54913 Mtetra
.659 .754 .92 r
.51214 .54913 .5176 .55469 .5276 .55159 .52217 .54601 Mtetra
.52217 .54601 .5276 .55159 .53763 .54847 .53223 .54287 Mtetra
.53223 .54287 .53763 .54847 .54771 .54534 .54232 .53972 Mtetra
.54232 .53972 .54771 .54534 .55782 .54221 .55246 .53656 Mtetra
.658 .753 .92 r
.55246 .53656 .55782 .54221 .56796 .53908 .56263 .5334 Mtetra
.56263 .5334 .56796 .53908 .57814 .53593 .57283 .53024 Mtetra
.57283 .53024 .57814 .53593 .58836 .53279 .58308 .52707 Mtetra
.58308 .52707 .58836 .53279 .59862 .52963 .59336 .52389 Mtetra
.59336 .52389 .59862 .52963 .60892 .52646 .60368 .5207 Mtetra
.60368 .5207 .60892 .52646 .61925 .52329 .61404 .5175 Mtetra
.657 .753 .92 r
.61404 .5175 .61925 .52329 .62962 .52011 .62444 .5143 Mtetra
.62444 .5143 .62962 .52011 .64003 .51691 .63487 .51108 Mtetra
.63487 .51108 .64003 .51691 .65048 .51371 .64535 .50785 Mtetra
.64535 .50785 .65048 .51371 .66096 .51049 .65586 .50462 Mtetra
.657 .752 .92 r
.65586 .50462 .66096 .51049 .67149 .50727 .66641 .50137 Mtetra
.66641 .50137 .67149 .50727 .68205 .50403 .67701 .49811 Mtetra
.67701 .49811 .68205 .50403 .69266 .50078 .68764 .49484 Mtetra
.68764 .49484 .69266 .50078 .7033 .49753 .69831 .49156 Mtetra
.69831 .49156 .7033 .49753 .71399 .49426 .70902 .48826 Mtetra
.70902 .48826 .71399 .49426 .72471 .49097 .71977 .48496 Mtetra
.71977 .48496 .72471 .49097 .73547 .48768 .73057 .48164 Mtetra
.73057 .48164 .73547 .48768 .74628 .48438 .7414 .47831 Mtetra
.7414 .47831 .74628 .48438 .75712 .48106 .75227 .47497 Mtetra
.75227 .47497 .75712 .48106 .76801 .47773 .76319 .47162 Mtetra
.76319 .47162 .76801 .47773 .77894 .47439 .77415 .46826 Mtetra
.77415 .46826 .77894 .47439 .78991 .47104 .78515 .46488 Mtetra
.78515 .46488 .78991 .47104 .80092 .46767 .79619 .46149 Mtetra
.79619 .46149 .80092 .46767 .81197 .46429 .80727 .45809 Mtetra
.80727 .45809 .81197 .46429 .82307 .4609 .8184 .45468 Mtetra
.8184 .45468 .82307 .4609 .83421 .4575 .82956 .45125 Mtetra
.82956 .45125 .83421 .4575 .84539 .45409 .84078 .44781 Mtetra
.84078 .44781 .84539 .45409 .85661 .45066 .85203 .44436 Mtetra
.85203 .44436 .85661 .45066 .86788 .44722 .86333 .44089 Mtetra
.86333 .44089 .86788 .44722 .87919 .44376 .87467 .43741 Mtetra
.87467 .43741 .87919 .44376 .89054 .4403 .88606 .43392 Mtetra
.88606 .43392 .89054 .4403 .90194 .43682 .89749 .43042 Mtetra
.89749 .43042 .90194 .43682 .91338 .43333 .90896 .4269 Mtetra
.596 .703 .918 r
.29461 .60714 .30052 .61318 .30973 .61134 .30381 .60566 Mtetra
.613 .723 .924 r
.30381 .60566 .30973 .61134 .31895 .60982 .31307 .60378 Mtetra
.494 .666 .939 r
.31307 .60378 .31895 .60982 .32994 .57806 .32224 .60397 Mtetra
.357 .077 .344 r
.32224 .60397 .32994 .57806 .33781 .60123 .33201 .59438 Mtetra
.56 .664 .907 r
.33201 .59438 .33781 .60123 .34715 .59944 .3413 .59372 Mtetra
.623 .727 .921 r
.3413 .59372 .34715 .59944 .35655 .59725 .35071 .59159 Mtetra
.623 .73 .923 r
.35071 .59159 .35655 .59725 .36596 .59547 .36016 .58946 Mtetra
.536 .686 .935 r
.36016 .58946 .36596 .59547 .37056 .70457 .36957 .58899 Mtetra
.589 .389 .578 r
.36957 .58899 .37056 .70457 .38513 .5866 .37942 .57933 Mtetra
.548 .648 .9 r
.37942 .57933 .38513 .5866 .39465 .58474 .3889 .57896 Mtetra
.629 .73 .92 r
.3889 .57896 .39465 .58474 .40423 .58228 .39849 .57666 Mtetra
.639 .739 .921 r
.39849 .57666 .40423 .58228 .41385 .57973 .40814 .57411 Mtetra
.639 .74 .921 r
.40814 .57411 .41385 .57973 .42351 .57726 .41781 .57154 Mtetra
.627 .733 .923 r
.41781 .57154 .42351 .57726 .43318 .57554 .42752 .56925 Mtetra
.45 .641 .939 r
.42752 .56925 .43318 .57554 .44324 .55958 .43719 .57014 Mtetra
0 0 0 r
.43719 .57014 .44324 .55958 .45278 .56616 .44717 .55948 Mtetra
.59 .688 .91 r
.44717 .55948 .45278 .56616 .46257 .5639 .45697 .55811 Mtetra
.639 .737 .919 r
.45697 .55811 .46257 .5639 .47241 .56116 .46682 .55551 Mtetra
.649 .746 .92 r
.46682 .55551 .47241 .56116 .48229 .55826 .47672 .55265 Mtetra
.653 .749 .92 r
.47672 .55265 .48229 .55826 .4922 .55528 .48666 .54967 Mtetra
.656 .751 .92 r
.48666 .54967 .4922 .55528 .50215 .55223 .49664 .54663 Mtetra
.657 .753 .92 r
.49664 .54663 .50215 .55223 .51214 .54913 .50665 .54353 Mtetra
.658 .753 .92 r
.50665 .54353 .51214 .54913 .52217 .54601 .5167 .54039 Mtetra
.659 .754 .92 r
.5167 .54039 .52217 .54601 .53223 .54287 .52678 .53723 Mtetra
.52678 .53723 .53223 .54287 .54232 .53972 .5369 .53406 Mtetra
.5369 .53406 .54232 .53972 .55246 .53656 .54706 .53088 Mtetra
.54706 .53088 .55246 .53656 .56263 .5334 .55726 .52769 Mtetra
.658 .753 .92 r
.55726 .52769 .56263 .5334 .57283 .53024 .56749 .52451 Mtetra
.56749 .52451 .57283 .53024 .58308 .52707 .57776 .52131 Mtetra
.57776 .52131 .58308 .52707 .59336 .52389 .58807 .51811 Mtetra
.58807 .51811 .59336 .52389 .60368 .5207 .59841 .5149 Mtetra
.59841 .5149 .60368 .5207 .61404 .5175 .6088 .51168 Mtetra
.6088 .51168 .61404 .5175 .62444 .5143 .61922 .50845 Mtetra
.657 .753 .92 r
.61922 .50845 .62444 .5143 .63487 .51108 .62968 .50521 Mtetra
.62968 .50521 .63487 .51108 .64535 .50785 .64018 .50196 Mtetra
.64018 .50196 .64535 .50785 .65586 .50462 .65072 .4987 Mtetra
.65072 .4987 .65586 .50462 .66641 .50137 .6613 .49543 Mtetra
.657 .752 .92 r
.6613 .49543 .66641 .50137 .67701 .49811 .67192 .49214 Mtetra
.67192 .49214 .67701 .49811 .68764 .49484 .68258 .48885 Mtetra
.68258 .48885 .68764 .49484 .69831 .49156 .69328 .48555 Mtetra
.69328 .48555 .69831 .49156 .70902 .48826 .70402 .48223 Mtetra
.70402 .48223 .70902 .48826 .71977 .48496 .7148 .4789 Mtetra
.7148 .4789 .71977 .48496 .73057 .48164 .72562 .47556 Mtetra
.72562 .47556 .73057 .48164 .7414 .47831 .73648 .47221 Mtetra
.73648 .47221 .7414 .47831 .75227 .47497 .74739 .46885 Mtetra
.74739 .46885 .75227 .47497 .76319 .47162 .75833 .46547 Mtetra
.75833 .46547 .76319 .47162 .77415 .46826 .76932 .46208 Mtetra
.76932 .46208 .77415 .46826 .78515 .46488 .78035 .45868 Mtetra
.78035 .45868 .78515 .46488 .79619 .46149 .79142 .45527 Mtetra
.79142 .45527 .79619 .46149 .80727 .45809 .80253 .45184 Mtetra
.80253 .45184 .80727 .45809 .8184 .45468 .81369 .4484 Mtetra
.81369 .4484 .8184 .45468 .82956 .45125 .82489 .44495 Mtetra
.82489 .44495 .82956 .45125 .84078 .44781 .83613 .44149 Mtetra
.83613 .44149 .84078 .44781 .85203 .44436 .84742 .43801 Mtetra
.84742 .43801 .85203 .44436 .86333 .44089 .85875 .43452 Mtetra
.85875 .43452 .86333 .44089 .87467 .43741 .87012 .43102 Mtetra
.87012 .43102 .87467 .43741 .88606 .43392 .88154 .4275 Mtetra
.88154 .4275 .88606 .43392 .89749 .43042 .893 .42397 Mtetra
.893 .42397 .89749 .43042 .90896 .4269 .90451 .42043 Mtetra
.514 .62 .895 r
.28877 .59952 .29461 .60714 .30381 .60566 .29785 .59987 Mtetra
.613 .72 .922 r
.29785 .59987 .30381 .60566 .31307 .60378 .30713 .59799 Mtetra
.596 .715 .927 r
.30713 .59799 .31307 .60378 .32224 .60397 .31642 .59643 Mtetra
.891 .714 .655 r
.31642 .59643 .32224 .60397 .33201 .59438 .32752 .5645 Mtetra
.027 .046 .542 r
.32752 .5645 .33201 .59438 .3413 .59372 .33543 .58773 Mtetra
.61 .714 .919 r
.33543 .58773 .3413 .59372 .35071 .59159 .34485 .5859 Mtetra
.627 .731 .922 r
.34485 .5859 .35071 .59159 .36016 .58946 .35432 .58366 Mtetra
.607 .722 .926 r
.35432 .58366 .36016 .58946 .36957 .58899 .36381 .58184 Mtetra
.953 .664 .452 r
.36381 .58184 .36957 .58899 .37942 .57933 .36837 .69141 Mtetra
0 0 .215 r
.36837 .69141 .37942 .57933 .3889 .57896 .38313 .57286 Mtetra
.612 .714 .917 r
.38313 .57286 .3889 .57896 .39849 .57666 .39272 .57095 Mtetra
.636 .736 .921 r
.39272 .57095 .39849 .57666 .40814 .57411 .40238 .56845 Mtetra
.64 .74 .921 r
.40238 .56845 .40814 .57411 .41781 .57154 .41208 .56585 Mtetra
.636 .738 .922 r
.41208 .56585 .41781 .57154 .42752 .56925 .42182 .56333 Mtetra
.602 .72 .927 r
.42182 .56333 .42752 .56925 .43719 .57014 .43157 .56156 Mtetra
.839 .713 .725 r
.43157 .56156 .43719 .57014 .44717 .55948 .44172 .5455 Mtetra
.324 .381 .767 r
.44172 .5455 .44717 .55948 .45697 .55811 .45133 .55207 Mtetra
.627 .725 .918 r
.45133 .55207 .45697 .55811 .46682 .55551 .4612 .54976 Mtetra
.646 .743 .92 r
.4612 .54976 .46682 .55551 .47672 .55265 .47112 .54697 Mtetra
.652 .748 .92 r
.47112 .54697 .47672 .55265 .48666 .54967 .48108 .54402 Mtetra
.655 .75 .92 r
.48108 .54402 .48666 .54967 .49664 .54663 .49108 .54098 Mtetra
.657 .752 .92 r
.49108 .54098 .49664 .54663 .50665 .54353 .50112 .53788 Mtetra
.658 .753 .92 r
.50112 .53788 .50665 .54353 .5167 .54039 .51119 .53473 Mtetra
.659 .754 .92 r
.51119 .53473 .5167 .54039 .52678 .53723 .5213 .53155 Mtetra
.5213 .53155 .52678 .53723 .5369 .53406 .53144 .52836 Mtetra
.53144 .52836 .5369 .53406 .54706 .53088 .54163 .52516 Mtetra
.54163 .52516 .54706 .53088 .55726 .52769 .55185 .52195 Mtetra
.658 .753 .92 r
.55185 .52195 .55726 .52769 .56749 .52451 .5621 .51873 Mtetra
.5621 .51873 .56749 .52451 .57776 .52131 .5724 .51551 Mtetra
.5724 .51551 .57776 .52131 .58807 .51811 .58273 .51229 Mtetra
.58273 .51229 .58807 .51811 .59841 .5149 .59311 .50905 Mtetra
.59311 .50905 .59841 .5149 .6088 .51168 .60352 .50581 Mtetra
.60352 .50581 .6088 .51168 .61922 .50845 .61397 .50256 Mtetra
.657 .753 .92 r
.61397 .50256 .61922 .50845 .62968 .50521 .62445 .4993 Mtetra
.62445 .4993 .62968 .50521 .64018 .50196 .63498 .49602 Mtetra
.63498 .49602 .64018 .50196 .65072 .4987 .64555 .49274 Mtetra
.64555 .49274 .65072 .4987 .6613 .49543 .65616 .48944 Mtetra
.657 .752 .92 r
.65616 .48944 .6613 .49543 .67192 .49214 .6668 .48614 Mtetra
.6668 .48614 .67192 .49214 .68258 .48885 .67749 .48282 Mtetra
.67749 .48282 .68258 .48885 .69328 .48555 .68822 .47949 Mtetra
.68822 .47949 .69328 .48555 .70402 .48223 .69898 .47615 Mtetra
.69898 .47615 .70402 .48223 .7148 .4789 .70979 .4728 Mtetra
.70979 .4728 .7148 .4789 .72562 .47556 .72064 .46944 Mtetra
.72064 .46944 .72562 .47556 .73648 .47221 .73153 .46606 Mtetra
.73153 .46606 .73648 .47221 .74739 .46885 .74247 .46267 Mtetra
.74247 .46267 .74739 .46885 .75833 .46547 .75344 .45927 Mtetra
.75344 .45927 .75833 .46547 .76932 .46208 .76446 .45586 Mtetra
.76446 .45586 .76932 .46208 .78035 .45868 .77552 .45244 Mtetra
.77552 .45244 .78035 .45868 .79142 .45527 .78662 .449 Mtetra
.78662 .449 .79142 .45527 .80253 .45184 .79776 .44555 Mtetra
.79776 .44555 .80253 .45184 .81369 .4484 .80895 .44209 Mtetra
.80895 .44209 .81369 .4484 .82489 .44495 .82018 .43861 Mtetra
.82018 .43861 .82489 .44495 .83613 .44149 .83145 .43512 Mtetra
.83145 .43512 .83613 .44149 .84742 .43801 .84277 .43162 Mtetra
.84277 .43162 .84742 .43801 .85875 .43452 .85413 .4281 Mtetra
.85413 .4281 .85875 .43452 .87012 .43102 .86554 .42457 Mtetra
.86554 .42457 .87012 .43102 .88154 .4275 .87699 .42103 Mtetra
.87699 .42103 .88154 .4275 .893 .42397 .88849 .41748 Mtetra
.88849 .41748 .893 .42397 .90451 .42043 .90003 .41391 Mtetra
0 0 0 r
.28089 .62022 .28877 .59952 .29785 .59987 .29188 .59374 Mtetra
.596 .704 .918 r
.29188 .59374 .29785 .59987 .30713 .59799 .30115 .59222 Mtetra
.613 .723 .924 r
.30115 .59222 .30713 .59799 .31642 .59643 .31048 .59029 Mtetra
.495 .666 .939 r
.31048 .59029 .31642 .59643 .32752 .5645 .31972 .59045 Mtetra
.351 .069 .338 r
.31972 .59045 .32752 .5645 .33543 .58773 .32958 .58078 Mtetra
.56 .664 .907 r
.32958 .58078 .33543 .58773 .34485 .5859 .33894 .58009 Mtetra
.623 .727 .921 r
.33894 .58009 .34485 .5859 .35432 .58366 .34843 .57791 Mtetra
.623 .73 .923 r
.34843 .57791 .35432 .58366 .36381 .58184 .35795 .57573 Mtetra
.536 .686 .935 r
.35795 .57573 .36381 .58184 .36837 .69141 .36744 .57522 Mtetra
.587 .386 .576 r
.36744 .57522 .36837 .69141 .38313 .57286 .37737 .56549 Mtetra
.548 .648 .9 r
.37737 .56549 .38313 .57286 .39272 .57095 .38692 .56508 Mtetra
.629 .73 .92 r
.38692 .56508 .39272 .57095 .40238 .56845 .39659 .56273 Mtetra
.639 .739 .921 r
.39659 .56273 .40238 .56845 .41208 .56585 .40631 .56013 Mtetra
.639 .74 .921 r
.40631 .56013 .41208 .56585 .42182 .56333 .41607 .55752 Mtetra
.627 .733 .923 r
.41607 .55752 .42182 .56333 .43157 .56156 .42586 .55518 Mtetra
.45 .641 .938 r
.42586 .55518 .43157 .56156 .44172 .5455 .4356 .55603 Mtetra
0 0 0 r
.4356 .55603 .44172 .5455 .45133 .55207 .44567 .54529 Mtetra
.589 .688 .91 r
.44567 .54529 .45133 .55207 .4612 .54976 .45555 .54388 Mtetra
.639 .737 .919 r
.45555 .54388 .4612 .54976 .47112 .54697 .46548 .54122 Mtetra
.649 .746 .92 r
.46548 .54122 .47112 .54697 .48108 .54402 .47547 .53831 Mtetra
.653 .749 .92 r
.47547 .53831 .48108 .54402 .49108 .54098 .48549 .53528 Mtetra
.656 .751 .92 r
.48549 .53528 .49108 .54098 .50112 .53788 .49555 .53218 Mtetra
.657 .753 .92 r
.49555 .53218 .50112 .53788 .51119 .53473 .50564 .52903 Mtetra
.658 .753 .92 r
.50564 .52903 .51119 .53473 .5213 .53155 .51578 .52584 Mtetra
.659 .754 .92 r
.51578 .52584 .5213 .53155 .53144 .52836 .52595 .52262 Mtetra
.52595 .52262 .53144 .52836 .54163 .52516 .53616 .5194 Mtetra
.53616 .5194 .54163 .52516 .55185 .52195 .5464 .51616 Mtetra
.5464 .51616 .55185 .52195 .5621 .51873 .55668 .51292 Mtetra
.658 .753 .92 r
.55668 .51292 .5621 .51873 .5724 .51551 .56701 .50968 Mtetra
.56701 .50968 .5724 .51551 .58273 .51229 .57737 .50643 Mtetra
.57737 .50643 .58273 .51229 .59311 .50905 .58776 .50317 Mtetra
.58776 .50317 .59311 .50905 .60352 .50581 .5982 .4999 Mtetra
.5982 .4999 .60352 .50581 .61397 .50256 .60868 .49663 Mtetra
.60868 .49663 .61397 .50256 .62445 .4993 .61919 .49334 Mtetra
.657 .753 .92 r
.61919 .49334 .62445 .4993 .63498 .49602 .62975 .49005 Mtetra
.62975 .49005 .63498 .49602 .64555 .49274 .64034 .48674 Mtetra
.64034 .48674 .64555 .49274 .65616 .48944 .65097 .48342 Mtetra
.65097 .48342 .65616 .48944 .6668 .48614 .66165 .48009 Mtetra
.657 .752 .92 r
.66165 .48009 .6668 .48614 .67749 .48282 .67236 .47675 Mtetra
.67236 .47675 .67749 .48282 .68822 .47949 .68312 .4734 Mtetra
.68312 .4734 .68822 .47949 .69898 .47615 .69391 .47003 Mtetra
.69391 .47003 .69898 .47615 .70979 .4728 .70475 .46666 Mtetra
.70475 .46666 .70979 .4728 .72064 .46944 .71563 .46327 Mtetra
.71563 .46327 .72064 .46944 .73153 .46606 .72655 .45987 Mtetra
.72655 .45987 .73153 .46606 .74247 .46267 .73751 .45646 Mtetra
.73751 .45646 .74247 .46267 .75344 .45927 .74852 .45303 Mtetra
.74852 .45303 .75344 .45927 .76446 .45586 .75956 .4496 Mtetra
.75956 .4496 .76446 .45586 .77552 .45244 .77065 .44615 Mtetra
.77065 .44615 .77552 .45244 .78662 .449 .78178 .44269 Mtetra
.78178 .44269 .78662 .449 .79776 .44555 .79296 .43921 Mtetra
.79296 .43921 .79776 .44555 .80895 .44209 .80418 .43572 Mtetra
.80418 .43572 .80895 .44209 .82018 .43861 .81544 .43222 Mtetra
.81544 .43222 .82018 .43861 .83145 .43512 .82674 .42871 Mtetra
.82674 .42871 .83145 .43512 .84277 .43162 .83809 .42518 Mtetra
.83809 .42518 .84277 .43162 .85413 .4281 .84949 .42164 Mtetra
.84949 .42164 .85413 .4281 .86554 .42457 .86093 .41808 Mtetra
.86093 .41808 .86554 .42457 .87699 .42103 .87241 .41452 Mtetra
.87241 .41452 .87699 .42103 .88849 .41748 .88394 .41093 Mtetra
.88394 .41093 .88849 .41748 .90003 .41391 .89551 .40734 Mtetra
.677 .521 .667 r
.27616 .59564 .28089 .62022 .29188 .59374 .28599 .58602 Mtetra
.513 .62 .895 r
.28599 .58602 .29188 .59374 .30115 .59222 .29514 .58634 Mtetra
.613 .72 .922 r
.29514 .58634 .30115 .59222 .31048 .59029 .30448 .58441 Mtetra
.596 .715 .927 r
.30448 .58441 .31048 .59029 .31972 .59045 .31385 .58281 Mtetra
.892 .715 .655 r
.31385 .58281 .31972 .59045 .32958 .58078 .32506 .55071 Mtetra
.022 .042 .539 r
.32506 .55071 .32958 .58078 .33894 .58009 .33302 .574 Mtetra
.61 .714 .919 r
.33302 .574 .33894 .58009 .34843 .57791 .3425 .57212 Mtetra
.627 .731 .922 r
.3425 .57212 .34843 .57791 .35795 .57573 .35205 .56985 Mtetra
.607 .722 .926 r
.35205 .56985 .35795 .57573 .36744 .57522 .36161 .56798 Mtetra
.954 .664 .449 r
.36161 .56798 .36744 .57522 .37737 .56549 .36614 .67802 Mtetra
0 0 .209 r
.36614 .67802 .37737 .56549 .38692 .56508 .38109 .55888 Mtetra
.612 .714 .917 r
.38109 .55888 .38692 .56508 .39659 .56273 .39077 .55692 Mtetra
.636 .736 .921 r
.39077 .55692 .39659 .56273 .40631 .56013 .4005 .55438 Mtetra
.64 .74 .921 r
.4005 .55438 .40631 .56013 .41607 .55752 .41028 .55172 Mtetra
.636 .738 .922 r
.41028 .55172 .41607 .55752 .42586 .55518 .4201 .54916 Mtetra
.602 .72 .927 r
.4201 .54916 .42586 .55518 .4356 .55603 .42993 .54734 Mtetra
.839 .714 .725 r
.42993 .54734 .4356 .55603 .44567 .54529 .44017 .53117 Mtetra
.323 .38 .766 r
.44017 .53117 .44567 .54529 .45555 .54388 .44986 .53773 Mtetra
.627 .725 .918 r
.44986 .53773 .45555 .54388 .46548 .54122 .45981 .53537 Mtetra
.646 .743 .92 r
.45981 .53537 .46548 .54122 .47547 .53831 .46981 .53253 Mtetra
.652 .748 .92 r
.46981 .53253 .47547 .53831 .48549 .53528 .47986 .52953 Mtetra
.655 .75 .92 r
.47986 .52953 .48549 .53528 .49555 .53218 .48994 .52644 Mtetra
.657 .752 .92 r
.48994 .52644 .49555 .53218 .50564 .52903 .50006 .52328 Mtetra
.658 .753 .92 r
.50006 .52328 .50564 .52903 .51578 .52584 .51022 .52008 Mtetra
.659 .754 .92 r
.51022 .52008 .51578 .52584 .52595 .52262 .52041 .51685 Mtetra
.52041 .51685 .52595 .52262 .53616 .5194 .53065 .5136 Mtetra
.53065 .5136 .53616 .5194 .5464 .51616 .54092 .51034 Mtetra
.54092 .51034 .5464 .51616 .55668 .51292 .55123 .50708 Mtetra
.658 .753 .92 r
.55123 .50708 .55668 .51292 .56701 .50968 .56157 .50381 Mtetra
.56157 .50381 .56701 .50968 .57737 .50643 .57196 .50053 Mtetra
.57196 .50053 .57737 .50643 .58776 .50317 .58238 .49725 Mtetra
.58238 .49725 .58776 .50317 .5982 .4999 .59285 .49396 Mtetra
.59285 .49396 .5982 .4999 .60868 .49663 .60335 .49066 Mtetra
.60335 .49066 .60868 .49663 .61919 .49334 .61389 .48735 Mtetra
.657 .753 .92 r
.61389 .48735 .61919 .49334 .62975 .49005 .62447 .48403 Mtetra
.62447 .48403 .62975 .49005 .64034 .48674 .63509 .4807 Mtetra
.63509 .4807 .64034 .48674 .65097 .48342 .64575 .47735 Mtetra
.64575 .47735 .65097 .48342 .66165 .48009 .65646 .474 Mtetra
.657 .752 .92 r
.65646 .474 .66165 .48009 .67236 .47675 .6672 .47064 Mtetra
.6672 .47064 .67236 .47675 .68312 .4734 .67798 .46726 Mtetra
.67798 .46726 .68312 .4734 .69391 .47003 .68881 .46387 Mtetra
.68881 .46387 .69391 .47003 .70475 .46666 .69967 .46047 Mtetra
.69967 .46047 .70475 .46666 .71563 .46327 .71058 .45706 Mtetra
.71058 .45706 .71563 .46327 .72655 .45987 .72153 .45364 Mtetra
.72153 .45364 .72655 .45987 .73751 .45646 .73252 .4502 Mtetra
.73252 .4502 .73751 .45646 .74852 .45303 .74355 .44675 Mtetra
.74355 .44675 .74852 .45303 .75956 .4496 .75463 .44329 Mtetra
.75463 .44329 .75956 .4496 .77065 .44615 .76575 .43981 Mtetra
.76575 .43981 .77065 .44615 .78178 .44269 .77691 .43633 Mtetra
.77691 .43633 .78178 .44269 .79296 .43921 .78812 .43283 Mtetra
.78812 .43283 .79296 .43921 .80418 .43572 .79937 .42931 Mtetra
.79937 .42931 .80418 .43572 .81544 .43222 .81066 .42579 Mtetra
.81066 .42579 .81544 .43222 .82674 .42871 .822 .42225 Mtetra
.822 .42225 .82674 .42871 .83809 .42518 .83338 .41869 Mtetra
.83338 .41869 .83809 .42518 .84949 .42164 .84481 .41513 Mtetra
.84481 .41513 .84949 .42164 .86093 .41808 .85628 .41155 Mtetra
.85628 .41155 .86093 .41808 .87241 .41452 .86779 .40795 Mtetra
.86779 .40795 .87241 .41452 .88394 .41093 .87935 .40434 Mtetra
.87935 .40434 .88394 .41093 .89551 .40734 .89096 .40072 Mtetra
.879 .451 .057 r
.27015 .58872 .27616 .59564 .28599 .58602 .27801 .60675 Mtetra
0 0 0 r
.27801 .60675 .28599 .58602 .29514 .58634 .28911 .58012 Mtetra
.596 .704 .918 r
.28911 .58012 .29514 .58634 .30448 .58441 .29845 .57855 Mtetra
.613 .723 .924 r
.29845 .57855 .30448 .58441 .31385 .58281 .30785 .57658 Mtetra
.495 .666 .938 r
.30785 .57658 .31385 .58281 .32506 .55071 .31716 .57671 Mtetra
.344 .06 .331 r
.31716 .57671 .32506 .55071 .33302 .574 .32711 .56695 Mtetra
.56 .664 .907 r
.32711 .56695 .33302 .574 .3425 .57212 .33654 .56622 Mtetra
.623 .727 .921 r
.33654 .56622 .3425 .57212 .35205 .56985 .3461 .564 Mtetra
.623 .73 .923 r
.3461 .564 .35205 .56985 .36161 .56798 .3557 .56177 Mtetra
.537 .686 .935 r
.3557 .56177 .36161 .56798 .36614 .67802 .36526 .56122 Mtetra
.586 .384 .574 r
.36526 .56122 .36614 .67802 .38109 .55888 .37528 .55141 Mtetra
.548 .648 .9 r
.37528 .55141 .38109 .55888 .39077 .55692 .38491 .55096 Mtetra
.629 .73 .92 r
.38491 .55096 .39077 .55692 .4005 .55438 .39466 .54856 Mtetra
.639 .739 .921 r
.39466 .54856 .4005 .55438 .41028 .55172 .40446 .54591 Mtetra
.639 .74 .921 r
.40446 .54591 .41028 .55172 .4201 .54916 .4143 .54325 Mtetra
.627 .733 .923 r
.4143 .54325 .4201 .54916 .42993 .54734 .42416 .54086 Mtetra
.451 .641 .938 r
.42416 .54086 .42993 .54734 .44017 .53117 .43399 .54168 Mtetra
0 0 0 r
.43399 .54168 .44017 .53117 .44986 .53773 .44415 .53085 Mtetra
.589 .688 .91 r
.44415 .53085 .44986 .53773 .45981 .53537 .4541 .52939 Mtetra
.639 .737 .919 r
.4541 .52939 .45981 .53537 .46981 .53253 .46412 .52668 Mtetra
.649 .746 .92 r
.46412 .52668 .46981 .53253 .47986 .52953 .47419 .52372 Mtetra
.653 .749 .92 r
.47419 .52372 .47986 .52953 .48994 .52644 .4843 .52064 Mtetra
.656 .751 .92 r
.4843 .52064 .48994 .52644 .50006 .52328 .49444 .51748 Mtetra
.657 .753 .92 r
.49444 .51748 .50006 .52328 .51022 .52008 .50462 .51428 Mtetra
.658 .753 .92 r
.50462 .51428 .51022 .52008 .52041 .51685 .51484 .51103 Mtetra
.659 .754 .92 r
.51484 .51103 .52041 .51685 .53065 .5136 .5251 .50776 Mtetra
.5251 .50776 .53065 .5136 .54092 .51034 .5354 .50448 Mtetra
.5354 .50448 .54092 .51034 .55123 .50708 .54573 .50119 Mtetra
.54573 .50119 .55123 .50708 .56157 .50381 .5561 .49789 Mtetra
.658 .753 .92 r
.5561 .49789 .56157 .50381 .57196 .50053 .56652 .49459 Mtetra
.56652 .49459 .57196 .50053 .58238 .49725 .57697 .49129 Mtetra
.57697 .49129 .58238 .49725 .59285 .49396 .58745 .48797 Mtetra
.58745 .48797 .59285 .49396 .60335 .49066 .59798 .48465 Mtetra
.59798 .48465 .60335 .49066 .61389 .48735 .60855 .48131 Mtetra
.60855 .48131 .61389 .48735 .62447 .48403 .61916 .47797 Mtetra
.657 .753 .92 r
.61916 .47797 .62447 .48403 .63509 .4807 .62981 .47461 Mtetra
.62981 .47461 .63509 .4807 .64575 .47735 .6405 .47125 Mtetra
.6405 .47125 .64575 .47735 .65646 .474 .65123 .46787 Mtetra
.65123 .46787 .65646 .474 .6672 .47064 .662 .46448 Mtetra
.657 .752 .92 r
.662 .46448 .6672 .47064 .67798 .46726 .67281 .46108 Mtetra
.67281 .46108 .67798 .46726 .68881 .46387 .68366 .45767 Mtetra
.68366 .45767 .68881 .46387 .69967 .46047 .69456 .45424 Mtetra
.69456 .45424 .69967 .46047 .71058 .45706 .7055 .45081 Mtetra
.7055 .45081 .71058 .45706 .72153 .45364 .71647 .44736 Mtetra
.71647 .44736 .72153 .45364 .73252 .4502 .72749 .4439 Mtetra
.72749 .4439 .73252 .4502 .74355 .44675 .73856 .44042 Mtetra
.73856 .44042 .74355 .44675 .75463 .44329 .74966 .43694 Mtetra
.74966 .43694 .75463 .44329 .76575 .43981 .76081 .43344 Mtetra
.76081 .43344 .76575 .43981 .77691 .43633 .77201 .42992 Mtetra
.77201 .42992 .77691 .43633 .78812 .43283 .78324 .4264 Mtetra
.78324 .4264 .78812 .43283 .79937 .42931 .79452 .42286 Mtetra
.79452 .42286 .79937 .42931 .81066 .42579 .80585 .41931 Mtetra
.80585 .41931 .81066 .42579 .822 .42225 .81722 .41574 Mtetra
.81722 .41574 .822 .42225 .83338 .41869 .82863 .41216 Mtetra
.82863 .41216 .83338 .41869 .84481 .41513 .84009 .40857 Mtetra
.84009 .40857 .84481 .41513 .85628 .41155 .85159 .40496 Mtetra
.85159 .40496 .85628 .41155 .86779 .40795 .86314 .40134 Mtetra
.86314 .40134 .86779 .40795 .87935 .40434 .87474 .39771 Mtetra
.87474 .39771 .87935 .40434 .89096 .40072 .88638 .39406 Mtetra
.54 .688 .935 r
.26403 .5826 .27015 .58872 .27801 .60675 .27325 .582 Mtetra
.677 .521 .667 r
.27325 .582 .27801 .60675 .28911 .58012 .28316 .5723 Mtetra
.513 .62 .895 r
.28316 .5723 .28911 .58012 .29845 .57855 .29238 .57258 Mtetra
.613 .72 .922 r
.29238 .57258 .29845 .57855 .30785 .57658 .3018 .57061 Mtetra
.596 .715 .927 r
.3018 .57061 .30785 .57658 .31716 .57671 .31123 .56897 Mtetra
.893 .716 .654 r
.31123 .56897 .31716 .57671 .32711 .56695 .32256 .53668 Mtetra
.017 .037 .537 r
.32256 .53668 .32711 .56695 .33654 .56622 .33056 .56004 Mtetra
.61 .714 .919 r
.33056 .56004 .33654 .56622 .3461 .564 .34012 .55812 Mtetra
.627 .731 .922 r
.34012 .55812 .3461 .564 .3557 .56177 .34974 .55579 Mtetra
.607 .722 .926 r
.34974 .55579 .3557 .56177 .36526 .56122 .35938 .55388 Mtetra
.955 .664 .445 r
.35938 .55388 .36526 .56122 .37528 .55141 .36387 .66439 Mtetra
0 0 .202 r
.36387 .66439 .37528 .55141 .38491 .55096 .37902 .54466 Mtetra
.612 .714 .917 r
.37902 .54466 .38491 .55096 .39466 .54856 .38878 .54266 Mtetra
.636 .736 .921 r
.38878 .54266 .39466 .54856 .40446 .54591 .39859 .54006 Mtetra
.64 .74 .921 r
.39859 .54006 .40446 .54591 .4143 .54325 .40845 .53736 Mtetra
.636 .738 .922 r
.40845 .53736 .4143 .54325 .42416 .54086 .41835 .53475 Mtetra
.602 .72 .927 r
.41835 .53475 .42416 .54086 .43399 .54168 .42826 .53288 Mtetra
.84 .714 .725 r
.42826 .53288 .43399 .54168 .44415 .53085 .43859 .5166 Mtetra
.321 .379 .766 r
.43859 .5166 .44415 .53085 .4541 .52939 .44836 .52315 Mtetra
.627 .725 .918 r
.44836 .52315 .4541 .52939 .46412 .52668 .45839 .52074 Mtetra
.646 .743 .92 r
.45839 .52074 .46412 .52668 .47419 .52372 .46848 .51784 Mtetra
.652 .748 .92 r
.46848 .51784 .47419 .52372 .4843 .52064 .47861 .51479 Mtetra
.655 .75 .92 r
.47861 .51479 .4843 .52064 .49444 .51748 .48878 .51164 Mtetra
.657 .752 .92 r
.48878 .51164 .49444 .51748 .50462 .51428 .49899 .50843 Mtetra
.658 .753 .92 r
.49899 .50843 .50462 .51428 .51484 .51103 .50923 .50517 Mtetra
.659 .754 .92 r
.50923 .50517 .51484 .51103 .5251 .50776 .51952 .50188 Mtetra
.51952 .50188 .5251 .50776 .5354 .50448 .52984 .49858 Mtetra
.52984 .49858 .5354 .50448 .54573 .50119 .5402 .49526 Mtetra
.5402 .49526 .54573 .50119 .5561 .49789 .5506 .49194 Mtetra
.658 .753 .92 r
.5506 .49194 .5561 .49789 .56652 .49459 .56103 .48861 Mtetra
.56103 .48861 .56652 .49459 .57697 .49129 .57151 .48528 Mtetra
.57151 .48528 .57697 .49129 .58745 .48797 .58203 .48194 Mtetra
.58203 .48194 .58745 .48797 .59798 .48465 .59258 .47859 Mtetra
.59258 .47859 .59798 .48465 .60855 .48131 .60318 .47523 Mtetra
.60318 .47523 .60855 .48131 .61916 .47797 .61381 .47186 Mtetra
.657 .753 .92 r
.61381 .47186 .61916 .47797 .62981 .47461 .62449 .46848 Mtetra
.62449 .46848 .62981 .47461 .6405 .47125 .63521 .46509 Mtetra
.63521 .46509 .6405 .47125 .65123 .46787 .64596 .46169 Mtetra
.64596 .46169 .65123 .46787 .662 .46448 .65676 .45828 Mtetra
.657 .752 .92 r
.65676 .45828 .662 .46448 .67281 .46108 .6676 .45485 Mtetra
.6676 .45485 .67281 .46108 .68366 .45767 .67848 .45142 Mtetra
.67848 .45142 .68366 .45767 .69456 .45424 .68941 .44797 Mtetra
.68941 .44797 .69456 .45424 .7055 .45081 .70037 .44451 Mtetra
.70037 .44451 .7055 .45081 .71647 .44736 .71138 .44103 Mtetra
.71138 .44103 .71647 .44736 .72749 .4439 .72243 .43755 Mtetra
.72243 .43755 .72749 .4439 .73856 .44042 .73353 .43405 Mtetra
.73353 .43405 .73856 .44042 .74966 .43694 .74466 .43054 Mtetra
.74466 .43054 .74966 .43694 .76081 .43344 .75584 .42701 Mtetra
.75584 .42701 .76081 .43344 .77201 .42992 .76707 .42347 Mtetra
.76707 .42347 .77201 .42992 .78324 .4264 .77833 .41992 Mtetra
.77833 .41992 .78324 .4264 .79452 .42286 .78965 .41636 Mtetra
.78965 .41636 .79452 .42286 .80585 .41931 .801 .41278 Mtetra
.801 .41278 .80585 .41931 .81722 .41574 .8124 .40919 Mtetra
.8124 .40919 .81722 .41574 .82863 .41216 .82385 .40558 Mtetra
.82385 .40558 .82863 .41216 .84009 .40857 .83534 .40196 Mtetra
.83534 .40196 .84009 .40857 .85159 .40496 .84688 .39833 Mtetra
.84688 .39833 .85159 .40496 .86314 .40134 .85846 .39468 Mtetra
.85846 .39468 .86314 .40134 .87474 .39771 .87009 .39102 Mtetra
.87009 .39102 .87474 .39771 .88638 .39406 .88176 .38734 Mtetra
.596 .714 .926 r
.25787 .57662 .26403 .5826 .27325 .582 .26718 .57498 Mtetra
.877 .447 .05 r
.26718 .57498 .27325 .582 .28316 .5723 .27508 .59305 Mtetra
0 0 0 r
.27508 .59305 .28316 .5723 .29238 .57258 .28629 .56626 Mtetra
.596 .704 .918 r
.28629 .56626 .29238 .57258 .3018 .57061 .2957 .56465 Mtetra
.613 .723 .924 r
.2957 .56465 .3018 .57061 .31123 .56897 .30518 .56264 Mtetra
.495 .666 .938 r
.30518 .56264 .31123 .56897 .32256 .53668 .31456 .56273 Mtetra
.337 .051 .323 r
.31456 .56273 .32256 .53668 .33056 .56004 .32459 .55289 Mtetra
.559 .664 .907 r
.32459 .55289 .33056 .56004 .34012 .55812 .3341 .55212 Mtetra
.623 .727 .921 r
.3341 .55212 .34012 .55812 .34974 .55579 .34374 .54985 Mtetra
.623 .729 .923 r
.34374 .54985 .34974 .55579 .35938 .55388 .35341 .54757 Mtetra
.537 .686 .935 r
.35341 .54757 .35938 .55388 .36387 .66439 .36305 .54699 Mtetra
.584 .381 .572 r
.36305 .54699 .36387 .66439 .37902 .54466 .37315 .53709 Mtetra
.548 .648 .9 r
.37315 .53709 .37902 .54466 .38878 .54266 .38286 .5366 Mtetra
.629 .73 .92 r
.38286 .5366 .38878 .54266 .39859 .54006 .39269 .53415 Mtetra
.639 .739 .921 r
.39269 .53415 .39859 .54006 .40845 .53736 .40257 .53145 Mtetra
.639 .74 .921 r
.40257 .53145 .40845 .53736 .41835 .53475 .41249 .52874 Mtetra
.627 .733 .923 r
.41249 .52874 .41835 .53475 .42826 .53288 .42244 .52629 Mtetra
.452 .641 .938 r
.42244 .52629 .42826 .53288 .43859 .5166 .43234 .52708 Mtetra
0 0 0 r
.43234 .52708 .43859 .5166 .44836 .52315 .44259 .51616 Mtetra
.589 .688 .91 r
.44259 .51616 .44836 .52315 .45839 .52074 .45263 .51465 Mtetra
.639 .737 .919 r
.45263 .51465 .45839 .52074 .46848 .51784 .46274 .51189 Mtetra
.649 .746 .92 r
.46274 .51189 .46848 .51784 .47861 .51479 .47289 .50887 Mtetra
.653 .749 .92 r
.47289 .50887 .47861 .51479 .48878 .51164 .48308 .50574 Mtetra
.656 .751 .92 r
.48308 .50574 .48878 .51164 .49899 .50843 .49331 .50253 Mtetra
.657 .753 .92 r
.49331 .50253 .49899 .50843 .50923 .50517 .50358 .49927 Mtetra
.658 .753 .92 r
.50358 .49927 .50923 .50517 .51952 .50188 .51389 .49596 Mtetra
.659 .754 .92 r
.51389 .49596 .51952 .50188 .52984 .49858 .52424 .49264 Mtetra
.52424 .49264 .52984 .49858 .5402 .49526 .53462 .4893 Mtetra
.53462 .4893 .5402 .49526 .5506 .49194 .54505 .48595 Mtetra
.54505 .48595 .5506 .49194 .56103 .48861 .55551 .4826 Mtetra
.658 .753 .92 r
.55551 .4826 .56103 .48861 .57151 .48528 .56602 .47924 Mtetra
.56602 .47924 .57151 .48528 .58203 .48194 .57656 .47587 Mtetra
.57656 .47587 .58203 .48194 .59258 .47859 .58714 .4725 Mtetra
.58714 .4725 .59258 .47859 .60318 .47523 .59776 .46911 Mtetra
.59776 .46911 .60318 .47523 .61381 .47186 .60843 .46572 Mtetra
.60843 .46572 .61381 .47186 .62449 .46848 .61913 .46232 Mtetra
.657 .753 .92 r
.61913 .46232 .62449 .46848 .63521 .46509 .62987 .4589 Mtetra
.62987 .4589 .63521 .46509 .64596 .46169 .64066 .45547 Mtetra
.64066 .45547 .64596 .46169 .65676 .45828 .65149 .45204 Mtetra
.65149 .45204 .65676 .45828 .6676 .45485 .66236 .44859 Mtetra
.657 .752 .92 r
.66236 .44859 .6676 .45485 .67848 .45142 .67327 .44512 Mtetra
.67327 .44512 .67848 .45142 .68941 .44797 .68422 .44165 Mtetra
.68422 .44165 .68941 .44797 .70037 .44451 .69521 .43816 Mtetra
.69521 .43816 .70037 .44451 .71138 .44103 .70625 .43466 Mtetra
.70625 .43466 .71138 .44103 .72243 .43755 .71733 .43115 Mtetra
.71733 .43115 .72243 .43755 .73353 .43405 .72846 .42763 Mtetra
.72846 .42763 .73353 .43405 .74466 .43054 .73962 .42409 Mtetra
.73962 .42409 .74466 .43054 .75584 .42701 .75084 .42054 Mtetra
.75084 .42054 .75584 .42701 .76707 .42347 .76209 .41698 Mtetra
.76209 .41698 .76707 .42347 .77833 .41992 .77339 .4134 Mtetra
.77339 .4134 .77833 .41992 .78965 .41636 .78473 .40981 Mtetra
.78473 .40981 .78965 .41636 .801 .41278 .79612 .4062 Mtetra
.79612 .4062 .801 .41278 .8124 .40919 .80755 .40258 Mtetra
.80755 .40258 .8124 .40919 .82385 .40558 .81903 .39895 Mtetra
.81903 .39895 .82385 .40558 .83534 .40196 .83056 .39531 Mtetra
.83056 .39531 .83534 .40196 .84688 .39833 .84212 .39165 Mtetra
.84212 .39165 .84688 .39833 .85846 .39468 .85374 .38797 Mtetra
.85374 .38797 .85846 .39468 .87009 .39102 .8654 .38428 Mtetra
.8654 .38428 .87009 .39102 .88176 .38734 .87711 .38058 Mtetra
.603 .714 .923 r
.25167 .57055 .25787 .57662 .26718 .57498 .261 .56877 Mtetra
.54 .688 .935 r
.261 .56877 .26718 .57498 .27508 .59305 .27029 .56812 Mtetra
.676 .52 .666 r
.27029 .56812 .27508 .59305 .28629 .56626 .28028 .55834 Mtetra
.513 .62 .895 r
.28028 .55834 .28629 .56626 .2957 .56465 .28957 .55859 Mtetra
.613 .72 .922 r
.28957 .55859 .2957 .56465 .30518 .56264 .29906 .55657 Mtetra
.596 .715 .927 r
.29906 .55657 .30518 .56264 .31456 .56273 .30857 .55488 Mtetra
.894 .716 .653 r
.30857 .55488 .31456 .56273 .32459 .55289 .32001 .52242 Mtetra
.011 .033 .534 r
.32001 .52242 .32459 .55289 .3341 .55212 .32805 .54584 Mtetra
.61 .714 .919 r
.32805 .54584 .3341 .55212 .34374 .54985 .33769 .54387 Mtetra
.627 .731 .922 r
.33769 .54387 .34374 .54985 .35341 .54757 .34739 .54149 Mtetra
.607 .722 .926 r
.34739 .54149 .35341 .54757 .36305 .54699 .35711 .53953 Mtetra
.955 .663 .442 r
.35711 .53953 .36305 .54699 .37315 .53709 .36156 .65052 Mtetra
0 0 .195 r
.36156 .65052 .37315 .53709 .38286 .5366 .37692 .5302 Mtetra
.612 .714 .917 r
.37692 .5302 .38286 .5366 .39269 .53415 .38675 .52815 Mtetra
.636 .736 .921 r
.38675 .52815 .39269 .53415 .40257 .53145 .39665 .5255 Mtetra
.64 .74 .921 r
.39665 .5255 .40257 .53145 .41249 .52874 .40659 .52274 Mtetra
.636 .738 .922 r
.40659 .52274 .41249 .52874 .42244 .52629 .41657 .52008 Mtetra
.602 .72 .927 r
.41657 .52008 .42244 .52629 .43234 .52708 .42656 .51816 Mtetra
.841 .715 .725 r
.42656 .51816 .43234 .52708 .44259 .51616 .43699 .50177 Mtetra
.319 .378 .766 r
.43699 .50177 .44259 .51616 .45263 .51465 .44683 .50831 Mtetra
.627 .725 .918 r
.44683 .50831 .45263 .51465 .46274 .51189 .45695 .50585 Mtetra
.646 .743 .92 r
.45695 .50585 .46274 .51189 .47289 .50887 .46713 .5029 Mtetra
.652 .748 .92 r
.46713 .5029 .47289 .50887 .48308 .50574 .47734 .49978 Mtetra
.655 .75 .92 r
.47734 .49978 .48308 .50574 .49331 .50253 .4876 .49658 Mtetra
.657 .752 .92 r
.4876 .49658 .49331 .50253 .50358 .49927 .49789 .49331 Mtetra
.658 .753 .92 r
.49789 .49331 .50358 .49927 .51389 .49596 .50823 .49 Mtetra
.659 .754 .92 r
.50823 .49 .51389 .49596 .52424 .49264 .5186 .48665 Mtetra
.5186 .48665 .52424 .49264 .53462 .4893 .52901 .48329 Mtetra
.52901 .48329 .53462 .4893 .54505 .48595 .53946 .47992 Mtetra
.53946 .47992 .54505 .48595 .55551 .4826 .54995 .47654 Mtetra
.658 .753 .92 r
.54995 .47654 .55551 .4826 .56602 .47924 .56048 .47315 Mtetra
.56048 .47315 .56602 .47924 .57656 .47587 .57105 .46976 Mtetra
.57105 .46976 .57656 .47587 .58714 .4725 .58166 .46636 Mtetra
.58166 .46636 .58714 .4725 .59776 .46911 .59231 .46295 Mtetra
.59231 .46295 .59776 .46911 .60843 .46572 .603 .45953 Mtetra
.603 .45953 .60843 .46572 .61913 .46232 .61373 .4561 Mtetra
.657 .753 .92 r
.61373 .4561 .61913 .46232 .62987 .4589 .62451 .45266 Mtetra
.62451 .45266 .62987 .4589 .64066 .45547 .63532 .44921 Mtetra
.63532 .44921 .64066 .45547 .65149 .45204 .64618 .44575 Mtetra
.64618 .44575 .65149 .45204 .66236 .44859 .65707 .44227 Mtetra
.657 .752 .92 r
.65707 .44227 .66236 .44859 .67327 .44512 .66801 .43879 Mtetra
.66801 .43879 .67327 .44512 .68422 .44165 .67899 .43529 Mtetra
.67899 .43529 .68422 .44165 .69521 .43816 .69002 .43177 Mtetra
.69002 .43177 .69521 .43816 .70625 .43466 .70109 .42825 Mtetra
.70109 .42825 .70625 .43466 .71733 .43115 .7122 .42471 Mtetra
.7122 .42471 .71733 .43115 .72846 .42763 .72335 .42116 Mtetra
.72335 .42116 .72846 .42763 .73962 .42409 .73455 .4176 Mtetra
.73455 .4176 .73962 .42409 .75084 .42054 .74579 .41402 Mtetra
.74579 .41402 .75084 .42054 .76209 .41698 .75708 .41043 Mtetra
.75708 .41043 .76209 .41698 .77339 .4134 .76841 .40683 Mtetra
.76841 .40683 .77339 .4134 .78473 .40981 .77978 .40321 Mtetra
.77978 .40321 .78473 .40981 .79612 .4062 .7912 .39958 Mtetra
.7912 .39958 .79612 .4062 .80755 .40258 .80267 .39593 Mtetra
.80267 .39593 .80755 .40258 .81903 .39895 .81418 .39228 Mtetra
.81418 .39228 .81903 .39895 .83056 .39531 .82574 .3886 Mtetra
.82574 .3886 .83056 .39531 .84212 .39165 .83734 .38492 Mtetra
.83734 .38492 .84212 .39165 .85374 .38797 .84899 .38121 Mtetra
.84899 .38121 .85374 .38797 .8654 .38428 .86068 .3775 Mtetra
.86068 .3775 .8654 .38428 .87711 .38058 .87243 .37377 Mtetra
.585 .696 .918 r
.24546 .56408 .25167 .57055 .261 .56877 .25477 .56269 Mtetra
.596 .714 .926 r
.25477 .56269 .261 .56877 .27029 .56812 .26415 .561 Mtetra
.874 .443 .042 r
.26415 .561 .27029 .56812 .28028 .55834 .2721 .57912 Mtetra
0 0 0 r
.2721 .57912 .28028 .55834 .28957 .55859 .28342 .55217 Mtetra
.596 .704 .919 r
.28342 .55217 .28957 .55859 .29906 .55657 .2929 .55052 Mtetra
.613 .723 .924 r
.2929 .55052 .29906 .55657 .30857 .55488 .30246 .54846 Mtetra
.496 .666 .938 r
.30246 .54846 .30857 .55488 .32001 .52242 .31192 .5485 Mtetra
.33 .042 .316 r
.31192 .5485 .32001 .52242 .32805 .54584 .32203 .53859 Mtetra
.559 .664 .907 r
.32203 .53859 .32805 .54584 .33769 .54387 .33161 .53777 Mtetra
.623 .727 .921 r
.33161 .53777 .33769 .54387 .34739 .54149 .34133 .53546 Mtetra
.623 .729 .923 r
.34133 .53546 .34739 .54149 .35711 .53953 .35109 .53313 Mtetra
.537 .686 .935 r
.35109 .53313 .35711 .53953 .36156 .65052 .3608 .5325 Mtetra
.582 .379 .571 r
.3608 .5325 .36156 .65052 .37692 .5302 .37099 .52252 Mtetra
.547 .648 .901 r
.37099 .52252 .37692 .5302 .38675 .52815 .38078 .52199 Mtetra
.629 .73 .92 r
.38078 .52199 .38675 .52815 .39665 .5255 .39069 .51949 Mtetra
.639 .739 .921 r
.39069 .51949 .39665 .5255 .40659 .52274 .40065 .51673 Mtetra
.639 .74 .921 r
.40065 .51673 .40659 .52274 .41657 .52008 .41065 .51397 Mtetra
.627 .733 .923 r
.41065 .51397 .41657 .52008 .42656 .51816 .42069 .51147 Mtetra
.452 .641 .938 r
.42069 .51147 .42656 .51816 .43699 .50177 .43067 .51222 Mtetra
0 0 0 r
.43067 .51222 .43699 .50177 .44683 .50831 .44101 .50121 Mtetra
.589 .688 .91 r
.44101 .50121 .44683 .50831 .45695 .50585 .45113 .49966 Mtetra
.639 .737 .919 r
.45113 .49966 .45695 .50585 .46713 .5029 .46133 .49684 Mtetra
.649 .746 .92 r
.46133 .49684 .46713 .5029 .47734 .49978 .47157 .49377 Mtetra
.653 .749 .92 r
.47157 .49377 .47734 .49978 .4876 .49658 .48185 .49058 Mtetra
.656 .751 .92 r
.48185 .49058 .4876 .49658 .49789 .49331 .49217 .48731 Mtetra
.657 .753 .92 r
.49217 .48731 .49789 .49331 .50823 .49 .50253 .48399 Mtetra
.658 .753 .92 r
.50253 .48399 .50823 .49 .5186 .48665 .51292 .48063 Mtetra
.659 .754 .92 r
.51292 .48063 .5186 .48665 .52901 .48329 .52336 .47724 Mtetra
.52336 .47724 .52901 .48329 .53946 .47992 .53384 .47384 Mtetra
.53384 .47384 .53946 .47992 .54995 .47654 .54435 .47044 Mtetra
.54435 .47044 .54995 .47654 .56048 .47315 .55491 .46702 Mtetra
.658 .753 .92 r
.55491 .46702 .56048 .47315 .57105 .46976 .56551 .4636 Mtetra
.56551 .4636 .57105 .46976 .58166 .46636 .57614 .46018 Mtetra
.57614 .46018 .58166 .46636 .59231 .46295 .58682 .45674 Mtetra
.58682 .45674 .59231 .46295 .603 .45953 .59754 .4533 Mtetra
.59754 .4533 .603 .45953 .61373 .4561 .6083 .44984 Mtetra
.6083 .44984 .61373 .4561 .62451 .45266 .6191 .44638 Mtetra
.657 .753 .92 r
.6191 .44638 .62451 .45266 .63532 .44921 .62994 .4429 Mtetra
.62994 .4429 .63532 .44921 .64618 .44575 .64083 .43941 Mtetra
.64083 .43941 .64618 .44575 .65707 .44227 .65175 .43591 Mtetra
.65175 .43591 .65707 .44227 .66801 .43879 .66272 .4324 Mtetra
.657 .752 .92 r
.66272 .4324 .66801 .43879 .67899 .43529 .67373 .42888 Mtetra
.67373 .42888 .67899 .43529 .69002 .43177 .68479 .42534 Mtetra
.68479 .42534 .69002 .43177 .70109 .42825 .69588 .42179 Mtetra
.69588 .42179 .70109 .42825 .7122 .42471 .70702 .41822 Mtetra
.70702 .41822 .7122 .42471 .72335 .42116 .71821 .41465 Mtetra
.71821 .41465 .72335 .42116 .73455 .4176 .72944 .41106 Mtetra
.72944 .41106 .73455 .4176 .74579 .41402 .74071 .40746 Mtetra
.74071 .40746 .74579 .41402 .75708 .41043 .75203 .40384 Mtetra
.75203 .40384 .75708 .41043 .76841 .40683 .76339 .40021 Mtetra
.76339 .40021 .76841 .40683 .77978 .40321 .7748 .39656 Mtetra
.7748 .39656 .77978 .40321 .7912 .39958 .78625 .39291 Mtetra
.78625 .39291 .7912 .39958 .80267 .39593 .79775 .38924 Mtetra
.79775 .38924 .80267 .39593 .81418 .39228 .80929 .38555 Mtetra
.80929 .38555 .81418 .39228 .82574 .3886 .82088 .38185 Mtetra
.82088 .38185 .82574 .3886 .83734 .38492 .83252 .37813 Mtetra
.83252 .37813 .83734 .38492 .84899 .38121 .8442 .37441 Mtetra
.8442 .37441 .84899 .38121 .86068 .3775 .85593 .37066 Mtetra
.85593 .37066 .86068 .3775 .87243 .37377 .8677 .3669 Mtetra
.471 .581 .883 r
.2394 .55543 .24546 .56408 .25477 .56269 .24851 .55652 Mtetra
.603 .714 .923 r
.24851 .55652 .25477 .56269 .26415 .561 .25791 .55469 Mtetra
.541 .688 .934 r
.25791 .55469 .26415 .561 .2721 .57912 .26727 .55401 Mtetra
.676 .519 .666 r
.26727 .55401 .2721 .57912 .28342 .55217 .27735 .54415 Mtetra
.512 .62 .895 r
.27735 .54415 .28342 .55217 .2929 .55052 .28671 .54436 Mtetra
.613 .72 .922 r
.28671 .54436 .2929 .55052 .30246 .54846 .29628 .54229 Mtetra
.596 .715 .927 r
.29628 .54229 .30246 .54846 .31192 .5485 .30587 .54055 Mtetra
.895 .717 .653 r
.30587 .54055 .31192 .5485 .32203 .53859 .31742 .50792 Mtetra
.006 .029 .532 r
.31742 .50792 .32203 .53859 .33161 .53777 .32551 .53139 Mtetra
.61 .714 .919 r
.32551 .53139 .33161 .53777 .34133 .53546 .33523 .52938 Mtetra
.627 .731 .922 r
.33523 .52938 .34133 .53546 .35109 .53313 .34501 .52695 Mtetra
.607 .721 .926 r
.34501 .52695 .35109 .53313 .3608 .5325 .3548 .52494 Mtetra
.956 .663 .439 r
.3548 .52494 .3608 .5325 .37099 .52252 .35921 .6364 Mtetra
0 0 .188 r
.35921 .6364 .37099 .52252 .38078 .52199 .37477 .51548 Mtetra
.612 .714 .917 r
.37477 .51548 .38078 .52199 .39069 .51949 .38469 .51338 Mtetra
.636 .736 .921 r
.38469 .51338 .39069 .51949 .40065 .51673 .39467 .51068 Mtetra
.64 .74 .921 r
.39467 .51068 .40065 .51673 .41065 .51397 .4047 .50787 Mtetra
.636 .738 .922 r
.4047 .50787 .41065 .51397 .42069 .51147 .41476 .50515 Mtetra
.602 .72 .927 r
.41476 .50515 .42069 .51147 .43067 .51222 .42484 .50319 Mtetra
.842 .716 .725 r
.42484 .50319 .43067 .51222 .44101 .50121 .43536 .48669 Mtetra
.317 .377 .766 r
.43536 .48669 .44101 .50121 .45113 .49966 .44528 .49321 Mtetra
.627 .725 .918 r
.44528 .49321 .45113 .49966 .46133 .49684 .45549 .49069 Mtetra
.646 .743 .92 r
.45549 .49069 .46133 .49684 .47157 .49377 .46575 .48768 Mtetra
.652 .748 .92 r
.46575 .48768 .47157 .49377 .48185 .49058 .47605 .48451 Mtetra
.655 .75 .92 r
.47605 .48451 .48185 .49058 .49217 .48731 .4864 .48125 Mtetra
.657 .752 .92 r
.4864 .48125 .49217 .48731 .50253 .48399 .49678 .47793 Mtetra
.658 .753 .92 r
.49678 .47793 .50253 .48399 .51292 .48063 .50721 .47455 Mtetra
.659 .754 .92 r
.50721 .47455 .51292 .48063 .52336 .47724 .51767 .47115 Mtetra
.51767 .47115 .52336 .47724 .53384 .47384 .52817 .46773 Mtetra
.52817 .46773 .53384 .47384 .54435 .47044 .53872 .46429 Mtetra
.53872 .46429 .54435 .47044 .55491 .46702 .5493 .46085 Mtetra
.658 .753 .92 r
.5493 .46085 .55491 .46702 .56551 .4636 .55992 .45741 Mtetra
.55992 .45741 .56551 .4636 .57614 .46018 .57059 .45396 Mtetra
.57059 .45396 .57614 .46018 .58682 .45674 .58129 .45049 Mtetra
.58129 .45049 .58682 .45674 .59754 .4533 .59204 .44702 Mtetra
.59204 .44702 .59754 .4533 .6083 .44984 .60282 .44354 Mtetra
.60282 .44354 .6083 .44984 .6191 .44638 .61365 .44005 Mtetra
.657 .753 .92 r
.61365 .44005 .6191 .44638 .62994 .4429 .62452 .43655 Mtetra
.62452 .43655 .62994 .4429 .64083 .43941 .63544 .43304 Mtetra
.63544 .43304 .64083 .43941 .65175 .43591 .64639 .42951 Mtetra
.64639 .42951 .65175 .43591 .66272 .4324 .65739 .42597 Mtetra
.657 .752 .92 r
.65739 .42597 .66272 .4324 .67373 .42888 .66843 .42242 Mtetra
.66843 .42242 .67373 .42888 .68479 .42534 .67951 .41886 Mtetra
.67951 .41886 .68479 .42534 .69588 .42179 .69064 .41528 Mtetra
.69064 .41528 .69588 .42179 .70702 .41822 .70181 .41169 Mtetra
.70181 .41169 .70702 .41822 .71821 .41465 .71303 .40809 Mtetra
.71303 .40809 .71821 .41465 .72944 .41106 .72429 .40447 Mtetra
.72429 .40447 .72944 .41106 .74071 .40746 .73559 .40084 Mtetra
.73559 .40084 .74071 .40746 .75203 .40384 .74694 .3972 Mtetra
.74694 .3972 .75203 .40384 .76339 .40021 .75833 .39354 Mtetra
.75833 .39354 .76339 .40021 .7748 .39656 .76977 .38987 Mtetra
.76977 .38987 .7748 .39656 .78625 .39291 .78126 .38619 Mtetra
.78126 .38619 .78625 .39291 .79775 .38924 .79279 .38249 Mtetra
.79279 .38249 .79775 .38924 .80929 .38555 .80436 .37877 Mtetra
.80436 .37877 .80929 .38555 .82088 .38185 .81599 .37505 Mtetra
.81599 .37505 .82088 .38185 .83252 .37813 .82766 .3713 Mtetra
.82766 .3713 .83252 .37813 .8442 .37441 .83937 .36755 Mtetra
.83937 .36755 .8442 .37441 .85593 .37066 .85114 .36378 Mtetra
.85114 .36378 .85593 .37066 .8677 .3669 .86295 .35999 Mtetra
.684 .865 .468 r
.2316 .56633 .2394 .55543 .24851 .55652 .24224 .54995 Mtetra
.585 .696 .919 r
.24224 .54995 .24851 .55652 .25791 .55469 .25162 .54852 Mtetra
.596 .714 .926 r
.25162 .54852 .25791 .55469 .26727 .55401 .26108 .54679 Mtetra
.871 .44 .034 r
.26108 .54679 .26727 .55401 .27735 .54415 .26907 .56494 Mtetra
0 0 0 r
.26907 .56494 .27735 .54415 .28671 .54436 .2805 .53784 Mtetra
.596 .704 .919 r
.2805 .53784 .28671 .54436 .29628 .54229 .29006 .53614 Mtetra
.613 .723 .924 r
.29006 .53614 .29628 .54229 .30587 .54055 .29969 .53403 Mtetra
.496 .666 .938 r
.29969 .53403 .30587 .54055 .31742 .50792 .30922 .53404 Mtetra
.322 .033 .308 r
.30922 .53404 .31742 .50792 .32551 .53139 .31942 .52404 Mtetra
.559 .664 .908 r
.31942 .52404 .32551 .53139 .33523 .52938 .32909 .52318 Mtetra
.623 .727 .921 r
.32909 .52318 .33523 .52938 .34501 .52695 .33888 .52081 Mtetra
.623 .729 .923 r
.33888 .52081 .34501 .52695 .3548 .52494 .34872 .51843 Mtetra
.537 .686 .935 r
.34872 .51843 .3548 .52494 .35921 .6364 .35851 .51776 Mtetra
.58 .376 .569 r
.35851 .51776 .35921 .6364 .37477 .51548 .36879 .50769 Mtetra
.547 .648 .901 r
.36879 .50769 .37477 .51548 .38469 .51338 .37866 .50712 Mtetra
.629 .73 .92 r
.37866 .50712 .38469 .51338 .39467 .51068 .38865 .50457 Mtetra
.639 .739 .921 r
.38865 .50457 .39467 .51068 .4047 .50787 .3987 .50176 Mtetra
.639 .74 .921 r
.3987 .50176 .4047 .50787 .41476 .50515 .40878 .49894 Mtetra
.627 .733 .923 r
.40878 .49894 .41476 .50515 .42484 .50319 .4189 .49639 Mtetra
.453 .641 .938 r
.4189 .49639 .42484 .50319 .43536 .48669 .42897 .4971 Mtetra
0 0 0 r
.42897 .4971 .43536 .48669 .44528 .49321 .4394 .486 Mtetra
.589 .688 .91 r
.4394 .486 .44528 .49321 .45549 .49069 .44961 .48439 Mtetra
.639 .737 .919 r
.44961 .48439 .45549 .49069 .46575 .48768 .45989 .48152 Mtetra
.649 .746 .92 r
.45989 .48152 .46575 .48768 .47605 .48451 .47022 .47839 Mtetra
.653 .749 .92 r
.47022 .47839 .47605 .48451 .4864 .48125 .48059 .47514 Mtetra
.656 .751 .92 r
.48059 .47514 .4864 .48125 .49678 .47793 .491 .47182 Mtetra
.657 .753 .92 r
.491 .47182 .49678 .47793 .50721 .47455 .50145 .46843 Mtetra
.658 .753 .92 r
.50145 .46843 .50721 .47455 .51767 .47115 .51194 .46501 Mtetra
.659 .754 .92 r
.51194 .46501 .51767 .47115 .52817 .46773 .52247 .46157 Mtetra
.52247 .46157 .52817 .46773 .53872 .46429 .53304 .45811 Mtetra
.53304 .45811 .53872 .46429 .5493 .46085 .54365 .45464 Mtetra
.54365 .45464 .5493 .46085 .55992 .45741 .5543 .45117 Mtetra
.658 .753 .92 r
.5543 .45117 .55992 .45741 .57059 .45396 .56499 .44769 Mtetra
.56499 .44769 .57059 .45396 .58129 .45049 .57572 .4442 Mtetra
.57572 .4442 .58129 .45049 .59204 .44702 .5865 .4407 Mtetra
.5865 .4407 .59204 .44702 .60282 .44354 .59731 .4372 Mtetra
.59731 .4372 .60282 .44354 .61365 .44005 .60817 .43368 Mtetra
.60817 .43368 .61365 .44005 .62452 .43655 .61907 .43015 Mtetra
.657 .753 .92 r
.61907 .43015 .62452 .43655 .63544 .43304 .63001 .42661 Mtetra
.63001 .42661 .63544 .43304 .64639 .42951 .64099 .42306 Mtetra
.64099 .42306 .64639 .42951 .65739 .42597 .65202 .41949 Mtetra
.65202 .41949 .65739 .42597 .66843 .42242 .66309 .41592 Mtetra
.657 .752 .92 r
.66309 .41592 .66843 .42242 .67951 .41886 .67421 .41233 Mtetra
.67421 .41233 .67951 .41886 .69064 .41528 .68536 .40872 Mtetra
.68536 .40872 .69064 .41528 .70181 .41169 .69656 .40511 Mtetra
.69656 .40511 .70181 .41169 .71303 .40809 .70781 .40148 Mtetra
.70781 .40148 .71303 .40809 .72429 .40447 .7191 .39784 Mtetra
.7191 .39784 .72429 .40447 .73559 .40084 .73044 .39418 Mtetra
.73044 .39418 .73559 .40084 .74694 .3972 .74182 .39051 Mtetra
.74182 .39051 .74694 .3972 .75833 .39354 .75324 .38683 Mtetra
.75324 .38683 .75833 .39354 .76977 .38987 .76471 .38313 Mtetra
.76471 .38313 .76977 .38987 .78126 .38619 .77623 .37941 Mtetra
.77623 .37941 .78126 .38619 .79279 .38249 .78779 .37569 Mtetra
.78779 .37569 .79279 .38249 .80436 .37877 .7994 .37195 Mtetra
.7994 .37195 .80436 .37877 .81599 .37505 .81106 .36819 Mtetra
.81106 .36819 .81599 .37505 .82766 .3713 .82276 .36442 Mtetra
.82276 .36442 .82766 .3713 .83937 .36755 .83451 .36064 Mtetra
.83451 .36064 .83937 .36755 .85114 .36378 .84631 .35684 Mtetra
.84631 .35684 .85114 .36378 .86295 .35999 .85816 .35302 Mtetra
.733 .607 .717 r
.22598 .5515 .2316 .56633 .24224 .54995 .23611 .54119 Mtetra
.471 .581 .883 r
.23611 .54119 .24224 .54995 .25162 .54852 .2453 .54225 Mtetra
.603 .714 .923 r
.2453 .54225 .25162 .54852 .26108 .54679 .25478 .54038 Mtetra
.541 .688 .934 r
.25478 .54038 .26108 .54679 .26907 .56494 .26421 .53965 Mtetra
.676 .519 .665 r
.26421 .53965 .26907 .56494 .2805 .53784 .27437 .52971 Mtetra
.512 .62 .895 r
.27437 .52971 .2805 .53784 .29006 .53614 .28381 .52988 Mtetra
.613 .72 .922 r
.28381 .52988 .29006 .53614 .29969 .53403 .29345 .52776 Mtetra
.596 .715 .927 r
.29345 .52776 .29969 .53403 .30922 .53404 .30312 .52598 Mtetra
.896 .718 .652 r
.30312 .52598 .30922 .53404 .31942 .52404 .31479 .49316 Mtetra
0 .024 .529 r
.31479 .49316 .31942 .52404 .32909 .52318 .32292 .5167 Mtetra
.61 .714 .919 r
.32292 .5167 .32909 .52318 .33888 .52081 .33272 .51463 Mtetra
.627 .731 .922 r
.33272 .51463 .33888 .52081 .34872 .51843 .34258 .51215 Mtetra
.607 .721 .926 r
.34258 .51215 .34872 .51843 .35851 .51776 .35246 .51009 Mtetra
.957 .663 .435 r
.35246 .51009 .35851 .51776 .36879 .50769 .35682 .62202 Mtetra
0 0 .182 r
.35682 .62202 .36879 .50769 .37866 .50712 .37259 .50051 Mtetra
.612 .714 .917 r
.37259 .50051 .37866 .50712 .38865 .50457 .38259 .49836 Mtetra
.636 .736 .921 r
.38259 .49836 .38865 .50457 .3987 .50176 .39266 .4956 Mtetra
.64 .74 .921 r
.39266 .4956 .3987 .50176 .40878 .49894 .40277 .49274 Mtetra
.636 .738 .922 r
.40277 .49274 .40878 .49894 .4189 .49639 .41291 .48997 Mtetra
.603 .719 .927 r
.41291 .48997 .4189 .49639 .42897 .4971 .42308 .48795 Mtetra
.842 .717 .725 r
.42308 .48795 .42897 .4971 .4394 .486 .43369 .47133 Mtetra
.315 .376 .766 r
.43369 .47133 .4394 .486 .44961 .48439 .4437 .47783 Mtetra
.627 .725 .918 r
.4437 .47783 .44961 .48439 .45989 .48152 .454 .47526 Mtetra
.646 .743 .92 r
.454 .47526 .45989 .48152 .47022 .47839 .46435 .4722 Mtetra
.652 .748 .92 r
.46435 .4722 .47022 .47839 .48059 .47514 .47474 .46897 Mtetra
.655 .75 .92 r
.47474 .46897 .48059 .47514 .491 .47182 .48517 .46565 Mtetra
.657 .752 .92 r
.48517 .46565 .491 .47182 .50145 .46843 .49565 .46226 Mtetra
.658 .753 .92 r
.49565 .46226 .50145 .46843 .51194 .46501 .50617 .45883 Mtetra
.659 .754 .92 r
.50617 .45883 .51194 .46501 .52247 .46157 .51672 .45537 Mtetra
.51672 .45537 .52247 .46157 .53304 .45811 .52732 .45188 Mtetra
.52732 .45188 .53304 .45811 .54365 .45464 .53796 .44839 Mtetra
.53796 .44839 .54365 .45464 .5543 .45117 .54863 .44489 Mtetra
.658 .753 .92 r
.54863 .44489 .5543 .45117 .56499 .44769 .55935 .44138 Mtetra
.55935 .44138 .56499 .44769 .57572 .4442 .57011 .43786 Mtetra
.57011 .43786 .57572 .4442 .5865 .4407 .58091 .43434 Mtetra
.58091 .43434 .5865 .4407 .59731 .4372 .59176 .43081 Mtetra
.59176 .43081 .59731 .4372 .60817 .43368 .60264 .42726 Mtetra
.60264 .42726 .60817 .43368 .61907 .43015 .61357 .42371 Mtetra
.657 .753 .92 r
.61357 .42371 .61907 .43015 .63001 .42661 .62454 .42014 Mtetra
.62454 .42014 .63001 .42661 .64099 .42306 .63556 .41656 Mtetra
.63556 .41656 .64099 .42306 .65202 .41949 .64661 .41297 Mtetra
.64661 .41297 .65202 .41949 .66309 .41592 .65771 .40937 Mtetra
.657 .752 .92 r
.65771 .40937 .66309 .41592 .67421 .41233 .66886 .40575 Mtetra
.66886 .40575 .67421 .41233 .68536 .40872 .68004 .40212 Mtetra
.68004 .40212 .68536 .40872 .69656 .40511 .69128 .39848 Mtetra
.69128 .39848 .69656 .40511 .70781 .40148 .70255 .39482 Mtetra
.70255 .39482 .70781 .40148 .7191 .39784 .71388 .39115 Mtetra
.71388 .39115 .7191 .39784 .73044 .39418 .72524 .38747 Mtetra
.72524 .38747 .73044 .39418 .74182 .39051 .73665 .38377 Mtetra
.73665 .38377 .74182 .39051 .75324 .38683 .74811 .38006 Mtetra
.74811 .38006 .75324 .38683 .76471 .38313 .75961 .37633 Mtetra
.75961 .37633 .76471 .38313 .77623 .37941 .77116 .37259 Mtetra
.77116 .37259 .77623 .37941 .78779 .37569 .78276 .36884 Mtetra
.78276 .36884 .78779 .37569 .7994 .37195 .7944 .36507 Mtetra
.7944 .36507 .7994 .37195 .81106 .36819 .80609 .36129 Mtetra
.80609 .36129 .81106 .36819 .82276 .36442 .81783 .35749 Mtetra
.81783 .35749 .82276 .36442 .83451 .36064 .82961 .35367 Mtetra
.82961 .35367 .83451 .36064 .84631 .35684 .84145 .34985 Mtetra
.84145 .34985 .84631 .35684 .85816 .35302 .85333 .346 Mtetra
0 .121 .639 r
.21964 .54445 .22598 .5515 .23611 .54119 .22823 .55207 Mtetra
.693 .872 .477 r
.22823 .55207 .23611 .54119 .2453 .54225 .23896 .53558 Mtetra
.585 .696 .919 r
.23896 .53558 .2453 .54225 .25478 .54038 .24842 .5341 Mtetra
.596 .714 .926 r
.24842 .5341 .25478 .54038 .26421 .53965 .25795 .53232 Mtetra
.869 .436 .027 r
.25795 .53232 .26421 .53965 .27437 .52971 .26598 .55052 Mtetra
0 0 0 r
.26598 .55052 .27437 .52971 .28381 .52988 .27753 .52326 Mtetra
.596 .704 .919 r
.27753 .52326 .28381 .52988 .29345 .52776 .28717 .52151 Mtetra
.613 .723 .924 r
.28717 .52151 .29345 .52776 .30312 .52598 .29687 .51935 Mtetra
.496 .666 .938 r
.29687 .51935 .30312 .52598 .31479 .49316 .30648 .51932 Mtetra
.314 .023 .3 r
.30648 .51932 .31479 .49316 .32292 .5167 .31677 .50924 Mtetra
.559 .664 .908 r
.31677 .50924 .32292 .5167 .33272 .51463 .32652 .50833 Mtetra
.623 .727 .921 r
.32652 .50833 .33272 .51463 .34258 .51215 .33639 .50591 Mtetra
.623 .729 .923 r
.33639 .50591 .34258 .51215 .35246 .51009 .34631 .50348 Mtetra
.537 .686 .935 r
.34631 .50348 .35246 .51009 .35682 .62202 .35618 .50276 Mtetra
.579 .373 .567 r
.35618 .50276 .35682 .62202 .37259 .50051 .36655 .49261 Mtetra
.547 .648 .901 r
.36655 .49261 .37259 .50051 .38259 .49836 .3765 .49199 Mtetra
.629 .73 .92 r
.3765 .49199 .38259 .49836 .39266 .4956 .38658 .48938 Mtetra
.639 .739 .921 r
.38658 .48938 .39266 .4956 .40277 .49274 .39671 .48652 Mtetra
.639 .74 .921 r
.39671 .48652 .40277 .49274 .41291 .48997 .40688 .48364 Mtetra
.627 .733 .923 r
.40688 .48364 .41291 .48997 .42308 .48795 .41709 .48104 Mtetra
.454 .641 .937 r
.41709 .48104 .42308 .48795 .43369 .47133 .42724 .4817 Mtetra
0 0 0 r
.42724 .4817 .43369 .47133 .4437 .47783 .43776 .47052 Mtetra
.589 .688 .91 r
.43776 .47052 .4437 .47783 .454 .47526 .44806 .46886 Mtetra
.639 .737 .919 r
.44806 .46886 .454 .47526 .46435 .4722 .45843 .46593 Mtetra
.649 .746 .92 r
.45843 .46593 .46435 .4722 .47474 .46897 .46885 .46274 Mtetra
.653 .749 .92 r
.46885 .46274 .47474 .46897 .48517 .46565 .47931 .45943 Mtetra
.656 .751 .92 r
.47931 .45943 .48517 .46565 .49565 .46226 .48981 .45604 Mtetra
.657 .753 .92 r
.48981 .45604 .49565 .46226 .50617 .45883 .50035 .4526 Mtetra
.658 .753 .92 r
.50035 .4526 .50617 .45883 .51672 .45537 .51094 .44912 Mtetra
.659 .754 .92 r
.51094 .44912 .51672 .45537 .52732 .45188 .52156 .44561 Mtetra
.52156 .44561 .52732 .45188 .53796 .44839 .53222 .44209 Mtetra
.53222 .44209 .53796 .44839 .54863 .44489 .54293 .43856 Mtetra
.54293 .43856 .54863 .44489 .55935 .44138 .55367 .43503 Mtetra
.658 .753 .92 r
.55367 .43503 .55935 .44138 .57011 .43786 .56446 .43148 Mtetra
.56446 .43148 .57011 .43786 .58091 .43434 .57529 .42793 Mtetra
.57529 .42793 .58091 .43434 .59176 .43081 .58616 .42437 Mtetra
.58616 .42437 .59176 .43081 .60264 .42726 .59708 .4208 Mtetra
.59708 .4208 .60264 .42726 .61357 .42371 .60804 .41722 Mtetra
.60804 .41722 .61357 .42371 .62454 .42014 .61903 .41362 Mtetra
.657 .753 .92 r
.61903 .41362 .62454 .42014 .63556 .41656 .63008 .41002 Mtetra
.63008 .41002 .63556 .41656 .64661 .41297 .64116 .4064 Mtetra
.64116 .4064 .64661 .41297 .65771 .40937 .65229 .40277 Mtetra
.65229 .40277 .65771 .40937 .66886 .40575 .66347 .39913 Mtetra
.657 .752 .92 r
.66347 .39913 .66886 .40575 .68004 .40212 .67469 .39547 Mtetra
.67469 .39547 .68004 .40212 .69128 .39848 .68595 .3918 Mtetra
.68595 .3918 .69128 .39848 .70255 .39482 .69726 .38812 Mtetra
.69726 .38812 .70255 .39482 .71388 .39115 .70861 .38442 Mtetra
.70861 .38442 .71388 .39115 .72524 .38747 .72001 .38071 Mtetra
.72001 .38071 .72524 .38747 .73665 .38377 .73145 .37698 Mtetra
.73145 .37698 .73665 .38377 .74811 .38006 .74294 .37324 Mtetra
.74294 .37324 .74811 .38006 .75961 .37633 .75448 .36949 Mtetra
.75448 .36949 .75961 .37633 .77116 .37259 .76606 .36572 Mtetra
.76606 .36572 .77116 .37259 .78276 .36884 .77769 .36194 Mtetra
.77769 .36194 .78276 .36884 .7944 .36507 .78937 .35814 Mtetra
.78937 .35814 .7944 .36507 .80609 .36129 .80109 .35433 Mtetra
.80109 .35433 .80609 .36129 .81783 .35749 .81286 .3505 Mtetra
.81286 .3505 .81783 .35749 .82961 .35367 .82468 .34666 Mtetra
.82468 .34666 .82961 .35367 .84145 .34985 .83655 .3428 Mtetra
.83655 .3428 .84145 .34985 .85333 .346 .84846 .33893 Mtetra
.55 .692 .933 r
.2132 .53801 .21964 .54445 .22823 .55207 .22255 .53711 Mtetra
.733 .607 .717 r
.22255 .53711 .22823 .55207 .23896 .53558 .23278 .52671 Mtetra
.47 .58 .883 r
.23278 .52671 .23896 .53558 .24842 .5341 .24203 .52774 Mtetra
.603 .714 .923 r
.24203 .52774 .24842 .5341 .25795 .53232 .25158 .52581 Mtetra
.541 .688 .934 r
.25158 .52581 .25795 .53232 .26598 .55052 .26109 .52504 Mtetra
.675 .518 .665 r
.26109 .52504 .26598 .55052 .27753 .52326 .27134 .51501 Mtetra
.512 .62 .895 r
.27134 .51501 .27753 .52326 .28717 .52151 .28085 .51515 Mtetra
.613 .72 .922 r
.28085 .51515 .28717 .52151 .29687 .51935 .29057 .51298 Mtetra
.596 .715 .927 r
.29057 .51298 .29687 .51935 .30648 .51932 .30032 .51115 Mtetra
.898 .719 .651 r
.30032 .51115 .30648 .51932 .31677 .50924 .31211 .47815 Mtetra
0 .02 .527 r
.31211 .47815 .31677 .50924 .32652 .50833 .32029 .50174 Mtetra
.61 .714 .919 r
.32029 .50174 .32652 .50833 .33639 .50591 .33016 .49962 Mtetra
.627 .731 .922 r
.33016 .49962 .33639 .50591 .34631 .50348 .3401 .49709 Mtetra
.607 .721 .926 r
.3401 .49709 .34631 .50348 .35618 .50276 .35007 .49498 Mtetra
.958 .662 .432 r
.35007 .49498 .35618 .50276 .36655 .49261 .35438 .60738 Mtetra
0 0 .175 r
.35438 .60738 .36655 .49261 .3765 .49199 .37038 .48527 Mtetra
.612 .714 .918 r
.37038 .48527 .3765 .49199 .38658 .48938 .38046 .48307 Mtetra
.636 .736 .921 r
.38046 .48307 .38658 .48938 .39671 .48652 .39061 .48025 Mtetra
.64 .74 .921 r
.39061 .48025 .39671 .48652 .40688 .48364 .40081 .47733 Mtetra
.636 .738 .922 r
.40081 .47733 .40688 .48364 .41709 .48104 .41104 .4745 Mtetra
.603 .719 .927 r
.41104 .4745 .41709 .48104 .42724 .4817 .42129 .47243 Mtetra
.843 .718 .725 r
.42129 .47243 .42724 .4817 .43776 .47052 .432 .4557 Mtetra
.313 .375 .766 r
.432 .4557 .43776 .47052 .44806 .46886 .44209 .46219 Mtetra
.627 .725 .918 r
.44209 .46219 .44806 .46886 .45843 .46593 .45248 .45956 Mtetra
.646 .743 .92 r
.45248 .45956 .45843 .46593 .46885 .46274 .46292 .45643 Mtetra
.652 .748 .92 r
.46292 .45643 .46885 .46274 .47931 .45943 .4734 .45315 Mtetra
.655 .75 .92 r
.4734 .45315 .47931 .45943 .48981 .45604 .48393 .44976 Mtetra
.657 .752 .92 r
.48393 .44976 .48981 .45604 .50035 .4526 .4945 .44632 Mtetra
.658 .753 .92 r
.4945 .44632 .50035 .4526 .51094 .44912 .50511 .44282 Mtetra
.659 .754 .92 r
.50511 .44282 .51094 .44912 .52156 .44561 .51576 .4393 Mtetra
.51576 .4393 .52156 .44561 .53222 .44209 .52645 .43575 Mtetra
.52645 .43575 .53222 .44209 .54293 .43856 .53718 .43219 Mtetra
.53718 .43219 .54293 .43856 .55367 .43503 .54796 .42863 Mtetra
.658 .753 .92 r
.54796 .42863 .55367 .43503 .56446 .43148 .55877 .42506 Mtetra
.55877 .42506 .56446 .43148 .57529 .42793 .56963 .42148 Mtetra
.56963 .42148 .57529 .42793 .58616 .42437 .58053 .41789 Mtetra
.58053 .41789 .58616 .42437 .59708 .4208 .59147 .41429 Mtetra
.59147 .41429 .59708 .4208 .60804 .41722 .60246 .41068 Mtetra
.60246 .41068 .60804 .41722 .61903 .41362 .61349 .40706 Mtetra
.657 .753 .92 r
.61349 .40706 .61903 .41362 .63008 .41002 .62456 .40343 Mtetra
.62456 .40343 .63008 .41002 .64116 .4064 .63568 .39978 Mtetra
.63568 .39978 .64116 .4064 .65229 .40277 .64684 .39612 Mtetra
.64684 .39612 .65229 .40277 .66347 .39913 .65804 .39245 Mtetra
.657 .752 .92 r
.65804 .39245 .66347 .39913 .67469 .39547 .66929 .38877 Mtetra
.66929 .38877 .67469 .39547 .68595 .3918 .68058 .38507 Mtetra
.68058 .38507 .68595 .3918 .69726 .38812 .69192 .38136 Mtetra
.69192 .38136 .69726 .38812 .70861 .38442 .70331 .37764 Mtetra
.70331 .37764 .70861 .38442 .72001 .38071 .71474 .3739 Mtetra
.71474 .3739 .72001 .38071 .73145 .37698 .72621 .37014 Mtetra
.72621 .37014 .73145 .37698 .74294 .37324 .73774 .36638 Mtetra
.73774 .36638 .74294 .37324 .75448 .36949 .7493 .36259 Mtetra
.7493 .36259 .75448 .36949 .76606 .36572 .76092 .3588 Mtetra
.76092 .3588 .76606 .36572 .77769 .36194 .77258 .35499 Mtetra
.77258 .35499 .77769 .36194 .78937 .35814 .78429 .35116 Mtetra
.78429 .35116 .78937 .35814 .80109 .35433 .79605 .34732 Mtetra
.79605 .34732 .80109 .35433 .81286 .3505 .80786 .34346 Mtetra
.80786 .34346 .81286 .3505 .82468 .34666 .81971 .33959 Mtetra
.81971 .33959 .82468 .34666 .83655 .3428 .83161 .3357 Mtetra
.83161 .3357 .83655 .3428 .84846 .33893 .84356 .3318 Mtetra
.591 .709 .926 r
.20671 .53162 .2132 .53801 .22255 .53711 .21615 .52995 Mtetra
0 .126 .644 r
.21615 .52995 .22255 .53711 .23278 .52671 .22479 .53757 Mtetra
.701 .878 .486 r
.22479 .53757 .23278 .52671 .24203 .52774 .23563 .52096 Mtetra
.585 .696 .919 r
.23563 .52096 .24203 .52774 .25158 .52581 .24516 .51943 Mtetra
.596 .714 .926 r
.24516 .51943 .25158 .52581 .26109 .52504 .25476 .51761 Mtetra
.866 .432 .019 r
.25476 .51761 .26109 .52504 .27134 .51501 .26284 .53584 Mtetra
0 0 0 r
.26284 .53584 .27134 .51501 .28085 .51515 .27451 .50842 Mtetra
.596 .704 .919 r
.27451 .50842 .28085 .51515 .29057 .51298 .28422 .50662 Mtetra
.613 .723 .924 r
.28422 .50662 .29057 .51298 .30032 .51115 .29401 .50441 Mtetra
.497 .666 .938 r
.29401 .50441 .30032 .51115 .31211 .47815 .3037 .50434 Mtetra
.306 .013 .292 r
.3037 .50434 .31211 .47815 .32029 .50174 .31408 .49417 Mtetra
.559 .664 .908 r
.31408 .49417 .32029 .50174 .33016 .49962 .3239 .49322 Mtetra
.623 .727 .921 r
.3239 .49322 .33016 .49962 .3401 .49709 .33386 .49074 Mtetra
.623 .729 .923 r
.33386 .49074 .3401 .49709 .35007 .49498 .34386 .48826 Mtetra
.538 .686 .935 r
.34386 .48826 .35007 .49498 .35438 .60738 .35381 .48749 Mtetra
.577 .371 .565 r
.35381 .48749 .35438 .60738 .37038 .48527 .36428 .47725 Mtetra
.547 .648 .901 r
.36428 .47725 .37038 .48527 .38046 .48307 .3743 .47659 Mtetra
.629 .73 .92 r
.3743 .47659 .38046 .48307 .39061 .48025 .38447 .47393 Mtetra
.639 .739 .921 r
.38447 .47393 .39061 .48025 .40081 .47733 .39469 .471 Mtetra
.639 .74 .921 r
.39469 .471 .40081 .47733 .41104 .4745 .40495 .46807 Mtetra
.627 .733 .923 r
.40495 .46807 .41104 .4745 .42129 .47243 .41524 .46541 Mtetra
.455 .641 .937 r
.41524 .46541 .42129 .47243 .432 .4557 .42547 .46603 Mtetra
0 0 0 r
.42547 .46603 .432 .4557 .44209 .46219 .4361 .45475 Mtetra
.589 .688 .91 r
.4361 .45475 .44209 .46219 .45248 .45956 .44648 .45304 Mtetra
.639 .737 .919 r
.44648 .45304 .45248 .45956 .46292 .45643 .45694 .45005 Mtetra
.649 .746 .92 r
.45694 .45005 .46292 .45643 .4734 .45315 .46745 .4468 Mtetra
.653 .749 .92 r
.46745 .4468 .4734 .45315 .48393 .44976 .478 .44343 Mtetra
.656 .751 .92 r
.478 .44343 .48393 .44976 .4945 .44632 .4886 .43998 Mtetra
.657 .753 .92 r
.4886 .43998 .4945 .44632 .50511 .44282 .49924 .43648 Mtetra
.658 .753 .92 r
.49924 .43648 .50511 .44282 .51576 .4393 .50991 .43293 Mtetra
.659 .754 .92 r
.50991 .43293 .51576 .4393 .52645 .43575 .52063 .42936 Mtetra
.52063 .42936 .52645 .43575 .53718 .43219 .53139 .42578 Mtetra
.53139 .42578 .53718 .43219 .54796 .42863 .54219 .42218 Mtetra
.54219 .42218 .54796 .42863 .55877 .42506 .55304 .41858 Mtetra
.658 .753 .92 r
.55304 .41858 .55877 .42506 .56963 .42148 .56393 .41497 Mtetra
.56393 .41497 .56963 .42148 .58053 .41789 .57485 .41136 Mtetra
.57485 .41136 .58053 .41789 .59147 .41429 .58583 .40773 Mtetra
.58583 .40773 .59147 .41429 .60246 .41068 .59684 .4041 Mtetra
.59684 .4041 .60246 .41068 .61349 .40706 .6079 .40045 Mtetra
.6079 .40045 .61349 .40706 .62456 .40343 .619 .39679 Mtetra
.657 .753 .92 r
.619 .39679 .62456 .40343 .63568 .39978 .63015 .39311 Mtetra
.63015 .39311 .63568 .39978 .64684 .39612 .64134 .38943 Mtetra
.64134 .38943 .64684 .39612 .65804 .39245 .65257 .38573 Mtetra
.65257 .38573 .65804 .39245 .66929 .38877 .66385 .38202 Mtetra
.657 .752 .92 r
.66385 .38202 .66929 .38877 .68058 .38507 .67518 .37829 Mtetra
.67518 .37829 .68058 .38507 .69192 .38136 .68655 .37456 Mtetra
.68655 .37456 .69192 .38136 .70331 .37764 .69797 .3708 Mtetra
.69797 .3708 .70331 .37764 .71474 .3739 .70943 .36703 Mtetra
.70943 .36703 .71474 .3739 .72621 .37014 .72094 .36325 Mtetra
.72094 .36325 .72621 .37014 .73774 .36638 .73249 .35946 Mtetra
.73249 .35946 .73774 .36638 .7493 .36259 .74409 .35565 Mtetra
.74409 .35565 .7493 .36259 .76092 .3588 .75574 .35182 Mtetra
.75574 .35182 .76092 .3588 .77258 .35499 .76744 .34798 Mtetra
.76744 .34798 .77258 .35499 .78429 .35116 .77918 .34413 Mtetra
.77918 .34413 .78429 .35116 .79605 .34732 .79097 .34026 Mtetra
.79097 .34026 .79605 .34732 .80786 .34346 .80281 .33637 Mtetra
.80281 .33637 .80786 .34346 .81971 .33959 .8147 .33247 Mtetra
.8147 .33247 .81971 .33959 .83161 .3357 .82664 .32855 Mtetra
.82664 .32855 .83161 .3357 .84356 .3318 .83862 .32462 Mtetra
.586 .7 .921 r
.20021 .52498 .20671 .53162 .21615 .52995 .20964 .52341 Mtetra
.55 .691 .933 r
.20964 .52341 .21615 .52995 .22479 .53757 .21907 .52246 Mtetra
.733 .607 .717 r
.21907 .52246 .22479 .53757 .23563 .52096 .22938 .51198 Mtetra
.47 .58 .883 r
.22938 .51198 .23563 .52096 .24516 .51943 .2387 .51297 Mtetra
.603 .714 .923 r
.2387 .51297 .24516 .51943 .25476 .51761 .24833 .51099 Mtetra
.541 .688 .934 r
.24833 .51099 .25476 .51761 .26284 .53584 .25791 .51018 Mtetra
.675 .518 .664 r
.25791 .51018 .26284 .53584 .27451 .50842 .26826 .50006 Mtetra
.512 .62 .896 r
.26826 .50006 .27451 .50842 .28422 .50662 .27784 .50016 Mtetra
.613 .72 .922 r
.27784 .50016 .28422 .50662 .29401 .50441 .28764 .49793 Mtetra
.596 .715 .927 r
.28764 .49793 .29401 .50441 .3037 .50434 .29747 .49605 Mtetra
.899 .719 .651 r
.29747 .49605 .3037 .50434 .31408 .49417 .30939 .46288 Mtetra
0 .015 .524 r
.30939 .46288 .31408 .49417 .3239 .49322 .31761 .48652 Mtetra
.61 .714 .919 r
.31761 .48652 .3239 .49322 .33386 .49074 .32756 .48435 Mtetra
.627 .731 .922 r
.32756 .48435 .33386 .49074 .34386 .48826 .33759 .48176 Mtetra
.607 .721 .926 r
.33759 .48176 .34386 .48826 .35381 .48749 .34763 .4796 Mtetra
.959 .662 .428 r
.34763 .4796 .35381 .48749 .36428 .47725 .35189 .59247 Mtetra
0 0 .167 r
.35189 .59247 .36428 .47725 .3743 .47659 .36812 .46976 Mtetra
.612 .714 .918 r
.36812 .46976 .3743 .47659 .38447 .47393 .37829 .4675 Mtetra
.636 .736 .921 r
.37829 .4675 .38447 .47393 .39469 .471 .38852 .46463 Mtetra
.64 .74 .921 r
.38852 .46463 .39469 .471 .40495 .46807 .39881 .46165 Mtetra
.636 .738 .922 r
.39881 .46165 .40495 .46807 .41524 .46541 .40913 .45876 Mtetra
.603 .719 .927 r
.40913 .45876 .41524 .46541 .42547 .46603 .41947 .45663 Mtetra
.844 .719 .725 r
.41947 .45663 .42547 .46603 .4361 .45475 .43028 .43979 Mtetra
.312 .374 .766 r
.43028 .43979 .4361 .45475 .44648 .45304 .44045 .44625 Mtetra
.626 .725 .918 r
.44045 .44625 .44648 .45304 .45694 .45005 .45093 .44356 Mtetra
.646 .743 .92 r
.45093 .44356 .45694 .45005 .46745 .4468 .46146 .44038 Mtetra
.652 .748 .92 r
.46146 .44038 .46745 .4468 .478 .44343 .47204 .43703 Mtetra
.655 .75 .92 r
.47204 .43703 .478 .44343 .4886 .43998 .48266 .43359 Mtetra
.657 .752 .92 r
.48266 .43359 .4886 .43998 .49924 .43648 .49332 .43008 Mtetra
.658 .753 .92 r
.49332 .43008 .49924 .43648 .50991 .43293 .50403 .42652 Mtetra
.659 .754 .92 r
.50403 .42652 .50991 .43293 .52063 .42936 .51477 .42293 Mtetra
.51477 .42293 .52063 .42936 .53139 .42578 .52556 .41932 Mtetra
.52556 .41932 .53139 .42578 .54219 .42218 .53639 .4157 Mtetra
.53639 .4157 .54219 .42218 .55304 .41858 .54726 .41207 Mtetra
.658 .753 .92 r
.54726 .41207 .55304 .41858 .56393 .41497 .55818 .40843 Mtetra
.55818 .40843 .56393 .41497 .57485 .41136 .56914 .40478 Mtetra
.56914 .40478 .57485 .41136 .58583 .40773 .58014 .40113 Mtetra
.58014 .40113 .58583 .40773 .59684 .4041 .59118 .39746 Mtetra
.59118 .39746 .59684 .4041 .6079 .40045 .60227 .39379 Mtetra
.60227 .39379 .6079 .40045 .619 .39679 .6134 .3901 Mtetra
.657 .753 .92 r
.6134 .3901 .619 .39679 .63015 .39311 .62458 .3864 Mtetra
.62458 .3864 .63015 .39311 .64134 .38943 .6358 .38269 Mtetra
.6358 .38269 .64134 .38943 .65257 .38573 .64707 .37896 Mtetra
.64707 .37896 .65257 .38573 .66385 .38202 .65838 .37522 Mtetra
.657 .752 .92 r
.65838 .37522 .66385 .38202 .67518 .37829 .66973 .37147 Mtetra
.66973 .37147 .67518 .37829 .68655 .37456 .68113 .3677 Mtetra
.68113 .3677 .68655 .37456 .69797 .3708 .69258 .36392 Mtetra
.69258 .36392 .69797 .3708 .70943 .36703 .70408 .36012 Mtetra
.70408 .36012 .70943 .36703 .72094 .36325 .71562 .35631 Mtetra
.71562 .35631 .72094 .36325 .73249 .35946 .7272 .35249 Mtetra
.7272 .35249 .73249 .35946 .74409 .35565 .73884 .34865 Mtetra
.73884 .34865 .74409 .35565 .75574 .35182 .75052 .34479 Mtetra
.75052 .34479 .75574 .35182 .76744 .34798 .76225 .34092 Mtetra
.76225 .34092 .76744 .34798 .77918 .34413 .77403 .33704 Mtetra
.77403 .33704 .77918 .34413 .79097 .34026 .78585 .33314 Mtetra
.78585 .33314 .79097 .34026 .80281 .33637 .79773 .32922 Mtetra
.79773 .32922 .80281 .33637 .8147 .33247 .80965 .32529 Mtetra
.80965 .32529 .8147 .33247 .82664 .32855 .82162 .32135 Mtetra
.82162 .32135 .82664 .32855 .83862 .32462 .83365 .31738 Mtetra
.519 .635 .904 r
.19378 .51707 .20021 .52498 .20964 .52341 .20309 .51692 Mtetra
.591 .709 .926 r
.20309 .51692 .20964 .52341 .21907 .52246 .21259 .5152 Mtetra
0 .131 .649 r
.21259 .5152 .21907 .52246 .22938 .51198 .2213 .5228 Mtetra
.71 .884 .495 r
.2213 .5228 .22938 .51198 .2387 .51297 .23224 .50609 Mtetra
.585 .696 .919 r
.23224 .50609 .2387 .51297 .24833 .51099 .24185 .50451 Mtetra
.596 .714 .926 r
.24185 .50451 .24833 .51099 .25791 .51018 .25152 .50263 Mtetra
.862 .427 .011 r
.25152 .50263 .25791 .51018 .26826 .50006 .25965 .5209 Mtetra
0 0 0 r
.25965 .5209 .26826 .50006 .27784 .50016 .27144 .49332 Mtetra
.596 .704 .919 r
.27144 .49332 .27784 .50016 .28764 .49793 .28123 .49147 Mtetra
.613 .723 .924 r
.28123 .49147 .28764 .49793 .29747 .49605 .2911 .48921 Mtetra
.497 .666 .938 r
.2911 .48921 .29747 .49605 .30939 .46288 .30086 .48909 Mtetra
.298 .003 .284 r
.30086 .48909 .30939 .46288 .31761 .48652 .31133 .47884 Mtetra
.559 .664 .908 r
.31133 .47884 .31761 .48652 .32756 .48435 .32123 .47783 Mtetra
.623 .727 .921 r
.32123 .47783 .32756 .48435 .33759 .48176 .33127 .4753 Mtetra
.623 .729 .923 r
.33127 .4753 .33759 .48176 .34763 .4796 .34136 .47277 Mtetra
.538 .686 .934 r
.34136 .47277 .34763 .4796 .35189 .59247 .35139 .47195 Mtetra
.575 .368 .563 r
.35139 .47195 .35189 .59247 .36812 .46976 .36196 .46162 Mtetra
.547 .648 .901 r
.36196 .46162 .36812 .46976 .37829 .4675 .37207 .46091 Mtetra
.629 .73 .92 r
.37207 .46091 .37829 .4675 .38852 .46463 .38232 .45819 Mtetra
.639 .739 .921 r
.38232 .45819 .38852 .46463 .39881 .46165 .39262 .45521 Mtetra
.639 .74 .921 r
.39262 .45521 .39881 .46165 .40913 .45876 .40297 .45222 Mtetra
.627 .733 .923 r
.40297 .45222 .40913 .45876 .41947 .45663 .41335 .4495 Mtetra
.455 .641 .937 r
.41335 .4495 .41947 .45663 .43028 .43979 .42368 .45008 Mtetra
0 0 0 r
.42368 .45008 .43028 .43979 .44045 .44625 .4344 .4387 Mtetra
.589 .688 .91 r
.4344 .4387 .44045 .44625 .45093 .44356 .44487 .43693 Mtetra
.639 .737 .919 r
.44487 .43693 .45093 .44356 .46146 .44038 .45543 .43388 Mtetra
.649 .746 .92 r
.45543 .43388 .46146 .44038 .47204 .43703 .46603 .43057 Mtetra
.653 .749 .92 r
.46603 .43057 .47204 .43703 .48266 .43359 .47668 .42714 Mtetra
.656 .751 .92 r
.47668 .42714 .48266 .43359 .49332 .43008 .48737 .42362 Mtetra
.657 .753 .92 r
.48737 .42362 .49332 .43008 .50403 .42652 .4981 .42006 Mtetra
.658 .753 .92 r
.4981 .42006 .50403 .42652 .51477 .42293 .50887 .41645 Mtetra
.659 .754 .92 r
.50887 .41645 .51477 .42293 .52556 .41932 .51969 .41281 Mtetra
.51969 .41281 .52556 .41932 .53639 .4157 .53055 .40916 Mtetra
.53055 .40916 .53639 .4157 .54726 .41207 .54145 .4055 Mtetra
.54145 .4055 .54726 .41207 .55818 .40843 .55239 .40183 Mtetra
.658 .753 .92 r
.55239 .40183 .55818 .40843 .56914 .40478 .56338 .39816 Mtetra
.56338 .39816 .56914 .40478 .58014 .40113 .57441 .39448 Mtetra
.57441 .39448 .58014 .40113 .59118 .39746 .58548 .39078 Mtetra
.58548 .39078 .59118 .39746 .60227 .39379 .5966 .38708 Mtetra
.5966 .38708 .60227 .39379 .6134 .3901 .60776 .38336 Mtetra
.60776 .38336 .6134 .3901 .62458 .3864 .61897 .37963 Mtetra
.657 .753 .92 r
.61897 .37963 .62458 .3864 .6358 .38269 .63022 .37589 Mtetra
.63022 .37589 .6358 .38269 .64707 .37896 .64152 .37214 Mtetra
.64152 .37214 .64707 .37896 .65838 .37522 .65286 .36837 Mtetra
.65286 .36837 .65838 .37522 .66973 .37147 .66425 .36459 Mtetra
.657 .752 .92 r
.66425 .36459 .66973 .37147 .68113 .3677 .67568 .36079 Mtetra
.67568 .36079 .68113 .3677 .69258 .36392 .68716 .35698 Mtetra
.68716 .35698 .69258 .36392 .70408 .36012 .69869 .35316 Mtetra
.69869 .35316 .70408 .36012 .71562 .35631 .71026 .34932 Mtetra
.71026 .34932 .71562 .35631 .7272 .35249 .72188 .34546 Mtetra
.72188 .34546 .7272 .35249 .73884 .34865 .73355 .3416 Mtetra
.73355 .3416 .73884 .34865 .75052 .34479 .74526 .33771 Mtetra
.74526 .33771 .75052 .34479 .76225 .34092 .75703 .33381 Mtetra
.75703 .33381 .76225 .34092 .77403 .33704 .76884 .3299 Mtetra
.76884 .3299 .77403 .33704 .78585 .33314 .7807 .32597 Mtetra
.7807 .32597 .78585 .33314 .79773 .32922 .79261 .32202 Mtetra
.79261 .32202 .79773 .32922 .80965 .32529 .80456 .31806 Mtetra
.80456 .31806 .80965 .32529 .82162 .32135 .81657 .31409 Mtetra
.81657 .31409 .82162 .32135 .83365 .31738 .82863 .31009 Mtetra
0 0 .011 r
.17715 .60946 .19378 .51707 .20309 .51692 .19651 .51017 Mtetra
.586 .7 .921 r
.19651 .51017 .20309 .51692 .21259 .5152 .20602 .50855 Mtetra
.55 .691 .933 r
.20602 .50855 .21259 .5152 .2213 .5228 .21552 .50755 Mtetra
.733 .608 .717 r
.21552 .50755 .2213 .5228 .23224 .50609 .22592 .49699 Mtetra
.469 .58 .883 r
.22592 .49699 .23224 .50609 .24185 .50451 .23532 .49794 Mtetra
.603 .714 .923 r
.23532 .49794 .24185 .50451 .25152 .50263 .24503 .49591 Mtetra
.541 .688 .934 r
.24503 .49591 .25152 .50263 .25965 .5209 .25468 .49505 Mtetra
.675 .517 .664 r
.25468 .49505 .25965 .5209 .27144 .49332 .26512 .48485 Mtetra
.511 .62 .896 r
.26512 .48485 .27144 .49332 .28123 .49147 .27478 .4849 Mtetra
.613 .72 .922 r
.27478 .4849 .28123 .49147 .2911 .48921 .28466 .48262 Mtetra
.596 .715 .927 r
.28466 .48262 .2911 .48921 .30086 .48909 .29456 .48069 Mtetra
.9 .72 .65 r
.29456 .48069 .30086 .48909 .31133 .47884 .30661 .44733 Mtetra
0 .011 .521 r
.30661 .44733 .31133 .47884 .32123 .47783 .31488 .47103 Mtetra
.61 .714 .919 r
.31488 .47103 .32123 .47783 .33127 .4753 .32492 .4688 Mtetra
.627 .731 .922 r
.32492 .4688 .33127 .4753 .34136 .47277 .33503 .46616 Mtetra
.607 .721 .926 r
.33503 .46616 .34136 .47277 .35139 .47195 .34516 .46394 Mtetra
.959 .662 .425 r
.34516 .46394 .35139 .47195 .36196 .46162 .34936 .57728 Mtetra
0 0 .16 r
.34936 .57728 .36196 .46162 .37207 .46091 .36582 .45397 Mtetra
.612 .714 .918 r
.36582 .45397 .37207 .46091 .38232 .45819 .37607 .45165 Mtetra
.636 .736 .921 r
.37607 .45165 .38232 .45819 .39262 .45521 .3864 .44872 Mtetra
.64 .74 .921 r
.3864 .44872 .39262 .45521 .40297 .45222 .39677 .44568 Mtetra
.636 .738 .922 r
.39677 .44568 .40297 .45222 .41335 .4495 .40718 .44274 Mtetra
.603 .719 .927 r
.40718 .44274 .41335 .4495 .42368 .45008 .41761 .44055 Mtetra
.845 .72 .725 r
.41761 .44055 .42368 .45008 .4344 .4387 .42853 .42359 Mtetra
.31 .373 .765 r
.42853 .42359 .4344 .4387 .44487 .43693 .43878 .43003 Mtetra
.626 .725 .918 r
.43878 .43003 .44487 .43693 .45543 .43388 .44935 .42728 Mtetra
.646 .743 .92 r
.44935 .42728 .45543 .43388 .46603 .43057 .45998 .42404 Mtetra
.652 .748 .92 r
.45998 .42404 .46603 .43057 .47668 .42714 .47065 .42062 Mtetra
.655 .75 .92 r
.47065 .42062 .47668 .42714 .48737 .42362 .48137 .41711 Mtetra
.657 .752 .92 r
.48137 .41711 .48737 .42362 .4981 .42006 .49213 .41354 Mtetra
.658 .753 .92 r
.49213 .41354 .4981 .42006 .50887 .41645 .50293 .40991 Mtetra
.659 .754 .92 r
.50293 .40991 .50887 .41645 .51969 .41281 .51377 .40626 Mtetra
.51377 .40626 .51969 .41281 .53055 .40916 .52466 .40258 Mtetra
.52466 .40258 .53055 .40916 .54145 .4055 .53559 .39889 Mtetra
.53559 .39889 .54145 .4055 .55239 .40183 .54656 .39519 Mtetra
.658 .753 .92 r
.54656 .39519 .55239 .40183 .56338 .39816 .55758 .39149 Mtetra
.55758 .39149 .56338 .39816 .57441 .39448 .56864 .38778 Mtetra
.56864 .38778 .57441 .39448 .58548 .39078 .57974 .38405 Mtetra
.57974 .38405 .58548 .39078 .5966 .38708 .59089 .38032 Mtetra
.59089 .38032 .5966 .38708 .60776 .38336 .60208 .37658 Mtetra
.60208 .37658 .60776 .38336 .61897 .37963 .61332 .37282 Mtetra
.657 .753 .92 r
.61332 .37282 .61897 .37963 .63022 .37589 .6246 .36905 Mtetra
.6246 .36905 .63022 .37589 .64152 .37214 .63593 .36527 Mtetra
.63593 .36527 .64152 .37214 .65286 .36837 .6473 .36147 Mtetra
.6473 .36147 .65286 .36837 .66425 .36459 .65872 .35766 Mtetra
.657 .752 .92 r
.65872 .35766 .66425 .36459 .67568 .36079 .67018 .35383 Mtetra
.67018 .35383 .67568 .36079 .68716 .35698 .6817 .34999 Mtetra
.6817 .34999 .68716 .35698 .69869 .35316 .69325 .34614 Mtetra
.69325 .34614 .69869 .35316 .71026 .34932 .70486 .34227 Mtetra
.70486 .34227 .71026 .34932 .72188 .34546 .71651 .33839 Mtetra
.71651 .33839 .72188 .34546 .73355 .3416 .72821 .33449 Mtetra
.72821 .33449 .73355 .3416 .74526 .33771 .73996 .33058 Mtetra
.73996 .33058 .74526 .33771 .75703 .33381 .75176 .32665 Mtetra
.75176 .32665 .75703 .33381 .76884 .3299 .76361 .3227 Mtetra
.76361 .3227 .76884 .3299 .7807 .32597 .7755 .31874 Mtetra
.7755 .31874 .7807 .32597 .79261 .32202 .78745 .31477 Mtetra
.78745 .31477 .79261 .32202 .80456 .31806 .79944 .31078 Mtetra
.79944 .31078 .80456 .31806 .81657 .31409 .81148 .30677 Mtetra
.81148 .30677 .81657 .31409 .82863 .31009 .82358 .30275 Mtetra
.581 .377 .569 r
.17969 .51195 .17715 .60946 .19651 .51017 .19002 .50215 Mtetra
.519 .635 .904 r
.19002 .50215 .19651 .51017 .20602 .50855 .1994 .50195 Mtetra
.591 .709 .926 r
.1994 .50195 .20602 .50855 .21552 .50755 .20898 .50018 Mtetra
0 .136 .654 r
.20898 .50018 .21552 .50755 .22592 .49699 .21774 .50778 Mtetra
.718 .89 .504 r
.21774 .50778 .22592 .49699 .23532 .49794 .22878 .49095 Mtetra
.585 .696 .919 r
.22878 .49095 .23532 .49794 .24503 .49591 .23847 .48932 Mtetra
.597 .714 .926 r
.23847 .48932 .24503 .49591 .25468 .49505 .24823 .48739 Mtetra
.859 .423 .003 r
.24823 .48739 .25468 .49505 .26512 .48485 .2564 .5057 Mtetra
0 0 0 r
.2564 .5057 .26512 .48485 .27478 .4849 .26831 .47795 Mtetra
.596 .704 .919 r
.26831 .47795 .27478 .4849 .28466 .48262 .27818 .47605 Mtetra
.613 .723 .924 r
.27818 .47605 .28466 .48262 .29456 .48069 .28813 .47373 Mtetra
.498 .666 .937 r
.28813 .47373 .29456 .48069 .30661 .44733 .29797 .47357 Mtetra
.29 0 .275 r
.29797 .47357 .30661 .44733 .31488 .47103 .30854 .46323 Mtetra
.559 .664 .908 r
.30854 .46323 .31488 .47103 .32492 .4688 .31852 .46217 Mtetra
.623 .727 .921 r
.31852 .46217 .32492 .4688 .33503 .46616 .32865 .45959 Mtetra
.623 .729 .923 r
.32865 .45959 .33503 .46616 .34516 .46394 .33882 .45699 Mtetra
.538 .686 .934 r
.33882 .45699 .34516 .46394 .34936 .57728 .34894 .45613 Mtetra
.573 .365 .56 r
.34894 .45613 .34936 .57728 .36582 .45397 .35959 .44571 Mtetra
.546 .648 .901 r
.35959 .44571 .36582 .45397 .37607 .45165 .36979 .44495 Mtetra
.629 .73 .92 r
.36979 .44495 .37607 .45165 .3864 .44872 .38013 .44217 Mtetra
.639 .739 .921 r
.38013 .44217 .3864 .44872 .39677 .44568 .39053 .43913 Mtetra
.639 .74 .921 r
.39053 .43913 .39677 .44568 .40718 .44274 .40097 .43607 Mtetra
.627 .733 .923 r
.40097 .43607 .40718 .44274 .41761 .44055 .41144 .43329 Mtetra
.456 .641 .937 r
.41144 .43329 .41761 .44055 .42853 .42359 .42185 .43383 Mtetra
0 0 0 r
.42185 .43383 .42853 .42359 .43878 .43003 .43267 .42235 Mtetra
.589 .688 .91 r
.43267 .42235 .43878 .43003 .44935 .42728 .44324 .42053 Mtetra
.639 .737 .919 r
.44324 .42053 .44935 .42728 .45998 .42404 .45389 .41742 Mtetra
.649 .746 .92 r
.45389 .41742 .45998 .42404 .47065 .42062 .46458 .41404 Mtetra
.653 .749 .92 r
.46458 .41404 .47065 .42062 .48137 .41711 .47533 .41054 Mtetra
.656 .751 .92 r
.47533 .41054 .48137 .41711 .49213 .41354 .48611 .40696 Mtetra
.657 .753 .92 r
.48611 .40696 .49213 .41354 .50293 .40991 .49694 .40333 Mtetra
.658 .753 .92 r
.49694 .40333 .50293 .40991 .51377 .40626 .50781 .39965 Mtetra
.659 .754 .92 r
.50781 .39965 .51377 .40626 .52466 .40258 .51873 .39595 Mtetra
.51873 .39595 .52466 .40258 .53559 .39889 .52969 .39224 Mtetra
.52969 .39224 .53559 .39889 .54656 .39519 .54069 .38851 Mtetra
.54069 .38851 .54656 .39519 .55758 .39149 .55173 .38477 Mtetra
.658 .753 .92 r
.55173 .38477 .55758 .39149 .56864 .38778 .56282 .38103 Mtetra
.56282 .38103 .56864 .38778 .57974 .38405 .57395 .37728 Mtetra
.57395 .37728 .57974 .38405 .59089 .38032 .58513 .37351 Mtetra
.58513 .37351 .59089 .38032 .60208 .37658 .59635 .36974 Mtetra
.59635 .36974 .60208 .37658 .61332 .37282 .60762 .36595 Mtetra
.60762 .36595 .61332 .37282 .6246 .36905 .61893 .36215 Mtetra
.657 .753 .92 r
.61893 .36215 .6246 .36905 .63593 .36527 .63029 .35834 Mtetra
.63029 .35834 .63593 .36527 .6473 .36147 .6417 .35452 Mtetra
.6417 .35452 .6473 .36147 .65872 .35766 .65315 .35068 Mtetra
.65315 .35068 .65872 .35766 .67018 .35383 .66465 .34682 Mtetra
.657 .752 .92 r
.66465 .34682 .67018 .35383 .6817 .34999 .67619 .34295 Mtetra
.67619 .34295 .6817 .34999 .69325 .34614 .68778 .33907 Mtetra
.68778 .33907 .69325 .34614 .70486 .34227 .69942 .33517 Mtetra
.69942 .33517 .70486 .34227 .71651 .33839 .71111 .33126 Mtetra
.71111 .33126 .71651 .33839 .72821 .33449 .72284 .32733 Mtetra
.72284 .32733 .72821 .33449 .73996 .33058 .73462 .32339 Mtetra
.73462 .32339 .73996 .33058 .75176 .32665 .74646 .31943 Mtetra
.74646 .31943 .75176 .32665 .76361 .3227 .75834 .31545 Mtetra
.75834 .31545 .76361 .3227 .7755 .31874 .77027 .31146 Mtetra
.77027 .31146 .7755 .31874 .78745 .31477 .78224 .30746 Mtetra
.78224 .30746 .78745 .31477 .79944 .31078 .79427 .30343 Mtetra
.79427 .30343 .79944 .31078 .81148 .30677 .80635 .2994 Mtetra
.80635 .2994 .81148 .30677 .82358 .30275 .81848 .29534 Mtetra
.947 .66 .462 r
.17311 .50409 .17969 .51195 .19002 .50215 .17311 .59488 Mtetra
0 0 .002 r
.17311 .59488 .19002 .50215 .1994 .50195 .19275 .4951 Mtetra
.586 .7 .921 r
.19275 .4951 .1994 .50195 .20898 .50018 .20234 .49343 Mtetra
.55 .691 .933 r
.20234 .49343 .20898 .50018 .21774 .50778 .21191 .49238 Mtetra
.734 .608 .717 r
.21191 .49238 .21774 .50778 .22878 .49095 .22241 .48173 Mtetra
.469 .58 .883 r
.22241 .48173 .22878 .49095 .23847 .48932 .23188 .48264 Mtetra
.603 .714 .923 r
.23188 .48264 .23847 .48932 .24823 .48739 .24166 .48056 Mtetra
.541 .688 .934 r
.24166 .48056 .24823 .48739 .2564 .5057 .25139 .47965 Mtetra
.674 .516 .663 r
.25139 .47965 .2564 .5057 .26831 .47795 .26192 .46936 Mtetra
.511 .62 .896 r
.26192 .46936 .26831 .47795 .27818 .47605 .27166 .46937 Mtetra
.613 .72 .922 r
.27166 .46937 .27818 .47605 .28813 .47373 .28163 .46703 Mtetra
.596 .715 .927 r
.28163 .46703 .28813 .47373 .29797 .47357 .29161 .46505 Mtetra
.901 .721 .649 r
.29161 .46505 .29797 .47357 .30854 .46323 .30379 .4315 Mtetra
0 .006 .518 r
.30379 .4315 .30854 .46323 .31852 .46217 .3121 .45525 Mtetra
.61 .714 .919 r
.3121 .45525 .31852 .46217 .32865 .45959 .32222 .45297 Mtetra
.627 .731 .922 r
.32222 .45297 .32865 .45959 .33882 .45699 .33242 .45027 Mtetra
.607 .721 .926 r
.33242 .45027 .33882 .45699 .34894 .45613 .34263 .44799 Mtetra
.96 .661 .421 r
.34263 .44799 .34894 .45613 .35959 .44571 .34679 .5618 Mtetra
0 0 .153 r
.34679 .5618 .35959 .44571 .36979 .44495 .36348 .43789 Mtetra
.612 .714 .918 r
.36348 .43789 .36979 .44495 .38013 .44217 .37382 .43551 Mtetra
.636 .736 .921 r
.37382 .43551 .38013 .44217 .39053 .43913 .38424 .43252 Mtetra
.64 .74 .921 r
.38424 .43252 .39053 .43913 .40097 .43607 .3947 .42942 Mtetra
.636 .738 .922 r
.3947 .42942 .40097 .43607 .41144 .43329 .4052 .42641 Mtetra
.603 .719 .927 r
.4052 .42641 .41144 .43329 .42185 .43383 .41573 .42417 Mtetra
.846 .72 .725 r
.41573 .42417 .42185 .43383 .43267 .42235 .42675 .40708 Mtetra
.308 .371 .765 r
.42675 .40708 .43267 .42235 .44324 .42053 .43708 .4135 Mtetra
.626 .725 .918 r
.43708 .4135 .44324 .42053 .45389 .41742 .44775 .41069 Mtetra
.646 .743 .92 r
.44775 .41069 .45389 .41742 .46458 .41404 .45847 .40738 Mtetra
.652 .748 .92 r
.45847 .40738 .46458 .41404 .47533 .41054 .46924 .40391 Mtetra
.655 .75 .92 r
.46924 .40391 .47533 .41054 .48611 .40696 .48005 .40033 Mtetra
.657 .752 .92 r
.48005 .40033 .48611 .40696 .49694 .40333 .49091 .39669 Mtetra
.658 .753 .92 r
.49091 .39669 .49694 .40333 .50781 .39965 .50181 .393 Mtetra
.659 .754 .92 r
.50181 .393 .50781 .39965 .51873 .39595 .51275 .38927 Mtetra
.51275 .38927 .51873 .39595 .52969 .39224 .52374 .38553 Mtetra
.52374 .38553 .52969 .39224 .54069 .38851 .53477 .38177 Mtetra
.53477 .38177 .54069 .38851 .55173 .38477 .54584 .37801 Mtetra
.658 .753 .92 r
.54584 .37801 .55173 .38477 .56282 .38103 .55696 .37423 Mtetra
.55696 .37423 .56282 .38103 .57395 .37728 .56813 .37045 Mtetra
.56813 .37045 .57395 .37728 .58513 .37351 .57933 .36666 Mtetra
.57933 .36666 .58513 .37351 .59635 .36974 .59059 .36285 Mtetra
.59059 .36285 .59635 .36974 .60762 .36595 .60188 .35904 Mtetra
.60188 .35904 .60762 .36595 .61893 .36215 .61323 .35521 Mtetra
.657 .753 .92 r
.61323 .35521 .61893 .36215 .63029 .35834 .62462 .35137 Mtetra
.62462 .35137 .63029 .35834 .6417 .35452 .63605 .34751 Mtetra
.63605 .34751 .6417 .35452 .65315 .35068 .64754 .34364 Mtetra
.64754 .34364 .65315 .35068 .66465 .34682 .65907 .33976 Mtetra
.657 .752 .92 r
.65907 .33976 .66465 .34682 .67619 .34295 .67064 .33586 Mtetra
.67064 .33586 .67619 .34295 .68778 .33907 .68227 .33195 Mtetra
.68227 .33195 .68778 .33907 .69942 .33517 .69394 .32802 Mtetra
.69394 .32802 .69942 .33517 .71111 .33126 .70566 .32408 Mtetra
.70566 .32408 .71111 .33126 .72284 .32733 .71743 .32012 Mtetra
.71743 .32012 .72284 .32733 .73462 .32339 .72924 .31614 Mtetra
.72924 .31614 .73462 .32339 .74646 .31943 .74111 .31215 Mtetra
.74111 .31215 .74646 .31943 .75834 .31545 .75302 .30815 Mtetra
.75302 .30815 .75834 .31545 .77027 .31146 .76499 .30413 Mtetra
.76499 .30413 .77027 .31146 .78224 .30746 .777 .30009 Mtetra
.777 .30009 .78224 .30746 .79427 .30343 .78907 .29604 Mtetra
.78907 .29604 .79427 .30343 .80635 .2994 .80118 .29196 Mtetra
.80118 .29196 .80635 .2994 .81848 .29534 .81335 .28788 Mtetra
.509 .671 .937 r
.16638 .49723 .17311 .50409 .17311 .59488 .17577 .49685 Mtetra
.579 .374 .567 r
.17577 .49685 .17311 .59488 .19275 .4951 .18619 .48696 Mtetra
.519 .635 .905 r
.18619 .48696 .19275 .4951 .20234 .49343 .19564 .48672 Mtetra
.591 .709 .926 r
.19564 .48672 .20234 .49343 .21191 .49238 .2053 .4849 Mtetra
0 .14 .659 r
.2053 .4849 .21191 .49238 .22241 .48173 .21412 .49249 Mtetra
.726 .896 .513 r
.21412 .49249 .22241 .48173 .23188 .48264 .22527 .47554 Mtetra
.585 .696 .919 r
.22527 .47554 .23188 .48264 .24166 .48056 .23503 .47386 Mtetra
.597 .714 .926 r
.23503 .47386 .24166 .48056 .25139 .47965 .24487 .47188 Mtetra
.856 .419 0 r
.24487 .47188 .25139 .47965 .26192 .46936 .25308 .49022 Mtetra
0 0 0 r
.25308 .49022 .26192 .46936 .27166 .46937 .26512 .46231 Mtetra
.596 .704 .919 r
.26512 .46231 .27166 .46937 .28163 .46703 .27508 .46035 Mtetra
.613 .723 .924 r
.27508 .46035 .28163 .46703 .29161 .46505 .28511 .45798 Mtetra
.498 .666 .937 r
.28511 .45798 .29161 .46505 .30379 .4315 .29503 .45777 Mtetra
.281 0 .266 r
.29503 .45777 .30379 .4315 .3121 .45525 .3057 .44733 Mtetra
.558 .664 .908 r
.3057 .44733 .3121 .45525 .32222 .45297 .31576 .44623 Mtetra
.623 .727 .921 r
.31576 .44623 .32222 .45297 .33242 .45027 .32597 .44359 Mtetra
.623 .729 .923 r
.32597 .44359 .33242 .45027 .34263 .44799 .33623 .44093 Mtetra
.538 .686 .934 r
.33623 .44093 .34263 .44799 .34679 .5618 .34643 .44002 Mtetra
.571 .362 .558 r
.34643 .44002 .34679 .5618 .36348 .43789 .35719 .42951 Mtetra
.546 .648 .901 r
.35719 .42951 .36348 .43789 .37382 .43551 .36747 .42869 Mtetra
.629 .73 .92 r
.36747 .42869 .37382 .43551 .38424 .43252 .3779 .42585 Mtetra
.639 .739 .921 r
.3779 .42585 .38424 .43252 .3947 .42942 .38839 .42275 Mtetra
.639 .74 .921 r
.38839 .42275 .3947 .42942 .4052 .42641 .39892 .41963 Mtetra
.627 .733 .923 r
.39892 .41963 .4052 .42641 .41573 .42417 .40948 .41679 Mtetra
.457 .641 .936 r
.40948 .41679 .41573 .42417 .42675 .40708 .41999 .41727 Mtetra
0 0 0 r
.41999 .41727 .42675 .40708 .43708 .4135 .43091 .4057 Mtetra
.589 .688 .91 r
.43091 .4057 .43708 .4135 .44775 .41069 .44157 .40382 Mtetra
.639 .737 .92 r
.44157 .40382 .44775 .41069 .45847 .40738 .45231 .40064 Mtetra
.649 .746 .92 r
.45231 .40064 .45847 .40738 .46924 .40391 .46311 .3972 Mtetra
.653 .749 .92 r
.46311 .3972 .46924 .40391 .48005 .40033 .47395 .39364 Mtetra
.656 .751 .92 r
.47395 .39364 .48005 .40033 .49091 .39669 .48483 .38999 Mtetra
.657 .753 .92 r
.48483 .38999 .49091 .39669 .50181 .393 .49576 .38629 Mtetra
.658 .753 .92 r
.49576 .38629 .50181 .393 .51275 .38927 .50673 .38255 Mtetra
.659 .754 .92 r
.50673 .38255 .51275 .38927 .52374 .38553 .51775 .37878 Mtetra
.51775 .37878 .52374 .38553 .53477 .38177 .52881 .37499 Mtetra
.52881 .37499 .53477 .38177 .54584 .37801 .53991 .37119 Mtetra
.53991 .37119 .54584 .37801 .55696 .37423 .55106 .36739 Mtetra
.658 .753 .92 r
.55106 .36739 .55696 .37423 .56813 .37045 .56225 .36357 Mtetra
.56225 .36357 .56813 .37045 .57933 .36666 .57349 .35975 Mtetra
.57349 .35975 .57933 .36666 .59059 .36285 .58477 .35591 Mtetra
.58477 .35591 .59059 .36285 .60188 .35904 .5961 .35207 Mtetra
.5961 .35207 .60188 .35904 .61323 .35521 .60748 .34821 Mtetra
.60748 .34821 .61323 .35521 .62462 .35137 .6189 .34434 Mtetra
.657 .753 .92 r
.6189 .34434 .62462 .35137 .63605 .34751 .63037 .34045 Mtetra
.63037 .34045 .63605 .34751 .64754 .34364 .64188 .33655 Mtetra
.64188 .33655 .64754 .34364 .65907 .33976 .65344 .33264 Mtetra
.65344 .33264 .65907 .33976 .67064 .33586 .66505 .32871 Mtetra
.657 .752 .92 r
.66505 .32871 .67064 .33586 .68227 .33195 .67671 .32477 Mtetra
.67671 .32477 .68227 .33195 .69394 .32802 .68841 .32081 Mtetra
.68841 .32081 .69394 .32802 .70566 .32408 .70017 .31684 Mtetra
.70017 .31684 .70566 .32408 .71743 .32012 .71197 .31285 Mtetra
.71197 .31285 .71743 .32012 .72924 .31614 .72382 .30884 Mtetra
.72382 .30884 .72924 .31614 .74111 .31215 .73572 .30482 Mtetra
.73572 .30482 .74111 .31215 .75302 .30815 .74767 .30079 Mtetra
.74767 .30079 .75302 .30815 .76499 .30413 .75967 .29673 Mtetra
.75967 .29673 .76499 .30413 .777 .30009 .77172 .29266 Mtetra
.77172 .29266 .777 .30009 .78907 .29604 .78382 .28858 Mtetra
.78382 .28858 .78907 .29604 .80118 .29196 .79597 .28448 Mtetra
.79597 .28448 .80118 .29196 .81335 .28788 .80818 .28036 Mtetra
.578 .702 .927 r
.15959 .49046 .16638 .49723 .17577 .49685 .16912 .48888 Mtetra
.948 .66 .459 r
.16912 .48888 .17577 .49685 .18619 .48696 .169 .58003 Mtetra
0 0 0 r
.169 .58003 .18619 .48696 .19564 .48672 .18892 .47975 Mtetra
.586 .7 .921 r
.18892 .47975 .19564 .48672 .2053 .4849 .19859 .47804 Mtetra
.55 .691 .933 r
.19859 .47804 .2053 .4849 .21412 .49249 .20823 .47694 Mtetra
.734 .608 .717 r
.20823 .47694 .21412 .49249 .22527 .47554 .21883 .4662 Mtetra
.468 .58 .884 r
.21883 .4662 .22527 .47554 .23503 .47386 .22837 .46707 Mtetra
.603 .714 .923 r
.22837 .46707 .23503 .47386 .24487 .47188 .23823 .46493 Mtetra
.542 .688 .934 r
.23823 .46493 .24487 .47188 .25308 .49022 .24804 .46397 Mtetra
.674 .516 .663 r
.24804 .46397 .25308 .49022 .26512 .46231 .25867 .4536 Mtetra
.511 .62 .896 r
.25867 .4536 .26512 .46231 .27508 .46035 .26849 .45355 Mtetra
.613 .72 .922 r
.26849 .45355 .27508 .46035 .28511 .45798 .27854 .45117 Mtetra
.596 .715 .927 r
.27854 .45117 .28511 .45798 .29503 .45777 .2886 .44913 Mtetra
.902 .722 .649 r
.2886 .44913 .29503 .45777 .3057 .44733 .30091 .41539 Mtetra
0 .001 .515 r
.30091 .41539 .3057 .44733 .31576 .44623 .30927 .43919 Mtetra
.61 .714 .919 r
.30927 .43919 .31576 .44623 .32597 .44359 .31948 .43685 Mtetra
.627 .731 .922 r
.31948 .43685 .32597 .44359 .33623 .44093 .32976 .43409 Mtetra
.607 .721 .926 r
.32976 .43409 .33623 .44093 .34643 .44002 .34007 .43176 Mtetra
.961 .661 .417 r
.34007 .43176 .34643 .44002 .35719 .42951 .34416 .54603 Mtetra
0 0 .146 r
.34416 .54603 .35719 .42951 .36747 .42869 .36109 .42151 Mtetra
.612 .714 .918 r
.36109 .42151 .36747 .42869 .3779 .42585 .37153 .41908 Mtetra
.636 .736 .921 r
.37153 .41908 .3779 .42585 .38839 .42275 .38203 .41602 Mtetra
.64 .74 .921 r
.38203 .41602 .38839 .42275 .39892 .41963 .39259 .41286 Mtetra
.636 .738 .922 r
.39259 .41286 .39892 .41963 .40948 .41679 .40319 .40979 Mtetra
.603 .719 .927 r
.40319 .40979 .40948 .41679 .41999 .41727 .4138 .40748 Mtetra
.847 .721 .725 r
.4138 .40748 .41999 .41727 .43091 .4057 .42493 .39028 Mtetra
.306 .37 .765 r
.42493 .39028 .43091 .4057 .44157 .40382 .43535 .39667 Mtetra
.626 .725 .918 r
.43535 .39667 .44157 .40382 .45231 .40064 .44611 .3938 Mtetra
.646 .743 .92 r
.44611 .3938 .45231 .40064 .46311 .3972 .45693 .39042 Mtetra
.652 .748 .92 r
.45693 .39042 .46311 .3972 .47395 .39364 .4678 .38688 Mtetra
.655 .75 .92 r
.4678 .38688 .47395 .39364 .48483 .38999 .47871 .38323 Mtetra
.657 .752 .92 r
.47871 .38323 .48483 .38999 .49576 .38629 .48967 .37952 Mtetra
.658 .753 .92 r
.48967 .37952 .49576 .38629 .50673 .38255 .50067 .37576 Mtetra
.659 .754 .92 r
.50067 .37576 .50673 .38255 .51775 .37878 .51171 .37197 Mtetra
.51171 .37197 .51775 .37878 .52881 .37499 .5228 .36815 Mtetra
.5228 .36815 .52881 .37499 .53991 .37119 .53394 .36433 Mtetra
.53394 .36433 .53991 .37119 .55106 .36739 .54511 .36049 Mtetra
.658 .753 .92 r
.54511 .36049 .55106 .36739 .56225 .36357 .55634 .35664 Mtetra
.55634 .35664 .56225 .36357 .57349 .35975 .56761 .35279 Mtetra
.56761 .35279 .57349 .35975 .58477 .35591 .57892 .34892 Mtetra
.57892 .34892 .58477 .35591 .5961 .35207 .59028 .34505 Mtetra
.59028 .34505 .5961 .35207 .60748 .34821 .60169 .34116 Mtetra
.60169 .34116 .60748 .34821 .6189 .34434 .61314 .33726 Mtetra
.657 .753 .92 r
.61314 .33726 .6189 .34434 .63037 .34045 .62464 .33334 Mtetra
.62464 .33334 .63037 .34045 .64188 .33655 .63618 .32941 Mtetra
.63618 .32941 .64188 .33655 .65344 .33264 .64778 .32547 Mtetra
.64778 .32547 .65344 .33264 .66505 .32871 .65942 .32151 Mtetra
.657 .752 .92 r
.65942 .32151 .66505 .32871 .67671 .32477 .67111 .31754 Mtetra
.67111 .31754 .67671 .32477 .68841 .32081 .68285 .31355 Mtetra
.68285 .31355 .68841 .32081 .70017 .31684 .69464 .30954 Mtetra
.69464 .30954 .70017 .31684 .71197 .31285 .70647 .30552 Mtetra
.70647 .30552 .71197 .31285 .72382 .30884 .71836 .30149 Mtetra
.71836 .30149 .72382 .30884 .73572 .30482 .73029 .29743 Mtetra
.73029 .29743 .73572 .30482 .74767 .30079 .74228 .29337 Mtetra
.74228 .29337 .74767 .30079 .75967 .29673 .75431 .28928 Mtetra
.75431 .28928 .75967 .29673 .77172 .29266 .7664 .28518 Mtetra
.7664 .28518 .77172 .29266 .78382 .28858 .77854 .28106 Mtetra
.77854 .28106 .78382 .28858 .79597 .28448 .79072 .27693 Mtetra
.79072 .27693 .79597 .28448 .80818 .28036 .80296 .27278 Mtetra
.573 .692 .921 r
.15279 .48337 .15959 .49046 .16912 .48888 .16232 .4819 Mtetra
.509 .671 .937 r
.16232 .4819 .16912 .48888 .169 .58003 .17178 .48148 Mtetra
.577 .371 .565 r
.17178 .48148 .169 .58003 .18892 .47975 .18229 .4715 Mtetra
.518 .635 .905 r
.18229 .4715 .18892 .47975 .19859 .47804 .19182 .47122 Mtetra
.591 .709 .926 r
.19182 .47122 .19859 .47804 .20823 .47694 .20155 .46934 Mtetra
0 .145 .664 r
.20155 .46934 .20823 .47694 .21883 .4662 .21044 .47692 Mtetra
.733 .902 .521 r
.21044 .47692 .21883 .4662 .22837 .46707 .22169 .45985 Mtetra
.584 .696 .919 r
.22169 .45985 .22837 .46707 .23823 .46493 .23154 .45812 Mtetra
.597 .714 .926 r
.23154 .45812 .23823 .46493 .24804 .46397 .24145 .45609 Mtetra
.852 .415 0 r
.24145 .45609 .24804 .46397 .25867 .4536 .24971 .47445 Mtetra
0 0 0 r
.24971 .47445 .25867 .4536 .26849 .45355 .26188 .44638 Mtetra
.596 .704 .919 r
.26188 .44638 .26849 .45355 .27854 .45117 .27192 .44437 Mtetra
.613 .723 .924 r
.27192 .44437 .27854 .45117 .2886 .44913 .28203 .44194 Mtetra
.498 .666 .937 r
.28203 .44194 .2886 .44913 .30091 .41539 .29204 .44168 Mtetra
.272 0 .257 r
.29204 .44168 .30091 .41539 .30927 .43919 .3028 .43115 Mtetra
.558 .665 .908 r
.3028 .43115 .30927 .43919 .31948 .43685 .31295 .42999 Mtetra
.623 .727 .921 r
.31295 .42999 .31948 .43685 .32976 .43409 .32325 .42729 Mtetra
.623 .729 .923 r
.32325 .42729 .32976 .43409 .34007 .43176 .33359 .42458 Mtetra
.539 .686 .934 r
.33359 .42458 .34007 .43176 .34416 .54603 .34389 .42361 Mtetra
.569 .359 .556 r
.34389 .42361 .34416 .54603 .36109 .42151 .35474 .413 Mtetra
.546 .648 .901 r
.35474 .413 .36109 .42151 .37153 .41908 .36511 .41213 Mtetra
.629 .73 .92 r
.36511 .41213 .37153 .41908 .38203 .41602 .37563 .40923 Mtetra
.639 .739 .921 r
.37563 .40923 .38203 .41602 .39259 .41286 .38621 .40606 Mtetra
.639 .74 .921 r
.38621 .40606 .39259 .41286 .40319 .40979 .39684 .40288 Mtetra
.627 .733 .923 r
.39684 .40288 .40319 .40979 .4138 .40748 .4075 .39998 Mtetra
.457 .642 .936 r
.4075 .39998 .4138 .40748 .42493 .39028 .41809 .40041 Mtetra
0 0 0 r
.41809 .40041 .42493 .39028 .43535 .39667 .42912 .38874 Mtetra
.589 .688 .91 r
.42912 .38874 .43535 .39667 .44611 .3938 .43987 .3868 Mtetra
.639 .737 .92 r
.43987 .3868 .44611 .3938 .45693 .39042 .45071 .38356 Mtetra
.649 .746 .92 r
.45071 .38356 .45693 .39042 .4678 .38688 .46161 .38005 Mtetra
.653 .749 .92 r
.46161 .38005 .4678 .38688 .47871 .38323 .47254 .37641 Mtetra
.656 .751 .92 r
.47254 .37641 .47871 .38323 .48967 .37952 .48353 .3727 Mtetra
.657 .753 .92 r
.48353 .3727 .48967 .37952 .50067 .37576 .49456 .36893 Mtetra
.658 .753 .92 r
.49456 .36893 .50067 .37576 .51171 .37197 .50563 .36511 Mtetra
.659 .754 .92 r
.50563 .36511 .51171 .37197 .5228 .36815 .51675 .36127 Mtetra
.51675 .36127 .5228 .36815 .53394 .36433 .52791 .35741 Mtetra
.52791 .35741 .53394 .36433 .54511 .36049 .53912 .35354 Mtetra
.53912 .35354 .54511 .36049 .55634 .35664 .55038 .34967 Mtetra
.658 .753 .92 r
.55038 .34967 .55634 .35664 .56761 .35279 .56167 .34578 Mtetra
.56167 .34578 .56761 .35279 .57892 .34892 .57302 .34188 Mtetra
.57302 .34188 .57892 .34892 .59028 .34505 .58441 .33798 Mtetra
.58441 .33798 .59028 .34505 .60169 .34116 .59585 .33406 Mtetra
.59585 .33406 .60169 .34116 .61314 .33726 .60733 .33012 Mtetra
.60733 .33012 .61314 .33726 .62464 .33334 .61886 .32618 Mtetra
.657 .753 .92 r
.61886 .32618 .62464 .33334 .63618 .32941 .63044 .32222 Mtetra
.63044 .32222 .63618 .32941 .64778 .32547 .64207 .31824 Mtetra
.64207 .31824 .64778 .32547 .65942 .32151 .65374 .31425 Mtetra
.65374 .31425 .65942 .32151 .67111 .31754 .66547 .31025 Mtetra
.657 .752 .92 r
.66547 .31025 .67111 .31754 .68285 .31355 .67724 .30623 Mtetra
.67724 .30623 .68285 .31355 .69464 .30954 .68906 .30219 Mtetra
.68906 .30219 .69464 .30954 .70647 .30552 .70093 .29814 Mtetra
.70093 .29814 .70647 .30552 .71836 .30149 .71285 .29407 Mtetra
.71285 .29407 .71836 .30149 .73029 .29743 .72482 .28999 Mtetra
.72482 .28999 .73029 .29743 .74228 .29337 .73684 .28589 Mtetra
.73684 .28589 .74228 .29337 .75431 .28928 .74891 .28177 Mtetra
.74891 .28177 .75431 .28928 .7664 .28518 .76103 .27764 Mtetra
.76103 .27764 .7664 .28518 .77854 .28106 .77321 .27349 Mtetra
.77321 .27349 .77854 .28106 .79072 .27693 .78543 .26932 Mtetra
.78543 .26932 .79072 .27693 .80296 .27278 .79771 .26514 Mtetra
.473 .594 .893 r
.14616 .47441 .15279 .48337 .16232 .4819 .15546 .47502 Mtetra
.578 .702 .927 r
.15546 .47502 .16232 .4819 .17178 .48148 .16506 .47339 Mtetra
.949 .66 .457 r
.16506 .47339 .17178 .48148 .18229 .4715 .16481 .56491 Mtetra
0 0 0 r
.16481 .56491 .18229 .4715 .19182 .47122 .18503 .46414 Mtetra
.586 .7 .921 r
.18503 .46414 .19182 .47122 .20155 .46934 .19477 .46237 Mtetra
.55 .691 .933 r
.19477 .46237 .20155 .46934 .21044 .47692 .20449 .46122 Mtetra
.734 .608 .718 r
.20449 .46122 .21044 .47692 .22169 .45985 .21518 .45039 Mtetra
.468 .58 .884 r
.21518 .45039 .22169 .45985 .23154 .45812 .2248 .45121 Mtetra
.603 .714 .923 r
.2248 .45121 .23154 .45812 .24145 .45609 .23475 .44902 Mtetra
.542 .687 .934 r
.23475 .44902 .24145 .45609 .24971 .47445 .24464 .44801 Mtetra
.673 .515 .662 r
.24464 .44801 .24971 .47445 .26188 .44638 .25536 .43754 Mtetra
.51 .62 .896 r
.25536 .43754 .26188 .44638 .27192 .44437 .26525 .43745 Mtetra
.613 .72 .922 r
.26525 .43745 .27192 .44437 .28203 .44194 .27539 .43501 Mtetra
.596 .715 .927 r
.27539 .43501 .28203 .44194 .29204 .44168 .28554 .43291 Mtetra
.903 .723 .648 r
.28554 .43291 .29204 .44168 .3028 .43115 .29798 .39899 Mtetra
0 0 .513 r
.29798 .39899 .3028 .43115 .31295 .42999 .30639 .42284 Mtetra
.61 .714 .919 r
.30639 .42284 .31295 .42999 .32325 .42729 .31669 .42044 Mtetra
.627 .731 .922 r
.31669 .42044 .32325 .42729 .33359 .42458 .32706 .41762 Mtetra
.607 .721 .926 r
.32706 .41762 .33359 .42458 .34389 .42361 .33745 .41522 Mtetra
.961 .66 .413 r
.33745 .41522 .34389 .42361 .35474 .413 .34148 .52995 Mtetra
0 0 .138 r
.34148 .52995 .35474 .413 .36511 .41213 .35867 .40483 Mtetra
.612 .714 .918 r
.35867 .40483 .36511 .41213 .37563 .40923 .36919 .40233 Mtetra
.636 .736 .921 r
.36919 .40233 .37563 .40923 .38621 .40606 .37979 .39922 Mtetra
.64 .74 .921 r
.37979 .39922 .38621 .40606 .39684 .40288 .39044 .39599 Mtetra
.636 .738 .922 r
.39044 .39599 .39684 .40288 .4075 .39998 .40113 .39285 Mtetra
.603 .719 .927 r
.40113 .39285 .4075 .39998 .41809 .40041 .41184 .39048 Mtetra
.847 .722 .725 r
.41184 .39048 .41809 .40041 .42912 .38874 .42308 .37316 Mtetra
.304 .369 .765 r
.42308 .37316 .42912 .38874 .43987 .3868 .43359 .37952 Mtetra
.626 .725 .918 r
.43359 .37952 .43987 .3868 .45071 .38356 .44445 .37658 Mtetra
.646 .743 .92 r
.44445 .37658 .45071 .38356 .46161 .38005 .45537 .37314 Mtetra
.652 .748 .92 r
.45537 .37314 .46161 .38005 .47254 .37641 .46633 .36952 Mtetra
.655 .75 .92 r
.46633 .36952 .47254 .37641 .48353 .3727 .47735 .36581 Mtetra
.657 .752 .92 r
.47735 .36581 .48353 .3727 .49456 .36893 .4884 .36203 Mtetra
.658 .753 .92 r
.4884 .36203 .49456 .36893 .50563 .36511 .49951 .3582 Mtetra
.659 .754 .92 r
.49951 .3582 .50563 .36511 .51675 .36127 .51065 .35433 Mtetra
.51065 .35433 .51675 .36127 .52791 .35741 .52185 .35045 Mtetra
.52185 .35045 .52791 .35741 .53912 .35354 .53309 .34655 Mtetra
.53309 .34655 .53912 .35354 .55038 .34967 .54437 .34264 Mtetra
.658 .753 .92 r
.54437 .34264 .55038 .34967 .56167 .34578 .5557 .33872 Mtetra
.5557 .33872 .56167 .34578 .57302 .34188 .56707 .33479 Mtetra
.56707 .33479 .57302 .34188 .58441 .33798 .5785 .33085 Mtetra
.5785 .33085 .58441 .33798 .59585 .33406 .58997 .3269 Mtetra
.58997 .3269 .59585 .33406 .60733 .33012 .60148 .32294 Mtetra
.60148 .32294 .60733 .33012 .61886 .32618 .61305 .31896 Mtetra
.657 .753 .92 r
.61305 .31896 .61886 .32618 .63044 .32222 .62466 .31497 Mtetra
.62466 .31497 .63044 .32222 .64207 .31824 .63632 .31096 Mtetra
.63632 .31096 .64207 .31824 .65374 .31425 .64803 .30694 Mtetra
.64803 .30694 .65374 .31425 .66547 .31025 .65978 .3029 Mtetra
.657 .752 .92 r
.65978 .3029 .66547 .31025 .67724 .30623 .67159 .29885 Mtetra
.67159 .29885 .67724 .30623 .68906 .30219 .68344 .29478 Mtetra
.68344 .29478 .68906 .30219 .70093 .29814 .69535 .2907 Mtetra
.69535 .2907 .70093 .29814 .71285 .29407 .7073 .2866 Mtetra
.7073 .2866 .71285 .29407 .72482 .28999 .71931 .28249 Mtetra
.71931 .28249 .72482 .28999 .73684 .28589 .73136 .27835 Mtetra
.73136 .27835 .73684 .28589 .74891 .28177 .74347 .27421 Mtetra
.74347 .27421 .74891 .28177 .76103 .27764 .75563 .27004 Mtetra
.75563 .27004 .76103 .27764 .77321 .27349 .76784 .26586 Mtetra
.76784 .26586 .77321 .27349 .78543 .26932 .7801 .26166 Mtetra
.7801 .26166 .78543 .26932 .79771 .26514 .79241 .25744 Mtetra
.763 .891 .485 r
.13678 .48847 .14616 .47441 .15546 .47502 .14858 .46782 Mtetra
.573 .692 .921 r
.14858 .46782 .15546 .47502 .16506 .47339 .15818 .4663 Mtetra
.51 .671 .937 r
.15818 .4663 .16506 .47339 .16481 .56491 .16772 .46583 Mtetra
.575 .368 .563 r
.16772 .46583 .16481 .56491 .18503 .46414 .17832 .45577 Mtetra
.518 .635 .905 r
.17832 .45577 .18503 .46414 .19477 .46237 .18792 .45544 Mtetra
.591 .709 .926 r
.18792 .45544 .19477 .46237 .20449 .46122 .19774 .45351 Mtetra
0 .15 .669 r
.19774 .45351 .20449 .46122 .21518 .45039 .20668 .46106 Mtetra
.741 .907 .529 r
.20668 .46106 .21518 .45039 .2248 .45121 .21805 .44388 Mtetra
.584 .696 .919 r
.21805 .44388 .2248 .45121 .23475 .44902 .22798 .44209 Mtetra
.597 .714 .926 r
.22798 .44209 .23475 .44902 .24464 .44801 .23797 .44 Mtetra
.849 .41 0 r
.23797 .44 .24464 .44801 .25536 .43754 .24628 .4584 Mtetra
.648 .76 .282 r
.24628 .4584 .25536 .43754 .26525 .43745 .25858 .43016 Mtetra
.596 .704 .919 r
.25858 .43016 .26525 .43745 .27539 .43501 .2687 .42809 Mtetra
.613 .723 .924 r
.2687 .42809 .27539 .43501 .28554 .43291 .2789 .4256 Mtetra
.499 .666 .937 r
.2789 .4256 .28554 .43291 .29798 .39899 .28899 .42529 Mtetra
.262 0 .247 r
.28899 .42529 .29798 .39899 .30639 .42284 .29985 .41467 Mtetra
.558 .665 .908 r
.29985 .41467 .30639 .42284 .31669 .42044 .31008 .41346 Mtetra
.623 .727 .921 r
.31008 .41346 .31669 .42044 .32706 .41762 .32047 .41069 Mtetra
.623 .729 .923 r
.32047 .41069 .32706 .41762 .33745 .41522 .33091 .40792 Mtetra
.539 .686 .934 r
.33091 .40792 .33745 .41522 .34148 .52995 .34129 .40689 Mtetra
.567 .356 .554 r
.34129 .40689 .34148 .52995 .35867 .40483 .35225 .39619 Mtetra
.546 .648 .902 r
.35225 .39619 .35867 .40483 .36919 .40233 .36271 .39527 Mtetra
.629 .73 .92 r
.36271 .39527 .36919 .40233 .37979 .39922 .37332 .3923 Mtetra
.639 .739 .921 r
.37332 .3923 .37979 .39922 .39044 .39599 .384 .38907 Mtetra
.639 .74 .921 r
.384 .38907 .39044 .39599 .40113 .39285 .39472 .38582 Mtetra
.627 .733 .923 r
.39472 .38582 .40113 .39285 .41184 .39048 .40547 .38285 Mtetra
.458 .642 .936 r
.40547 .38285 .41184 .39048 .42308 .37316 .41616 .38323 Mtetra
0 0 0 r
.41616 .38323 .42308 .37316 .43359 .37952 .42729 .37146 Mtetra
.588 .688 .911 r
.42729 .37146 .43359 .37952 .44445 .37658 .43814 .36945 Mtetra
.639 .737 .92 r
.43814 .36945 .44445 .37658 .45537 .37314 .44908 .36614 Mtetra
.649 .746 .92 r
.44908 .36614 .45537 .37314 .46633 .36952 .46007 .36256 Mtetra
.653 .749 .92 r
.46007 .36256 .46633 .36952 .47735 .36581 .47111 .35886 Mtetra
.656 .751 .92 r
.47111 .35886 .47735 .36581 .4884 .36203 .4822 .35507 Mtetra
.657 .753 .92 r
.4822 .35507 .4884 .36203 .49951 .3582 .49333 .35123 Mtetra
.658 .753 .92 r
.49333 .35123 .49951 .3582 .51065 .35433 .50451 .34734 Mtetra
.659 .754 .92 r
.50451 .34734 .51065 .35433 .52185 .35045 .51573 .34343 Mtetra
.51573 .34343 .52185 .35045 .53309 .34655 .527 .3395 Mtetra
.527 .3395 .53309 .34655 .54437 .34264 .53832 .33556 Mtetra
.53832 .33556 .54437 .34264 .5557 .33872 .54968 .3316 Mtetra
.658 .753 .92 r
.54968 .3316 .5557 .33872 .56707 .33479 .56108 .32764 Mtetra
.56108 .32764 .56707 .33479 .5785 .33085 .57254 .32367 Mtetra
.57254 .32367 .5785 .33085 .58997 .3269 .58404 .31969 Mtetra
.58404 .31969 .58997 .3269 .60148 .32294 .59559 .31569 Mtetra
.59559 .31569 .60148 .32294 .61305 .31896 .60718 .31168 Mtetra
.60718 .31168 .61305 .31896 .62466 .31497 .61883 .30766 Mtetra
.657 .753 .92 r
.61883 .30766 .62466 .31497 .63632 .31096 .63052 .30362 Mtetra
.63052 .30362 .63632 .31096 .64803 .30694 .64226 .29957 Mtetra
.64226 .29957 .64803 .30694 .65978 .3029 .65405 .2955 Mtetra
.65405 .2955 .65978 .3029 .67159 .29885 .66589 .29142 Mtetra
.657 .752 .92 r
.66589 .29142 .67159 .29885 .68344 .29478 .67778 .28732 Mtetra
.67778 .28732 .68344 .29478 .69535 .2907 .68972 .2832 Mtetra
.68972 .2832 .69535 .2907 .7073 .2866 .70171 .27907 Mtetra
.70171 .27907 .7073 .2866 .71931 .28249 .71375 .27492 Mtetra
.71375 .27492 .71931 .28249 .73136 .27835 .72584 .27076 Mtetra
.72584 .27076 .73136 .27835 .74347 .27421 .73798 .26658 Mtetra
.73798 .26658 .74347 .27421 .75563 .27004 .75018 .26238 Mtetra
.75018 .26238 .75563 .27004 .76784 .26586 .76242 .25816 Mtetra
.76242 .25816 .76784 .26586 .7801 .26166 .77472 .25393 Mtetra
.77472 .25393 .7801 .26166 .79241 .25744 .78707 .24968 Mtetra
.706 .567 .695 r
.13125 .46909 .13678 .48847 .14858 .46782 .14187 .45874 Mtetra
.473 .594 .893 r
.14187 .45874 .14858 .46782 .15818 .4663 .15125 .45931 Mtetra
.579 .702 .927 r
.15125 .45931 .15818 .4663 .16772 .46583 .16093 .45763 Mtetra
.95 .66 .454 r
.16093 .45763 .16772 .46583 .17832 .45577 .16054 .54951 Mtetra
0 0 0 r
.16054 .54951 .17832 .45577 .18792 .45544 .18106 .44824 Mtetra
.586 .7 .922 r
.18106 .44824 .18792 .45544 .19774 .45351 .19088 .44641 Mtetra
.551 .691 .933 r
.19088 .44641 .19774 .45351 .20668 .46106 .20068 .44522 Mtetra
.734 .609 .718 r
.20068 .44522 .20668 .46106 .21805 .44388 .21147 .43429 Mtetra
.467 .58 .884 r
.21147 .43429 .21805 .44388 .22798 .44209 .22116 .43507 Mtetra
.603 .714 .923 r
.22116 .43507 .22798 .44209 .23797 .44 .23119 .43282 Mtetra
.542 .687 .934 r
.23119 .43282 .23797 .44 .24628 .4584 .24116 .43176 Mtetra
.673 .514 .662 r
.24116 .43176 .24628 .4584 .25858 .43016 .25199 .4212 Mtetra
.51 .62 .896 r
.25199 .4212 .25858 .43016 .2687 .42809 .26196 .42106 Mtetra
.613 .72 .922 r
.26196 .42106 .2687 .42809 .2789 .4256 .27218 .41855 Mtetra
.596 .715 .927 r
.27218 .41855 .2789 .4256 .28899 .42529 .28242 .41639 Mtetra
.904 .723 .647 r
.28242 .41639 .28899 .42529 .29985 .41467 .295 .38229 Mtetra
0 0 .51 r
.295 .38229 .29985 .41467 .31008 .41346 .30345 .40618 Mtetra
.61 .714 .919 r
.30345 .40618 .31008 .41346 .32047 .41069 .31384 .40372 Mtetra
.627 .731 .922 r
.31384 .40372 .32047 .41069 .33091 .40792 .3243 .40083 Mtetra
.608 .721 .926 r
.3243 .40083 .33091 .40792 .34129 .40689 .33479 .39838 Mtetra
.962 .66 .409 r
.33479 .39838 .34129 .40689 .35225 .39619 .33875 .51356 Mtetra
0 0 .131 r
.33875 .51356 .35225 .39619 .36271 .39527 .35619 .38783 Mtetra
.612 .714 .918 r
.35619 .38783 .36271 .39527 .37332 .3923 .36681 .38528 Mtetra
.636 .736 .921 r
.36681 .38528 .37332 .3923 .384 .38907 .3775 .38209 Mtetra
.64 .74 .921 r
.3775 .38209 .384 .38907 .39472 .38582 .38825 .3788 Mtetra
.636 .738 .922 r
.38825 .3788 .39472 .38582 .40547 .38285 .39904 .37559 Mtetra
.603 .719 .927 r
.39904 .37559 .40547 .38285 .41616 .38323 .40984 .37316 Mtetra
.848 .723 .725 r
.40984 .37316 .41616 .38323 .42729 .37146 .42119 .35571 Mtetra
.302 .368 .765 r
.42119 .35571 .42729 .37146 .43814 .36945 .43179 .36204 Mtetra
.626 .725 .918 r
.43179 .36204 .43814 .36945 .44908 .36614 .44275 .35904 Mtetra
.646 .743 .92 r
.44275 .35904 .44908 .36614 .46007 .36256 .45377 .35552 Mtetra
.652 .748 .92 r
.45377 .35552 .46007 .36256 .47111 .35886 .46484 .35184 Mtetra
.655 .75 .92 r
.46484 .35184 .47111 .35886 .4822 .35507 .47595 .34805 Mtetra
.657 .752 .92 r
.47595 .34805 .4822 .35507 .49333 .35123 .48711 .3442 Mtetra
.658 .753 .92 r
.48711 .3442 .49333 .35123 .50451 .34734 .49832 .3403 Mtetra
.659 .754 .92 r
.49832 .3403 .50451 .34734 .51573 .34343 .50958 .33636 Mtetra
.50958 .33636 .51573 .34343 .527 .3395 .52087 .3324 Mtetra
.52087 .3324 .527 .3395 .53832 .33556 .53222 .32842 Mtetra
.53222 .32842 .53832 .33556 .54968 .3316 .54361 .32444 Mtetra
.658 .753 .92 r
.54361 .32444 .54968 .3316 .56108 .32764 .55505 .32044 Mtetra
.55505 .32044 .56108 .32764 .57254 .32367 .56653 .31644 Mtetra
.56653 .31644 .57254 .32367 .58404 .31969 .57807 .31242 Mtetra
.57807 .31242 .58404 .31969 .59559 .31569 .58965 .3084 Mtetra
.58965 .3084 .59559 .31569 .60718 .31168 .60128 .30435 Mtetra
.60128 .30435 .60718 .31168 .61883 .30766 .61295 .3003 Mtetra
.657 .753 .92 r
.61295 .3003 .61883 .30766 .63052 .30362 .62468 .29623 Mtetra
.62468 .29623 .63052 .30362 .64226 .29957 .63645 .29214 Mtetra
.63645 .29214 .64226 .29957 .65405 .2955 .64828 .28804 Mtetra
.64828 .28804 .65405 .2955 .66589 .29142 .66015 .28393 Mtetra
.657 .752 .92 r
.66015 .28393 .66589 .29142 .67778 .28732 .67207 .2798 Mtetra
.67207 .2798 .67778 .28732 .68972 .2832 .68405 .27565 Mtetra
.68405 .27565 .68972 .2832 .70171 .27907 .69607 .27148 Mtetra
.69607 .27148 .70171 .27907 .71375 .27492 .70815 .2673 Mtetra
.70815 .2673 .71375 .27492 .72584 .27076 .72028 .26311 Mtetra
.72028 .26311 .72584 .27076 .73798 .26658 .73246 .25889 Mtetra
.73246 .25889 .73798 .26658 .75018 .26238 .74469 .25466 Mtetra
.74469 .25466 .75018 .26238 .76242 .25816 .75697 .25041 Mtetra
.75697 .25041 .76242 .25816 .77472 .25393 .7693 .24614 Mtetra
.7693 .24614 .77472 .25393 .78707 .24968 .78169 .24186 Mtetra
.686 .206 0 r
.12433 .46125 .13125 .46909 .14187 .45874 .13237 .47278 Mtetra
.77 .896 .493 r
.13237 .47278 .14187 .45874 .15125 .45931 .14429 .45199 Mtetra
.573 .692 .921 r
.14429 .45199 .15125 .45931 .16093 .45763 .15397 .45042 Mtetra
.51 .671 .936 r
.15397 .45042 .16093 .45763 .16054 .54951 .16358 .4499 Mtetra
.573 .365 .561 r
.16358 .4499 .16054 .54951 .18106 .44824 .17428 .43975 Mtetra
.518 .635 .905 r
.17428 .43975 .18106 .44824 .19088 .44641 .18396 .43937 Mtetra
.591 .709 .926 r
.18396 .43937 .19088 .44641 .20068 .44522 .19386 .43738 Mtetra
0 .155 .673 r
.19386 .43738 .20068 .44522 .21147 .43429 .20286 .44492 Mtetra
.749 .912 .537 r
.20286 .44492 .21147 .43429 .22116 .43507 .21434 .42761 Mtetra
.584 .696 .919 r
.21434 .42761 .22116 .43507 .23119 .43282 .22435 .42577 Mtetra
.597 .714 .926 r
.22435 .42577 .23119 .43282 .24116 .43176 .23443 .42362 Mtetra
.845 .405 0 r
.23443 .42362 .24116 .43176 .25199 .4212 .24278 .44205 Mtetra
.658 .767 .292 r
.24278 .44205 .25199 .4212 .26196 .42106 .25521 .41364 Mtetra
.596 .704 .919 r
.25521 .41364 .26196 .42106 .27218 .41855 .26542 .41151 Mtetra
.613 .723 .924 r
.26542 .41151 .27218 .41855 .28242 .41639 .27571 .40896 Mtetra
.499 .666 .937 r
.27571 .40896 .28242 .41639 .295 .38229 .28588 .4086 Mtetra
.253 0 .237 r
.28588 .4086 .295 .38229 .30345 .40618 .29684 .39788 Mtetra
.558 .665 .908 r
.29684 .39788 .30345 .40618 .31384 .40372 .30717 .39661 Mtetra
.623 .727 .921 r
.30717 .39661 .31384 .40372 .3243 .40083 .31765 .39378 Mtetra
.623 .729 .923 r
.31765 .39378 .3243 .40083 .33479 .39838 .32817 .39094 Mtetra
.539 .686 .934 r
.32817 .39094 .33479 .39838 .33875 .51356 .33864 .38986 Mtetra
.564 .352 .551 r
.33864 .38986 .33875 .51356 .35619 .38783 .3497 .37906 Mtetra
.546 .648 .902 r
.3497 .37906 .35619 .38783 .36681 .38528 .36026 .37808 Mtetra
.629 .73 .92 r
.36026 .37808 .36681 .38528 .3775 .38209 .37097 .37505 Mtetra
.639 .739 .921 r
.37097 .37505 .3775 .38209 .38825 .3788 .38174 .37175 Mtetra
.639 .74 .921 r
.38174 .37175 .38825 .3788 .39904 .37559 .39255 .36843 Mtetra
.627 .733 .923 r
.39255 .36843 .39904 .37559 .40984 .37316 .4034 .3654 Mtetra
.459 .642 .936 r
.4034 .3654 .40984 .37316 .42119 .35571 .41419 .36572 Mtetra
0 0 0 r
.41419 .36572 .42119 .35571 .43179 .36204 .42542 .35385 Mtetra
.588 .688 .911 r
.42542 .35385 .43179 .36204 .44275 .35904 .43638 .35178 Mtetra
.639 .737 .92 r
.43638 .35178 .44275 .35904 .45377 .35552 .44742 .3484 Mtetra
.649 .746 .92 r
.44742 .3484 .45377 .35552 .46484 .35184 .45851 .34474 Mtetra
.653 .749 .92 r
.45851 .34474 .46484 .35184 .47595 .34805 .46966 .34097 Mtetra
.656 .751 .92 r
.46966 .34097 .47595 .34805 .48711 .3442 .48085 .33711 Mtetra
.657 .753 .92 r
.48085 .33711 .48711 .3442 .49832 .3403 .49208 .33319 Mtetra
.658 .753 .92 r
.49208 .33319 .49832 .3403 .50958 .33636 .50337 .32923 Mtetra
.659 .754 .92 r
.50337 .32923 .50958 .33636 .52087 .3324 .5147 .32524 Mtetra
.5147 .32524 .52087 .3324 .53222 .32842 .52607 .32123 Mtetra
.52607 .32123 .53222 .32842 .54361 .32444 .5375 .31722 Mtetra
.5375 .31722 .54361 .32444 .55505 .32044 .54897 .31319 Mtetra
.658 .753 .92 r
.54897 .31319 .55505 .32044 .56653 .31644 .56048 .30915 Mtetra
.56048 .30915 .56653 .31644 .57807 .31242 .57205 .3051 Mtetra
.57205 .3051 .57807 .31242 .58965 .3084 .58366 .30104 Mtetra
.58366 .30104 .58965 .3084 .60128 .30435 .59532 .29697 Mtetra
.59532 .29697 .60128 .30435 .61295 .3003 .60703 .29288 Mtetra
.60703 .29288 .61295 .3003 .62468 .29623 .61879 .28878 Mtetra
.657 .753 .92 r
.61879 .28878 .62468 .29623 .63645 .29214 .6306 .28466 Mtetra
.6306 .28466 .63645 .29214 .64828 .28804 .64246 .28053 Mtetra
.64246 .28053 .64828 .28804 .66015 .28393 .65437 .27638 Mtetra
.65437 .27638 .66015 .28393 .67207 .2798 .66632 .27222 Mtetra
.657 .752 .92 r
.66632 .27222 .67207 .2798 .68405 .27565 .67833 .26803 Mtetra
.67833 .26803 .68405 .27565 .69607 .27148 .69039 .26384 Mtetra
.69039 .26384 .69607 .27148 .70815 .2673 .7025 .25962 Mtetra
.7025 .25962 .70815 .2673 .72028 .26311 .71467 .25539 Mtetra
.71467 .25539 .72028 .26311 .73246 .25889 .72688 .25114 Mtetra
.72688 .25114 .73246 .25889 .74469 .25466 .73915 .24688 Mtetra
.73915 .24688 .74469 .25466 .75697 .25041 .75147 .24259 Mtetra
.75147 .24259 .75697 .25041 .7693 .24614 .76384 .23829 Mtetra
.76384 .23829 .7693 .24614 .78169 .24186 .77627 .23397 Mtetra
.529 .68 .934 r
.11727 .45407 .12433 .46125 .13237 .47278 .1268 .45323 Mtetra
.706 .566 .695 r
.1268 .45323 .13237 .47278 .14429 .45199 .13751 .44278 Mtetra
.472 .593 .893 r
.13751 .44278 .14429 .45199 .15397 .45042 .14696 .44331 Mtetra
.579 .702 .927 r
.14696 .44331 .15397 .45042 .16358 .4499 .15672 .44157 Mtetra
.951 .66 .451 r
.15672 .44157 .16358 .4499 .17428 .43975 .1562 .53381 Mtetra
0 0 0 r
.1562 .53381 .17428 .43975 .18396 .43937 .17702 .43205 Mtetra
.586 .7 .922 r
.17702 .43205 .18396 .43937 .19386 .43738 .18692 .43017 Mtetra
.551 .691 .932 r
.18692 .43017 .19386 .43738 .20286 .44492 .1968 .42892 Mtetra
.734 .609 .718 r
.1968 .42892 .20286 .44492 .21434 .42761 .20769 .41789 Mtetra
.467 .58 .884 r
.20769 .41789 .21434 .42761 .22435 .42577 .21746 .41862 Mtetra
.603 .714 .923 r
.21746 .41862 .22435 .42577 .23443 .42362 .22757 .41632 Mtetra
.542 .687 .934 r
.22757 .41632 .23443 .42362 .24278 .44205 .23763 .4152 Mtetra
.673 .514 .661 r
.23763 .4152 .24278 .44205 .25521 .41364 .24855 .40455 Mtetra
.51 .62 .896 r
.24855 .40455 .25521 .41364 .26542 .41151 .25861 .40435 Mtetra
.613 .72 .922 r
.25861 .40435 .26542 .41151 .27571 .40896 .26892 .40179 Mtetra
.596 .715 .927 r
.26892 .40179 .27571 .40896 .28588 .4086 .27925 .39957 Mtetra
.905 .724 .646 r
.27925 .39957 .28588 .4086 .29684 .39788 .29197 .36527 Mtetra
0 0 .507 r
.29197 .36527 .29684 .39788 .30717 .39661 .30046 .38921 Mtetra
.61 .714 .919 r
.30046 .38921 .30717 .39661 .31765 .39378 .31094 .38668 Mtetra
.627 .731 .922 r
.31094 .38668 .31765 .39378 .32817 .39094 .3215 .38373 Mtetra
.608 .721 .926 r
.3215 .38373 .32817 .39094 .33864 .38986 .33207 .38121 Mtetra
.963 .659 .405 r
.33207 .38121 .33864 .38986 .3497 .37906 .33597 .49685 Mtetra
0 0 .123 r
.33597 .49685 .3497 .37906 .36026 .37808 .35367 .37052 Mtetra
.612 .714 .918 r
.35367 .37052 .36026 .37808 .37097 .37505 .36438 .3679 Mtetra
.636 .736 .921 r
.36438 .3679 .37097 .37505 .38174 .37175 .37518 .36465 Mtetra
.64 .74 .921 r
.37518 .36465 .38174 .37175 .39255 .36843 .38602 .36128 Mtetra
.636 .738 .922 r
.38602 .36128 .39255 .36843 .4034 .3654 .3969 .35801 Mtetra
.603 .719 .927 r
.3969 .35801 .4034 .3654 .41419 .36572 .40781 .35551 Mtetra
.849 .724 .725 r
.40781 .35551 .41419 .36572 .42542 .35385 .41927 .33793 Mtetra
.3 .367 .765 r
.41927 .33793 .42542 .35385 .43638 .35178 .42996 .34423 Mtetra
.626 .725 .918 r
.42996 .34423 .43638 .35178 .44742 .3484 .44102 .34116 Mtetra
.646 .743 .92 r
.44102 .34116 .44742 .3484 .45851 .34474 .45214 .33757 Mtetra
.652 .748 .92 r
.45214 .33757 .45851 .34474 .46966 .34097 .46331 .33381 Mtetra
.655 .75 .92 r
.46331 .33381 .46966 .34097 .48085 .33711 .47453 .32995 Mtetra
.657 .752 .92 r
.47453 .32995 .48085 .33711 .49208 .33319 .4858 .32603 Mtetra
.658 .753 .92 r
.4858 .32603 .49208 .33319 .50337 .32923 .49711 .32205 Mtetra
.659 .754 .92 r
.49711 .32205 .50337 .32923 .5147 .32524 .50847 .31803 Mtetra
.50847 .31803 .5147 .32524 .52607 .32123 .51988 .31399 Mtetra
.51988 .31399 .52607 .32123 .5375 .31722 .53134 .30994 Mtetra
.53134 .30994 .5375 .31722 .54897 .31319 .54284 .30588 Mtetra
.658 .753 .92 r
.54284 .30588 .54897 .31319 .56048 .30915 .55439 .30181 Mtetra
.55439 .30181 .56048 .30915 .57205 .3051 .56598 .29773 Mtetra
.56598 .29773 .57205 .3051 .58366 .30104 .57763 .29363 Mtetra
.57763 .29363 .58366 .30104 .59532 .29697 .58932 .28953 Mtetra
.58932 .28953 .59532 .29697 .60703 .29288 .60106 .2854 Mtetra
.60106 .2854 .60703 .29288 .61879 .28878 .61286 .28127 Mtetra
.657 .753 .92 r
.61286 .28127 .61879 .28878 .6306 .28466 .6247 .27712 Mtetra
.6247 .27712 .6306 .28466 .64246 .28053 .63659 .27295 Mtetra
.63659 .27295 .64246 .28053 .65437 .27638 .64853 .26877 Mtetra
.64853 .26877 .65437 .27638 .66632 .27222 .66053 .26457 Mtetra
.657 .752 .92 r
.66053 .26457 .66632 .27222 .67833 .26803 .67257 .26036 Mtetra
.67257 .26036 .67833 .26803 .69039 .26384 .68467 .25613 Mtetra
.68467 .25613 .69039 .26384 .7025 .25962 .69681 .25188 Mtetra
.69681 .25188 .7025 .25962 .71467 .25539 .70901 .24762 Mtetra
.70901 .24762 .71467 .25539 .72688 .25114 .72126 .24333 Mtetra
.72126 .24333 .72688 .25114 .73915 .24688 .73357 .23903 Mtetra
.73357 .23903 .73915 .24688 .75147 .24259 .74593 .23471 Mtetra
.74593 .23471 .75147 .24259 .76384 .23829 .75834 .23038 Mtetra
.75834 .23038 .76384 .23829 .77627 .23397 .7708 .22603 Mtetra
.571 .696 .926 r
.11017 .44684 .11727 .45407 .1268 .45323 .1198 .44526 Mtetra
.68 .2 0 r
.1198 .44526 .1268 .45323 .13751 .44278 .12788 .45679 Mtetra
.777 .901 .501 r
.12788 .45679 .13751 .44278 .14696 .44331 .13993 .43587 Mtetra
.573 .692 .922 r
.13993 .43587 .14696 .44331 .15672 .44157 .14968 .43425 Mtetra
.51 .671 .936 r
.14968 .43425 .15672 .44157 .1562 .53381 .15937 .43368 Mtetra
.571 .362 .559 r
.15937 .43368 .1562 .53381 .17702 .43205 .17017 .42343 Mtetra
.518 .635 .905 r
.17017 .42343 .17702 .43205 .18692 .43017 .17992 .423 Mtetra
.591 .709 .926 r
.17992 .423 .18692 .43017 .1968 .42892 .1899 .42096 Mtetra
0 .16 .678 r
.1899 .42096 .1968 .42892 .20769 .41789 .19897 .42848 Mtetra
.756 .917 .545 r
.19897 .42848 .20769 .41789 .21746 .41862 .21056 .41105 Mtetra
.584 .696 .919 r
.21056 .41105 .21746 .41862 .22757 .41632 .22065 .40915 Mtetra
.597 .714 .926 r
.22065 .40915 .22757 .41632 .23763 .4152 .23082 .40694 Mtetra
.841 .401 0 r
.23082 .40694 .23763 .4152 .24855 .40455 .23922 .42539 Mtetra
.667 .775 .301 r
.23922 .42539 .24855 .40455 .25861 .40435 .25179 .39681 Mtetra
.596 .704 .919 r
.25179 .39681 .25861 .40435 .26892 .40179 .26208 .39462 Mtetra
.613 .723 .924 r
.26208 .39462 .26892 .40179 .27925 .39957 .27246 .39201 Mtetra
.499 .666 .937 r
.27246 .39201 .27925 .39957 .29197 .36527 .28271 .39159 Mtetra
.243 0 .227 r
.28271 .39159 .29197 .36527 .30046 .38921 .29378 .38078 Mtetra
.558 .665 .908 r
.29378 .38078 .30046 .38921 .31094 .38668 .3042 .37945 Mtetra
.623 .727 .921 r
.3042 .37945 .31094 .38668 .3215 .38373 .31477 .37656 Mtetra
.623 .729 .923 r
.31477 .37656 .3215 .38373 .33207 .38121 .32539 .37365 Mtetra
.539 .686 .934 r
.32539 .37365 .33207 .38121 .33597 .49685 .33595 .37251 Mtetra
.562 .349 .549 r
.33595 .37251 .33597 .49685 .35367 .37052 .34711 .36161 Mtetra
.545 .648 .902 r
.34711 .36161 .35367 .37052 .36438 .3679 .35776 .36057 Mtetra
.629 .73 .92 r
.35776 .36057 .36438 .3679 .37518 .36465 .36857 .35747 Mtetra
.639 .739 .921 r
.36857 .35747 .37518 .36465 .38602 .36128 .37943 .3541 Mtetra
.639 .74 .921 r
.37943 .3541 .38602 .36128 .3969 .35801 .39035 .35071 Mtetra
.627 .733 .923 r
.39035 .35071 .3969 .35801 .40781 .35551 .4013 .34761 Mtetra
.459 .642 .936 r
.4013 .34761 .40781 .35551 .41927 .33793 .41218 .34788 Mtetra
0 0 0 r
.41218 .34788 .41927 .33793 .42996 .34423 .42353 .3359 Mtetra
.588 .688 .911 r
.42353 .3359 .42996 .34423 .44102 .34116 .43458 .33376 Mtetra
.639 .737 .92 r
.43458 .33376 .44102 .34116 .45214 .33757 .44572 .33031 Mtetra
.649 .746 .92 r
.44572 .33031 .45214 .33757 .46331 .33381 .45692 .32658 Mtetra
.653 .749 .92 r
.45692 .32658 .46331 .33381 .47453 .32995 .46817 .32273 Mtetra
.656 .751 .92 r
.46817 .32273 .47453 .32995 .4858 .32603 .47947 .3188 Mtetra
.657 .753 .92 r
.47947 .3188 .4858 .32603 .49711 .32205 .49081 .3148 Mtetra
.658 .753 .92 r
.49081 .3148 .49711 .32205 .50847 .31803 .5022 .31076 Mtetra
.659 .754 .92 r
.5022 .31076 .50847 .31803 .51988 .31399 .51364 .3067 Mtetra
.51364 .3067 .51988 .31399 .53134 .30994 .52513 .30261 Mtetra
.52513 .30261 .53134 .30994 .54284 .30588 .53666 .29852 Mtetra
.53666 .29852 .54284 .30588 .55439 .30181 .54824 .29441 Mtetra
.658 .753 .92 r
.54824 .29441 .55439 .30181 .56598 .29773 .55987 .29029 Mtetra
.55987 .29029 .56598 .29773 .57763 .29363 .57155 .28617 Mtetra
.57155 .28617 .57763 .29363 .58932 .28953 .58327 .28203 Mtetra
.58327 .28203 .58932 .28953 .60106 .2854 .59505 .27787 Mtetra
.59505 .27787 .60106 .2854 .61286 .28127 .60688 .2737 Mtetra
.60688 .2737 .61286 .28127 .6247 .27712 .61875 .26952 Mtetra
.657 .753 .92 r
.61875 .26952 .6247 .27712 .63659 .27295 .63068 .26532 Mtetra
.63068 .26532 .63659 .27295 .64853 .26877 .64266 .2611 Mtetra
.64266 .2611 .64853 .26877 .66053 .26457 .65468 .25687 Mtetra
.65468 .25687 .66053 .26457 .67257 .26036 .66676 .25262 Mtetra
.657 .752 .92 r
.66676 .25262 .67257 .26036 .68467 .25613 .6789 .24836 Mtetra
.6789 .24836 .68467 .25613 .69681 .25188 .69108 .24408 Mtetra
.69108 .24408 .69681 .25188 .70901 .24762 .70331 .23978 Mtetra
.70331 .23978 .70901 .24762 .72126 .24333 .7156 .23546 Mtetra
.7156 .23546 .72126 .24333 .73357 .23903 .72794 .23113 Mtetra
.72794 .23113 .73357 .23903 .74593 .23471 .74034 .22677 Mtetra
.74034 .22677 .74593 .23471 .75834 .23038 .75279 .2224 Mtetra
.75279 .2224 .75834 .23038 .7708 .22603 .76529 .21801 Mtetra
.537 .66 .916 r
.10311 .43885 .11017 .44684 .1198 .44526 .11266 .43797 Mtetra
.529 .68 .934 r
.11266 .43797 .1198 .44526 .12788 .45679 .12226 .43707 Mtetra
.706 .566 .695 r
.12226 .43707 .12788 .45679 .13993 .43587 .13307 .42654 Mtetra
.472 .593 .893 r
.13307 .42654 .13993 .43587 .14968 .43425 .14259 .42702 Mtetra
.579 .702 .927 r
.14259 .42702 .14968 .43425 .15937 .43368 .15243 .42522 Mtetra
.951 .659 .448 r
.15243 .42522 .15937 .43368 .17017 .42343 .15177 .51782 Mtetra
0 0 0 r
.15177 .51782 .17017 .42343 .17992 .423 .17291 .41556 Mtetra
.586 .7 .922 r
.17291 .41556 .17992 .423 .1899 .42096 .18289 .41362 Mtetra
.551 .691 .932 r
.18289 .41362 .1899 .42096 .19897 .42848 .19285 .41231 Mtetra
.735 .609 .718 r
.19285 .41231 .19897 .42848 .21056 .41105 .20384 .40119 Mtetra
.466 .58 .884 r
.20384 .40119 .21056 .41105 .22065 .40915 .21369 .40188 Mtetra
.603 .714 .923 r
.21369 .40188 .22065 .40915 .23082 .40694 .22389 .39951 Mtetra
.542 .687 .933 r
.22389 .39951 .23082 .40694 .23922 .42539 .23403 .39833 Mtetra
.672 .513 .661 r
.23403 .39833 .23922 .42539 .25179 .39681 .24506 .38758 Mtetra
.509 .62 .897 r
.24506 .38758 .25179 .39681 .26208 .39462 .2552 .38734 Mtetra
.613 .72 .922 r
.2552 .38734 .26208 .39462 .27246 .39201 .26559 .38471 Mtetra
.596 .715 .927 r
.26559 .38471 .27246 .39201 .28271 .39159 .27601 .38242 Mtetra
.906 .725 .646 r
.27601 .38242 .28271 .39159 .29378 .38078 .28887 .34794 Mtetra
0 0 .503 r
.28887 .34794 .29378 .38078 .3042 .37945 .29742 .37191 Mtetra
.61 .714 .919 r
.29742 .37191 .3042 .37945 .31477 .37656 .30799 .36933 Mtetra
.627 .731 .922 r
.30799 .36933 .31477 .37656 .32539 .37365 .31864 .36631 Mtetra
.608 .721 .926 r
.31864 .36631 .32539 .37365 .33595 .37251 .3293 .36372 Mtetra
.963 .659 .401 r
.3293 .36372 .33595 .37251 .34711 .36161 .33313 .47981 Mtetra
0 0 .115 r
.33313 .47981 .34711 .36161 .35776 .36057 .3511 .35287 Mtetra
.612 .714 .918 r
.3511 .35287 .35776 .36057 .36857 .35747 .36191 .35018 Mtetra
.636 .736 .921 r
.36191 .35018 .36857 .35747 .37943 .3541 .3728 .34686 Mtetra
.64 .74 .921 r
.3728 .34686 .37943 .3541 .39035 .35071 .38374 .34343 Mtetra
.636 .738 .922 r
.38374 .34343 .39035 .35071 .4013 .34761 .39473 .34008 Mtetra
.603 .719 .926 r
.39473 .34008 .4013 .34761 .41218 .34788 .40573 .33752 Mtetra
.85 .725 .725 r
.40573 .33752 .41218 .34788 .42353 .3359 .41731 .31981 Mtetra
.298 .366 .764 r
.41731 .31981 .42353 .3359 .43458 .33376 .4281 .32608 Mtetra
.626 .725 .918 r
.4281 .32608 .43458 .33376 .44572 .33031 .43926 .32293 Mtetra
.646 .743 .92 r
.43926 .32293 .44572 .33031 .45692 .32658 .45048 .31927 Mtetra
.652 .748 .92 r
.45048 .31927 .45692 .32658 .46817 .32273 .46176 .31543 Mtetra
.655 .75 .92 r
.46176 .31543 .46817 .32273 .47947 .3188 .47309 .3115 Mtetra
.657 .752 .92 r
.47309 .3115 .47947 .3188 .49081 .3148 .48446 .30749 Mtetra
.658 .753 .92 r
.48446 .30749 .49081 .3148 .5022 .31076 .49588 .30344 Mtetra
.659 .754 .92 r
.49588 .30344 .5022 .31076 .51364 .3067 .50735 .29934 Mtetra
.50735 .29934 .51364 .3067 .52513 .30261 .51887 .29523 Mtetra
.51887 .29523 .52513 .30261 .53666 .29852 .53043 .2911 Mtetra
.53043 .2911 .53666 .29852 .54824 .29441 .54205 .28696 Mtetra
.658 .753 .92 r
.54205 .28696 .54824 .29441 .55987 .29029 .55371 .2828 Mtetra
.55371 .2828 .55987 .29029 .57155 .28617 .56542 .27864 Mtetra
.56542 .27864 .57155 .28617 .58327 .28203 .57718 .27447 Mtetra
.57718 .27447 .58327 .28203 .59505 .27787 .58899 .27028 Mtetra
.58899 .27028 .59505 .27787 .60688 .2737 .60085 .26608 Mtetra
.60085 .26608 .60688 .2737 .61875 .26952 .61276 .26186 Mtetra
.657 .753 .92 r
.61276 .26186 .61875 .26952 .63068 .26532 .62472 .25763 Mtetra
.62472 .25763 .63068 .26532 .64266 .2611 .63673 .25338 Mtetra
.63673 .25338 .64266 .2611 .65468 .25687 .6488 .24911 Mtetra
.6488 .24911 .65468 .25687 .66676 .25262 .66091 .24483 Mtetra
.657 .752 .92 r
.66091 .24483 .66676 .25262 .6789 .24836 .67308 .24053 Mtetra
.67308 .24053 .6789 .24836 .69108 .24408 .6853 .23621 Mtetra
.6853 .23621 .69108 .24408 .70331 .23978 .69757 .23188 Mtetra
.69757 .23188 .70331 .23978 .7156 .23546 .70989 .22753 Mtetra
.70989 .22753 .7156 .23546 .72794 .23113 .72227 .22316 Mtetra
.72227 .22316 .72794 .23113 .74034 .22677 .73471 .21877 Mtetra
.73471 .21877 .74034 .22677 .75279 .2224 .74719 .21436 Mtetra
.74719 .21436 .75279 .2224 .76529 .21801 .75973 .20994 Mtetra
.03 .131 .637 r
.0975 .41949 .10311 .43885 .11266 .43797 .10547 .43062 Mtetra
.571 .696 .926 r
.10547 .43062 .11266 .43797 .12226 .43707 .11518 .42898 Mtetra
.674 .194 0 r
.11518 .42898 .12226 .43707 .13307 .42654 .12331 .44051 Mtetra
.784 .906 .509 r
.12331 .44051 .13307 .42654 .14259 .42702 .13548 .41946 Mtetra
.573 .692 .922 r
.13548 .41946 .14259 .42702 .15243 .42522 .14532 .41777 Mtetra
.51 .671 .936 r
.14532 .41777 .15243 .42522 .15177 .51782 .15508 .41715 Mtetra
.568 .359 .556 r
.15508 .41715 .15177 .51782 .17291 .41556 .16598 .40681 Mtetra
.517 .635 .905 r
.16598 .40681 .17291 .41556 .18289 .41362 .17581 .40633 Mtetra
.591 .709 .926 r
.17581 .40633 .18289 .41362 .19285 .41231 .18587 .40423 Mtetra
0 .165 .683 r
.18587 .40423 .19285 .41231 .20384 .40119 .195 .41173 Mtetra
.763 .922 .553 r
.195 .41173 .20384 .40119 .21369 .40188 .20672 .39417 Mtetra
.584 .696 .919 r
.20672 .39417 .21369 .40188 .22389 .39951 .21689 .39221 Mtetra
.597 .714 .926 r
.21689 .39221 .22389 .39951 .23403 .39833 .22714 .38994 Mtetra
.837 .396 0 r
.22714 .38994 .23403 .39833 .24506 .38758 .23559 .40842 Mtetra
.676 .782 .31 r
.23559 .40842 .24506 .38758 .2552 .38734 .24829 .37967 Mtetra
.596 .704 .919 r
.24829 .37967 .2552 .38734 .26559 .38471 .25868 .37742 Mtetra
.613 .723 .924 r
.25868 .37742 .26559 .38471 .27601 .38242 .26914 .37473 Mtetra
.5 .666 .936 r
.26914 .37473 .27601 .38242 .28887 .34794 .27949 .37426 Mtetra
.232 0 .216 r
.27949 .37426 .28887 .34794 .29742 .37191 .29066 .36335 Mtetra
.558 .665 .909 r
.29066 .36335 .29742 .37191 .30799 .36933 .30117 .36196 Mtetra
.623 .727 .921 r
.30117 .36196 .30799 .36933 .31864 .36631 .31183 .359 Mtetra
.623 .729 .923 r
.31183 .359 .31864 .36631 .3293 .36372 .32255 .35603 Mtetra
.539 .686 .934 r
.32255 .35603 .3293 .36372 .33313 .47981 .3332 .35482 Mtetra
.56 .345 .546 r
.3332 .35482 .33313 .47981 .3511 .35287 .34448 .34383 Mtetra
.545 .648 .902 r
.34448 .34383 .3511 .35287 .36191 .35018 .35521 .34272 Mtetra
.629 .73 .92 r
.35521 .34272 .36191 .35018 .3728 .34686 .36612 .33955 Mtetra
.639 .739 .921 r
.36612 .33955 .3728 .34686 .38374 .34343 .37709 .33611 Mtetra
.639 .74 .921 r
.37709 .33611 .38374 .34343 .39473 .34008 .3881 .33265 Mtetra
.627 .733 .923 r
.3881 .33265 .39473 .34008 .40573 .33752 .39915 .32947 Mtetra
.46 .642 .935 r
.39915 .32947 .40573 .33752 .41731 .31981 .41013 .32969 Mtetra
0 0 0 r
.41013 .32969 .41731 .31981 .4281 .32608 .42159 .3176 Mtetra
.588 .688 .911 r
.42159 .3176 .4281 .32608 .43926 .32293 .43275 .31539 Mtetra
.639 .737 .92 r
.43275 .31539 .43926 .32293 .45048 .31927 .444 .31186 Mtetra
.649 .746 .92 r
.444 .31186 .45048 .31927 .46176 .31543 .4553 .30806 Mtetra
.653 .749 .92 r
.4553 .30806 .46176 .31543 .47309 .3115 .46666 .30413 Mtetra
.656 .751 .92 r
.46666 .30413 .47309 .3115 .48446 .30749 .47806 .30012 Mtetra
.657 .753 .92 r
.47806 .30012 .48446 .30749 .49588 .30344 .48951 .29605 Mtetra
.658 .753 .92 r
.48951 .29605 .49588 .30344 .50735 .29934 .50101 .29193 Mtetra
.659 .754 .92 r
.50101 .29193 .50735 .29934 .51887 .29523 .51256 .28779 Mtetra
.51256 .28779 .51887 .29523 .53043 .2911 .52416 .28362 Mtetra
.52416 .28362 .53043 .2911 .54205 .28696 .53581 .27945 Mtetra
.53581 .27945 .54205 .28696 .55371 .2828 .5475 .27526 Mtetra
.658 .753 .92 r
.5475 .27526 .55371 .2828 .56542 .27864 .55924 .27106 Mtetra
.55924 .27106 .56542 .27864 .57718 .27447 .57104 .26685 Mtetra
.57104 .26685 .57718 .27447 .58899 .27028 .58288 .26263 Mtetra
.58288 .26263 .58899 .27028 .60085 .26608 .59477 .25839 Mtetra
.59477 .25839 .60085 .26608 .61276 .26186 .60672 .25414 Mtetra
.60672 .25414 .61276 .26186 .62472 .25763 .61871 .24987 Mtetra
.657 .753 .92 r
.61871 .24987 .62472 .25763 .63673 .25338 .63076 .24559 Mtetra
.63076 .24559 .63673 .25338 .6488 .24911 .64286 .24129 Mtetra
.64286 .24129 .6488 .24911 .66091 .24483 .65501 .23697 Mtetra
.65501 .23697 .66091 .24483 .67308 .24053 .66721 .23264 Mtetra
.657 .752 .92 r
.66721 .23264 .67308 .24053 .6853 .23621 .67947 .22828 Mtetra
.67947 .22828 .6853 .23621 .69757 .23188 .69178 .22391 Mtetra
.69178 .22391 .69757 .23188 .70989 .22753 .70414 .21953 Mtetra
.70414 .21953 .70989 .22753 .72227 .22316 .71656 .21512 Mtetra
.71656 .21512 .72227 .22316 .73471 .21877 .72903 .2107 Mtetra
.72903 .2107 .73471 .21877 .74719 .21436 .74155 .20626 Mtetra
.74155 .20626 .74719 .21436 .75973 .20994 .75413 .2018 Mtetra
0 0 0 r
.08748 .43304 .0975 .41949 .10547 .43062 .09834 .4225 Mtetra
.537 .66 .916 r
.09834 .4225 .10547 .43062 .11518 .42898 .10796 .42157 Mtetra
.53 .68 .934 r
.10796 .42157 .11518 .42898 .12331 .44051 .11764 .42062 Mtetra
.706 .566 .695 r
.11764 .42062 .12331 .44051 .13548 .41946 .12855 .40999 Mtetra
.471 .593 .893 r
.12855 .40999 .13548 .41946 .14532 .41777 .13814 .41042 Mtetra
.579 .702 .927 r
.13814 .41042 .14532 .41777 .15508 .41715 .14806 .40857 Mtetra
.952 .659 .444 r
.14806 .40857 .15508 .41715 .16598 .40681 .14725 .50152 Mtetra
0 0 0 r
.14725 .50152 .16598 .40681 .17581 .40633 .16872 .39876 Mtetra
.586 .7 .922 r
.16872 .39876 .17581 .40633 .18587 .40423 .17878 .39676 Mtetra
.551 .691 .932 r
.17878 .39676 .18587 .40423 .195 .41173 .18882 .3954 Mtetra
.735 .609 .718 r
.18882 .3954 .195 .41173 .20672 .39417 .19992 .38418 Mtetra
.466 .58 .884 r
.19992 .38418 .20672 .39417 .21689 .39221 .20985 .38481 Mtetra
.603 .714 .923 r
.20985 .38481 .21689 .39221 .22714 .38994 .22013 .38238 Mtetra
.542 .687 .933 r
.22013 .38238 .22714 .38994 .23559 .40842 .23036 .38115 Mtetra
.672 .512 .66 r
.23036 .38115 .23559 .40842 .24829 .37967 .24149 .3703 Mtetra
.509 .62 .897 r
.24149 .3703 .24829 .37967 .25868 .37742 .25172 .37 Mtetra
.613 .72 .922 r
.25172 .37 .25868 .37742 .26914 .37473 .2622 .3673 Mtetra
.596 .715 .927 r
.2622 .3673 .26914 .37473 .27949 .37426 .27271 .36496 Mtetra
.908 .726 .645 r
.27271 .36496 .27949 .37426 .29066 .36335 .28572 .33028 Mtetra
0 0 .5 r
.28572 .33028 .29066 .36335 .30117 .36196 .29431 .35429 Mtetra
.61 .714 .919 r
.29431 .35429 .30117 .36196 .31183 .359 .30498 .35164 Mtetra
.627 .731 .922 r
.30498 .35164 .31183 .359 .32255 .35603 .31572 .34855 Mtetra
.608 .721 .926 r
.31572 .34855 .32255 .35603 .3332 .35482 .32648 .34589 Mtetra
.964 .658 .397 r
.32648 .34589 .3332 .35482 .34448 .34383 .33024 .46243 Mtetra
0 0 .108 r
.33024 .46243 .34448 .34383 .35521 .34272 .34849 .33489 Mtetra
.612 .714 .918 r
.34849 .33489 .35521 .34272 .36612 .33955 .35939 .33213 Mtetra
.636 .736 .921 r
.35939 .33213 .36612 .33955 .37709 .33611 .37038 .32873 Mtetra
.64 .74 .921 r
.37038 .32873 .37709 .33611 .3881 .33265 .38142 .32522 Mtetra
.636 .738 .922 r
.38142 .32522 .3881 .33265 .39915 .32947 .39251 .32181 Mtetra
.603 .719 .926 r
.39251 .32181 .39915 .32947 .41013 .32969 .40362 .31917 Mtetra
.851 .726 .725 r
.40362 .31917 .41013 .32969 .42159 .3176 .41531 .30134 Mtetra
.296 .365 .764 r
.41531 .30134 .42159 .3176 .43275 .31539 .42619 .30756 Mtetra
.626 .725 .918 r
.42619 .30756 .43275 .31539 .444 .31186 .43746 .30434 Mtetra
.646 .743 .92 r
.43746 .30434 .444 .31186 .4553 .30806 .44879 .30061 Mtetra
.652 .748 .92 r
.44879 .30061 .4553 .30806 .46666 .30413 .46018 .29669 Mtetra
.655 .75 .92 r
.46018 .29669 .46666 .30413 .47806 .30012 .47161 .29268 Mtetra
.657 .752 .92 r
.47161 .29268 .47806 .30012 .48951 .29605 .48309 .2886 Mtetra
.658 .753 .92 r
.48309 .2886 .48951 .29605 .50101 .29193 .49463 .28446 Mtetra
.659 .754 .92 r
.49463 .28446 .50101 .29193 .51256 .28779 .50621 .28029 Mtetra
.50621 .28029 .51256 .28779 .52416 .28362 .51784 .27609 Mtetra
.51784 .27609 .52416 .28362 .53581 .27945 .52952 .27188 Mtetra
.52952 .27188 .53581 .27945 .5475 .27526 .54124 .26765 Mtetra
.658 .753 .92 r
.54124 .26765 .5475 .27526 .55924 .27106 .55302 .26342 Mtetra
.55302 .26342 .55924 .27106 .57104 .26685 .56485 .25917 Mtetra
.56485 .25917 .57104 .26685 .58288 .26263 .57672 .25492 Mtetra
.57672 .25492 .58288 .26263 .59477 .25839 .58865 .25064 Mtetra
.58865 .25064 .59477 .25839 .60672 .25414 .60063 .24636 Mtetra
.60063 .24636 .60672 .25414 .61871 .24987 .61266 .24205 Mtetra
.657 .753 .92 r
.61266 .24205 .61871 .24987 .63076 .24559 .62474 .23774 Mtetra
.62474 .23774 .63076 .24559 .64286 .24129 .63688 .2334 Mtetra
.63688 .2334 .64286 .24129 .65501 .23697 .64906 .22905 Mtetra
.64906 .22905 .65501 .23697 .66721 .23264 .6613 .22468 Mtetra
.657 .752 .92 r
.6613 .22468 .66721 .23264 .67947 .22828 .6736 .22029 Mtetra
.6736 .22029 .67947 .22828 .69178 .22391 .68594 .21589 Mtetra
.68594 .21589 .69178 .22391 .70414 .21953 .69834 .21146 Mtetra
.69834 .21146 .70414 .21953 .71656 .21512 .71079 .20702 Mtetra
.71079 .20702 .71656 .21512 .72903 .2107 .7233 .20256 Mtetra
.7233 .20256 .72903 .2107 .74155 .20626 .73587 .19808 Mtetra
.73587 .19808 .74155 .20626 .75413 .2018 .74849 .19359 Mtetra
.853 .712 .706 r
.08045 .42356 .08748 .43304 .09834 .4225 .09268 .40298 Mtetra
.026 .128 .635 r
.09268 .40298 .09834 .4225 .10796 .42157 .10069 .4141 Mtetra
.571 .696 .926 r
.10069 .4141 .10796 .42157 .11764 .42062 .11048 .4124 Mtetra
.667 .188 0 r
.11048 .4124 .11764 .42062 .12855 .40999 .11865 .42393 Mtetra
.791 .91 .517 r
.11865 .42393 .12855 .40999 .13814 .41042 .13095 .40273 Mtetra
.573 .692 .922 r
.13095 .40273 .13814 .41042 .14806 .40857 .14087 .40099 Mtetra
.511 .671 .936 r
.14087 .40099 .14806 .40857 .14725 .50152 .15071 .40032 Mtetra
.566 .355 .554 r
.15071 .40032 .14725 .50152 .16872 .39876 .16171 .38988 Mtetra
.517 .635 .905 r
.16171 .38988 .16872 .39876 .17878 .39676 .17162 .38935 Mtetra
.591 .709 .926 r
.17162 .38935 .17878 .39676 .18882 .3954 .18177 .38718 Mtetra
0 .169 .687 r
.18177 .38718 .18882 .3954 .19992 .38418 .19096 .39466 Mtetra
.77 .926 .561 r
.19096 .39466 .19992 .38418 .20985 .38481 .2028 .37698 Mtetra
.584 .696 .919 r
.2028 .37698 .20985 .38481 .22013 .38238 .21306 .37496 Mtetra
.597 .714 .926 r
.21306 .37496 .22013 .38238 .23036 .38115 .2234 .37262 Mtetra
.833 .391 0 r
.2234 .37262 .23036 .38115 .24149 .3703 .23189 .39112 Mtetra
.685 .789 .319 r
.23189 .39112 .24149 .3703 .25172 .37 .24474 .3622 Mtetra
.596 .704 .919 r
.24474 .3622 .25172 .37 .2622 .3673 .25521 .35988 Mtetra
.613 .723 .924 r
.25521 .35988 .2622 .3673 .27271 .36496 .26577 .35713 Mtetra
.5 .665 .936 r
.26577 .35713 .27271 .36496 .28572 .33028 .2762 .3566 Mtetra
.221 0 .205 r
.2762 .3566 .28572 .33028 .29431 .35429 .28749 .34559 Mtetra
.558 .665 .909 r
.28749 .34559 .29431 .35429 .30498 .35164 .29808 .34414 Mtetra
.623 .727 .921 r
.29808 .34414 .30498 .35164 .31572 .34855 .30884 .3411 Mtetra
.623 .729 .923 r
.30884 .3411 .31572 .34855 .32648 .34589 .31965 .33806 Mtetra
.54 .686 .933 r
.31965 .33806 .32648 .34589 .33024 .46243 .3304 .33679 Mtetra
.557 .342 .544 r
.3304 .33679 .33024 .46243 .34849 .33489 .34178 .3257 Mtetra
.545 .648 .902 r
.34178 .3257 .34849 .33489 .35939 .33213 .35262 .32453 Mtetra
.629 .73 .92 r
.35262 .32453 .35939 .33213 .37038 .32873 .36363 .32128 Mtetra
.639 .739 .921 r
.36363 .32128 .37038 .32873 .38142 .32522 .37469 .31777 Mtetra
.639 .74 .921 r
.37469 .31777 .38142 .32522 .39251 .32181 .38581 .31423 Mtetra
.628 .733 .923 r
.38581 .31423 .39251 .32181 .40362 .31917 .39697 .31098 Mtetra
.461 .642 .935 r
.39697 .31098 .40362 .31917 .41531 .30134 .40805 .31113 Mtetra
0 0 0 r
.40805 .31113 .41531 .30134 .42619 .30756 .41962 .29894 Mtetra
.588 .688 .911 r
.41962 .29894 .42619 .30756 .43746 .30434 .43088 .29666 Mtetra
.639 .737 .92 r
.43088 .29666 .43746 .30434 .44879 .30061 .44223 .29305 Mtetra
.649 .746 .92 r
.44223 .29305 .44879 .30061 .46018 .29669 .45365 .28918 Mtetra
.653 .749 .92 r
.45365 .28918 .46018 .29669 .47161 .29268 .46511 .28517 Mtetra
.656 .751 .92 r
.46511 .28517 .47161 .29268 .48309 .2886 .47663 .28108 Mtetra
.657 .753 .92 r
.47663 .28108 .48309 .2886 .49463 .28446 .48819 .27692 Mtetra
.658 .753 .92 r
.48819 .27692 .49463 .28446 .50621 .28029 .4998 .27273 Mtetra
.659 .754 .92 r
.4998 .27273 .50621 .28029 .51784 .27609 .51146 .2685 Mtetra
.51146 .2685 .51784 .27609 .52952 .27188 .52317 .26425 Mtetra
.52317 .26425 .52952 .27188 .54124 .26765 .53494 .25999 Mtetra
.53494 .25999 .54124 .26765 .55302 .26342 .54675 .25572 Mtetra
.658 .753 .92 r
.54675 .25572 .55302 .26342 .56485 .25917 .55861 .25144 Mtetra
.55861 .25144 .56485 .25917 .57672 .25492 .57052 .24714 Mtetra
.57052 .24714 .57672 .25492 .58865 .25064 .58248 .24284 Mtetra
.58248 .24284 .58865 .25064 .60063 .24636 .59449 .23851 Mtetra
.59449 .23851 .60063 .24636 .61266 .24205 .60656 .23418 Mtetra
.60656 .23418 .61266 .24205 .62474 .23774 .61868 .22982 Mtetra
.657 .753 .92 r
.61868 .22982 .62474 .23774 .63688 .2334 .63085 .22545 Mtetra
.63085 .22545 .63688 .2334 .64906 .22905 .64307 .22106 Mtetra
.64307 .22106 .64906 .22905 .6613 .22468 .65534 .21666 Mtetra
.65534 .21666 .6613 .22468 .6736 .22029 .66767 .21224 Mtetra
.657 .752 .92 r
.66767 .21224 .6736 .22029 .68594 .21589 .68006 .20779 Mtetra
.68006 .20779 .68594 .21589 .69834 .21146 .69249 .20334 Mtetra
.69249 .20334 .69834 .21146 .71079 .20702 .70498 .19886 Mtetra
.70498 .19886 .71079 .20702 .7233 .20256 .71753 .19436 Mtetra
.71753 .19436 .7233 .20256 .73587 .19808 .73013 .18985 Mtetra
.73013 .18985 .73587 .19808 .74849 .19359 .74279 .18531 Mtetra
.42 .626 .939 r
.07312 .41587 .08045 .42356 .09268 .40298 .08252 .41648 Mtetra
0 0 0 r
.08252 .41648 .09268 .40298 .10069 .4141 .09348 .40585 Mtetra
.537 .66 .916 r
.09348 .40585 .10069 .4141 .11048 .4124 .10317 .40486 Mtetra
.53 .68 .934 r
.10317 .40486 .11048 .4124 .11865 .42393 .11293 .40386 Mtetra
.706 .566 .695 r
.11293 .40386 .11865 .42393 .13095 .40273 .12395 .39314 Mtetra
.471 .593 .894 r
.12395 .39314 .13095 .40273 .14087 .40099 .13361 .39351 Mtetra
.579 .702 .927 r
.13361 .39351 .14087 .40099 .15071 .40032 .14361 .3916 Mtetra
.953 .659 .441 r
.14361 .3916 .15071 .40032 .16171 .38988 .14265 .48491 Mtetra
0 0 0 r
.14265 .48491 .16171 .38988 .17162 .38935 .16445 .38165 Mtetra
.586 .7 .922 r
.16445 .38165 .17162 .38935 .18177 .38718 .17459 .37959 Mtetra
.551 .691 .932 r
.17459 .37959 .18177 .38718 .19096 .39466 .18472 .37816 Mtetra
.735 .61 .718 r
.18472 .37816 .19096 .39466 .2028 .37698 .19593 .36685 Mtetra
.465 .58 .885 r
.19593 .36685 .2028 .37698 .21306 .37496 .20593 .36743 Mtetra
.603 .714 .923 r
.20593 .36743 .21306 .37496 .2234 .37262 .21631 .36493 Mtetra
.543 .687 .933 r
.21631 .36493 .2234 .37262 .23189 .39112 .22662 .36364 Mtetra
.671 .511 .66 r
.22662 .36364 .23189 .39112 .24474 .3622 .23786 .35269 Mtetra
.509 .62 .897 r
.23786 .35269 .24474 .3622 .25521 .35988 .24817 .35233 Mtetra
.613 .72 .922 r
.24817 .35233 .25521 .35988 .26577 .35713 .25875 .34956 Mtetra
.596 .715 .927 r
.25875 .34956 .26577 .35713 .2762 .3566 .26935 .34715 Mtetra
.909 .727 .644 r
.26935 .34715 .2762 .3566 .28749 .34559 .28251 .31228 Mtetra
0 0 .497 r
.28251 .31228 .28749 .34559 .29808 .34414 .29115 .33633 Mtetra
.609 .714 .919 r
.29115 .33633 .29808 .34414 .30884 .3411 .30191 .3336 Mtetra
.627 .731 .922 r
.30191 .3336 .30884 .3411 .31965 .33806 .31275 .33045 Mtetra
.608 .721 .925 r
.31275 .33045 .31965 .33806 .3304 .33679 .32361 .32772 Mtetra
.964 .657 .393 r
.32361 .32772 .3304 .33679 .34178 .3257 .32728 .44469 Mtetra
0 0 .1 r
.32728 .44469 .34178 .3257 .35262 .32453 .34582 .31655 Mtetra
.611 .714 .918 r
.34582 .31655 .35262 .32453 .36363 .32128 .35682 .31372 Mtetra
.636 .736 .921 r
.35682 .31372 .36363 .32128 .37469 .31777 .36791 .31025 Mtetra
.64 .74 .921 r
.36791 .31025 .37469 .31777 .38581 .31423 .37906 .30667 Mtetra
.636 .738 .922 r
.37906 .30667 .38581 .31423 .39697 .31098 .39025 .30317 Mtetra
.603 .719 .926 r
.39025 .30317 .39697 .31098 .40805 .31113 .40146 .30046 Mtetra
.852 .727 .725 r
.40146 .30046 .40805 .31113 .41962 .29894 .41327 .2825 Mtetra
.294 .364 .764 r
.41327 .2825 .41962 .29894 .43088 .29666 .42425 .28869 Mtetra
.626 .725 .918 r
.42425 .28869 .43088 .29666 .44223 .29305 .43563 .28539 Mtetra
.646 .743 .92 r
.43563 .28539 .44223 .29305 .45365 .28918 .44707 .28157 Mtetra
.652 .748 .92 r
.44707 .28157 .45365 .28918 .46511 .28517 .45856 .27758 Mtetra
.655 .75 .92 r
.45856 .27758 .46511 .28517 .47663 .28108 .47011 .27349 Mtetra
.657 .752 .92 r
.47011 .27349 .47663 .28108 .48819 .27692 .4817 .26932 Mtetra
.658 .753 .92 r
.4817 .26932 .48819 .27692 .4998 .27273 .49335 .2651 Mtetra
.659 .754 .92 r
.49335 .2651 .4998 .27273 .51146 .2685 .50504 .26085 Mtetra
.50504 .26085 .51146 .2685 .52317 .26425 .51678 .25657 Mtetra
.51678 .25657 .52317 .26425 .53494 .25999 .52858 .25227 Mtetra
.52858 .25227 .53494 .25999 .54675 .25572 .54042 .24796 Mtetra
.658 .753 .92 r
.54042 .24796 .54675 .25572 .55861 .25144 .55232 .24364 Mtetra
.55232 .24364 .55861 .25144 .57052 .24714 .56426 .23931 Mtetra
.56426 .23931 .57052 .24714 .58248 .24284 .57626 .23497 Mtetra
.57626 .23497 .58248 .24284 .59449 .23851 .58831 .23061 Mtetra
.58831 .23061 .59449 .23851 .60656 .23418 .60041 .22624 Mtetra
.60041 .22624 .60656 .23418 .61868 .22982 .61256 .22185 Mtetra
.657 .753 .92 r
.61256 .22185 .61868 .22982 .63085 .22545 .62477 .21744 Mtetra
.62477 .21744 .63085 .22545 .64307 .22106 .63702 .21301 Mtetra
.63702 .21301 .64307 .22106 .65534 .21666 .64934 .20857 Mtetra
.64934 .20857 .65534 .21666 .66767 .21224 .6617 .20411 Mtetra
.657 .752 .92 r
.6617 .20411 .66767 .21224 .68006 .20779 .67412 .19964 Mtetra
.67412 .19964 .68006 .20779 .69249 .20334 .6866 .19514 Mtetra
.6866 .19514 .69249 .20334 .70498 .19886 .69913 .19063 Mtetra
.69913 .19063 .70498 .19886 .71753 .19436 .71171 .18609 Mtetra
.71171 .18609 .71753 .19436 .73013 .18985 .72435 .18154 Mtetra
.72435 .18154 .73013 .18985 .74279 .18531 .73705 .17697 Mtetra
.556 .69 .929 r
.06572 .40832 .07312 .41587 .08252 .41648 .0754 .40687 Mtetra
.854 .712 .706 r
.0754 .40687 .08252 .41648 .09348 .40585 .08777 .38615 Mtetra
.021 .125 .633 r
.08777 .38615 .09348 .40585 .10317 .40486 .09582 .39727 Mtetra
.571 .696 .926 r
.09582 .39727 .10317 .40486 .11293 .40386 .10568 .39551 Mtetra
.661 .182 0 r
.10568 .39551 .11293 .40386 .12395 .39314 .1139 .40704 Mtetra
.797 .915 .524 r
.1139 .40704 .12395 .39314 .13361 .39351 .12634 .3857 Mtetra
.573 .692 .922 r
.12634 .3857 .13361 .39351 .14361 .3916 .13634 .3839 Mtetra
.511 .671 .936 r
.13634 .3839 .14361 .3916 .14265 .48491 .14626 .38317 Mtetra
.564 .352 .551 r
.14626 .38317 .14265 .48491 .16445 .38165 .15736 .37264 Mtetra
.517 .635 .905 r
.15736 .37264 .16445 .38165 .17459 .37959 .16736 .37204 Mtetra
.591 .709 .925 r
.16736 .37204 .17459 .37959 .18472 .37816 .17759 .36981 Mtetra
0 .174 .692 r
.17759 .36981 .18472 .37816 .19593 .36685 .18684 .37727 Mtetra
.776 .93 .568 r
.18684 .37727 .19593 .36685 .20593 .36743 .1988 .35946 Mtetra
.584 .696 .919 r
.1988 .35946 .20593 .36743 .21631 .36493 .20915 .35737 Mtetra
.597 .714 .926 r
.20915 .35737 .21631 .36493 .22662 .36364 .21958 .35497 Mtetra
.828 .386 0 r
.21958 .35497 .22662 .36364 .23786 .35269 .22812 .37349 Mtetra
.694 .797 .329 r
.22812 .37349 .23786 .35269 .24817 .35233 .24111 .34439 Mtetra
.595 .704 .919 r
.24111 .34439 .24817 .35233 .25875 .34956 .25167 .34201 Mtetra
.613 .723 .924 r
.25167 .34201 .25875 .34956 .26935 .34715 .26233 .33919 Mtetra
.501 .665 .936 r
.26233 .33919 .26935 .34715 .28251 .31228 .27285 .33859 Mtetra
.21 0 .194 r
.27285 .33859 .28251 .31228 .29115 .33633 .28424 .32748 Mtetra
.557 .665 .909 r
.28424 .32748 .29115 .33633 .30191 .3336 .29493 .32597 Mtetra
.623 .727 .921 r
.29493 .32597 .30191 .3336 .31275 .33045 .30579 .32286 Mtetra
.623 .729 .923 r
.30579 .32286 .31275 .33045 .32361 .32772 .3167 .31975 Mtetra
.54 .686 .933 r
.3167 .31975 .32361 .32772 .32728 .44469 .32755 .31841 Mtetra
.555 .338 .541 r
.32755 .31841 .32728 .44469 .34582 .31655 .33904 .30721 Mtetra
.545 .648 .902 r
.33904 .30721 .34582 .31655 .35682 .31372 .34998 .30597 Mtetra
.629 .73 .92 r
.34998 .30597 .35682 .31372 .36791 .31025 .36108 .30266 Mtetra
.639 .739 .921 r
.36108 .30266 .36791 .31025 .37906 .30667 .37225 .29906 Mtetra
.639 .74 .921 r
.37225 .29906 .37906 .30667 .39025 .30317 .38348 .29546 Mtetra
.628 .733 .923 r
.38348 .29546 .39025 .30317 .40146 .30046 .39474 .29213 Mtetra
.461 .642 .935 r
.39474 .29213 .40146 .30046 .41327 .2825 .40592 .29222 Mtetra
0 0 0 r
.40592 .29222 .41327 .2825 .42425 .28869 .4176 .27991 Mtetra
.588 .688 .911 r
.4176 .27991 .42425 .28869 .43563 .28539 .42897 .27756 Mtetra
.639 .737 .92 r
.42897 .27756 .43563 .28539 .44707 .28157 .44044 .27387 Mtetra
.649 .746 .92 r
.44044 .27387 .44707 .28157 .45856 .27758 .45196 .26991 Mtetra
.653 .749 .92 r
.45196 .26991 .45856 .27758 .47011 .27349 .46353 .26582 Mtetra
.656 .751 .92 r
.46353 .26582 .47011 .27349 .4817 .26932 .47516 .26165 Mtetra
.657 .753 .92 r
.47516 .26165 .4817 .26932 .49335 .2651 .48684 .25741 Mtetra
.658 .753 .92 r
.48684 .25741 .49335 .2651 .50504 .26085 .49857 .25313 Mtetra
.659 .754 .92 r
.49857 .25313 .50504 .26085 .51678 .25657 .51034 .24882 Mtetra
.51034 .24882 .51678 .25657 .52858 .25227 .52217 .24449 Mtetra
.52217 .24449 .52858 .25227 .54042 .24796 .53405 .24014 Mtetra
.53405 .24014 .54042 .24796 .55232 .24364 .54598 .23579 Mtetra
.658 .753 .92 r
.54598 .23579 .55232 .24364 .56426 .23931 .55795 .23142 Mtetra
.55795 .23142 .56426 .23931 .57626 .23497 .56999 .22704 Mtetra
.56999 .22704 .57626 .23497 .58831 .23061 .58207 .22264 Mtetra
.58207 .22264 .58831 .23061 .60041 .22624 .59421 .21823 Mtetra
.59421 .21823 .60041 .22624 .61256 .22185 .60639 .2138 Mtetra
.60639 .2138 .61256 .22185 .62477 .21744 .61864 .20936 Mtetra
.657 .753 .92 r
.61864 .20936 .62477 .21744 .63702 .21301 .63093 .2049 Mtetra
.63093 .2049 .63702 .21301 .64934 .20857 .64328 .20042 Mtetra
.64328 .20042 .64934 .20857 .6617 .20411 .65568 .19593 Mtetra
.65568 .19593 .6617 .20411 .67412 .19964 .66814 .19141 Mtetra
.657 .752 .92 r
.66814 .19141 .67412 .19964 .6866 .19514 .68065 .18688 Mtetra
.68065 .18688 .6866 .19514 .69913 .19063 .69322 .18233 Mtetra
.69322 .18233 .69913 .19063 .71171 .18609 .70585 .17776 Mtetra
.70585 .17776 .71171 .18609 .72435 .18154 .71853 .17317 Mtetra
.71853 .17317 .72435 .18154 .73705 .17697 .73126 .16856 Mtetra
.542 .669 .92 r
.05834 .40021 .06572 .40832 .0754 .40687 .06799 .39906 Mtetra
.42 .626 .938 r
.06799 .39906 .0754 .40687 .08777 .38615 .07746 .39962 Mtetra
0 0 0 r
.07746 .39962 .08777 .38615 .09582 .39727 .08852 .38889 Mtetra
.536 .66 .916 r
.08852 .38889 .09582 .39727 .10568 .39551 .0983 .38784 Mtetra
.53 .68 .934 r
.0983 .38784 .10568 .39551 .1139 .40704 .10813 .38679 Mtetra
.706 .566 .695 r
.10813 .38679 .1139 .40704 .12634 .3857 .11925 .37596 Mtetra
.47 .593 .894 r
.11925 .37596 .12634 .3857 .13634 .3839 .12899 .37629 Mtetra
.579 .702 .927 r
.12899 .37629 .13634 .3839 .14626 .38317 .13908 .37431 Mtetra
.954 .659 .438 r
.13908 .37431 .14626 .38317 .15736 .37264 .13796 .46797 Mtetra
0 0 0 r
.13796 .46797 .15736 .37264 .16736 .37204 .1601 .36421 Mtetra
.586 .7 .922 r
.1601 .36421 .16736 .37204 .17759 .36981 .17033 .36209 Mtetra
.551 .691 .932 r
.17033 .36209 .17759 .36981 .18684 .37727 .18054 .3606 Mtetra
.735 .61 .718 r
.18054 .3606 .18684 .37727 .1988 .35946 .19185 .34918 Mtetra
.465 .579 .885 r
.19185 .34918 .1988 .35946 .20915 .35737 .20194 .34971 Mtetra
.603 .714 .923 r
.20194 .34971 .20915 .35737 .21958 .35497 .21241 .34715 Mtetra
.543 .687 .933 r
.21241 .34715 .21958 .35497 .22812 .37349 .22281 .34579 Mtetra
.671 .511 .659 r
.22281 .34579 .22812 .37349 .24111 .34439 .23415 .33474 Mtetra
.508 .62 .897 r
.23415 .33474 .24111 .34439 .25167 .34201 .24456 .33432 Mtetra
.613 .72 .922 r
.24456 .33432 .25167 .34201 .26233 .33919 .25523 .33148 Mtetra
.596 .715 .927 r
.25523 .33148 .26233 .33919 .27285 .33859 .26592 .329 Mtetra
.91 .728 .643 r
.26592 .329 .27285 .33859 .28424 .32748 .27924 .29394 Mtetra
0 0 .494 r
.27924 .29394 .28424 .32748 .29493 .32597 .28792 .31802 Mtetra
.609 .714 .919 r
.28792 .31802 .29493 .32597 .30579 .32286 .29878 .31522 Mtetra
.627 .731 .922 r
.29878 .31522 .30579 .32286 .3167 .31975 .30972 .31199 Mtetra
.608 .721 .925 r
.30972 .31199 .3167 .31975 .32755 .31841 .32068 .30919 Mtetra
.965 .657 .389 r
.32068 .30919 .32755 .31841 .33904 .30721 .32427 .4266 Mtetra
0 0 .092 r
.32427 .4266 .33904 .30721 .34998 .30597 .34309 .29785 Mtetra
.611 .714 .918 r
.34309 .29785 .34998 .30597 .36108 .30266 .3542 .29495 Mtetra
.636 .736 .921 r
.3542 .29495 .36108 .30266 .37225 .29906 .3654 .2914 Mtetra
.64 .74 .921 r
.3654 .2914 .37225 .29906 .38348 .29546 .37665 .28774 Mtetra
.636 .738 .922 r
.37665 .28774 .38348 .29546 .39474 .29213 .38794 .28417 Mtetra
.603 .719 .926 r
.38794 .28417 .39474 .29213 .40592 .29222 .39926 .28139 Mtetra
.853 .728 .725 r
.39926 .28139 .40592 .29222 .4176 .27991 .4112 .26329 Mtetra
.292 .362 .764 r
.4112 .26329 .4176 .27991 .42897 .27756 .42227 .26943 Mtetra
.626 .725 .918 r
.42227 .26943 .42897 .27756 .44044 .27387 .43376 .26605 Mtetra
.645 .743 .92 r
.43376 .26605 .44044 .27387 .45196 .26991 .44531 .26216 Mtetra
.652 .748 .92 r
.44531 .26216 .45196 .26991 .46353 .26582 .45691 .25808 Mtetra
.655 .75 .92 r
.45691 .25808 .46353 .26582 .47516 .26165 .46857 .25391 Mtetra
.657 .752 .92 r
.46857 .25391 .47516 .26165 .48684 .25741 .48028 .24966 Mtetra
.658 .753 .92 r
.48028 .24966 .48684 .25741 .49857 .25313 .49204 .24535 Mtetra
.659 .754 .92 r
.49204 .24535 .49857 .25313 .51034 .24882 .50385 .24101 Mtetra
.50385 .24101 .51034 .24882 .52217 .24449 .51571 .23665 Mtetra
.51571 .23665 .52217 .24449 .53405 .24014 .52762 .23226 Mtetra
.52762 .23226 .53405 .24014 .54598 .23579 .53958 .22787 Mtetra
.658 .753 .92 r
.53958 .22787 .54598 .23579 .55795 .23142 .5516 .22346 Mtetra
.5516 .22346 .55795 .23142 .56999 .22704 .56366 .21904 Mtetra
.56366 .21904 .56999 .22704 .58207 .22264 .57578 .21461 Mtetra
.57578 .21461 .58207 .22264 .59421 .21823 .58795 .21016 Mtetra
.58795 .21016 .59421 .21823 .60639 .2138 .60018 .2057 Mtetra
.60018 .2057 .60639 .2138 .61864 .20936 .61246 .20122 Mtetra
.657 .753 .92 r
.61246 .20122 .61864 .20936 .63093 .2049 .62479 .19672 Mtetra
.62479 .19672 .63093 .2049 .64328 .20042 .63717 .19221 Mtetra
.63717 .19221 .64328 .20042 .65568 .19593 .64961 .18767 Mtetra
.64961 .18767 .65568 .19593 .66814 .19141 .66211 .18312 Mtetra
.657 .752 .92 r
.66211 .18312 .66814 .19141 .68065 .18688 .67466 .17855 Mtetra
.67466 .17855 .68065 .18688 .69322 .18233 .68727 .17396 Mtetra
.68727 .17396 .69322 .18233 .70585 .17776 .69993 .16935 Mtetra
.69993 .16935 .70585 .17776 .71853 .17317 .71265 .16472 Mtetra
.71265 .16472 .71853 .17317 .73126 .16856 .72543 .16007 Mtetra
.244 .373 .796 r
.05171 .38664 .05834 .40021 .06799 .39906 .0605 .39138 Mtetra
.556 .69 .929 r
.0605 .39138 .06799 .39906 .07746 .39962 .07027 .38987 Mtetra
.855 .713 .705 r
.07027 .38987 .07746 .39962 .08852 .38889 .08276 .36901 Mtetra
.016 .121 .632 r
.08276 .36901 .08852 .38889 .0983 .38784 .09086 .38012 Mtetra
.571 .696 .926 r
.09086 .38012 .0983 .38784 .10813 .38679 .1008 .37831 Mtetra
.654 .176 0 r
.1008 .37831 .10813 .38679 .11925 .37596 .10907 .38982 Mtetra
.804 .919 .532 r
.10907 .38982 .11925 .37596 .12899 .37629 .12164 .36834 Mtetra
.573 .692 .922 r
.12164 .36834 .12899 .37629 .13908 .37431 .13172 .36648 Mtetra
.511 .671 .936 r
.13172 .36648 .13908 .37431 .13796 .46797 .14172 .36569 Mtetra
.561 .348 .549 r
.14172 .36569 .13796 .46797 .1601 .36421 .15293 .35506 Mtetra
.517 .635 .906 r
.15293 .35506 .1601 .36421 .17033 .36209 .16301 .35441 Mtetra
.591 .709 .925 r
.16301 .35441 .17033 .36209 .18054 .3606 .17332 .35211 Mtetra
0 .179 .696 r
.17332 .35211 .18054 .3606 .19185 .34918 .18265 .35954 Mtetra
.783 .934 .576 r
.18265 .35954 .19185 .34918 .20194 .34971 .19473 .3416 Mtetra
.584 .696 .919 r
.19473 .3416 .20194 .34971 .21241 .34715 .20517 .33945 Mtetra
.597 .714 .926 r
.20517 .33945 .21241 .34715 .22281 .34579 .21569 .33698 Mtetra
.824 .381 0 r
.21569 .33698 .22281 .34579 .23415 .33474 .22427 .35551 Mtetra
.703 .803 .338 r
.22427 .35551 .23415 .33474 .24456 .33432 .23742 .32624 Mtetra
.595 .704 .919 r
.23742 .32624 .24456 .33432 .25523 .33148 .24807 .32379 Mtetra
.613 .723 .924 r
.24807 .32379 .25523 .33148 .26592 .329 .25882 .3209 Mtetra
.501 .665 .936 r
.25882 .3209 .26592 .329 .27924 .29394 .26944 .32024 Mtetra
.199 0 .182 r
.26944 .32024 .27924 .29394 .28792 .31802 .28094 .30902 Mtetra
.557 .665 .909 r
.28094 .30902 .28792 .31802 .29878 .31522 .29172 .30744 Mtetra
.623 .727 .921 r
.29172 .30744 .29878 .31522 .30972 .31199 .30268 .30426 Mtetra
.623 .729 .923 r
.30268 .30426 .30972 .31199 .32068 .30919 .31369 .30107 Mtetra
.54 .685 .933 r
.31369 .30107 .32068 .30919 .32427 .4266 .32463 .29967 Mtetra
.552 .334 .538 r
.32463 .29967 .32427 .4266 .34309 .29785 .33624 .28836 Mtetra
.545 .649 .902 r
.33624 .28836 .34309 .29785 .3542 .29495 .34728 .28706 Mtetra
.629 .73 .92 r
.34728 .28706 .3542 .29495 .3654 .2914 .35849 .28366 Mtetra
.639 .739 .921 r
.35849 .28366 .3654 .2914 .37665 .28774 .36977 .27999 Mtetra
.639 .74 .921 r
.36977 .27999 .37665 .28774 .38794 .28417 .38109 .2763 Mtetra
.628 .733 .923 r
.38109 .2763 .38794 .28417 .39926 .28139 .39246 .2729 Mtetra
.462 .642 .935 r
.39246 .2729 .39926 .28139 .4112 .26329 .40375 .27292 Mtetra
0 0 0 r
.40375 .27292 .4112 .26329 .42227 .26943 .41555 .2605 Mtetra
.588 .688 .911 r
.41555 .2605 .42227 .26943 .43376 .26605 .42703 .25807 Mtetra
.639 .737 .92 r
.42703 .25807 .43376 .26605 .44531 .26216 .4386 .2543 Mtetra
.649 .746 .92 r
.4386 .2543 .44531 .26216 .45691 .25808 .45024 .25026 Mtetra
.653 .749 .92 r
.45024 .25026 .45691 .25808 .46857 .25391 .46193 .24609 Mtetra
.656 .751 .92 r
.46193 .24609 .46857 .25391 .48028 .24966 .47367 .24183 Mtetra
.657 .753 .92 r
.47367 .24183 .48028 .24966 .49204 .24535 .48546 .23751 Mtetra
.658 .753 .92 r
.48546 .23751 .49204 .24535 .50385 .24101 .4973 .23314 Mtetra
.659 .754 .92 r
.4973 .23314 .50385 .24101 .51571 .23665 .5092 .22874 Mtetra
.5092 .22874 .51571 .23665 .52762 .23226 .52114 .22432 Mtetra
.52114 .22432 .52762 .23226 .53958 .22787 .53314 .21989 Mtetra
.53314 .21989 .53958 .22787 .5516 .22346 .54519 .21544 Mtetra
.658 .753 .92 r
.54519 .21544 .5516 .22346 .56366 .21904 .55729 .21099 Mtetra
.55729 .21099 .56366 .21904 .57578 .21461 .56944 .20651 Mtetra
.56944 .20651 .57578 .21461 .58795 .21016 .58165 .20203 Mtetra
.58165 .20203 .58795 .21016 .60018 .2057 .59391 .19753 Mtetra
.59391 .19753 .60018 .2057 .61246 .20122 .60623 .19301 Mtetra
.60623 .19301 .61246 .20122 .62479 .19672 .61859 .18847 Mtetra
.657 .753 .92 r
.61859 .18847 .62479 .19672 .63717 .19221 .63102 .18392 Mtetra
.63102 .18392 .63717 .19221 .64961 .18767 .6435 .17935 Mtetra
.6435 .17935 .64961 .18767 .66211 .18312 .65603 .17476 Mtetra
.65603 .17476 .66211 .18312 .67466 .17855 .66862 .17015 Mtetra
.657 .752 .92 r
.66862 .17015 .67466 .17855 .68727 .17396 .68126 .16552 Mtetra
.68126 .16552 .68727 .17396 .69993 .16935 .69397 .16088 Mtetra
.69397 .16088 .69993 .16935 .71265 .16472 .70673 .15621 Mtetra
.70673 .15621 .71265 .16472 .72543 .16007 .71954 .15152 Mtetra
.669 .933 .646 r
.04179 .3948 .05171 .38664 .0605 .39138 .05304 .38314 Mtetra
.542 .669 .92 r
.05304 .38314 .0605 .39138 .07027 .38987 .06277 .38192 Mtetra
.421 .626 .938 r
.06277 .38192 .07027 .38987 .08276 .36901 .07231 .38243 Mtetra
0 0 0 r
.07231 .38243 .08276 .36901 .09086 .38012 .08348 .37161 Mtetra
.536 .66 .916 r
.08348 .37161 .09086 .38012 .1008 .37831 .09333 .3705 Mtetra
.53 .68 .934 r
.09333 .3705 .1008 .37831 .10907 .38982 .10324 .36939 Mtetra
.705 .566 .695 r
.10324 .36939 .10907 .38982 .12164 .36834 .11447 .35846 Mtetra
.47 .593 .894 r
.11447 .35846 .12164 .36834 .13172 .36648 .12429 .35874 Mtetra
.579 .702 .927 r
.12429 .35874 .13172 .36648 .14172 .36569 .13445 .3567 Mtetra
.955 .658 .435 r
.13445 .3567 .14172 .36569 .15293 .35506 .13318 .4507 Mtetra
0 0 0 r
.13318 .4507 .15293 .35506 .16301 .35441 .15566 .34644 Mtetra
.586 .7 .922 r
.15566 .34644 .16301 .35441 .17332 .35211 .16598 .34425 Mtetra
.551 .691 .932 r
.16598 .34425 .17332 .35211 .18265 .35954 .17628 .3427 Mtetra
.736 .61 .718 r
.17628 .3427 .18265 .35954 .19473 .3416 .1877 .33118 Mtetra
.464 .579 .885 r
.1877 .33118 .19473 .3416 .20517 .33945 .19788 .33165 Mtetra
.603 .714 .923 r
.19788 .33165 .20517 .33945 .21569 .33698 .20843 .32901 Mtetra
.543 .687 .933 r
.20843 .32901 .21569 .33698 .22427 .35551 .21892 .32759 Mtetra
.671 .51 .659 r
.21892 .32759 .22427 .35551 .23742 .32624 .23038 .31644 Mtetra
.508 .62 .897 r
.23038 .31644 .23742 .32624 .24807 .32379 .24087 .31596 Mtetra
.613 .72 .922 r
.24087 .31596 .24807 .32379 .25882 .3209 .25164 .31305 Mtetra
.596 .715 .927 r
.25164 .31305 .25882 .3209 .26944 .32024 .26243 .3105 Mtetra
.911 .728 .642 r
.26243 .3105 .26944 .32024 .28094 .30902 .2759 .27524 Mtetra
0 0 .491 r
.2759 .27524 .28094 .30902 .29172 .30744 .28463 .29934 Mtetra
.609 .714 .919 r
.28463 .29934 .29172 .30744 .30268 .30426 .29559 .29647 Mtetra
.627 .731 .922 r
.29559 .29647 .30268 .30426 .31369 .30107 .30663 .29317 Mtetra
.608 .721 .925 r
.30663 .29317 .31369 .30107 .32463 .29967 .31769 .29029 Mtetra
.965 .656 .384 r
.31769 .29029 .32463 .29967 .33624 .28836 .3212 .40813 Mtetra
0 0 .084 r
.3212 .40813 .33624 .28836 .34728 .28706 .34032 .27878 Mtetra
.611 .714 .918 r
.34032 .27878 .34728 .28706 .35849 .28366 .35153 .2758 Mtetra
.636 .736 .921 r
.35153 .2758 .35849 .28366 .36977 .27999 .36283 .27218 Mtetra
.64 .74 .921 r
.36283 .27218 .36977 .27999 .38109 .2763 .37419 .26844 Mtetra
.636 .738 .922 r
.37419 .26844 .38109 .2763 .39246 .2729 .38559 .26479 Mtetra
.603 .719 .926 r
.38559 .26479 .39246 .2729 .40375 .27292 .39701 .26192 Mtetra
.854 .729 .725 r
.39701 .26192 .40375 .27292 .41555 .2605 .40908 .24369 Mtetra
.29 .361 .764 r
.40908 .24369 .41555 .2605 .42703 .25807 .42025 .24979 Mtetra
.626 .725 .918 r
.42025 .24979 .42703 .25807 .4386 .2543 .43185 .24633 Mtetra
.645 .743 .92 r
.43185 .24633 .4386 .2543 .45024 .25026 .44351 .24235 Mtetra
.652 .748 .92 r
.44351 .24235 .45024 .25026 .46193 .24609 .45523 .23819 Mtetra
.655 .75 .92 r
.45523 .23819 .46193 .24609 .47367 .24183 .467 .23393 Mtetra
.657 .752 .92 r
.467 .23393 .47367 .24183 .48546 .23751 .47883 .22959 Mtetra
.658 .753 .92 r
.47883 .22959 .48546 .23751 .4973 .23314 .49071 .2252 Mtetra
.659 .754 .92 r
.49071 .2252 .4973 .23314 .5092 .22874 .50263 .22077 Mtetra
.50263 .22077 .5092 .22874 .52114 .22432 .51461 .21632 Mtetra
.51461 .21632 .52114 .22432 .53314 .21989 .52664 .21184 Mtetra
.52664 .21184 .53314 .21989 .54519 .21544 .53873 .20736 Mtetra
.658 .753 .92 r
.53873 .20736 .54519 .21544 .55729 .21099 .55086 .20286 Mtetra
.55086 .20286 .55729 .21099 .56944 .20651 .56305 .19835 Mtetra
.56305 .19835 .56944 .20651 .58165 .20203 .5753 .19383 Mtetra
.5753 .19383 .58165 .20203 .59391 .19753 .58759 .18929 Mtetra
.58759 .18929 .59391 .19753 .60623 .19301 .59994 .18473 Mtetra
.59994 .18473 .60623 .19301 .61859 .18847 .61235 .18016 Mtetra
.657 .753 .92 r
.61235 .18016 .61859 .18847 .63102 .18392 .62481 .17557 Mtetra
.62481 .17557 .63102 .18392 .6435 .17935 .63733 .17096 Mtetra
.63733 .17096 .6435 .17935 .65603 .17476 .6499 .16633 Mtetra
.6499 .16633 .65603 .17476 .66862 .17015 .66253 .16168 Mtetra
.657 .752 .92 r
.66253 .16168 .66862 .17015 .68126 .16552 .67521 .15702 Mtetra
.67521 .15702 .68126 .16552 .69397 .16088 .68795 .15233 Mtetra
.68795 .15233 .69397 .16088 .70673 .15621 .70075 .14762 Mtetra
.70075 .14762 .70673 .15621 .71954 .15152 .71361 .1429 Mtetra
.808 .694 .738 r
.03464 .38389 .04179 .3948 .05304 .38314 .04634 .36941 Mtetra
.242 .372 .796 r
.04634 .36941 .05304 .38314 .06277 .38192 .05519 .37411 Mtetra
.556 .689 .929 r
.05519 .37411 .06277 .38192 .07231 .38243 .06503 .37255 Mtetra
.855 .714 .705 r
.06503 .37255 .07231 .38243 .08348 .37161 .07766 .35155 Mtetra
.011 .118 .63 r
.07766 .35155 .08348 .37161 .09333 .3705 .08581 .36265 Mtetra
.571 .696 .926 r
.08581 .36265 .09333 .3705 .10324 .36939 .09583 .36077 Mtetra
.648 .17 0 r
.09583 .36077 .10324 .36939 .11447 .35846 .10414 .37227 Mtetra
.81 .923 .539 r
.10414 .37227 .11447 .35846 .12429 .35874 .11685 .35065 Mtetra
.573 .692 .922 r
.11685 .35065 .12429 .35874 .13445 .3567 .12701 .34873 Mtetra
.511 .671 .936 r
.12701 .34873 .13445 .3567 .13318 .4507 .13709 .34787 Mtetra
.559 .345 .546 r
.13709 .34787 .13318 .4507 .15566 .34644 .14842 .33715 Mtetra
.516 .635 .906 r
.14842 .33715 .15566 .34644 .16598 .34425 .15857 .33643 Mtetra
.591 .709 .925 r
.15857 .33643 .16598 .34425 .17628 .3427 .16898 .33407 Mtetra
0 .183 .7 r
.16898 .33407 .17628 .3427 .1877 .33118 .17837 .34146 Mtetra
.789 .938 .583 r
.17837 .34146 .1877 .33118 .19788 .33165 .19058 .3234 Mtetra
.584 .696 .919 r
.19058 .3234 .19788 .33165 .20843 .32901 .20111 .32118 Mtetra
.597 .714 .926 r
.20111 .32118 .20843 .32901 .21892 .32759 .21172 .31864 Mtetra
.819 .376 0 r
.21172 .31864 .21892 .32759 .23038 .31644 .22035 .33718 Mtetra
.711 .81 .347 r
.22035 .33718 .23038 .31644 .24087 .31596 .23365 .30773 Mtetra
.595 .704 .919 r
.23365 .30773 .24087 .31596 .25164 .31305 .2444 .30521 Mtetra
.613 .723 .924 r
.2444 .30521 .25164 .31305 .26243 .3105 .25524 .30224 Mtetra
.501 .665 .936 r
.25524 .30224 .26243 .3105 .2759 .27524 .26595 .30152 Mtetra
.187 0 .17 r
.26595 .30152 .2759 .27524 .28463 .29934 .27757 .2902 Mtetra
.557 .665 .909 r
.27757 .2902 .28463 .29934 .29559 .29647 .28845 .28855 Mtetra
.623 .727 .921 r
.28845 .28855 .29559 .29647 .30663 .29317 .29951 .28529 Mtetra
.623 .729 .923 r
.29951 .28529 .30663 .29317 .31769 .29029 .31062 .28202 Mtetra
.54 .685 .933 r
.31062 .28202 .31769 .29029 .3212 .40813 .32166 .28055 Mtetra
.549 .33 .535 r
.32166 .28055 .3212 .40813 .34032 .27878 .33339 .26914 Mtetra
.544 .649 .902 r
.33339 .26914 .34032 .27878 .35153 .2758 .34453 .26776 Mtetra
.629 .73 .92 r
.34453 .26776 .35153 .2758 .36283 .27218 .35584 .26428 Mtetra
.639 .739 .921 r
.35584 .26428 .36283 .27218 .37419 .26844 .36723 .26053 Mtetra
.639 .74 .921 r
.36723 .26053 .37419 .26844 .38559 .26479 .37866 .25676 Mtetra
.628 .733 .923 r
.37866 .25676 .38559 .26479 .39701 .26192 .39014 .25328 Mtetra
.462 .642 .935 r
.39014 .25328 .39701 .26192 .40908 .24369 .40153 .25323 Mtetra
0 0 0 r
.40153 .25323 .40908 .24369 .42025 .24979 .41346 .24069 Mtetra
.588 .688 .911 r
.41346 .24069 .42025 .24979 .43185 .24633 .42504 .23819 Mtetra
.639 .737 .92 r
.42504 .23819 .43185 .24633 .44351 .24235 .43673 .23434 Mtetra
.649 .746 .92 r
.43673 .23434 .44351 .24235 .45523 .23819 .44848 .23021 Mtetra
.653 .749 .92 r
.44848 .23021 .45523 .23819 .467 .23393 .46029 .22595 Mtetra
.656 .751 .92 r
.46029 .22595 .467 .23393 .47883 .22959 .47214 .2216 Mtetra
.657 .753 .92 r
.47214 .2216 .47883 .22959 .49071 .2252 .48405 .21719 Mtetra
.658 .753 .92 r
.48405 .21719 .49071 .2252 .50263 .22077 .49602 .21274 Mtetra
.659 .754 .92 r
.49602 .21274 .50263 .22077 .51461 .21632 .50803 .20825 Mtetra
.50803 .20825 .51461 .21632 .52664 .21184 .5201 .20374 Mtetra
.5201 .20374 .52664 .21184 .53873 .20736 .53221 .19921 Mtetra
.53221 .19921 .53873 .20736 .55086 .20286 .54439 .19468 Mtetra
.658 .753 .92 r
.54439 .19468 .55086 .20286 .56305 .19835 .55661 .19013 Mtetra
.55661 .19013 .56305 .19835 .5753 .19383 .56889 .18556 Mtetra
.56889 .18556 .5753 .19383 .58759 .18929 .58122 .18099 Mtetra
.58122 .18099 .58759 .18929 .59994 .18473 .59361 .17639 Mtetra
.59361 .17639 .59994 .18473 .61235 .18016 .60605 .17178 Mtetra
.60605 .17178 .61235 .18016 .62481 .17557 .61855 .16715 Mtetra
.657 .753 .92 r
.61855 .16715 .62481 .17557 .63733 .17096 .63111 .1625 Mtetra
.63111 .1625 .63733 .17096 .6499 .16633 .64372 .15783 Mtetra
.64372 .15783 .6499 .16633 .66253 .16168 .65638 .15315 Mtetra
.65638 .15315 .66253 .16168 .67521 .15702 .66911 .14844 Mtetra
.657 .752 .92 r
.66911 .14844 .67521 .15702 .68795 .15233 .68189 .14371 Mtetra
.68189 .14371 .68795 .15233 .70075 .14762 .69473 .13897 Mtetra
.69473 .13897 .70075 .14762 .71361 .1429 .70762 .1342 Mtetra
.307 .565 .929 r
.02702 .37574 .03464 .38389 .04634 .36941 .03628 .37751 Mtetra
.679 .939 .656 r
.03628 .37751 .04634 .36941 .05519 .37411 .04763 .36574 Mtetra
.542 .669 .92 r
.04763 .36574 .05519 .37411 .06503 .37255 .05744 .36447 Mtetra
.421 .626 .938 r
.05744 .36447 .06503 .37255 .07766 .35155 .06706 .36492 Mtetra
0 0 0 r
.06706 .36492 .07766 .35155 .08581 .36265 .07834 .354 Mtetra
.536 .66 .916 r
.07834 .354 .08581 .36265 .09583 .36077 .08827 .35283 Mtetra
.53 .68 .934 r
.08827 .35283 .09583 .36077 .10414 .37227 .09826 .35165 Mtetra
.705 .566 .694 r
.09826 .35165 .10414 .37227 .11685 .35065 .1096 .34063 Mtetra
.47 .593 .894 r
.1096 .34063 .11685 .35065 .12701 .34873 .11949 .34084 Mtetra
.579 .702 .927 r
.11949 .34084 .12701 .34873 .13709 .34787 .12974 .33874 Mtetra
.955 .658 .431 r
.12974 .33874 .13709 .34787 .14842 .33715 .1283 .43308 Mtetra
0 0 0 r
.1283 .43308 .14842 .33715 .15857 .33643 .15114 .32833 Mtetra
.585 .7 .922 r
.15114 .32833 .15857 .33643 .16898 .33407 .16155 .32607 Mtetra
.551 .691 .932 r
.16155 .32607 .16898 .33407 .17837 .34146 .17194 .32445 Mtetra
.736 .61 .718 r
.17194 .32445 .17837 .34146 .19058 .3234 .18347 .31282 Mtetra
.464 .579 .885 r
.18347 .31282 .19058 .3234 .20111 .32118 .19373 .31323 Mtetra
.603 .714 .923 r
.19373 .31323 .20111 .32118 .21172 .31864 .20438 .31053 Mtetra
.543 .687 .933 r
.20438 .31053 .21172 .31864 .22035 .33718 .21496 .30904 Mtetra
.67 .509 .658 r
.21496 .30904 .22035 .33718 .23365 .30773 .22653 .29778 Mtetra
.508 .62 .897 r
.22653 .29778 .23365 .30773 .2444 .30521 .23711 .29723 Mtetra
.613 .72 .922 r
.23711 .29723 .2444 .30521 .25524 .30224 .24798 .29425 Mtetra
.596 .715 .927 r
.24798 .29425 .25524 .30224 .26595 .30152 .25886 .29162 Mtetra
.912 .729 .641 r
.25886 .29162 .26595 .30152 .27757 .2902 .2725 .25617 Mtetra
0 0 .487 r
.2725 .25617 .27757 .2902 .28845 .28855 .28128 .2803 Mtetra
.609 .714 .919 r
.28128 .2803 .28845 .28855 .29951 .28529 .29234 .27735 Mtetra
.627 .731 .922 r
.29234 .27735 .29951 .28529 .31062 .28202 .30348 .27397 Mtetra
.608 .721 .925 r
.30348 .27397 .31062 .28202 .32166 .28055 .31464 .27102 Mtetra
.966 .655 .38 r
.31464 .27102 .32166 .28055 .33339 .26914 .31806 .38928 Mtetra
0 0 .076 r
.31806 .38928 .33339 .26914 .34453 .26776 .33749 .25933 Mtetra
.611 .714 .918 r
.33749 .25933 .34453 .26776 .35584 .26428 .3488 .25627 Mtetra
.636 .736 .921 r
.3488 .25627 .35584 .26428 .36723 .26053 .36021 .25257 Mtetra
.64 .74 .921 r
.36021 .25257 .36723 .26053 .37866 .25676 .37168 .24874 Mtetra
.636 .738 .922 r
.37168 .24874 .37866 .25676 .39014 .25328 .38319 .24501 Mtetra
.603 .719 .926 r
.38319 .24501 .39014 .25328 .40153 .25323 .39472 .24207 Mtetra
.855 .73 .725 r
.39472 .24207 .40153 .25323 .41346 .24069 .40691 .2237 Mtetra
.288 .36 .763 r
.40691 .2237 .41346 .24069 .42504 .23819 .41819 .22975 Mtetra
.626 .726 .918 r
.41819 .22975 .42504 .23819 .43673 .23434 .4299 .2262 Mtetra
.645 .743 .92 r
.4299 .2262 .43673 .23434 .44848 .23021 .44168 .22214 Mtetra
.652 .748 .92 r
.44168 .22214 .44848 .23021 .46029 .22595 .45351 .21789 Mtetra
.655 .75 .92 r
.45351 .21789 .46029 .22595 .47214 .2216 .4654 .21354 Mtetra
.657 .752 .92 r
.4654 .21354 .47214 .2216 .48405 .21719 .47735 .20911 Mtetra
.658 .753 .92 r
.47735 .20911 .48405 .21719 .49602 .21274 .48934 .20463 Mtetra
.659 .754 .92 r
.48934 .20463 .49602 .21274 .50803 .20825 .50139 .20011 Mtetra
.50139 .20011 .50803 .20825 .5201 .20374 .51349 .19557 Mtetra
.51349 .19557 .5201 .20374 .53221 .19921 .52565 .191 Mtetra
.52565 .191 .53221 .19921 .54439 .19468 .53786 .18643 Mtetra
.658 .753 .92 r
.53786 .18643 .54439 .19468 .55661 .19013 .55012 .18184 Mtetra
.55012 .18184 .55661 .19013 .56889 .18556 .56243 .17723 Mtetra
.56243 .17723 .56889 .18556 .58122 .18099 .5748 .17261 Mtetra
.5748 .17261 .58122 .18099 .59361 .17639 .58723 .16798 Mtetra
.58723 .16798 .59361 .17639 .60605 .17178 .59971 .16333 Mtetra
.59971 .16333 .60605 .17178 .61855 .16715 .61224 .15866 Mtetra
.657 .753 .92 r
.61224 .15866 .61855 .16715 .63111 .1625 .62484 .15397 Mtetra
.62484 .15397 .63111 .1625 .64372 .15783 .63748 .14926 Mtetra
.63748 .14926 .64372 .15783 .65638 .15315 .65019 .14454 Mtetra
.65019 .14454 .65638 .15315 .66911 .14844 .66295 .13979 Mtetra
.657 .752 .92 r
.66295 .13979 .66911 .14844 .68189 .14371 .67577 .13502 Mtetra
.67577 .13502 .68189 .14371 .69473 .13897 .68865 .13024 Mtetra
.68865 .13024 .69473 .13897 .70762 .1342 .70159 .12543 Mtetra
.541 .682 .93 r
.01931 .3678 .02702 .37574 .03628 .37751 .02905 .36645 Mtetra
.809 .694 .738 r
.02905 .36645 .03628 .37751 .04763 .36574 .04086 .35186 Mtetra
.24 .371 .796 r
.04086 .35186 .04763 .36574 .05744 .36447 .04977 .35652 Mtetra
.556 .689 .929 r
.04977 .35652 .05744 .36447 .06706 .36492 .0597 .35489 Mtetra
.856 .715 .705 r
.0597 .35489 .06706 .36492 .07834 .354 .07247 .33376 Mtetra
.006 .114 .628 r
.07247 .33376 .07834 .354 .08827 .35283 .08065 .34484 Mtetra
.571 .696 .926 r
.08065 .34484 .08827 .35283 .09826 .35165 .09076 .34289 Mtetra
.641 .164 0 r
.09076 .34289 .09826 .35165 .1096 .34063 .09911 .35439 Mtetra
.816 .926 .546 r
.09911 .35439 .1096 .34063 .11949 .34084 .11196 .33262 Mtetra
.573 .692 .922 r
.11196 .33262 .11949 .34084 .12974 .33874 .12221 .33063 Mtetra
.512 .671 .936 r
.12221 .33063 .12974 .33874 .1283 .43308 .13238 .32971 Mtetra
.556 .341 .543 r
.13238 .32971 .1283 .43308 .15114 .32833 .14381 .31888 Mtetra
.516 .635 .906 r
.14381 .31888 .15114 .32833 .16155 .32607 .15405 .3181 Mtetra
.591 .709 .925 r
.15405 .3181 .16155 .32607 .17194 .32445 .16455 .31567 Mtetra
0 .188 .704 r
.16455 .31567 .17194 .32445 .18347 .31282 .174 .32303 Mtetra
.795 .942 .59 r
.174 .32303 .18347 .31282 .19373 .31323 .18634 .30484 Mtetra
.584 .696 .919 r
.18634 .30484 .19373 .31323 .20438 .31053 .19696 .30255 Mtetra
.597 .714 .926 r
.19696 .30255 .20438 .31053 .21496 .30904 .20767 .29993 Mtetra
.815 .371 0 r
.20767 .29993 .21496 .30904 .22653 .29778 .21636 .31848 Mtetra
.72 .817 .356 r
.21636 .31848 .22653 .29778 .23711 .29723 .2298 .28886 Mtetra
.595 .704 .919 r
.2298 .28886 .23711 .29723 .24798 .29425 .24065 .28626 Mtetra
.613 .723 .924 r
.24065 .28626 .24798 .29425 .25886 .29162 .25159 .28322 Mtetra
.502 .665 .936 r
.25159 .28322 .25886 .29162 .2725 .25617 .2624 .28243 Mtetra
.174 0 .157 r
.2624 .28243 .2725 .25617 .28128 .2803 .27414 .271 Mtetra
.557 .665 .909 r
.27414 .271 .28128 .2803 .29234 .27735 .28511 .26927 Mtetra
.623 .727 .921 r
.28511 .26927 .29234 .27735 .30348 .27397 .29627 .26594 Mtetra
.623 .729 .923 r
.29627 .26594 .30348 .27397 .31464 .27102 .30749 .26259 Mtetra
.541 .685 .933 r
.30749 .26259 .31464 .27102 .31806 .38928 .31864 .26105 Mtetra
.547 .326 .532 r
.31864 .26105 .31806 .38928 .33749 .25933 .33048 .24952 Mtetra
.544 .649 .903 r
.33048 .24952 .33749 .25933 .3488 .25627 .34172 .24807 Mtetra
.629 .73 .92 r
.34172 .24807 .3488 .25627 .36021 .25257 .35314 .24452 Mtetra
.639 .739 .921 r
.35314 .24452 .36021 .25257 .37168 .24874 .36464 .24068 Mtetra
.639 .74 .921 r
.36464 .24068 .37168 .24874 .38319 .24501 .37618 .23683 Mtetra
.628 .733 .923 r
.37618 .23683 .38319 .24501 .39472 .24207 .38777 .23326 Mtetra
.463 .642 .934 r
.38777 .23326 .39472 .24207 .40691 .2237 .39927 .23314 Mtetra
0 0 0 r
.39927 .23314 .40691 .2237 .41819 .22975 .41132 .22049 Mtetra
.588 .688 .911 r
.41132 .22049 .41819 .22975 .4299 .2262 .42302 .2179 Mtetra
.639 .737 .92 r
.42302 .2179 .4299 .2262 .44168 .22214 .43482 .21396 Mtetra
.649 .746 .92 r
.43482 .21396 .44168 .22214 .45351 .21789 .44669 .20974 Mtetra
.653 .749 .92 r
.44669 .20974 .45351 .21789 .4654 .21354 .45861 .20539 Mtetra
.656 .751 .92 r
.45861 .20539 .4654 .21354 .47735 .20911 .47059 .20096 Mtetra
.657 .753 .92 r
.47059 .20096 .47735 .20911 .48934 .20463 .48262 .19646 Mtetra
.658 .753 .92 r
.48262 .19646 .48934 .20463 .50139 .20011 .4947 .19191 Mtetra
.659 .754 .92 r
.4947 .19191 .50139 .20011 .51349 .19557 .50684 .18733 Mtetra
.50684 .18733 .51349 .19557 .52565 .191 .51903 .18272 Mtetra
.51903 .18272 .52565 .191 .53786 .18643 .53127 .17811 Mtetra
.53127 .17811 .53786 .18643 .55012 .18184 .54357 .17348 Mtetra
.658 .753 .92 r
.54357 .17348 .55012 .18184 .56243 .17723 .55592 .16883 Mtetra
.55592 .16883 .56243 .17723 .5748 .17261 .56833 .16417 Mtetra
.56833 .16417 .5748 .17261 .58723 .16798 .58079 .1595 Mtetra
.58079 .1595 .58723 .16798 .59971 .16333 .59331 .15481 Mtetra
.59331 .15481 .59971 .16333 .61224 .15866 .60588 .1501 Mtetra
.60588 .1501 .61224 .15866 .62484 .15397 .61851 .14537 Mtetra
.657 .753 .92 r
.61851 .14537 .62484 .15397 .63748 .14926 .6312 .14062 Mtetra
.6312 .14062 .63748 .14926 .65019 .14454 .64394 .13586 Mtetra
.64394 .13586 .65019 .14454 .66295 .13979 .65675 .13107 Mtetra
.65675 .13107 .66295 .13979 .67577 .13502 .66961 .12626 Mtetra
.657 .752 .92 r
.66961 .12626 .67577 .13502 .68865 .13024 .68253 .12144 Mtetra
.68253 .12144 .68865 .13024 .70159 .12543 .6955 .11659 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05eoo`0GD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBo@0GOol00`00
Oomoo`17Ool008Moo`<006=oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aB
o5;mD_`005;lD_d00U;l5goo00<007ooOol0AWoo0025Ool2001ROol085;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_dFOol00`00Oomoo`16
Ool0089oo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`00e;mD_aoo`0FOol00`00Oomoo`15Ool0081oo`8006=oo`0UD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_`05goo00<007ooOol0A7oo001mOol3001QOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo003D_eB
o7oo01Eoo`03001oogoo04Aoo`00Ngoo0P000Woo00<007ooOol0GGoo02aBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;m5goo00<007ooOol0@goo001hOol3001ROol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@0GOol00`00Oomoo`12Ool007Ioo`80065oo`0dD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`12Ool007=oo`<0065oo`9Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo004D_eBo5;lD_`GOol00`00Oomoo`11Ool0075o
o`80069oo`0iD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;l01Eoo`03001oo`00049oo`00KWoo0`00H7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomoo`10Ool006]oo`<0065o
o`10D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_dGOol00`00Oomoo`0oOol006Uoo`8000=oo`03001oogoo05]oo`03D_aBoE;l009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aB
o5;lD_d00U;l5Woo00<007ooOol0?goo001VOol3001OOol0BE<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m01Ioo`03001oogoo03ioo`00I7oo0P00H7oo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l5Woo00<007ooOol0?Goo001QOol3001POol0Ce;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m01Eoo`03001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P00Ggoo00=Bo5;mD_`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol0
9Woo00<007ooOol04goo000dOol00`00Oomoo`02Ool00`00Oomoo`0POol3001POol0EE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo02Eoo`03
001oogoo01=oo`00>Goo00<007ooOol07Woo0P000Woo00<007ooOol0G7oo0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;m
D_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Eoo`03001oogoo02Aoo`03
001oo`0001Aoo`00;7oo1P001goo00<007ooOol06goo0`00Ggoo05aBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Woo00<007ooOol08goo
00<007oo000057oo000eOol4000LOol2001POol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0FOol00`00Oomoo`0QOol01@00
Oomoogoo00004goo000eOol00`00Oomoo`0JOol3001POol0HU;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol2000S
Ool01@00Oomoogoo00004goo000eOol00`00Oomoo`0GOol3001OOol2D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d05Goo00<007ooOol07goo0`0000Aoo`000000019oo`00=Goo1@004goo0P00H7oo06U>
g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol0=goo001:Ool300000goo001o
o`1MOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009B
o003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol027oo
1000:goo0018Ool2001OOol0L4kLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m5Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0:7oo0015Ool3001MOol5B[`01TkL
D_e>g4klC]aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`0
05;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`FOol00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Oomoo`0XOol004=oo`8005moo`80001dB[e6_4ZlA[aBoDkLD_e>g5;mC]aBoDkL
D_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Ioo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo02Qoo`00@7oo0`00H7oo00=ZeR5G00001DZl0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o006D_eBo5;lD_aBoE;l5Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0:7oo000nOol2
001ROol0NSZMJ]I^mb5G8GQ>g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`FOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003]oo`@0069o
o`07>YeZeV[FJ]HQMb5G8GP00dkL00E>gDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_aoo`0DOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003Uoo`80
00Aoo`03001oogoo05Qoo`24C_e>g4kmC]`jWCIm>YeZeVkgJ]I^mV[F9GPQEb5hC]a>oDkLD_e>g5;m
C]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol00goo1000
:goo000fOol3001MOol02dkLC_a>o5;mC]a>gDkLC_e>g3ZM>Wd01F[F00TQEb5g8ELQN4kLC_a>g5;m
C]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0COol200000goo001o
o`0bOol003=oo`<005ioo`0AD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLK_MZeVkfJ]I^m`020000N4Jl
B[e6_4ZlC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEo
o`03001oogoo035oo`00<Goo0P00Ggoo00=>o5;mC]`00Tkl00IBoDkLC_a>o5;mB]`3B]d01d[LJ]IZ
eV[F8ELQM`0000E:_005C_aBo5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m01Eoo`03001oogoo031oo`00;Woo0`00GGoo07=BoDkLC_e>g5;mC]aBoDkLD_e>g5;m
C]aBoDkLD_e:g4kMB]a>gF[FK_MZeVkf8ELUN25GC]e>g4kmC]a>gDkLD_e>g5;mC]aBoDklD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0300007E;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d05Goo00<007ooOol0;goo000/Ool4001JOol0
1D4`AC12W4JL@Y`00TkL00I>gDkLC]a>o5;mC]`2C_`01TkmC]a>oDkLB]e:g0=:g@=ZeP058GPQEb5g
8EM>g@03C]`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00000005;m
00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;l
D_`EOol00`00Oomoo`0_Ool002Yoo`8005eoo`1b@C15D44`AYa2O4JL@W]BoDkLC_e>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLC]e:g4kMB]a^mV[FK_LQEbEh8ELUN4kLC]e>g4kmC]aBoDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m0`0002ABoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0^Ool002Yoo`8005ao
o`05@C15<44`AE11<002@Y`01TJL@Ya>o4kLC_e>g09>o00:D_e>g4klC]a>oDkLC]e>g3ZM>Wd5J]H0
2R5G8GPQEb5gC]aBoDkLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0800005D_eBo5;lD_aB
o@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m009Bo1Eoo`03001oogoo02ioo`0047oo1@000goo100017oo10001Woo00<007oo0000FWoo
06m1<4E@@C15D44`AE1:_4kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g6kfJ]I^mf[F
K_IZeTZmA[a:_4JlB[e>g5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`0002YBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0]Ool0019oo`03001oogoo009oo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`03Ool200000goo001oo`17Ool00a0450Aoo`0:Ool4@[d034D`@C15
D44`AC11<002B]a>g4[LC]e:g09>o006D_e>g4klC_aBoDkL0Tkl00A:gD[LB]e:g@AZeP8000A:_007
C_a>g5;mC]a>o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo006D_eBo5;lD_aBoE;l0`000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0E
Ool00`00Oomoo`0/Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`02Ool20003Ool00`00Oomoo`15Ool00a@440Aoo`06Ool0LD[LC_e>g4kmB]a6_D:lA[e1<4E@
@C15D44`AE000@02C]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMB]a^mV[FK_LQEbEh
001:_DJlB[a6_5;mC]aBoDkLD_e>o5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`00035Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo00EOol00`00Oomoo`0/Ool000Moo`H000Eoo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`14Ool00a0450@@1003
Ool3C]`01TkMC]a>gDkLC]e>g092_@06AE11<4D`@C15D44`0T:L00I6W4kLC]a>g4kMC]`2C_`01e;m
C]a>oDkLC_e>g4km009:g@03B]a:gF[F00=ZeP038ELQN25G009>g006C]e>g5;lD_aBoDkl0U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo0000080
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Aoo`03001oogoo
02]oo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo049oo`1e40@D17;C00m2W4Jl@Ya6_4[LC_e>g4kmB]a>gD[LC]e2W4Jm
@C15D44`AE11<4JL@W]6W49kC_e>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC]eZeVkf
J]HUN25G9GPQEdkmC]a>gDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l00<0000iD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l01=oo`03001oo`0002aoo`004Woo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo009oo`8000Ioo`80049oo`0450Abdg;D00h4AY`024kMC]a>
g4kLC_e>g4[MB]`2@[d01dD`@C15D44`AC11<4JL00=2W006C_e>g4klC]a>oDkL0Tkl00UBoDkLC]e>
g4kmC]a>gCYm>Yd01F[F00<QMb5G8GP00dkL00EBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo003D_eBo000008000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0ZOol0011oo`<000Ao
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0n
Ool0L1@4L]=bm7;C00l03TJl@Ya6_4:LC_e>g4kmC]a>oD[LC]e2_4Jm@C15D44`AE11<4E@@C1>gDZl
C]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]`jWCImK_IZeVkgJ]I^mR5G9GPQEbEhC]aBoDkL
D_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0`00041Bo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oAEoo`03001oogoo02Uoo`004Woo00<007ooOol00goo100017oo10001Goo00<007ooOol027oo00<0
07ooOol0?Goo00Qbdg;DL]=be00>00l03TkM0d[L00I>oDkLC]e>g4kmB]`2@[d03TE@@C15<44`AE11
<4E@009>gD[LC]a:g4kmC]`2C_`02U;mC]a>o4klD_e>g4kMC]a>oDkL1F[F0P0014Zl00E>g4klC]aB
oDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`30003D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aB
o1Ioo`03001oogoo02Qoo`00:7oo00<007ooOol02Woo00<007ooOol0=Goo079:g4kmB]a>gD[L?[dn
WG;dL]=fm7;CL_@03P0?00i>gDZlC]e:_4kmB]a>oDkLC_e2W4Jm@C15D44`AE11<4E@@C000TZlC]e:
_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gD[LK_MZeVkfJ]HUN000B[a6_4ZmA[a:_4kLD_e>
g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d20000Ae;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`05Goo00<007ooOol0:7oo000XOol3000;Ool00`00Oomoo`0`Ool05D[MB[a:g4ZlB]e:g4kMB]a>
gCjML]Abdg;DL]=be7;C00l03P0?00i>g@03C]`014kMC]a>gDkL0T:m00]5<44`AE11<4D`@C15D001
009>g4kM00=>g00:D_e>g4klC_aBoDkLC_e>g4kmB]`3B]d2J]H00cYmJ]IZeP028GL01TkMC]a>g4kL
C]e>o09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`00`000U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004
D_eBo5;lD_`EOol00`00Oomoo`0WOol002Qoo`03001oogoo00aoo`03001oogoo02moo`1`FbY:gDZl
B]e:_4kMB]a>oD[LC]ebdgKdL]=bm7;CM_A2W4Jl@Ya6_4:LC_e:g4kmC]a>oD[LC_e2_4Jm@C15D44`
AE11<4E@@W]6W49kAYa>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]dfO6kgJ]I^mR5G
9GPQEdkMC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_d30000CU;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02Ioo`00:7oo00<007ooOol03Goo00<007ooOol0
;Goo0e/Z00I:gDZlB]a:_4[MB]`3B]d01W;CL]Abdg;DL]=be0A6W003C]a>gDkL009>g00=C]e:g4:m
@[e5D44`AC11<4E@@C15D4:LAY`00T:L00M>g4kmC]a>o4kLD_e>g002C_`025;mC]a>gDkLC_e>g3ZM
>Wd4J]H01BEh8ELQMb5gC]d00dkL00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol002Qoo`8000moo`03001o
ogoo02aoo`1[Fb]K:U];FbY>gD[LC]e:g4[MB[a:gD[LL_AbdgKdL]=bm7;CA[a2W4Jl@Ya6_4kLC_e>
g4kmC]a>gD:LA[e1<4E@@C15D44`AE11<4EAB[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>
g4km=W`jWF[FK_IZeVkgJ]HUN25G9GPQEe;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7@030000EU;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`0UOol002Qo
o`03001oogoo00moo`03001oogoo02Yoo`04FbYAm3il?W/2?W`01TkMB]a>gD[LB]e:g09:g@06L]Ab
dg;DL]=be00>0T[L00Q>gD[LB]a>g4kmC]a>gDkL0T:m00a5<44`AE11<4E@@C15D44`009:g4kMB]`2
C]`01TkmC]a>o4klD_e>g09>o005C_e>g4kMC]a>o@06J]H5B[`01E;mC]a>o4kLD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`00`000U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aB
o@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Goo00<0
07ooOol097oo000XOol00`00Oomoo`0@Ool00`00Oomoo`0QOol014ZlB]e:_4[M17oo06IAm5HDDOA2
O3iK@Wa:g4kMB]a>gD[L?[dnW3jmL]=bm7;CM_Abd`0?00i>gDZlC]e:_4kMC]a>oD[LC_e2_4Jm@C15
D44`AE11<4E@@C15D001C]e:_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gD[LC]eZeVkgJ]I^
mR5G0016_4ZlA[a:_DJlD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDad30000GE<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol2000VOol002Moo`03001oogoo019oo`03001o
ogoo01aoo`06B[e6_4ZlB[a:_D[L0T[M00EUH7ooOomUH5Gd009Am08nO00>?W/nO4[LC]e:g4kMB]`n
WG;CL]Abdg;DL]=be0803`0400h03dkLC]d3C]`02TkMC]a2_D:mAE11<4D`@C15D44`0TE@0P020TkL
00i>gDkLC]a>o5;mC]a>o4kLC_e>g4kmC]a:gD[L0T[M16[F00DUN25G8GM>g4kM00=>g005D_e>o5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00<0009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@02D_`DOol00`00Oomoo`0SOol002Moo`<001=oo`03001oogoo01Yoo`1]Im9S/T[MA[a:gDJl
B]e:_4[MB[aUH6E0EQAAm5HDDOAF54ZlB]e:_4[MB]a>gD[LC_e:g7;dL]=fm7;CL_AbddJl@Ya6_4:L
A[a>g4kmB]a>oDkLC_e2W4Jm@C15D44`AE11<4E@@C16W49kAYa2Ne;mC]a>oDkLD_e>g5;mC]aBoDkL
D_e>g5;mB]a>gD[LC]e:g6kfJ]I^mb5G9GPQEbEhC]a>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDad00`0006AC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001o
ogoo029oo`009goo00<007ooOol057oo00<007ooOol06Goo0f>b00EW/T[LB]e:g4[M0092_@9UH0=A
m00:EOAK:U/ZB[a:gDZlB]a:_4[MB]`2B]d01W;DL]=be7;CL]Abd`A6W09>g004C]e>g4kLB]`2@[d0
14D`@C15D44`14E@0T:L00I6W49lC_a>g4kmC]`2C_`01e;mC]a>o4kLC_e>g4km009:g@03B]a:gF[F
009ZeP8QM`059GPQEdkLC]a>g@02C]`00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo080009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol08Woo000EOol4
0004Ool40006Ool00`00Oomoo`0EOol00`00Oomoo`0GOol0C5YFGWHf>cYL=S/jG4ZlC]e:_4Jm@Ya6
_E7dEQAAm5HDDOAK:UL:FbY:g4kMB]a>gD[LB]e:_4[ML]=bm7;CL_Abdg;d00i6_4:LA[a2W4kmC]a>
oDkLC_e2_4Jm@C15D44`AE11<4EA@C15DD4`C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>
oCIm>YdfO6kg0f[F01XUN25G9GPQEe;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;m
D_aBoE;l0`0006YBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo025oo`00
57oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo01Ioo`8000moo`04
B]e:g4[MB[`3Ool03F>bGWIJEUif>S/jFcXkB]e:g4[MB]a6_D:m009Am00;EOAAm57dDO@nO3ik?Wa:
g4kMB]a>g@02B]d01d[LB]ebdg;DL]=be7;C00803`9:g006C]e:g4kMC]a>oDkL0T:m00I5D44`AC11
<4E@@C03AE002@02C]a:g4kMC]a>o4kLC_e>g002C_`025;mC]a>o4kLC_e>g4kMC]`5J]H5B[`01dkl
C]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`300000e;lD_eBo002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00=BoGooOol04goo00<007ooOol087oo000IOol01000Oomoo`0017oo00<0
07ooOol00goo0P006Goo00<007ooOol01goo05Q5DD4`@Y`nO4:L?W]:gDZlB]d0]Goo0;ENMUYEGWIJ
ESYL=S/jG3HkB]e:_4[MB[a6_E7dEQAAm5HDDOAF53iK@W`nFdkMB]a>gD[LC]e:g4[MB[abm7;CL_Ab
dg;d00h03`0>C]e:_4kMB[a>oDkLC_e2W4Jm@C15D44`AE11<4E@@C15DD4`009:_4kMB[a>gDkLD_e>
g5;mC]aBoDkLD_e>g5;mB]a>gD[LC]e:g09ZeP0FK_LQE`00A[a:_DJlB[a6_5;mC]aBoDkLD_e>o5;m
C]aBoDklD_e>o5;mD_`30000LU;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoAAoo`03001oogoo021oo`0037oo1P001goo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo01Yoo`03001oogoo00Eoo`95D00BAE55D49l?Wa2O4ZlB]e:g4[MFUINMUYFGWIJEUifFUI:
_DJl0TZl00E:gD[LB]e2_DJm00=Am003EOAAm57d008nO00=?W]>gD[LC]e:g4kM?Yebe7;CL]Abdg;D
L]<0100?0TkL00A>gDkLC]e>g092_@04AC11<4E@@C05AE020083C]`02dkMC]a>o4klD_e>g4kmC]a>
oDkLC_d00T[M00=:g4[MJ]H00f[F00<QMbEhB[`00TZl00I>gDkLD_aBo5;mC_`2D_`015;mD_aBo5;l
0`0000=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eB
o5;lD_`EOol00`00Oomoo`0OOol001Eoo`@000=oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo01]oo`03001oogoo00=oo`1KAE51<4EA@E15DD4`@Y`nO4:L@[a6_D:lA[eJEEifFUINMUYEIk9S
/D[MA[a:gDJlB]e:_4[M@[aF557dEQAAm5HDDOA:gDZlB]e:_4kmB]a>gD[LC_ebdg;dL]=bm7;CL_A2
W4Jl@Ya6_4:LC_e>g4kmB]a>oD:lAE11<4E@@C15D44`AE51<4EA@W]6W49kAYa>g5;mC]a>oDkLD_e>
g5;mC]aBoDkLD_e>g4kMB]a>gD[LC]d00f[F00hUN25G9GQ>g4kmC]a>gDkLD_e>g5;mC]aBoE;l0`00
07UBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo00DOol00`00Oomoo`0OOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009o
o`8001eoo`04001oogooOol2AE002TEAAE15D4E@AE4004ZmB[a:gD:m0TJm00INMUYFGWIJEUifHk42
Hk801D[MB]a:gD[LA[d00T:m00=Am5GdDO@00U7d00MEm5L:B]a:_4[MB[a:g002B]d024[LB]ebdg;D
L]=be7;CL]@4AY`3C]`02TkMC]a:gD4`AE11<4E@@C15D44`0TE@00E6W49l@Ya2W4kM00=>g00:C_e>
g4klC_aBoDkLC_e>g4kmC]`3B]d024[LJ]IZeV[F8ELUMb5g9GP3C]`014kMD_aBo5;l0`0000=Bo5;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004
D_eBo5;lD_`DOol00`00Oomoo`0NOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo01Yoo`1QA[a:_DJlB]dnWD:m@C15DD5@AE51<4EA@E0004JlB]e6_4[M@[a6_D:l
GWIJEEifFUINMSHk>U`f>dkMB[a>gDZlA[e2W5HDDOAF557dEQAG2E/ZE`U>gD[LC]e:g4kMB]a:gDZl
B]ebdg;dL]=bm7;C00m2W4Jl@Ya6_4kLC_e>g4kmC]a5D44`AE11<4E@@C15D44`AE51D4JL@W]6W49k
D_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g3ZM=Wd00V[F00Y^mf[FJ]HQEbEh8ELUN4kLD_e>g0<0
0021C]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01eoo`005Goo1@000goo10001Goo00<007oo
Ool037oo00=^eP1COol02Woo00QWT6N`A[a6_DJlA[dnWDEA0dE@00=5DDE@00000P0001E:_4[MB]a:
gD:mA[eJEUifHk5NMUYF>U/j>cYKB]a:gD[LB]e:g4Jm@[d00U7d00=Em57dDO@00Sil00DnNdkMB]a>
gD[L00=:g@06B]abe7;CL]Abdg;D0P0?0d[L00Y>gDkLC]e>g4km@C15<44`AE11<0E5D00;009>gD[L
C]a:g4kmC]a>o4kLC_e>g002C_`01U;mC]a>gDkLC_e>g0IZePA:_0<00003C]aBoE;l009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00=BoE;lD_`04goo0P007goo000VOol00`00Oomoo`0<Ool00f[EK]Ioo`0:Ool0>VNaIi1W/DJl
B[e6_4[M@E15DD4`AE51D4EA@E12W3il@Ya6_4[MB[a:g@2EA[eJEUifFUENMUYF>U`f>cYLB[a:gDZl
B]e:_4JmDOAF557dEQAAm49l?U]2O3iKC]e:g4kMB]a:gD[LB]e:_7;dL]=bm7;C0`0?02I:_4kMB[a>
gD[LC_e>g4E@@C15D44`AE11<4EA@C15DD4`00<00TkMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>
gD[LC]e:g6kg0f[F00<UN000B[`00P0008Q6_4ZlC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAo
o`03001oogoo01aoo`009Goo00<007oo000037oo00AZeF[FJ]D0L`Uoo`08FSEF=CYL>U/jG4JmB]e6
_095D00GAE55D4E@AE15DCil@W`nO4[MB[a:gD[LB]eJEUifFUINMUYFGWI:_4ZmA[a:_002B]d014[L
B]e2_EGd0e7d00=Em57d?W`00Sil00`nNdkMB]a>gD[L?Yebdg;DL]=be7;CL]@400l3C]`02TkMC]a>
gD4`AE11<4E@@C15D44`0TE@00E5D@0200800TkM00=>g00:D_e>g4klC_aBoDkLC_e>g4kmC]`3B]d4
J]H300001TkMC]a>g4kLC]e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00DOol00`00Oomoo`07
Ool5000?Ool002Eoo`8000eoo`09K]IZ]FkF05=:gDJlB]e6_4[M00=oo`1UFSEF=EXf>U/jG3Xk>Ua6
_4[M@C15DD5@AE51<4EAAE15DCik@Y`nO4Jm@[a6_D:lGWIJEEifFUINMV>AHk96_4[MA[a:gDJlB]e:
_4[MDOAF557dEQAAm5HDB[a:gDZlB]e:_4kmB]a>gD[LL_Abdg;dL]=bm7;CA[a2W4Jl@Ya6_4[LC_e>
g4kmB]a5D44`AE11<4EA@C15DD4`AE55D4JL@W]6W49kC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e:
g4kMB]a>g@030000SV[F8ELUN25GC]e>g4kmC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo
00<007ooOol01goo00D007ooOomoo`0000moo`009Goo00<007ooOol02goo00AZeV[EK]IZe@80L`04
A[e6_4JmA[d2Ool02fN`ESEJ=EHeFSDjFcYL>U/jG4JmAE400dE@00Y5DDE@AE15D000B[a:_DZlA[e2
_@96_@05GWIJEUifFUIS/P02Hk401T[LB]e:g4[MB]a6_@92_@03DOAEm57d009Am006EbY:_4[LB[a:
gDZl0d[M00E:g7;DL]=be7;C009be0A6W00:C]e>g4kLC]a>gD4`AC11<4E@@C05AE000d:LAYa2O002
@Y`01TkmC]a>o4kLD_e>g09>o005C_e>g4kmC]a>o@030004J]H01BEh8ELUMdkLC]d00dkL00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Aoo`03001oogoo00Moo`03001oogoo011oo`009Goo00<0
07ooOol02goo06aZ]FkFJ]E^eVZe17<0D`1cA[a:gDJlD81F=EXfESEJ=EHeB]e6_4ZmA[a:gD5@AE51
<4EA@E15DD5@AE4004[MA[a:gDJlB]e2_4JmFUINMUYEGWIJESYL=S/jG4ZlC]e:_4kM@[a6_E7dEQAA
m5HDDOAK:UL9EbY:g4kMB]a>gD[LB]e:g4[MB[abm7;CL_Abdg;d00m6_4:LA[a2W4kmC]a>oDkLAE11
<4E@@C15D44`AE51<4EA@E15DDZlC]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC_d300000dkm=W`jW@03
J]H0T6kgJ]HUN25G9GQ>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001o
ogoo00Moo`03001oogoo00moo`009Goo0P000goo00=V]VJgOol01Goo00IZeFkFJ]EZeV[EK]H4@Y`2
@[d02eHeFSEF=EXeESEW/6N@A[e6_4JmA[`00TE@00E5DDE@AE15D4EA00<0000EB]e:_4[MB]a:gD:m
GWIJEV>bFUINMSXk>U/j>cYKB]a:gD[LB]e2_DJm00=Am003EOAAm3il008nO005B]a>gD[LC]e:g003
B]d01G;CL]Abe7;DL]<00P0?00Y>gD[LC]a:g4kmC]a>gD4`AE11<0I5D006AE55D003B]a>gD[L0TkL
00E>oDkLC_a>g5;m00<00005C_e>g4kMC]a>o@06J]H4B[`01TkLD_e>g4klC]aBo@=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mOomoo`0BOol00`00Oomoo`08Ool00`00Oomoo`0>Ool002Eoo`1I001oogooOomR
]VKGI[HMNAUHA[e2_4Jm@[a6_F[EK]IZ]FkFJ[D4Ld:LAYe2W4:m?Ya2_EHeFSEF=EXfIi1W/6>@Ik56
_4Zm@C15DD5@AE51<4EAAE15DCik@Y`nO4[MA[a:gDZl0;I2_5ifFUINMUYEGWHj>cYL=S/jG4ZlB]e:
_4[M@[aF557dEQAAm5HD?U]2O3iK@Wa:g4kMB]a>gDZlB]e:g4[ML]=bm7;CL]@03P0200l06DkMB[a>
gDZlC_e:g4E@@C15D44`AE51<4EA@C15DDE@AE400TkMB[a>gDZlC]e>g5;m00<0000;D_e>g5;mC]a>
gD[LC]e:g4kMJ]I^m`02J]H0T25G0016_4ZlA[a:_DkLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoAAoo`03001oogoo00Qoo`03001oogoo00eoo`009Goo00X007ooOomoofJgI[IV]fJf7GTI
N0=6_@07A[aZeV[EJ]IZeF[F07<014:L0T:m00]J=EHeFSEWT5XeESDjG3YK>Ua6_DEA00=5D00AAE55
D4E@AE15DCil@W`nO49lB[a:gD[LGWIJEUifFUINMP02Hk4014ZlB[e6_4Zl0T[M00A:g4:mDOAEm0=A
m003EO@nNcil008nO004B]a>gD[LC]d2?Yd2L]@00g;CL]Abe00400l02TkMC]a>g4kLC]e1<4D`@C15
D44`1TE@00D00`02C]a>g4kM00<0000:D_e>g4klC_a>oDkLC_e>g4[MB]`2B]d4J]H01BEh8GLUMdkL
C]d00TkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`EOol00`00Oomoo`03Ool0
1@00Oomoogoo00003goo000TOol0K`00OomoogooI]MV]VJgH[IVeaUH7GTIF1ei@[a6_D:l=WeZ]FkF
J[D4M01CB]e6_4[MA[a2_EHeFSIF=EXeESEJ=SYK>U`j>d[M@E15DD4`AE55D4EA@E15LDE@AE56_4[M
A[a:gD:lA[eJEUifFUENMUYFHk5OTF>bA[a:gDJlB]e:_4[MB[aF557dEQAAm5HDDOAG2DZlB]e:_4[M
B]a>oD[LC]e:g7;dL]=be7;CL_A2W4Jl@Ya6_4:LC_e:g4kmC]a5D44`AE11<4E@@C15DD5@AE51D4Ea
@W]6W003000044kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gD[L0V[F099^mb5G9GPQEbEhC]a>
gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007ooOol017oo0`0047oo
000TOol300002FJgI[IV]fJfI[MV]VJg@Ya2_@02@Y`01c9m=WeZeF[FJ]EZeV[E0080L`0>A[e6_4Jm
A[eJ=EHeIk1F=EXeESEJ=CYK>U`jF`95D00BAE55D4E@AE15DDE@AE55D000B[a:_DZlA[e2_DJmFUIN
MUYF1F>a00M:g4[MB]a:gD:mA[e2_@02DO@00eGdDOAG2@02E`T01DZlB]a:_4[MB]`00d[M00I:g7;D
L]Abe7;CL]@4AY`01dkLC]e>g4kL@C15D44`00I5D00:AE55D0000016W49l@Ya>g4kmC]`2C_`02e;m
C]a>o4klC_e>g4kMC]`jWCIm>Yd016[F00<UMbEh8GL00TkL00E>gDkLD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00Ool05goo000TOol0B`00@Ya6_D:LI[MR]VKGI[IV
]e>cEkA2W4Jm@Y`fOC9mK]IZ]FkFJ[E^eP1C17@0D`AcA[a:gD:MFSEF=EXfESEJ=F>@Ik16_4Zm@C15
DD5@AE51D4EAAE15DD5@AG4004[MA[a:gDJlA[e2_5ifFUIS/EYEGWHj>cYL=S/jG4ZlC]e:_4Jm@[aF
557dEQAAm5HDD`UG:P02E`T07D[LC]e:g4kMB[a:gD[LB]ebdg;dL]=be6kC00m2W4Jl@Ya6_4kLC_e>
g4E@@C15D44`AE51<4EA@C000`0001I1D4kMB[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>
g3ZM=Wa^m`=ZeP2B9GPQEbEh8EMBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo1Aoo`03001oogoo01Eoo`006Woo10001Woo00<007oo@[d00T:m015V]fJfEkAV]VJg6GPMN4:L
@[e2W6[FJ]EZeV[EJ]IZe@Ac00A2W092_@0:ESEJ=EHeFSEF=FN`Hi16_DJlAE43AE001DEAAE15DDE@
AE400`00019:gDZlB]e:g4Jm@[eNMP2EGWIJEUif>S/jFcXkB]e:g4[MB]`2@[d01UGdDOAAm5L9EQ@n
N`<nO005B]a>gD[LB]e:g003B]d017;CL]Abe7;D0P0?00=:g4kMB]`00TkL00I>oD4`AE11<4E@@C03
0003AE002TEA00=>g4[LC]e:g4klC]a>oDkL0Tkl00QBoDkLC_a>g4kmC]a>gDkL16[F0P0014Zl00M>
o4kLD_e>g4klD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo01Eoo`00
6Goo00<007ooOol00Woo00<007ooOol00goo05X007ooOom2W4Jm@Y`V?F:fI]MR]Qei6EPMND:lA[e2
_6kFJ[E^eVZeK]IZ]@Ac@Ya6WD:L@[dnW4:mESEJ=EHeIk1ST6N`Hi1:gD5@AE51<4EAAE15DD5@AG55
D4Ea?W]2W3ilB]e6_4[MB[`0]@2EGWIJEUifFUENMSXk>U`f>d[MB[a:gDZlA[eAm5HDDOAF557dEQ@n
Fd9l?U]2O4[LC]e:g3jm>Y`n_CjML]A^dg;dL]<300l01dZlC]e:_4kMC]a5D44`00<0000K@C15DD5@
AE51D4EaAE000dZlC]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gD[L009ZeP2FK_LQE`00
A[a:_DJlB[a6_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l4goo00<0
07ooOol057oo000IOol00`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool02RHl9SdV?FJgI[IV]fJf
7GTIN1eh0TJm00Q6_6[FJ]EZeV[EJ]H0L`Ac0d:L0T:m00QJ=EHeFSEF=EXe>U/jG3YK0TE@00I5DDE@
AE15D4EAAE02AE404T9l?Wa2O3ilB]e:_4[MB]aNMUYFGWIJEUifGi5S/DZlB[e6_0=:g@0?@[eAm57d
EOAAm5GdDOAF54ZlB]a:_4[MB]a>gD[L008nW@=be003L]=be00?00<03`03C]a>gDkL00<00003@C15
D4E@00A5D003AE55D4EA00800`=>g00;C]e>g4klC_aBoDkLC_e>g4kmC]a>o@02B]d00d[LB]eZeP03
J]H00bEg9GQ>g002C]`01TkMC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
2E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eB
o5;l01Aoo`03001oogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
05XV?B8lI]MR]VJgH[IVeaUh7GTIF1ei@[a6_D:lK]IZ]FkFJ[D4M01C17=6_4[MA[a2_EHeFSIST5Xe
ESDjG3YK>Ua1<4EA@E15DD5@AE55D4EA@E15LDE@B]e6_4[MA[a6_D:lA[eJEUifFUENMUYFHk5OT4[M
A[a:gDJlB]e:_4[MDOAF557dEQAAm5HDDOAG2DZlB]e:_4kMB]a>oD[LC]e^dg;dL]=be6kCA[a2W4Jl
@Y`300008T[LC_e1<4E@@C15DD4`AE51<4EAAE15DDE@AYa2NdJLC]aBoDkLC_e>g5;mC]aBoDkLD_e>
g5;mC]aBoD[LC]e:g4kM0f[F09DUN25G9GQ>g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m01=oo`03001oogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00goo00UV]fJfI[MV]VJgDk=C]4:L@[d00T:L00/bOCImJ]EZeV[EJ]IZe@Ac07=6
_DJl0096_@09@[eF=EXeESEJ=EHe>Ua5D4EA00=5D00BAE55D4EAAE15DDE@AE4004[MB[a:_DZlA[e2
_DJmFUINMUYF0f>a00EOTD[MB]a:gD[L0092_@06A[eAm5GdDOAF557d0UL900I:gDZlB]a:_4[MB]`3
B]d01G;CL]Abe7;DL]<00`000TJL00=>g4kmC]`01TE@00I5DDE@AE55D4EA@W`2@Y`01TJLC]a>o4kL
C_e>g09>o009D_e>g4klC]a>oDkLC]djOCZM00EZeP8UM`069GQ>g4klC]aBoDkL0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0COol00`00Oomoo`0BOol001Uoo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00Aoo`0ZI[MR]VKGH[IooaUHEkA2W4Jm@Ya6_FZeK]IZ]FkF
J[E^eP1C17@0Dd:m?Ya2_EHeFSEF=EXfESEW/6>?AE51D4EA@E15DDE@AE51D4EaAE15LDE@0P0002I:
gDJlB]e6_4Jm@[aNMUYFHk5JEEif>S/jG3HkC]e:_4kMB[a6_D:lEQAAm5HDDOAF55<8E`UC2DkMB]a>
gD[LB]e:_4[MB]abe6kC0`0002L03`0@B[a>gDZlC]e>g4km@C15DD4`AE51<4EAAE15DD5@AG55D4Ea
B[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g3ZM=Wd00V[F09QZef[FJ]I6_4ZlA[a:_4kL
D_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007ooOol0
4Goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool20006Ool00fJgI[Ioo`02Ool27GP2A[d024Jl
A[eZeF[FJ]EZeV[EJ]H3@Y`3@[d01UHeFSEF=EXeHi1WT0=5D006AE55D4E@AE15DDE@0dEA00DnO49l
?Wa:gDZl009:g@0FA[e2_EifFUINMUYF>U/j>cYK>S]:gD[LB]e:g4:mDOAF557dEOAAm3il?W/2?W`0
1TkMB]a>gD[LB]e:g0<00003L]=be7;D00<03`07B]a>gD[LC]e>g4E@@C001TE@00Y5DDE@AE55D@03
B]a>g4[LC]e:g09>o00:D_e>g4klC_aBoDkLC_a>g4kmC]`5J]H20004B[`014kLC_a>g5;m0e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0BOol00`00Oomoo`0AOol001Yoo`@0
00Eoo`03001oogoo00Yoo`177GTIF1ei@[a6_D:lK]IZ]FkFJ[E^eVZe@Ye2W4JM@Ya2WCjLFSIF=EXe
HhmW/6>?AE51<4EAAE15DD5@AG55D4EAAE15LDE@@Y`nNd:L?Wa:gDJlB]e:_5ifFUENMUYFGWIJED[M
A[a:gDJlB]e:_4[M@YaF557dEQAAm5HEDOA2O3iK@W`nFdkMB]a>o@0200001SZL?[ebdg;DK]=bm0<0
3`0AC]e:_4kMB[a>oD4`AE11<4EA@C15DD5@AE55D4EAAE15L@0200<04TkLD_e>g4kmC]aBoDkLD_e>
g5;mC]aBoDkLD_e:g4kMB]aZe`=ZeP2G9GP004ZlA[a:_4JlB[a>g5;mC]aBoDkLD_e>o5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04Woo0`004Woo0005Ool200000goo0000000IOol00`00
Oomoo`0;Ool00aei7GQ6_@02A[d02DJlJ]HbOF[FJ]EZePAcA[e6_003A[d025HeFSEF=FN@ESEJ=DE@
AE43AE000dEAAE15D@02AE404DE@AE55DD9l?Wa2O3ilA[e2_DJmFUINMUYFGUIJEV>aGi000TZl00=:
_D[LB]d00T[M00Y2_EGdDOAF557dEOAAm4[MB[a:g0<00004C]e:g3jML]<3L]@00g;C00l03`0200l2
C]`00dkMC]a5D005AE001TEAAE15DDE@AE55D092W006AYa>g4kLC]a>gDkL0Tkl00IBoDkLC_e>g4km
C]`3B]d5J]H29GL01TkMC]a>g4kLC]e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@0COol00`00Oomoo`0@Ool000Aoo`03001oogoo008001Yoo`03001oogoo00]o
o`106GPMNAUHA[e2_4Jm<We^eVZeK]IZ]@Ad07=:gDJlB]e6_5XeESEW/5HeFSEF=DEA@E15DD5@AE55
D4EA@E15LDE@AG55D4Ea001:gDJlB]e6_4Jm@[a6_EYFGWIJEEifGi1S/En@B]e6_4[M@Ya6_D:lA[eA
m5HDDOAF557dEQD30000=D[MB[a>gD[LC_e:g7;DK]=bm7;CL]A^ddJl@Ya6_4:LC_e>g4kmB]a5DD4`
AE51<4EAAE15DD5@AG55D4Ea@W]6W49kC_e>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gCIl
J]L00V[F09PQEbEh8EM>gDkLC_e>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m4goo00<007ooOol03goo0004Ool01@00Oomoogoo00006Goo0`003Goo00=2W4:m
@Y`00S9m00HfOF[EJ]IZeF[FJ]D317<024JlA[e6_EXeESEJ=EHeFSD3AE001TEAAE15DDE@AE55D0=5
D@0DAE000000B]e:_4ZmB[a6_D:mGUIJEUifFUINESXk>U/j>d[MB]a:g@=2_@03EQAAm5Gd00<0009C
2@06C]e:g4kMB]a:gD[L0T[M00=be7;CL]@00W;D00<03dJLAY`00TJL00A>gDkLC_e1<095D006AE55
D4E@AE15DDE@0TEA00Y5LD9l@Ya2W4kmC]a>o4kLC_e>g09>o008D_e>g4kMC]a>oDkL>YdfO@EZeP<U
M`05D_e>g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@0COol00`00Oomoo`0>Ool000Aoo`05001oogooOol0000IOol00`00Oomoo`0>Ool08D:LA[e2W4Jm
J[E^eVZeK]IZ]FkF@Ya6WD:L@YdnW4:mESEJ=EHeFSIF=DEA@C15DDE@AE51D4EaAE15LDE@AG55D004
00004d[MA[a:gDZlA[eJEEifGi1NMUYE>U`j>cYLB[a>gDZlC]e:_4Jm00<0000iEQEAm5HD?U]2O3iK
C]e:g4kMB]a:gDZlB]ebdg;DK]=bm7;C01003dkMB[a>gDZlC_e>g4E@@C15DD5@AE51D4EaAE15LDE@
BG55D004B[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g6[G00=ZeP2JJ]MZeTZlA[a:_4Jl
D_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`COol0
0`00Oomoo`0>Ool000Aoo`05001oogooOol0000IOol00`00Oomoo`0?Ool2A[d024JlA[eZeF[FJ]EZ
eV[E17<3@Y`3@[d01UHeFSEF=EXeAE15D@=5D003AE55D4EA0095D@0FAE15DDEA@W`nO49l?Wa:gDZl
B]d0UDJmFUINEUYFGWIJESYK>S/jFd[LB]d300004D:mDOAF557dEOAAm3il?W/nO4[LC]e:g4kMB]a:
gD[LB]d00W;D00=bdg;D00l00P0?00E>g4[LC]e:g4kM00E5D003AE55D4EA0095D@09AE15D@03C]e:
g4kLB]aBoDkL009>o006D_e>g4klC_aBoD[L0d[M00=:g6[FJ]H00V[F00<UM`00B[`00dZl00EBoDkl
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001o
ogoo00eoo`000goo0P000Woo0P006Goo00<007ooOol047oo0312_4Jm@[a^eVZeK]IZ]FkF07<4M4:L
AYe2W4:m?YaJ=UHeFSEF=DEA@E15DD5@AG55D4EAAE15LDE@AG55D4UaAE12W3ik@Y`nO4[MA[a:gEYF
GWIJEEifFUIO/En@B]d30000@D[MB[a:gD:LEQEAm5HDDOAF5E7d@W`nFd9lB]a>gD[LC_e:g3jmK]=b
m7;CL]A^d`0@00l0400?C_e>g4kmB]a5DD4`AE51<4EAAE15DD5@AG55D4EaAE001003C_e>g5;mC]aB
oDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gF[FJ]L00V[F09/QEbEh8EM>gDkLC_e>g5;mC]aBoDkLD_e>
g5;mD_aBoDklD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03001oogoo00ao
o`008Woo0P004Woo0TJm00E6_39mJ]EZeV[E00<4L`0AA[a6_DJm@[eF=EXeESEJ=DE@>Ua5D4EAAE15
DDE@AE55D006AE402d[MB[a:_DZlA[e2_EiFFUINMUYFGUH00`000TZl00=:_DJlB]d00T[M00UAm5Gd
DOAF557dEOABj4[MB[`00T[L00I>gD[LC]e:g7;DL]<3L]@5AY`2C]`01DkM@C15D4E@AE400dE@00I5
DDE@AE55DDJL@W`2@Y`01TkMC]a>g4kLD_e>g09>o006D_e>g4kmC]a>oD[L0d[M00@fOF[FJ]HUN0<U
M`06C]e>g4kLD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_aBo00COol00`00Oomoo`0<Ool0029oo`03001oogoo019oo`0X<WdfOFZeK]IZ]FkFJ[D4
M01cB]e6_4[MA[aJ=EHeFSIF=DEAESE5DDE@AE51D4EaAE15LDE@AG55D4EaAE19L@00B]e6_4[M@[a6
_D:lGWH30000AV>aGi1O/DZlC]e:_4kMB[a6_D:mA[eAm5HEDOAF55;XD`U:_4[MB[a:gD[LB]e:_4[M
B]abe6kCL_Abdg;D@Ya6_4:LA[a:g4kmC]a>oD4`AE51D4EA@E15LDE@AG55D4UaAE16W49kAYa2Ne;m
C]aBoDkLD_e>g5;mC]aBoDkLC_e>g4km=W`jWCIm0V[F09eZef[F9GPQEbEhC]a>gDkLC_e>g5;mC]aB
oDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol00`00Oomo
o`0;Ool0025oo`03001oogoo01=oo`8bO@05J]IZeF[FJ]EZeP0317<02DJmA[a6_D:mFSEF=EXeAE1S
S`03AE000dEAAE15D@02AE401DE@AE55DDEaAE400P0000A:gDZlB[e6_@80000;GUIOT5ifFUHjFcXk
>U]:g4[MB]a:g@02@[d0357dEQAAm5GdDOAC25;XD`Q:g4kMB]a>g@9:g@05B]a:gG;DL]Abd`02L]@0
0`0@00m6W002AY`00dkLC]e>g004AE001TEAAE15DDEAAG55D095D@0:C]e:g4kLB]a>oDkLC_a>g4km
C]`2C_`01e;mC]a>gDkLC_dfOCZM00AZeP0:9GLUN2Eg9GM>g5;mC]a>o5;lD_d3D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04Woo0P0037oo000QOol00`00Ool0
000DOol01FkFJ[E^eVZeK]H00Woo01]2W4JM@Ya2_CjL@[eF=EXeESE5DF>?AE51D4EaAE15LDE@AG55
D4EaAE19LDE@@Y`nNd:L?W`00`0004a2_4JmFUENMUYFGWHf>cYL>S/jG3HkC]e:_4kM@Ya6_E7dEQAA
m5<9DOA2O3iK@Wa:g4kMB]a>gD[LB]e:_4[ML]=be6kCL_@03`0@00m>gDZlC]e>g4km@C15DD4`AE55
D4EAAE15LDE@AG55D4Ua00=>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmJ]IZe`9ZeP80
002KA[a:_4JlB[a>g5;mC]aBoDklD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00COol00`00Oomoo`0:Ool0025oo`8001Ioo`04J]IZeF[FJ]D2Ool00`Ad@Ya2
W002@Y`014:mFSEF=EXe0V>?00=5D4EAAE000dEA00A5D4EAAE55L@=5D@<0009:g@04B[a:gD[MGWH3
FUH01UifA[a:_4ZlB[e6_0=:g@06@[eEm57dEQAAm5Gd0Sil00LnNcilB]a>gD[LC]e:g002?Yd3L]@0
2G;C00l03`0@B]a>g4[LC]e>g002AE001TEAAE15DDE@AE55D095D@05AG55D@0400A>g@03C]`02U;m
C]a>o4klD_e>g4kmC]a>oD[L0d[M0f[F00<UN000B[`014Zl00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04Goo0P002goo000?Ool4
0004Ool40006Ool00`00Oomoo`0FOol00fkFJ[Eoo`02Ool05@Ac17A6_4[MA[a:gCjLFSIF=F>@ESE5
DDE@AE51D4EaAE15LDE@AG55D0030000DDEA@Y`nNd:L@[a6_D:lA[eJEUifFUENMUYFGi16_4[MA[a:
gDZlB]e:_4JmDOAF5E7dEQAAm5HEB[a:gDZlB]e:g4kMB]a>oCjML]A^dg;dL]=be00?01003`0@B]a>
oDkLC_e1<4EAAE15DD5@AG55D4EaAE19LDE@AG52NdJL@W]>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>
gD[LC]e:g002J]H0X6[GJ]HUN25GC_e>g4kMC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l3Woo0`0000=oo`00Ool02Woo000>Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol06goo0PAc00h4M4JlA[e6_D:m
ESESSeHeFSE5D4EAAE15DDE@0TEA0`0000Q5DDEaAE55L@00B]e:_4Zm0TJm00E2_DJmFUINMUYF00AO
T09:_00>B[e2_D:m@[eF557dEOAAm5HDDOABj4ZlB]e:_09:g003C]e:g4kM009be004L]=be7;DL]@4
AY`3C]`4AE002TEAAE15DDEAAG55D4EA@Ya6W49l0T:L00I>gDkLC]a>o5;mC]`2C_`01TkmC]a>oDkL
B]e:g09:g@=ZeP039GLUN2Eg009>g005C]e>g4kLD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`08Ool40004Ool00`00Oomoo`09Ool001=o
o`04001oogoo0004Ool00`00Oomoo`03Ool2000MOol03PBD17<4M4JlB]e6_5XeESEJ=UHeAE51D4Ea
AE030000F4E@AG55D4UaAE19LDE@0016_4[MA[a:gDJlA[e2_5ifFUINMUYE>U`j>cYL=S]>gDZlC]e2
W4Jm@[eF557dEQEAm5<8C^QC24[LC]e:g4kMB]a:gDZlB]ebdg;DK]=be6kC0112W4Jl@Ya6_4kLC_e>
g4EA@E15DDE@AE55D4EaAE15LDE@BG5:_4kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL>Ydf
O6[G0f[F09mZebEg9GPQEe;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d01Woo0`0027oo00<007ooOol02Goo000COol01000Oomo
o`0017oo00<007ooOol00Woo0P007Woo14:L0T:m00EF=EXeESEJ=DE@00<00095D@07AE15DDEAAG55
DDEaAE400`000T[M00A:_4[MB]e6_@=JEP09GWIJESYK>S/jFd[LB]e:g4[M0092_@0<DOAF557dEOAA
m3il?W/nO4[LC]e:g4kM0T[M00=:g7;DL]@00g;D00l03`0@B]a>g4[LC]e>g4kMAE15DDE@AE55D4EA
AE000TEA00I5LDEA00A:g4kMB]`2C]`01TkmC]a>o4klD_e>g09>o004C_e>g4kMC]`6J]H4B[`01dkl
C]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo0=oo`<000aoo`03001oogoo00Qoo`003goo10000goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol07Woo00M2W4JM@Ya2_CjL@[eF=@030000GDE@AE55D4EaAE15LDE@BG55D4EaAE19LDEA
@Y`nNd:LB[a:gDJlB]d0U4JmFUENMUYFGWIJECYL>S/jG4ZlB]e:_4[M@YaF5E7dEQAAm5HE?U]2O3iK
@Wa:g4kMB]a>gD[LB]e:_7;DK]=be6kC01003`0@B[a>gDZlC]e:g4EAAE15DD5@AG55D4EaAE19LDE@
BG400dkMB[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e:g002J]H0XV[GJ]HUN000B[a6_4Zl
A[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo08000moo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol07goo0d:L0`0000MF=EXeESE5DDE@AE55D006AE403DEaAE55LCil@W`n
O49l?Wa:gDZlB]eJEUif00=JEP06Gi1KT4ZlB[a:_D[L0T[M00Y2_E7dEOAAm5HDDOAEm4ZlB]e:_09:
g004C]e:g4kM?Yd5L]@300l01@0@C]a>g4kLC]d00dE@00E5DDE@AE55DDEa00=5D@80109>g00?C]e>
g4kLC_aBoDkLC_a>g4kmC]a>oDkLB]e:g4[M00AZeP039GLUN2Eg009>g006C]e>g5;lD_aBoDkl0U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo11o
o`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool087oo0P0006A6_4:mESEJ=Um_FSE1D3YLAE15LDE@AG55D4EaAE19LDEABG55D4UaA[a:gDJlB]e6
_4Jm@[aNMUYFGWIJEEifFi1OT4JlB]e6_4[MB[a:gDZlEQAAm5HEDOAF557d001:_4[MB[a>oD[LC]e:
g4kmK]=be6kCL]A^dg;D@Ya6_4:LAYa:g4kmC]a5DD5@AG55D4EaAE19LDE@AG55D4Ua@W]6W49kD_e>
g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>g@=ZeP2R9GPUMbEh8EM>oDkLC]e>g5;mC]aBoDkL
D_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
3goo00<007ooOol027oo000?Ool50003Ool40005Ool2000NOol300002TJmA[a6_DJm@[eF=EXeESE5
DEHe0dEA0155D4EAAE55LDEAAG55DDEaAE4004ZlB]e:_4ZmB[a6_D:m009JEP09GWIJEUYF>S/jFd[L
B]e:g4[M00=2_@04EQAAm5GdDO@300000dZlB]e:_003B]d00d[LB]ebe004L]@5AY`01DkLC]e>g4EA
AE000dEA00E5D4EAAE55LDEA0092W006AYa2O4klC]a>oDkL0Tkl00YBoDkLC_a>g4kmC]a>gDkL>Ydf
O@AZeP089GPUMbEh9GM>o4kLD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`?Ool00`00Oomoo`08Ool0021oo`03001oogoo01Yo
o`<000Aoo`0E@[dnW4:m@YeJ=EHeFSI5D6>?AE15LDE@AG55D4UaAE19LDE@BG55DDUa00<0001<B]e6
_4[MB[a6_EYEGWIKT5ifFUDjG3Xk>Ua:_4kMB[a>gD:LA[eAm5HDDOAF5E7d@W`nFd9lB]a>gD[LB]e:
g4[MB[abe6kCL]A^dg;D00m>gDZlC]e:_4kMC]a>oDE@AE51D4EaAE15LDE@BG55D4UaAE1>gDZlC]e:
_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]`2J]H0YF[GJ]IZeTJlB[a6_4ZlA[aBoDkLD_e>g5;m
C_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@0>Ool00`00Oomoo`08Ool0021oo`03001oogoo01Moo`<000Qoo`=2_@07ESEJ=EHeAE5SSdEA
AE000TEA0155LDEAAE55DDEaAE55L@00BG4nO49l?Wa:gDZlB]d0U4Jm00=JEP06GWIJESYK>S/jFd[L
0d[M00I2_EGdDOAF557dEQ@2?W`01SikC]e:g4kMB]a>g@9:g@03B]abe7;D009be00801003dkMB]a>
g4[LC]e>g095D006AE55D4EAAE55LDEA0dEa00T014kLB]a>gD[LC]a>o5;mC]`00Tkl00=BoDkLC_`0
0T[M00=:g4[MB]d00f[F00<UM`00B[`014Zl0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00eoo`03001oogoo00Qoo`00
7goo00<007ooOol05Goo0`003Goo04lnW5XfESEJ=Em^FUI5D4EaAE15LDE@AG55D4UaAE59LDE@0015
DD:L?W]2W3ilB]e6_4[MFUINMUYEGWIJEUn@Ffm:gDJlB]e:_4[MB[a6_E7dEQEAm5HDDOAF5CiK@W`n
FdkmB]a>gD[LC_dnWG;DK]=be6kCL]@03`0`00l044[LC_e>g4km@E15LDE@AG55D4UaAE15LDE@BG55
D@0200@04E;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC]d00f[F0:EZebEg9GQ>g4kmC]a>
gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d03Goo00<007ooOol01goo000OOol2000COol3000AOol01D:mFSEF=EXe
ESD00dEA00DnWDEAAE55LDEA00I5L@06B]e:_4ZlB[a6_D:m0UYF00INMUYFFUIKT5n@A[`2B[`04dZm
B]a:gD[MEQAAm5HDDOAF557d001:_4[MB[a>gD[LC]e:g4kM00Ebe0E6W0=>g006AE55D4EAAE55LDE@
0TEA00I5LDEAAG52W4JL@W`2C]`02dkMC]a>g4klD_e>g4klC]a>oDkLC_d00T[M00=:g4[MJ]H00V[F
00<UN2Eg9GP00dkL00E>gDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00aoo`03001oogoo00Moo`007goo00<0
07ooOol03goo0`0057oo02a2_EHeHhmF=EXeAE15LDE@@[e5D4UaAE19LDE@BG55DDUaAE59L@00B]e6
_4[M@[a6_D:lGWIJEUifFfmOT5]_Gi1:_4kMB[a>gD:lA[e2_EHDDOAF5E7d0P00015:gDZlB]e:_4[M
B]a:gDZlB]e^dg;DK]=be6kCAYa2W4Jl0096W00RB]a>oDE@AE55D4EaAE15LDE@BG55D4UaAE16W49k
AYa2Ne;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4km=WdjWFJfJ]L2J]H0YFJf9GPUMbEhC]aBoDkLD_e>
g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00<Ool00`00Oomoo`07Ool001moo`03001oogoo00aoo`<001Qoo`06FSEF=EXe
ESE5DDE@0TEA00I5LDEAAG55DDEaAE42AG401DUaAG400000B]d00TZl00i2_DJmFUIJEU^@GWIJESYK
>S/jFd[LB]e:g4[M0T:m00AAm5HDDOAF50<00004C]e:g4kMB]`3B]d00d[LL]Abe003L]@02`0@C]e:
g4kLB]a>gDkLC]e5D4EAAE000TEA00i5LDEAAG55LDUaAG5>g4[LC]e:g4klC]a>oDkL0Tkl00QBoDkL
C_a>g4kmC]`jWCIm1F[F14Zl00A>g4klC]aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0:Ool00`00Oomoo`07Ool0
01moo`03001oogoo00Uoo`<001]oo`1PESEJ=EHeFUI5D4EaAE19LDE@AG55D4UaAE59LDE@BG55DDUa
?W]2W3ilB]e6_4[M@[a6_EYEGWIJEUif=S/jG3Xk>Ua:_4[MB[a:gD:lEQEAm5HD001F5CiK@W`nFdkM
B]a>gD[LC]e:g4[MB[abe6kCL]A^d`0`00m>gDZlC]e:_4kmC]a5LDE@AG55D4UaAE15LDE@BG55DDUa
00A>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g6[G0V[F0:UV]V[G9GL004JlB[a6_5;mC]aB
oDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo00:Ool00`00Oomoo`07Ool001moo`8000Qoo`8001moo`03ESEJ=EHe
00I5D@05AG55DDEaAG400003AG402D9l?Wa2O3ilB]e:_4[MFUINMP03FUH01UifA[a:_4ZlB[e:g09:
g@07@[eAm5HDDOAF557dEQ@00Sil00LnNdkMB]a>gD[LC]dnW@05L]@02@0?010044kMB]a>g4[LC]e5
D002AE401TEaAE15DDEAAG55D@95L@80109>g00;C]e>g4klC_aBoDkLC_a>g4kmC]a>o@02B]d00d[L
J]IZeP02J]H00bEh9GLUN003B[`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo00Qoo`03001oogoo
00Moo`007Woo00<007ooOol01Goo0`008Goo065JEUHeFSEoodEa>U]5LDE@BG55DDUaAE19LDEABG55
DDUaAE5:gDJlB]e6_4Jm@[aNMUYFGWIJEEifFfmKT4JlB]e6_4[MB[a:gDZlEQAAm000DOAF557d001:
_4[MB[a>oD[LC]e:g4kmK]=be6kCL]A^ddJL@Ya6_4JLC_e:g4kmC]a5DDE@AG55D4EaAE19LDEABG55
DDUa@W]6W49kD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMI[IZe`02J]H0Z2Eg9GPUMbEhC]a>
oDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@Yoo`03001oogoo00Ioo`007Woo00<007ooOol00Woo0`00
97oo00eF=EXeOomoodE@Oom5DDEaAE55LDEAAG55D@02AG401DUaAG55L@00B]d00TZl00=2_DJm@[d0
0UYF00UNMU]_FhmKSe^@B]a:gD[LB]d00d:m00AF557dEQAAm0800004B]a:_4[MB[`3B]d00d[LB]eb
e004L]@4AY`01TkMC]a>g4E@AE55D095D@0>AG55DDEaAG59LDEaAYa2W4JL@Wa>o4kLC_e>g09>o009
D_e>g4klC]a>oDkLC]dfOCZM00AZeP049GLUN2EgC]d3C]`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0Yoo`03
001oogoo00Ioo`007Woo00<007oo00000P00:7oo015F=GooOom5LGooBG55D4UaAE19LDEABG55DDUa
AE59LDEA0080000GB]e6_4[M@[a6_EYEGWIJEUifFUDjG3Xk>Ua:_4kMB[a6_D:lA[d005HDDOAF5@03
0000gTkMB]a>gD[LB]e:g4[MB[abe6kCL]A^dg;D00m6W4:LA[a6W4kmC]a5LDE@AG55D4UaAE19LDE@
BG55DDUaAE5>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g3ZM=WeZeVJfJ]MZeREh9GLUN2Eg
D_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Uoo`03001oogoo00Ioo`007Woo0`00;Goo00=5DGoo
AE400TEA00E5LDEAAG55LDUa00=5L@09BG4nO49l?Wa:gDZlB]e2_DJm00=JEP08GWHj>cYK>S/jFd[L
B]e:g092_@05EQAAm5HD001F5002?W`01SikC]e:g4kMB]a>g@9:g@03B]abe7;D009be0804006C]e:
g4kLB]a>oDkL0TEA00I5LDEAAE55DDEaAE42AG401TUa00A>g4[LC]e:g09>o00:D_e>g4klC_aBoDkL
C_a>g4kmC]`4J]H00bEh001:_003B[`01E;mC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l27oo00<0
07ooOol01Woo0004Ool50003Ool40004Ool40007Ool00`00Oomoo`0/Ool0GDEaOom5LDE@BG55DDUa
AE0004EABG55DDUaAG52W3ik@Ya:_4[MA[a:gDZlGWIJEEifFUINMTJlB]e6_4[MB[a:gDZlA[eAm5HE
DOAF557dEQDnFd9l?U]>oD[LC]e:g4km?Yebe6kCL]A^dg;D00l0<00?C]e:_4kMB[a>oDE@BG55D4Ea
AE19LDEABG55DDUaAE401@04D_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]aZe`02J]H0ZfJf
:GPUMdZlA[a:_4JlD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo007Ool00`00Oomoo`06Ool000Io
o`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`05Ool2000^Ool00dEA
AG55D@06AG403DUaAG59LDEa@W`nO49l@[e6_D:mA[eJEUif009JEP03FfmKSdJl009:_003B[e:g4[M
0092_@0>DOAF557dEQAAm000B[a:gDZlC]e:g4kMB]a>g@Ebe0A6W006C]e>g4kLC]a5DDE@0TEA00E5
LDEAAG55LDUa0095L@03@Ya6W49l009>g00;C]e>g4klC_aBoDkLC_e>g4kmC]a>o@02B]d4J]H012Eg
9GPUMdkM0dkL00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo007Ool00`00Oomoo`06Ool000Ioo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`0[Ool0
9TUaAE59LCjLBG55DDUaAE59LDEABG55DDUb001:gDJlB]e2_4Jm@[aNMUYFGWIGKe^@FfmKSdZlC]e:
_4kM@[a6_D:mEQAAm5HEDO@20000=D[MB[a:gDZlB]e:g4[MB[a:gFkCL]A^dg;D00m6W4:LA[a>g4km
B]a>oDE@AG55D4UaAE19LDE@BG55DDUa@W]6W49kAYa2Ne;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g4km
=WdjWFJfJ]L00V[F0:XUMbUhC]a>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m1Woo00<0
07ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
27oo00<007ooOol0:Woo00E5DDEaAE55LDEA0095L@06BG55LDEaAG59LDEa0P0000I:gDZlB[a:_4Jm
@[d2FUH02EifFUHjFcXk>U]:g4[MB]a:g@02@[d0157dEQAAm5HD0`0000A>gD[LC]e:g0=:g@05B]ab
e7;DL]A^e0020303AY`00dkLC_e>g002AE400dEaAE55L@05AG402TUaB]a>g4[LC]a:g4klC]a>oDkL
0Tkl00QBoDkLC]e>g4kmC]`fWCIm16[F00TUN2Eg9GQ>g5;mC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo003D_eBo7oo00Ioo`03001oogoo00Eoo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo00Uoo`03001oogoo02Uoo`1KAG55D4UaAE59LDE@BG55DDUaAE59LTEa
BG4nNd:L?Wa:gDJlB]e:_4JmFUENMUYFGWHj>cYL>S/jG4ZlC]e:_4kM@[aF5E7dEQ@005HE?U]2O3iK
C]e:g4kMB]a>gD[LB]e:_7;DK]=be6kC03003dkMB[a>gDkLC_e>g4UaAE15LDE@BG55DDUaAE59LDEa
00E:_4kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLJ]L00V[F0:eV]RUh001:_4JlB[a>g5;m
C]aBoDklD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Ioo`03001oogoo00Eoo`001Woo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Yoo`8002Uoo`03AE55LDEA00I5L@0:
BG55LDUaAG59LCil@W`nO49lB[`2B]d01UifFUIJEUYFGWI6_09:_00FB[e:g4[MB]e2_E7dEQAAm5HD
DOAF53il@W`nNdkMB]a>gD[LC]dnWG;DK]@3L]@01@0@0300<4kMB]`00TkL00I>gDE@AE55DDEaAE42
AG400dUaAG59L@0200D3C]`02TkMC]a>o4klD_e>g4kmC]a>oDkL0d[M16[F00<UMbEh9GL00dZl00=B
o5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`04Ool00`00Oomoo`05Ool000Aoo`<0
00Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0<Ool00`00Oomoo`0VOol0GDUaAE59
LDE@BG4004UaAE59LDEABG55DDUbAG59LDJlB]e6_4[M@[a6_EYFGWIJEEifEfiKSdJlB]e6_4[MA[a:
gDZlA[eAm5HEDOAF557d001:_4[MB[a>oD[LC]e:g4kmK]=be6kCL]A^ddJL@Ya6_4JLC_e:g4kmC]a5
LDE@BG55D4UaAE19LDEABG55DDJL@W]6W4kLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMI[IZ
e`02J]H0[BEg:GPUMdkMC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`017oo00<0
07ooOol01Goo0006Ool00`00Oomoo`03Ool40004Ool4000@Ool00`00Oomoo`0VOol014EaOom5LDEA
0TEa00U9LDEaAG55LDUaAG59LDEa00000dZl00I6_D:mA[eJEUifFUH3Ffl01D[LB]e:g4[MB]`00T:m
00AF557dEQAAm0800004B]a:_4[MB[`3B]d01d[LB]ebe7;DK]Abe00`00A6W006C]e>g4kLAE55LDEA
1TEa00Y9LD9lAYa2W4JLC]a>o4kLC_e>g09>o008D_e>g4kMC]a>oDkL=YdfO@AZeP059GPUMbEh9GM>
g@02C]`00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo009oo`03001oogoo00Eo
o`00:Goo00<007ooOol09Goo00i5D7ooAE59LDEABG55DDUaAE59LTEaBG55LDUb0P0001I6_4[MA[a6
_D:lGWIJEUifFUDjG3Xk>Ua:_4kMB[a>gDZlA[eAm5HDDOAF5@<0000aC]e:g4kMB]a:gD[LB]e:_7;D
K]=be6jc030044kMB[a>gDZlC_e>g4UaAE19LDE@BG55DDUaAE59LDEaBG5:_4kMB[a>gDkLD_e>g5;m
C]aBoDkLD_e>g4kmC]a>oCIm>Yd00V[F0;1V]V[GA[a:_4JlB[a6_5;mC]aBoDkLD_e>g5;mD_aBoDkL
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m0goo00<007ooOol01Goo000ZOol00`00Oomoo`0TOol01DEaOom5LDEa
BG400dEa00Y9LDEaBG55LDUaOom2O3il@Wa:_09:g@0:A[e2_EYFFUINMSXk>U/j>cYKB]`3B]d03D:m
EQAAm5HD001F53il@W`nNdkMB]a>gD[L00=:g@05B]abe7;DL]A^e00203001TkMB]a>g4kLC_e5D095
D@0<AG55DDEaAG59LDEaBG55L@05B]a>g4[L0TkL0Tkl00UBoDkLC_a>o5;mC]a>gDkLC_d016[F00<U
M`00B[`014Zl00EBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0goo00<007ooOol01Goo
000[Ool2000TOol0B4EAOom5D4UaAE59LDEABG55LDUaAG59LTEaOolnNd:L?Wa2W4JlB]e:_5ifFUEN
MUYFGWI6_4[MA[a:gDZlB]e:_4[M@[aF5E7dEQEAm5HE?U]2O3iKC_e:g4kMB]`n_CZML]A^/g;DK]=b
e00?030044kMB[a>gDkLC_e5D4UaAE19LDEABG55DDUaAG59LP801@0BC]aBoDkLC_e>g5;mC]aBoDkL
D_e>g5;mC]a>gD[LC]eV]V[G0V[F0:lUMbVHC]a>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo003Ool00`00Oomoo`04Ool002eoo`03001oogoo025oo`04AG5oodEa0002AG40
1dUaAG59LDEaBG55LDUa009oo`=:_005B]e2_DJmFUINMP02FUH00eM^Ffm6_002B[`04dZmA[a:gD[M
@[eAm000DOAF557d001:_4[MB[a>gD[LC]e:g4kM009be003K]Abe7;D00A6W006C]e>g4kLC]a5LDEA
0TEa00U9LDEaAG55LDUaAG56W4:LAY`00dkL00Y>gDkLC_a>o5;mC]a>oDkLC_e>g09:g@AZeP059GPU
MbEhC]a>g@02C]`00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l0Woo00<0
07ooOol017oo000^Ool00`00Oomoo`0ROol02dEABG55DDUaAE59LDEABG95LDUaAG400goo01M6_4[M
A[a6_D:lA[eJEUifFUENMSXk>Ua:_4kMB[a>gDZlA[e2_EHDDOAF5E7d00<0003WB[a:gDZlB]e:g4[M
B[a:gFkCL]A^/g;D0316W4:LA[a6W4kmB]a>oDE@BG55D4UaAE59LDEABG95LDUb@W]6W49kAYa>g5;m
C]aBoDkLD_e>g5;mC]a>oDkLC_e>g3ZM=WeZeVJfJ]MZ]RUh9GLYV4kLD_e>g5;mC]aBoDkLD_e>g5;m
C]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aoo`0000Ioo`00;goo00<007ooOol08Goo0TEa00U9LDEa
AG55LDUaAG59LDEaBG4017oo0dZl01Y6_D:mFUIJEUifFUHjFcXk>U]:g4[MB]a:gD[L@[d005HDDOAF
55Gd@W`nNcilB]a>gD[L0d[M00e:g7;DL]Abe6kDL]@0<4kMB]a>g4[LC_e>g002AE4034EaAE55LDEa
BG55LDUaAG59LD[LC]a:g09>g004C_a>g4kmC]`2C_`01U;mC]a>gDkLC_e>g0EZePA:_006C]aBoDkL
C_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aoo`0000Ioo`00<7oo0P008Goo00Y5
D4UaAE59LDEABG95LDUaAG59LPIoo`3oA[a:gDZlA[e2_5ifFUINMUYE>U`j>cYL>S]:gDZlB]e2_5HE
DOAF5E7dEQDnFd9l?U]>gD[LC]e:g4[MB]a:gDZlL]A^e7;DK[<4<00`C]e:_4kMB[a>oDE@BG55DDUa
AE59LDEABG55LDVBAG401DZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4kMB]aZefZfJ]HUM`00
A[a:_4JlB[a>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0000Ioo`00
<Woo00<007ooOol07Woo14Ea00I9LDEaBG55LDUaAG47Ool014ZlB]e:gEif0eYF00INMUM^B[a:_4Zm
A[`3B]d03T:mEQAAm5HDDOAF53il@W`nNdkMB]a>gD[L?Yd2L]@016kDL]Abe7;D0`0`00I>gDkLC]a>
g4kMAE42AG401dUaAG59LDEaBG55LDUa00801@=>g00:C]e>g4klC_aBoDkLC_e>g4kmB]`3B]d3J]H0
1BEh9GLUN4kLC]d00TkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo003Ool0
0`00Oomoo`04Ool003=oo`03001oogoo01eoo`0:AE59LDEABG55DDUaAE59LTEaBG48Ool0md:lA]eJ
EUifFUENMUM^EfmGCT[MA[a:gDJlB]e:_4JmDOAF5E7dEQEAm000B[a:gDZlC_e:g4kMB]abe6kDL]A^
/g;DK]@4<4:LA[a6W4kmB]a>oDkLBG55D4UaAE59LDEABG95LDUbAG56W49kAYa>g5;mC]a>oDkLD_e>
g5;mC]aBoDkLD_e:g4kMB]a>gFJfJ]MV]RUh9GLYV4kLC]e>g4kmC]aBoDkLD_eBo5;mC]aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l00Ioo`03001oogoo00=oo`00=7oo00<007ooOol07Goo00=5LDUaAG400TEa00A9LDEa
BG55L@Uoo`04@[e6_EYFGWH3FUH01SYK>S]:gD[LB]e:g092_@04EQAAm5HDEO@300000dZlB]e:_003
B]d01d[LL]Abe7;DK]Abe00`00A6W004C_e>g4kMAE44AG403TUaAG59LDEaBG52O4JL@Ya6W4kLC_a>
g4kmC]`2C_`01e;mC]a>gDkLC_dfOCJM00AZeP0:9GLUN2Eg9GQ>g5;mC]a>o5;lD_d3D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00Qoo`03001oogoo00=oo`00=Goo0P007Goo00Q9LDEABG4nW4UbAG59LDEa2goo0?12
_5ifFUIGKeYEGWHj>cYL>S]>gDZlC]e:_4JmDOAF5E7dEQEAm49l?U]2O4[LC]e:g4[MB]a:gFjcL]A^
e7;DK[=be00`C]e:_4kMB[a>oDkLBG55DDUaAE59LDEaBG55LDVBAG401TZlC]e:_4kMC]aBoDkLD_e>
g5;mC]aBoDkLC_e>g4kmI[IZefJfJ]IV]TZlA[a:_4JlB[a>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_d;
Ool00`00Oomoo`03Ool003Moo`03001oogoo01Yoo`=5L@05BG55LDUaAG59L@0;Ool01@1d@[eJEUYF
GWH00UYF00<j>cYK>S/00d[M00e2_EHDEOAF557dEQ@nO49l?W/nO4[LC]e:g003B]d01FkDL]A^e7;D
K]@00P0`00I>gD[LC]a:g4kMC]`2AG4034UaAG59LDEaBG55LDUa00D01T[LC]a:g09>g09>o006D_e>
g4klC_aBoD[L0d[M16[F00<004ZlB[`00TZl0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo0moo`03001oogoo00=o
o`00>7oo00<007ooOol06Goo00Q9LDEABG55LDUaAE59LTEa37oo0>QNMUYEGWIJEUifDdeGKTJlB]e6
_4[MB[a:gD:lEQEAm5HEDOAF5DZlB]e:_4[MB]a>gD[L?[e^e7;DK[=be6kDL]@0<0@`031>oD[LC_e>
g4kmAE19LDEABG55DDUbAG59LTEaAYa2NdJLC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LJ]IV
]V[GI[HYN2EgC_e>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0019oo`03001oogoo00=oo`00>Goo00<007ooOol067oo00Q5
LDUaAG59LDEaBG55LDUa3Goo00=NMUYFFUH00UM^00EGCUM^B[a:_DJl00=2_@09DOAF55GdEQAAm000
B[a:gDZl009:g009C]e:g7;DK]Abe6kDL]A^e0@`00=6W004C]e>g4kLC]`4AG402DUaAG59LDEaBG52
O4JL@Ya6W003C]`02TkMC]a>o4klD_e>g4kmC]a>oD[L0T[M16[F00HUN2EgC]a>g4kMC]`2D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo004Ool00`00
Oomoo`0?Ool00`00Oomoo`03Ool003Yoo`8001Uoo`07AE5oodEABG95LDUaAG403Goo00=JEUifFUD0
0Woo00`jG3Xk>Ua:_4kMB[a6_D:mEQEAm5HEDO@30000bd[LC]e:g4kMB]a:gDZlL]A^e7;DK[=be00`
1312W4JlAYa>oDkLC_e5DDUaAE59LTEaBG55LDVBAG59TTZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkL
C_e>g4km=WdjWFJfJ]IV]V[G9GLYN2EgD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`027oo00<007ooOol03goo00<007ooOol00goo000lOol00`00Oomo
o`0FOol01TEaOom9LDEaBG55L@moo`0?FUIoogooOolj>cYK>S/jFd[LB]e:g4:mEOAF557d009F5007
@W`nNcilB]a>gD[LC]d00T[M00e:g7;DK]Abe6kD1300<0@`B]a>g4[LC_e>g002AG401TUaAG59LDEa
BG55L@99L@0400I:g4kLB]`2C]`2C_`02E;mC]a>o4klD_e>g4kMC]a>o@04J]H00bEg001:_002B[`0
14klC]aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0;Ool00`00
Oomoo`0?Ool00`00Oomoo`02Ool003eoo`03001oogoo01Eoo`06AE5oodEaBG55LDUb57oo04A6_4[M
A[a:gDZlB]e2_5HEDOAF5E7dEQEAm49l?U]2O4[LC]e:g4km>Yebe6jcL]A^e7;D0304<@0`131:_4kM
B[a>oDE@BG55DDUaAG59LTEaBG95LDVB00D01TkLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kM
I[IZefJf:GPUMbVH0TZl08a6_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m4Goo
00<007ooOol03Woo00<007ooOol00Woo000nOol00`00Oomoo`0DOol01TUaOom9LDEaBG55LAEoo`04
B[a:_DJlB[`2B]d02D:mEQAEm5HDDOAF5000B]e:_002B]`024kMB]a>gFkDL]A^e7;DK]@5AY`3C]`0
1TkMAG55LDEaBG55L@A9L@03AYa2W4JL00=>g00:C]e>g4klC_aBoDkLC_e>g4kmB]`2B]d4J]H01RUh
9GLUN4kLC]e>g09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol03Goo00<0
07ooOol00Woo000oOol00`00Oomoo`0COol01TEAOom5DDUbAG59LAIoo`0:B[a>gDZlC]e2_DJmDOAF
5E7dEQD20000^TZlB]e:_4[MB]a:gDZlB]e^e7;DK[=be6kDAYa2W4JlAYa>oD[LC_e>g4UaAE59LTEa
BG55LDVBAG59TT9kAYa2NdJLC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4km=WdjWFJfJ]IV]V[G9GLYN2Eg
:IQ>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoAaoo`03001oogoo00eoo`03001oogoo009oo`00@7oo0P005Goo
00A9LDEaBG55LAMoo`07B]a:gD[LB]e2_EHDDO@00eHD00HnNcilB]a>gD[LC]d2B]d05D[LL]A^e7;D
K]Abe0@`C]e:g4kLB]a>oDkLC]e5LDUaAG59LDEaBG55L@02BG4014UbB]a>g4[L0TkL00A>o4kLC_e>
g09>o005D_e>g4kMC]a>o@05J]H5B[`01TkLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m021oo`03001oogoo00aoo`03001oogoo
009oo`00@Woo00<007ooOol04Woo00=5LDUaAG406Goo03m:_4[MB[a6_E7dEQEAm5HEDOA2O3iK@W`n
FdkMB]a>gD[LB]e:_7;DK]Abe6jc1340<4kMB[a>gDZlC_e>g4UaAE59LDEaBI95LDUbAG59TTEa00I:
_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gFJfJ]MV]V[F00000dZl07]6_5;mC]aBoDkLD_e>
o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`09Goo00<0
07ooOol02goo00<007ooOol00Woo0013Ool00`00Oomoo`0AOol00dUaAG59L@0JOol2B]d01D[L@[eF
55HDDO@00UHD00i:gDZlB]a:_4kMB]a>gCjML]A^e7;DK]Abe00`0P@`00Y>gDkLC]a>g4kMAG59LDEa
BG55L@E9L@801P=>g00:C]e>g4klC_aBoDkLC_e>g4kmB]`2B]d4J]H01RUh9GM>g4kLC]e>g09Bo005
D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo2Qoo`03001o
ogoo00]oo`03001oogoo009oo`00A7oo00<007ooOol047oo00=5DDUbAG406goo0;A:_4[M@[aF5E7d
EQEAm5HE001:gDZlB]e:_4kMB]a>oFkDL]A^/g;DK[Abe4:LA[a6W4kmB]a>oDkLBG55DDUbAG59LTEa
BI95LDVBAG56W49kAYa>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e:g4kMB]aZeVJfJ]MV]RVH9GM>oDkL
C]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d]Ool00`00Oomo
o`0;Ool00`00Oomoo`01Ool004Eoo`80011oo`03BG55LDUa01aoo`92_@04DOAF55HDEQ@3000034kM
B]a>gD[LB]e:g4[MK]Abe6kDL]A^e0A6W008C_e>g4kMAG59LDEaBG55L@A9L@0:BI92O4JL@Ya6W4kL
C_a>g4kmC]`2C_`01e;mC]a>gDkLC_dfOCJM00AZeP079GLYN2EgC_a>g5;mC]`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l035oo`03001oogoo00Yoo`03001oogoo005oo`00Agoo
00<007ooOol03Woo00=9LGooOol077oo03a2_EHEDOAF5E7dEQDnFd9l?U]>gD[LC]e:g4[MB[a:gFjd
L]A^/g;D031>gDZlC]e:_4kmC]a9LDEaBG55LDVBAG59TTEaBI95L@06B[a>gDZlC]e>g5;mC]aBoDkL
D_e>g5;mC]a>oDkLC_eV]V[GI[IZeREg0002B[`0KTJlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_deOol00`00Oomoo`09Ool00`00Oomoo`01Ool004Qoo`03001oogoo00eoo`03AG5o
ogoo01aoo`04@[eF55HDDO@3EQ@03Cik?W`nO4kMB]a>gD[L?Ye^e7;DK]Abe6kD00<4<009B]a>g4[L
C]e5LDUaAG59LDEa00E9L@801P=>g006C]e>g4klC_aBoDkL0Tkl00=BoD[LB]d00T[M0f[F00<YN2Eg
:GP00dZl0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`iOol00`00Oomoo`09Ool00`00Oomoo`01
Ool004Uoo`03001oogoo00aoo`03BG9oogoo01eoo`0EA[eAm5HEDOAF5E7d001:_4[MB[a>gD[LC_e:
g7;DK[=be6jdL]A2W4Jl0096W02=B]a>oDkLBG55DDUbAG59LTEaBI95LDVBAG56W49kAYa>g5;mC]a>
oDkLD_e>g5;mC]aBoDkLD_e:g4kMB]aZeVJfJ]MV]RVH9GLYV4kLC]e>g5;mC]aBoDkLD_eBo5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l03eoo`03001oogoo00Qoo`03001oogoo005oo`00BWoo0P0037oo00=5LGooOol07Goo00E2_EHD
EQAF557d00<00005B[a:g4ZlB]e:g002B]d01G;DK]Abe6kD134014JL0dkL00A9LDEaBG55L@A9L@0:
BI92O4JL@Ya6W4kLC_a>g4kmC]`2C_`01e;mC]a>gDkLC_dfOCJM009ZeP05J[IZeREg:GPUM`02C]`0
1DkMC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mD_aoo`10Ool00`00Oomoo`07Ool00`00Oomoo`01Ool004aoo`03001oogoo
00Uoo`03BG5oogoo01eoo`0jA[eAm5HEDOAF5Goo@W`nFd9lB]a>gD[LB]e:_4[MK[Abe6jcL]A^]0@a
B[a>gDZlC]e>g4kmAG59LDEaBI95LDVBAG59TTUaBI9:_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4km
C]a>oFJfJ]MV]V[FI[H3B[`0H4JLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoDIoo`03001oogoo00Ioo`03001oogoo005oo`00
CGoo00<007ooOol0:Goo00=F557dEQ@00Woo00`nNcil?Wa2O4[LC]e:g4[MB]a:gFkDL]@2K]@02`@`
135:g4kLB]a>gDkLBG55LDUaAG400TUa00Q9LTUaBI99L@06B]a>g4[L0TkL0Tkl00IBoDkLC_a>o5;m
B]`3B]d01FZfJ]IZeV[F000014Zl0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`17Ool00`00Oomoo`07Ool10001Ool1Ool004ioo`03
001oogoo02Uoo`03EQEAm7oo009oo`2@B[a:gDZlB]e:g4kmB]`n_FjcL]A^]7;DK[<4<@@`135:g4km
C]a>oDEABG95LDUbAG59TTEaBI95LDVB00H01dkLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoD[LC]e:g6[F
I[IZefJf:IPUMdkmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mCGoo00<007ooOol01Woo0@000Goo0Goo001?Ool2000YOol00eHDOomoo`03Ool3
B[`01D[MB]a>gD[LL]@00fkD00=be0@`AY`00TJL0dkL00A9LDEaBG55L@A9L@06BI99LDJL@Ya6W49l
0TkL00Y>gDkLC_a>o5;mC]a>oDkLC_e:g09:g@06J]IZ]V[FJ]HYN2Eg0TkL00E>gDkLD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_aBOol00`00Oomoo`05Ool10001Ool1Ool0
055oo`03001oogoo02Ioo`03EQEoogoo00Aoo`0>B]a>gD[LC]e:_4[MB]abe6jcL]A^]7;D1316_096
W01gC]a>oDkLBG55LDVBAG59TTEaBI99LDVBAG5>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]a>oDkLC_df
OCZMI[IZeVJfJ]LUMbVH9GMBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o01EOol00`00Oomoo`05Ool10001Ool1Ool0059oo`03001oogoo02eoo`05B]a>gD[LC]e:g002B]d0
3W;DK]A^e6kD1344<4kLB]a>gDkLC]e5LDUaAG42BG402TUbBG59TTUaBI801TkLB]a>g4[L0Tkl00YB
oDkLC_a>o5;mC]a>gDkLC_eZ]P=ZeP039GL004Zl00=:_003C]aBoDkL009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo5Uoo`03001oogoo00Aoo`40005oo`5oo`00Dgoo00<007ooOol0;Goo07m:g4kmB]a>
gCZML]A^]7;DK[Abe0@`1344<4kMB[a>gD[LBG95LDUbAG59TTEaBI95LDVBBG401`06D_e>g4kmC]aB
oDkLD_e>g5;mC]aBoDkLC]e:g4kMI[IZefJf:IPUMbVHC]a>gDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo01MOol00`00Oomoo`03Ool10001Ool1Ool005Aoo`03001oogoo02eoo`04B]a>gD[LC]d3
K]@00g;DK]A6W003AY`2C]`00dkMAG59L@05BG401TVBBG59TT:LAYa2O09>g00:C]e>g4klC_aBoDkL
C_e>g4kmC]`2B]d02V[FJ[IZeV[F:GPUMbUhC]a>gDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo01ROol00`00
Oomoo`03Ool10001Ool005Eoo`8002ioo`0:B[a:gD[LL]A^]7;DK[Abe0@`A[`2AY`0JTkLC_e>g4km
AG59TTEaBI95LDVBBG59TTEaAYa2NdJLC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]`jWFJfJ]IV]V[G
9GLYV2EgD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mIGoo00<007ooOol00goo0@000Goo001GOol00`00Oomoo`0/
Ool014[LB]e:gG;D0fkD00X4<D[LC]a:g4kMC]a>gDkLBG55L@99L@0>BG99LDVBBG59TP06C]a:g4kL
B]a>o4kLC_e>g09>o006D_e>g4kMC]a>oFJf0f[F00<UM`00B[`00TZl00A>o4kLD_e>g09Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_a/Ool00`00Oomoo`02
Ool10001Ool005Qoo`03001oogoo02aoo`0^>Yebe6jdL]A^]7;D1304<@@`C]e:_4kMB]a>oDEaBI95
LDVBAG59TTEaBI99L@0700IBoDkLC_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC]eV]V[GI[IZeREg:IP2
B[`0>TJLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
LGoo00D007ooOomoo`00005oo`00FGoo00<007ooOol0;7oo0fkD00=be6kDAY`00dJL0TkL00=>gDkL
BG401DUa00I9TTUaBI92W4JL@W`2C]`02TkMC]a>o4klD_e>g4kmC]a>oDkL0T[M00UZeVJfJ]IZeRVH
9GLYN4kLC]d00TkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l
MGoo00@007ooOol0005oo`00FWoo0P00;Goo00=^]7;DK[@00Woo05e6_4JLAYa2W4kmC]a>oDEaBI95
LDVBAG59TTUaBI95LDVB@W]6W49kD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL>YdfOF[FI[IZefJf:IPU
MbVHC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0N7oo00@007ooOol0
005oo`00G7oo00<007ooOol0:Woo00=be6kDOol00Woo00L4<4kLB]a>gD[LC]e>g004BG403TVBBG59
TTUaBI99L@07B]a>g4[LC_a>g4kmC]`2C_`01U;mC]a>gDkLC_e>g0=ZeP03I[IZeTZl00=:_006C]aB
oDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_alOol00`00Ool00001Ool005eoo`03001oogoo
02ioo`0W1344<4kMB[a>gDZlC_e5LDVBAG59TTEaBI95LDVBBG59TP0600M:_4kMB[aBoDkLD_e>g5;m
C]aBoDkLC]e:g4kMB]aZefJfJ]HUM`00009:_00^AYaBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_f0Ool10001Ool1000005ioo`03001oogoo02eoo`84<@05131>g4kLC]e>g002BG401TUbBG59LDUa
BI99L@99TP05AYa2O4JLC]a>g@02C]`01dklD_e>g4kmC]a>oDkL00=:g@05I[IZeVZf:IPYM`02C]`0
1TkMC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo024Ool2000005moo`8002ioo`96W01=@Ya6_4kLC_e5
LDVBAG59TTEaBI99LDVBBG59TT9kAYa2NdJLC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gFJfJ]MV
]RVH9GLYV4kLC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo028Ool20000065oo`03001oogoo02aoo`03B]a>gD[L009>
g0A9L@03BI99LDVB00A9TP03B]a>g4[L009>g00?C_e>g4klC_aBoDkLC]e>g4kmC]aZeVZfJ]IV]V[F
00A:_006C]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoE;lOol0RWoo0P00001ROol00`00Oomoo`0/Ool094ZlC]e:_4kMC]a9TTEaBI95
LDVBAG59TTUaBI99L@07B[a>gDZlD_e>g5;mC]aBoDkLD_e>g4kMB]a>gD[LJ]MV]V[FI[H0009:_00Q
AYa:_4kLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;l08Yoo`@0009oo`00Hgoo00<007ooOol0;7oo00I>g4kMC]a>g4UaBG83BG400dVBBG59TP02
BI80149lAYa>g4kM0TkL00M>o5;mC]a>oDkLC_e>g003B]d026JfJ]IZ]V[F:GLYN4kLC]d2C]`00e;l
D_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08aoo`@000Ioo`00
I7oo0P00;Goo03a>g4kmB]a9TTEaBI95LDVBBG59TTUaBI99LDJL@W]6W4kLD_e>g5;mC]aBoDkLD_e>
g5;mC]a>gD[LC]eV]V[GI[IZeREg:IQ>g4kMC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaf;Ool4000:Ool006Ioo`03001oogoo02]oo`03C]a>oDUa0099L@03BI99LDVB00A9
TP03B]a>g4[L009>g00:C_e>g4klC_aBoDkLC_a>g4kmC]`2=Wd03F[FI[IZeVZf:IPYMbUhC]aBoDkL
C_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo02:Ool4000>Ool006Moo`03001oogoo02]o
o`0OC]a>oDEaBI99LDVBAG59TTUaBI99L@08B[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLJ]MV
]V[FI[H00P0001=:_4JLB[a>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBo@2:Ool3000BOol0
06Qoo`03001oogoo02]oo`07C]a9LTUaBI99LDVBBG400dVB0P0700a>g4kMC]a>g4klD_e>g4klC]a>
oDkLC_d2B]d024[LJ]IV]V[F:GLYN4kLC]d2C]`00e;lD_e>o002D_`01E;mD_aBo5;lD_d00U;lRGoo
10005Goo001YOol2000/Ool0;4EaBI95LDVBBG59TTUaBI99LDJL@W]6W49kC_e>g5;mC]aBoDkLD_e>
g5;mC]a>gD[LC]eV]V[GI[IZeREg:IQ>g4kMC]a>oDkLD_e>g5;mD_aBoDkLD_f8Ool4000IOol006]o
o`03001oogoo02Uoo`99L@03BI99LDVB00E9TP06C]a:g4kLB]a>oDkL0Tkl00IBoDkLC_a>g4kmC]`2
=Wd03F[FI[IZeVJf:IPYMbUhC]aBoDkLC_a>g5;m009Bo8Moo`@001eoo`00K7oo00<007ooOol0:7oo
0255LDVBBG59TTEaBI99LDVBBG5=TP07C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC_e>g6[GI[IZeVJf
Ool004ZlAY`00TZlRGoo10008Goo001]Ool00`00Oomoo`0XOol01DUaBI99LDVBBG4014VB0P0700]>
gDkLC]a>g5;mC]a>o4kLC_e>g4km009:g@03B]aZeVJf08eoo`<002Eoo`00KWoo00<007ooOol09goo
01Y9TTEaBI99LDVBBG59TTVABI92NdJL@W]>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LRWoo1000
:7oo001_Ool2000WOol00dUaBI99L@06BI802TkLB]a>g4[LC_e>g4klC]aBoDkL0Tkl00E>oDkLC]df
OCJM08Ioo`@002aoo`00LGoo00<007ooOol097oo01U9TTUaBI95LDVBBG59TTUaCI801`08B[a>gDZl
D_e>g5;mC]aBoDkLD_e>g4kmC]a>o@23Ool4000`Ool0079oo`03001oogoo02=oo`05BG59TTVBBI99
L@04BI800dJL@Ya6W003C]`014kMC]a>o4klQGoo1000=7oo001cOol00`00Oomoo`0ROol03DVBAG59
TTUaBI99LDfBBI59TT9kAYa2NdJL08Moo`@003Qoo`00M7oo0P008Woo00=9LDVBBG401TVB00=oo`00
Ool0QGoo0`00?7oo001fOol00`00Oomoo`0OOol024VBBG59TTUaBI99LDVBBG42Ool00`00Oomoo`20
Ool4000oOol007Moo`03001oogoo01moo`M9TP9oo`03001oogoo07aoo`@004=oo`00N7oo00<007oo
Ool07Woo00M5LDVBBG59TTUaCI99T@02Ool00`00Oomoo`1hOol40017Ool007Uoo`8001ioo`03BI99
LDVB00A9TP9oo`03001oogoo07Aoo`@004]oo`00Ngoo00<007ooOol06goo00M9LDVBBG59TTUaBI99
L@02Ool00`00Oomoo`1aOol3001?Ool007aoo`03001oogoo01]oo`I9TP9oo`03001oogoo06eoo`@0
059oo`00OGoo00<007ooOol06Woo00I9TTUaBI99LDfBBI82Ool00`00Oomoo`1YOol4001FOol007io
o`8001Yoo`03BG59TTVB00=9TP9oo`03001oogoo06Eoo`@005Yoo`00P7oo00<007ooOol05goo00I9
TTUaBI99LDVBBG42Ool00`00Oomoo`1QOol4001NOol0085oo`03001oogoo01Ioo`E9TP=oo`03001o
ogoo05ioo`<0069oo`00PWoo00<007ooOol05Goo00E9TTUaBI99LDfB00=oo`03001oogoo05Yoo`@0
06Eoo`00Pgoo00<007ooOol057oo00=9LDVBBI800TVB0goo00<007ooOol0EWoo1000JGoo0024Ool2
000DOol01DVBBG5=TTVABI800goo00<007ooOol0DWoo1000KGoo0026Ool00`00Oomoo`0BOol4BI83
Ool00`00Oomoo`1>Ool4001aOol008Moo`03001oogoo015oo`04BG59TTUaCI83Ool00`00Oomoo`1;
Ool3001eOol008Qoo`03001oogoo011oo`A9TP=oo`03001oogoo04Moo`@007Qoo`00RGoo0P0047oo
00A9LDfBBI59TP=oo`03001oogoo04=oo`@007aoo`00Rgoo00<007ooOol03Woo0dVB0goo00<007oo
Ool0?goo1000P7oo002<Ool00`00Oomoo`0=Ool00dVBBG5=TP02Ool00`00Oomoo`0lOol40024Ool0
08eoo`03001oogoo00aoo`99TP=oo`03001oogoo03Uoo`<008Qoo`00SWoo0P0037oo00==TTVBOol0
0Woo00<007ooOol0=Goo1000Rgoo002@Ool00`00Oomoo`09Ool2BI83Ool00`00Oomoo`0aOol4002?
Ool0095oo`03001oogoo00Qoo`03BI99LGoo009oo`03001oogoo02eoo`@009=oo`00TWoo00<007oo
Ool01goo0TVB0goo00<007ooOol0:Goo1000Ugoo002COol20007Ool00dfBBI9oo`02Ool00`00Oomo
o`0UOol4002KOol009Eoo`03001oogoo00Eoo`05BI9oogooOol0000TOol3002OOol009Ioo`03001o
ogoo00Aoo`05BG5oogooOol0000POol4002ROol009Moo`03001oogoo00=oo`05BI9oogooOol0000L
Ool4002VOol009Qoo`03001oogoo00Ioo`03001oogoo01Ioo`@00:Yoo`00VGoo0P001Woo00<007oo
Ool04Woo1000[Woo002KOol00`00Oomoo`03Ool00`00Oomoo`0?Ool3002bOol009aoo`03001oogoo
009oo`03001oogoo00]oo`@00;Eoo`00WGoo00D007ooOomoo`0000Uoo`@00;Uoo`00WWoo0P0000=o
o`00Ool017oo1000_Goo002POol200000goo000000020031Ool00:5oo`800<Eoo`00ogooJGoo003o
OomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.755 .637 .73 r
.39627 .69984 .40137 .71098 .41066 .69778 .40547 .68974 Mtetra
.48 .568 .867 r
.40547 .68974 .41066 .69778 .41957 .69654 .4143 .69143 Mtetra
.625 .726 .919 r
.4143 .69143 .41957 .69654 .42854 .6945 .42327 .68959 Mtetra
.639 .738 .921 r
.42327 .68959 .42854 .6945 .43754 .69232 .43229 .68743 Mtetra
.64 .74 .921 r
.43229 .68743 .43754 .69232 .44658 .69019 .44135 .68523 Mtetra
.631 .735 .923 r
.44135 .68523 .44658 .69019 .45563 .68855 .45043 .68322 Mtetra
.545 .691 .935 r
.45043 .68322 .45563 .68855 .46299 .78828 .45951 .68287 Mtetra
.603 .41 .593 r
.45951 .68287 .46299 .78828 .47393 .6802 .46878 .67364 Mtetra
.558 .651 .897 r
.46878 .67364 .47393 .6802 .48308 .6785 .47793 .67341 Mtetra
.636 .734 .919 r
.47793 .67341 .48308 .6785 .49227 .67619 .48713 .67127 Mtetra
.648 .745 .92 r
.48713 .67127 .49227 .67619 .50149 .67371 .49638 .66884 Mtetra
.653 .749 .92 r
.49638 .66884 .50149 .67371 .51075 .67114 .50565 .66628 Mtetra
.655 .751 .92 r
.50565 .66628 .51075 .67114 .52004 .6685 .51496 .66366 Mtetra
.657 .752 .92 r
.51496 .66366 .52004 .6685 .52936 .66582 .5243 .66098 Mtetra
.658 .753 .92 r
.5243 .66098 .52936 .66582 .53871 .66312 .53367 .65826 Mtetra
.659 .754 .92 r
.53367 .65826 .53871 .66312 .54809 .66039 .54308 .65553 Mtetra
.54308 .65553 .54809 .66039 .5575 .65766 .55251 .65278 Mtetra
.55251 .65278 .5575 .65766 .56695 .65493 .56198 .65002 Mtetra
.56198 .65002 .56695 .65493 .57643 .65219 .57148 .64726 Mtetra
.658 .753 .92 r
.57148 .64726 .57643 .65219 .58594 .64945 .58101 .6445 Mtetra
.58101 .6445 .58594 .64945 .59548 .6467 .59058 .64174 Mtetra
.59058 .64174 .59548 .6467 .60505 .64395 .60017 .63897 Mtetra
.60017 .63897 .60505 .64395 .61466 .6412 .6098 .63619 Mtetra
.6098 .63619 .61466 .6412 .6243 .63843 .61947 .63341 Mtetra
.61947 .63341 .6243 .63843 .63398 .63566 .62916 .63062 Mtetra
.657 .753 .92 r
.62916 .63062 .63398 .63566 .64368 .63288 .63889 .62782 Mtetra
.63889 .62782 .64368 .63288 .65342 .6301 .64866 .62502 Mtetra
.64866 .62502 .65342 .6301 .6632 .6273 .65845 .6222 Mtetra
.65845 .6222 .6632 .6273 .67301 .6245 .66829 .61938 Mtetra
.657 .752 .92 r
.66829 .61938 .67301 .6245 .68285 .62169 .67815 .61655 Mtetra
.67815 .61655 .68285 .62169 .69273 .61887 .68805 .61371 Mtetra
.68805 .61371 .69273 .61887 .70264 .61604 .69799 .61086 Mtetra
.69799 .61086 .70264 .61604 .71258 .6132 .70796 .60801 Mtetra
.70796 .60801 .71258 .6132 .72256 .61035 .71796 .60514 Mtetra
.71796 .60514 .72256 .61035 .73258 .60749 .728 .60227 Mtetra
.728 .60227 .73258 .60749 .74263 .60463 .73808 .59938 Mtetra
.73808 .59938 .74263 .60463 .75271 .60175 .74819 .59649 Mtetra
.74819 .59649 .75271 .60175 .76283 .59887 .75833 .59358 Mtetra
.75833 .59358 .76283 .59887 .77299 .59597 .76851 .59067 Mtetra
.76851 .59067 .77299 .59597 .78318 .59307 .77873 .58774 Mtetra
.77873 .58774 .78318 .59307 .79341 .59015 .78899 .58481 Mtetra
.78899 .58481 .79341 .59015 .80368 .58723 .79928 .58187 Mtetra
.79928 .58187 .80368 .58723 .81398 .5843 .80961 .57891 Mtetra
.80961 .57891 .81398 .5843 .82432 .58135 .81997 .57595 Mtetra
.81997 .57595 .82432 .58135 .83469 .5784 .83037 .57298 Mtetra
.83037 .57298 .83469 .5784 .84511 .57543 .84081 .56999 Mtetra
.84081 .56999 .84511 .57543 .85556 .57246 .85129 .567 Mtetra
.85129 .567 .85556 .57246 .86604 .56948 .8618 .56399 Mtetra
.8618 .56399 .86604 .56948 .87657 .56648 .87236 .56098 Mtetra
.87236 .56098 .87657 .56648 .88713 .56347 .88295 .55795 Mtetra
.88295 .55795 .88713 .56347 .89773 .56046 .89357 .55492 Mtetra
.89357 .55492 .89773 .56046 .90837 .55743 .90424 .55187 Mtetra
.90424 .55187 .90837 .55743 .91905 .55439 .91495 .54881 Mtetra
.91495 .54881 .91905 .55439 .92976 .55135 .92569 .54574 Mtetra
.92569 .54574 .92976 .55135 .94052 .54829 .93648 .54267 Mtetra
.93648 .54267 .94052 .54829 .95131 .54522 .9473 .53957 Mtetra
.9473 .53957 .95131 .54522 .96215 .54214 .95816 .53647 Mtetra
.95816 .53647 .96215 .54214 .97302 .53905 .96907 .53336 Mtetra
.96907 .53336 .97302 .53905 .98393 .53594 .98001 .53024 Mtetra
.015 .385 .846 r
.39094 .69405 .39627 .69984 .40547 .68974 .39963 .69915 Mtetra
0 0 0 r
.39963 .69915 .40547 .68974 .4143 .69143 .409 .68585 Mtetra
.6 .701 .914 r
.409 .68585 .4143 .69143 .42327 .68959 .41798 .68458 Mtetra
.635 .734 .92 r
.41798 .68458 .42327 .68959 .43229 .68743 .42701 .6825 Mtetra
.64 .74 .921 r
.42701 .6825 .43229 .68743 .44135 .68523 .43608 .68029 Mtetra
.637 .739 .922 r
.43608 .68029 .44135 .68523 .45043 .68322 .44519 .67812 Mtetra
.614 .726 .926 r
.44519 .67812 .45043 .68322 .45951 .68287 .45431 .67645 Mtetra
.952 .663 .45 r
.45431 .67645 .45951 .68287 .46878 .67364 .46169 .77661 Mtetra
0 0 .308 r
.46169 .77661 .46878 .67364 .47793 .67341 .47275 .66799 Mtetra
.619 .717 .916 r
.47275 .66799 .47793 .67341 .48713 .67127 .48197 .66626 Mtetra
.644 .741 .92 r
.48197 .66626 .48713 .67127 .49638 .66884 .49123 .66391 Mtetra
.651 .747 .92 r
.49123 .66391 .49638 .66884 .50565 .66628 .50053 .66139 Mtetra
.654 .75 .92 r
.50053 .66139 .50565 .66628 .51496 .66366 .50985 .65877 Mtetra
.656 .752 .92 r
.50985 .65877 .51496 .66366 .5243 .66098 .51922 .65609 Mtetra
.658 .753 .92 r
.51922 .65609 .5243 .66098 .53367 .65826 .52861 .65337 Mtetra
.659 .754 .92 r
.52861 .65337 .53367 .65826 .54308 .65553 .53803 .65062 Mtetra
.53803 .65062 .54308 .65553 .55251 .65278 .54749 .64786 Mtetra
.54749 .64786 .55251 .65278 .56198 .65002 .55698 .64508 Mtetra
.55698 .64508 .56198 .65002 .57148 .64726 .5665 .64231 Mtetra
.658 .753 .92 r
.5665 .64231 .57148 .64726 .58101 .6445 .57605 .63952 Mtetra
.57605 .63952 .58101 .6445 .59058 .64174 .58564 .63674 Mtetra
.58564 .63674 .59058 .64174 .60017 .63897 .59526 .63395 Mtetra
.59526 .63395 .60017 .63897 .6098 .63619 .60491 .63116 Mtetra
.60491 .63116 .6098 .63619 .61947 .63341 .6146 .62835 Mtetra
.6146 .62835 .61947 .63341 .62916 .63062 .62432 .62555 Mtetra
.62432 .62555 .62916 .63062 .63889 .62782 .63407 .62273 Mtetra
.657 .753 .92 r
.63407 .62273 .63889 .62782 .64866 .62502 .64386 .61991 Mtetra
.64386 .61991 .64866 .62502 .65845 .6222 .65368 .61707 Mtetra
.65368 .61707 .65845 .6222 .66829 .61938 .66353 .61423 Mtetra
.66353 .61423 .66829 .61938 .67815 .61655 .67342 .61138 Mtetra
.657 .752 .92 r
.67342 .61138 .67815 .61655 .68805 .61371 .68335 .60853 Mtetra
.68335 .60853 .68805 .61371 .69799 .61086 .69331 .60566 Mtetra
.69331 .60566 .69799 .61086 .70796 .60801 .7033 .60278 Mtetra
.7033 .60278 .70796 .60801 .71796 .60514 .71333 .5999 Mtetra
.71333 .5999 .71796 .60514 .728 .60227 .72339 .597 Mtetra
.72339 .597 .728 .60227 .73808 .59938 .73349 .5941 Mtetra
.73349 .5941 .73808 .59938 .74819 .59649 .74363 .59119 Mtetra
.74363 .59119 .74819 .59649 .75833 .59358 .7538 .58826 Mtetra
.7538 .58826 .75833 .59358 .76851 .59067 .76401 .58533 Mtetra
.76401 .58533 .76851 .59067 .77873 .58774 .77425 .58239 Mtetra
.77425 .58239 .77873 .58774 .78899 .58481 .78453 .57943 Mtetra
.78453 .57943 .78899 .58481 .79928 .58187 .79485 .57647 Mtetra
.79485 .57647 .79928 .58187 .80961 .57891 .8052 .5735 Mtetra
.8052 .5735 .80961 .57891 .81997 .57595 .81559 .57051 Mtetra
.81559 .57051 .81997 .57595 .83037 .57298 .82602 .56752 Mtetra
.82602 .56752 .83037 .57298 .84081 .56999 .83649 .56452 Mtetra
.83649 .56452 .84081 .56999 .85129 .567 .84699 .5615 Mtetra
.84699 .5615 .85129 .567 .8618 .56399 .85754 .55848 Mtetra
.85754 .55848 .8618 .56399 .87236 .56098 .86812 .55544 Mtetra
.86812 .55544 .87236 .56098 .88295 .55795 .87873 .5524 Mtetra
.87873 .5524 .88295 .55795 .89357 .55492 .88939 .54934 Mtetra
.88939 .54934 .89357 .55492 .90424 .55187 .90009 .54627 Mtetra
.90009 .54627 .90424 .55187 .91495 .54881 .91082 .54319 Mtetra
.91082 .54319 .91495 .54881 .92569 .54574 .92159 .5401 Mtetra
.92159 .5401 .92569 .54574 .93648 .54267 .93241 .537 Mtetra
.93241 .537 .93648 .54267 .9473 .53957 .94326 .53389 Mtetra
.94326 .53389 .9473 .53957 .95816 .53647 .95415 .53077 Mtetra
.95415 .53077 .95816 .53647 .96907 .53336 .96508 .52764 Mtetra
.96508 .52764 .96907 .53336 .98001 .53024 .97606 .52449 Mtetra
.576 .706 .931 r
.38557 .68881 .39094 .69405 .39963 .69915 .39449 .68791 Mtetra
.755 .637 .73 r
.39449 .68791 .39963 .69915 .409 .68585 .40376 .67773 Mtetra
.48 .568 .867 r
.40376 .67773 .409 .68585 .41798 .68458 .41265 .67939 Mtetra
.625 .726 .919 r
.41265 .67939 .41798 .68458 .42701 .6825 .4217 .67752 Mtetra
.639 .738 .921 r
.4217 .67752 .42701 .6825 .43608 .68029 .43079 .67532 Mtetra
.64 .74 .921 r
.43079 .67532 .43608 .68029 .44519 .67812 .43991 .67309 Mtetra
.631 .735 .923 r
.43991 .67309 .44519 .67812 .45431 .67645 .44906 .67104 Mtetra
.545 .691 .935 r
.44906 .67104 .45431 .67645 .46169 .77661 .45822 .67065 Mtetra
.602 .408 .591 r
.45822 .67065 .46169 .77661 .47275 .66799 .46756 .66135 Mtetra
.558 .651 .897 r
.46756 .66135 .47275 .66799 .48197 .66626 .47677 .66109 Mtetra
.636 .734 .919 r
.47677 .66109 .48197 .66626 .49123 .66391 .48605 .65891 Mtetra
.648 .745 .92 r
.48605 .65891 .49123 .66391 .50053 .66139 .49537 .65644 Mtetra
.653 .749 .92 r
.49537 .65644 .50053 .66139 .50985 .65877 .50472 .65384 Mtetra
.655 .751 .92 r
.50472 .65384 .50985 .65877 .51922 .65609 .5141 .65117 Mtetra
.657 .752 .92 r
.5141 .65117 .51922 .65609 .52861 .65337 .52351 .64845 Mtetra
.658 .753 .92 r
.52351 .64845 .52861 .65337 .53803 .65062 .53296 .64569 Mtetra
.659 .754 .92 r
.53296 .64569 .53803 .65062 .54749 .64786 .54244 .64291 Mtetra
.54244 .64291 .54749 .64786 .55698 .64508 .55195 .64012 Mtetra
.55195 .64012 .55698 .64508 .5665 .64231 .56149 .63732 Mtetra
.56149 .63732 .5665 .64231 .57605 .63952 .57106 .63452 Mtetra
.658 .753 .92 r
.57106 .63452 .57605 .63952 .58564 .63674 .58067 .63171 Mtetra
.58067 .63171 .58564 .63674 .59526 .63395 .59031 .6289 Mtetra
.59031 .6289 .59526 .63395 .60491 .63116 .59999 .62609 Mtetra
.59999 .62609 .60491 .63116 .6146 .62835 .6097 .62327 Mtetra
.6097 .62327 .6146 .62835 .62432 .62555 .61944 .62044 Mtetra
.61944 .62044 .62432 .62555 .63407 .62273 .62922 .6176 Mtetra
.657 .753 .92 r
.62922 .6176 .63407 .62273 .64386 .61991 .63903 .61476 Mtetra
.63903 .61476 .64386 .61991 .65368 .61707 .64887 .61191 Mtetra
.64887 .61191 .65368 .61707 .66353 .61423 .65875 .60905 Mtetra
.65875 .60905 .66353 .61423 .67342 .61138 .66866 .60618 Mtetra
.657 .752 .92 r
.66866 .60618 .67342 .61138 .68335 .60853 .67861 .60331 Mtetra
.67861 .60331 .68335 .60853 .69331 .60566 .68859 .60042 Mtetra
.68859 .60042 .69331 .60566 .7033 .60278 .69861 .59753 Mtetra
.69861 .59753 .7033 .60278 .71333 .5999 .70867 .59462 Mtetra
.70867 .59462 .71333 .5999 .72339 .597 .71876 .59171 Mtetra
.71876 .59171 .72339 .597 .73349 .5941 .72888 .58878 Mtetra
.72888 .58878 .73349 .5941 .74363 .59119 .73904 .58585 Mtetra
.73904 .58585 .74363 .59119 .7538 .58826 .74924 .58291 Mtetra
.74924 .58291 .7538 .58826 .76401 .58533 .75947 .57996 Mtetra
.75947 .57996 .76401 .58533 .77425 .58239 .76974 .57699 Mtetra
.76974 .57699 .77425 .58239 .78453 .57943 .78005 .57402 Mtetra
.78005 .57402 .78453 .57943 .79485 .57647 .79039 .57104 Mtetra
.79039 .57104 .79485 .57647 .8052 .5735 .80077 .56804 Mtetra
.80077 .56804 .8052 .5735 .81559 .57051 .81119 .56504 Mtetra
.81119 .56504 .81559 .57051 .82602 .56752 .82165 .56203 Mtetra
.82165 .56203 .82602 .56752 .83649 .56452 .83214 .559 Mtetra
.83214 .559 .83649 .56452 .84699 .5615 .84267 .55597 Mtetra
.84267 .55597 .84699 .5615 .85754 .55848 .85324 .55292 Mtetra
.85324 .55292 .85754 .55848 .86812 .55544 .86385 .54987 Mtetra
.86385 .54987 .86812 .55544 .87873 .5524 .87449 .5468 Mtetra
.87449 .5468 .87873 .5524 .88939 .54934 .88518 .54372 Mtetra
.88518 .54372 .88939 .54934 .90009 .54627 .8959 .54064 Mtetra
.8959 .54064 .90009 .54627 .91082 .54319 .90666 .53754 Mtetra
.90666 .53754 .91082 .54319 .92159 .5401 .91747 .53443 Mtetra
.91747 .53443 .92159 .5401 .93241 .537 .92831 .53131 Mtetra
.92831 .53131 .93241 .537 .94326 .53389 .93919 .52817 Mtetra
.93919 .52817 .94326 .53389 .95415 .53077 .95011 .52503 Mtetra
.95011 .52503 .95415 .53077 .96508 .52764 .96108 .52187 Mtetra
.96108 .52187 .96508 .52764 .97606 .52449 .97208 .51871 Mtetra
.615 .726 .925 r
.38015 .68371 .38557 .68881 .39449 .68791 .38912 .68203 Mtetra
.019 .388 .847 r
.38912 .68203 .39449 .68791 .40376 .67773 .39787 .68712 Mtetra
0 0 0 r
.39787 .68712 .40376 .67773 .41265 .67939 .40731 .67374 Mtetra
.6 .701 .914 r
.40731 .67374 .41265 .67939 .4217 .67752 .41636 .67243 Mtetra
.635 .734 .92 r
.41636 .67243 .4217 .67752 .43079 .67532 .42546 .67032 Mtetra
.64 .74 .921 r
.42546 .67032 .43079 .67532 .43991 .67309 .4346 .66806 Mtetra
.637 .739 .922 r
.4346 .66806 .43991 .67309 .44906 .67104 .44377 .66586 Mtetra
.614 .726 .925 r
.44377 .66586 .44906 .67104 .45822 .67065 .45297 .66414 Mtetra
.953 .662 .447 r
.45297 .66414 .45822 .67065 .46756 .66135 .46036 .76474 Mtetra
0 0 .303 r
.46036 .76474 .46756 .66135 .47677 .66109 .47155 .65559 Mtetra
.619 .717 .916 r
.47155 .65559 .47677 .66109 .48605 .65891 .48084 .65382 Mtetra
.644 .741 .92 r
.48084 .65382 .48605 .65891 .49537 .65644 .49017 .65143 Mtetra
.651 .747 .92 r
.49017 .65143 .49537 .65644 .50472 .65384 .49954 .64886 Mtetra
.654 .75 .92 r
.49954 .64886 .50472 .65384 .5141 .65117 .50895 .64621 Mtetra
.656 .752 .92 r
.50895 .64621 .5141 .65117 .52351 .64845 .51838 .64349 Mtetra
.658 .753 .92 r
.51838 .64349 .52351 .64845 .53296 .64569 .52785 .64072 Mtetra
.659 .754 .92 r
.52785 .64072 .53296 .64569 .54244 .64291 .53735 .63793 Mtetra
.53735 .63793 .54244 .64291 .55195 .64012 .54688 .63512 Mtetra
.54688 .63512 .55195 .64012 .56149 .63732 .55645 .6323 Mtetra
.55645 .6323 .56149 .63732 .57106 .63452 .56604 .62948 Mtetra
.658 .753 .92 r
.56604 .62948 .57106 .63452 .58067 .63171 .57567 .62665 Mtetra
.57567 .62665 .58067 .63171 .59031 .6289 .58534 .62382 Mtetra
.58534 .62382 .59031 .6289 .59999 .62609 .59504 .62099 Mtetra
.59504 .62099 .59999 .62609 .6097 .62327 .60477 .61815 Mtetra
.60477 .61815 .6097 .62327 .61944 .62044 .61453 .6153 Mtetra
.61453 .6153 .61944 .62044 .62922 .6176 .62433 .61245 Mtetra
.62433 .61245 .62922 .6176 .63903 .61476 .63416 .60958 Mtetra
.657 .753 .92 r
.63416 .60958 .63903 .61476 .64887 .61191 .64403 .60671 Mtetra
.64403 .60671 .64887 .61191 .65875 .60905 .65394 .60384 Mtetra
.65394 .60384 .65875 .60905 .66866 .60618 .66387 .60095 Mtetra
.66387 .60095 .66866 .60618 .67861 .60331 .67384 .59805 Mtetra
.657 .752 .92 r
.67384 .59805 .67861 .60331 .68859 .60042 .68385 .59515 Mtetra
.68385 .59515 .68859 .60042 .69861 .59753 .69389 .59223 Mtetra
.69389 .59223 .69861 .59753 .70867 .59462 .70397 .58931 Mtetra
.70397 .58931 .70867 .59462 .71876 .59171 .71409 .58638 Mtetra
.71409 .58638 .71876 .59171 .72888 .58878 .72424 .58343 Mtetra
.72424 .58343 .72888 .58878 .73904 .58585 .73442 .58048 Mtetra
.73442 .58048 .73904 .58585 .74924 .58291 .74465 .57752 Mtetra
.74465 .57752 .74924 .58291 .75947 .57996 .7549 .57455 Mtetra
.7549 .57455 .75947 .57996 .76974 .57699 .7652 .57156 Mtetra
.7652 .57156 .76974 .57699 .78005 .57402 .77553 .56857 Mtetra
.77553 .56857 .78005 .57402 .79039 .57104 .7859 .56557 Mtetra
.7859 .56557 .79039 .57104 .80077 .56804 .79631 .56256 Mtetra
.79631 .56256 .80077 .56804 .81119 .56504 .80675 .55953 Mtetra
.80675 .55953 .81119 .56504 .82165 .56203 .81724 .5565 Mtetra
.81724 .5565 .82165 .56203 .83214 .559 .82776 .55345 Mtetra
.82776 .55345 .83214 .559 .84267 .55597 .83832 .5504 Mtetra
.83832 .5504 .84267 .55597 .85324 .55292 .84891 .54733 Mtetra
.84891 .54733 .85324 .55292 .86385 .54987 .85955 .54426 Mtetra
.85955 .54426 .86385 .54987 .87449 .5468 .87022 .54117 Mtetra
.87022 .54117 .87449 .5468 .88518 .54372 .88094 .53807 Mtetra
.88094 .53807 .88518 .54372 .8959 .54064 .89169 .53496 Mtetra
.89169 .53496 .8959 .54064 .90666 .53754 .90248 .53184 Mtetra
.90248 .53184 .90666 .53754 .91747 .53443 .91331 .52871 Mtetra
.91331 .52871 .91747 .53443 .92831 .53131 .92419 .52557 Mtetra
.92419 .52557 .92831 .53131 .93919 .52817 .9351 .52241 Mtetra
.9351 .52241 .93919 .52817 .95011 .52503 .94605 .51925 Mtetra
.94605 .51925 .95011 .52503 .96108 .52187 .95704 .51607 Mtetra
.95704 .51607 .96108 .52187 .97208 .51871 .96807 .51288 Mtetra
.625 .73 .923 r
.3747 .67862 .38015 .68371 .38912 .68203 .38369 .67672 Mtetra
.576 .706 .931 r
.38369 .67672 .38912 .68203 .39787 .68712 .39268 .67578 Mtetra
.756 .637 .73 r
.39268 .67578 .39787 .68712 .40731 .67374 .40203 .66553 Mtetra
.479 .568 .867 r
.40203 .66553 .40731 .67374 .41636 .67243 .41099 .66717 Mtetra
.625 .726 .919 r
.41099 .66717 .41636 .67243 .42546 .67032 .4201 .66525 Mtetra
.639 .738 .921 r
.4201 .66525 .42546 .67032 .4346 .66806 .42926 .66302 Mtetra
.64 .74 .921 r
.42926 .66302 .4346 .66806 .44377 .66586 .43845 .66074 Mtetra
.631 .735 .923 r
.43845 .66074 .44377 .66586 .45297 .66414 .44767 .65865 Mtetra
.545 .691 .935 r
.44767 .65865 .45297 .66414 .46036 .76474 .4569 .65824 Mtetra
.6 .406 .59 r
.4569 .65824 .46036 .76474 .47155 .65559 .46631 .64886 Mtetra
.558 .651 .898 r
.46631 .64886 .47155 .65559 .48084 .65382 .4756 .64857 Mtetra
.636 .734 .919 r
.4756 .64857 .48084 .65382 .49017 .65143 .48495 .64635 Mtetra
.648 .745 .92 r
.48495 .64635 .49017 .65143 .49954 .64886 .49434 .64384 Mtetra
.653 .749 .92 r
.49434 .64384 .49954 .64886 .50895 .64621 .50376 .6412 Mtetra
.655 .751 .92 r
.50376 .6412 .50895 .64621 .51838 .64349 .51322 .63848 Mtetra
.657 .752 .92 r
.51322 .63848 .51838 .64349 .52785 .64072 .52271 .63572 Mtetra
.658 .753 .92 r
.52271 .63572 .52785 .64072 .53735 .63793 .53223 .63292 Mtetra
.659 .754 .92 r
.53223 .63292 .53735 .63793 .54688 .63512 .54178 .63009 Mtetra
.54178 .63009 .54688 .63512 .55645 .6323 .55137 .62725 Mtetra
.55137 .62725 .55645 .6323 .56604 .62948 .56099 .62441 Mtetra
.56099 .62441 .56604 .62948 .57567 .62665 .57064 .62156 Mtetra
.658 .753 .92 r
.57064 .62156 .57567 .62665 .58534 .62382 .58033 .61871 Mtetra
.58033 .61871 .58534 .62382 .59504 .62099 .59005 .61586 Mtetra
.59005 .61586 .59504 .62099 .60477 .61815 .5998 .613 Mtetra
.5998 .613 .60477 .61815 .61453 .6153 .60959 .61013 Mtetra
.60959 .61013 .61453 .6153 .62433 .61245 .61941 .60726 Mtetra
.61941 .60726 .62433 .61245 .63416 .60958 .62927 .60437 Mtetra
.657 .753 .92 r
.62927 .60437 .63416 .60958 .64403 .60671 .63916 .60148 Mtetra
.63916 .60148 .64403 .60671 .65394 .60384 .64909 .59859 Mtetra
.64909 .59859 .65394 .60384 .66387 .60095 .65905 .59568 Mtetra
.65905 .59568 .66387 .60095 .67384 .59805 .66905 .59276 Mtetra
.657 .752 .92 r
.66905 .59276 .67384 .59805 .68385 .59515 .67908 .58984 Mtetra
.67908 .58984 .68385 .59515 .69389 .59223 .68915 .58691 Mtetra
.68915 .58691 .69389 .59223 .70397 .58931 .69925 .58396 Mtetra
.69925 .58396 .70397 .58931 .71409 .58638 .70939 .58101 Mtetra
.70939 .58101 .71409 .58638 .72424 .58343 .71956 .57805 Mtetra
.71956 .57805 .72424 .58343 .73442 .58048 .72977 .57507 Mtetra
.72977 .57507 .73442 .58048 .74465 .57752 .74002 .57209 Mtetra
.74002 .57209 .74465 .57752 .7549 .57455 .75031 .5691 Mtetra
.75031 .5691 .7549 .57455 .7652 .57156 .76063 .5661 Mtetra
.76063 .5661 .7652 .57156 .77553 .56857 .77099 .56309 Mtetra
.77099 .56309 .77553 .56857 .7859 .56557 .78138 .56006 Mtetra
.78138 .56006 .7859 .56557 .79631 .56256 .79182 .55703 Mtetra
.79182 .55703 .79631 .56256 .80675 .55953 .80229 .55399 Mtetra
.80229 .55399 .80675 .55953 .81724 .5565 .8128 .55093 Mtetra
.8128 .55093 .81724 .5565 .82776 .55345 .82335 .54787 Mtetra
.82335 .54787 .82776 .55345 .83832 .5504 .83393 .54479 Mtetra
.83393 .54479 .83832 .5504 .84891 .54733 .84456 .5417 Mtetra
.84456 .5417 .84891 .54733 .85955 .54426 .85522 .53861 Mtetra
.85522 .53861 .85955 .54426 .87022 .54117 .86593 .5355 Mtetra
.86593 .5355 .87022 .54117 .88094 .53807 .87667 .53238 Mtetra
.87667 .53238 .88094 .53807 .89169 .53496 .88745 .52925 Mtetra
.88745 .52925 .89169 .53496 .90248 .53184 .89827 .52611 Mtetra
.89827 .52611 .90248 .53184 .91331 .52871 .90913 .52295 Mtetra
.90913 .52295 .91331 .52871 .92419 .52557 .92003 .51979 Mtetra
.92003 .51979 .92419 .52557 .9351 .52241 .93097 .51661 Mtetra
.93097 .51661 .9351 .52241 .94605 .51925 .94196 .51343 Mtetra
.94196 .51343 .94605 .51925 .95704 .51607 .95298 .51023 Mtetra
.95298 .51023 .95704 .51607 .96807 .51288 .96404 .50702 Mtetra
.626 .73 .921 r
.36922 .67347 .3747 .67862 .38369 .67672 .37823 .67154 Mtetra
.615 .726 .925 r
.37823 .67154 .38369 .67672 .39268 .67578 .38726 .66983 Mtetra
.024 .39 .849 r
.38726 .66983 .39268 .67578 .40203 .66553 .39608 .67491 Mtetra
0 0 0 r
.39608 .67491 .40203 .66553 .41099 .66717 .4056 .66144 Mtetra
.6 .701 .914 r
.4056 .66144 .41099 .66717 .4201 .66525 .41471 .66009 Mtetra
.635 .734 .92 r
.41471 .66009 .4201 .66525 .42926 .66302 .42388 .65794 Mtetra
.64 .74 .921 r
.42388 .65794 .42926 .66302 .43845 .66074 .4331 .65564 Mtetra
.637 .739 .922 r
.4331 .65564 .43845 .66074 .44767 .65865 .44234 .65339 Mtetra
.614 .726 .925 r
.44234 .65339 .44767 .65865 .4569 .65824 .45161 .65164 Mtetra
.954 .662 .444 r
.45161 .65164 .4569 .65824 .46631 .64886 .45902 .75268 Mtetra
0 0 .298 r
.45902 .75268 .46631 .64886 .4756 .64857 .47033 .64299 Mtetra
.619 .717 .916 r
.47033 .64299 .4756 .64857 .48495 .64635 .47969 .64118 Mtetra
.644 .741 .92 r
.47969 .64118 .48495 .64635 .49434 .64384 .4891 .63875 Mtetra
.651 .747 .92 r
.4891 .63875 .49434 .64384 .50376 .6412 .49855 .63614 Mtetra
.654 .75 .92 r
.49855 .63614 .50376 .6412 .51322 .63848 .50802 .63344 Mtetra
.656 .752 .92 r
.50802 .63344 .51322 .63848 .52271 .63572 .51753 .63067 Mtetra
.658 .753 .92 r
.51753 .63067 .52271 .63572 .53223 .63292 .52708 .62787 Mtetra
.659 .754 .92 r
.52708 .62787 .53223 .63292 .54178 .63009 .53665 .62503 Mtetra
.53665 .62503 .54178 .63009 .55137 .62725 .54626 .62217 Mtetra
.54626 .62217 .55137 .62725 .56099 .62441 .5559 .61931 Mtetra
.5559 .61931 .56099 .62441 .57064 .62156 .56558 .61644 Mtetra
.658 .753 .92 r
.56558 .61644 .57064 .62156 .58033 .61871 .57529 .61357 Mtetra
.57529 .61357 .58033 .61871 .59005 .61586 .58503 .61069 Mtetra
.58503 .61069 .59005 .61586 .5998 .613 .59481 .60781 Mtetra
.59481 .60781 .5998 .613 .60959 .61013 .60462 .60492 Mtetra
.60462 .60492 .60959 .61013 .61941 .60726 .61447 .60203 Mtetra
.61447 .60203 .61941 .60726 .62927 .60437 .62435 .59913 Mtetra
.62435 .59913 .62927 .60437 .63916 .60148 .63426 .59622 Mtetra
.657 .753 .92 r
.63426 .59622 .63916 .60148 .64909 .59859 .64421 .5933 Mtetra
.64421 .5933 .64909 .59859 .65905 .59568 .6542 .59038 Mtetra
.6542 .59038 .65905 .59568 .66905 .59276 .66422 .58744 Mtetra
.66422 .58744 .66905 .59276 .67908 .58984 .67427 .5845 Mtetra
.657 .752 .92 r
.67427 .5845 .67908 .58984 .68915 .58691 .68437 .58154 Mtetra
.68437 .58154 .68915 .58691 .69925 .58396 .69449 .57858 Mtetra
.69449 .57858 .69925 .58396 .70939 .58101 .70466 .57561 Mtetra
.70466 .57561 .70939 .58101 .71956 .57805 .71486 .57263 Mtetra
.71486 .57263 .71956 .57805 .72977 .57507 .7251 .56963 Mtetra
.7251 .56963 .72977 .57507 .74002 .57209 .73537 .56663 Mtetra
.73537 .56663 .74002 .57209 .75031 .5691 .74568 .56362 Mtetra
.74568 .56362 .75031 .5691 .76063 .5661 .75603 .5606 Mtetra
.75603 .5606 .76063 .5661 .77099 .56309 .76641 .55756 Mtetra
.76641 .55756 .77099 .56309 .78138 .56006 .77684 .55452 Mtetra
.77684 .55452 .78138 .56006 .79182 .55703 .7873 .55147 Mtetra
.7873 .55147 .79182 .55703 .80229 .55399 .7978 .5484 Mtetra
.7978 .5484 .80229 .55399 .8128 .55093 .80833 .54533 Mtetra
.80833 .54533 .8128 .55093 .82335 .54787 .81891 .54224 Mtetra
.81891 .54224 .82335 .54787 .83393 .54479 .82952 .53914 Mtetra
.82952 .53914 .83393 .54479 .84456 .5417 .84017 .53604 Mtetra
.84017 .53604 .84456 .5417 .85522 .53861 .85087 .53292 Mtetra
.85087 .53292 .85522 .53861 .86593 .5355 .8616 .52979 Mtetra
.8616 .52979 .86593 .5355 .87667 .53238 .87237 .52665 Mtetra
.87237 .52665 .87667 .53238 .88745 .52925 .88318 .5235 Mtetra
.88318 .5235 .88745 .52925 .89827 .52611 .89403 .52033 Mtetra
.89403 .52033 .89827 .52611 .90913 .52295 .90492 .51716 Mtetra
.90492 .51716 .90913 .52295 .92003 .51979 .91585 .51397 Mtetra
.91585 .51397 .92003 .51979 .93097 .51661 .92682 .51077 Mtetra
.92682 .51077 .93097 .51661 .94196 .51343 .93783 .50757 Mtetra
.93783 .50757 .94196 .51343 .95298 .51023 .94889 .50435 Mtetra
.94889 .50435 .95298 .51023 .96404 .50702 .95998 .50111 Mtetra
.621 .724 .92 r
.36372 .66819 .36922 .67347 .37823 .67154 .37273 .66637 Mtetra
.625 .73 .923 r
.37273 .66637 .37823 .67154 .38726 .66983 .38179 .66443 Mtetra
.576 .706 .931 r
.38179 .66443 .38726 .66983 .39608 .67491 .39084 .66346 Mtetra
.756 .638 .73 r
.39084 .66346 .39608 .67491 .4056 .66144 .40027 .65313 Mtetra
.479 .568 .867 r
.40027 .65313 .4056 .66144 .41471 .66009 .40929 .65475 Mtetra
.625 .726 .919 r
.40929 .65475 .41471 .66009 .42388 .65794 .41848 .6528 Mtetra
.639 .738 .921 r
.41848 .6528 .42388 .65794 .4331 .65564 .42771 .65052 Mtetra
.64 .74 .921 r
.42771 .65052 .4331 .65564 .44234 .65339 .43697 .6482 Mtetra
.631 .735 .923 r
.43697 .6482 .44234 .65339 .45161 .65164 .44626 .64607 Mtetra
.546 .691 .935 r
.44626 .64607 .45161 .65164 .45902 .75268 .45556 .64562 Mtetra
.599 .404 .588 r
.45556 .64562 .45902 .75268 .47033 .64299 .46505 .63618 Mtetra
.558 .651 .898 r
.46505 .63618 .47033 .64299 .47969 .64118 .47441 .63585 Mtetra
.636 .734 .919 r
.47441 .63585 .47969 .64118 .4891 .63875 .48383 .63359 Mtetra
.648 .745 .92 r
.48383 .63359 .4891 .63875 .49855 .63614 .4933 .63103 Mtetra
.653 .749 .92 r
.4933 .63103 .49855 .63614 .50802 .63344 .50279 .62835 Mtetra
.655 .751 .92 r
.50279 .62835 .50802 .63344 .51753 .63067 .51233 .62559 Mtetra
.657 .752 .92 r
.51233 .62559 .51753 .63067 .52708 .62787 .52189 .62278 Mtetra
.658 .753 .92 r
.52189 .62278 .52708 .62787 .53665 .62503 .53149 .61993 Mtetra
.659 .754 .92 r
.53149 .61993 .53665 .62503 .54626 .62217 .54112 .61706 Mtetra
.54112 .61706 .54626 .62217 .5559 .61931 .55079 .61418 Mtetra
.55079 .61418 .5559 .61931 .56558 .61644 .56048 .61129 Mtetra
.56048 .61129 .56558 .61644 .57529 .61357 .57022 .60839 Mtetra
.658 .753 .92 r
.57022 .60839 .57529 .61357 .58503 .61069 .57998 .6055 Mtetra
.57998 .6055 .58503 .61069 .59481 .60781 .58978 .60259 Mtetra
.58978 .60259 .59481 .60781 .60462 .60492 .59962 .59969 Mtetra
.59962 .59969 .60462 .60492 .61447 .60203 .60948 .59677 Mtetra
.60948 .59677 .61447 .60203 .62435 .59913 .61939 .59385 Mtetra
.61939 .59385 .62435 .59913 .63426 .59622 .62933 .59092 Mtetra
.657 .753 .92 r
.62933 .59092 .63426 .59622 .64421 .5933 .6393 .58799 Mtetra
.6393 .58799 .64421 .5933 .6542 .59038 .64931 .58504 Mtetra
.64931 .58504 .6542 .59038 .66422 .58744 .65936 .58208 Mtetra
.65936 .58208 .66422 .58744 .67427 .5845 .66944 .57912 Mtetra
.657 .752 .92 r
.66944 .57912 .67427 .5845 .68437 .58154 .67955 .57615 Mtetra
.67955 .57615 .68437 .58154 .69449 .57858 .68971 .57316 Mtetra
.68971 .57316 .69449 .57858 .70466 .57561 .6999 .57017 Mtetra
.6999 .57017 .70466 .57561 .71486 .57263 .71012 .56717 Mtetra
.71012 .56717 .71486 .57263 .7251 .56963 .72039 .56416 Mtetra
.72039 .56416 .7251 .56963 .73537 .56663 .73068 .56113 Mtetra
.73068 .56113 .73537 .56663 .74568 .56362 .74102 .5581 Mtetra
.74102 .5581 .74568 .56362 .75603 .5606 .7514 .55506 Mtetra
.7514 .55506 .75603 .5606 .76641 .55756 .76181 .552 Mtetra
.76181 .552 .76641 .55756 .77684 .55452 .77226 .54894 Mtetra
.77226 .54894 .77684 .55452 .7873 .55147 .78275 .54587 Mtetra
.78275 .54587 .7873 .55147 .7978 .5484 .79327 .54278 Mtetra
.79327 .54278 .7978 .5484 .80833 .54533 .80384 .53968 Mtetra
.80384 .53968 .80833 .54533 .81891 .54224 .81444 .53658 Mtetra
.81444 .53658 .81891 .54224 .82952 .53914 .82508 .53346 Mtetra
.82508 .53346 .82952 .53914 .84017 .53604 .83576 .53033 Mtetra
.83576 .53033 .84017 .53604 .85087 .53292 .84648 .52719 Mtetra
.84648 .52719 .85087 .53292 .8616 .52979 .85724 .52404 Mtetra
.85724 .52404 .8616 .52979 .87237 .52665 .86804 .52088 Mtetra
.86804 .52088 .87237 .52665 .88318 .5235 .87888 .5177 Mtetra
.87888 .5177 .88318 .5235 .89403 .52033 .88976 .51452 Mtetra
.88976 .51452 .89403 .52033 .90492 .51716 .90068 .51132 Mtetra
.90068 .51132 .90492 .51716 .91585 .51397 .91164 .50812 Mtetra
.91164 .50812 .91585 .51397 .92682 .51077 .92264 .5049 Mtetra
.92264 .5049 .92682 .51077 .93783 .50757 .93368 .50166 Mtetra
.93368 .50166 .93783 .50757 .94889 .50435 .94477 .49842 Mtetra
.94477 .49842 .94889 .50435 .95998 .50111 .95589 .49517 Mtetra
.6 .704 .917 r
.35819 .66252 .36372 .66819 .37273 .66637 .3672 .66115 Mtetra
.626 .73 .921 r
.3672 .66115 .37273 .66637 .38179 .66443 .37628 .65917 Mtetra
.615 .726 .925 r
.37628 .65917 .38179 .66443 .39084 .66346 .38538 .65742 Mtetra
.028 .392 .851 r
.38538 .65742 .39084 .66346 .40027 .65313 .39425 .6625 Mtetra
0 0 0 r
.39425 .6625 .40027 .65313 .40929 .65475 .40386 .64894 Mtetra
.6 .701 .914 r
.40386 .64894 .40929 .65475 .41848 .6528 .41304 .64755 Mtetra
.635 .734 .92 r
.41304 .64755 .41848 .6528 .42771 .65052 .42228 .64536 Mtetra
.64 .74 .921 r
.42228 .64536 .42771 .65052 .43697 .6482 .43156 .64302 Mtetra
.637 .739 .922 r
.43156 .64302 .43697 .6482 .44626 .64607 .44088 .64073 Mtetra
.615 .726 .925 r
.44088 .64073 .44626 .64607 .45556 .64562 .45022 .63894 Mtetra
.955 .662 .441 r
.45022 .63894 .45556 .64562 .46505 .63618 .45765 .74042 Mtetra
0 0 .292 r
.45765 .74042 .46505 .63618 .47441 .63585 .46909 .63019 Mtetra
.619 .717 .916 r
.46909 .63019 .47441 .63585 .48383 .63359 .47853 .62833 Mtetra
.644 .741 .92 r
.47853 .62833 .48383 .63359 .4933 .63103 .48801 .62586 Mtetra
.651 .747 .92 r
.48801 .62586 .4933 .63103 .50279 .62835 .49753 .62321 Mtetra
.654 .75 .92 r
.49753 .62321 .50279 .62835 .51233 .62559 .50708 .62046 Mtetra
.656 .752 .92 r
.50708 .62046 .51233 .62559 .52189 .62278 .51667 .61765 Mtetra
.658 .753 .92 r
.51667 .61765 .52189 .62278 .53149 .61993 .52629 .6148 Mtetra
.659 .754 .92 r
.52629 .6148 .53149 .61993 .54112 .61706 .53595 .61191 Mtetra
.53595 .61191 .54112 .61706 .55079 .61418 .54563 .60901 Mtetra
.54563 .60901 .55079 .61418 .56048 .61129 .55535 .6061 Mtetra
.55535 .6061 .56048 .61129 .57022 .60839 .56511 .60319 Mtetra
.658 .753 .92 r
.56511 .60319 .57022 .60839 .57998 .6055 .5749 .60027 Mtetra
.5749 .60027 .57998 .6055 .58978 .60259 .58472 .59734 Mtetra
.58472 .59734 .58978 .60259 .59962 .59969 .59458 .59442 Mtetra
.59458 .59442 .59962 .59969 .60948 .59677 .60447 .59148 Mtetra
.60447 .59148 .60948 .59677 .61939 .59385 .6144 .58854 Mtetra
.6144 .58854 .61939 .59385 .62933 .59092 .62436 .58559 Mtetra
.62436 .58559 .62933 .59092 .6393 .58799 .63436 .58263 Mtetra
.657 .753 .92 r
.63436 .58263 .6393 .58799 .64931 .58504 .64439 .57967 Mtetra
.64439 .57967 .64931 .58504 .65936 .58208 .65446 .57669 Mtetra
.65446 .57669 .65936 .58208 .66944 .57912 .66457 .57371 Mtetra
.66457 .57371 .66944 .57912 .67955 .57615 .67471 .57071 Mtetra
.657 .752 .92 r
.67471 .57071 .67955 .57615 .68971 .57316 .68489 .56771 Mtetra
.68489 .56771 .68971 .57316 .6999 .57017 .6951 .5647 Mtetra
.6951 .5647 .6999 .57017 .71012 .56717 .70535 .56167 Mtetra
.70535 .56167 .71012 .56717 .72039 .56416 .71564 .55864 Mtetra
.71564 .55864 .72039 .56416 .73068 .56113 .72597 .5556 Mtetra
.72597 .5556 .73068 .56113 .74102 .5581 .73633 .55255 Mtetra
.73633 .55255 .74102 .5581 .7514 .55506 .74673 .54948 Mtetra
.74673 .54948 .7514 .55506 .76181 .552 .75717 .54641 Mtetra
.75717 .54641 .76181 .552 .77226 .54894 .76765 .54332 Mtetra
.76765 .54332 .77226 .54894 .78275 .54587 .77816 .54023 Mtetra
.77816 .54023 .78275 .54587 .79327 .54278 .78872 .53712 Mtetra
.78872 .53712 .79327 .54278 .80384 .53968 .79931 .534 Mtetra
.79931 .534 .80384 .53968 .81444 .53658 .80994 .53088 Mtetra
.80994 .53088 .81444 .53658 .82508 .53346 .82061 .52774 Mtetra
.82061 .52774 .82508 .53346 .83576 .53033 .83132 .52459 Mtetra
.83132 .52459 .83576 .53033 .84648 .52719 .84207 .52143 Mtetra
.84207 .52143 .84648 .52719 .85724 .52404 .85285 .51825 Mtetra
.85285 .51825 .85724 .52404 .86804 .52088 .86368 .51507 Mtetra
.86368 .51507 .86804 .52088 .87888 .5177 .87455 .51187 Mtetra
.87455 .51187 .87888 .5177 .88976 .51452 .88546 .50867 Mtetra
.88546 .50867 .88976 .51452 .90068 .51132 .89641 .50545 Mtetra
.89641 .50545 .90068 .51132 .91164 .50812 .9074 .50222 Mtetra
.9074 .50222 .91164 .50812 .92264 .5049 .91843 .49898 Mtetra
.91843 .49898 .92264 .5049 .93368 .50166 .9295 .49572 Mtetra
.9295 .49572 .93368 .50166 .94477 .49842 .94062 .49246 Mtetra
.94062 .49246 .94477 .49842 .95589 .49517 .95178 .48918 Mtetra
.51 .609 .887 r
.35272 .65507 .35819 .66252 .3672 .66115 .36164 .65578 Mtetra
.621 .724 .92 r
.36164 .65578 .3672 .66115 .37628 .65917 .37073 .65392 Mtetra
.625 .73 .923 r
.37073 .65392 .37628 .65917 .38538 .65742 .37985 .65195 Mtetra
.576 .706 .931 r
.37985 .65195 .38538 .65742 .39425 .6625 .38898 .65094 Mtetra
.756 .638 .73 r
.38898 .65094 .39425 .6625 .40386 .64894 .39848 .64053 Mtetra
.478 .567 .867 r
.39848 .64053 .40386 .64894 .41304 .64755 .40757 .64213 Mtetra
.625 .726 .919 r
.40757 .64213 .41304 .64755 .42228 .64536 .41683 .64013 Mtetra
.639 .738 .921 r
.41683 .64013 .42228 .64536 .43156 .64302 .42613 .63782 Mtetra
.64 .74 .921 r
.42613 .63782 .43156 .64302 .44088 .64073 .43546 .63546 Mtetra
.631 .735 .923 r
.43546 .63546 .44088 .64073 .45022 .63894 .44483 .63329 Mtetra
.546 .691 .934 r
.44483 .63329 .45022 .63894 .45765 .74042 .45419 .6328 Mtetra
.598 .402 .587 r
.45419 .6328 .45765 .74042 .46909 .63019 .46377 .62328 Mtetra
.557 .651 .898 r
.46377 .62328 .46909 .63019 .47853 .62833 .4732 .62292 Mtetra
.636 .734 .919 r
.4732 .62292 .47853 .62833 .48801 .62586 .4827 .62062 Mtetra
.648 .745 .92 r
.4827 .62062 .48801 .62586 .49753 .62321 .49224 .61801 Mtetra
.653 .749 .92 r
.49224 .61801 .49753 .62321 .50708 .62046 .50181 .61529 Mtetra
.655 .751 .92 r
.50181 .61529 .50708 .62046 .51667 .61765 .51142 .61248 Mtetra
.657 .752 .92 r
.51142 .61248 .51667 .61765 .52629 .6148 .52106 .60963 Mtetra
.658 .753 .92 r
.52106 .60963 .52629 .6148 .53595 .61191 .53074 .60673 Mtetra
.659 .754 .92 r
.53074 .60673 .53595 .61191 .54563 .60901 .54045 .60381 Mtetra
.54045 .60381 .54563 .60901 .55535 .6061 .55019 .60088 Mtetra
.55019 .60088 .55535 .6061 .56511 .60319 .55997 .59795 Mtetra
.55997 .59795 .56511 .60319 .5749 .60027 .56978 .59501 Mtetra
.658 .753 .92 r
.56978 .59501 .5749 .60027 .58472 .59734 .57963 .59206 Mtetra
.57963 .59206 .58472 .59734 .59458 .59442 .58951 .58911 Mtetra
.58951 .58911 .59458 .59442 .60447 .59148 .59942 .58616 Mtetra
.59942 .58616 .60447 .59148 .6144 .58854 .60938 .58319 Mtetra
.60938 .58319 .6144 .58854 .62436 .58559 .61936 .58022 Mtetra
.61936 .58022 .62436 .58559 .63436 .58263 .62938 .57725 Mtetra
.657 .753 .92 r
.62938 .57725 .63436 .58263 .64439 .57967 .63944 .57426 Mtetra
.63944 .57426 .64439 .57967 .65446 .57669 .64954 .57126 Mtetra
.64954 .57126 .65446 .57669 .66457 .57371 .65967 .56826 Mtetra
.65967 .56826 .66457 .57371 .67471 .57071 .66983 .56524 Mtetra
.657 .752 .92 r
.66983 .56524 .67471 .57071 .68489 .56771 .68004 .56222 Mtetra
.68004 .56222 .68489 .56771 .6951 .5647 .69028 .55919 Mtetra
.69028 .55919 .6951 .5647 .70535 .56167 .70055 .55614 Mtetra
.70055 .55614 .70535 .56167 .71564 .55864 .71087 .55309 Mtetra
.71087 .55309 .71564 .55864 .72597 .5556 .72122 .55003 Mtetra
.72122 .55003 .72597 .5556 .73633 .55255 .73161 .54695 Mtetra
.73161 .54695 .73633 .55255 .74673 .54948 .74204 .54387 Mtetra
.74204 .54387 .74673 .54948 .75717 .54641 .7525 .54077 Mtetra
.7525 .54077 .75717 .54641 .76765 .54332 .76301 .53767 Mtetra
.76301 .53767 .76765 .54332 .77816 .54023 .77355 .53455 Mtetra
.77355 .53455 .77816 .54023 .78872 .53712 .78413 .53142 Mtetra
.78413 .53142 .78872 .53712 .79931 .534 .79475 .52828 Mtetra
.79475 .52828 .79931 .534 .80994 .53088 .80541 .52514 Mtetra
.80541 .52514 .80994 .53088 .82061 .52774 .8161 .52197 Mtetra
.8161 .52197 .82061 .52774 .83132 .52459 .82684 .5188 Mtetra
.82684 .5188 .83132 .52459 .84207 .52143 .83762 .51562 Mtetra
.83762 .51562 .84207 .52143 .85285 .51825 .84844 .51243 Mtetra
.84844 .51243 .85285 .51825 .86368 .51507 .85929 .50922 Mtetra
.85929 .50922 .86368 .51507 .87455 .51187 .87019 .506 Mtetra
.87019 .506 .87455 .51187 .88546 .50867 .88113 .50277 Mtetra
.88113 .50277 .88546 .50867 .89641 .50545 .89211 .49953 Mtetra
.89211 .49953 .89641 .50545 .9074 .50222 .90313 .49628 Mtetra
.90313 .49628 .9074 .50222 .91843 .49898 .91419 .49302 Mtetra
.91419 .49302 .91843 .49898 .9295 .49572 .9253 .48974 Mtetra
.9253 .48974 .9295 .49572 .94062 .49246 .93644 .48645 Mtetra
.93644 .48645 .94062 .49246 .95178 .48918 .94763 .48315 Mtetra
0 0 0 r
.3461 .66956 .35272 .65507 .36164 .65578 .35607 .65003 Mtetra
.6 .704 .917 r
.35607 .65003 .36164 .65578 .37073 .65392 .36515 .64862 Mtetra
.626 .73 .922 r
.36515 .64862 .37073 .65392 .37985 .65195 .37429 .64661 Mtetra
.615 .726 .925 r
.37429 .64661 .37985 .65195 .38898 .65094 .38346 .64482 Mtetra
.033 .395 .852 r
.38346 .64482 .38898 .65094 .39848 .64053 .3924 .64989 Mtetra
0 0 0 r
.3924 .64989 .39848 .64053 .40757 .64213 .40208 .63623 Mtetra
.6 .701 .914 r
.40208 .63623 .40757 .64213 .41683 .64013 .41134 .63481 Mtetra
.635 .734 .92 r
.41134 .63481 .41683 .64013 .42613 .63782 .42065 .63257 Mtetra
.64 .74 .921 r
.42065 .63257 .42613 .63782 .43546 .63546 .43001 .63019 Mtetra
.637 .739 .922 r
.43001 .63019 .43546 .63546 .44483 .63329 .4394 .62786 Mtetra
.615 .726 .925 r
.4394 .62786 .44483 .63329 .45419 .6328 .44881 .62603 Mtetra
.956 .661 .437 r
.44881 .62603 .45419 .6328 .46377 .62328 .45625 .72795 Mtetra
0 0 .287 r
.45625 .72795 .46377 .62328 .4732 .62292 .46783 .61717 Mtetra
.619 .717 .916 r
.46783 .61717 .4732 .62292 .4827 .62062 .47735 .61528 Mtetra
.644 .741 .92 r
.47735 .61528 .4827 .62062 .49224 .61801 .48691 .61276 Mtetra
.651 .747 .92 r
.48691 .61276 .49224 .61801 .50181 .61529 .4965 .61006 Mtetra
.654 .75 .92 r
.4965 .61006 .50181 .61529 .51142 .61248 .50613 .60727 Mtetra
.656 .752 .92 r
.50613 .60727 .51142 .61248 .52106 .60963 .5158 .60441 Mtetra
.658 .753 .92 r
.5158 .60441 .52106 .60963 .53074 .60673 .52549 .60151 Mtetra
.659 .754 .92 r
.52549 .60151 .53074 .60673 .54045 .60381 .53523 .59858 Mtetra
.53523 .59858 .54045 .60381 .55019 .60088 .54499 .59563 Mtetra
.54499 .59563 .55019 .60088 .55997 .59795 .55479 .59267 Mtetra
.55479 .59267 .55997 .59795 .56978 .59501 .56463 .58971 Mtetra
.658 .753 .92 r
.56463 .58971 .56978 .59501 .57963 .59206 .5745 .58674 Mtetra
.5745 .58674 .57963 .59206 .58951 .58911 .5844 .58377 Mtetra
.5844 .58377 .58951 .58911 .59942 .58616 .59434 .5808 Mtetra
.59434 .5808 .59942 .58616 .60938 .58319 .60432 .57781 Mtetra
.60432 .57781 .60938 .58319 .61936 .58022 .61433 .57482 Mtetra
.61433 .57482 .61936 .58022 .62938 .57725 .62438 .57182 Mtetra
.62438 .57182 .62938 .57725 .63944 .57426 .63446 .56882 Mtetra
.657 .753 .92 r
.63446 .56882 .63944 .57426 .64954 .57126 .64458 .5658 Mtetra
.64458 .5658 .64954 .57126 .65967 .56826 .65473 .56277 Mtetra
.65473 .56277 .65967 .56826 .66983 .56524 .66493 .55974 Mtetra
.66493 .55974 .66983 .56524 .68004 .56222 .67515 .5567 Mtetra
.657 .752 .92 r
.67515 .5567 .68004 .56222 .69028 .55919 .68542 .55364 Mtetra
.68542 .55364 .69028 .55919 .70055 .55614 .69572 .55058 Mtetra
.69572 .55058 .70055 .55614 .71087 .55309 .70606 .5475 Mtetra
.70606 .5475 .71087 .55309 .72122 .55003 .71644 .54442 Mtetra
.71644 .54442 .72122 .55003 .73161 .54695 .72686 .54132 Mtetra
.72686 .54132 .73161 .54695 .74204 .54387 .73731 .53822 Mtetra
.73731 .53822 .74204 .54387 .7525 .54077 .7478 .5351 Mtetra
.7478 .5351 .7525 .54077 .76301 .53767 .75833 .53197 Mtetra
.75833 .53197 .76301 .53767 .77355 .53455 .7689 .52884 Mtetra
.7689 .52884 .77355 .53455 .78413 .53142 .77951 .52569 Mtetra
.77951 .52569 .78413 .53142 .79475 .52828 .79016 .52253 Mtetra
.79016 .52253 .79475 .52828 .80541 .52514 .80084 .51936 Mtetra
.80084 .51936 .80541 .52514 .8161 .52197 .81157 .51617 Mtetra
.81157 .51617 .8161 .52197 .82684 .5188 .82234 .51298 Mtetra
.82234 .51298 .82684 .5188 .83762 .51562 .83314 .50977 Mtetra
.83314 .50977 .83762 .51562 .84844 .51243 .84399 .50656 Mtetra
.84399 .50656 .84844 .51243 .85929 .50922 .85488 .50333 Mtetra
.85488 .50333 .85929 .50922 .87019 .506 .8658 .50009 Mtetra
.8658 .50009 .87019 .506 .88113 .50277 .87677 .49684 Mtetra
.87677 .49684 .88113 .50277 .89211 .49953 .88778 .49358 Mtetra
.88778 .49358 .89211 .49953 .90313 .49628 .89883 .4903 Mtetra
.89883 .4903 .90313 .49628 .91419 .49302 .90992 .48701 Mtetra
.90992 .48701 .91419 .49302 .9253 .48974 .92106 .48371 Mtetra
.92106 .48371 .9253 .48974 .93644 .48645 .93224 .4804 Mtetra
.93224 .4804 .93644 .48645 .94763 .48315 .94345 .47708 Mtetra
.708 .568 .695 r
.34107 .65204 .3461 .66956 .35607 .65003 .35055 .64249 Mtetra
.509 .609 .887 r
.35055 .64249 .35607 .65003 .36515 .64862 .35954 .64317 Mtetra
.621 .724 .92 r
.35954 .64317 .36515 .64862 .37429 .64661 .36869 .64128 Mtetra
.625 .73 .923 r
.36869 .64128 .37429 .64661 .38346 .64482 .37789 .63926 Mtetra
.576 .706 .931 r
.37789 .63926 .38346 .64482 .3924 .64989 .38708 .63822 Mtetra
.757 .639 .73 r
.38708 .63822 .3924 .64989 .40208 .63623 .39666 .62773 Mtetra
.478 .567 .868 r
.39666 .62773 .40208 .63623 .41134 .63481 .40582 .6293 Mtetra
.625 .726 .919 r
.40582 .6293 .41134 .63481 .42065 .63257 .41515 .62727 Mtetra
.639 .738 .921 r
.41515 .62727 .42065 .63257 .43001 .63019 .42452 .62491 Mtetra
.64 .74 .921 r
.42452 .62491 .43001 .63019 .4394 .62786 .43393 .6225 Mtetra
.631 .735 .923 r
.43393 .6225 .4394 .62786 .44881 .62603 .44337 .62029 Mtetra
.546 .691 .934 r
.44337 .62029 .44881 .62603 .45625 .72795 .45281 .61977 Mtetra
.596 .4 .585 r
.45281 .61977 .45625 .72795 .46783 .61717 .46246 .61017 Mtetra
.557 .651 .898 r
.46246 .61017 .46783 .61717 .47735 .61528 .47197 .60978 Mtetra
.636 .734 .919 r
.47197 .60978 .47735 .61528 .48691 .61276 .48154 .60743 Mtetra
.648 .745 .92 r
.48154 .60743 .48691 .61276 .4965 .61006 .49116 .60478 Mtetra
.653 .749 .92 r
.49116 .60478 .4965 .61006 .50613 .60727 .50081 .60201 Mtetra
.655 .751 .92 r
.50081 .60201 .50613 .60727 .5158 .60441 .5105 .59916 Mtetra
.657 .752 .92 r
.5105 .59916 .5158 .60441 .52549 .60151 .52022 .59625 Mtetra
.658 .753 .92 r
.52022 .59625 .52549 .60151 .53523 .59858 .52997 .59331 Mtetra
.659 .754 .92 r
.52997 .59331 .53523 .59858 .54499 .59563 .53976 .59035 Mtetra
.53976 .59035 .54499 .59563 .55479 .59267 .54959 .58737 Mtetra
.54959 .58737 .55479 .59267 .56463 .58971 .55944 .58438 Mtetra
.55944 .58438 .56463 .58971 .5745 .58674 .56934 .58139 Mtetra
.658 .753 .92 r
.56934 .58139 .5745 .58674 .5844 .58377 .57927 .5784 Mtetra
.57927 .5784 .5844 .58377 .59434 .5808 .58923 .5754 Mtetra
.58923 .5754 .59434 .5808 .60432 .57781 .59923 .5724 Mtetra
.59923 .5724 .60432 .57781 .61433 .57482 .60926 .56938 Mtetra
.60926 .56938 .61433 .57482 .62438 .57182 .61933 .56636 Mtetra
.61933 .56636 .62438 .57182 .63446 .56882 .62944 .56334 Mtetra
.657 .753 .92 r
.62944 .56334 .63446 .56882 .64458 .5658 .63959 .5603 Mtetra
.63959 .5603 .64458 .5658 .65473 .56277 .64977 .55725 Mtetra
.64977 .55725 .65473 .56277 .66493 .55974 .65998 .5542 Mtetra
.65998 .5542 .66493 .55974 .67515 .5567 .67024 .55113 Mtetra
.657 .752 .92 r
.67024 .55113 .67515 .5567 .68542 .55364 .68053 .54806 Mtetra
.68053 .54806 .68542 .55364 .69572 .55058 .69086 .54497 Mtetra
.69086 .54497 .69572 .55058 .70606 .5475 .70122 .54188 Mtetra
.70122 .54188 .70606 .5475 .71644 .54442 .71163 .53877 Mtetra
.71163 .53877 .71644 .54442 .72686 .54132 .72207 .53565 Mtetra
.72207 .53565 .72686 .54132 .73731 .53822 .73255 .53253 Mtetra
.73255 .53253 .73731 .53822 .7478 .5351 .74307 .52939 Mtetra
.74307 .52939 .7478 .5351 .75833 .53197 .75363 .52624 Mtetra
.75363 .52624 .75833 .53197 .7689 .52884 .76423 .52308 Mtetra
.76423 .52308 .7689 .52884 .77951 .52569 .77486 .51991 Mtetra
.77486 .51991 .77951 .52569 .79016 .52253 .78554 .51673 Mtetra
.78554 .51673 .79016 .52253 .80084 .51936 .79625 .51354 Mtetra
.79625 .51354 .80084 .51936 .81157 .51617 .80701 .51033 Mtetra
.80701 .51033 .81157 .51617 .82234 .51298 .8178 .50712 Mtetra
.8178 .50712 .82234 .51298 .83314 .50977 .82864 .50389 Mtetra
.82864 .50389 .83314 .50977 .84399 .50656 .83951 .50065 Mtetra
.83951 .50065 .84399 .50656 .85488 .50333 .85043 .4974 Mtetra
.85043 .4974 .85488 .50333 .8658 .50009 .86138 .49414 Mtetra
.86138 .49414 .8658 .50009 .87677 .49684 .87238 .49086 Mtetra
.87238 .49086 .87677 .49684 .88778 .49358 .88342 .48758 Mtetra
.88342 .48758 .88778 .49358 .89883 .4903 .8945 .48428 Mtetra
.8945 .48428 .89883 .4903 .90992 .48701 .90563 .48097 Mtetra
.90563 .48097 .90992 .48701 .92106 .48371 .91679 .47765 Mtetra
.91679 .47765 .92106 .48371 .93224 .4804 .928 .47431 Mtetra
.928 .47431 .93224 .4804 .94345 .47708 .93925 .47096 Mtetra
.664 .182 0 r
.33543 .64567 .34107 .65204 .35055 .64249 .34385 .65699 Mtetra
0 0 0 r
.34385 .65699 .35055 .64249 .35954 .64317 .35391 .63734 Mtetra
.6 .704 .917 r
.35391 .63734 .35954 .64317 .36869 .64128 .36306 .63589 Mtetra
.626 .73 .922 r
.36306 .63589 .36869 .64128 .37789 .63926 .37227 .63384 Mtetra
.615 .726 .925 r
.37227 .63384 .37789 .63926 .38708 .63822 .38151 .63201 Mtetra
.037 .397 .853 r
.38151 .63201 .38708 .63822 .39666 .62773 .39052 .63707 Mtetra
0 0 0 r
.39052 .63707 .39666 .62773 .40582 .6293 .40028 .62332 Mtetra
.6 .701 .914 r
.40028 .62332 .40582 .6293 .41515 .62727 .40961 .62186 Mtetra
.635 .735 .92 r
.40961 .62186 .41515 .62727 .42452 .62491 .419 .61958 Mtetra
.64 .74 .921 r
.419 .61958 .42452 .62491 .43393 .6225 .42843 .61715 Mtetra
.637 .739 .922 r
.42843 .61715 .43393 .6225 .44337 .62029 .43789 .61478 Mtetra
.615 .726 .925 r
.43789 .61478 .44337 .62029 .45281 .61977 .44738 .61291 Mtetra
.957 .661 .434 r
.44738 .61291 .45281 .61977 .46246 .61017 .45484 .71527 Mtetra
0 0 .281 r
.45484 .71527 .46246 .61017 .47197 .60978 .46656 .60394 Mtetra
.619 .717 .916 r
.46656 .60394 .47197 .60978 .48154 .60743 .47614 .602 Mtetra
.644 .741 .92 r
.47614 .602 .48154 .60743 .49116 .60478 .48578 .59944 Mtetra
.651 .747 .92 r
.48578 .59944 .49116 .60478 .50081 .60201 .49545 .5967 Mtetra
.654 .75 .92 r
.49545 .5967 .50081 .60201 .5105 .59916 .50516 .59386 Mtetra
.656 .752 .92 r
.50516 .59386 .5105 .59916 .52022 .59625 .5149 .59095 Mtetra
.658 .753 .92 r
.5149 .59095 .52022 .59625 .52997 .59331 .52468 .58801 Mtetra
.659 .754 .92 r
.52468 .58801 .52997 .59331 .53976 .59035 .5345 .58503 Mtetra
.5345 .58503 .53976 .59035 .54959 .58737 .54434 .58203 Mtetra
.54434 .58203 .54959 .58737 .55944 .58438 .55422 .57902 Mtetra
.55422 .57902 .55944 .58438 .56934 .58139 .56414 .57601 Mtetra
.658 .753 .92 r
.56414 .57601 .56934 .58139 .57927 .5784 .57409 .57299 Mtetra
.57409 .57299 .57927 .5784 .58923 .5754 .58408 .56997 Mtetra
.58408 .56997 .58923 .5754 .59923 .5724 .5941 .56694 Mtetra
.5941 .56694 .59923 .5724 .60926 .56938 .60416 .56391 Mtetra
.60416 .56391 .60926 .56938 .61933 .56636 .61426 .56087 Mtetra
.61426 .56087 .61933 .56636 .62944 .56334 .62439 .55782 Mtetra
.62439 .55782 .62944 .56334 .63959 .5603 .63456 .55476 Mtetra
.657 .753 .92 r
.63456 .55476 .63959 .5603 .64977 .55725 .64477 .5517 Mtetra
.64477 .5517 .64977 .55725 .65998 .5542 .65501 .54862 Mtetra
.65501 .54862 .65998 .5542 .67024 .55113 .66529 .54553 Mtetra
.66529 .54553 .67024 .55113 .68053 .54806 .67561 .54244 Mtetra
.657 .752 .92 r
.67561 .54244 .68053 .54806 .69086 .54497 .68596 .53933 Mtetra
.68596 .53933 .69086 .54497 .70122 .54188 .69635 .53621 Mtetra
.69635 .53621 .70122 .54188 .71163 .53877 .70678 .53309 Mtetra
.70678 .53309 .71163 .53877 .72207 .53565 .71725 .52995 Mtetra
.71725 .52995 .72207 .53565 .73255 .53253 .72776 .5268 Mtetra
.72776 .5268 .73255 .53253 .74307 .52939 .73831 .52364 Mtetra
.73831 .52364 .74307 .52939 .75363 .52624 .74889 .52047 Mtetra
.74889 .52047 .75363 .52624 .76423 .52308 .75952 .51729 Mtetra
.75952 .51729 .76423 .52308 .77486 .51991 .77018 .5141 Mtetra
.77018 .5141 .77486 .51991 .78554 .51673 .78088 .51089 Mtetra
.78088 .51089 .78554 .51673 .79625 .51354 .79163 .50768 Mtetra
.79163 .50768 .79625 .51354 .80701 .51033 .80241 .50445 Mtetra
.80241 .50445 .80701 .51033 .8178 .50712 .81323 .50121 Mtetra
.81323 .50121 .8178 .50712 .82864 .50389 .8241 .49796 Mtetra
.8241 .49796 .82864 .50389 .83951 .50065 .835 .4947 Mtetra
.835 .4947 .83951 .50065 .85043 .4974 .84595 .49143 Mtetra
.84595 .49143 .85043 .4974 .86138 .49414 .85693 .48814 Mtetra
.85693 .48814 .86138 .49414 .87238 .49086 .86796 .48485 Mtetra
.86796 .48485 .87238 .49086 .88342 .48758 .87903 .48154 Mtetra
.87903 .48154 .88342 .48758 .8945 .48428 .89014 .47821 Mtetra
.89014 .47821 .8945 .48428 .90563 .48097 .9013 .47488 Mtetra
.9013 .47488 .90563 .48097 .91679 .47765 .91249 .47154 Mtetra
.91249 .47154 .91679 .47765 .928 .47431 .92373 .46818 Mtetra
.92373 .46818 .928 .47431 .93925 .47096 .93502 .46481 Mtetra
.555 .695 .933 r
.32972 .64001 .33543 .64567 .34385 .65699 .33878 .63933 Mtetra
.708 .568 .695 r
.33878 .63933 .34385 .65699 .35391 .63734 .34834 .62971 Mtetra
.509 .609 .887 r
.34834 .62971 .35391 .63734 .36306 .63589 .3574 .63036 Mtetra
.621 .724 .92 r
.3574 .63036 .36306 .63589 .37227 .63384 .36662 .62843 Mtetra
.625 .73 .923 r
.36662 .62843 .37227 .63384 .38151 .63201 .37589 .62637 Mtetra
.576 .706 .931 r
.37589 .62637 .38151 .63201 .39052 .63707 .38515 .62529 Mtetra
.757 .639 .73 r
.38515 .62529 .39052 .63707 .40028 .62332 .39481 .61472 Mtetra
.477 .567 .868 r
.39481 .61472 .40028 .62332 .40961 .62186 .40404 .61627 Mtetra
.625 .726 .919 r
.40404 .61627 .40961 .62186 .419 .61958 .41344 .61419 Mtetra
.639 .738 .921 r
.41344 .61419 .419 .61958 .42843 .61715 .42289 .61178 Mtetra
.64 .74 .921 r
.42289 .61178 .42843 .61715 .43789 .61478 .43237 .60934 Mtetra
.631 .735 .923 r
.43237 .60934 .43789 .61478 .44738 .61291 .44189 .60708 Mtetra
.546 .691 .934 r
.44189 .60708 .44738 .61291 .45484 .71527 .4514 .60652 Mtetra
.595 .398 .584 r
.4514 .60652 .45484 .71527 .46656 .60394 .46113 .59685 Mtetra
.557 .651 .898 r
.46113 .59685 .46656 .60394 .47614 .602 .47071 .59642 Mtetra
.636 .734 .919 r
.47071 .59642 .47614 .602 .48578 .59944 .48037 .59403 Mtetra
.648 .745 .92 r
.48037 .59403 .48578 .59944 .49545 .5967 .49006 .59133 Mtetra
.653 .749 .92 r
.49006 .59133 .49545 .5967 .50516 .59386 .49979 .58851 Mtetra
.655 .751 .92 r
.49979 .58851 .50516 .59386 .5149 .59095 .50956 .58561 Mtetra
.657 .752 .92 r
.50956 .58561 .5149 .59095 .52468 .58801 .51936 .58266 Mtetra
.658 .753 .92 r
.51936 .58266 .52468 .58801 .5345 .58503 .52919 .57967 Mtetra
.659 .754 .92 r
.52919 .57967 .5345 .58503 .54434 .58203 .53906 .57665 Mtetra
.53906 .57665 .54434 .58203 .55422 .57902 .54897 .57362 Mtetra
.54897 .57362 .55422 .57902 .56414 .57601 .55891 .57059 Mtetra
.55891 .57059 .56414 .57601 .57409 .57299 .56889 .56755 Mtetra
.658 .753 .92 r
.56889 .56755 .57409 .57299 .58408 .56997 .5789 .56451 Mtetra
.5789 .56451 .58408 .56997 .5941 .56694 .58895 .56146 Mtetra
.58895 .56146 .5941 .56694 .60416 .56391 .59903 .5584 Mtetra
.59903 .5584 .60416 .56391 .61426 .56087 .60915 .55534 Mtetra
.60915 .55534 .61426 .56087 .62439 .55782 .61931 .55227 Mtetra
.61931 .55227 .62439 .55782 .63456 .55476 .6295 .54919 Mtetra
.657 .753 .92 r
.6295 .54919 .63456 .55476 .64477 .5517 .63973 .5461 Mtetra
.63973 .5461 .64477 .5517 .65501 .54862 .65 .543 Mtetra
.65 .543 .65501 .54862 .66529 .54553 .66031 .53989 Mtetra
.66031 .53989 .66529 .54553 .67561 .54244 .67065 .53678 Mtetra
.657 .752 .92 r
.67065 .53678 .67561 .54244 .68596 .53933 .68103 .53365 Mtetra
.68103 .53365 .68596 .53933 .69635 .53621 .69145 .53051 Mtetra
.69145 .53051 .69635 .53621 .70678 .53309 .70191 .52736 Mtetra
.70191 .52736 .70678 .53309 .71725 .52995 .7124 .5242 Mtetra
.7124 .5242 .71725 .52995 .72776 .5268 .72294 .52103 Mtetra
.72294 .52103 .72776 .5268 .73831 .52364 .73351 .51785 Mtetra
.73351 .51785 .73831 .52364 .74889 .52047 .74412 .51466 Mtetra
.74412 .51466 .74889 .52047 .75952 .51729 .75477 .51146 Mtetra
.75477 .51146 .75952 .51729 .77018 .5141 .76547 .50824 Mtetra
.76547 .50824 .77018 .5141 .78088 .51089 .7762 .50501 Mtetra
.7762 .50501 .78088 .51089 .79163 .50768 .78697 .50178 Mtetra
.78697 .50178 .79163 .50768 .80241 .50445 .79778 .49853 Mtetra
.79778 .49853 .80241 .50445 .81323 .50121 .80863 .49527 Mtetra
.80863 .49527 .81323 .50121 .8241 .49796 .81953 .492 Mtetra
.81953 .492 .8241 .49796 .835 .4947 .83046 .48871 Mtetra
.83046 .48871 .835 .4947 .84595 .49143 .84144 .48541 Mtetra
.84144 .48541 .84595 .49143 .85693 .48814 .85245 .48211 Mtetra
.85245 .48211 .85693 .48814 .86796 .48485 .86351 .47879 Mtetra
.86351 .47879 .86796 .48485 .87903 .48154 .87461 .47545 Mtetra
.87461 .47545 .87903 .48154 .89014 .47821 .88575 .47211 Mtetra
.88575 .47211 .89014 .47821 .9013 .47488 .89694 .46875 Mtetra
.89694 .46875 .9013 .47488 .91249 .47154 .90817 .46538 Mtetra
.90817 .46538 .91249 .47154 .92373 .46818 .91944 .462 Mtetra
.91944 .462 .92373 .46818 .93502 .46481 .93075 .4586 Mtetra
.605 .719 .926 r
.32397 .6345 .32972 .64001 .33878 .63933 .33309 .63287 Mtetra
.657 .176 0 r
.33309 .63287 .33878 .63933 .34834 .62971 .34157 .64421 Mtetra
0 0 0 r
.34157 .64421 .34834 .62971 .3574 .63036 .35172 .62444 Mtetra
.6 .704 .917 r
.35172 .62444 .3574 .63036 .36662 .62843 .36094 .62296 Mtetra
.626 .73 .922 r
.36094 .62296 .36662 .62843 .37589 .62637 .37022 .62086 Mtetra
.615 .726 .925 r
.37022 .62086 .37589 .62637 .38515 .62529 .37953 .61899 Mtetra
.042 .399 .855 r
.37953 .61899 .38515 .62529 .39481 .61472 .38861 .62404 Mtetra
0 0 0 r
.38861 .62404 .39481 .61472 .40404 .61627 .39845 .61019 Mtetra
.6 .701 .915 r
.39845 .61019 .40404 .61627 .41344 .61419 .40785 .6087 Mtetra
.635 .735 .92 r
.40785 .6087 .41344 .61419 .42289 .61178 .41732 .60637 Mtetra
.64 .74 .921 r
.41732 .60637 .42289 .61178 .43237 .60934 .42682 .6039 Mtetra
.637 .739 .922 r
.42682 .6039 .43237 .60934 .44189 .60708 .43636 .60148 Mtetra
.615 .726 .925 r
.43636 .60148 .44189 .60708 .4514 .60652 .44592 .59957 Mtetra
.957 .661 .43 r
.44592 .59957 .4514 .60652 .46113 .59685 .4534 .70237 Mtetra
0 0 .276 r
.4534 .70237 .46113 .59685 .47071 .59642 .46526 .59049 Mtetra
.619 .717 .916 r
.46526 .59049 .47071 .59642 .48037 .59403 .47492 .58851 Mtetra
.644 .741 .92 r
.47492 .58851 .48037 .59403 .49006 .59133 .48464 .5859 Mtetra
.651 .747 .92 r
.48464 .5859 .49006 .59133 .49979 .58851 .49439 .58311 Mtetra
.654 .75 .92 r
.49439 .58311 .49979 .58851 .50956 .58561 .50418 .58022 Mtetra
.656 .752 .92 r
.50418 .58022 .50956 .58561 .51936 .58266 .514 .57727 Mtetra
.658 .753 .92 r
.514 .57727 .51936 .58266 .52919 .57967 .52386 .57427 Mtetra
.659 .754 .92 r
.52386 .57427 .52919 .57967 .53906 .57665 .53375 .57124 Mtetra
.53375 .57124 .53906 .57665 .54897 .57362 .54368 .56819 Mtetra
.54368 .56819 .54897 .57362 .55891 .57059 .55365 .56514 Mtetra
.55365 .56514 .55891 .57059 .56889 .56755 .56365 .56207 Mtetra
.658 .753 .92 r
.56365 .56207 .56889 .56755 .5789 .56451 .57368 .55901 Mtetra
.57368 .55901 .5789 .56451 .58895 .56146 .58375 .55593 Mtetra
.58375 .55593 .58895 .56146 .59903 .5584 .59386 .55286 Mtetra
.59386 .55286 .59903 .5584 .60915 .55534 .60401 .54977 Mtetra
.60401 .54977 .60915 .55534 .61931 .55227 .61419 .54668 Mtetra
.61419 .54668 .61931 .55227 .6295 .54919 .62441 .54358 Mtetra
.62441 .54358 .6295 .54919 .63973 .5461 .63466 .54047 Mtetra
.657 .753 .92 r
.63466 .54047 .63973 .5461 .65 .543 .64496 .53735 Mtetra
.64496 .53735 .65 .543 .66031 .53989 .65529 .53422 Mtetra
.65529 .53422 .66031 .53989 .67065 .53678 .66566 .53108 Mtetra
.66566 .53108 .67065 .53678 .68103 .53365 .67606 .52793 Mtetra
.657 .752 .92 r
.67606 .52793 .68103 .53365 .69145 .53051 .68651 .52477 Mtetra
.68651 .52477 .69145 .53051 .70191 .52736 .69699 .5216 Mtetra
.69699 .5216 .70191 .52736 .7124 .5242 .70752 .51842 Mtetra
.70752 .51842 .7124 .5242 .72294 .52103 .71808 .51523 Mtetra
.71808 .51523 .72294 .52103 .73351 .51785 .72868 .51202 Mtetra
.72868 .51202 .73351 .51785 .74412 .51466 .73932 .50881 Mtetra
.73932 .50881 .74412 .51466 .75477 .51146 .75 .50558 Mtetra
.75 .50558 .75477 .51146 .76547 .50824 .76072 .50235 Mtetra
.76072 .50235 .76547 .50824 .7762 .50501 .77148 .4991 Mtetra
.77148 .4991 .7762 .50501 .78697 .50178 .78228 .49584 Mtetra
.78228 .49584 .78697 .50178 .79778 .49853 .79312 .49256 Mtetra
.79312 .49256 .79778 .49853 .80863 .49527 .804 .48928 Mtetra
.804 .48928 .80863 .49527 .81953 .492 .81492 .48599 Mtetra
.81492 .48599 .81953 .492 .83046 .48871 .82589 .48268 Mtetra
.82589 .48268 .83046 .48871 .84144 .48541 .83689 .47936 Mtetra
.83689 .47936 .84144 .48541 .85245 .48211 .84794 .47603 Mtetra
.84794 .47603 .85245 .48211 .86351 .47879 .85903 .47268 Mtetra
.85903 .47268 .86351 .47879 .87461 .47545 .87016 .46933 Mtetra
.87016 .46933 .87461 .47545 .88575 .47211 .88133 .46596 Mtetra
.88133 .46596 .88575 .47211 .89694 .46875 .89255 .46258 Mtetra
.89255 .46258 .89694 .46875 .90817 .46538 .90381 .45918 Mtetra
.90381 .45918 .90817 .46538 .91944 .462 .91511 .45578 Mtetra
.91511 .45578 .91944 .462 .93075 .4586 .92646 .45236 Mtetra
.615 .723 .923 r
.31818 .62896 .32397 .6345 .33309 .63287 .32733 .62713 Mtetra
.555 .695 .933 r
.32733 .62713 .33309 .63287 .34157 .64421 .33646 .62642 Mtetra
.708 .568 .695 r
.33646 .62642 .34157 .64421 .35172 .62444 .3461 .61672 Mtetra
.509 .609 .888 r
.3461 .61672 .35172 .62444 .36094 .62296 .35522 .61734 Mtetra
.621 .724 .92 r
.35522 .61734 .36094 .62296 .37022 .62086 .36452 .61536 Mtetra
.625 .73 .923 r
.36452 .61536 .37022 .62086 .37953 .61899 .37386 .61326 Mtetra
.576 .706 .931 r
.37386 .61326 .37953 .61899 .38861 .62404 .38319 .61214 Mtetra
.757 .639 .731 r
.38319 .61214 .38861 .62404 .39845 .61019 .39293 .6015 Mtetra
.476 .567 .868 r
.39293 .6015 .39845 .61019 .40785 .6087 .40223 .60302 Mtetra
.625 .726 .919 r
.40223 .60302 .40785 .6087 .41732 .60637 .41171 .60089 Mtetra
.639 .738 .921 r
.41171 .60089 .41732 .60637 .42682 .6039 .42123 .59844 Mtetra
.64 .74 .921 r
.42123 .59844 .42682 .6039 .43636 .60148 .43079 .59595 Mtetra
.631 .735 .923 r
.43079 .59595 .43636 .60148 .44592 .59957 .44038 .59365 Mtetra
.546 .691 .934 r
.44038 .59365 .44592 .59957 .4534 .70237 .44997 .59305 Mtetra
.594 .395 .582 r
.44997 .59305 .4534 .70237 .46526 .59049 .45979 .5833 Mtetra
.557 .651 .898 r
.45979 .5833 .46526 .59049 .47492 .58851 .46944 .58283 Mtetra
.636 .734 .919 r
.46944 .58283 .47492 .58851 .48464 .5859 .47917 .5804 Mtetra
.648 .745 .92 r
.47917 .5804 .48464 .5859 .49439 .58311 .48895 .57765 Mtetra
.653 .749 .92 r
.48895 .57765 .49439 .58311 .50418 .58022 .49876 .57478 Mtetra
.655 .751 .92 r
.49876 .57478 .50418 .58022 .514 .57727 .5086 .57183 Mtetra
.657 .752 .92 r
.5086 .57183 .514 .57727 .52386 .57427 .51849 .56883 Mtetra
.658 .753 .92 r
.51849 .56883 .52386 .57427 .53375 .57124 .5284 .56579 Mtetra
.659 .754 .92 r
.5284 .56579 .53375 .57124 .54368 .56819 .53836 .56273 Mtetra
.53836 .56273 .54368 .56819 .55365 .56514 .54834 .55965 Mtetra
.54834 .55965 .55365 .56514 .56365 .56207 .55837 .55656 Mtetra
.55837 .55656 .56365 .56207 .57368 .55901 .56843 .55347 Mtetra
.658 .753 .92 r
.56843 .55347 .57368 .55901 .58375 .55593 .57853 .55038 Mtetra
.57853 .55038 .58375 .55593 .59386 .55286 .58866 .54728 Mtetra
.58866 .54728 .59386 .55286 .60401 .54977 .59883 .54417 Mtetra
.59883 .54417 .60401 .54977 .61419 .54668 .60904 .54105 Mtetra
.60904 .54105 .61419 .54668 .62441 .54358 .61928 .53793 Mtetra
.61928 .53793 .62441 .54358 .63466 .54047 .62956 .5348 Mtetra
.657 .753 .92 r
.62956 .5348 .63466 .54047 .64496 .53735 .63988 .53166 Mtetra
.63988 .53166 .64496 .53735 .65529 .53422 .65024 .52851 Mtetra
.65024 .52851 .65529 .53422 .66566 .53108 .66063 .52534 Mtetra
.66063 .52534 .66566 .53108 .67606 .52793 .67107 .52217 Mtetra
.657 .752 .92 r
.67107 .52217 .67606 .52793 .68651 .52477 .68154 .51899 Mtetra
.68154 .51899 .68651 .52477 .69699 .5216 .69205 .5158 Mtetra
.69205 .5158 .69699 .5216 .70752 .51842 .7026 .51259 Mtetra
.7026 .51259 .70752 .51842 .71808 .51523 .71319 .50938 Mtetra
.71319 .50938 .71808 .51523 .72868 .51202 .72382 .50615 Mtetra
.72382 .50615 .72868 .51202 .73932 .50881 .73448 .50292 Mtetra
.73448 .50292 .73932 .50881 .75 .50558 .74519 .49967 Mtetra
.74519 .49967 .75 .50558 .76072 .50235 .75594 .49641 Mtetra
.75594 .49641 .76072 .50235 .77148 .4991 .76673 .49314 Mtetra
.76673 .49314 .77148 .4991 .78228 .49584 .77756 .48985 Mtetra
.77756 .48985 .78228 .49584 .79312 .49256 .78843 .48656 Mtetra
.78843 .48656 .79312 .49256 .804 .48928 .79934 .48325 Mtetra
.79934 .48325 .804 .48928 .81492 .48599 .81029 .47993 Mtetra
.81029 .47993 .81492 .48599 .82589 .48268 .82128 .4766 Mtetra
.82128 .4766 .82589 .48268 .83689 .47936 .83232 .47326 Mtetra
.83232 .47326 .83689 .47936 .84794 .47603 .8434 .46991 Mtetra
.8434 .46991 .84794 .47603 .85903 .47268 .85451 .46654 Mtetra
.85451 .46654 .85903 .47268 .87016 .46933 .86568 .46316 Mtetra
.86568 .46316 .87016 .46933 .88133 .46596 .87688 .45977 Mtetra
.87688 .45977 .88133 .46596 .89255 .46258 .88813 .45636 Mtetra
.88813 .45636 .89255 .46258 .90381 .45918 .89942 .45294 Mtetra
.89942 .45294 .90381 .45918 .91511 .45578 .91075 .44951 Mtetra
.91075 .44951 .91511 .45578 .92646 .45236 .92213 .44607 Mtetra
.61 .717 .921 r
.31236 .62327 .31818 .62896 .32733 .62713 .32152 .62153 Mtetra
.605 .719 .926 r
.32152 .62153 .32733 .62713 .33646 .62642 .33072 .61987 Mtetra
.65 .17 0 r
.33072 .61987 .33646 .62642 .3461 .61672 .33925 .63122 Mtetra
0 0 0 r
.33925 .63122 .3461 .61672 .35522 .61734 .34949 .61134 Mtetra
.6 .704 .917 r
.34949 .61134 .35522 .61734 .36452 .61536 .35878 .60981 Mtetra
.626 .73 .922 r
.35878 .60981 .36452 .61536 .37386 .61326 .36814 .60767 Mtetra
.615 .725 .925 r
.36814 .60767 .37386 .61326 .38319 .61214 .37752 .60575 Mtetra
.046 .402 .856 r
.37752 .60575 .38319 .61214 .39293 .6015 .38666 .61079 Mtetra
0 0 0 r
.38666 .61079 .39293 .6015 .40223 .60302 .39659 .59685 Mtetra
.6 .701 .915 r
.39659 .59685 .40223 .60302 .41171 .60089 .40607 .59531 Mtetra
.635 .735 .92 r
.40607 .59531 .41171 .60089 .42123 .59844 .41561 .59294 Mtetra
.64 .74 .921 r
.41561 .59294 .42123 .59844 .43079 .59595 .42519 .59043 Mtetra
.638 .739 .922 r
.42519 .59043 .43079 .59595 .44038 .59365 .4348 .58796 Mtetra
.615 .726 .925 r
.4348 .58796 .44038 .59365 .44997 .59305 .44444 .586 Mtetra
.958 .66 .427 r
.44444 .586 .44997 .59305 .45979 .5833 .45193 .68925 Mtetra
0 0 .27 r
.45193 .68925 .45979 .5833 .46944 .58283 .46393 .57682 Mtetra
.619 .717 .916 r
.46393 .57682 .46944 .58283 .47917 .5804 .47368 .57479 Mtetra
.644 .741 .92 r
.47368 .57479 .47917 .5804 .48895 .57765 .48347 .57213 Mtetra
.651 .747 .92 r
.48347 .57213 .48895 .57765 .49876 .57478 .4933 .56929 Mtetra
.654 .75 .92 r
.4933 .56929 .49876 .57478 .5086 .57183 .50317 .56635 Mtetra
.656 .752 .92 r
.50317 .56635 .5086 .57183 .51849 .56883 .51308 .56335 Mtetra
.658 .753 .92 r
.51308 .56335 .51849 .56883 .5284 .56579 .52302 .5603 Mtetra
.659 .754 .92 r
.52302 .5603 .5284 .56579 .53836 .56273 .533 .55722 Mtetra
.533 .55722 .53836 .56273 .54834 .55965 .54301 .55412 Mtetra
.54301 .55412 .54834 .55965 .55837 .55656 .55306 .55101 Mtetra
.55306 .55101 .55837 .55656 .56843 .55347 .56314 .5479 Mtetra
.658 .753 .92 r
.56314 .5479 .56843 .55347 .57853 .55038 .57326 .54478 Mtetra
.57326 .54478 .57853 .55038 .58866 .54728 .58342 .54166 Mtetra
.58342 .54166 .58866 .54728 .59883 .54417 .59361 .53853 Mtetra
.59361 .53853 .59883 .54417 .60904 .54105 .60385 .53539 Mtetra
.60385 .53539 .60904 .54105 .61928 .53793 .61412 .53224 Mtetra
.61412 .53224 .61928 .53793 .62956 .5348 .62442 .52909 Mtetra
.62442 .52909 .62956 .5348 .63988 .53166 .63477 .52593 Mtetra
.657 .753 .92 r
.63477 .52593 .63988 .53166 .65024 .52851 .64515 .52275 Mtetra
.64515 .52275 .65024 .52851 .66063 .52534 .65557 .51957 Mtetra
.65557 .51957 .66063 .52534 .67107 .52217 .66603 .51638 Mtetra
.66603 .51638 .67107 .52217 .68154 .51899 .67653 .51317 Mtetra
.657 .752 .92 r
.67653 .51317 .68154 .51899 .69205 .5158 .68707 .50996 Mtetra
.68707 .50996 .69205 .5158 .7026 .51259 .69765 .50673 Mtetra
.69765 .50673 .7026 .51259 .71319 .50938 .70826 .50349 Mtetra
.70826 .50349 .71319 .50938 .72382 .50615 .71892 .50024 Mtetra
.71892 .50024 .72382 .50615 .73448 .50292 .72962 .49698 Mtetra
.72962 .49698 .73448 .50292 .74519 .49967 .74035 .49371 Mtetra
.74035 .49371 .74519 .49967 .75594 .49641 .75113 .49043 Mtetra
.75113 .49043 .75594 .49641 .76673 .49314 .76194 .48714 Mtetra
.76194 .48714 .76673 .49314 .77756 .48985 .7728 .48383 Mtetra
.7728 .48383 .77756 .48985 .78843 .48656 .7837 .48051 Mtetra
.7837 .48051 .78843 .48656 .79934 .48325 .79464 .47718 Mtetra
.79464 .47718 .79934 .48325 .81029 .47993 .80562 .47384 Mtetra
.80562 .47384 .81029 .47993 .82128 .4766 .81665 .47049 Mtetra
.81665 .47049 .82128 .4766 .83232 .47326 .82771 .46712 Mtetra
.82771 .46712 .83232 .47326 .8434 .46991 .83882 .46374 Mtetra
.83882 .46374 .8434 .46991 .85451 .46654 .84997 .46035 Mtetra
.84997 .46035 .85451 .46654 .86568 .46316 .86116 .45695 Mtetra
.86116 .45695 .86568 .46316 .87688 .45977 .8724 .45353 Mtetra
.8724 .45353 .87688 .45977 .88813 .45636 .88368 .4501 Mtetra
.88368 .4501 .88813 .45636 .89942 .45294 .895 .44666 Mtetra
.895 .44666 .89942 .45294 .91075 .44951 .90636 .4432 Mtetra
.90636 .4432 .91075 .44951 .92213 .44607 .91777 .43973 Mtetra
.582 .689 .915 r
.30654 .61704 .31236 .62327 .32152 .62153 .31568 .61591 Mtetra
.615 .723 .923 r
.31568 .61591 .32152 .62153 .33072 .61987 .3249 .61404 Mtetra
.555 .695 .933 r
.3249 .61404 .33072 .61987 .33925 .63122 .3341 .61329 Mtetra
.708 .568 .695 r
.3341 .61329 .33925 .63122 .34949 .61134 .34382 .60351 Mtetra
.508 .609 .888 r
.34382 .60351 .34949 .61134 .35878 .60981 .35301 .6041 Mtetra
.621 .724 .92 r
.35301 .6041 .35878 .60981 .36814 .60767 .36238 .60208 Mtetra
.625 .73 .923 r
.36238 .60208 .36814 .60767 .37752 .60575 .37179 .59994 Mtetra
.576 .706 .931 r
.37179 .59994 .37752 .60575 .38666 .61079 .3812 .59878 Mtetra
.758 .64 .731 r
.3812 .59878 .38666 .61079 .39659 .59685 .39102 .58805 Mtetra
.476 .567 .868 r
.39102 .58805 .39659 .59685 .40607 .59531 .40039 .58954 Mtetra
.625 .726 .919 r
.40039 .58954 .40607 .59531 .41561 .59294 .40995 .58738 Mtetra
.639 .738 .921 r
.40995 .58738 .41561 .59294 .42519 .59043 .41954 .58488 Mtetra
.64 .74 .921 r
.41954 .58488 .42519 .59043 .4348 .58796 .42918 .58234 Mtetra
.631 .735 .923 r
.42918 .58234 .4348 .58796 .44444 .586 .43885 .57999 Mtetra
.547 .691 .934 r
.43885 .57999 .44444 .586 .45193 .68925 .44852 .57936 Mtetra
.592 .393 .581 r
.44852 .57936 .45193 .68925 .46393 .57682 .45841 .56953 Mtetra
.557 .651 .898 r
.45841 .56953 .46393 .57682 .47368 .57479 .46815 .56902 Mtetra
.636 .734 .919 r
.46815 .56902 .47368 .57479 .48347 .57213 .47796 .56653 Mtetra
.648 .745 .92 r
.47796 .56653 .48347 .57213 .4933 .56929 .48781 .56374 Mtetra
.653 .749 .92 r
.48781 .56374 .4933 .56929 .50317 .56635 .49771 .56082 Mtetra
.655 .751 .92 r
.49771 .56082 .50317 .56635 .51308 .56335 .50763 .55782 Mtetra
.657 .752 .92 r
.50763 .55782 .51308 .56335 .52302 .5603 .5176 .55477 Mtetra
.658 .753 .92 r
.5176 .55477 .52302 .5603 .533 .55722 .5276 .55168 Mtetra
.659 .754 .92 r
.5276 .55168 .533 .55722 .54301 .55412 .53764 .54856 Mtetra
.53764 .54856 .54301 .55412 .55306 .55101 .54771 .54543 Mtetra
.54771 .54543 .55306 .55101 .56314 .5479 .55782 .54229 Mtetra
.55782 .54229 .56314 .5479 .57326 .54478 .56796 .53915 Mtetra
.658 .753 .92 r
.56796 .53915 .57326 .54478 .58342 .54166 .57815 .536 Mtetra
.57815 .536 .58342 .54166 .59361 .53853 .58837 .53285 Mtetra
.58837 .53285 .59361 .53853 .60385 .53539 .59862 .52969 Mtetra
.59862 .52969 .60385 .53539 .61412 .53224 .60892 .52652 Mtetra
.60892 .52652 .61412 .53224 .62442 .52909 .61925 .52334 Mtetra
.61925 .52334 .62442 .52909 .63477 .52593 .62962 .52016 Mtetra
.657 .753 .92 r
.62962 .52016 .63477 .52593 .64515 .52275 .64003 .51696 Mtetra
.64003 .51696 .64515 .52275 .65557 .51957 .65048 .51375 Mtetra
.65048 .51375 .65557 .51957 .66603 .51638 .66097 .51054 Mtetra
.66097 .51054 .66603 .51638 .67653 .51317 .67149 .50731 Mtetra
.657 .752 .92 r
.67149 .50731 .67653 .51317 .68707 .50996 .68206 .50407 Mtetra
.68206 .50407 .68707 .50996 .69765 .50673 .69266 .50082 Mtetra
.69266 .50082 .69765 .50673 .70826 .50349 .7033 .49757 Mtetra
.7033 .49757 .70826 .50349 .71892 .50024 .71399 .49429 Mtetra
.71399 .49429 .71892 .50024 .72962 .49698 .72471 .49101 Mtetra
.72471 .49101 .72962 .49698 .74035 .49371 .73548 .48772 Mtetra
.73548 .48772 .74035 .49371 .75113 .49043 .74628 .48441 Mtetra
.74628 .48441 .75113 .49043 .76194 .48714 .75713 .48109 Mtetra
.75713 .48109 .76194 .48714 .7728 .48383 .76801 .47777 Mtetra
.76801 .47777 .7728 .48383 .7837 .48051 .77894 .47442 Mtetra
.77894 .47442 .7837 .48051 .79464 .47718 .78991 .47107 Mtetra
.78991 .47107 .79464 .47718 .80562 .47384 .80092 .4677 Mtetra
.80092 .4677 .80562 .47384 .81665 .47049 .81198 .46433 Mtetra
.81198 .46433 .81665 .47049 .82771 .46712 .82307 .46094 Mtetra
.82307 .46094 .82771 .46712 .83882 .46374 .83421 .45753 Mtetra
.83421 .45753 .83882 .46374 .84997 .46035 .84539 .45412 Mtetra
.84539 .45412 .84997 .46035 .86116 .45695 .85661 .45069 Mtetra
.85661 .45069 .86116 .45695 .8724 .45353 .86788 .44725 Mtetra
.86788 .44725 .8724 .45353 .88368 .4501 .87919 .44379 Mtetra
.87919 .44379 .88368 .4501 .895 .44666 .89055 .44033 Mtetra
.89055 .44033 .895 .44666 .90636 .4432 .90194 .43685 Mtetra
.90194 .43685 .90636 .4432 .91777 .43973 .91339 .43335 Mtetra
.405 .499 .842 r
.30092 .60709 .30654 .61704 .31568 .61591 .3098 .61013 Mtetra
.61 .717 .921 r
.3098 .61013 .31568 .61591 .3249 .61404 .31904 .60835 Mtetra
.605 .719 .925 r
.31904 .60835 .3249 .61404 .3341 .61329 .3283 .60665 Mtetra
.644 .163 0 r
.3283 .60665 .3341 .61329 .34382 .60351 .33689 .61802 Mtetra
0 0 0 r
.33689 .61802 .34382 .60351 .35301 .6041 .34722 .59801 Mtetra
.6 .704 .917 r
.34722 .59801 .35301 .6041 .36238 .60208 .35659 .59644 Mtetra
.626 .73 .922 r
.35659 .59644 .36238 .60208 .37179 .59994 .36602 .59425 Mtetra
.615 .725 .925 r
.36602 .59425 .37179 .59994 .3812 .59878 .37548 .5923 Mtetra
.051 .404 .858 r
.37548 .5923 .3812 .59878 .39102 .58805 .38469 .59732 Mtetra
0 0 0 r
.38469 .59732 .39102 .58805 .40039 .58954 .3947 .58329 Mtetra
.6 .701 .915 r
.3947 .58329 .40039 .58954 .40995 .58738 .40425 .5817 Mtetra
.635 .735 .92 r
.40425 .5817 .40995 .58738 .41954 .58488 .41387 .57929 Mtetra
.64 .74 .921 r
.41387 .57929 .41954 .58488 .42918 .58234 .42352 .57672 Mtetra
.638 .739 .922 r
.42352 .57672 .42918 .58234 .43885 .57999 .43322 .57421 Mtetra
.615 .726 .925 r
.43322 .57421 .43885 .57999 .44852 .57936 .44293 .57221 Mtetra
.959 .66 .423 r
.44293 .57221 .44852 .57936 .45841 .56953 .45044 .6759 Mtetra
0 0 .264 r
.45044 .6759 .45841 .56953 .46815 .56902 .46259 .56291 Mtetra
.619 .717 .916 r
.46259 .56291 .46815 .56902 .47796 .56653 .47241 .56083 Mtetra
.644 .741 .92 r
.47241 .56083 .47796 .56653 .48781 .56374 .48229 .55813 Mtetra
.651 .747 .92 r
.48229 .55813 .48781 .56374 .49771 .56082 .4922 .55524 Mtetra
.654 .75 .92 r
.4922 .55524 .49771 .56082 .50763 .55782 .50215 .55225 Mtetra
.656 .752 .92 r
.50215 .55225 .50763 .55782 .5176 .55477 .51214 .5492 Mtetra
.658 .753 .92 r
.51214 .5492 .5176 .55477 .5276 .55168 .52217 .54609 Mtetra
.659 .754 .92 r
.52217 .54609 .5276 .55168 .53764 .54856 .53223 .54296 Mtetra
.53223 .54296 .53764 .54856 .54771 .54543 .54232 .53981 Mtetra
.54232 .53981 .54771 .54543 .55782 .54229 .55246 .53665 Mtetra
.55246 .53665 .55782 .54229 .56796 .53915 .56263 .53348 Mtetra
.658 .753 .92 r
.56263 .53348 .56796 .53915 .57815 .536 .57284 .53031 Mtetra
.57284 .53031 .57815 .536 .58837 .53285 .58308 .52713 Mtetra
.58308 .52713 .58837 .53285 .59862 .52969 .59336 .52395 Mtetra
.59336 .52395 .59862 .52969 .60892 .52652 .60368 .52076 Mtetra
.60368 .52076 .60892 .52652 .61925 .52334 .61404 .51756 Mtetra
.61404 .51756 .61925 .52334 .62962 .52016 .62444 .51435 Mtetra
.62444 .51435 .62962 .52016 .64003 .51696 .63488 .51113 Mtetra
.657 .753 .92 r
.63488 .51113 .64003 .51696 .65048 .51375 .64535 .5079 Mtetra
.64535 .5079 .65048 .51375 .66097 .51054 .65586 .50466 Mtetra
.65586 .50466 .66097 .51054 .67149 .50731 .66642 .50141 Mtetra
.66642 .50141 .67149 .50731 .68206 .50407 .67701 .49815 Mtetra
.657 .752 .92 r
.67701 .49815 .68206 .50407 .69266 .50082 .68764 .49488 Mtetra
.68764 .49488 .69266 .50082 .7033 .49757 .69831 .4916 Mtetra
.69831 .4916 .7033 .49757 .71399 .49429 .70902 .4883 Mtetra
.70902 .4883 .71399 .49429 .72471 .49101 .71977 .485 Mtetra
.71977 .485 .72471 .49101 .73548 .48772 .73057 .48168 Mtetra
.73057 .48168 .73548 .48772 .74628 .48441 .7414 .47835 Mtetra
.7414 .47835 .74628 .48441 .75713 .48109 .75228 .47501 Mtetra
.75228 .47501 .75713 .48109 .76801 .47777 .76319 .47166 Mtetra
.76319 .47166 .76801 .47777 .77894 .47442 .77415 .46829 Mtetra
.77415 .46829 .77894 .47442 .78991 .47107 .78515 .46491 Mtetra
.78515 .46491 .78991 .47107 .80092 .4677 .79619 .46152 Mtetra
.79619 .46152 .80092 .4677 .81198 .46433 .80727 .45812 Mtetra
.80727 .45812 .81198 .46433 .82307 .46094 .8184 .45471 Mtetra
.8184 .45471 .82307 .46094 .83421 .45753 .82957 .45128 Mtetra
.82957 .45128 .83421 .45753 .84539 .45412 .84078 .44784 Mtetra
.84078 .44784 .84539 .45412 .85661 .45069 .85203 .44439 Mtetra
.85203 .44439 .85661 .45069 .86788 .44725 .86333 .44092 Mtetra
.86333 .44092 .86788 .44725 .87919 .44379 .87468 .43744 Mtetra
.87468 .43744 .87919 .44379 .89055 .44033 .88606 .43395 Mtetra
.88606 .43395 .89055 .44033 .90194 .43685 .89749 .43045 Mtetra
.89749 .43045 .90194 .43685 .91339 .43335 .90897 .42693 Mtetra
0 0 0 r
.29406 .61542 .30092 .60709 .3098 .61013 .30393 .60381 Mtetra
.582 .689 .915 r
.30393 .60381 .3098 .61013 .31904 .60835 .31313 .60265 Mtetra
.615 .723 .923 r
.31313 .60265 .31904 .60835 .3283 .60665 .32243 .60073 Mtetra
.555 .695 .933 r
.32243 .60073 .3283 .60665 .33689 .61802 .3317 .59994 Mtetra
.708 .568 .695 r
.3317 .59994 .33689 .61802 .34722 .59801 .3415 .59009 Mtetra
.508 .609 .888 r
.3415 .59009 .34722 .59801 .35659 .59644 .35076 .59065 Mtetra
.62 .724 .92 r
.35076 .59065 .35659 .59644 .36602 .59425 .36021 .58858 Mtetra
.625 .73 .923 r
.36021 .58858 .36602 .59425 .37548 .5923 .36969 .58639 Mtetra
.576 .706 .93 r
.36969 .58639 .37548 .5923 .38469 .59732 .37917 .58519 Mtetra
.758 .64 .731 r
.37917 .58519 .38469 .59732 .3947 .58329 .38908 .57438 Mtetra
.475 .567 .868 r
.38908 .57438 .3947 .58329 .40425 .5817 .39852 .57584 Mtetra
.625 .726 .919 r
.39852 .57584 .40425 .5817 .41387 .57929 .40815 .57363 Mtetra
.639 .738 .921 r
.40815 .57363 .41387 .57929 .42352 .57672 .41783 .57108 Mtetra
.64 .74 .921 r
.41783 .57108 .42352 .57672 .43322 .57421 .42754 .5685 Mtetra
.631 .735 .923 r
.42754 .5685 .43322 .57421 .44293 .57221 .43729 .5661 Mtetra
.547 .691 .934 r
.43729 .5661 .44293 .57221 .45044 .6759 .44704 .56543 Mtetra
.591 .391 .579 r
.44704 .56543 .45044 .6759 .46259 .56291 .45702 .55552 Mtetra
.556 .652 .898 r
.45702 .55552 .46259 .56291 .47241 .56083 .46683 .55497 Mtetra
.636 .734 .919 r
.46683 .55497 .47241 .56083 .48229 .55813 .47673 .55244 Mtetra
.648 .745 .92 r
.47673 .55244 .48229 .55813 .4922 .55524 .48666 .54959 Mtetra
.653 .749 .92 r
.48666 .54959 .4922 .55524 .50215 .55225 .49664 .54662 Mtetra
.655 .751 .92 r
.49664 .54662 .50215 .55225 .51214 .5492 .50665 .54357 Mtetra
.657 .752 .92 r
.50665 .54357 .51214 .5492 .52217 .54609 .5167 .54047 Mtetra
.658 .753 .92 r
.5167 .54047 .52217 .54609 .53223 .54296 .52678 .53732 Mtetra
.659 .754 .92 r
.52678 .53732 .53223 .54296 .54232 .53981 .5369 .53415 Mtetra
.5369 .53415 .54232 .53981 .55246 .53665 .54706 .53097 Mtetra
.54706 .53097 .55246 .53665 .56263 .53348 .55726 .52778 Mtetra
.55726 .52778 .56263 .53348 .57284 .53031 .56749 .52458 Mtetra
.658 .753 .92 r
.56749 .52458 .57284 .53031 .58308 .52713 .57776 .52138 Mtetra
.57776 .52138 .58308 .52713 .59336 .52395 .58807 .51817 Mtetra
.58807 .51817 .59336 .52395 .60368 .52076 .59841 .51496 Mtetra
.59841 .51496 .60368 .52076 .61404 .51756 .6088 .51173 Mtetra
.6088 .51173 .61404 .51756 .62444 .51435 .61922 .5085 Mtetra
.61922 .5085 .62444 .51435 .63488 .51113 .62968 .50526 Mtetra
.657 .753 .92 r
.62968 .50526 .63488 .51113 .64535 .5079 .64018 .50201 Mtetra
.64018 .50201 .64535 .5079 .65586 .50466 .65072 .49874 Mtetra
.65072 .49874 .65586 .50466 .66642 .50141 .6613 .49547 Mtetra
.6613 .49547 .66642 .50141 .67701 .49815 .67192 .49219 Mtetra
.657 .752 .92 r
.67192 .49219 .67701 .49815 .68764 .49488 .68258 .48889 Mtetra
.68258 .48889 .68764 .49488 .69831 .4916 .69328 .48559 Mtetra
.69328 .48559 .69831 .4916 .70902 .4883 .70402 .48227 Mtetra
.70402 .48227 .70902 .4883 .71977 .485 .7148 .47894 Mtetra
.7148 .47894 .71977 .485 .73057 .48168 .72562 .4756 Mtetra
.72562 .4756 .73057 .48168 .7414 .47835 .73649 .47225 Mtetra
.73649 .47225 .7414 .47835 .75228 .47501 .74739 .46888 Mtetra
.74739 .46888 .75228 .47501 .76319 .47166 .75833 .46551 Mtetra
.75833 .46551 .76319 .47166 .77415 .46829 .76932 .46212 Mtetra
.76932 .46212 .77415 .46829 .78515 .46491 .78035 .45871 Mtetra
.78035 .45871 .78515 .46491 .79619 .46152 .79142 .4553 Mtetra
.79142 .4553 .79619 .46152 .80727 .45812 .80254 .45187 Mtetra
.80254 .45187 .80727 .45812 .8184 .45471 .81369 .44844 Mtetra
.81369 .44844 .8184 .45471 .82957 .45128 .82489 .44498 Mtetra
.82489 .44498 .82957 .45128 .84078 .44784 .83614 .44152 Mtetra
.83614 .44152 .84078 .44784 .85203 .44439 .84742 .43804 Mtetra
.84742 .43804 .85203 .44439 .86333 .44092 .85875 .43455 Mtetra
.85875 .43455 .86333 .44092 .87468 .43744 .87013 .43105 Mtetra
.87013 .43105 .87468 .43744 .88606 .43395 .88154 .42753 Mtetra
.88154 .42753 .88606 .43395 .89749 .43045 .89301 .424 Mtetra
.89301 .424 .89749 .43045 .90897 .42693 .90452 .42046 Mtetra
.785 .672 .74 r
.28836 .60547 .29406 .61542 .30393 .60381 .29826 .59375 Mtetra
.404 .498 .842 r
.29826 .59375 .30393 .60381 .31313 .60265 .3072 .59678 Mtetra
.61 .717 .921 r
.3072 .59678 .31313 .60265 .32243 .60073 .31651 .59495 Mtetra
.605 .719 .925 r
.31651 .59495 .32243 .60073 .3317 .59994 .32585 .59321 Mtetra
.637 .157 0 r
.32585 .59321 .3317 .59994 .3415 .59009 .3345 .60459 Mtetra
0 0 0 r
.3345 .60459 .3415 .59009 .35076 .59065 .34492 .58446 Mtetra
.6 .704 .917 r
.34492 .58446 .35076 .59065 .36021 .58858 .35436 .58285 Mtetra
.626 .73 .922 r
.35436 .58285 .36021 .58858 .36969 .58639 .36386 .58062 Mtetra
.615 .725 .925 r
.36386 .58062 .36969 .58639 .37917 .58519 .3734 .57862 Mtetra
.055 .406 .859 r
.3734 .57862 .37917 .58519 .38908 .57438 .38268 .58362 Mtetra
0 0 0 r
.38268 .58362 .38908 .57438 .39852 .57584 .39278 .56949 Mtetra
.6 .701 .915 r
.39278 .56949 .39852 .57584 .40815 .57363 .4024 .56787 Mtetra
.635 .735 .92 r
.4024 .56787 .40815 .57363 .41783 .57108 .4121 .5654 Mtetra
.64 .74 .921 r
.4121 .5654 .41783 .57108 .42754 .5685 .42183 .56279 Mtetra
.638 .739 .922 r
.42183 .56279 .42754 .5685 .43729 .5661 .43161 .56023 Mtetra
.615 .726 .925 r
.43161 .56023 .43729 .5661 .44704 .56543 .4414 .55818 Mtetra
.959 .66 .42 r
.4414 .55818 .44704 .56543 .45702 .55552 .44893 .66231 Mtetra
0 0 .259 r
.44893 .66231 .45702 .55552 .46683 .55497 .46122 .54876 Mtetra
.619 .717 .916 r
.46122 .54876 .46683 .55497 .47673 .55244 .47113 .54664 Mtetra
.644 .741 .92 r
.47113 .54664 .47673 .55244 .48666 .54959 .48108 .54388 Mtetra
.651 .747 .92 r
.48108 .54388 .48666 .54959 .49664 .54662 .49108 .54094 Mtetra
.654 .75 .92 r
.49108 .54094 .49664 .54662 .50665 .54357 .50112 .5379 Mtetra
.656 .752 .92 r
.50112 .5379 .50665 .54357 .5167 .54047 .51119 .53479 Mtetra
.658 .753 .92 r
.51119 .53479 .5167 .54047 .52678 .53732 .5213 .53164 Mtetra
.659 .754 .92 r
.5213 .53164 .52678 .53732 .5369 .53415 .53144 .52846 Mtetra
.53144 .52846 .5369 .53415 .54706 .53097 .54163 .52525 Mtetra
.54163 .52525 .54706 .53097 .55726 .52778 .55185 .52203 Mtetra
.55185 .52203 .55726 .52778 .56749 .52458 .56211 .51881 Mtetra
.658 .753 .92 r
.56211 .51881 .56749 .52458 .57776 .52138 .5724 .51559 Mtetra
.5724 .51559 .57776 .52138 .58807 .51817 .58274 .51235 Mtetra
.58274 .51235 .58807 .51817 .59841 .51496 .59311 .50911 Mtetra
.59311 .50911 .59841 .51496 .6088 .51173 .60352 .50587 Mtetra
.60352 .50587 .6088 .51173 .61922 .5085 .61397 .50261 Mtetra
.61397 .50261 .61922 .5085 .62968 .50526 .62446 .49935 Mtetra
.62446 .49935 .62968 .50526 .64018 .50201 .63498 .49607 Mtetra
.657 .753 .92 r
.63498 .49607 .64018 .50201 .65072 .49874 .64555 .49279 Mtetra
.64555 .49279 .65072 .49874 .6613 .49547 .65616 .48949 Mtetra
.65616 .48949 .6613 .49547 .67192 .49219 .6668 .48618 Mtetra
.6668 .48618 .67192 .49219 .68258 .48889 .67749 .48286 Mtetra
.657 .752 .92 r
.67749 .48286 .68258 .48889 .69328 .48559 .68822 .47953 Mtetra
.68822 .47953 .69328 .48559 .70402 .48227 .69899 .47619 Mtetra
.69899 .47619 .70402 .48227 .7148 .47894 .7098 .47284 Mtetra
.7098 .47284 .7148 .47894 .72562 .4756 .72065 .46948 Mtetra
.72065 .46948 .72562 .4756 .73649 .47225 .73154 .4661 Mtetra
.73154 .4661 .73649 .47225 .74739 .46888 .74247 .46271 Mtetra
.74247 .46271 .74739 .46888 .75833 .46551 .75344 .45931 Mtetra
.75344 .45931 .75833 .46551 .76932 .46212 .76446 .4559 Mtetra
.76446 .4559 .76932 .46212 .78035 .45871 .77552 .45247 Mtetra
.77552 .45247 .78035 .45871 .79142 .4553 .78662 .44903 Mtetra
.78662 .44903 .79142 .4553 .80254 .45187 .79777 .44558 Mtetra
.79777 .44558 .80254 .45187 .81369 .44844 .80895 .44212 Mtetra
.80895 .44212 .81369 .44844 .82489 .44498 .82018 .43864 Mtetra
.82018 .43864 .82489 .44498 .83614 .44152 .83146 .43515 Mtetra
.83146 .43515 .83614 .44152 .84742 .43804 .84278 .43165 Mtetra
.84278 .43165 .84742 .43804 .85875 .43455 .85414 .42813 Mtetra
.85414 .42813 .85875 .43455 .87013 .43105 .86554 .4246 Mtetra
.86554 .4246 .87013 .43105 .88154 .42753 .877 .42106 Mtetra
.877 .42106 .88154 .42753 .89301 .424 .88849 .41751 Mtetra
.88849 .41751 .89301 .424 .90452 .42046 .90003 .41394 Mtetra
.25 .533 .92 r
.28239 .59908 .28836 .60547 .29826 .59375 .29132 .60206 Mtetra
0 0 0 r
.29132 .60206 .29826 .59375 .3072 .59678 .30127 .59036 Mtetra
.582 .689 .915 r
.30127 .59036 .3072 .59678 .31651 .59495 .31055 .58916 Mtetra
.615 .723 .923 r
.31055 .58916 .31651 .59495 .32585 .59321 .31992 .58719 Mtetra
.555 .695 .933 r
.31992 .58719 .32585 .59321 .3345 .60459 .32926 .58637 Mtetra
.708 .568 .695 r
.32926 .58637 .3345 .60459 .34492 .58446 .33914 .57643 Mtetra
.508 .609 .888 r
.33914 .57643 .34492 .58446 .35436 .58285 .34848 .57696 Mtetra
.62 .724 .92 r
.34848 .57696 .35436 .58285 .36386 .58062 .35799 .57485 Mtetra
.625 .73 .923 r
.35799 .57485 .36386 .58062 .3734 .57862 .36756 .57261 Mtetra
.577 .706 .93 r
.36756 .57261 .3734 .57862 .38268 .58362 .37711 .57137 Mtetra
.758 .641 .731 r
.37711 .57137 .38268 .58362 .39278 .56949 .38711 .56048 Mtetra
.475 .567 .869 r
.38711 .56048 .39278 .56949 .4024 .56787 .39662 .56191 Mtetra
.625 .726 .919 r
.39662 .56191 .4024 .56787 .4121 .5654 .40633 .55965 Mtetra
.639 .738 .921 r
.40633 .55965 .4121 .5654 .42183 .56279 .41609 .55706 Mtetra
.64 .74 .921 r
.41609 .55706 .42183 .56279 .43161 .56023 .42588 .55442 Mtetra
.631 .735 .923 r
.42588 .55442 .43161 .56023 .4414 .55818 .43571 .55198 Mtetra
.547 .691 .934 r
.43571 .55198 .4414 .55818 .44893 .66231 .44553 .55126 Mtetra
.589 .388 .577 r
.44553 .55126 .44893 .66231 .46122 .54876 .4556 .54127 Mtetra
.556 .652 .899 r
.4556 .54127 .46122 .54876 .47113 .54664 .46549 .54068 Mtetra
.636 .734 .919 r
.46549 .54068 .47113 .54664 .48108 .54388 .47547 .5381 Mtetra
.648 .745 .92 r
.47547 .5381 .48108 .54388 .49108 .54094 .48549 .5352 Mtetra
.653 .749 .92 r
.48549 .5352 .49108 .54094 .50112 .5379 .49555 .53218 Mtetra
.655 .751 .92 r
.49555 .53218 .50112 .5379 .51119 .53479 .50564 .52907 Mtetra
.657 .752 .92 r
.50564 .52907 .51119 .53479 .5213 .53164 .51578 .52592 Mtetra
.658 .753 .92 r
.51578 .52592 .5213 .53164 .53144 .52846 .52595 .52272 Mtetra
.659 .754 .92 r
.52595 .52272 .53144 .52846 .54163 .52525 .53616 .51949 Mtetra
.53616 .51949 .54163 .52525 .55185 .52203 .5464 .51625 Mtetra
.5464 .51625 .55185 .52203 .56211 .51881 .55669 .51301 Mtetra
.55669 .51301 .56211 .51881 .5724 .51559 .56701 .50976 Mtetra
.658 .753 .92 r
.56701 .50976 .5724 .51559 .58274 .51235 .57737 .5065 Mtetra
.57737 .5065 .58274 .51235 .59311 .50911 .58776 .50323 Mtetra
.58776 .50323 .59311 .50911 .60352 .50587 .5982 .49996 Mtetra
.5982 .49996 .60352 .50587 .61397 .50261 .60868 .49668 Mtetra
.60868 .49668 .61397 .50261 .62446 .49935 .61919 .49339 Mtetra
.61919 .49339 .62446 .49935 .63498 .49607 .62975 .4901 Mtetra
.657 .753 .92 r
.62975 .4901 .63498 .49607 .64555 .49279 .64034 .48679 Mtetra
.64034 .48679 .64555 .49279 .65616 .48949 .65098 .48347 Mtetra
.65098 .48347 .65616 .48949 .6668 .48618 .66165 .48014 Mtetra
.66165 .48014 .6668 .48618 .67749 .48286 .67236 .47679 Mtetra
.657 .752 .92 r
.67236 .47679 .67749 .48286 .68822 .47953 .68312 .47344 Mtetra
.68312 .47344 .68822 .47953 .69899 .47619 .69392 .47008 Mtetra
.69392 .47008 .69899 .47619 .7098 .47284 .70475 .4667 Mtetra
.70475 .4667 .7098 .47284 .72065 .46948 .71563 .46331 Mtetra
.71563 .46331 .72065 .46948 .73154 .4661 .72655 .45991 Mtetra
.72655 .45991 .73154 .4661 .74247 .46271 .73751 .4565 Mtetra
.73751 .4565 .74247 .46271 .75344 .45931 .74852 .45307 Mtetra
.74852 .45307 .75344 .45931 .76446 .4559 .75956 .44963 Mtetra
.75956 .44963 .76446 .4559 .77552 .45247 .77065 .44618 Mtetra
.77065 .44618 .77552 .45247 .78662 .44903 .78179 .44272 Mtetra
.78179 .44272 .78662 .44903 .79777 .44558 .79296 .43924 Mtetra
.79296 .43924 .79777 .44558 .80895 .44212 .80418 .43576 Mtetra
.80418 .43576 .80895 .44212 .82018 .43864 .81544 .43225 Mtetra
.81544 .43225 .82018 .43864 .83146 .43515 .82675 .42874 Mtetra
.82675 .42874 .83146 .43515 .84278 .43165 .8381 .42521 Mtetra
.8381 .42521 .84278 .43165 .85414 .42813 .84949 .42167 Mtetra
.84949 .42167 .85414 .42813 .86554 .4246 .86093 .41811 Mtetra
.86093 .41811 .86554 .4246 .877 .42106 .87241 .41455 Mtetra
.87241 .41455 .877 .42106 .88849 .41751 .88394 .41096 Mtetra
.88394 .41096 .88849 .41751 .90003 .41394 .89552 .40737 Mtetra
.572 .703 .93 r
.27635 .59313 .28239 .59908 .29132 .60206 .28557 .592 Mtetra
.785 .673 .74 r
.28557 .592 .29132 .60206 .30127 .59036 .29555 .58019 Mtetra
.403 .498 .842 r
.29555 .58019 .30127 .59036 .31055 .58916 .30456 .5832 Mtetra
.61 .717 .921 r
.30456 .5832 .31055 .58916 .31992 .58719 .31394 .58133 Mtetra
.605 .719 .925 r
.31394 .58133 .31992 .58719 .32926 .58637 .32335 .57954 Mtetra
.63 .151 0 r
.32335 .57954 .32926 .58637 .33914 .57643 .33206 .59094 Mtetra
0 0 0 r
.33206 .59094 .33914 .57643 .34848 .57696 .34258 .57068 Mtetra
.6 .704 .917 r
.34258 .57068 .34848 .57696 .35799 .57485 .35209 .56903 Mtetra
.626 .73 .922 r
.35209 .56903 .35799 .57485 .36756 .57261 .36167 .56675 Mtetra
.615 .725 .925 r
.36167 .56675 .36756 .57261 .37711 .57137 .37128 .5647 Mtetra
.059 .408 .86 r
.37128 .5647 .37711 .57137 .38711 .56048 .38063 .56969 Mtetra
0 0 0 r
.38063 .56969 .38711 .56048 .39662 .56191 .39082 .55546 Mtetra
.6 .701 .915 r
.39082 .55546 .39662 .56191 .40633 .55965 .40053 .55379 Mtetra
.635 .735 .92 r
.40053 .55379 .40633 .55965 .41609 .55706 .4103 .55128 Mtetra
.64 .74 .921 r
.4103 .55128 .41609 .55706 .42588 .55442 .42011 .54862 Mtetra
.638 .739 .922 r
.42011 .54862 .42588 .55442 .43571 .55198 .42997 .54601 Mtetra
.615 .726 .925 r
.42997 .54601 .43571 .55198 .44553 .55126 .43985 .54391 Mtetra
.96 .659 .416 r
.43985 .54391 .44553 .55126 .4556 .54127 .44738 .64848 Mtetra
0 0 .253 r
.44738 .64848 .4556 .54127 .46549 .54068 .45983 .53437 Mtetra
.619 .717 .916 r
.45983 .53437 .46549 .54068 .47547 .5381 .46982 .5322 Mtetra
.644 .741 .92 r
.46982 .5322 .47547 .5381 .48549 .5352 .47986 .52939 Mtetra
.651 .747 .92 r
.47986 .52939 .48549 .5352 .49555 .53218 .48994 .5264 Mtetra
.654 .75 .92 r
.48994 .5264 .49555 .53218 .50564 .52907 .50006 .5233 Mtetra
.656 .752 .92 r
.50006 .5233 .50564 .52907 .51578 .52592 .51022 .52014 Mtetra
.658 .753 .92 r
.51022 .52014 .51578 .52592 .52595 .52272 .52041 .51694 Mtetra
.659 .754 .92 r
.52041 .51694 .52595 .52272 .53616 .51949 .53065 .5137 Mtetra
.53065 .5137 .53616 .51949 .5464 .51625 .54092 .51044 Mtetra
.54092 .51044 .5464 .51625 .55669 .51301 .55123 .50716 Mtetra
.55123 .50716 .55669 .51301 .56701 .50976 .56157 .50389 Mtetra
.658 .753 .92 r
.56157 .50389 .56701 .50976 .57737 .5065 .57196 .5006 Mtetra
.57196 .5006 .57737 .5065 .58776 .50323 .58238 .49731 Mtetra
.58238 .49731 .58776 .50323 .5982 .49996 .59285 .49402 Mtetra
.59285 .49402 .5982 .49996 .60868 .49668 .60335 .49071 Mtetra
.60335 .49071 .60868 .49668 .61919 .49339 .61389 .4874 Mtetra
.61389 .4874 .61919 .49339 .62975 .4901 .62447 .48408 Mtetra
.62447 .48408 .62975 .4901 .64034 .48679 .63509 .48075 Mtetra
.657 .753 .92 r
.63509 .48075 .64034 .48679 .65098 .48347 .64576 .4774 Mtetra
.64576 .4774 .65098 .48347 .66165 .48014 .65646 .47405 Mtetra
.65646 .47405 .66165 .48014 .67236 .47679 .6672 .47068 Mtetra
.6672 .47068 .67236 .47679 .68312 .47344 .67798 .4673 Mtetra
.657 .752 .92 r
.67798 .4673 .68312 .47344 .69392 .47008 .68881 .46391 Mtetra
.68881 .46391 .69392 .47008 .70475 .4667 .69967 .46051 Mtetra
.69967 .46051 .70475 .4667 .71563 .46331 .71058 .4571 Mtetra
.71058 .4571 .71563 .46331 .72655 .45991 .72153 .45368 Mtetra
.72153 .45368 .72655 .45991 .73751 .4565 .73252 .45024 Mtetra
.73252 .45024 .73751 .4565 .74852 .45307 .74356 .44679 Mtetra
.74356 .44679 .74852 .45307 .75956 .44963 .75463 .44333 Mtetra
.75463 .44333 .75956 .44963 .77065 .44618 .76575 .43985 Mtetra
.76575 .43985 .77065 .44618 .78179 .44272 .77692 .43636 Mtetra
.77692 .43636 .78179 .44272 .79296 .43924 .78812 .43286 Mtetra
.78812 .43286 .79296 .43924 .80418 .43576 .79937 .42935 Mtetra
.79937 .42935 .80418 .43576 .81544 .43225 .81066 .42582 Mtetra
.81066 .42582 .81544 .43225 .82675 .42874 .822 .42228 Mtetra
.822 .42228 .82675 .42874 .8381 .42521 .83338 .41873 Mtetra
.83338 .41873 .8381 .42521 .84949 .42167 .84481 .41516 Mtetra
.84481 .41516 .84949 .42167 .86093 .41811 .85628 .41158 Mtetra
.85628 .41158 .86093 .41811 .87241 .41455 .8678 .40798 Mtetra
.8678 .40798 .87241 .41455 .88394 .41096 .87936 .40437 Mtetra
.87936 .40437 .88394 .41096 .89552 .40737 .89097 .40075 Mtetra
.602 .716 .925 r
.27026 .58722 .27635 .59313 .28557 .592 .27954 .58552 Mtetra
.252 .534 .92 r
.27954 .58552 .28557 .592 .29555 .58019 .28853 .58847 Mtetra
0 0 0 r
.28853 .58847 .29555 .58019 .30456 .5832 .29857 .57669 Mtetra
.582 .689 .915 r
.29857 .57669 .30456 .5832 .31394 .58133 .30792 .57544 Mtetra
.615 .723 .923 r
.30792 .57544 .31394 .58133 .32335 .57954 .31736 .57343 Mtetra
.556 .695 .933 r
.31736 .57343 .32335 .57954 .33206 .59094 .32678 .57257 Mtetra
.708 .568 .695 r
.32678 .57257 .33206 .59094 .34258 .57068 .33675 .56255 Mtetra
.507 .609 .888 r
.33675 .56255 .34258 .57068 .35209 .56903 .34615 .56305 Mtetra
.62 .724 .92 r
.34615 .56305 .35209 .56903 .36167 .56675 .35575 .56089 Mtetra
.625 .73 .923 r
.35575 .56089 .36167 .56675 .37128 .5647 .36538 .5586 Mtetra
.577 .706 .93 r
.36538 .5586 .37128 .5647 .38063 .56969 .37502 .55732 Mtetra
.759 .641 .731 r
.37502 .55732 .38063 .56969 .39082 .55546 .3851 .54634 Mtetra
.474 .567 .869 r
.3851 .54634 .39082 .55546 .40053 .55379 .39469 .54774 Mtetra
.625 .726 .919 r
.39469 .54774 .40053 .55379 .4103 .55128 .40448 .54543 Mtetra
.639 .738 .921 r
.40448 .54543 .4103 .55128 .42011 .54862 .41431 .54279 Mtetra
.64 .74 .921 r
.41431 .54279 .42011 .54862 .42997 .54601 .42419 .5401 Mtetra
.631 .735 .923 r
.42419 .5401 .42997 .54601 .43985 .54391 .4341 .53761 Mtetra
.547 .691 .934 r
.4341 .53761 .43985 .54391 .44738 .64848 .444 .53685 Mtetra
.587 .386 .576 r
.444 .53685 .44738 .64848 .45983 .53437 .45416 .52678 Mtetra
.556 .652 .899 r
.45416 .52678 .45983 .53437 .46982 .5322 .46413 .52614 Mtetra
.636 .734 .919 r
.46413 .52614 .46982 .5322 .47986 .52939 .47419 .52351 Mtetra
.648 .745 .92 r
.47419 .52351 .47986 .52939 .48994 .5264 .4843 .52056 Mtetra
.653 .749 .92 r
.4843 .52056 .48994 .5264 .50006 .5233 .49444 .51748 Mtetra
.655 .751 .92 r
.49444 .51748 .50006 .5233 .51022 .52014 .50462 .51432 Mtetra
.657 .752 .92 r
.50462 .51432 .51022 .52014 .52041 .51694 .51484 .51111 Mtetra
.658 .753 .92 r
.51484 .51111 .52041 .51694 .53065 .5137 .5251 .50786 Mtetra
.659 .754 .92 r
.5251 .50786 .53065 .5137 .54092 .51044 .5354 .50458 Mtetra
.5354 .50458 .54092 .51044 .55123 .50716 .54573 .50128 Mtetra
.54573 .50128 .55123 .50716 .56157 .50389 .5561 .49798 Mtetra
.5561 .49798 .56157 .50389 .57196 .5006 .56652 .49467 Mtetra
.658 .753 .92 r
.56652 .49467 .57196 .5006 .58238 .49731 .57697 .49135 Mtetra
.57697 .49135 .58238 .49731 .59285 .49402 .58746 .48803 Mtetra
.58746 .48803 .59285 .49402 .60335 .49071 .59798 .4847 Mtetra
.59798 .4847 .60335 .49071 .61389 .4874 .60855 .48137 Mtetra
.60855 .48137 .61389 .4874 .62447 .48408 .61916 .47802 Mtetra
.61916 .47802 .62447 .48408 .63509 .48075 .62981 .47466 Mtetra
.657 .753 .92 r
.62981 .47466 .63509 .48075 .64576 .4774 .6405 .47129 Mtetra
.6405 .47129 .64576 .4774 .65646 .47405 .65123 .46792 Mtetra
.65123 .46792 .65646 .47405 .6672 .47068 .662 .46453 Mtetra
.662 .46453 .6672 .47068 .67798 .4673 .67281 .46112 Mtetra
.657 .752 .92 r
.67281 .46112 .67798 .4673 .68881 .46391 .68367 .45771 Mtetra
.68367 .45771 .68881 .46391 .69967 .46051 .69456 .45428 Mtetra
.69456 .45428 .69967 .46051 .71058 .4571 .7055 .45085 Mtetra
.7055 .45085 .71058 .4571 .72153 .45368 .71648 .4474 Mtetra
.71648 .4474 .72153 .45368 .73252 .45024 .7275 .44393 Mtetra
.7275 .44393 .73252 .45024 .74356 .44679 .73856 .44046 Mtetra
.73856 .44046 .74356 .44679 .75463 .44333 .74967 .43697 Mtetra
.74967 .43697 .75463 .44333 .76575 .43985 .76082 .43347 Mtetra
.76082 .43347 .76575 .43985 .77692 .43636 .77201 .42996 Mtetra
.77201 .42996 .77692 .43636 .78812 .43286 .78325 .42643 Mtetra
.78325 .42643 .78812 .43286 .79937 .42935 .79453 .42289 Mtetra
.79453 .42289 .79937 .42935 .81066 .42582 .80585 .41934 Mtetra
.80585 .41934 .81066 .42582 .822 .42228 .81722 .41577 Mtetra
.81722 .41577 .822 .42228 .83338 .41873 .82863 .41219 Mtetra
.82863 .41219 .83338 .41873 .84481 .41516 .84009 .4086 Mtetra
.84009 .4086 .84481 .41516 .85628 .41158 .8516 .40499 Mtetra
.8516 .40499 .85628 .41158 .8678 .40798 .86315 .40137 Mtetra
.86315 .40137 .8678 .40798 .87936 .40437 .87474 .39774 Mtetra
.87474 .39774 .87936 .40437 .89097 .40075 .88638 .39409 Mtetra
.6 .711 .922 r
.26415 .58115 .27026 .58722 .27954 .58552 .27344 .57947 Mtetra
.572 .703 .93 r
.27344 .57947 .27954 .58552 .28853 .58847 .28273 .5783 Mtetra
.786 .673 .74 r
.28273 .5783 .28853 .58847 .29857 .57669 .2928 .56641 Mtetra
.402 .498 .842 r
.2928 .56641 .29857 .57669 .30792 .57544 .30188 .56939 Mtetra
.61 .717 .921 r
.30188 .56939 .30792 .57544 .31736 .57343 .31133 .56748 Mtetra
.605 .719 .925 r
.31133 .56748 .31736 .57343 .32678 .57257 .32081 .56564 Mtetra
.623 .145 0 r
.32081 .56564 .32678 .57257 .33675 .56255 .32958 .57705 Mtetra
0 0 0 r
.32958 .57705 .33675 .56255 .34615 .56305 .3402 .55667 Mtetra
.6 .704 .917 r
.3402 .55667 .34615 .56305 .35575 .56089 .34978 .55497 Mtetra
.626 .73 .922 r
.34978 .55497 .35575 .56089 .36538 .5586 .35944 .55264 Mtetra
.615 .725 .925 r
.35944 .55264 .36538 .5586 .37502 .55732 .36913 .55055 Mtetra
.064 .41 .861 r
.36913 .55055 .37502 .55732 .3851 .54634 .37855 .55552 Mtetra
0 0 0 r
.37855 .55552 .3851 .54634 .39469 .54774 .38883 .54119 Mtetra
.6 .701 .915 r
.38883 .54119 .39469 .54774 .40448 .54543 .39862 .53947 Mtetra
.635 .735 .92 r
.39862 .53947 .40448 .54543 .41431 .54279 .40847 .53691 Mtetra
.64 .74 .921 r
.40847 .53691 .41431 .54279 .42419 .5401 .41837 .5342 Mtetra
.638 .739 .922 r
.41837 .5342 .42419 .5401 .4341 .53761 .4283 .53154 Mtetra
.615 .726 .925 r
.4283 .53154 .4341 .53761 .444 .53685 .43826 .52939 Mtetra
.961 .659 .412 r
.43826 .52939 .444 .53685 .45416 .52678 .44581 .63441 Mtetra
0 0 .247 r
.44581 .63441 .45416 .52678 .46413 .52614 .45841 .51973 Mtetra
.619 .717 .916 r
.45841 .51973 .46413 .52614 .47419 .52351 .46849 .51751 Mtetra
.644 .741 .92 r
.46849 .51751 .47419 .52351 .4843 .52056 .47861 .51465 Mtetra
.651 .747 .92 r
.47861 .51465 .4843 .52056 .49444 .51748 .48878 .5116 Mtetra
.654 .75 .92 r
.48878 .5116 .49444 .51748 .50462 .51432 .49899 .50845 Mtetra
.656 .752 .92 r
.49899 .50845 .50462 .51432 .51484 .51111 .50923 .50524 Mtetra
.658 .753 .92 r
.50923 .50524 .51484 .51111 .5251 .50786 .51952 .50197 Mtetra
.659 .754 .92 r
.51952 .50197 .5251 .50786 .5354 .50458 .52984 .49867 Mtetra
.52984 .49867 .5354 .50458 .54573 .50128 .5402 .49536 Mtetra
.5402 .49536 .54573 .50128 .5561 .49798 .5506 .49203 Mtetra
.5506 .49203 .5561 .49798 .56652 .49467 .56103 .48869 Mtetra
.658 .753 .92 r
.56103 .48869 .56652 .49467 .57697 .49135 .57151 .48535 Mtetra
.57151 .48535 .57697 .49135 .58746 .48803 .58203 .48201 Mtetra
.58203 .48201 .58746 .48803 .59798 .4847 .59258 .47865 Mtetra
.59258 .47865 .59798 .4847 .60855 .48137 .60318 .47529 Mtetra
.60318 .47529 .60855 .48137 .61916 .47802 .61381 .47192 Mtetra
.61381 .47192 .61916 .47802 .62981 .47466 .62449 .46854 Mtetra
.62449 .46854 .62981 .47466 .6405 .47129 .63521 .46514 Mtetra
.657 .753 .92 r
.63521 .46514 .6405 .47129 .65123 .46792 .64596 .46174 Mtetra
.64596 .46174 .65123 .46792 .662 .46453 .65676 .45833 Mtetra
.65676 .45833 .662 .46453 .67281 .46112 .6676 .4549 Mtetra
.6676 .4549 .67281 .46112 .68367 .45771 .67849 .45146 Mtetra
.657 .752 .92 r
.67849 .45146 .68367 .45771 .69456 .45428 .68941 .44801 Mtetra
.68941 .44801 .69456 .45428 .7055 .45085 .70038 .44455 Mtetra
.70038 .44455 .7055 .45085 .71648 .4474 .71138 .44107 Mtetra
.71138 .44107 .71648 .4474 .7275 .44393 .72243 .43759 Mtetra
.72243 .43759 .7275 .44393 .73856 .44046 .73353 .43409 Mtetra
.73353 .43409 .73856 .44046 .74967 .43697 .74467 .43057 Mtetra
.74467 .43057 .74967 .43697 .76082 .43347 .75585 .42705 Mtetra
.75585 .42705 .76082 .43347 .77201 .42996 .76707 .42351 Mtetra
.76707 .42351 .77201 .42996 .78325 .42643 .77834 .41996 Mtetra
.77834 .41996 .78325 .42643 .79453 .42289 .78965 .41639 Mtetra
.78965 .41639 .79453 .42289 .80585 .41934 .80101 .41281 Mtetra
.80101 .41281 .80585 .41934 .81722 .41577 .81241 .40922 Mtetra
.81241 .40922 .81722 .41577 .82863 .41219 .82385 .40561 Mtetra
.82385 .40561 .82863 .41219 .84009 .4086 .83534 .40199 Mtetra
.83534 .40199 .84009 .4086 .8516 .40499 .84688 .39836 Mtetra
.84688 .39836 .8516 .40499 .86315 .40137 .85846 .39471 Mtetra
.85846 .39471 .86315 .40137 .87474 .39774 .87009 .39105 Mtetra
.87009 .39105 .87474 .39774 .88638 .39409 .88177 .38738 Mtetra
.567 .678 .914 r
.25804 .57443 .26415 .58115 .27344 .57947 .26729 .57347 Mtetra
.602 .716 .925 r
.26729 .57347 .27344 .57947 .28273 .5783 .27664 .57172 Mtetra
.254 .535 .92 r
.27664 .57172 .28273 .5783 .2928 .56641 .2857 .57465 Mtetra
.546 .82 .467 r
.2857 .57465 .2928 .56641 .30188 .56939 .29583 .56278 Mtetra
.582 .689 .915 r
.29583 .56278 .30188 .56939 .31133 .56748 .30525 .56149 Mtetra
.615 .723 .923 r
.30525 .56149 .31133 .56748 .32081 .56564 .31477 .55944 Mtetra
.556 .695 .933 r
.31477 .55944 .32081 .56564 .32958 .57705 .32425 .55853 Mtetra
.708 .568 .695 r
.32425 .55853 .32958 .57705 .3402 .55667 .33431 .54844 Mtetra
.507 .609 .888 r
.33431 .54844 .3402 .55667 .34978 .55497 .34379 .54889 Mtetra
.62 .724 .92 r
.34379 .54889 .34978 .55497 .35944 .55264 .35346 .54669 Mtetra
.625 .73 .923 r
.35346 .54669 .35944 .55264 .36913 .55055 .36318 .54435 Mtetra
.577 .706 .93 r
.36318 .54435 .36913 .55055 .37855 .55552 .37289 .54302 Mtetra
.759 .642 .731 r
.37289 .54302 .37855 .55552 .38883 .54119 .38305 .53196 Mtetra
.474 .567 .869 r
.38305 .53196 .38883 .54119 .39862 .53947 .39272 .53332 Mtetra
.625 .726 .919 r
.39272 .53332 .39862 .53947 .40847 .53691 .40259 .53096 Mtetra
.639 .738 .921 r
.40259 .53096 .40847 .53691 .41837 .5342 .41251 .52827 Mtetra
.64 .74 .921 r
.41251 .52827 .41837 .5342 .4283 .53154 .42246 .52553 Mtetra
.631 .735 .923 r
.42246 .52553 .4283 .53154 .43826 .52939 .43246 .52299 Mtetra
.548 .691 .933 r
.43246 .52299 .43826 .52939 .44581 .63441 .44244 .52219 Mtetra
.586 .384 .574 r
.44244 .52219 .44581 .63441 .45841 .51973 .45269 .51203 Mtetra
.556 .652 .899 r
.45269 .51203 .45841 .51973 .46849 .51751 .46275 .51135 Mtetra
.636 .734 .919 r
.46275 .51135 .46849 .51751 .47861 .51465 .47289 .50866 Mtetra
.648 .745 .92 r
.47289 .50866 .47861 .51465 .48878 .5116 .48308 .50566 Mtetra
.653 .749 .92 r
.48308 .50566 .48878 .5116 .49899 .50845 .49331 .50252 Mtetra
.655 .751 .92 r
.49331 .50252 .49899 .50845 .50923 .50524 .50358 .49931 Mtetra
.657 .752 .92 r
.50358 .49931 .50923 .50524 .51952 .50197 .51389 .49604 Mtetra
.658 .753 .92 r
.51389 .49604 .51952 .50197 .52984 .49867 .52424 .49273 Mtetra
.659 .754 .92 r
.52424 .49273 .52984 .49867 .5402 .49536 .53462 .48939 Mtetra
.53462 .48939 .5402 .49536 .5506 .49203 .54505 .48604 Mtetra
.54505 .48604 .5506 .49203 .56103 .48869 .55551 .48268 Mtetra
.55551 .48268 .56103 .48869 .57151 .48535 .56602 .47931 Mtetra
.658 .753 .92 r
.56602 .47931 .57151 .48535 .58203 .48201 .57656 .47594 Mtetra
.57656 .47594 .58203 .48201 .59258 .47865 .58714 .47256 Mtetra
.58714 .47256 .59258 .47865 .60318 .47529 .59776 .46917 Mtetra
.59776 .46917 .60318 .47529 .61381 .47192 .60843 .46578 Mtetra
.60843 .46578 .61381 .47192 .62449 .46854 .61913 .46237 Mtetra
.61913 .46237 .62449 .46854 .63521 .46514 .62988 .45895 Mtetra
.657 .753 .92 r
.62988 .45895 .63521 .46514 .64596 .46174 .64066 .45552 Mtetra
.64066 .45552 .64596 .46174 .65676 .45833 .65149 .45208 Mtetra
.65149 .45208 .65676 .45833 .6676 .4549 .66236 .44863 Mtetra
.66236 .44863 .6676 .4549 .67849 .45146 .67327 .44517 Mtetra
.657 .752 .92 r
.67327 .44517 .67849 .45146 .68941 .44801 .68422 .44169 Mtetra
.68422 .44169 .68941 .44801 .70038 .44455 .69522 .4382 Mtetra
.69522 .4382 .70038 .44455 .71138 .44107 .70625 .4347 Mtetra
.70625 .4347 .71138 .44107 .72243 .43759 .71734 .43119 Mtetra
.71734 .43119 .72243 .43759 .73353 .43409 .72846 .42767 Mtetra
.72846 .42767 .73353 .43409 .74467 .43057 .73963 .42413 Mtetra
.73963 .42413 .74467 .43057 .75585 .42705 .75084 .42058 Mtetra
.75084 .42058 .75585 .42705 .76707 .42351 .76209 .41701 Mtetra
.76209 .41701 .76707 .42351 .77834 .41996 .77339 .41343 Mtetra
.77339 .41343 .77834 .41996 .78965 .41639 .78473 .40984 Mtetra
.78473 .40984 .78965 .41639 .80101 .41281 .79612 .40624 Mtetra
.79612 .40624 .80101 .41281 .81241 .40922 .80756 .40262 Mtetra
.80756 .40262 .81241 .40922 .82385 .40561 .81903 .39899 Mtetra
.81903 .39899 .82385 .40561 .83534 .40199 .83056 .39534 Mtetra
.83056 .39534 .83534 .40199 .84688 .39836 .84213 .39168 Mtetra
.84213 .39168 .84688 .39836 .85846 .39471 .85374 .388 Mtetra
.85374 .388 .85846 .39471 .87009 .39105 .86541 .38432 Mtetra
.86541 .38432 .87009 .39105 .88177 .38738 .87711 .38061 Mtetra
.29 .379 .781 r
.2524 .56154 .25804 .57443 .26729 .57347 .26111 .56731 Mtetra
.6 .711 .922 r
.26111 .56731 .26729 .57347 .27664 .57172 .27048 .56558 Mtetra
.572 .703 .93 r
.27048 .56558 .27664 .57172 .2857 .57465 .27984 .56437 Mtetra
.786 .674 .74 r
.27984 .56437 .2857 .57465 .29583 .56278 .29 .55239 Mtetra
.401 .497 .842 r
.29 .55239 .29583 .56278 .30525 .56149 .29914 .55534 Mtetra
.61 .717 .921 r
.29914 .55534 .30525 .56149 .31477 .55944 .30867 .55339 Mtetra
.605 .719 .925 r
.30867 .55339 .31477 .55944 .32425 .55853 .31823 .5515 Mtetra
.615 .138 0 r
.31823 .5515 .32425 .55853 .33431 .54844 .32706 .56293 Mtetra
0 0 0 r
.32706 .56293 .33431 .54844 .34379 .54889 .33777 .54241 Mtetra
.6 .704 .917 r
.33777 .54241 .34379 .54889 .35346 .54669 .34744 .54067 Mtetra
.626 .73 .922 r
.34744 .54067 .35346 .54669 .36318 .54435 .35718 .53829 Mtetra
.615 .725 .924 r
.35718 .53829 .36318 .54435 .37289 .54302 .36694 .53615 Mtetra
.068 .412 .863 r
.36694 .53615 .37289 .54302 .38305 .53196 .37643 .54111 Mtetra
.58 .81 .418 r
.37643 .54111 .38305 .53196 .39272 .53332 .38681 .52667 Mtetra
.6 .701 .915 r
.38681 .52667 .39272 .53332 .40259 .53096 .39667 .52491 Mtetra
.635 .735 .92 r
.39667 .52491 .40259 .53096 .41251 .52827 .40661 .52229 Mtetra
.64 .74 .921 r
.40661 .52229 .41251 .52827 .42246 .52553 .41659 .51953 Mtetra
.638 .739 .922 r
.41659 .51953 .42246 .52553 .43246 .52299 .4266 .51682 Mtetra
.615 .726 .925 r
.4266 .51682 .43246 .52299 .44244 .52219 .43665 .51462 Mtetra
.961 .658 .408 r
.43665 .51462 .44244 .52219 .45269 .51203 .44421 .62007 Mtetra
0 0 .241 r
.44421 .62007 .45269 .51203 .46275 .51135 .45697 .50484 Mtetra
.619 .717 .916 r
.45697 .50484 .46275 .51135 .47289 .50866 .46713 .50256 Mtetra
.644 .741 .92 r
.46713 .50256 .47289 .50866 .48308 .50566 .47735 .49965 Mtetra
.651 .747 .92 r
.47735 .49965 .48308 .50566 .49331 .50252 .4876 .49654 Mtetra
.654 .75 .92 r
.4876 .49654 .49331 .50252 .50358 .49931 .49789 .49334 Mtetra
.656 .752 .92 r
.49789 .49334 .50358 .49931 .51389 .49604 .50823 .49006 Mtetra
.658 .753 .92 r
.50823 .49006 .51389 .49604 .52424 .49273 .5186 .48674 Mtetra
.659 .754 .92 r
.5186 .48674 .52424 .49273 .53462 .48939 .52901 .48339 Mtetra
.52901 .48339 .53462 .48939 .54505 .48604 .53946 .48001 Mtetra
.53946 .48001 .54505 .48604 .55551 .48268 .54995 .47662 Mtetra
.54995 .47662 .55551 .48268 .56602 .47931 .56048 .47323 Mtetra
.658 .753 .92 r
.56048 .47323 .56602 .47931 .57656 .47594 .57105 .46983 Mtetra
.57105 .46983 .57656 .47594 .58714 .47256 .58166 .46642 Mtetra
.58166 .46642 .58714 .47256 .59776 .46917 .59231 .46301 Mtetra
.59231 .46301 .59776 .46917 .60843 .46578 .603 .45959 Mtetra
.603 .45959 .60843 .46578 .61913 .46237 .61373 .45616 Mtetra
.61373 .45616 .61913 .46237 .62988 .45895 .62451 .45271 Mtetra
.62451 .45271 .62988 .45895 .64066 .45552 .63532 .44926 Mtetra
.657 .753 .92 r
.63532 .44926 .64066 .45552 .65149 .45208 .64618 .4458 Mtetra
.64618 .4458 .65149 .45208 .66236 .44863 .65707 .44232 Mtetra
.65707 .44232 .66236 .44863 .67327 .44517 .66801 .43883 Mtetra
.66801 .43883 .67327 .44517 .68422 .44169 .679 .43533 Mtetra
.657 .752 .92 r
.679 .43533 .68422 .44169 .69522 .4382 .69002 .43182 Mtetra
.69002 .43182 .69522 .4382 .70625 .4347 .70109 .42829 Mtetra
.70109 .42829 .70625 .4347 .71734 .43119 .7122 .42475 Mtetra
.7122 .42475 .71734 .43119 .72846 .42767 .72335 .4212 Mtetra
.72335 .4212 .72846 .42767 .73963 .42413 .73455 .41764 Mtetra
.73455 .41764 .73963 .42413 .75084 .42058 .74579 .41406 Mtetra
.74579 .41406 .75084 .42058 .76209 .41701 .75708 .41047 Mtetra
.75708 .41047 .76209 .41701 .77339 .41343 .76841 .40686 Mtetra
.76841 .40686 .77339 .41343 .78473 .40984 .77979 .40325 Mtetra
.77979 .40325 .78473 .40984 .79612 .40624 .79121 .39961 Mtetra
.79121 .39961 .79612 .40624 .80756 .40262 .80267 .39597 Mtetra
.80267 .39597 .80756 .40262 .81903 .39899 .81418 .39231 Mtetra
.81418 .39231 .81903 .39899 .83056 .39534 .82574 .38864 Mtetra
.82574 .38864 .83056 .39534 .84213 .39168 .83734 .38495 Mtetra
.83734 .38495 .84213 .39168 .85374 .388 .84899 .38125 Mtetra
.84899 .38125 .85374 .388 .86541 .38432 .86069 .37753 Mtetra
.86069 .37753 .86541 .38432 .87711 .38061 .87243 .3738 Mtetra
0 0 0 r
.24489 .57103 .2524 .56154 .26111 .56731 .25495 .56049 Mtetra
.567 .678 .914 r
.25495 .56049 .26111 .56731 .27048 .56558 .26427 .55949 Mtetra
.602 .716 .925 r
.26427 .55949 .27048 .56558 .27984 .56437 .27369 .55769 Mtetra
.256 .536 .92 r
.27369 .55769 .27984 .56437 .29 .55239 .28282 .5606 Mtetra
.558 .83 .478 r
.28282 .5606 .29 .55239 .29914 .55534 .29303 .54864 Mtetra
.582 .689 .915 r
.29303 .54864 .29914 .55534 .30867 .55339 .30253 .54731 Mtetra
.615 .723 .923 r
.30253 .54731 .30867 .55339 .31823 .5515 .31212 .5452 Mtetra
.556 .695 .933 r
.31212 .5452 .31823 .5515 .32706 .56293 .32169 .54425 Mtetra
.708 .568 .695 r
.32169 .54425 .32706 .56293 .33777 .54241 .33183 .53407 Mtetra
.507 .608 .889 r
.33183 .53407 .33777 .54241 .34744 .54067 .34138 .53449 Mtetra
.62 .724 .92 r
.34138 .53449 .34744 .54067 .35718 .53829 .35113 .53224 Mtetra
.625 .73 .923 r
.35113 .53224 .35718 .53829 .36694 .53615 .36093 .52986 Mtetra
.577 .706 .93 r
.36093 .52986 .36694 .53615 .37643 .54111 .37072 .52848 Mtetra
.759 .642 .732 r
.37072 .52848 .37643 .54111 .38681 .52667 .38098 .51733 Mtetra
.473 .566 .869 r
.38098 .51733 .38681 .52667 .39667 .52491 .39072 .51866 Mtetra
.625 .726 .919 r
.39072 .51866 .39667 .52491 .40661 .52229 .40067 .51625 Mtetra
.639 .738 .921 r
.40067 .51625 .40661 .52229 .41659 .51953 .41067 .5135 Mtetra
.64 .74 .921 r
.41067 .5135 .41659 .51953 .4266 .51682 .42071 .51071 Mtetra
.631 .735 .923 r
.42071 .51071 .4266 .51682 .43665 .51462 .43079 .50811 Mtetra
.548 .691 .933 r
.43079 .50811 .43665 .51462 .44421 .62007 .44086 .50726 Mtetra
.584 .381 .572 r
.44086 .50726 .44421 .62007 .45697 .50484 .45119 .49702 Mtetra
.556 .652 .899 r
.45119 .49702 .45697 .50484 .46713 .50256 .46134 .4963 Mtetra
.636 .734 .919 r
.46134 .4963 .46713 .50256 .47735 .49965 .47157 .49355 Mtetra
.648 .745 .92 r
.47157 .49355 .47735 .49965 .4876 .49654 .48185 .49049 Mtetra
.653 .749 .92 r
.48185 .49049 .4876 .49654 .49789 .49334 .49217 .4873 Mtetra
.655 .751 .92 r
.49217 .4873 .49789 .49334 .50823 .49006 .50253 .48403 Mtetra
.657 .752 .92 r
.50253 .48403 .50823 .49006 .5186 .48674 .51292 .48071 Mtetra
.658 .753 .92 r
.51292 .48071 .5186 .48674 .52901 .48339 .52336 .47734 Mtetra
.659 .754 .92 r
.52336 .47734 .52901 .48339 .53946 .48001 .53384 .47394 Mtetra
.53384 .47394 .53946 .48001 .54995 .47662 .54436 .47053 Mtetra
.54436 .47053 .54995 .47662 .56048 .47323 .55491 .46711 Mtetra
.55491 .46711 .56048 .47323 .57105 .46983 .56551 .46368 Mtetra
.658 .753 .92 r
.56551 .46368 .57105 .46983 .58166 .46642 .57614 .46025 Mtetra
.57614 .46025 .58166 .46642 .59231 .46301 .58682 .45681 Mtetra
.58682 .45681 .59231 .46301 .603 .45959 .59754 .45336 Mtetra
.59754 .45336 .603 .45959 .61373 .45616 .6083 .4499 Mtetra
.6083 .4499 .61373 .45616 .62451 .45271 .6191 .44643 Mtetra
.6191 .44643 .62451 .45271 .63532 .44926 .62994 .44295 Mtetra
.657 .753 .92 r
.62994 .44295 .63532 .44926 .64618 .4458 .64083 .43946 Mtetra
.64083 .43946 .64618 .4458 .65707 .44232 .65175 .43596 Mtetra
.65175 .43596 .65707 .44232 .66801 .43883 .66272 .43245 Mtetra
.66272 .43245 .66801 .43883 .679 .43533 .67373 .42892 Mtetra
.657 .752 .92 r
.67373 .42892 .679 .43533 .69002 .43182 .68479 .42538 Mtetra
.68479 .42538 .69002 .43182 .70109 .42829 .69589 .42183 Mtetra
.69589 .42183 .70109 .42829 .7122 .42475 .70703 .41827 Mtetra
.70703 .41827 .7122 .42475 .72335 .4212 .71821 .41469 Mtetra
.71821 .41469 .72335 .4212 .73455 .41764 .72944 .4111 Mtetra
.72944 .4111 .73455 .41764 .74579 .41406 .74071 .40749 Mtetra
.74071 .40749 .74579 .41406 .75708 .41047 .75203 .40388 Mtetra
.75203 .40388 .75708 .41047 .76841 .40686 .76339 .40025 Mtetra
.76339 .40025 .76841 .40686 .77979 .40325 .7748 .3966 Mtetra
.7748 .3966 .77979 .40325 .79121 .39961 .78625 .39294 Mtetra
.78625 .39294 .79121 .39961 .80267 .39597 .79775 .38927 Mtetra
.79775 .38927 .80267 .39597 .81418 .39231 .80929 .38558 Mtetra
.80929 .38558 .81418 .39231 .82574 .38864 .82088 .38188 Mtetra
.82088 .38188 .82574 .38864 .83734 .38495 .83252 .37817 Mtetra
.83252 .37817 .83734 .38495 .84899 .38125 .8442 .37444 Mtetra
.8442 .37444 .84899 .38125 .86069 .37753 .85593 .37069 Mtetra
.85593 .37069 .86069 .37753 .87243 .3738 .86771 .36694 Mtetra
.818 .698 .732 r
.23884 .56201 .24489 .57103 .25495 .56049 .24925 .54747 Mtetra
.288 .378 .781 r
.24925 .54747 .25495 .56049 .26427 .55949 .25803 .55323 Mtetra
.6 .711 .922 r
.25803 .55323 .26427 .55949 .27369 .55769 .26747 .55146 Mtetra
.572 .703 .93 r
.26747 .55146 .27369 .55769 .28282 .5606 .2769 .5502 Mtetra
.787 .675 .74 r
.2769 .5502 .28282 .5606 .29303 .54864 .28715 .53813 Mtetra
.4 .497 .843 r
.28715 .53813 .29303 .54864 .30253 .54731 .29636 .54106 Mtetra
.61 .717 .921 r
.29636 .54106 .30253 .54731 .31212 .5452 .30597 .53905 Mtetra
.605 .719 .925 r
.30597 .53905 .31212 .5452 .32169 .54425 .3156 .53712 Mtetra
.608 .132 0 r
.3156 .53712 .32169 .54425 .33183 .53407 .32449 .54855 Mtetra
0 0 0 r
.32449 .54855 .33183 .53407 .34138 .53449 .33531 .52791 Mtetra
.6 .704 .917 r
.33531 .52791 .34138 .53449 .35113 .53224 .34505 .52612 Mtetra
.626 .73 .922 r
.34505 .52612 .35113 .53224 .36093 .52986 .35487 .52369 Mtetra
.615 .725 .924 r
.35487 .52369 .36093 .52986 .37072 .52848 .36471 .5215 Mtetra
.072 .414 .864 r
.36471 .5215 .37072 .52848 .38098 .51733 .37428 .52644 Mtetra
.59 .819 .428 r
.37428 .52644 .38098 .51733 .39072 .51866 .38475 .5119 Mtetra
.6 .702 .915 r
.38475 .5119 .39072 .51866 .40067 .51625 .39469 .51009 Mtetra
.635 .735 .92 r
.39469 .51009 .40067 .51625 .41067 .5135 .40471 .50742 Mtetra
.64 .74 .921 r
.40471 .50742 .41067 .5135 .42071 .51071 .41478 .5046 Mtetra
.638 .739 .922 r
.41478 .5046 .42071 .51071 .43079 .50811 .42488 .50184 Mtetra
.615 .726 .925 r
.42488 .50184 .43079 .50811 .44086 .50726 .43501 .49959 Mtetra
.962 .658 .404 r
.43501 .49959 .44086 .50726 .45119 .49702 .44258 .60548 Mtetra
0 0 .234 r
.44258 .60548 .45119 .49702 .46134 .4963 .45551 .48968 Mtetra
.619 .717 .916 r
.45551 .48968 .46134 .4963 .47157 .49355 .46575 .48735 Mtetra
.644 .741 .92 r
.46575 .48735 .47157 .49355 .48185 .49049 .47605 .48438 Mtetra
.651 .747 .92 r
.47605 .48438 .48185 .49049 .49217 .4873 .4864 .48121 Mtetra
.654 .75 .92 r
.4864 .48121 .49217 .4873 .50253 .48403 .49678 .47795 Mtetra
.656 .752 .92 r
.49678 .47795 .50253 .48403 .51292 .48071 .50721 .47462 Mtetra
.658 .753 .92 r
.50721 .47462 .51292 .48071 .52336 .47734 .51767 .47124 Mtetra
.659 .754 .92 r
.51767 .47124 .52336 .47734 .53384 .47394 .52817 .46782 Mtetra
.52817 .46782 .53384 .47394 .54436 .47053 .53872 .46439 Mtetra
.53872 .46439 .54436 .47053 .55491 .46711 .5493 .46094 Mtetra
.5493 .46094 .55491 .46711 .56551 .46368 .55992 .45749 Mtetra
.658 .753 .92 r
.55992 .45749 .56551 .46368 .57614 .46025 .57059 .45403 Mtetra
.57059 .45403 .57614 .46025 .58682 .45681 .58129 .45056 Mtetra
.58129 .45056 .58682 .45681 .59754 .45336 .59204 .44709 Mtetra
.59204 .44709 .59754 .45336 .6083 .4499 .60283 .4436 Mtetra
.60283 .4436 .6083 .4499 .6191 .44643 .61365 .44011 Mtetra
.61365 .44011 .6191 .44643 .62994 .44295 .62453 .4366 Mtetra
.62453 .4366 .62994 .44295 .64083 .43946 .63544 .43309 Mtetra
.657 .753 .92 r
.63544 .43309 .64083 .43946 .65175 .43596 .64639 .42956 Mtetra
.64639 .42956 .65175 .43596 .66272 .43245 .65739 .42602 Mtetra
.65739 .42602 .66272 .43245 .67373 .42892 .66843 .42246 Mtetra
.66843 .42246 .67373 .42892 .68479 .42538 .67952 .4189 Mtetra
.657 .752 .92 r
.67952 .4189 .68479 .42538 .69589 .42183 .69064 .41532 Mtetra
.69064 .41532 .69589 .42183 .70703 .41827 .70182 .41173 Mtetra
.70182 .41173 .70703 .41827 .71821 .41469 .71303 .40813 Mtetra
.71303 .40813 .71821 .41469 .72944 .4111 .72429 .40451 Mtetra
.72429 .40451 .72944 .4111 .74071 .40749 .73559 .40088 Mtetra
.73559 .40088 .74071 .40749 .75203 .40388 .74694 .39724 Mtetra
.74694 .39724 .75203 .40388 .76339 .40025 .75834 .39358 Mtetra
.75834 .39358 .76339 .40025 .7748 .3966 .76978 .38991 Mtetra
.76978 .38991 .7748 .3966 .78625 .39294 .78126 .38622 Mtetra
.78126 .38622 .78625 .39294 .79775 .38927 .79279 .38252 Mtetra
.79279 .38252 .79775 .38927 .80929 .38558 .80437 .37881 Mtetra
.80437 .37881 .80929 .38558 .82088 .38188 .81599 .37508 Mtetra
.81599 .37508 .82088 .38188 .83252 .37817 .82766 .37134 Mtetra
.82766 .37134 .83252 .37817 .8442 .37444 .83938 .36758 Mtetra
.83938 .36758 .8442 .37444 .85593 .37069 .85114 .36381 Mtetra
.85114 .36381 .85593 .37069 .86771 .36694 .86295 .36002 Mtetra
.378 .605 .937 r
.23255 .55539 .23884 .56201 .24925 .54747 .24165 .55693 Mtetra
0 0 0 r
.24165 .55693 .24925 .54747 .25803 .55323 .2518 .54631 Mtetra
.567 .678 .914 r
.2518 .54631 .25803 .55323 .26747 .55146 .2612 .54526 Mtetra
.602 .716 .925 r
.2612 .54526 .26747 .55146 .2769 .5502 .27069 .54342 Mtetra
.258 .536 .92 r
.27069 .54342 .2769 .5502 .28715 .53813 .27989 .5463 Mtetra
.569 .839 .49 r
.27989 .5463 .28715 .53813 .29636 .54106 .29019 .53425 Mtetra
.582 .689 .915 r
.29019 .53425 .29636 .54106 .30597 .53905 .29977 .53287 Mtetra
.615 .723 .923 r
.29977 .53287 .30597 .53905 .3156 .53712 .30944 .53072 Mtetra
.556 .695 .933 r
.30944 .53072 .3156 .53712 .32449 .54855 .31908 .52973 Mtetra
.708 .568 .695 r
.31908 .52973 .32449 .54855 .33531 .52791 .3293 .51946 Mtetra
.506 .608 .889 r
.3293 .51946 .33531 .52791 .34505 .52612 .33894 .51984 Mtetra
.62 .724 .92 r
.33894 .51984 .34505 .52612 .35487 .52369 .34877 .51754 Mtetra
.625 .73 .923 r
.34877 .51754 .35487 .52369 .36471 .5215 .35864 .5151 Mtetra
.577 .706 .93 r
.35864 .5151 .36471 .5215 .37428 .52644 .36851 .51368 Mtetra
.76 .643 .732 r
.36851 .51368 .37428 .52644 .38475 .5119 .37886 .50244 Mtetra
.473 .566 .869 r
.37886 .50244 .38475 .5119 .39469 .51009 .38869 .50373 Mtetra
.625 .726 .919 r
.38869 .50373 .39469 .51009 .40471 .50742 .39872 .50127 Mtetra
.639 .738 .921 r
.39872 .50127 .40471 .50742 .41478 .5046 .4088 .49847 Mtetra
.64 .74 .921 r
.4088 .49847 .41478 .5046 .42488 .50184 .41893 .49562 Mtetra
.631 .735 .923 r
.41893 .49562 .42488 .50184 .43501 .49959 .42909 .49297 Mtetra
.548 .691 .933 r
.42909 .49297 .43501 .49959 .44258 .60548 .43925 .49208 Mtetra
.582 .378 .57 r
.43925 .49208 .44258 .60548 .45551 .48968 .44967 .48174 Mtetra
.556 .652 .899 r
.44967 .48174 .45551 .48968 .46575 .48735 .4599 .48098 Mtetra
.636 .734 .919 r
.4599 .48098 .46575 .48735 .47605 .48438 .47022 .47817 Mtetra
.648 .745 .92 r
.47022 .47817 .47605 .48438 .4864 .48121 .48059 .47506 Mtetra
.653 .749 .92 r
.48059 .47506 .4864 .48121 .49678 .47795 .491 .47181 Mtetra
.655 .751 .92 r
.491 .47181 .49678 .47795 .50721 .47462 .50145 .46848 Mtetra
.657 .752 .92 r
.50145 .46848 .50721 .47462 .51767 .47124 .51194 .46509 Mtetra
.658 .753 .92 r
.51194 .46509 .51767 .47124 .52817 .46782 .52247 .46166 Mtetra
.659 .754 .92 r
.52247 .46166 .52817 .46782 .53872 .46439 .53304 .45821 Mtetra
.53304 .45821 .53872 .46439 .5493 .46094 .54365 .45474 Mtetra
.54365 .45474 .5493 .46094 .55992 .45749 .5543 .45125 Mtetra
.5543 .45125 .55992 .45749 .57059 .45403 .56499 .44777 Mtetra
.658 .753 .92 r
.56499 .44777 .57059 .45403 .58129 .45056 .57572 .44427 Mtetra
.57572 .44427 .58129 .45056 .59204 .44709 .5865 .44077 Mtetra
.5865 .44077 .59204 .44709 .60283 .4436 .59731 .43726 Mtetra
.59731 .43726 .60283 .4436 .61365 .44011 .60817 .43374 Mtetra
.60817 .43374 .61365 .44011 .62453 .4366 .61907 .4302 Mtetra
.61907 .4302 .62453 .4366 .63544 .43309 .63001 .42666 Mtetra
.657 .753 .92 r
.63001 .42666 .63544 .43309 .64639 .42956 .641 .42311 Mtetra
.641 .42311 .64639 .42956 .65739 .42602 .65202 .41954 Mtetra
.65202 .41954 .65739 .42602 .66843 .42246 .66309 .41596 Mtetra
.66309 .41596 .66843 .42246 .67952 .4189 .67421 .41237 Mtetra
.657 .752 .92 r
.67421 .41237 .67952 .4189 .69064 .41532 .68536 .40877 Mtetra
.68536 .40877 .69064 .41532 .70182 .41173 .69657 .40515 Mtetra
.69657 .40515 .70182 .41173 .71303 .40813 .70781 .40152 Mtetra
.70781 .40152 .71303 .40813 .72429 .40451 .7191 .39788 Mtetra
.7191 .39788 .72429 .40451 .73559 .40088 .73044 .39422 Mtetra
.73044 .39422 .73559 .40088 .74694 .39724 .74182 .39055 Mtetra
.74182 .39055 .74694 .39724 .75834 .39358 .75324 .38686 Mtetra
.75324 .38686 .75834 .39358 .76978 .38991 .76472 .38316 Mtetra
.76472 .38316 .76978 .38991 .78126 .38622 .77623 .37945 Mtetra
.77623 .37945 .78126 .38622 .79279 .38252 .7878 .37572 Mtetra
.7878 .37572 .79279 .38252 .80437 .37881 .79941 .37198 Mtetra
.79941 .37198 .80437 .37881 .81599 .37508 .81106 .36823 Mtetra
.81106 .36823 .81599 .37508 .82766 .37134 .82276 .36445 Mtetra
.82276 .36445 .82766 .37134 .83938 .36758 .83452 .36067 Mtetra
.83452 .36067 .83938 .36758 .85114 .36381 .84631 .35687 Mtetra
.84631 .35687 .85114 .36381 .86295 .36002 .85816 .35305 Mtetra
.574 .702 .929 r
.22619 .5491 .23255 .55539 .24165 .55693 .23555 .54781 Mtetra
.819 .699 .732 r
.23555 .54781 .24165 .55693 .2518 .54631 .24605 .53317 Mtetra
.286 .377 .781 r
.24605 .53317 .2518 .54631 .2612 .54526 .25489 .5389 Mtetra
.6 .711 .922 r
.25489 .5389 .2612 .54526 .27069 .54342 .2644 .53709 Mtetra
.573 .703 .93 r
.2644 .53709 .27069 .54342 .27989 .5463 .27392 .53579 Mtetra
.787 .675 .741 r
.27392 .53579 .27989 .5463 .29019 .53425 .28425 .52362 Mtetra
.399 .497 .843 r
.28425 .52362 .29019 .53425 .29977 .53287 .29354 .52652 Mtetra
.61 .717 .921 r
.29354 .52652 .29977 .53287 .30944 .53072 .30322 .52447 Mtetra
.605 .719 .925 r
.30322 .52447 .30944 .53072 .31908 .52973 .31293 .52249 Mtetra
.601 .126 0 r
.31293 .52249 .31908 .52973 .3293 .51946 .32188 .53393 Mtetra
0 0 0 r
.32188 .53393 .3293 .51946 .33894 .51984 .3328 .51316 Mtetra
.6 .704 .917 r
.3328 .51316 .33894 .51984 .34877 .51754 .34262 .51132 Mtetra
.626 .73 .922 r
.34262 .51132 .34877 .51754 .35864 .5151 .35252 .50884 Mtetra
.615 .725 .924 r
.35252 .50884 .35864 .5151 .36851 .51368 .36245 .5066 Mtetra
.076 .417 .865 r
.36245 .5066 .36851 .51368 .37886 .50244 .37209 .51151 Mtetra
.6 .827 .439 r
.37209 .51151 .37886 .50244 .38869 .50373 .38266 .49687 Mtetra
.6 .702 .915 r
.38266 .49687 .38869 .50373 .39872 .50127 .39268 .49501 Mtetra
.635 .735 .92 r
.39268 .49501 .39872 .50127 .4088 .49847 .40278 .49228 Mtetra
.64 .74 .921 r
.40278 .49228 .4088 .49847 .41893 .49562 .41293 .48941 Mtetra
.638 .739 .922 r
.41293 .48941 .41893 .49562 .42909 .49297 .42312 .48659 Mtetra
.615 .726 .925 r
.42312 .48659 .42909 .49297 .43925 .49208 .43334 .48428 Mtetra
.963 .657 .4 r
.43334 .48428 .43925 .49208 .44967 .48174 .44092 .59062 Mtetra
0 0 .228 r
.44092 .59062 .44967 .48174 .4599 .48098 .45402 .47424 Mtetra
.618 .717 .916 r
.45402 .47424 .4599 .48098 .47022 .47817 .46435 .47186 Mtetra
.644 .741 .92 r
.46435 .47186 .47022 .47817 .48059 .47506 .47474 .46883 Mtetra
.651 .747 .92 r
.47474 .46883 .48059 .47506 .491 .47181 .48517 .46561 Mtetra
.654 .75 .92 r
.48517 .46561 .491 .47181 .50145 .46848 .49565 .46229 Mtetra
.656 .752 .92 r
.49565 .46229 .50145 .46848 .51194 .46509 .50617 .4589 Mtetra
.658 .753 .92 r
.50617 .4589 .51194 .46509 .52247 .46166 .51672 .45546 Mtetra
.659 .754 .92 r
.51672 .45546 .52247 .46166 .53304 .45821 .52732 .45198 Mtetra
.52732 .45198 .53304 .45821 .54365 .45474 .53796 .44848 Mtetra
.53796 .44848 .54365 .45474 .5543 .45125 .54863 .44498 Mtetra
.54863 .44498 .5543 .45125 .56499 .44777 .55935 .44146 Mtetra
.658 .753 .92 r
.55935 .44146 .56499 .44777 .57572 .44427 .57011 .43794 Mtetra
.57011 .43794 .57572 .44427 .5865 .44077 .58092 .43441 Mtetra
.58092 .43441 .5865 .44077 .59731 .43726 .59176 .43087 Mtetra
.59176 .43087 .59731 .43726 .60817 .43374 .60264 .42732 Mtetra
.60264 .42732 .60817 .43374 .61907 .4302 .61357 .42376 Mtetra
.61357 .42376 .61907 .4302 .63001 .42666 .62454 .42019 Mtetra
.62454 .42019 .63001 .42666 .641 .42311 .63556 .41661 Mtetra
.657 .753 .92 r
.63556 .41661 .641 .42311 .65202 .41954 .64661 .41302 Mtetra
.64661 .41302 .65202 .41954 .66309 .41596 .65771 .40941 Mtetra
.65771 .40941 .66309 .41596 .67421 .41237 .66886 .4058 Mtetra
.66886 .4058 .67421 .41237 .68536 .40877 .68005 .40216 Mtetra
.657 .752 .92 r
.68005 .40216 .68536 .40877 .69657 .40515 .69128 .39852 Mtetra
.69128 .39852 .69657 .40515 .70781 .40152 .70256 .39486 Mtetra
.70256 .39486 .70781 .40152 .7191 .39788 .71388 .39119 Mtetra
.71388 .39119 .7191 .39788 .73044 .39422 .72524 .38751 Mtetra
.72524 .38751 .73044 .39422 .74182 .39055 .73666 .38381 Mtetra
.73666 .38381 .74182 .39055 .75324 .38686 .74811 .3801 Mtetra
.74811 .3801 .75324 .38686 .76472 .38316 .75962 .37637 Mtetra
.75962 .37637 .76472 .38316 .77623 .37945 .77117 .37263 Mtetra
.77117 .37263 .77623 .37945 .7878 .37572 .78276 .36887 Mtetra
.78276 .36887 .7878 .37572 .79941 .37198 .79441 .3651 Mtetra
.79441 .3651 .79941 .37198 .81106 .36823 .8061 .36132 Mtetra
.8061 .36132 .81106 .36823 .82276 .36445 .81783 .35752 Mtetra
.81783 .35752 .82276 .36445 .83452 .36067 .82962 .35371 Mtetra
.82962 .35371 .83452 .36067 .84631 .35687 .84145 .34988 Mtetra
.84145 .34988 .84631 .35687 .85816 .35305 .85333 .34603 Mtetra
.593 .709 .924 r
.21979 .54276 .22619 .5491 .23555 .54781 .22919 .54109 Mtetra
.38 .606 .937 r
.22919 .54109 .23555 .54781 .24605 .53317 .23837 .54259 Mtetra
0 0 0 r
.23837 .54259 .24605 .53317 .25489 .5389 .2486 .53188 Mtetra
.567 .678 .914 r
.2486 .53188 .25489 .5389 .2644 .53709 .25807 .5308 Mtetra
.602 .716 .925 r
.25807 .5308 .2644 .53709 .27392 .53579 .26764 .52891 Mtetra
.26 .537 .92 r
.26764 .52891 .27392 .53579 .28425 .52362 .2769 .53176 Mtetra
.581 .848 .501 r
.2769 .53176 .28425 .52362 .29354 .52652 .2873 .51961 Mtetra
.582 .689 .915 r
.2873 .51961 .29354 .52652 .30322 .52447 .29695 .51819 Mtetra
.615 .723 .923 r
.29695 .51819 .30322 .52447 .31293 .52249 .3067 .51599 Mtetra
.556 .695 .932 r
.3067 .51599 .31293 .52249 .32188 .53393 .31642 .51495 Mtetra
.708 .568 .694 r
.31642 .51495 .32188 .53393 .3328 .51316 .32674 .5046 Mtetra
.506 .608 .889 r
.32674 .5046 .3328 .51316 .34262 .51132 .33645 .50494 Mtetra
.62 .724 .92 r
.33645 .50494 .34262 .51132 .35252 .50884 .34636 .50258 Mtetra
.625 .73 .923 r
.34636 .50258 .35252 .50884 .36245 .5066 .35632 .50009 Mtetra
.577 .706 .93 r
.35632 .50009 .36245 .5066 .37209 .51151 .36627 .49862 Mtetra
.76 .643 .732 r
.36627 .49862 .37209 .51151 .38266 .49687 .37671 .48729 Mtetra
.472 .566 .869 r
.37671 .48729 .38266 .49687 .39268 .49501 .38661 .48854 Mtetra
.625 .726 .919 r
.38661 .48854 .39268 .49501 .40278 .49228 .39673 .48603 Mtetra
.639 .738 .921 r
.39673 .48603 .40278 .49228 .41293 .48941 .4069 .48317 Mtetra
.64 .74 .921 r
.4069 .48317 .41293 .48941 .42312 .48659 .41711 .48027 Mtetra
.631 .735 .923 r
.41711 .48027 .42312 .48659 .43334 .48428 .42736 .47756 Mtetra
.548 .691 .933 r
.42736 .47756 .43334 .48428 .44092 .59062 .4376 .47662 Mtetra
.58 .376 .568 r
.4376 .47662 .44092 .59062 .45402 .47424 .44812 .4662 Mtetra
.555 .652 .899 r
.44812 .4662 .45402 .47424 .46435 .47186 .45844 .46538 Mtetra
.636 .734 .919 r
.45844 .46538 .46435 .47186 .47474 .46883 .46885 .46252 Mtetra
.648 .745 .92 r
.46885 .46252 .47474 .46883 .48517 .46561 .47931 .45935 Mtetra
.653 .749 .92 r
.47931 .45935 .48517 .46561 .49565 .46229 .48981 .45604 Mtetra
.655 .751 .92 r
.48981 .45604 .49565 .46229 .50617 .4589 .50035 .45265 Mtetra
.657 .752 .92 r
.50035 .45265 .50617 .4589 .51672 .45546 .51093 .4492 Mtetra
.658 .753 .92 r
.51093 .4492 .51672 .45546 .52732 .45198 .52156 .44571 Mtetra
.659 .754 .92 r
.52156 .44571 .52732 .45198 .53796 .44848 .53222 .44219 Mtetra
.53222 .44219 .53796 .44848 .54863 .44498 .54293 .43865 Mtetra
.54293 .43865 .54863 .44498 .55935 .44146 .55368 .43511 Mtetra
.55368 .43511 .55935 .44146 .57011 .43794 .56446 .43156 Mtetra
.658 .753 .92 r
.56446 .43156 .57011 .43794 .58092 .43441 .57529 .428 Mtetra
.57529 .428 .58092 .43441 .59176 .43087 .58617 .42443 Mtetra
.58617 .42443 .59176 .43087 .60264 .42732 .59708 .42086 Mtetra
.59708 .42086 .60264 .42732 .61357 .42376 .60804 .41727 Mtetra
.60804 .41727 .61357 .42376 .62454 .42019 .61904 .41368 Mtetra
.61904 .41368 .62454 .42019 .63556 .41661 .63008 .41007 Mtetra
.657 .753 .92 r
.63008 .41007 .63556 .41661 .64661 .41302 .64117 .40645 Mtetra
.64117 .40645 .64661 .41302 .65771 .40941 .6523 .40282 Mtetra
.6523 .40282 .65771 .40941 .66886 .4058 .66347 .39917 Mtetra
.66347 .39917 .66886 .4058 .68005 .40216 .67469 .39551 Mtetra
.657 .752 .92 r
.67469 .39551 .68005 .40216 .69128 .39852 .68595 .39184 Mtetra
.68595 .39184 .69128 .39852 .70256 .39486 .69726 .38816 Mtetra
.69726 .38816 .70256 .39486 .71388 .39119 .70861 .38446 Mtetra
.70861 .38446 .71388 .39119 .72524 .38751 .72001 .38075 Mtetra
.72001 .38075 .72524 .38751 .73666 .38381 .73146 .37702 Mtetra
.73146 .37702 .73666 .38381 .74811 .3801 .74295 .37328 Mtetra
.74295 .37328 .74811 .3801 .75962 .37637 .75448 .36953 Mtetra
.75448 .36953 .75962 .37637 .77117 .37263 .76606 .36576 Mtetra
.76606 .36576 .77117 .37263 .78276 .36887 .77769 .36197 Mtetra
.77769 .36197 .78276 .36887 .79441 .3651 .78937 .35818 Mtetra
.78937 .35818 .79441 .3651 .8061 .36132 .80109 .35436 Mtetra
.80109 .35436 .8061 .36132 .81783 .35752 .81286 .35054 Mtetra
.81286 .35054 .81783 .35752 .82962 .35371 .82468 .34669 Mtetra
.82468 .34669 .82962 .35371 .84145 .34988 .83655 .34283 Mtetra
.83655 .34283 .84145 .34988 .85333 .34603 .84847 .33896 Mtetra
.575 .689 .919 r
.21339 .53598 .21979 .54276 .22919 .54109 .22277 .53469 Mtetra
.574 .702 .929 r
.22277 .53469 .22919 .54109 .23837 .54259 .2322 .53335 Mtetra
.819 .699 .732 r
.2322 .53335 .23837 .54259 .2486 .53188 .2428 .51861 Mtetra
.284 .375 .781 r
.2428 .51861 .2486 .53188 .25807 .5308 .2517 .52433 Mtetra
.6 .711 .922 r
.2517 .52433 .25807 .5308 .26764 .52891 .26129 .52247 Mtetra
.573 .703 .93 r
.26129 .52247 .26764 .52891 .2769 .53176 .27088 .52112 Mtetra
.788 .676 .741 r
.27088 .52112 .2769 .53176 .2873 .51961 .28131 .50886 Mtetra
.398 .496 .843 r
.28131 .50886 .2873 .51961 .29695 .51819 .29066 .51173 Mtetra
.61 .717 .921 r
.29066 .51173 .29695 .51819 .3067 .51599 .30042 .50963 Mtetra
.605 .719 .925 r
.30042 .50963 .3067 .51599 .31642 .51495 .31021 .5076 Mtetra
.593 .119 0 r
.31021 .5076 .31642 .51495 .32674 .5046 .31922 .51905 Mtetra
0 0 0 r
.31922 .51905 .32674 .5046 .33645 .50494 .33025 .49815 Mtetra
.6 .704 .917 r
.33025 .49815 .33645 .50494 .34636 .50258 .34015 .49625 Mtetra
.626 .73 .922 r
.34015 .49625 .34636 .50258 .35632 .50009 .35013 .49372 Mtetra
.615 .725 .924 r
.35013 .49372 .35632 .50009 .36627 .49862 .36014 .49143 Mtetra
.081 .419 .866 r
.36014 .49143 .36627 .49862 .37671 .48729 .36986 .49632 Mtetra
.611 .835 .449 r
.36986 .49632 .37671 .48729 .38661 .48854 .38052 .48157 Mtetra
.6 .702 .915 r
.38052 .48157 .38661 .48854 .39673 .48603 .39063 .47966 Mtetra
.635 .735 .92 r
.39063 .47966 .39673 .48603 .4069 .48317 .40082 .47688 Mtetra
.64 .74 .921 r
.40082 .47688 .4069 .48317 .41711 .48027 .41106 .47395 Mtetra
.638 .739 .922 r
.41106 .47395 .41711 .48027 .42736 .47756 .42133 .47107 Mtetra
.615 .726 .925 r
.42133 .47107 .42736 .47756 .4376 .47662 .43164 .46871 Mtetra
.963 .656 .396 r
.43164 .46871 .4376 .47662 .44812 .4662 .43923 .57548 Mtetra
0 0 .222 r
.43923 .57548 .44812 .4662 .45844 .46538 .4525 .45853 Mtetra
.618 .717 .917 r
.4525 .45853 .45844 .46538 .46885 .46252 .46292 .4561 Mtetra
.644 .741 .92 r
.46292 .4561 .46885 .46252 .47931 .45935 .4734 .45301 Mtetra
.651 .747 .92 r
.4734 .45301 .47931 .45935 .48981 .45604 .48393 .44972 Mtetra
.654 .75 .92 r
.48393 .44972 .48981 .45604 .50035 .45265 .4945 .44634 Mtetra
.656 .752 .92 r
.4945 .44634 .50035 .45265 .51093 .4492 .50511 .44289 Mtetra
.658 .753 .92 r
.50511 .44289 .51093 .4492 .52156 .44571 .51576 .43939 Mtetra
.659 .754 .92 r
.51576 .43939 .52156 .44571 .53222 .44219 .52645 .43585 Mtetra
.52645 .43585 .53222 .44219 .54293 .43865 .53718 .43229 Mtetra
.53718 .43229 .54293 .43865 .55368 .43511 .54796 .42872 Mtetra
.54796 .42872 .55368 .43511 .56446 .43156 .55877 .42514 Mtetra
.658 .753 .92 r
.55877 .42514 .56446 .43156 .57529 .428 .56963 .42155 Mtetra
.56963 .42155 .57529 .428 .58617 .42443 .58053 .41795 Mtetra
.58053 .41795 .58617 .42443 .59708 .42086 .59147 .41435 Mtetra
.59147 .41435 .59708 .42086 .60804 .41727 .60246 .41074 Mtetra
.60246 .41074 .60804 .41727 .61904 .41368 .61349 .40711 Mtetra
.61349 .40711 .61904 .41368 .63008 .41007 .62456 .40348 Mtetra
.62456 .40348 .63008 .41007 .64117 .40645 .63568 .39983 Mtetra
.657 .753 .92 r
.63568 .39983 .64117 .40645 .6523 .40282 .64684 .39617 Mtetra
.64684 .39617 .6523 .40282 .66347 .39917 .65804 .3925 Mtetra
.65804 .3925 .66347 .39917 .67469 .39551 .66929 .38881 Mtetra
.66929 .38881 .67469 .39551 .68595 .39184 .68059 .38512 Mtetra
.657 .752 .92 r
.68059 .38512 .68595 .39184 .69726 .38816 .69193 .3814 Mtetra
.69193 .3814 .69726 .38816 .70861 .38446 .70331 .37768 Mtetra
.70331 .37768 .70861 .38446 .72001 .38075 .71474 .37394 Mtetra
.71474 .37394 .72001 .38075 .73146 .37702 .72622 .37018 Mtetra
.72622 .37018 .73146 .37702 .74295 .37328 .73774 .36641 Mtetra
.73774 .36641 .74295 .37328 .75448 .36953 .74931 .36263 Mtetra
.74931 .36263 .75448 .36953 .76606 .36576 .76092 .35883 Mtetra
.76092 .35883 .76606 .36576 .77769 .36197 .77259 .35502 Mtetra
.77259 .35502 .77769 .36197 .78937 .35818 .7843 .3512 Mtetra
.7843 .3512 .78937 .35818 .80109 .35436 .79605 .34735 Mtetra
.79605 .34735 .80109 .35436 .81286 .35054 .80786 .3435 Mtetra
.80786 .3435 .81286 .35054 .82468 .34669 .81971 .33962 Mtetra
.81971 .33962 .82468 .34669 .83655 .34283 .83161 .33574 Mtetra
.83161 .33574 .83655 .34283 .84847 .33896 .84357 .33183 Mtetra
.434 .546 .87 r
.2072 .52649 .21339 .53598 .22277 .53469 .2163 .52825 Mtetra
.593 .709 .924 r
.2163 .52825 .22277 .53469 .2322 .53335 .22578 .52653 Mtetra
.381 .606 .937 r
.22578 .52653 .2322 .53335 .2428 .51861 .23502 .528 Mtetra
0 0 0 r
.23502 .528 .2428 .51861 .2517 .52433 .24535 .51721 Mtetra
.567 .678 .914 r
.24535 .51721 .2517 .52433 .26129 .52247 .25489 .51607 Mtetra
.602 .716 .925 r
.25489 .51607 .26129 .52247 .27088 .52112 .26454 .51414 Mtetra
.262 .538 .92 r
.26454 .51414 .27088 .52112 .28131 .50886 .27387 .51696 Mtetra
.592 .857 .513 r
.27387 .51696 .28131 .50886 .29066 .51173 .28436 .50472 Mtetra
.581 .689 .915 r
.28436 .50472 .29066 .51173 .30042 .50963 .29409 .50325 Mtetra
.615 .723 .923 r
.29409 .50325 .30042 .50963 .31021 .5076 .30392 .50099 Mtetra
.556 .695 .932 r
.30392 .50099 .31021 .5076 .31922 .51905 .31371 .49991 Mtetra
.708 .567 .694 r
.31371 .49991 .31922 .51905 .33025 .49815 .32412 .48947 Mtetra
.506 .608 .889 r
.32412 .48947 .33025 .49815 .34015 .49625 .33391 .48977 Mtetra
.62 .724 .92 r
.33391 .48977 .34015 .49625 .35013 .49372 .3439 .48736 Mtetra
.625 .73 .923 r
.3439 .48736 .35013 .49372 .36014 .49143 .35395 .48481 Mtetra
.577 .706 .93 r
.35395 .48481 .36014 .49143 .36986 .49632 .36398 .48329 Mtetra
.761 .644 .732 r
.36398 .48329 .36986 .49632 .38052 .48157 .37452 .47187 Mtetra
.472 .566 .87 r
.37452 .47187 .38052 .48157 .39063 .47966 .3845 .47308 Mtetra
.625 .726 .919 r
.3845 .47308 .39063 .47966 .40082 .47688 .3947 .47051 Mtetra
.639 .738 .921 r
.3947 .47051 .40082 .47688 .41106 .47395 .40496 .4676 Mtetra
.64 .74 .921 r
.40496 .4676 .41106 .47395 .42133 .47107 .41526 .46464 Mtetra
.631 .735 .923 r
.41526 .46464 .42133 .47107 .43164 .46871 .4256 .46187 Mtetra
.548 .691 .933 r
.4256 .46187 .43164 .46871 .43923 .57548 .43593 .46088 Mtetra
.579 .373 .566 r
.43593 .46088 .43923 .57548 .4525 .45853 .44655 .45037 Mtetra
.555 .652 .899 r
.44655 .45037 .4525 .45853 .46292 .4561 .45695 .4495 Mtetra
.636 .734 .919 r
.45695 .4495 .46292 .4561 .4734 .45301 .46746 .44658 Mtetra
.648 .745 .92 r
.46746 .44658 .4734 .45301 .48393 .44972 .47801 .44335 Mtetra
.653 .749 .92 r
.47801 .44335 .48393 .44972 .4945 .44634 .4886 .43998 Mtetra
.655 .751 .92 r
.4886 .43998 .4945 .44634 .50511 .44289 .49924 .43652 Mtetra
.657 .752 .92 r
.49924 .43652 .50511 .44289 .51576 .43939 .50991 .43301 Mtetra
.658 .753 .92 r
.50991 .43301 .51576 .43939 .52645 .43585 .52063 .42946 Mtetra
.659 .754 .92 r
.52063 .42946 .52645 .43585 .53718 .43229 .53139 .42588 Mtetra
.53139 .42588 .53718 .43229 .54796 .42872 .5422 .42228 Mtetra
.5422 .42228 .54796 .42872 .55877 .42514 .55304 .41867 Mtetra
.55304 .41867 .55877 .42514 .56963 .42155 .56393 .41505 Mtetra
.658 .753 .92 r
.56393 .41505 .56963 .42155 .58053 .41795 .57486 .41143 Mtetra
.57486 .41143 .58053 .41795 .59147 .41435 .58583 .4078 Mtetra
.58583 .4078 .59147 .41435 .60246 .41074 .59684 .40416 Mtetra
.59684 .40416 .60246 .41074 .61349 .40711 .6079 .4005 Mtetra
.6079 .4005 .61349 .40711 .62456 .40348 .619 .39684 Mtetra
.619 .39684 .62456 .40348 .63568 .39983 .63015 .39317 Mtetra
.657 .753 .92 r
.63015 .39317 .63568 .39983 .64684 .39617 .64134 .38948 Mtetra
.64134 .38948 .64684 .39617 .65804 .3925 .65258 .38578 Mtetra
.65258 .38578 .65804 .3925 .66929 .38881 .66386 .38207 Mtetra
.66386 .38207 .66929 .38881 .68059 .38512 .67518 .37834 Mtetra
.657 .752 .92 r
.67518 .37834 .68059 .38512 .69193 .3814 .68655 .3746 Mtetra
.68655 .3746 .69193 .3814 .70331 .37768 .69797 .37084 Mtetra
.69797 .37084 .70331 .37768 .71474 .37394 .70943 .36708 Mtetra
.70943 .36708 .71474 .37394 .72622 .37018 .72094 .36329 Mtetra
.72094 .36329 .72622 .37018 .73774 .36641 .73249 .3595 Mtetra
.73249 .3595 .73774 .36641 .74931 .36263 .74409 .35569 Mtetra
.74409 .35569 .74931 .36263 .76092 .35883 .75574 .35186 Mtetra
.75574 .35186 .76092 .35883 .77259 .35502 .76744 .34802 Mtetra
.76744 .34802 .77259 .35502 .7843 .3512 .77918 .34416 Mtetra
.77918 .34416 .7843 .3512 .79605 .34735 .79097 .34029 Mtetra
.79097 .34029 .79605 .34735 .80786 .3435 .80281 .33641 Mtetra
.80281 .33641 .80786 .3435 .81971 .33962 .8147 .3325 Mtetra
.8147 .3325 .81971 .33962 .83161 .33574 .82664 .32859 Mtetra
.82664 .32859 .83161 .33574 .84357 .33183 .83863 .32465 Mtetra
.704 .911 .561 r
.1992 .53535 .2072 .52649 .2163 .52825 .20984 .52137 Mtetra
.575 .689 .919 r
.20984 .52137 .2163 .52825 .22578 .52653 .21929 .52003 Mtetra
.574 .702 .929 r
.21929 .52003 .22578 .52653 .23502 .528 .22879 .51865 Mtetra
.82 .7 .732 r
.22879 .51865 .23502 .528 .24535 .51721 .23949 .5038 Mtetra
.282 .374 .781 r
.23949 .5038 .24535 .51721 .25489 .51607 .24846 .50951 Mtetra
.6 .711 .922 r
.24846 .50951 .25489 .51607 .26454 .51414 .25812 .50759 Mtetra
.573 .703 .93 r
.25812 .50759 .26454 .51414 .27387 .51696 .26778 .5062 Mtetra
.788 .677 .741 r
.26778 .5062 .27387 .51696 .28436 .50472 .27831 .49385 Mtetra
.397 .496 .843 r
.27831 .49385 .28436 .50472 .29409 .50325 .28773 .49669 Mtetra
.61 .717 .921 r
.28773 .49669 .29409 .50325 .30392 .50099 .29757 .49453 Mtetra
.605 .719 .925 r
.29757 .49453 .30392 .50099 .31371 .49991 .30745 .49245 Mtetra
.586 .113 0 r
.30745 .49245 .31371 .49991 .32412 .48947 .31652 .5039 Mtetra
0 0 0 r
.31652 .5039 .32412 .48947 .33391 .48977 .32765 .48287 Mtetra
.6 .704 .917 r
.32765 .48287 .33391 .48977 .3439 .48736 .33764 .48092 Mtetra
.626 .73 .922 r
.33764 .48092 .3439 .48736 .35395 .48481 .3477 .47833 Mtetra
.615 .725 .924 r
.3477 .47833 .35395 .48481 .36398 .48329 .3578 .47599 Mtetra
.085 .421 .867 r
.3578 .47599 .36398 .48329 .37452 .47187 .36759 .48086 Mtetra
.62 .843 .459 r
.36759 .48086 .37452 .47187 .3845 .47308 .37835 .466 Mtetra
.599 .702 .915 r
.37835 .466 .3845 .47308 .3947 .47051 .38855 .46403 Mtetra
.635 .735 .92 r
.38855 .46403 .3947 .47051 .40496 .4676 .39882 .46119 Mtetra
.64 .74 .921 r
.39882 .46119 .40496 .4676 .41526 .46464 .40915 .4582 Mtetra
.638 .739 .922 r
.40915 .4582 .41526 .46464 .4256 .46187 .41951 .45527 Mtetra
.615 .726 .925 r
.41951 .45527 .4256 .46187 .43593 .46088 .4299 .45285 Mtetra
.964 .656 .391 r
.4299 .45285 .43593 .46088 .44655 .45037 .43751 .56006 Mtetra
0 0 .215 r
.43751 .56006 .44655 .45037 .45695 .4495 .45095 .44254 Mtetra
.618 .717 .917 r
.45095 .44254 .45695 .4495 .46746 .44658 .46147 .44004 Mtetra
.644 .741 .92 r
.46147 .44004 .46746 .44658 .47801 .44335 .47204 .43689 Mtetra
.651 .747 .92 r
.47204 .43689 .47801 .44335 .4886 .43998 .48266 .43355 Mtetra
.654 .75 .92 r
.48266 .43355 .4886 .43998 .49924 .43652 .49332 .4301 Mtetra
.656 .752 .92 r
.49332 .4301 .49924 .43652 .50991 .43301 .50403 .42659 Mtetra
.658 .753 .92 r
.50403 .42659 .50991 .43301 .52063 .42946 .51477 .42302 Mtetra
.659 .754 .92 r
.51477 .42302 .52063 .42946 .53139 .42588 .52556 .41942 Mtetra
.52556 .41942 .53139 .42588 .5422 .42228 .53639 .41579 Mtetra
.53639 .41579 .5422 .42228 .55304 .41867 .54727 .41215 Mtetra
.54727 .41215 .55304 .41867 .56393 .41505 .55818 .40851 Mtetra
.658 .753 .92 r
.55818 .40851 .56393 .41505 .57486 .41143 .56914 .40486 Mtetra
.56914 .40486 .57486 .41143 .58583 .4078 .58014 .4012 Mtetra
.58014 .4012 .58583 .4078 .59684 .40416 .59118 .39753 Mtetra
.59118 .39753 .59684 .40416 .6079 .4005 .60227 .39385 Mtetra
.60227 .39385 .6079 .4005 .619 .39684 .6134 .39015 Mtetra
.6134 .39015 .619 .39684 .63015 .39317 .62458 .38645 Mtetra
.62458 .38645 .63015 .39317 .64134 .38948 .6358 .38274 Mtetra
.657 .753 .92 r
.6358 .38274 .64134 .38948 .65258 .38578 .64707 .37901 Mtetra
.64707 .37901 .65258 .38578 .66386 .38207 .65838 .37527 Mtetra
.65838 .37527 .66386 .38207 .67518 .37834 .66973 .37151 Mtetra
.66973 .37151 .67518 .37834 .68655 .3746 .68114 .36774 Mtetra
.657 .752 .92 r
.68114 .36774 .68655 .3746 .69797 .37084 .69258 .36396 Mtetra
.69258 .36396 .69797 .37084 .70943 .36708 .70408 .36016 Mtetra
.70408 .36016 .70943 .36708 .72094 .36329 .71562 .35635 Mtetra
.71562 .35635 .72094 .36329 .73249 .3595 .72721 .35253 Mtetra
.72721 .35253 .73249 .3595 .74409 .35569 .73884 .34869 Mtetra
.73884 .34869 .74409 .35569 .75574 .35186 .75052 .34483 Mtetra
.75052 .34483 .75574 .35186 .76744 .34802 .76225 .34096 Mtetra
.76225 .34096 .76744 .34802 .77918 .34416 .77403 .33708 Mtetra
.77403 .33708 .77918 .34416 .79097 .34029 .78586 .33318 Mtetra
.78586 .33318 .79097 .34029 .80281 .33641 .79773 .32926 Mtetra
.79773 .32926 .80281 .33641 .8147 .3325 .80965 .32533 Mtetra
.80965 .32533 .8147 .3325 .82664 .32859 .82163 .32138 Mtetra
.82163 .32138 .82664 .32859 .83863 .32465 .83365 .31742 Mtetra
.757 .641 .733 r
.19322 .52271 .1992 .53535 .20984 .52137 .20358 .51176 Mtetra
.433 .545 .871 r
.20358 .51176 .20984 .52137 .21929 .52003 .21275 .51349 Mtetra
.593 .709 .924 r
.21275 .51349 .21929 .52003 .22879 .51865 .2223 .51172 Mtetra
.382 .606 .937 r
.2223 .51172 .22879 .51865 .23949 .5038 .23162 .51316 Mtetra
0 0 0 r
.23162 .51316 .23949 .5038 .24846 .50951 .24204 .50227 Mtetra
.567 .678 .914 r
.24204 .50227 .24846 .50951 .25812 .50759 .25165 .50109 Mtetra
.602 .716 .925 r
.25165 .50109 .25812 .50759 .26778 .5062 .26138 .4991 Mtetra
.264 .538 .92 r
.26138 .4991 .26778 .5062 .27831 .49385 .27078 .5019 Mtetra
.603 .865 .524 r
.27078 .5019 .27831 .49385 .28773 .49669 .28137 .48956 Mtetra
.581 .689 .916 r
.28137 .48956 .28773 .49669 .29757 .49453 .29118 .48804 Mtetra
.615 .723 .923 r
.29118 .48804 .29757 .49453 .30745 .49245 .30109 .48573 Mtetra
.556 .695 .932 r
.30109 .48573 .30745 .49245 .31652 .5039 .31096 .4846 Mtetra
.708 .567 .694 r
.31096 .4846 .31652 .5039 .32765 .48287 .32147 .47407 Mtetra
.505 .608 .889 r
.32147 .47407 .32765 .48287 .33764 .48092 .33133 .47433 Mtetra
.62 .724 .92 r
.33133 .47433 .33764 .48092 .3477 .47833 .34141 .47186 Mtetra
.625 .73 .923 r
.34141 .47186 .3477 .47833 .3578 .47599 .35154 .46926 Mtetra
.577 .706 .93 r
.35154 .46926 .3578 .47599 .36759 .48086 .36166 .46769 Mtetra
.761 .644 .732 r
.36166 .46769 .36759 .48086 .37835 .466 .37229 .45617 Mtetra
.471 .566 .87 r
.37229 .45617 .37835 .466 .38855 .46403 .38236 .45734 Mtetra
.625 .726 .919 r
.38236 .45734 .38855 .46403 .39882 .46119 .39264 .45471 Mtetra
.639 .738 .921 r
.39264 .45471 .39882 .46119 .40915 .4582 .40299 .45174 Mtetra
.64 .74 .921 r
.40299 .45174 .40915 .4582 .41951 .45527 .41338 .44872 Mtetra
.631 .735 .923 r
.41338 .44872 .41951 .45527 .4299 .45285 .42381 .4459 Mtetra
.549 .69 .933 r
.42381 .4459 .4299 .45285 .43751 .56006 .43423 .44485 Mtetra
.577 .37 .564 r
.43423 .44485 .43751 .56006 .45095 .44254 .44494 .43425 Mtetra
.555 .652 .899 r
.44494 .43425 .45095 .44254 .46147 .44004 .45544 .43333 Mtetra
.636 .734 .919 r
.45544 .43333 .46147 .44004 .47204 .43689 .46603 .43035 Mtetra
.648 .745 .92 r
.46603 .43035 .47204 .43689 .48266 .43355 .47668 .42705 Mtetra
.653 .749 .92 r
.47668 .42705 .48266 .43355 .49332 .4301 .48737 .42362 Mtetra
.655 .751 .92 r
.48737 .42362 .49332 .4301 .50403 .42659 .4981 .4201 Mtetra
.657 .752 .92 r
.4981 .4201 .50403 .42659 .51477 .42302 .50887 .41653 Mtetra
.658 .753 .92 r
.50887 .41653 .51477 .42302 .52556 .41942 .51969 .41291 Mtetra
.659 .754 .92 r
.51969 .41291 .52556 .41942 .53639 .41579 .53055 .40926 Mtetra
.53055 .40926 .53639 .41579 .54727 .41215 .54145 .4056 Mtetra
.54145 .4056 .54727 .41215 .55818 .40851 .55239 .40192 Mtetra
.55239 .40192 .55818 .40851 .56914 .40486 .56338 .39824 Mtetra
.658 .753 .92 r
.56338 .39824 .56914 .40486 .58014 .4012 .57441 .39455 Mtetra
.57441 .39455 .58014 .4012 .59118 .39753 .58548 .39085 Mtetra
.58548 .39085 .59118 .39753 .60227 .39385 .5966 .38714 Mtetra
.5966 .38714 .60227 .39385 .6134 .39015 .60776 .38342 Mtetra
.60776 .38342 .6134 .39015 .62458 .38645 .61897 .37969 Mtetra
.61897 .37969 .62458 .38645 .6358 .38274 .63022 .37594 Mtetra
.657 .753 .92 r
.63022 .37594 .6358 .38274 .64707 .37901 .64152 .37219 Mtetra
.64152 .37219 .64707 .37901 .65838 .37527 .65286 .36842 Mtetra
.65286 .36842 .65838 .37527 .66973 .37151 .66425 .36463 Mtetra
.66425 .36463 .66973 .37151 .68114 .36774 .67568 .36084 Mtetra
.657 .752 .92 r
.67568 .36084 .68114 .36774 .69258 .36396 .68716 .35703 Mtetra
.68716 .35703 .69258 .36396 .70408 .36016 .69869 .3532 Mtetra
.69869 .3532 .70408 .36016 .71562 .35635 .71026 .34936 Mtetra
.71026 .34936 .71562 .35635 .72721 .35253 .72188 .3455 Mtetra
.72188 .3455 .72721 .35253 .73884 .34869 .73355 .34164 Mtetra
.73355 .34164 .73884 .34869 .75052 .34483 .74526 .33775 Mtetra
.74526 .33775 .75052 .34483 .76225 .34096 .75703 .33385 Mtetra
.75703 .33385 .76225 .34096 .77403 .33708 .76884 .32994 Mtetra
.76884 .32994 .77403 .33708 .78586 .33318 .7807 .32601 Mtetra
.7807 .32601 .78586 .33318 .79773 .32926 .79261 .32206 Mtetra
.79261 .32206 .79773 .32926 .80965 .32533 .80457 .3181 Mtetra
.80457 .3181 .80965 .32533 .82163 .32138 .81658 .31412 Mtetra
.81658 .31412 .82163 .32138 .83365 .31742 .82863 .31013 Mtetra
0 .359 .829 r
.18667 .51552 .19322 .52271 .20358 .51176 .19548 .52058 Mtetra
.712 .917 .57 r
.19548 .52058 .20358 .51176 .21275 .51349 .20622 .5065 Mtetra
.575 .689 .919 r
.20622 .5065 .21275 .51349 .2223 .51172 .21574 .50512 Mtetra
.574 .702 .929 r
.21574 .50512 .2223 .51172 .23162 .51316 .22532 .50369 Mtetra
.821 .701 .732 r
.22532 .50369 .23162 .51316 .24204 .50227 .23612 .48873 Mtetra
.28 .373 .781 r
.23612 .48873 .24204 .50227 .25165 .50109 .24515 .49442 Mtetra
.6 .711 .922 r
.24515 .49442 .25165 .50109 .26138 .4991 .25489 .49245 Mtetra
.573 .703 .93 r
.25489 .49245 .26138 .4991 .27078 .5019 .26463 .49101 Mtetra
.789 .677 .741 r
.26463 .49101 .27078 .5019 .28137 .48956 .27526 .47856 Mtetra
.396 .495 .843 r
.27526 .47856 .28137 .48956 .29118 .48804 .28475 .48137 Mtetra
.61 .717 .921 r
.28475 .48137 .29118 .48804 .30109 .48573 .29467 .47916 Mtetra
.605 .719 .925 r
.29467 .47916 .30109 .48573 .31096 .4846 .30463 .47702 Mtetra
.578 .106 0 r
.30463 .47702 .31096 .4846 .32147 .47407 .31376 .48849 Mtetra
.63 .785 .337 r
.31376 .48849 .32147 .47407 .33133 .47433 .32501 .46731 Mtetra
.6 .705 .917 r
.32501 .46731 .33133 .47433 .34141 .47186 .33508 .46532 Mtetra
.626 .73 .922 r
.33508 .46532 .34141 .47186 .35154 .46926 .34523 .46267 Mtetra
.615 .725 .924 r
.34523 .46267 .35154 .46926 .36166 .46769 .35541 .46027 Mtetra
.089 .423 .868 r
.35541 .46027 .36166 .46769 .37229 .45617 .36528 .46511 Mtetra
.63 .85 .469 r
.36528 .46511 .37229 .45617 .38236 .45734 .37614 .45014 Mtetra
.599 .702 .915 r
.37614 .45014 .38236 .45734 .39264 .45471 .38642 .44812 Mtetra
.635 .735 .92 r
.38642 .44812 .39264 .45471 .40299 .45174 .39679 .44522 Mtetra
.64 .74 .921 r
.39679 .44522 .40299 .45174 .41338 .44872 .4072 .44217 Mtetra
.638 .739 .922 r
.4072 .44217 .41338 .44872 .42381 .4459 .41766 .43918 Mtetra
.615 .726 .925 r
.41766 .43918 .42381 .4459 .43423 .44485 .42814 .4367 Mtetra
.964 .655 .387 r
.42814 .4367 .43423 .44485 .44494 .43425 .43576 .54434 Mtetra
0 0 .209 r
.43576 .54434 .44494 .43425 .45544 .43333 .44938 .42625 Mtetra
.618 .717 .917 r
.44938 .42625 .45544 .43333 .46603 .43035 .45999 .4237 Mtetra
.644 .741 .92 r
.45999 .4237 .46603 .43035 .47668 .42705 .47065 .42048 Mtetra
.651 .747 .92 r
.47065 .42048 .47668 .42705 .48737 .42362 .48137 .41707 Mtetra
.654 .75 .92 r
.48137 .41707 .48737 .42362 .4981 .4201 .49213 .41356 Mtetra
.656 .752 .92 r
.49213 .41356 .4981 .4201 .50887 .41653 .50293 .40998 Mtetra
.658 .753 .92 r
.50293 .40998 .50887 .41653 .51969 .41291 .51377 .40635 Mtetra
.659 .754 .92 r
.51377 .40635 .51969 .41291 .53055 .40926 .52466 .40268 Mtetra
.52466 .40268 .53055 .40926 .54145 .4056 .53559 .39899 Mtetra
.53559 .39899 .54145 .4056 .55239 .40192 .54656 .39528 Mtetra
.54656 .39528 .55239 .40192 .56338 .39824 .55758 .39157 Mtetra
.658 .753 .92 r
.55758 .39157 .56338 .39824 .57441 .39455 .56864 .38785 Mtetra
.56864 .38785 .57441 .39455 .58548 .39085 .57974 .38412 Mtetra
.57974 .38412 .58548 .39085 .5966 .38714 .59089 .38038 Mtetra
.59089 .38038 .5966 .38714 .60776 .38342 .60208 .37663 Mtetra
.60208 .37663 .60776 .38342 .61897 .37969 .61332 .37287 Mtetra
.61332 .37287 .61897 .37969 .63022 .37594 .6246 .3691 Mtetra
.6246 .3691 .63022 .37594 .64152 .37219 .63593 .36532 Mtetra
.657 .753 .92 r
.63593 .36532 .64152 .37219 .65286 .36842 .6473 .36152 Mtetra
.6473 .36152 .65286 .36842 .66425 .36463 .65872 .3577 Mtetra
.65872 .3577 .66425 .36463 .67568 .36084 .67019 .35388 Mtetra
.67019 .35388 .67568 .36084 .68716 .35703 .6817 .35004 Mtetra
.657 .752 .92 r
.6817 .35004 .68716 .35703 .69869 .3532 .69326 .34618 Mtetra
.69326 .34618 .69869 .3532 .71026 .34936 .70486 .34231 Mtetra
.70486 .34231 .71026 .34936 .72188 .3455 .71652 .33843 Mtetra
.71652 .33843 .72188 .3455 .73355 .34164 .72822 .33453 Mtetra
.72822 .33453 .73355 .34164 .74526 .33775 .73997 .33062 Mtetra
.73997 .33062 .74526 .33775 .75703 .33385 .75176 .32669 Mtetra
.75176 .32669 .75703 .33385 .76884 .32994 .76361 .32274 Mtetra
.76361 .32274 .76884 .32994 .7807 .32601 .7755 .31878 Mtetra
.7755 .31878 .7807 .32601 .79261 .32206 .78745 .3148 Mtetra
.78745 .3148 .79261 .32206 .80457 .3181 .79944 .31081 Mtetra
.79944 .31081 .80457 .3181 .81658 .31412 .81149 .3068 Mtetra
.81149 .3068 .81658 .31412 .82863 .31013 .82358 .30278 Mtetra
.551 .691 .932 r
.18002 .50883 .18667 .51552 .19548 .52058 .18945 .50781 Mtetra
.757 .641 .733 r
.18945 .50781 .19548 .52058 .20622 .5065 .1999 .49677 Mtetra
.432 .545 .871 r
.1999 .49677 .20622 .5065 .21574 .50512 .20914 .49846 Mtetra
.593 .709 .924 r
.20914 .49846 .21574 .50512 .22532 .50369 .21877 .49665 Mtetra
.383 .606 .937 r
.21877 .49665 .22532 .50369 .23612 .48873 .22815 .49805 Mtetra
0 0 0 r
.22815 .49805 .23612 .48873 .24515 .49442 .23866 .48707 Mtetra
.567 .678 .914 r
.23866 .48707 .24515 .49442 .25489 .49245 .24836 .48585 Mtetra
.602 .716 .925 r
.24836 .48585 .25489 .49245 .26463 .49101 .25816 .4838 Mtetra
.266 .539 .92 r
.25816 .4838 .26463 .49101 .27526 .47856 .26764 .48656 Mtetra
.613 .873 .534 r
.26764 .48656 .27526 .47856 .28475 .48137 .27832 .47413 Mtetra
.581 .689 .916 r
.27832 .47413 .28475 .48137 .29467 .47916 .28821 .47256 Mtetra
.615 .723 .923 r
.28821 .47256 .29467 .47916 .30463 .47702 .2982 .4702 Mtetra
.557 .695 .932 r
.2982 .4702 .30463 .47702 .31376 .48849 .30816 .46901 Mtetra
.708 .567 .694 r
.30816 .46901 .31376 .48849 .32501 .46731 .31876 .4584 Mtetra
.505 .608 .889 r
.31876 .4584 .32501 .46731 .33508 .46532 .32871 .45861 Mtetra
.62 .724 .92 r
.32871 .45861 .33508 .46532 .34523 .46267 .33887 .45608 Mtetra
.625 .73 .923 r
.33887 .45608 .34523 .46267 .35541 .46027 .34908 .45343 Mtetra
.577 .706 .93 r
.34908 .45343 .35541 .46027 .36528 .46511 .35929 .4518 Mtetra
.761 .645 .732 r
.35929 .4518 .36528 .46511 .37614 .45014 .37002 .44019 Mtetra
.471 .566 .87 r
.37002 .44019 .37614 .45014 .38642 .44812 .38017 .44132 Mtetra
.625 .726 .919 r
.38017 .44132 .38642 .44812 .39679 .44522 .39055 .43863 Mtetra
.639 .738 .921 r
.39055 .43863 .39679 .44522 .4072 .44217 .40098 .43559 Mtetra
.64 .74 .921 r
.40098 .43559 .4072 .44217 .41766 .43918 .41146 .43251 Mtetra
.631 .735 .923 r
.41146 .43251 .41766 .43918 .42814 .4367 .42198 .42963 Mtetra
.549 .69 .933 r
.42198 .42963 .42814 .4367 .43576 .54434 .43249 .42853 Mtetra
.575 .367 .562 r
.43249 .42853 .43576 .54434 .44938 .42625 .44331 .41783 Mtetra
.555 .652 .9 r
.44331 .41783 .44938 .42625 .45999 .4237 .4539 .41686 Mtetra
.636 .734 .919 r
.4539 .41686 .45999 .4237 .47065 .42048 .46459 .41382 Mtetra
.648 .745 .92 r
.46459 .41382 .47065 .42048 .48137 .41707 .47533 .41046 Mtetra
.653 .749 .92 r
.47533 .41046 .48137 .41707 .49213 .41356 .48611 .40696 Mtetra
.655 .751 .92 r
.48611 .40696 .49213 .41356 .50293 .40998 .49694 .40338 Mtetra
.657 .752 .92 r
.49694 .40338 .50293 .40998 .51377 .40635 .50781 .39973 Mtetra
.658 .753 .92 r
.50781 .39973 .51377 .40635 .52466 .40268 .51873 .39605 Mtetra
.659 .754 .92 r
.51873 .39605 .52466 .40268 .53559 .39899 .52969 .39233 Mtetra
.52969 .39233 .53559 .39899 .54656 .39528 .54069 .3886 Mtetra
.54069 .3886 .54656 .39528 .55758 .39157 .55173 .38486 Mtetra
.55173 .38486 .55758 .39157 .56864 .38785 .56282 .38111 Mtetra
.658 .753 .92 r
.56282 .38111 .56864 .38785 .57974 .38412 .57396 .37735 Mtetra
.57396 .37735 .57974 .38412 .59089 .38038 .58513 .37358 Mtetra
.58513 .37358 .59089 .38038 .60208 .37663 .59636 .3698 Mtetra
.59636 .3698 .60208 .37663 .61332 .37287 .60762 .36601 Mtetra
.60762 .36601 .61332 .37287 .6246 .3691 .61894 .36221 Mtetra
.61894 .36221 .6246 .3691 .63593 .36532 .63029 .35839 Mtetra
.657 .753 .92 r
.63029 .35839 .63593 .36532 .6473 .36152 .6417 .35457 Mtetra
.6417 .35457 .6473 .36152 .65872 .3577 .65315 .35072 Mtetra
.65315 .35072 .65872 .3577 .67019 .35388 .66465 .34687 Mtetra
.66465 .34687 .67019 .35388 .6817 .35004 .67619 .343 Mtetra
.657 .752 .92 r
.67619 .343 .6817 .35004 .69326 .34618 .68778 .33911 Mtetra
.68778 .33911 .69326 .34618 .70486 .34231 .69942 .33521 Mtetra
.69942 .33521 .70486 .34231 .71652 .33843 .71111 .3313 Mtetra
.71111 .3313 .71652 .33843 .72822 .33453 .72284 .32737 Mtetra
.72284 .32737 .72822 .33453 .73997 .33062 .73463 .32343 Mtetra
.73463 .32343 .73997 .33062 .75176 .32669 .74646 .31947 Mtetra
.74646 .31947 .75176 .32669 .76361 .32274 .75834 .31549 Mtetra
.75834 .31549 .76361 .32274 .7755 .31878 .77027 .3115 Mtetra
.77027 .3115 .7755 .31878 .78745 .3148 .78225 .30749 Mtetra
.78225 .30749 .78745 .3148 .79944 .31081 .79428 .30347 Mtetra
.79428 .30347 .79944 .31081 .81149 .3068 .80636 .29943 Mtetra
.80636 .29943 .81149 .3068 .82358 .30278 .81849 .29537 Mtetra
.582 .702 .925 r
.17332 .50211 .18002 .50883 .18945 .50781 .18282 .50051 Mtetra
0 .362 .831 r
.18282 .50051 .18945 .50781 .1999 .49677 .1917 .50556 Mtetra
.72 .922 .578 r
.1917 .50556 .1999 .49677 .20914 .49846 .20254 .49137 Mtetra
.575 .689 .919 r
.20254 .49137 .20914 .49846 .21877 .49665 .21214 .48994 Mtetra
.574 .702 .929 r
.21214 .48994 .21877 .49665 .22815 .49805 .22179 .48846 Mtetra
.821 .702 .733 r
.22179 .48846 .22815 .49805 .23866 .48707 .23269 .4734 Mtetra
.278 .372 .78 r
.23269 .4734 .23866 .48707 .24836 .48585 .24179 .47906 Mtetra
.6 .711 .922 r
.24179 .47906 .24836 .48585 .25816 .4838 .25161 .47704 Mtetra
.573 .703 .93 r
.25161 .47704 .25816 .4838 .26764 .48656 .26143 .47555 Mtetra
.789 .678 .741 r
.26143 .47555 .26764 .48656 .27832 .47413 .27215 .463 Mtetra
.395 .495 .843 r
.27215 .463 .27832 .47413 .28821 .47256 .28172 .46578 Mtetra
.61 .717 .921 r
.28172 .46578 .28821 .47256 .2982 .4702 .29172 .46351 Mtetra
.605 .719 .925 r
.29172 .46351 .2982 .4702 .30816 .46901 .30176 .46132 Mtetra
.57 .1 0 r
.30176 .46132 .30816 .46901 .31876 .4584 .31096 .47279 Mtetra
.64 .793 .346 r
.31096 .47279 .31876 .4584 .32871 .45861 .32232 .45148 Mtetra
.6 .705 .917 r
.32232 .45148 .32871 .45861 .33887 .45608 .33247 .44942 Mtetra
.626 .73 .922 r
.33247 .44942 .33887 .45608 .34908 .45343 .34271 .44672 Mtetra
.615 .725 .924 r
.34271 .44672 .34908 .45343 .35929 .4518 .35297 .44426 Mtetra
.093 .424 .869 r
.35297 .44426 .35929 .4518 .37002 .44019 .36292 .44908 Mtetra
.64 .858 .479 r
.36292 .44908 .37002 .44019 .38017 .44132 .37389 .434 Mtetra
.599 .702 .915 r
.37389 .434 .38017 .44132 .39055 .43863 .38426 .43192 Mtetra
.635 .735 .92 r
.38426 .43192 .39055 .43863 .40098 .43559 .39472 .42896 Mtetra
.64 .74 .921 r
.39472 .42896 .40098 .43559 .41146 .43251 .40522 .42585 Mtetra
.638 .739 .922 r
.40522 .42585 .41146 .43251 .42198 .42963 .41577 .42279 Mtetra
.615 .726 .925 r
.41577 .42279 .42198 .42963 .43249 .42853 .42635 .42026 Mtetra
.965 .654 .383 r
.42635 .42026 .43249 .42853 .44331 .41783 .43397 .52832 Mtetra
0 0 .202 r
.43397 .52832 .44331 .41783 .4539 .41686 .44777 .40966 Mtetra
.618 .717 .917 r
.44777 .40966 .4539 .41686 .46459 .41382 .45848 .40704 Mtetra
.644 .741 .92 r
.45848 .40704 .46459 .41382 .47533 .41046 .46924 .40376 Mtetra
.651 .747 .92 r
.46924 .40376 .47533 .41046 .48611 .40696 .48005 .40029 Mtetra
.654 .75 .92 r
.48005 .40029 .48611 .40696 .49694 .40338 .49091 .39671 Mtetra
.656 .752 .92 r
.49091 .39671 .49694 .40338 .50781 .39973 .50181 .39307 Mtetra
.658 .753 .92 r
.50181 .39307 .50781 .39973 .51873 .39605 .51275 .38936 Mtetra
.659 .754 .92 r
.51275 .38936 .51873 .39605 .52969 .39233 .52374 .38563 Mtetra
.52374 .38563 .52969 .39233 .54069 .3886 .53477 .38187 Mtetra
.53477 .38187 .54069 .3886 .55173 .38486 .54585 .3781 Mtetra
.54585 .3781 .55173 .38486 .56282 .38111 .55696 .37431 Mtetra
.658 .753 .92 r
.55696 .37431 .56282 .38111 .57396 .37735 .56813 .37052 Mtetra
.56813 .37052 .57396 .37735 .58513 .37358 .57933 .36672 Mtetra
.57933 .36672 .58513 .37358 .59636 .3698 .59059 .36292 Mtetra
.59059 .36292 .59636 .3698 .60762 .36601 .60189 .3591 Mtetra
.60189 .3591 .60762 .36601 .61894 .36221 .61323 .35526 Mtetra
.61323 .35526 .61894 .36221 .63029 .35839 .62462 .35142 Mtetra
.62462 .35142 .63029 .35839 .6417 .35457 .63606 .34756 Mtetra
.657 .753 .92 r
.63606 .34756 .6417 .35457 .65315 .35072 .64754 .34369 Mtetra
.64754 .34369 .65315 .35072 .66465 .34687 .65907 .3398 Mtetra
.65907 .3398 .66465 .34687 .67619 .343 .67064 .33591 Mtetra
.67064 .33591 .67619 .343 .68778 .33911 .68227 .33199 Mtetra
.657 .752 .92 r
.68227 .33199 .68778 .33911 .69942 .33521 .69394 .32806 Mtetra
.69394 .32806 .69942 .33521 .71111 .3313 .70566 .32412 Mtetra
.70566 .32412 .71111 .3313 .72284 .32737 .71743 .32016 Mtetra
.71743 .32016 .72284 .32737 .73463 .32343 .72925 .31618 Mtetra
.72925 .31618 .73463 .32343 .74646 .31947 .74111 .31219 Mtetra
.74111 .31219 .74646 .31947 .75834 .31549 .75303 .30819 Mtetra
.75303 .30819 .75834 .31549 .77027 .3115 .76499 .30416 Mtetra
.76499 .30416 .77027 .3115 .78225 .30749 .77701 .30013 Mtetra
.77701 .30013 .78225 .30749 .79428 .30347 .78907 .29607 Mtetra
.78907 .29607 .79428 .30347 .80636 .29943 .80119 .292 Mtetra
.80119 .292 .80636 .29943 .81849 .29537 .81335 .28791 Mtetra
.559 .677 .918 r
.16664 .49482 .17332 .50211 .18282 .50051 .1761 .49372 Mtetra
.551 .691 .932 r
.1761 .49372 .18282 .50051 .1917 .50556 .18561 .49265 Mtetra
.757 .642 .733 r
.18561 .49265 .1917 .50556 .20254 .49137 .19616 .48152 Mtetra
.431 .545 .871 r
.19616 .48152 .20254 .49137 .21214 .48994 .20547 .48318 Mtetra
.593 .709 .924 r
.20547 .48318 .21214 .48994 .22179 .48846 .21517 .48131 Mtetra
.384 .606 .937 r
.21517 .48131 .22179 .48846 .23269 .4734 .22462 .48267 Mtetra
0 0 0 r
.22462 .48267 .23269 .4734 .24179 .47906 .23523 .4716 Mtetra
.567 .678 .915 r
.23523 .4716 .24179 .47906 .25161 .47704 .245 .47032 Mtetra
.602 .716 .925 r
.245 .47032 .25161 .47704 .26143 .47555 .25489 .46823 Mtetra
.268 .54 .921 r
.25489 .46823 .26143 .47555 .27215 .463 .26444 .47096 Mtetra
.624 .881 .545 r
.26444 .47096 .27215 .463 .28172 .46578 .27522 .45843 Mtetra
.581 .689 .916 r
.27522 .45843 .28172 .46578 .29172 .46351 .28519 .4568 Mtetra
.615 .723 .923 r
.28519 .4568 .29172 .46351 .30176 .46132 .29527 .45438 Mtetra
.557 .695 .932 r
.29527 .45438 .30176 .46132 .31096 .47279 .30531 .45314 Mtetra
.708 .567 .694 r
.30531 .45314 .31096 .47279 .32232 .45148 .316 .44244 Mtetra
.505 .608 .89 r
.316 .44244 .32232 .45148 .33247 .44942 .32603 .4426 Mtetra
.62 .724 .92 r
.32603 .4426 .33247 .44942 .34271 .44672 .33628 .44002 Mtetra
.625 .73 .923 r
.33628 .44002 .34271 .44672 .35297 .44426 .34658 .4373 Mtetra
.577 .706 .93 r
.34658 .4373 .35297 .44426 .36292 .44908 .35687 .43562 Mtetra
.762 .645 .733 r
.35687 .43562 .36292 .44908 .37389 .434 .3677 .42391 Mtetra
.47 .566 .87 r
.3677 .42391 .37389 .434 .38426 .43192 .37794 .425 Mtetra
.625 .726 .919 r
.37794 .425 .38426 .43192 .39472 .42896 .38841 .42225 Mtetra
.639 .738 .921 r
.38841 .42225 .39472 .42896 .40522 .42585 .39894 .41915 Mtetra
.64 .74 .921 r
.39894 .41915 .40522 .42585 .41577 .42279 .40951 .41601 Mtetra
.631 .735 .923 r
.40951 .41601 .41577 .42279 .42635 .42026 .42012 .41306 Mtetra
.549 .69 .933 r
.42012 .41306 .42635 .42026 .43397 .52832 .43073 .41191 Mtetra
.573 .364 .56 r
.43073 .41191 .43397 .52832 .44777 .40966 .44164 .40111 Mtetra
.555 .652 .9 r
.44164 .40111 .44777 .40966 .45848 .40704 .45233 .40009 Mtetra
.636 .734 .919 r
.45233 .40009 .45848 .40704 .46924 .40376 .46311 .39698 Mtetra
.648 .745 .92 r
.46311 .39698 .46924 .40376 .48005 .40029 .47395 .39355 Mtetra
.653 .749 .92 r
.47395 .39355 .48005 .40029 .49091 .39671 .48483 .38999 Mtetra
.655 .751 .92 r
.48483 .38999 .49091 .39671 .50181 .39307 .49576 .38634 Mtetra
.657 .752 .92 r
.49576 .38634 .50181 .39307 .51275 .38936 .50673 .38263 Mtetra
.658 .753 .92 r
.50673 .38263 .51275 .38936 .52374 .38563 .51775 .37887 Mtetra
.659 .754 .92 r
.51775 .37887 .52374 .38563 .53477 .38187 .52881 .37509 Mtetra
.52881 .37509 .53477 .38187 .54585 .3781 .53991 .37128 Mtetra
.53991 .37128 .54585 .3781 .55696 .37431 .55106 .36747 Mtetra
.55106 .36747 .55696 .37431 .56813 .37052 .56225 .36365 Mtetra
.658 .753 .92 r
.56225 .36365 .56813 .37052 .57933 .36672 .57349 .35982 Mtetra
.57349 .35982 .57933 .36672 .59059 .36292 .58478 .35598 Mtetra
.58478 .35598 .59059 .36292 .60189 .3591 .5961 .35213 Mtetra
.5961 .35213 .60189 .3591 .61323 .35526 .60748 .34827 Mtetra
.60748 .34827 .61323 .35526 .62462 .35142 .6189 .34439 Mtetra
.6189 .34439 .62462 .35142 .63606 .34756 .63037 .34051 Mtetra
.657 .753 .92 r
.63037 .34051 .63606 .34756 .64754 .34369 .64188 .3366 Mtetra
.64188 .3366 .64754 .34369 .65907 .3398 .65345 .33269 Mtetra
.65345 .33269 .65907 .3398 .67064 .33591 .66505 .32876 Mtetra
.66505 .32876 .67064 .33591 .68227 .33199 .67671 .32481 Mtetra
.657 .752 .92 r
.67671 .32481 .68227 .33199 .69394 .32806 .68842 .32085 Mtetra
.68842 .32085 .69394 .32806 .70566 .32412 .70017 .31688 Mtetra
.70017 .31688 .70566 .32412 .71743 .32016 .71197 .31289 Mtetra
.71197 .31289 .71743 .32016 .72925 .31618 .72382 .30888 Mtetra
.72382 .30888 .72925 .31618 .74111 .31219 .73572 .30486 Mtetra
.73572 .30486 .74111 .31219 .75303 .30819 .74767 .30082 Mtetra
.74767 .30082 .75303 .30819 .76499 .30416 .75967 .29677 Mtetra
.75967 .29677 .76499 .30416 .77701 .30013 .77172 .2927 Mtetra
.77172 .2927 .77701 .30013 .78907 .29607 .78383 .28861 Mtetra
.78383 .28861 .78907 .29607 .80119 .292 .79598 .28451 Mtetra
.79598 .28451 .80119 .292 .81335 .28791 .80818 .28039 Mtetra
.314 .426 .816 r
.16045 .48272 .16664 .49482 .1761 .49372 .16934 .48689 Mtetra
.582 .702 .925 r
.16934 .48689 .1761 .49372 .18561 .49265 .17891 .48524 Mtetra
0 .364 .833 r
.17891 .48524 .18561 .49265 .19616 .48152 .18785 .49026 Mtetra
.728 .927 .586 r
.18785 .49026 .19616 .48152 .20547 .48318 .19879 .47597 Mtetra
.575 .689 .919 r
.19879 .47597 .20547 .48318 .21517 .48131 .20847 .47449 Mtetra
.574 .702 .929 r
.20847 .47449 .21517 .48131 .22462 .48267 .2182 .47295 Mtetra
.822 .702 .733 r
.2182 .47295 .22462 .48267 .23523 .4716 .22921 .45779 Mtetra
.276 .371 .78 r
.22921 .45779 .23523 .4716 .245 .47032 .23836 .46343 Mtetra
.6 .711 .922 r
.23836 .46343 .245 .47032 .25489 .46823 .24826 .46136 Mtetra
.573 .703 .93 r
.24826 .46136 .25489 .46823 .26444 .47096 .25817 .45981 Mtetra
.79 .678 .741 r
.25817 .45981 .26444 .47096 .27522 .45843 .26899 .44717 Mtetra
.394 .495 .843 r
.26899 .44717 .27522 .45843 .28519 .4568 .27863 .4499 Mtetra
.61 .717 .921 r
.27863 .4499 .28519 .4568 .29527 .45438 .28872 .44758 Mtetra
.605 .719 .925 r
.28872 .44758 .29527 .45438 .30531 .45314 .29884 .44534 Mtetra
.562 .093 0 r
.29884 .44534 .30531 .45314 .316 .44244 .30811 .4568 Mtetra
.649 .8 .356 r
.30811 .4568 .316 .44244 .32603 .4426 .31957 .43535 Mtetra
.6 .705 .917 r
.31957 .43535 .32603 .4426 .33628 .44002 .32981 .43324 Mtetra
.626 .73 .922 r
.32981 .43324 .33628 .44002 .34658 .4373 .34014 .43048 Mtetra
.615 .725 .924 r
.34014 .43048 .34658 .4373 .35687 .43562 .35049 .42796 Mtetra
.097 .426 .87 r
.35049 .42796 .35687 .43562 .3677 .42391 .36053 .43275 Mtetra
.649 .865 .489 r
.36053 .43275 .3677 .42391 .37794 .425 .3716 .41756 Mtetra
.599 .702 .915 r
.3716 .41756 .37794 .425 .38841 .42225 .38206 .41542 Mtetra
.635 .735 .92 r
.38206 .41542 .38841 .42225 .39894 .41915 .39261 .4124 Mtetra
.64 .74 .921 r
.39261 .4124 .39894 .41915 .40951 .41601 .40321 .40922 Mtetra
.638 .739 .922 r
.40321 .40922 .40951 .41601 .42012 .41306 .41385 .4061 Mtetra
.615 .726 .925 r
.41385 .4061 .42012 .41306 .43073 .41191 .42452 .4035 Mtetra
.965 .653 .378 r
.42452 .4035 .43073 .41191 .44164 .40111 .43215 .512 Mtetra
0 0 .195 r
.43215 .512 .44164 .40111 .45233 .40009 .44614 .39276 Mtetra
.618 .717 .917 r
.44614 .39276 .45233 .40009 .46311 .39698 .45694 .39008 Mtetra
.644 .741 .92 r
.45694 .39008 .46311 .39698 .47395 .39355 .4678 .38673 Mtetra
.651 .747 .92 r
.4678 .38673 .47395 .39355 .48483 .38999 .47871 .38319 Mtetra
.654 .75 .92 r
.47871 .38319 .48483 .38999 .49576 .38634 .48967 .37955 Mtetra
.656 .752 .92 r
.48967 .37955 .49576 .38634 .50673 .38263 .50067 .37583 Mtetra
.658 .753 .92 r
.50067 .37583 .50673 .38263 .51775 .37887 .51171 .37206 Mtetra
.659 .754 .92 r
.51171 .37206 .51775 .37887 .52881 .37509 .5228 .36825 Mtetra
.5228 .36825 .52881 .37509 .53991 .37128 .53394 .36442 Mtetra
.53394 .36442 .53991 .37128 .55106 .36747 .54511 .36058 Mtetra
.54511 .36058 .55106 .36747 .56225 .36365 .55634 .35673 Mtetra
.658 .753 .92 r
.55634 .35673 .56225 .36365 .57349 .35982 .56761 .35286 Mtetra
.56761 .35286 .57349 .35982 .58478 .35598 .57892 .34899 Mtetra
.57892 .34899 .58478 .35598 .5961 .35213 .59028 .34511 Mtetra
.59028 .34511 .5961 .35213 .60748 .34827 .60169 .34122 Mtetra
.60169 .34122 .60748 .34827 .6189 .34439 .61314 .33731 Mtetra
.61314 .33731 .6189 .34439 .63037 .34051 .62464 .3334 Mtetra
.62464 .3334 .63037 .34051 .64188 .3366 .63619 .32946 Mtetra
.657 .753 .92 r
.63619 .32946 .64188 .3366 .65345 .33269 .64778 .32552 Mtetra
.64778 .32552 .65345 .33269 .66505 .32876 .65942 .32156 Mtetra
.65942 .32156 .66505 .32876 .67671 .32481 .67111 .31758 Mtetra
.67111 .31758 .67671 .32481 .68842 .32085 .68285 .31359 Mtetra
.657 .752 .92 r
.68285 .31359 .68842 .32085 .70017 .31688 .69464 .30959 Mtetra
.69464 .30959 .70017 .31688 .71197 .31289 .70647 .30556 Mtetra
.70647 .30556 .71197 .31289 .72382 .30888 .71836 .30153 Mtetra
.71836 .30153 .72382 .30888 .73572 .30486 .7303 .29747 Mtetra
.7303 .29747 .73572 .30486 .74767 .30082 .74228 .29341 Mtetra
.74228 .29341 .74767 .30082 .75967 .29677 .75432 .28932 Mtetra
.75432 .28932 .75967 .29677 .77172 .2927 .7664 .28522 Mtetra
.7664 .28522 .77172 .2927 .78383 .28861 .77854 .2811 Mtetra
.77854 .2811 .78383 .28861 .79598 .28451 .79073 .27697 Mtetra
.79073 .27697 .79598 .28451 .80818 .28039 .80297 .27281 Mtetra
.602 .88 .562 r
.15194 .49095 .16045 .48272 .16934 .48689 .16258 .47949 Mtetra
.559 .677 .918 r
.16258 .47949 .16934 .48689 .17891 .48524 .17212 .47833 Mtetra
.551 .691 .932 r
.17212 .47833 .17891 .48524 .18785 .49026 .1817 .47722 Mtetra
.758 .642 .733 r
.1817 .47722 .18785 .49026 .19879 .47597 .19235 .46599 Mtetra
.431 .545 .871 r
.19235 .46599 .19879 .47597 .20847 .47449 .20172 .46761 Mtetra
.593 .709 .924 r
.20172 .46761 .20847 .47449 .2182 .47295 .21151 .46569 Mtetra
.384 .607 .936 r
.21151 .46569 .2182 .47295 .22921 .45779 .22103 .46701 Mtetra
0 0 0 r
.22103 .46701 .22921 .45779 .23836 .46343 .23174 .45586 Mtetra
.566 .678 .915 r
.23174 .45586 .23836 .46343 .24826 .46136 .24159 .45452 Mtetra
.602 .716 .925 r
.24159 .45452 .24826 .46136 .25817 .45981 .25156 .45237 Mtetra
.27 .541 .921 r
.25156 .45237 .25817 .45981 .26899 .44717 .26118 .45506 Mtetra
.634 .888 .556 r
.26118 .45506 .26899 .44717 .27863 .4499 .27207 .44243 Mtetra
.581 .69 .916 r
.27207 .44243 .27863 .4499 .28872 .44758 .28212 .44075 Mtetra
.615 .723 .923 r
.28212 .44075 .28872 .44758 .29884 .44534 .29228 .43828 Mtetra
.557 .695 .932 r
.29228 .43828 .29884 .44534 .30811 .4568 .3024 .43698 Mtetra
.708 .567 .694 r
.3024 .43698 .30811 .4568 .31957 .43535 .3132 .42618 Mtetra
.504 .608 .89 r
.3132 .42618 .31957 .43535 .32981 .43324 .32331 .4263 Mtetra
.62 .724 .92 r
.32331 .4263 .32981 .43324 .34014 .43048 .33365 .42366 Mtetra
.625 .73 .923 r
.33365 .42366 .34014 .43048 .35049 .42796 .34404 .42088 Mtetra
.578 .706 .93 r
.34404 .42088 .35049 .42796 .36053 .43275 .35442 .41914 Mtetra
.762 .646 .733 r
.35442 .41914 .36053 .43275 .3716 .41756 .36535 .40733 Mtetra
.469 .566 .87 r
.36535 .40733 .3716 .41756 .38206 .41542 .37567 .40837 Mtetra
.625 .726 .919 r
.37567 .40837 .38206 .41542 .39261 .4124 .38623 .40556 Mtetra
.639 .738 .921 r
.38623 .40556 .39261 .4124 .40321 .40922 .39686 .4024 Mtetra
.64 .74 .921 r
.39686 .4024 .40321 .40922 .41385 .4061 .40752 .39919 Mtetra
.631 .735 .923 r
.40752 .39919 .41385 .4061 .42452 .4035 .41823 .39618 Mtetra
.549 .69 .932 r
.41823 .39618 .42452 .4035 .43215 .512 .42893 .39497 Mtetra
.571 .361 .557 r
.42893 .39497 .43215 .512 .44614 .39276 .43994 .38408 Mtetra
.554 .652 .9 r
.43994 .38408 .44614 .39276 .45694 .39008 .45073 .383 Mtetra
.636 .734 .919 r
.45073 .383 .45694 .39008 .4678 .38673 .46161 .37982 Mtetra
.648 .745 .92 r
.46161 .37982 .4678 .38673 .47871 .38319 .47255 .37633 Mtetra
.653 .749 .92 r
.47255 .37633 .47871 .38319 .48967 .37955 .48353 .37269 Mtetra
.655 .751 .92 r
.48353 .37269 .48967 .37955 .50067 .37583 .49456 .36897 Mtetra
.657 .752 .92 r
.49456 .36897 .50067 .37583 .51171 .37206 .50563 .36519 Mtetra
.658 .753 .92 r
.50563 .36519 .51171 .37206 .5228 .36825 .51675 .36137 Mtetra
.659 .754 .92 r
.51675 .36137 .5228 .36825 .53394 .36442 .52791 .35751 Mtetra
.52791 .35751 .53394 .36442 .54511 .36058 .53912 .35364 Mtetra
.53912 .35364 .54511 .36058 .55634 .35673 .55038 .34975 Mtetra
.55038 .34975 .55634 .35673 .56761 .35286 .56168 .34586 Mtetra
.658 .753 .92 r
.56168 .34586 .56761 .35286 .57892 .34899 .57302 .34195 Mtetra
.57302 .34195 .57892 .34899 .59028 .34511 .58441 .33804 Mtetra
.58441 .33804 .59028 .34511 .60169 .34122 .59585 .33412 Mtetra
.59585 .33412 .60169 .34122 .61314 .33731 .60733 .33018 Mtetra
.60733 .33018 .61314 .33731 .62464 .3334 .61887 .32623 Mtetra
.61887 .32623 .62464 .3334 .63619 .32946 .63044 .32227 Mtetra
.657 .753 .92 r
.63044 .32227 .63619 .32946 .64778 .32552 .64207 .31829 Mtetra
.64207 .31829 .64778 .32552 .65942 .32156 .65375 .3143 Mtetra
.65375 .3143 .65942 .32156 .67111 .31758 .66547 .31029 Mtetra
.66547 .31029 .67111 .31758 .68285 .31359 .67724 .30627 Mtetra
.657 .752 .92 r
.67724 .30627 .68285 .31359 .69464 .30959 .68906 .30224 Mtetra
.68906 .30224 .69464 .30959 .70647 .30556 .70093 .29818 Mtetra
.70093 .29818 .70647 .30556 .71836 .30153 .71285 .29411 Mtetra
.71285 .29411 .71836 .30153 .7303 .29747 .72482 .29003 Mtetra
.72482 .29003 .7303 .29747 .74228 .29341 .73684 .28593 Mtetra
.73684 .28593 .74228 .29341 .75432 .28932 .74892 .28181 Mtetra
.74892 .28181 .75432 .28932 .7664 .28522 .76104 .27768 Mtetra
.76104 .27768 .7664 .28522 .77854 .2811 .77321 .27353 Mtetra
.77321 .27353 .77854 .2811 .79073 .27697 .78544 .26936 Mtetra
.78544 .26936 .79073 .27697 .80297 .27281 .79771 .26518 Mtetra
.801 .687 .74 r
.14544 .48063 .15194 .49095 .16258 .47949 .15633 .46725 Mtetra
.312 .425 .816 r
.15633 .46725 .16258 .47949 .17212 .47833 .16528 .47139 Mtetra
.582 .702 .925 r
.16528 .47139 .17212 .47833 .1817 .47722 .17493 .46969 Mtetra
0 .367 .834 r
.17493 .46969 .1817 .47722 .19235 .46599 .18394 .47469 Mtetra
.735 .932 .594 r
.18394 .47469 .19235 .46599 .20172 .46761 .19498 .46029 Mtetra
.575 .689 .919 r
.19498 .46029 .20172 .46761 .21151 .46569 .20473 .45876 Mtetra
.574 .702 .929 r
.20473 .45876 .21151 .46569 .22103 .46701 .21454 .45717 Mtetra
.823 .703 .733 r
.21454 .45717 .22103 .46701 .23174 .45586 .22565 .44189 Mtetra
.274 .37 .78 r
.22565 .44189 .23174 .45586 .24159 .45452 .23488 .44751 Mtetra
.6 .711 .922 r
.23488 .44751 .24159 .45452 .25156 .45237 .24486 .44538 Mtetra
.573 .702 .93 r
.24486 .44538 .25156 .45237 .26118 .45506 .25484 .44378 Mtetra
.79 .679 .742 r
.25484 .44378 .26118 .45506 .27207 .44243 .26577 .43104 Mtetra
.393 .494 .843 r
.26577 .43104 .27207 .44243 .28212 .44075 .27549 .43374 Mtetra
.61 .717 .921 r
.27549 .43374 .28212 .44075 .29228 .43828 .28566 .43136 Mtetra
.605 .719 .925 r
.28566 .43136 .29228 .43828 .3024 .43698 .29587 .42905 Mtetra
.555 .087 0 r
.29587 .42905 .3024 .43698 .3132 .42618 .3052 .44052 Mtetra
.659 .808 .365 r
.3052 .44052 .3132 .42618 .32331 .4263 .31678 .41893 Mtetra
.6 .705 .917 r
.31678 .41893 .32331 .4263 .33365 .42366 .32711 .41676 Mtetra
.626 .73 .922 r
.32711 .41676 .33365 .42366 .34404 .42088 .33752 .41394 Mtetra
.615 .725 .924 r
.33752 .41394 .34404 .42088 .35442 .41914 .34797 .41136 Mtetra
.101 .428 .871 r
.34797 .41136 .35442 .41914 .36535 .40733 .35809 .41611 Mtetra
.659 .872 .498 r
.35809 .41611 .36535 .40733 .37567 .40837 .36926 .40081 Mtetra
.599 .702 .915 r
.36926 .40081 .37567 .40837 .38623 .40556 .37982 .39861 Mtetra
.635 .735 .92 r
.37982 .39861 .38623 .40556 .39686 .4024 .39046 .39552 Mtetra
.64 .74 .921 r
.39046 .39552 .39686 .4024 .40752 .39919 .40115 .39228 Mtetra
.638 .739 .922 r
.40115 .39228 .40752 .39919 .41823 .39618 .41189 .38909 Mtetra
.615 .726 .925 r
.41189 .38909 .41823 .39618 .42893 .39497 .42265 .38643 Mtetra
.965 .652 .373 r
.42265 .38643 .42893 .39497 .43994 .38408 .43029 .49535 Mtetra
0 0 .189 r
.43029 .49535 .43994 .38408 .45073 .383 .44448 .37554 Mtetra
.618 .717 .917 r
.44448 .37554 .45073 .383 .46161 .37982 .45537 .37279 Mtetra
.644 .741 .92 r
.45537 .37279 .46161 .37982 .47255 .37633 .46634 .36938 Mtetra
.651 .747 .92 r
.46634 .36938 .47255 .37633 .48353 .37269 .47735 .36577 Mtetra
.654 .75 .92 r
.47735 .36577 .48353 .37269 .49456 .36897 .4884 .36205 Mtetra
.656 .752 .92 r
.4884 .36205 .49456 .36897 .50563 .36519 .49951 .35827 Mtetra
.658 .753 .92 r
.49951 .35827 .50563 .36519 .51675 .36137 .51065 .35442 Mtetra
.659 .754 .92 r
.51065 .35442 .51675 .36137 .52791 .35751 .52185 .35055 Mtetra
.52185 .35055 .52791 .35751 .53912 .35364 .53309 .34664 Mtetra
.53309 .34664 .53912 .35364 .55038 .34975 .54437 .34273 Mtetra
.54437 .34273 .55038 .34975 .56168 .34586 .5557 .3388 Mtetra
.658 .753 .92 r
.5557 .3388 .56168 .34586 .57302 .34195 .56708 .33486 Mtetra
.56708 .33486 .57302 .34195 .58441 .33804 .5785 .33092 Mtetra
.5785 .33092 .58441 .33804 .59585 .33412 .58997 .32696 Mtetra
.58997 .32696 .59585 .33412 .60733 .33018 .60148 .323 Mtetra
.60148 .323 .60733 .33018 .61887 .32623 .61305 .31901 Mtetra
.61305 .31901 .61887 .32623 .63044 .32227 .62466 .31502 Mtetra
.62466 .31502 .63044 .32227 .64207 .31829 .63632 .31101 Mtetra
.657 .753 .92 r
.63632 .31101 .64207 .31829 .65375 .3143 .64803 .30699 Mtetra
.64803 .30699 .65375 .3143 .66547 .31029 .65978 .30295 Mtetra
.65978 .30295 .66547 .31029 .67724 .30627 .67159 .2989 Mtetra
.67159 .2989 .67724 .30627 .68906 .30224 .68345 .29483 Mtetra
.657 .752 .92 r
.68345 .29483 .68906 .30224 .70093 .29818 .69535 .29074 Mtetra
.69535 .29074 .70093 .29818 .71285 .29411 .7073 .28664 Mtetra
.7073 .28664 .71285 .29411 .72482 .29003 .71931 .28253 Mtetra
.71931 .28253 .72482 .29003 .73684 .28593 .73137 .27839 Mtetra
.73137 .27839 .73684 .28593 .74892 .28181 .74347 .27424 Mtetra
.74347 .27424 .74892 .28181 .76104 .27768 .75563 .27008 Mtetra
.75563 .27008 .76104 .27768 .77321 .27353 .76784 .26589 Mtetra
.76784 .26589 .77321 .27353 .78544 .26936 .7801 .26169 Mtetra
.7801 .26169 .78544 .26936 .79771 .26518 .79242 .25748 Mtetra
.3 .561 .928 r
.13856 .47327 .14544 .48063 .15633 .46725 .14771 .47543 Mtetra
.613 .889 .574 r
.14771 .47543 .15633 .46725 .16528 .47139 .15845 .46388 Mtetra
.559 .677 .918 r
.15845 .46388 .16528 .47139 .17493 .46969 .16806 .46267 Mtetra
.552 .691 .932 r
.16806 .46267 .17493 .46969 .18394 .47469 .17772 .4615 Mtetra
.758 .642 .733 r
.17772 .4615 .18394 .47469 .19498 .46029 .18846 .45019 Mtetra
.43 .545 .871 r
.18846 .45019 .19498 .46029 .20473 .45876 .19791 .45177 Mtetra
.593 .709 .924 r
.19791 .45177 .20473 .45876 .21454 .45717 .20777 .44979 Mtetra
.385 .607 .936 r
.20777 .44979 .21454 .45717 .22565 .44189 .21738 .45107 Mtetra
0 0 0 r
.21738 .45107 .22565 .44189 .23488 .44751 .22818 .43982 Mtetra
.566 .678 .915 r
.22818 .43982 .23488 .44751 .24486 .44538 .23811 .43843 Mtetra
.602 .716 .925 r
.23811 .43843 .24486 .44538 .25484 .44378 .24816 .43623 Mtetra
.272 .541 .921 r
.24816 .43623 .25484 .44378 .26577 .43104 .25786 .43888 Mtetra
.644 .896 .566 r
.25786 .43888 .26577 .43104 .27549 .43374 .26885 .42615 Mtetra
.581 .69 .916 r
.26885 .42615 .27549 .43374 .28566 .43136 .27899 .42441 Mtetra
.615 .723 .923 r
.27899 .42441 .28566 .43136 .29587 .42905 .28923 .42187 Mtetra
.557 .695 .932 r
.28923 .42187 .29587 .42905 .3052 .44052 .29944 .42053 Mtetra
.708 .567 .694 r
.29944 .42053 .3052 .44052 .31678 .41893 .31034 .40963 Mtetra
.504 .608 .89 r
.31034 .40963 .31678 .41893 .32711 .41676 .32054 .4097 Mtetra
.62 .724 .921 r
.32054 .4097 .32711 .41676 .33752 .41394 .33096 .40699 Mtetra
.625 .73 .923 r
.33096 .40699 .33752 .41394 .34797 .41136 .34144 .40416 Mtetra
.578 .705 .93 r
.34144 .40416 .34797 .41136 .35809 .41611 .35192 .40236 Mtetra
.763 .646 .733 r
.35192 .40236 .35809 .41611 .36926 .40081 .36295 .39045 Mtetra
.469 .565 .87 r
.36295 .39045 .36926 .40081 .37982 .39861 .37336 .39144 Mtetra
.625 .726 .919 r
.37336 .39144 .37982 .39861 .39046 .39552 .38402 .38856 Mtetra
.639 .738 .921 r
.38402 .38856 .39046 .39552 .40115 .39228 .39473 .38534 Mtetra
.64 .74 .921 r
.39473 .38534 .40115 .39228 .41189 .38909 .4055 .38206 Mtetra
.631 .735 .923 r
.4055 .38206 .41189 .38909 .42265 .38643 .4163 .37898 Mtetra
.549 .69 .932 r
.4163 .37898 .42265 .38643 .43029 .49535 .4271 .37771 Mtetra
.568 .358 .555 r
.4271 .37771 .43029 .49535 .44448 .37554 .43822 .36673 Mtetra
.554 .652 .9 r
.43822 .36673 .44448 .37554 .45537 .37279 .4491 .36558 Mtetra
.636 .734 .919 r
.4491 .36558 .45537 .37279 .46634 .36938 .46008 .36234 Mtetra
.648 .745 .92 r
.46008 .36234 .46634 .36938 .47735 .36577 .47112 .35877 Mtetra
.653 .749 .92 r
.47112 .35877 .47735 .36577 .4884 .36205 .4822 .35507 Mtetra
.655 .751 .92 r
.4822 .35507 .4884 .36205 .49951 .35827 .49333 .35128 Mtetra
.657 .752 .92 r
.49333 .35128 .49951 .35827 .51065 .35442 .50451 .34742 Mtetra
.658 .753 .92 r
.50451 .34742 .51065 .35442 .52185 .35055 .51573 .34353 Mtetra
.659 .754 .92 r
.51573 .34353 .52185 .35055 .53309 .34664 .527 .3396 Mtetra
.527 .3396 .53309 .34664 .54437 .34273 .53832 .33565 Mtetra
.53832 .33565 .54437 .34273 .5557 .3388 .54968 .33169 Mtetra
.54968 .33169 .5557 .3388 .56708 .33486 .56109 .32772 Mtetra
.658 .753 .92 r
.56109 .32772 .56708 .33486 .5785 .33092 .57254 .32374 Mtetra
.57254 .32374 .5785 .33092 .58997 .32696 .58404 .31975 Mtetra
.58404 .31975 .58997 .32696 .60148 .323 .59559 .31575 Mtetra
.59559 .31575 .60148 .323 .61305 .31901 .60719 .31174 Mtetra
.60719 .31174 .61305 .31901 .62466 .31502 .61883 .30772 Mtetra
.61883 .30772 .62466 .31502 .63632 .31101 .63052 .30368 Mtetra
.657 .753 .92 r
.63052 .30368 .63632 .31101 .64803 .30699 .64226 .29962 Mtetra
.64226 .29962 .64803 .30699 .65978 .30295 .65405 .29555 Mtetra
.65405 .29555 .65978 .30295 .67159 .2989 .66589 .29147 Mtetra
.66589 .29147 .67159 .2989 .68345 .29483 .67778 .28737 Mtetra
.657 .752 .92 r
.67778 .28737 .68345 .29483 .69535 .29074 .68972 .28325 Mtetra
.68972 .28325 .69535 .29074 .7073 .28664 .70171 .27912 Mtetra
.70171 .27912 .7073 .28664 .71931 .28253 .71375 .27497 Mtetra
.71375 .27497 .71931 .28253 .73137 .27839 .72584 .2708 Mtetra
.72584 .2708 .73137 .27839 .74347 .27424 .73799 .26662 Mtetra
.73799 .26662 .74347 .27424 .75563 .27008 .75018 .26242 Mtetra
.75018 .26242 .75563 .27008 .76784 .26589 .76243 .2582 Mtetra
.76243 .2582 .76784 .26589 .7801 .26169 .77473 .25397 Mtetra
.77473 .25397 .7801 .26169 .79242 .25748 .78708 .24972 Mtetra
.556 .692 .93 r
.1316 .46624 .13856 .47327 .14771 .47543 .14115 .46498 Mtetra
.801 .688 .74 r
.14115 .46498 .14771 .47543 .15845 .46388 .15213 .4515 Mtetra
.311 .424 .816 r
.15213 .4515 .15845 .46388 .16806 .46267 .16115 .45562 Mtetra
.582 .702 .925 r
.16115 .45562 .16806 .46267 .17772 .4615 .17088 .45386 Mtetra
0 .369 .836 r
.17088 .45386 .17772 .4615 .18846 .45019 .17995 .45884 Mtetra
.743 .937 .602 r
.17995 .45884 .18846 .45019 .19791 .45177 .19109 .44433 Mtetra
.575 .689 .919 r
.19109 .44433 .19791 .45177 .20777 .44979 .20093 .44274 Mtetra
.574 .702 .929 r
.20093 .44274 .20777 .44979 .21738 .45107 .21082 .4411 Mtetra
.823 .704 .733 r
.21082 .4411 .21738 .45107 .22818 .43982 .22204 .42571 Mtetra
.272 .369 .78 r
.22204 .42571 .22818 .43982 .23811 .43843 .23133 .43131 Mtetra
.6 .711 .922 r
.23133 .43131 .23811 .43843 .24816 .43623 .24139 .42912 Mtetra
.573 .702 .93 r
.24139 .42912 .24816 .43623 .25786 .43888 .25146 .42746 Mtetra
.791 .68 .742 r
.25146 .42746 .25786 .43888 .26885 .42615 .26249 .41461 Mtetra
.392 .494 .844 r
.26249 .41461 .26885 .42615 .27899 .42441 .27228 .41728 Mtetra
.61 .717 .921 r
.27228 .41728 .27899 .42441 .28923 .42187 .28254 .41484 Mtetra
.605 .719 .925 r
.28254 .41484 .28923 .42187 .29944 .42053 .29284 .41247 Mtetra
0 0 .449 r
.29284 .41247 .29944 .42053 .31034 .40963 .30224 .42393 Mtetra
.668 .815 .375 r
.30224 .42393 .31034 .40963 .32054 .4097 .31394 .40221 Mtetra
.6 .705 .917 r
.31394 .40221 .32054 .4097 .33096 .40699 .32436 .39998 Mtetra
.626 .73 .922 r
.32436 .39998 .33096 .40699 .34144 .40416 .33486 .39709 Mtetra
.615 .725 .924 r
.33486 .39709 .34144 .40416 .35192 .40236 .3454 .39444 Mtetra
.105 .43 .872 r
.3454 .39444 .35192 .40236 .36295 .39045 .3556 .39916 Mtetra
.668 .879 .508 r
.3556 .39916 .36295 .39045 .37336 .39144 .36689 .38375 Mtetra
.599 .702 .915 r
.36689 .38375 .37336 .39144 .38402 .38856 .37753 .38148 Mtetra
.634 .735 .92 r
.37753 .38148 .38402 .38856 .39473 .38534 .38827 .37833 Mtetra
.64 .74 .921 r
.38827 .37833 .39473 .38534 .4055 .38206 .39906 .37502 Mtetra
.638 .739 .922 r
.39906 .37502 .4055 .38206 .4163 .37898 .40989 .37177 Mtetra
.615 .726 .925 r
.40989 .37177 .4163 .37898 .4271 .37771 .42076 .36904 Mtetra
.966 .652 .369 r
.42076 .36904 .4271 .37771 .43822 .36673 .42839 .47838 Mtetra
0 0 .182 r
.42839 .47838 .43822 .36673 .4491 .36558 .44278 .35799 Mtetra
.618 .717 .917 r
.44278 .35799 .4491 .36558 .46008 .36234 .45378 .35518 Mtetra
.644 .741 .92 r
.45378 .35518 .46008 .36234 .47112 .35877 .46484 .3517 Mtetra
.651 .747 .92 r
.46484 .3517 .47112 .35877 .4822 .35507 .47595 .34801 Mtetra
.654 .75 .92 r
.47595 .34801 .4822 .35507 .49333 .35128 .48711 .34423 Mtetra
.656 .752 .92 r
.48711 .34423 .49333 .35128 .50451 .34742 .49832 .34036 Mtetra
.658 .753 .92 r
.49832 .34036 .50451 .34742 .51573 .34353 .50957 .33645 Mtetra
.659 .754 .92 r
.50957 .33645 .51573 .34353 .527 .3396 .52087 .3325 Mtetra
.52087 .3325 .527 .3396 .53832 .33565 .53222 .32852 Mtetra
.53222 .32852 .53832 .33565 .54968 .33169 .54361 .32453 Mtetra
.54361 .32453 .54968 .33169 .56109 .32772 .55505 .32052 Mtetra
.658 .753 .92 r
.55505 .32052 .56109 .32772 .57254 .32374 .56654 .31651 Mtetra
.56654 .31651 .57254 .32374 .58404 .31975 .57807 .31249 Mtetra
.57807 .31249 .58404 .31975 .59559 .31575 .58965 .30846 Mtetra
.58965 .30846 .59559 .31575 .60719 .31174 .60128 .30441 Mtetra
.60128 .30441 .60719 .31174 .61883 .30772 .61295 .30036 Mtetra
.61295 .30036 .61883 .30772 .63052 .30368 .62468 .29628 Mtetra
.62468 .29628 .63052 .30368 .64226 .29962 .63645 .2922 Mtetra
.657 .753 .92 r
.63645 .2922 .64226 .29962 .65405 .29555 .64828 .28809 Mtetra
.64828 .28809 .65405 .29555 .66589 .29147 .66015 .28398 Mtetra
.66015 .28398 .66589 .29147 .67778 .28737 .67208 .27984 Mtetra
.67208 .27984 .67778 .28737 .68972 .28325 .68405 .27569 Mtetra
.657 .752 .92 r
.68405 .27569 .68972 .28325 .70171 .27912 .69608 .27153 Mtetra
.69608 .27153 .70171 .27912 .71375 .27497 .70815 .26735 Mtetra
.70815 .26735 .71375 .27497 .72584 .2708 .72028 .26315 Mtetra
.72028 .26315 .72584 .2708 .73799 .26662 .73246 .25893 Mtetra
.73246 .25893 .73799 .26662 .75018 .26242 .74469 .2547 Mtetra
.74469 .2547 .75018 .26242 .76243 .2582 .75697 .25045 Mtetra
.75697 .25045 .76243 .2582 .77473 .25397 .76931 .24618 Mtetra
.76931 .24618 .77473 .25397 .78708 .24972 .7817 .24189 Mtetra
.568 .691 .923 r
.12461 .45898 .1316 .46624 .14115 .46498 .13419 .45751 Mtetra
.302 .562 .928 r
.13419 .45751 .14115 .46498 .15213 .4515 .1434 .45963 Mtetra
.624 .897 .585 r
.1434 .45963 .15213 .4515 .16115 .45562 .15425 .44798 Mtetra
.559 .677 .918 r
.15425 .44798 .16115 .45562 .17088 .45386 .16393 .44673 Mtetra
.552 .691 .932 r
.16393 .44673 .17088 .45386 .17995 .45884 .17367 .44551 Mtetra
.758 .643 .734 r
.17367 .44551 .17995 .45884 .19109 .44433 .18451 .4341 Mtetra
.429 .545 .871 r
.18451 .4341 .19109 .44433 .20093 .44274 .19403 .43563 Mtetra
.593 .709 .924 r
.19403 .43563 .20093 .44274 .21082 .4411 .20398 .4336 Mtetra
.386 .607 .936 r
.20398 .4336 .21082 .4411 .22204 .42571 .21365 .43484 Mtetra
0 0 0 r
.21365 .43484 .22204 .42571 .23133 .43131 .22456 .42349 Mtetra
.566 .678 .915 r
.22456 .42349 .23133 .43131 .24139 .42912 .23457 .42205 Mtetra
.602 .716 .925 r
.23457 .42205 .24139 .42912 .25146 .42746 .24471 .41978 Mtetra
.274 .542 .921 r
.24471 .41978 .25146 .42746 .26249 .41461 .25448 .42239 Mtetra
.654 .903 .576 r
.25448 .42239 .26249 .41461 .27228 .41728 .26558 .40956 Mtetra
.581 .69 .916 r
.26558 .40956 .27228 .41728 .28254 .41484 .2758 .40777 Mtetra
.615 .723 .923 r
.2758 .40777 .28254 .41484 .29284 .41247 .28613 .40517 Mtetra
.557 .695 .932 r
.28613 .40517 .29284 .41247 .30224 .42393 .29643 .40376 Mtetra
.708 .567 .694 r
.29643 .40376 .30224 .42393 .31394 .40221 .30743 .39277 Mtetra
.504 .608 .89 r
.30743 .39277 .31394 .40221 .32436 .39998 .31771 .39279 Mtetra
.62 .724 .921 r
.31771 .39279 .32436 .39998 .33486 .39709 .32823 .39002 Mtetra
.625 .73 .922 r
.32823 .39002 .33486 .39709 .3454 .39444 .3388 .38711 Mtetra
.578 .705 .929 r
.3388 .38711 .3454 .39444 .3556 .39916 .34937 .38526 Mtetra
.763 .647 .733 r
.34937 .38526 .3556 .39916 .36689 .38375 .36051 .37324 Mtetra
.468 .565 .871 r
.36051 .37324 .36689 .38375 .37753 .38148 .37101 .37418 Mtetra
.625 .726 .919 r
.37101 .37418 .37753 .38148 .38827 .37833 .38176 .37124 Mtetra
.639 .738 .921 r
.38176 .37124 .38827 .37833 .39906 .37502 .39257 .36795 Mtetra
.64 .74 .921 r
.39257 .36795 .39906 .37502 .40989 .37177 .40343 .3646 Mtetra
.631 .735 .923 r
.40343 .3646 .40989 .37177 .42076 .36904 .41434 .36146 Mtetra
.55 .69 .932 r
.41434 .36146 .42076 .36904 .42839 .47838 .42523 .36013 Mtetra
.566 .355 .553 r
.42523 .36013 .42839 .47838 .44278 .35799 .43645 .34904 Mtetra
.554 .652 .9 r
.43645 .34904 .44278 .35799 .45378 .35518 .44743 .34783 Mtetra
.636 .734 .919 r
.44743 .34783 .45378 .35518 .46484 .3517 .45852 .34452 Mtetra
.648 .745 .92 r
.45852 .34452 .46484 .3517 .47595 .34801 .46966 .34088 Mtetra
.653 .749 .92 r
.46966 .34088 .47595 .34801 .48711 .34423 .48085 .3371 Mtetra
.655 .751 .92 r
.48085 .3371 .48711 .34423 .49832 .34036 .49208 .33324 Mtetra
.657 .752 .92 r
.49208 .33324 .49832 .34036 .50957 .33645 .50337 .32931 Mtetra
.658 .753 .92 r
.50337 .32931 .50957 .33645 .52087 .3325 .5147 .32534 Mtetra
.659 .754 .92 r
.5147 .32534 .52087 .3325 .53222 .32852 .52607 .32133 Mtetra
.52607 .32133 .53222 .32852 .54361 .32453 .5375 .31731 Mtetra
.5375 .31731 .54361 .32453 .55505 .32052 .54897 .31328 Mtetra
.54897 .31328 .55505 .32052 .56654 .31651 .56048 .30923 Mtetra
.658 .753 .92 r
.56048 .30923 .56654 .31651 .57807 .31249 .57205 .30517 Mtetra
.57205 .30517 .57807 .31249 .58965 .30846 .58366 .30111 Mtetra
.58366 .30111 .58965 .30846 .60128 .30441 .59532 .29703 Mtetra
.59532 .29703 .60128 .30441 .61295 .30036 .60703 .29294 Mtetra
.60703 .29294 .61295 .30036 .62468 .29628 .61879 .28883 Mtetra
.61879 .28883 .62468 .29628 .63645 .2922 .6306 .28471 Mtetra
.657 .753 .92 r
.6306 .28471 .63645 .2922 .64828 .28809 .64246 .28058 Mtetra
.64246 .28058 .64828 .28809 .66015 .28398 .65437 .27643 Mtetra
.65437 .27643 .66015 .28398 .67208 .27984 .66633 .27226 Mtetra
.66633 .27226 .67208 .27984 .68405 .27569 .67833 .26808 Mtetra
.657 .752 .92 r
.67833 .26808 .68405 .27569 .69608 .27153 .6904 .26388 Mtetra
.6904 .26388 .69608 .27153 .70815 .26735 .70251 .25967 Mtetra
.70251 .25967 .70815 .26735 .72028 .26315 .71467 .25543 Mtetra
.71467 .25543 .72028 .26315 .73246 .25893 .72688 .25118 Mtetra
.72688 .25118 .73246 .25893 .74469 .2547 .73915 .24692 Mtetra
.73915 .24692 .74469 .2547 .75697 .25045 .75147 .24263 Mtetra
.75147 .24263 .75697 .25045 .76931 .24618 .76385 .23833 Mtetra
.76385 .23833 .76931 .24618 .7817 .24189 .77627 .23401 Mtetra
.491 .615 .902 r
.11775 .45025 .12461 .45898 .13419 .45751 .12715 .45036 Mtetra
.556 .692 .93 r
.12715 .45036 .13419 .45751 .1434 .45963 .13677 .44905 Mtetra
.802 .689 .74 r
.13677 .44905 .1434 .45963 .15425 .44798 .14786 .43547 Mtetra
.309 .424 .816 r
.14786 .43547 .15425 .44798 .16393 .44673 .15694 .43955 Mtetra
.582 .702 .925 r
.15694 .43955 .16393 .44673 .17367 .44551 .16675 .43774 Mtetra
.001 .371 .838 r
.16675 .43774 .17367 .44551 .18451 .4341 .17588 .44269 Mtetra
.75 .941 .61 r
.17588 .44269 .18451 .4341 .19403 .43563 .18714 .42807 Mtetra
.575 .689 .919 r
.18714 .42807 .19403 .43563 .20398 .4336 .19705 .42643 Mtetra
.574 .702 .929 r
.19705 .42643 .20398 .4336 .21365 .43484 .20702 .42473 Mtetra
.824 .705 .733 r
.20702 .42473 .21365 .43484 .22456 .42349 .21835 .40923 Mtetra
.27 .368 .78 r
.21835 .40923 .22456 .42349 .23457 .42205 .22771 .4148 Mtetra
.6 .711 .922 r
.22771 .4148 .23457 .42205 .24471 .41978 .23786 .41255 Mtetra
.573 .702 .93 r
.23786 .41255 .24471 .41978 .25448 .42239 .24802 .41084 Mtetra
.791 .681 .742 r
.24802 .41084 .25448 .42239 .26558 .40956 .25915 .39789 Mtetra
.391 .494 .844 r
.25915 .39789 .26558 .40956 .2758 .40777 .26902 .40051 Mtetra
.61 .717 .921 r
.26902 .40051 .2758 .40777 .28613 .40517 .27937 .39801 Mtetra
.605 .719 .925 r
.27937 .39801 .28613 .40517 .29643 .40376 .28975 .39558 Mtetra
0 0 .456 r
.28975 .39558 .29643 .40376 .30743 .39277 .29922 .40703 Mtetra
.677 .822 .384 r
.29922 .40703 .30743 .39277 .31771 .39279 .31104 .38517 Mtetra
.6 .705 .917 r
.31104 .38517 .31771 .39279 .32823 .39002 .32155 .38287 Mtetra
.626 .73 .922 r
.32155 .38287 .32823 .39002 .3388 .38711 .33215 .37992 Mtetra
.615 .725 .924 r
.33215 .37992 .3388 .38711 .34937 .38526 .34278 .37721 Mtetra
.109 .432 .873 r
.34278 .37721 .34937 .38526 .36051 .37324 .35306 .3819 Mtetra
.677 .885 .517 r
.35306 .3819 .36051 .37324 .37101 .37418 .36446 .36636 Mtetra
.599 .702 .915 r
.36446 .36636 .37101 .37418 .38176 .37124 .3752 .36403 Mtetra
.634 .735 .92 r
.3752 .36403 .38176 .37124 .39257 .36795 .38604 .36081 Mtetra
.64 .74 .921 r
.38604 .36081 .39257 .36795 .40343 .3646 .39693 .35743 Mtetra
.638 .739 .922 r
.39693 .35743 .40343 .3646 .41434 .36146 .40786 .35411 Mtetra
.615 .726 .925 r
.40786 .35411 .41434 .36146 .42523 .36013 .41882 .35131 Mtetra
.966 .651 .364 r
.41882 .35131 .42523 .36013 .43645 .34904 .42646 .46107 Mtetra
0 0 .175 r
.42646 .46107 .43645 .34904 .44743 .34783 .44105 .3401 Mtetra
.618 .717 .917 r
.44105 .3401 .44743 .34783 .45852 .34452 .45215 .33722 Mtetra
.644 .741 .92 r
.45215 .33722 .45852 .34452 .46966 .34088 .46332 .33367 Mtetra
.651 .747 .92 r
.46332 .33367 .46966 .34088 .48085 .3371 .47453 .32991 Mtetra
.654 .75 .92 r
.47453 .32991 .48085 .3371 .49208 .33324 .4858 .32605 Mtetra
.656 .752 .92 r
.4858 .32605 .49208 .33324 .50337 .32931 .49711 .32211 Mtetra
.658 .753 .92 r
.49711 .32211 .50337 .32931 .5147 .32534 .50847 .31812 Mtetra
.659 .754 .92 r
.50847 .31812 .5147 .32534 .52607 .32133 .51988 .31409 Mtetra
.51988 .31409 .52607 .32133 .5375 .31731 .53134 .31004 Mtetra
.53134 .31004 .5375 .31731 .54897 .31328 .54284 .30597 Mtetra
.54284 .30597 .54897 .31328 .56048 .30923 .55439 .30189 Mtetra
.658 .753 .92 r
.55439 .30189 .56048 .30923 .57205 .30517 .56598 .2978 Mtetra
.56598 .2978 .57205 .30517 .58366 .30111 .57763 .2937 Mtetra
.57763 .2937 .58366 .30111 .59532 .29703 .58932 .28959 Mtetra
.58932 .28959 .59532 .29703 .60703 .29294 .60107 .28546 Mtetra
.60107 .28546 .60703 .29294 .61879 .28883 .61286 .28133 Mtetra
.61286 .28133 .61879 .28883 .6306 .28471 .6247 .27717 Mtetra
.6247 .27717 .6306 .28471 .64246 .28058 .63659 .27301 Mtetra
.657 .753 .92 r
.63659 .27301 .64246 .28058 .65437 .27643 .64854 .26882 Mtetra
.64854 .26882 .65437 .27643 .66633 .27226 .66053 .26462 Mtetra
.66053 .26462 .66633 .27226 .67833 .26808 .67257 .26041 Mtetra
.67257 .26041 .67833 .26808 .6904 .26388 .68467 .25617 Mtetra
.657 .752 .92 r
.68467 .25617 .6904 .26388 .70251 .25967 .69682 .25192 Mtetra
.69682 .25192 .70251 .25967 .71467 .25543 .70902 .24766 Mtetra
.70902 .24766 .71467 .25543 .72688 .25118 .72127 .24337 Mtetra
.72127 .24337 .72688 .25118 .73915 .24692 .73357 .23907 Mtetra
.73357 .23907 .73915 .24692 .75147 .24263 .74593 .23475 Mtetra
.74593 .23475 .75147 .24263 .76385 .23833 .75834 .23042 Mtetra
.75834 .23042 .76385 .23833 .77627 .23401 .77081 .22606 Mtetra
.719 .79 .308 r
.10613 .4787 .11775 .45025 .12715 .45036 .12008 .44299 Mtetra
.568 .691 .923 r
.12008 .44299 .12715 .45036 .13677 .44905 .12974 .44147 Mtetra
.303 .562 .928 r
.12974 .44147 .13677 .44905 .14786 .43547 .13902 .44355 Mtetra
.635 .904 .596 r
.13902 .44355 .14786 .43547 .15694 .43955 .14997 .4318 Mtetra
.558 .677 .918 r
.14997 .4318 .15694 .43955 .16675 .43774 .15973 .43049 Mtetra
.552 .691 .932 r
.15973 .43049 .16675 .43774 .17588 .44269 .16954 .42921 Mtetra
.759 .643 .734 r
.16954 .42921 .17588 .44269 .18714 .42807 .18049 .41771 Mtetra
.429 .544 .871 r
.18049 .41771 .18714 .42807 .19705 .42643 .19008 .4192 Mtetra
.593 .709 .924 r
.19008 .4192 .19705 .42643 .20702 .42473 .20011 .41711 Mtetra
.387 .607 .936 r
.20011 .41711 .20702 .42473 .21835 .40923 .20986 .4183 Mtetra
0 0 0 r
.20986 .4183 .21835 .40923 .22771 .4148 .22087 .40686 Mtetra
.566 .678 .915 r
.22087 .40686 .22771 .4148 .23786 .41255 .23097 .40536 Mtetra
.602 .716 .924 r
.23097 .40536 .23786 .41255 .24802 .41084 .24119 .40303 Mtetra
.276 .543 .921 r
.24119 .40303 .24802 .41084 .25915 .39789 .25104 .4056 Mtetra
.664 .91 .586 r
.25104 .4056 .25915 .39789 .26902 .40051 .26224 .39266 Mtetra
.581 .69 .916 r
.26224 .39266 .26902 .40051 .27937 .39801 .27255 .39081 Mtetra
.615 .723 .923 r
.27255 .39081 .27937 .39801 .28975 .39558 .28297 .38815 Mtetra
.557 .695 .932 r
.28297 .38815 .28975 .39558 .29922 .40703 .29336 .38668 Mtetra
.708 .567 .693 r
.29336 .38668 .29922 .40703 .31104 .38517 .30446 .37559 Mtetra
.503 .608 .89 r
.30446 .37559 .31104 .38517 .32155 .38287 .31483 .37555 Mtetra
.62 .724 .921 r
.31483 .37555 .32155 .38287 .33215 .37992 .32544 .37272 Mtetra
.625 .73 .922 r
.32544 .37272 .33215 .37992 .34278 .37721 .33611 .36975 Mtetra
.578 .705 .929 r
.33611 .36975 .34278 .37721 .35306 .3819 .34677 .36783 Mtetra
.764 .647 .733 r
.34677 .36783 .35306 .3819 .36446 .36636 .35801 .35571 Mtetra
.468 .565 .871 r
.35801 .35571 .36446 .36636 .3752 .36403 .36861 .3566 Mtetra
.625 .726 .919 r
.36861 .3566 .3752 .36403 .38604 .36081 .37946 .35359 Mtetra
.639 .738 .921 r
.37946 .35359 .38604 .36081 .39693 .35743 .39037 .35023 Mtetra
.64 .74 .921 r
.39037 .35023 .39693 .35743 .40786 .35411 .40133 .34681 Mtetra
.631 .735 .923 r
.40133 .34681 .40786 .35411 .41882 .35131 .41233 .3436 Mtetra
.55 .69 .932 r
.41233 .3436 .41882 .35131 .42646 .46107 .42332 .3422 Mtetra
.564 .351 .55 r
.42332 .3422 .42646 .46107 .44105 .3401 .43466 .33101 Mtetra
.554 .652 .9 r
.43466 .33101 .44105 .3401 .45215 .33722 .44574 .32974 Mtetra
.636 .734 .919 r
.44574 .32974 .45215 .33722 .46332 .33367 .45693 .32636 Mtetra
.648 .745 .92 r
.45693 .32636 .46332 .33367 .47453 .32991 .46817 .32264 Mtetra
.653 .749 .92 r
.46817 .32264 .47453 .32991 .4858 .32605 .47947 .31879 Mtetra
.655 .751 .92 r
.47947 .31879 .4858 .32605 .49711 .32211 .49081 .31485 Mtetra
.657 .752 .92 r
.49081 .31485 .49711 .32211 .50847 .31812 .5022 .31085 Mtetra
.658 .753 .92 r
.5022 .31085 .50847 .31812 .51988 .31409 .51364 .3068 Mtetra
.659 .754 .92 r
.51364 .3068 .51988 .31409 .53134 .31004 .52513 .30271 Mtetra
.52513 .30271 .53134 .31004 .54284 .30597 .53666 .29861 Mtetra
.53666 .29861 .54284 .30597 .55439 .30189 .54824 .2945 Mtetra
.54824 .2945 .55439 .30189 .56598 .2978 .55987 .29037 Mtetra
.658 .753 .92 r
.55987 .29037 .56598 .2978 .57763 .2937 .57155 .28624 Mtetra
.57155 .28624 .57763 .2937 .58932 .28959 .58328 .28209 Mtetra
.58328 .28209 .58932 .28959 .60107 .28546 .59505 .27793 Mtetra
.59505 .27793 .60107 .28546 .61286 .28133 .60688 .27376 Mtetra
.60688 .27376 .61286 .28133 .6247 .27717 .61875 .26957 Mtetra
.61875 .26957 .6247 .27717 .63659 .27301 .63068 .26537 Mtetra
.657 .753 .92 r
.63068 .26537 .63659 .27301 .64854 .26882 .64266 .26116 Mtetra
.64266 .26116 .64854 .26882 .66053 .26462 .65469 .25692 Mtetra
.65469 .25692 .66053 .26462 .67257 .26041 .66677 .25267 Mtetra
.66677 .25267 .67257 .26041 .68467 .25617 .6789 .24841 Mtetra
.657 .752 .92 r
.6789 .24841 .68467 .25617 .69682 .25192 .69108 .24412 Mtetra
.69108 .24412 .69682 .25192 .70902 .24766 .70332 .23982 Mtetra
.70332 .23982 .70902 .24766 .72127 .24337 .71561 .2355 Mtetra
.71561 .2355 .72127 .24337 .73357 .23907 .72795 .23117 Mtetra
.72795 .23117 .73357 .23907 .74593 .23475 .74034 .22681 Mtetra
.74034 .22681 .74593 .23475 .75834 .23042 .75279 .22244 Mtetra
.75279 .22244 .75834 .23042 .77081 .22606 .76529 .21805 Mtetra
.644 .471 .635 r
.10241 .44428 .10613 .4787 .12008 .44299 .11314 .43413 Mtetra
.491 .615 .902 r
.11314 .43413 .12008 .44299 .12974 .44147 .12261 .4342 Mtetra
.556 .692 .93 r
.12261 .4342 .12974 .44147 .13902 .44355 .13231 .43283 Mtetra
.803 .69 .74 r
.13231 .43283 .13902 .44355 .14997 .4318 .14352 .41915 Mtetra
.308 .423 .816 r
.14352 .41915 .14997 .4318 .15973 .43049 .15266 .42319 Mtetra
.582 .702 .925 r
.15266 .42319 .15973 .43049 .16954 .42921 .16255 .42133 Mtetra
.006 .374 .839 r
.16255 .42133 .16954 .42921 .18049 .41771 .17174 .42625 Mtetra
.757 .946 .618 r
.17174 .42625 .18049 .41771 .19008 .4192 .18311 .41152 Mtetra
.575 .689 .919 r
.18311 .41152 .19008 .4192 .20011 .41711 .19311 .40982 Mtetra
.574 .702 .929 r
.19311 .40982 .20011 .41711 .20986 .4183 .20316 .40806 Mtetra
.825 .705 .733 r
.20316 .40806 .20986 .4183 .22087 .40686 .2146 .39244 Mtetra
.268 .367 .779 r
.2146 .39244 .22087 .40686 .23097 .40536 .22403 .39798 Mtetra
.6 .711 .922 r
.22403 .39798 .23097 .40536 .24119 .40303 .23427 .39567 Mtetra
.573 .702 .93 r
.23427 .39567 .24119 .40303 .25104 .4056 .2445 .3939 Mtetra
.792 .681 .742 r
.2445 .3939 .25104 .4056 .26224 .39266 .25574 .38084 Mtetra
.39 .493 .844 r
.25574 .38084 .26224 .39266 .27255 .39081 .2657 .38342 Mtetra
.61 .717 .921 r
.2657 .38342 .27255 .39081 .28297 .38815 .27613 .38086 Mtetra
.605 .719 .925 r
.27613 .38086 .28297 .38815 .29336 .38668 .28661 .37837 Mtetra
0 0 .464 r
.28661 .37837 .29336 .38668 .30446 .37559 .29614 .38981 Mtetra
.686 .829 .393 r
.29614 .38981 .30446 .37559 .31483 .37555 .30809 .3678 Mtetra
.599 .705 .917 r
.30809 .3678 .31483 .37555 .32544 .37272 .31869 .36544 Mtetra
.626 .73 .922 r
.31869 .36544 .32544 .37272 .33611 .36975 .32938 .36242 Mtetra
.615 .725 .924 r
.32938 .36242 .33611 .36975 .34677 .36783 .34011 .35964 Mtetra
.113 .434 .874 r
.34011 .35964 .34677 .36783 .35801 .35571 .35048 .3643 Mtetra
.686 .892 .526 r
.35048 .3643 .35801 .35571 .36861 .3566 .36199 .34864 Mtetra
.599 .702 .915 r
.36199 .34864 .36861 .3566 .37946 .35359 .37283 .34624 Mtetra
.634 .735 .92 r
.37283 .34624 .37946 .35359 .39037 .35023 .38376 .34296 Mtetra
.64 .74 .921 r
.38376 .34296 .39037 .35023 .40133 .34681 .39475 .33951 Mtetra
.638 .739 .922 r
.39475 .33951 .40133 .34681 .41233 .3436 .40579 .33611 Mtetra
.615 .726 .925 r
.40579 .33611 .41233 .3436 .42332 .3422 .41685 .33325 Mtetra
.966 .65 .359 r
.41685 .33325 .42332 .3422 .43466 .33101 .42449 .44341 Mtetra
0 0 .168 r
.42449 .44341 .43466 .33101 .44574 .32974 .43929 .32187 Mtetra
.618 .718 .917 r
.43929 .32187 .44574 .32974 .45693 .32636 .45049 .31892 Mtetra
.644 .741 .92 r
.45049 .31892 .45693 .32636 .46817 .32264 .46176 .31529 Mtetra
.651 .747 .92 r
.46176 .31529 .46817 .32264 .47947 .31879 .47309 .31146 Mtetra
.654 .75 .92 r
.47309 .31146 .47947 .31879 .49081 .31485 .48446 .30752 Mtetra
.656 .752 .92 r
.48446 .30752 .49081 .31485 .5022 .31085 .49588 .30351 Mtetra
.658 .753 .92 r
.49588 .30351 .5022 .31085 .51364 .3068 .50735 .29944 Mtetra
.659 .754 .92 r
.50735 .29944 .51364 .3068 .52513 .30271 .51887 .29533 Mtetra
.51887 .29533 .52513 .30271 .53666 .29861 .53043 .2912 Mtetra
.53043 .2912 .53666 .29861 .54824 .2945 .54205 .28705 Mtetra
.54205 .28705 .54824 .2945 .55987 .29037 .55371 .28289 Mtetra
.658 .753 .92 r
.55371 .28289 .55987 .29037 .57155 .28624 .56542 .27872 Mtetra
.56542 .27872 .57155 .28624 .58328 .28209 .57718 .27454 Mtetra
.57718 .27454 .58328 .28209 .59505 .27793 .58899 .27034 Mtetra
.58899 .27034 .59505 .27793 .60688 .27376 .60085 .26614 Mtetra
.60085 .26614 .60688 .27376 .61875 .26957 .61276 .26192 Mtetra
.61276 .26192 .61875 .26957 .63068 .26537 .62472 .25768 Mtetra
.62472 .25768 .63068 .26537 .64266 .26116 .63673 .25343 Mtetra
.657 .753 .92 r
.63673 .25343 .64266 .26116 .65469 .25692 .6488 .24916 Mtetra
.6488 .24916 .65469 .25692 .66677 .25267 .66091 .24488 Mtetra
.66091 .24488 .66677 .25267 .6789 .24841 .67308 .24058 Mtetra
.67308 .24058 .6789 .24841 .69108 .24412 .6853 .23626 Mtetra
.657 .752 .92 r
.6853 .23626 .69108 .24412 .70332 .23982 .69757 .23192 Mtetra
.69757 .23192 .70332 .23982 .71561 .2355 .7099 .22757 Mtetra
.7099 .22757 .71561 .2355 .72795 .23117 .72228 .2232 Mtetra
.72228 .2232 .72795 .23117 .74034 .22681 .73471 .21881 Mtetra
.73471 .21881 .74034 .22681 .75279 .22244 .7472 .2144 Mtetra
.7472 .2144 .75279 .22244 .76529 .21805 .75974 .20998 Mtetra
.934 .559 .243 r
.09532 .43601 .10241 .44428 .11314 .43413 .10135 .46261 Mtetra
.727 .796 .317 r
.10135 .46261 .11314 .43413 .12261 .4342 .11547 .4267 Mtetra
.568 .691 .923 r
.11547 .4267 .12261 .4342 .13231 .43283 .1252 .42512 Mtetra
.305 .563 .928 r
.1252 .42512 .13231 .43283 .14352 .41915 .13456 .42716 Mtetra
.646 .912 .607 r
.13456 .42716 .14352 .41915 .15266 .42319 .1456 .41532 Mtetra
.558 .677 .918 r
.1456 .41532 .15266 .42319 .16255 .42133 .15545 .41395 Mtetra
.552 .691 .932 r
.15545 .41395 .16255 .42133 .17174 .42625 .16534 .41262 Mtetra
.759 .644 .734 r
.16534 .41262 .17174 .42625 .18311 .41152 .17639 .40102 Mtetra
.428 .544 .872 r
.17639 .40102 .18311 .41152 .19311 .40982 .18606 .40246 Mtetra
.593 .709 .924 r
.18606 .40246 .19311 .40982 .20316 .40806 .19617 .40031 Mtetra
.388 .607 .936 r
.19617 .40031 .20316 .40806 .2146 .39244 .206 .40146 Mtetra
0 0 0 r
.206 .40146 .2146 .39244 .22403 .39798 .21711 .38991 Mtetra
.566 .678 .915 r
.21711 .38991 .22403 .39798 .23427 .39567 .22729 .38835 Mtetra
.602 .716 .924 r
.22729 .38835 .23427 .39567 .2445 .3939 .2376 .38596 Mtetra
.278 .543 .921 r
.2376 .38596 .2445 .3939 .25574 .38084 .24753 .38849 Mtetra
.673 .916 .595 r
.24753 .38849 .25574 .38084 .2657 .38342 .25884 .37545 Mtetra
.581 .69 .916 r
.25884 .37545 .2657 .38342 .27613 .38086 .26924 .37353 Mtetra
.615 .723 .923 r
.26924 .37353 .27613 .38086 .28661 .37837 .27975 .3708 Mtetra
.557 .695 .932 r
.27975 .3708 .28661 .37837 .29614 .38981 .29023 .36928 Mtetra
.708 .567 .693 r
.29023 .36928 .29614 .38981 .30809 .3678 .30144 .35809 Mtetra
.503 .608 .89 r
.30144 .35809 .30809 .3678 .31869 .36544 .3119 .35799 Mtetra
.62 .724 .921 r
.3119 .35799 .31869 .36544 .32938 .36242 .3226 .35509 Mtetra
.625 .73 .922 r
.3226 .35509 .32938 .36242 .34011 .35964 .33337 .35205 Mtetra
.578 .705 .929 r
.33337 .35205 .34011 .35964 .35048 .3643 .34412 .35007 Mtetra
.764 .648 .733 r
.34412 .35007 .35048 .3643 .36199 .34864 .35548 .33784 Mtetra
.467 .565 .871 r
.35548 .33784 .36199 .34864 .37283 .34624 .36616 .33868 Mtetra
.625 .726 .919 r
.36616 .33868 .37283 .34624 .38376 .34296 .37711 .3356 Mtetra
.639 .738 .921 r
.37711 .3356 .38376 .34296 .39475 .33951 .38812 .33216 Mtetra
.64 .74 .921 r
.38812 .33216 .39475 .33951 .40579 .33611 .39919 .32867 Mtetra
.631 .735 .923 r
.39919 .32867 .40579 .33611 .41685 .33325 .41029 .32539 Mtetra
.55 .69 .932 r
.41029 .32539 .41685 .33325 .42449 .44341 .42138 .32393 Mtetra
.562 .348 .548 r
.42138 .32393 .42449 .44341 .43929 .32187 .43283 .31263 Mtetra
.554 .652 .9 r
.43283 .31263 .43929 .32187 .45049 .31892 .44401 .31129 Mtetra
.636 .734 .919 r
.44401 .31129 .45049 .31892 .46176 .31529 .45531 .30784 Mtetra
.648 .745 .92 r
.45531 .30784 .46176 .31529 .47309 .31146 .46666 .30405 Mtetra
.653 .749 .92 r
.46666 .30405 .47309 .31146 .48446 .30752 .47806 .30012 Mtetra
.655 .751 .92 r
.47806 .30012 .48446 .30752 .49588 .30351 .48951 .2961 Mtetra
.657 .752 .92 r
.48951 .2961 .49588 .30351 .50735 .29944 .50101 .29202 Mtetra
.658 .753 .92 r
.50101 .29202 .50735 .29944 .51887 .29533 .51256 .28789 Mtetra
.659 .754 .92 r
.51256 .28789 .51887 .29533 .53043 .2912 .52416 .28372 Mtetra
.52416 .28372 .53043 .2912 .54205 .28705 .53581 .27954 Mtetra
.53581 .27954 .54205 .28705 .55371 .28289 .5475 .27535 Mtetra
.5475 .27535 .55371 .28289 .56542 .27872 .55925 .27114 Mtetra
.658 .753 .92 r
.55925 .27114 .56542 .27872 .57718 .27454 .57104 .26692 Mtetra
.57104 .26692 .57718 .27454 .58899 .27034 .58288 .26269 Mtetra
.58288 .26269 .58899 .27034 .60085 .26614 .59478 .25845 Mtetra
.59478 .25845 .60085 .26614 .61276 .26192 .60672 .2542 Mtetra
.60672 .2542 .61276 .26192 .62472 .25768 .61872 .24993 Mtetra
.61872 .24993 .62472 .25768 .63673 .25343 .63076 .24564 Mtetra
.657 .753 .92 r
.63076 .24564 .63673 .25343 .6488 .24916 .64286 .24134 Mtetra
.64286 .24134 .6488 .24916 .66091 .24488 .65501 .23702 Mtetra
.65501 .23702 .66091 .24488 .67308 .24058 .66722 .23268 Mtetra
.66722 .23268 .67308 .24058 .6853 .23626 .67947 .22833 Mtetra
.657 .752 .92 r
.67947 .22833 .6853 .23626 .69757 .23192 .69178 .22396 Mtetra
.69178 .22396 .69757 .23192 .7099 .22757 .70414 .21957 Mtetra
.70414 .21957 .7099 .22757 .72228 .2232 .71656 .21516 Mtetra
.71656 .21516 .72228 .2232 .73471 .21881 .72903 .21074 Mtetra
.72903 .21074 .73471 .21881 .7472 .2144 .74156 .2063 Mtetra
.74156 .2063 .7472 .2144 .75974 .20998 .75414 .20183 Mtetra
.509 .67 .935 r
.08808 .42856 .09532 .43601 .10135 .46261 .09762 .42796 Mtetra
.643 .47 .634 r
.09762 .42796 .10135 .46261 .11547 .4267 .10846 .41771 Mtetra
.49 .615 .902 r
.10846 .41771 .11547 .4267 .1252 .42512 .118 .41773 Mtetra
.557 .692 .93 r
.118 .41773 .1252 .42512 .13456 .42716 .12778 .41631 Mtetra
.803 .69 .74 r
.12778 .41631 .13456 .42716 .1456 .41532 .13909 .40252 Mtetra
.306 .422 .816 r
.13909 .40252 .1456 .41532 .15545 .41395 .1483 .40653 Mtetra
.582 .702 .925 r
.1483 .40653 .15545 .41395 .16534 .41262 .15826 .40461 Mtetra
.01 .376 .841 r
.15826 .40461 .16534 .41262 .17639 .40102 .16753 .40949 Mtetra
.764 .95 .625 r
.16753 .40949 .17639 .40102 .18606 .40246 .17901 .39465 Mtetra
.575 .689 .919 r
.17901 .39465 .18606 .40246 .19617 .40031 .18909 .39289 Mtetra
.574 .702 .929 r
.18909 .39289 .19617 .40031 .206 .40146 .19922 .39108 Mtetra
.826 .706 .733 r
.19922 .39108 .206 .40146 .21711 .38991 .21078 .37534 Mtetra
.266 .365 .779 r
.21078 .37534 .21711 .38991 .22729 .38835 .22028 .38085 Mtetra
.6 .711 .922 r
.22028 .38085 .22729 .38835 .2376 .38596 .2306 .37848 Mtetra
.573 .702 .929 r
.2306 .37848 .2376 .38596 .24753 .38849 .24093 .37664 Mtetra
.792 .682 .742 r
.24093 .37664 .24753 .38849 .25884 .37545 .25227 .36348 Mtetra
.389 .493 .844 r
.25227 .36348 .25884 .37545 .26924 .37353 .26231 .36601 Mtetra
.61 .717 .921 r
.26231 .36601 .26924 .37353 .27975 .3708 .27284 .36338 Mtetra
.605 .719 .925 r
.27284 .36338 .27975 .3708 .29023 .36928 .2834 .36082 Mtetra
0 0 .472 r
.2834 .36082 .29023 .36928 .30144 .35809 .29301 .37226 Mtetra
.694 .836 .402 r
.29301 .37226 .30144 .35809 .3119 .35799 .30508 .35011 Mtetra
.599 .705 .917 r
.30508 .35011 .3119 .35799 .3226 .35509 .31578 .34768 Mtetra
.626 .73 .922 r
.31578 .34768 .3226 .35509 .33337 .35205 .32657 .34459 Mtetra
.615 .725 .924 r
.32657 .34459 .33337 .35205 .34412 .35007 .33739 .34174 Mtetra
.117 .436 .875 r
.33739 .34174 .34412 .35007 .35548 .33784 .34785 .34635 Mtetra
.694 .898 .535 r
.34785 .34635 .35548 .33784 .36616 .33868 .35947 .33058 Mtetra
.599 .702 .915 r
.35947 .33058 .36616 .33868 .37711 .3356 .37041 .32811 Mtetra
.634 .735 .92 r
.37041 .32811 .37711 .3356 .38812 .33216 .38145 .32475 Mtetra
.64 .74 .921 r
.38145 .32475 .38812 .33216 .39919 .32867 .39254 .32123 Mtetra
.638 .739 .922 r
.39254 .32123 .39919 .32867 .41029 .32539 .40367 .31776 Mtetra
.615 .726 .925 r
.40367 .31776 .41029 .32539 .42138 .32393 .41484 .31482 Mtetra
.966 .648 .354 r
.41484 .31482 .42138 .32393 .43283 .31263 .42248 .42539 Mtetra
0 0 .16 r
.42248 .42539 .43283 .31263 .44401 .31129 .43749 .30328 Mtetra
.618 .718 .917 r
.43749 .30328 .44401 .31129 .45531 .30784 .4488 .30026 Mtetra
.644 .741 .92 r
.4488 .30026 .45531 .30784 .46666 .30405 .46018 .29655 Mtetra
.651 .747 .92 r
.46018 .29655 .46666 .30405 .47806 .30012 .47161 .29264 Mtetra
.654 .75 .92 r
.47161 .29264 .47806 .30012 .48951 .2961 .48309 .28862 Mtetra
.656 .752 .92 r
.48309 .28862 .48951 .2961 .50101 .29202 .49463 .28453 Mtetra
.658 .753 .92 r
.49463 .28453 .50101 .29202 .51256 .28789 .50621 .28038 Mtetra
.659 .754 .92 r
.50621 .28038 .51256 .28789 .52416 .28372 .51784 .27619 Mtetra
.51784 .27619 .52416 .28372 .53581 .27954 .52952 .27198 Mtetra
.52952 .27198 .53581 .27954 .5475 .27535 .54124 .26775 Mtetra
.54124 .26775 .5475 .27535 .55925 .27114 .55302 .2635 Mtetra
.658 .753 .92 r
.55302 .2635 .55925 .27114 .57104 .26692 .56485 .25925 Mtetra
.56485 .25925 .57104 .26692 .58288 .26269 .57672 .25499 Mtetra
.57672 .25499 .58288 .26269 .59478 .25845 .58865 .25071 Mtetra
.58865 .25071 .59478 .25845 .60672 .2542 .60063 .24642 Mtetra
.60063 .24642 .60672 .2542 .61872 .24993 .61266 .24211 Mtetra
.61266 .24211 .61872 .24993 .63076 .24564 .62474 .23779 Mtetra
.62474 .23779 .63076 .24564 .64286 .24134 .63688 .23345 Mtetra
.657 .753 .92 r
.63688 .23345 .64286 .24134 .65501 .23702 .64907 .2291 Mtetra
.64907 .2291 .65501 .23702 .66722 .23268 .6613 .22473 Mtetra
.6613 .22473 .66722 .23268 .67947 .22833 .6736 .22034 Mtetra
.6736 .22034 .67947 .22833 .69178 .22396 .68594 .21593 Mtetra
.657 .752 .92 r
.68594 .21593 .69178 .22396 .70414 .21957 .69834 .21151 Mtetra
.69834 .21151 .70414 .21957 .71656 .21516 .7108 .20707 Mtetra
.7108 .20707 .71656 .21516 .72903 .21074 .72331 .2026 Mtetra
.72331 .2026 .72903 .21074 .74156 .2063 .73587 .19812 Mtetra
.73587 .19812 .74156 .2063 .75414 .20183 .74849 .19363 Mtetra
.56 .689 .926 r
.08079 .42103 .08808 .42856 .09762 .42796 .09046 .41956 Mtetra
.934 .557 .237 r
.09046 .41956 .09762 .42796 .10846 .41771 .09648 .44622 Mtetra
.736 .803 .325 r
.09648 .44622 .10846 .41771 .118 .41773 .11077 .41011 Mtetra
.568 .691 .923 r
.11077 .41011 .118 .41773 .12778 .41631 .12058 .40848 Mtetra
.306 .563 .928 r
.12058 .40848 .12778 .41631 .13909 .40252 .13001 .41047 Mtetra
.656 .919 .617 r
.13001 .41047 .13909 .40252 .1483 .40653 .14116 .39853 Mtetra
.558 .677 .918 r
.14116 .39853 .1483 .40653 .15826 .40461 .15108 .39711 Mtetra
.552 .691 .931 r
.15108 .39711 .15826 .40461 .16753 .40949 .16105 .39572 Mtetra
.759 .644 .734 r
.16105 .39572 .16753 .40949 .17901 .39465 .17221 .38401 Mtetra
.427 .544 .872 r
.17221 .38401 .17901 .39465 .18909 .39289 .18196 .38541 Mtetra
.593 .709 .924 r
.18196 .38541 .18909 .39289 .19922 .39108 .19215 .3832 Mtetra
.389 .608 .936 r
.19215 .3832 .19922 .39108 .21078 .37534 .20206 .38429 Mtetra
.517 .823 .498 r
.20206 .38429 .21078 .37534 .22028 .38085 .21328 .37265 Mtetra
.566 .678 .915 r
.21328 .37265 .22028 .38085 .2306 .37848 .22355 .37103 Mtetra
.602 .716 .924 r
.22355 .37103 .2306 .37848 .24093 .37664 .23395 .36857 Mtetra
.28 .544 .921 r
.23395 .36857 .24093 .37664 .25227 .36348 .24396 .37106 Mtetra
.682 .922 .605 r
.24396 .37106 .25227 .36348 .26231 .36601 .25538 .3579 Mtetra
.581 .69 .916 r
.25538 .3579 .26231 .36601 .27284 .36338 .26587 .35592 Mtetra
.615 .723 .923 r
.26587 .35592 .27284 .36338 .2834 .36082 .27647 .35313 Mtetra
.558 .695 .932 r
.27647 .35313 .2834 .36082 .29301 .37226 .28704 .35154 Mtetra
.708 .567 .693 r
.28704 .35154 .29301 .37226 .30508 .35011 .29836 .34025 Mtetra
.502 .608 .89 r
.29836 .34025 .30508 .35011 .31578 .34768 .30891 .34009 Mtetra
.62 .724 .921 r
.30891 .34009 .31578 .34768 .32657 .34459 .31971 .33712 Mtetra
.625 .73 .922 r
.31971 .33712 .32657 .34459 .33739 .34174 .33057 .33401 Mtetra
.578 .705 .929 r
.33057 .33401 .33739 .34174 .34785 .34635 .34142 .33196 Mtetra
.764 .648 .734 r
.34142 .33196 .34785 .34635 .35947 .33058 .35289 .31963 Mtetra
.467 .565 .871 r
.35289 .31963 .35947 .33058 .37041 .32811 .36367 .32041 Mtetra
.625 .726 .919 r
.36367 .32041 .37041 .32811 .38145 .32475 .37472 .31726 Mtetra
.639 .738 .921 r
.37472 .31726 .38145 .32475 .39254 .32123 .38583 .31374 Mtetra
.64 .74 .921 r
.38583 .31374 .39254 .32123 .40367 .31776 .397 .31018 Mtetra
.631 .735 .923 r
.397 .31018 .40367 .31776 .41484 .31482 .40821 .30682 Mtetra
.55 .69 .932 r
.40821 .30682 .41484 .31482 .42248 .42539 .4194 .30529 Mtetra
.559 .344 .545 r
.4194 .30529 .42248 .42539 .43749 .30328 .43096 .29389 Mtetra
.553 .652 .9 r
.43096 .29389 .43749 .30328 .4488 .30026 .44225 .29248 Mtetra
.636 .734 .919 r
.44225 .29248 .4488 .30026 .46018 .29655 .45365 .28895 Mtetra
.648 .745 .92 r
.45365 .28895 .46018 .29655 .47161 .29264 .46511 .28508 Mtetra
.653 .749 .92 r
.46511 .28508 .47161 .29264 .48309 .28862 .47663 .28107 Mtetra
.655 .751 .92 r
.47663 .28107 .48309 .28862 .49463 .28453 .48819 .27697 Mtetra
.657 .752 .92 r
.48819 .27697 .49463 .28453 .50621 .28038 .4998 .27281 Mtetra
.658 .753 .92 r
.4998 .27281 .50621 .28038 .51784 .27619 .51146 .2686 Mtetra
.659 .754 .92 r
.51146 .2686 .51784 .27619 .52952 .27198 .52317 .26435 Mtetra
.52317 .26435 .52952 .27198 .54124 .26775 .53494 .26009 Mtetra
.53494 .26009 .54124 .26775 .55302 .2635 .54675 .25581 Mtetra
.54675 .25581 .55302 .2635 .56485 .25925 .55861 .25152 Mtetra
.658 .753 .92 r
.55861 .25152 .56485 .25925 .57672 .25499 .57052 .24722 Mtetra
.57052 .24722 .57672 .25499 .58865 .25071 .58248 .2429 Mtetra
.58248 .2429 .58865 .25071 .60063 .24642 .59449 .23858 Mtetra
.59449 .23858 .60063 .24642 .61266 .24211 .60656 .23424 Mtetra
.60656 .23424 .61266 .24211 .62474 .23779 .61868 .22988 Mtetra
.61868 .22988 .62474 .23779 .63688 .23345 .63085 .22551 Mtetra
.657 .753 .92 r
.63085 .22551 .63688 .23345 .64907 .2291 .64307 .22112 Mtetra
.64307 .22112 .64907 .2291 .6613 .22473 .65535 .21671 Mtetra
.65535 .21671 .6613 .22473 .6736 .22034 .66767 .21228 Mtetra
.66767 .21228 .6736 .22034 .68594 .21593 .68006 .20784 Mtetra
.657 .752 .92 r
.68006 .20784 .68594 .21593 .69834 .21151 .6925 .20338 Mtetra
.6925 .20338 .69834 .21151 .7108 .20707 .70499 .1989 Mtetra
.70499 .1989 .7108 .20707 .72331 .2026 .71753 .1944 Mtetra
.71753 .1944 .72331 .2026 .73587 .19812 .73014 .18989 Mtetra
.73014 .18989 .73587 .19812 .74849 .19363 .74279 .18535 Mtetra
.51 .638 .911 r
.0736 .41245 .08079 .42103 .09046 .41956 .08313 .41198 Mtetra
.509 .67 .935 r
.08313 .41198 .09046 .41956 .09648 .44622 .09274 .41133 Mtetra
.642 .469 .633 r
.09274 .41133 .09648 .44622 .11077 .41011 .10368 .40099 Mtetra
.49 .615 .902 r
.10368 .40099 .11077 .41011 .12058 .40848 .1133 .40096 Mtetra
.557 .692 .93 r
.1133 .40096 .12058 .40848 .13001 .41047 .12315 .39948 Mtetra
.804 .691 .74 r
.12315 .39948 .13001 .41047 .14116 .39853 .13458 .38558 Mtetra
.304 .421 .816 r
.13458 .38558 .14116 .39853 .15108 .39711 .14385 .38956 Mtetra
.582 .702 .925 r
.14385 .38956 .15108 .39711 .16105 .39572 .1539 .38757 Mtetra
.015 .378 .842 r
.1539 .38757 .16105 .39572 .17221 .38401 .16323 .39242 Mtetra
.77 .954 .632 r
.16323 .39242 .17221 .38401 .18196 .38541 .17482 .37747 Mtetra
.574 .689 .919 r
.17482 .37747 .18196 .38541 .19215 .3832 .18499 .37565 Mtetra
.574 .702 .929 r
.18499 .37565 .19215 .3832 .20206 .38429 .19521 .37377 Mtetra
.826 .707 .733 r
.19521 .37377 .20206 .38429 .21328 .37265 .20688 .35792 Mtetra
.264 .364 .779 r
.20688 .35792 .21328 .37265 .22355 .37103 .21646 .36339 Mtetra
.6 .711 .922 r
.21646 .36339 .22355 .37103 .23395 .36857 .22687 .36095 Mtetra
.573 .702 .929 r
.22687 .36095 .23395 .36857 .24396 .37106 .23728 .35906 Mtetra
.793 .683 .743 r
.23728 .35906 .24396 .37106 .25538 .3579 .24874 .34578 Mtetra
.388 .492 .844 r
.24874 .34578 .25538 .3579 .26587 .35592 .25886 .34827 Mtetra
.61 .717 .921 r
.25886 .34827 .26587 .35592 .27647 .35313 .26948 .34557 Mtetra
.605 .719 .925 r
.26948 .34557 .27647 .35313 .28704 .35154 .28014 .34295 Mtetra
0 0 .48 r
.28014 .34295 .28704 .35154 .29836 .34025 .28981 .35437 Mtetra
.703 .843 .411 r
.28981 .35437 .29836 .34025 .30891 .34009 .30202 .33207 Mtetra
.599 .705 .918 r
.30202 .33207 .30891 .34009 .31971 .33712 .31281 .32957 Mtetra
.626 .73 .922 r
.31281 .32957 .31971 .33712 .33057 .33401 .32369 .32641 Mtetra
.615 .725 .924 r
.32369 .32641 .33057 .33401 .34142 .33196 .33461 .32349 Mtetra
.12 .437 .876 r
.33461 .32349 .34142 .33196 .35289 .31963 .34516 .32806 Mtetra
.703 .904 .544 r
.34516 .32806 .35289 .31963 .36367 .32041 .35691 .31216 Mtetra
.599 .702 .916 r
.35691 .31216 .36367 .32041 .37472 .31726 .36794 .30963 Mtetra
.634 .735 .92 r
.36794 .30963 .37472 .31726 .38583 .31374 .37908 .30619 Mtetra
.64 .74 .921 r
.37908 .30619 .38583 .31374 .397 .31018 .39027 .30259 Mtetra
.638 .739 .922 r
.39027 .30259 .397 .31018 .40821 .30682 .40152 .29905 Mtetra
.615 .726 .925 r
.40152 .29905 .40821 .30682 .4194 .30529 .41279 .29604 Mtetra
.966 .647 .349 r
.41279 .29604 .4194 .30529 .43096 .29389 .42043 .407 Mtetra
0 0 .153 r
.42043 .407 .43096 .29389 .44225 .29248 .43566 .28432 Mtetra
.618 .718 .917 r
.43566 .28432 .44225 .29248 .45365 .28895 .44708 .28122 Mtetra
.644 .741 .92 r
.44708 .28122 .45365 .28895 .46511 .28508 .45856 .27743 Mtetra
.651 .747 .92 r
.45856 .27743 .46511 .28508 .47663 .28107 .47011 .27344 Mtetra
.654 .75 .92 r
.47011 .27344 .47663 .28107 .48819 .27697 .4817 .26935 Mtetra
.656 .752 .92 r
.4817 .26935 .48819 .27697 .4998 .27281 .49335 .26517 Mtetra
.658 .753 .92 r
.49335 .26517 .4998 .27281 .51146 .2686 .50504 .26094 Mtetra
.659 .754 .92 r
.50504 .26094 .51146 .2686 .52317 .26435 .51678 .25667 Mtetra
.51678 .25667 .52317 .26435 .53494 .26009 .52858 .25237 Mtetra
.52858 .25237 .53494 .26009 .54675 .25581 .54042 .24805 Mtetra
.54042 .24805 .54675 .25581 .55861 .25152 .55232 .24373 Mtetra
.658 .753 .92 r
.55232 .24373 .55861 .25152 .57052 .24722 .56426 .23939 Mtetra
.56426 .23939 .57052 .24722 .58248 .2429 .57626 .23504 Mtetra
.57626 .23504 .58248 .2429 .59449 .23858 .58831 .23067 Mtetra
.58831 .23067 .59449 .23858 .60656 .23424 .60041 .2263 Mtetra
.60041 .2263 .60656 .23424 .61868 .22988 .61256 .2219 Mtetra
.61256 .2219 .61868 .22988 .63085 .22551 .62477 .21749 Mtetra
.62477 .21749 .63085 .22551 .64307 .22112 .63703 .21307 Mtetra
.657 .753 .92 r
.63703 .21307 .64307 .22112 .65535 .21671 .64934 .20862 Mtetra
.64934 .20862 .65535 .21671 .66767 .21228 .6617 .20416 Mtetra
.6617 .20416 .66767 .21228 .68006 .20784 .67413 .19968 Mtetra
.67413 .19968 .68006 .20784 .6925 .20338 .6866 .19519 Mtetra
.657 .752 .92 r
.6866 .19519 .6925 .20338 .70499 .1989 .69913 .19067 Mtetra
.69913 .19067 .70499 .1989 .71753 .1944 .71172 .18614 Mtetra
.71172 .18614 .71753 .1944 .73014 .18989 .72436 .18158 Mtetra
.72436 .18158 .73014 .18989 .74279 .18535 .73705 .17701 Mtetra
0 0 .158 r
.07595 .33628 .0736 .41245 .08313 .41198 .07576 .40433 Mtetra
.56 .689 .926 r
.07576 .40433 .08313 .41198 .09274 .41133 .0855 .40281 Mtetra
.933 .555 .232 r
.0855 .40281 .09274 .41133 .10368 .40099 .09153 .42953 Mtetra
.744 .809 .334 r
.09153 .42953 .10368 .40099 .1133 .40096 .10598 .39321 Mtetra
.568 .691 .923 r
.10598 .39321 .1133 .40096 .12315 .39948 .11588 .39152 Mtetra
.308 .564 .928 r
.11588 .39152 .12315 .39948 .13458 .38558 .12537 .39347 Mtetra
.666 .925 .627 r
.12537 .39347 .13458 .38558 .14385 .38956 .13664 .38142 Mtetra
.558 .677 .918 r
.13664 .38142 .14385 .38956 .1539 .38757 .14664 .37994 Mtetra
.552 .691 .931 r
.14664 .37994 .1539 .38757 .16323 .39242 .15669 .37849 Mtetra
.76 .645 .734 r
.15669 .37849 .16323 .39242 .17482 .37747 .16796 .36669 Mtetra
.427 .544 .872 r
.16796 .36669 .17482 .37747 .18499 .37565 .17778 .36804 Mtetra
.593 .709 .924 r
.17778 .36804 .18499 .37565 .19521 .37377 .18806 .36576 Mtetra
.39 .608 .936 r
.18806 .36576 .19521 .37377 .20688 .35792 .19805 .3668 Mtetra
.531 .834 .512 r
.19805 .3668 .20688 .35792 .21646 .36339 .20938 .35505 Mtetra
.566 .678 .915 r
.20938 .35505 .21646 .36339 .22687 .36095 .21973 .35337 Mtetra
.602 .716 .924 r
.21973 .35337 .22687 .36095 .23728 .35906 .23022 .35085 Mtetra
.282 .545 .921 r
.23022 .35085 .23728 .35906 .24874 .34578 .24031 .35329 Mtetra
.691 .928 .614 r
.24031 .35329 .24874 .34578 .25886 .34827 .25185 .34002 Mtetra
.581 .69 .916 r
.25185 .34002 .25886 .34827 .26948 .34557 .26243 .33798 Mtetra
.615 .723 .923 r
.26243 .33798 .26948 .34557 .28014 .34295 .27313 .33511 Mtetra
.558 .695 .931 r
.27313 .33511 .28014 .34295 .28981 .35437 .28379 .33346 Mtetra
.708 .566 .693 r
.28379 .33346 .28981 .35437 .30202 .33207 .29522 .32206 Mtetra
.502 .608 .891 r
.29522 .32206 .30202 .33207 .31281 .32957 .30586 .32185 Mtetra
.62 .724 .921 r
.30586 .32185 .31281 .32957 .32369 .32641 .31676 .3188 Mtetra
.625 .73 .922 r
.31676 .3188 .32369 .32641 .33461 .32349 .32772 .31562 Mtetra
.578 .705 .929 r
.32772 .31562 .33461 .32349 .34516 .32806 .33867 .3135 Mtetra
.765 .649 .734 r
.33867 .3135 .34516 .32806 .35691 .31216 .35025 .30106 Mtetra
.466 .565 .871 r
.35025 .30106 .35691 .31216 .36794 .30963 .36113 .30178 Mtetra
.625 .726 .92 r
.36113 .30178 .36794 .30963 .37908 .30619 .37228 .29855 Mtetra
.639 .738 .921 r
.37228 .29855 .37908 .30619 .39027 .30259 .3835 .29496 Mtetra
.64 .74 .921 r
.3835 .29496 .39027 .30259 .40152 .29905 .39477 .29132 Mtetra
.631 .735 .923 r
.39477 .29132 .40152 .29905 .41279 .29604 .40608 .28788 Mtetra
.55 .69 .932 r
.40608 .28788 .41279 .29604 .42043 .407 .41738 .28628 Mtetra
.557 .341 .542 r
.41738 .28628 .42043 .407 .43566 .28432 .42906 .27478 Mtetra
.553 .652 .901 r
.42906 .27478 .43566 .28432 .44708 .28122 .44045 .2733 Mtetra
.636 .734 .919 r
.44045 .2733 .44708 .28122 .45856 .27743 .45196 .26969 Mtetra
.648 .745 .92 r
.45196 .26969 .45856 .27743 .47011 .27344 .46354 .26574 Mtetra
.653 .749 .92 r
.46354 .26574 .47011 .27344 .4817 .26935 .47516 .26164 Mtetra
.655 .751 .92 r
.47516 .26164 .4817 .26935 .49335 .26517 .48684 .25746 Mtetra
.657 .752 .92 r
.48684 .25746 .49335 .26517 .50504 .26094 .49856 .25321 Mtetra
.658 .753 .92 r
.49856 .25321 .50504 .26094 .51678 .25667 .51034 .24892 Mtetra
.659 .754 .92 r
.51034 .24892 .51678 .25667 .52858 .25237 .52217 .24459 Mtetra
.52217 .24459 .52858 .25237 .54042 .24805 .53405 .24024 Mtetra
.53405 .24024 .54042 .24805 .55232 .24373 .54598 .23587 Mtetra
.54598 .23587 .55232 .24373 .56426 .23939 .55796 .2315 Mtetra
.658 .753 .92 r
.55796 .2315 .56426 .23939 .57626 .23504 .56999 .22711 Mtetra
.56999 .22711 .57626 .23504 .58831 .23067 .58207 .22271 Mtetra
.58207 .22271 .58831 .23067 .60041 .2263 .59421 .21829 Mtetra
.59421 .21829 .60041 .2263 .61256 .2219 .6064 .21386 Mtetra
.6064 .21386 .61256 .2219 .62477 .21749 .61864 .20942 Mtetra
.61864 .20942 .62477 .21749 .63703 .21307 .63093 .20495 Mtetra
.657 .753 .92 r
.63093 .20495 .63703 .21307 .64934 .20862 .64328 .20047 Mtetra
.64328 .20047 .64934 .20862 .6617 .20416 .65569 .19598 Mtetra
.65569 .19598 .6617 .20416 .67413 .19968 .66814 .19146 Mtetra
.66814 .19146 .67413 .19968 .6866 .19519 .68066 .18693 Mtetra
.657 .752 .92 r
.68066 .18693 .6866 .19519 .69913 .19067 .69322 .18237 Mtetra
.69322 .18237 .69913 .19067 .71172 .18614 .70585 .1778 Mtetra
.70585 .1778 .71172 .18614 .72436 .18158 .71853 .17321 Mtetra
.71853 .17321 .72436 .18158 .73705 .17701 .73127 .1686 Mtetra
.41 .14 .391 r
.05752 .40586 .07595 .33628 .07576 .40433 .06848 .39562 Mtetra
.51 .638 .911 r
.06848 .39562 .07576 .40433 .0855 .40281 .07809 .3951 Mtetra
.509 .67 .935 r
.07809 .3951 .0855 .40281 .09153 .42953 .08778 .39439 Mtetra
.641 .467 .632 r
.08778 .39439 .09153 .42953 .10598 .39321 .09881 .38396 Mtetra
.49 .615 .902 r
.09881 .38396 .10598 .39321 .11588 .39152 .10851 .38387 Mtetra
.557 .692 .93 r
.10851 .38387 .11588 .39152 .12537 .39347 .11845 .38234 Mtetra
.804 .692 .741 r
.11845 .38234 .12537 .39347 .13664 .38142 .12998 .36832 Mtetra
.303 .42 .816 r
.12998 .36832 .13664 .38142 .14664 .37994 .13932 .37226 Mtetra
.582 .702 .925 r
.13932 .37226 .14664 .37994 .15669 .37849 .14946 .37021 Mtetra
.019 .381 .844 r
.14946 .37021 .15669 .37849 .16796 .36669 .15886 .37503 Mtetra
.777 .957 .639 r
.15886 .37503 .16796 .36669 .17778 .36804 .17056 .35996 Mtetra
.574 .689 .919 r
.17056 .35996 .17778 .36804 .18806 .36576 .18082 .35807 Mtetra
.574 .702 .929 r
.18082 .35807 .18806 .36576 .19805 .3668 .19112 .35613 Mtetra
.827 .708 .733 r
.19112 .35613 .19805 .3668 .20938 .35505 .20292 .34016 Mtetra
.261 .363 .779 r
.20292 .34016 .20938 .35505 .21973 .35337 .21256 .3456 Mtetra
.6 .711 .922 r
.21256 .3456 .21973 .35337 .23022 .35085 .22306 .34309 Mtetra
.573 .702 .929 r
.22306 .34309 .23022 .35085 .24031 .35329 .23357 .34113 Mtetra
.794 .683 .743 r
.23357 .34113 .24031 .35329 .25185 .34002 .24514 .32775 Mtetra
.387 .492 .844 r
.24514 .32775 .25185 .34002 .26243 .33798 .25534 .33018 Mtetra
.61 .717 .921 r
.25534 .33018 .26243 .33798 .27313 .33511 .26605 .32742 Mtetra
.605 .719 .925 r
.26605 .32742 .27313 .33511 .28379 .33346 .27681 .32472 Mtetra
0 0 .488 r
.27681 .32472 .28379 .33346 .29522 .32206 .28656 .33613 Mtetra
.711 .849 .42 r
.28656 .33613 .29522 .32206 .30586 .32185 .29889 .31368 Mtetra
.599 .705 .918 r
.29889 .31368 .30586 .32185 .31676 .3188 .30978 .31111 Mtetra
.626 .73 .922 r
.30978 .31111 .31676 .3188 .32772 .31562 .32076 .30788 Mtetra
.615 .725 .924 r
.32076 .30788 .32772 .31562 .33867 .3135 .33179 .30489 Mtetra
.124 .439 .877 r
.33179 .30489 .33867 .3135 .35025 .30106 .34242 .30941 Mtetra
.711 .91 .553 r
.34242 .30941 .35025 .30106 .36113 .30178 .35429 .29339 Mtetra
.599 .702 .916 r
.35429 .29339 .36113 .30178 .37228 .29855 .36543 .29078 Mtetra
.634 .735 .92 r
.36543 .29078 .37228 .29855 .3835 .29496 .37667 .28726 Mtetra
.64 .74 .921 r
.37667 .28726 .3835 .29496 .39477 .29132 .38797 .28359 Mtetra
.638 .739 .922 r
.38797 .28359 .39477 .29132 .40608 .28788 .39932 .27996 Mtetra
.615 .726 .925 r
.39932 .27996 .40608 .28788 .41738 .28628 .4107 .27687 Mtetra
.966 .646 .343 r
.4107 .27687 .41738 .28628 .42906 .27478 .41833 .38824 Mtetra
0 0 .146 r
.41833 .38824 .42906 .27478 .44045 .2733 .43379 .26499 Mtetra
.618 .718 .917 r
.43379 .26499 .44045 .2733 .45196 .26969 .44532 .2618 Mtetra
.644 .741 .92 r
.44532 .2618 .45196 .26969 .46354 .26574 .45692 .25794 Mtetra
.651 .747 .92 r
.45692 .25794 .46354 .26574 .47516 .26164 .46857 .25386 Mtetra
.654 .75 .92 r
.46857 .25386 .47516 .26164 .48684 .25746 .48028 .24968 Mtetra
.656 .752 .92 r
.48028 .24968 .48684 .25746 .49856 .25321 .49204 .24542 Mtetra
.658 .753 .92 r
.49204 .24542 .49856 .25321 .51034 .24892 .50385 .2411 Mtetra
.659 .754 .92 r
.50385 .2411 .51034 .24892 .52217 .24459 .51571 .23675 Mtetra
.51571 .23675 .52217 .24459 .53405 .24024 .52762 .23236 Mtetra
.52762 .23236 .53405 .24024 .54598 .23587 .53958 .22796 Mtetra
.53958 .22796 .54598 .23587 .55796 .2315 .5516 .22355 Mtetra
.658 .753 .92 r
.5516 .22355 .55796 .2315 .56999 .22711 .56366 .21912 Mtetra
.56366 .21912 .56999 .22711 .58207 .22271 .57578 .21468 Mtetra
.57578 .21468 .58207 .22271 .59421 .21829 .58796 .21023 Mtetra
.58796 .21023 .59421 .21829 .6064 .21386 .60018 .20576 Mtetra
.60018 .20576 .6064 .21386 .61864 .20942 .61246 .20128 Mtetra
.61246 .20128 .61864 .20942 .63093 .20495 .62479 .19678 Mtetra
.62479 .19678 .63093 .20495 .64328 .20047 .63718 .19226 Mtetra
.657 .753 .92 r
.63718 .19226 .64328 .20047 .65569 .19598 .64962 .18772 Mtetra
.64962 .18772 .65569 .19598 .66814 .19146 .66211 .18317 Mtetra
.66211 .18317 .66814 .19146 .68066 .18693 .67466 .1786 Mtetra
.67466 .1786 .68066 .18693 .69322 .18237 .68727 .17401 Mtetra
.657 .752 .92 r
.68727 .17401 .69322 .18237 .70585 .1778 .69993 .16939 Mtetra
.69993 .16939 .70585 .1778 .71853 .17321 .71265 .16476 Mtetra
.71265 .16476 .71853 .17321 .73127 .1686 .72543 .16012 Mtetra
.918 .702 .593 r
.0502 .39684 .05752 .40586 .06848 .39562 .07095 .31906 Mtetra
0 0 .15 r
.07095 .31906 .06848 .39562 .07809 .3951 .07063 .38732 Mtetra
.56 .689 .926 r
.07063 .38732 .07809 .3951 .08778 .39439 .08045 .38573 Mtetra
.932 .553 .226 r
.08045 .38573 .08778 .39439 .09881 .38396 .08647 .41251 Mtetra
.752 .815 .343 r
.08647 .41251 .09881 .38396 .10851 .38387 .10111 .37599 Mtetra
.568 .691 .923 r
.10111 .37599 .10851 .38387 .11845 .38234 .11109 .37424 Mtetra
.309 .564 .928 r
.11109 .37424 .11845 .38234 .12998 .36832 .12065 .37614 Mtetra
.676 .932 .637 r
.12065 .37614 .12998 .36832 .13932 .37226 .13202 .36399 Mtetra
.558 .677 .918 r
.13202 .36399 .13932 .37226 .14946 .37021 .14211 .36245 Mtetra
.552 .691 .931 r
.14211 .36245 .14946 .37021 .15886 .37503 .15224 .36094 Mtetra
.76 .646 .735 r
.15224 .36094 .15886 .37503 .17056 .35996 .16362 .34903 Mtetra
.426 .544 .872 r
.16362 .34903 .17056 .35996 .18082 .35807 .17352 .35033 Mtetra
.593 .709 .924 r
.17352 .35033 .18082 .35807 .19112 .35613 .18389 .34798 Mtetra
.391 .608 .935 r
.18389 .34798 .19112 .35613 .20292 .34016 .19396 .34897 Mtetra
.545 .845 .526 r
.19396 .34897 .20292 .34016 .21256 .3456 .2054 .33712 Mtetra
.566 .678 .915 r
.2054 .33712 .21256 .3456 .22306 .34309 .21584 .33537 Mtetra
.602 .716 .924 r
.21584 .33537 .22306 .34309 .23357 .34113 .22642 .33278 Mtetra
.284 .545 .921 r
.22642 .33278 .23357 .34113 .24514 .32775 .2366 .33517 Mtetra
.7 .934 .623 r
.2366 .33517 .24514 .32775 .25534 .33018 .24825 .32179 Mtetra
.581 .69 .916 r
.24825 .32179 .25534 .33018 .26605 .32742 .25892 .31968 Mtetra
.615 .723 .923 r
.25892 .31968 .26605 .32742 .27681 .32472 .26972 .31674 Mtetra
.558 .695 .931 r
.26972 .31674 .27681 .32472 .28656 .33613 .28047 .31502 Mtetra
.708 .566 .693 r
.28047 .31502 .28656 .33613 .29889 .31368 .29202 .30352 Mtetra
.502 .608 .891 r
.29202 .30352 .29889 .31368 .30978 .31111 .30275 .30324 Mtetra
.62 .724 .921 r
.30275 .30324 .30978 .31111 .32076 .30788 .31375 .30012 Mtetra
.625 .73 .922 r
.31375 .30012 .32076 .30788 .33179 .30489 .32481 .29687 Mtetra
.578 .705 .929 r
.32481 .29687 .33179 .30489 .34242 .30941 .33586 .29467 Mtetra
.765 .65 .734 r
.33586 .29467 .34242 .30941 .35429 .29339 .34756 .28212 Mtetra
.465 .565 .872 r
.34756 .28212 .35429 .29339 .36543 .29078 .35854 .28278 Mtetra
.625 .726 .92 r
.35854 .28278 .36543 .29078 .37667 .28726 .36979 .27947 Mtetra
.639 .738 .921 r
.36979 .27947 .37667 .28726 .38797 .28359 .38112 .27581 Mtetra
.64 .74 .921 r
.38112 .27581 .38797 .28359 .39932 .27996 .39249 .27209 Mtetra
.631 .735 .922 r
.39249 .27209 .39932 .27996 .4107 .27687 .40392 .26857 Mtetra
.551 .69 .932 r
.40392 .26857 .4107 .27687 .41833 .38824 .41532 .2669 Mtetra
.554 .337 .54 r
.41532 .2669 .41833 .38824 .43379 .26499 .42712 .25528 Mtetra
.553 .652 .901 r
.42712 .25528 .43379 .26499 .44532 .2618 .43862 .25373 Mtetra
.636 .734 .919 r
.43862 .25373 .44532 .2618 .45692 .25794 .45024 .25003 Mtetra
.648 .745 .92 r
.45024 .25003 .45692 .25794 .46857 .25386 .46193 .246 Mtetra
.653 .749 .92 r
.46193 .246 .46857 .25386 .48028 .24968 .47367 .24182 Mtetra
.655 .751 .92 r
.47367 .24182 .48028 .24968 .49204 .24542 .48546 .23756 Mtetra
.657 .752 .92 r
.48546 .23756 .49204 .24542 .50385 .2411 .4973 .23322 Mtetra
.658 .753 .92 r
.4973 .23322 .50385 .2411 .51571 .23675 .5092 .22884 Mtetra
.659 .754 .92 r
.5092 .22884 .51571 .23675 .52762 .23236 .52114 .22442 Mtetra
.52114 .22442 .52762 .23236 .53958 .22796 .53314 .21998 Mtetra
.53314 .21998 .53958 .22796 .5516 .22355 .54519 .21553 Mtetra
.54519 .21553 .5516 .22355 .56366 .21912 .55729 .21107 Mtetra
.658 .753 .92 r
.55729 .21107 .56366 .21912 .57578 .21468 .56945 .20659 Mtetra
.56945 .20659 .57578 .21468 .58796 .21023 .58165 .2021 Mtetra
.58165 .2021 .58796 .21023 .60018 .20576 .59391 .19759 Mtetra
.59391 .19759 .60018 .20576 .61246 .20128 .60623 .19307 Mtetra
.60623 .19307 .61246 .20128 .62479 .19678 .6186 .18853 Mtetra
.6186 .18853 .62479 .19678 .63718 .19226 .63102 .18398 Mtetra
.657 .753 .92 r
.63102 .18398 .63718 .19226 .64962 .18772 .6435 .1794 Mtetra
.6435 .1794 .64962 .18772 .66211 .18317 .65603 .17481 Mtetra
.65603 .17481 .66211 .18317 .67466 .1786 .66862 .1702 Mtetra
.66862 .1702 .67466 .1786 .68727 .17401 .68127 .16557 Mtetra
.657 .752 .92 r
.68127 .16557 .68727 .17401 .69993 .16939 .69397 .16092 Mtetra
.69397 .16092 .69993 .16939 .71265 .16476 .70673 .15625 Mtetra
.70673 .15625 .71265 .16476 .72543 .16012 .71955 .15156 Mtetra
.471 .651 .937 r
.04266 .38897 .0502 .39684 .07095 .31906 .0522 .38881 Mtetra
.403 .132 .384 r
.0522 .38881 .07095 .31906 .07063 .38732 .06326 .37847 Mtetra
.51 .638 .911 r
.06326 .37847 .07063 .38732 .08045 .38573 .07295 .3779 Mtetra
.51 .669 .935 r
.07295 .3779 .08045 .38573 .08647 .41251 .08271 .37713 Mtetra
.641 .466 .631 r
.08271 .37713 .08647 .41251 .10111 .37599 .09386 .3666 Mtetra
.489 .615 .902 r
.09386 .3666 .10111 .37599 .11109 .37424 .10363 .36646 Mtetra
.557 .692 .93 r
.10363 .36646 .11109 .37424 .12065 .37614 .11365 .36486 Mtetra
.805 .692 .741 r
.11365 .36486 .12065 .37614 .13202 .36399 .1253 .35074 Mtetra
.301 .42 .816 r
.1253 .35074 .13202 .36399 .14211 .36245 .13471 .35464 Mtetra
.582 .702 .925 r
.13471 .35464 .14211 .36245 .15224 .36094 .14493 .35252 Mtetra
.024 .383 .845 r
.14493 .35252 .15224 .36094 .16362 .34903 .1544 .3573 Mtetra
.783 .961 .646 r
.1544 .3573 .16362 .34903 .17352 .35033 .16622 .34211 Mtetra
.574 .689 .919 r
.16622 .34211 .17352 .35033 .18389 .34798 .17656 .34016 Mtetra
.574 .702 .929 r
.17656 .34016 .18389 .34798 .19396 .34897 .18696 .33815 Mtetra
.828 .709 .733 r
.18696 .33815 .19396 .34897 .2054 .33712 .19887 .32206 Mtetra
.259 .362 .779 r
.19887 .32206 .2054 .33712 .21584 .33537 .20859 .32746 Mtetra
.6 .711 .922 r
.20859 .32746 .21584 .33537 .22642 .33278 .21918 .32489 Mtetra
.574 .702 .929 r
.21918 .32489 .22642 .33278 .2366 .33517 .22978 .32286 Mtetra
.794 .684 .743 r
.22978 .32286 .2366 .33517 .24825 .32179 .24147 .30936 Mtetra
.386 .492 .844 r
.24147 .30936 .24825 .32179 .25892 .31968 .25175 .31174 Mtetra
.61 .717 .921 r
.25175 .31174 .25892 .31968 .26972 .31674 .26256 .3089 Mtetra
.605 .719 .925 r
.26256 .3089 .26972 .31674 .28047 .31502 .27342 .30614 Mtetra
0 0 .495 r
.27342 .30614 .28047 .31502 .29202 .30352 .28323 .31753 Mtetra
.72 .855 .429 r
.28323 .31753 .29202 .30352 .30275 .30324 .2957 .29493 Mtetra
.599 .705 .918 r
.2957 .29493 .30275 .30324 .31375 .30012 .30669 .29229 Mtetra
.626 .73 .922 r
.30669 .29229 .31375 .30012 .32481 .29687 .31778 .28898 Mtetra
.615 .725 .924 r
.31778 .28898 .32481 .29687 .33586 .29467 .3289 .28591 Mtetra
.128 .441 .877 r
.3289 .28591 .33586 .29467 .34756 .28212 .33963 .29038 Mtetra
.719 .915 .561 r
.33963 .29038 .34756 .28212 .35854 .28278 .35162 .27424 Mtetra
.599 .702 .916 r
.35162 .27424 .35854 .28278 .36979 .27947 .36286 .27155 Mtetra
.634 .735 .92 r
.36286 .27155 .36979 .27947 .38112 .27581 .37421 .26796 Mtetra
.64 .74 .921 r
.37421 .26796 .38112 .27581 .39249 .27209 .38562 .2642 Mtetra
.638 .739 .922 r
.38562 .2642 .39249 .27209 .40392 .26857 .39707 .26049 Mtetra
.615 .726 .925 r
.39707 .26049 .40392 .26857 .41532 .2669 .40856 .25733 Mtetra
.966 .645 .338 r
.40856 .25733 .41532 .2669 .42712 .25528 .41619 .36908 Mtetra
0 0 .138 r
.41619 .36908 .42712 .25528 .43862 .25373 .43188 .24526 Mtetra
.618 .718 .917 r
.43188 .24526 .43862 .25373 .45024 .25003 .44352 .242 Mtetra
.644 .741 .92 r
.44352 .242 .45024 .25003 .46193 .246 .45523 .23804 Mtetra
.651 .747 .92 r
.45523 .23804 .46193 .246 .47367 .24182 .467 .23388 Mtetra
.654 .75 .92 r
.467 .23388 .47367 .24182 .48546 .23756 .47883 .22962 Mtetra
.656 .752 .92 r
.47883 .22962 .48546 .23756 .4973 .23322 .4907 .22527 Mtetra
.658 .753 .92 r
.4907 .22527 .4973 .23322 .5092 .22884 .50263 .22086 Mtetra
.659 .754 .92 r
.50263 .22086 .5092 .22884 .52114 .22442 .51461 .21642 Mtetra
.51461 .21642 .52114 .22442 .53314 .21998 .52664 .21194 Mtetra
.52664 .21194 .53314 .21998 .54519 .21553 .53873 .20745 Mtetra
.53873 .20745 .54519 .21553 .55729 .21107 .55087 .20295 Mtetra
.658 .753 .92 r
.55087 .20295 .55729 .21107 .56945 .20659 .56306 .19843 Mtetra
.56306 .19843 .56945 .20659 .58165 .2021 .5753 .1939 Mtetra
.5753 .1939 .58165 .2021 .59391 .19759 .5876 .18936 Mtetra
.5876 .18936 .59391 .19759 .60623 .19307 .59995 .1848 Mtetra
.59995 .1848 .60623 .19307 .6186 .18853 .61235 .18022 Mtetra
.61235 .18022 .6186 .18853 .63102 .18398 .62481 .17562 Mtetra
.62481 .17562 .63102 .18398 .6435 .1794 .63733 .17101 Mtetra
.657 .753 .92 r
.63733 .17101 .6435 .1794 .65603 .17481 .6499 .16638 Mtetra
.6499 .16638 .65603 .17481 .66862 .1702 .66253 .16173 Mtetra
.66253 .16173 .66862 .1702 .68127 .16557 .67521 .15706 Mtetra
.67521 .15706 .68127 .16557 .69397 .16092 .68796 .15238 Mtetra
.657 .752 .92 r
.68796 .15238 .69397 .16092 .70673 .15625 .70075 .14767 Mtetra
.70075 .14767 .70673 .15625 .71955 .15156 .71361 .14294 Mtetra
.549 .683 .927 r
.03507 .38106 .04266 .38897 .0522 .38881 .0448 .37965 Mtetra
.92 .702 .592 r
.0448 .37965 .0522 .38881 .06326 .37847 .06585 .30152 Mtetra
0 0 .143 r
.06585 .30152 .06326 .37847 .07295 .3779 .0654 .36999 Mtetra
.56 .689 .926 r
.0654 .36999 .07295 .3779 .08271 .37713 .0753 .36834 Mtetra
.932 .551 .22 r
.0753 .36834 .08271 .37713 .09386 .3666 .08132 .39517 Mtetra
.759 .821 .351 r
.08132 .39517 .09386 .3666 .10363 .36646 .09614 .35845 Mtetra
.568 .691 .923 r
.09614 .35845 .10363 .36646 .11365 .36486 .1062 .35663 Mtetra
.311 .565 .928 r
.1062 .35663 .11365 .36486 .1253 .35074 .11584 .35849 Mtetra
.685 .938 .647 r
.11584 .35849 .1253 .35074 .13471 .35464 .12732 .34623 Mtetra
.558 .677 .918 r
.12732 .34623 .13471 .35464 .14493 .35252 .13749 .34462 Mtetra
.552 .691 .931 r
.13749 .34462 .14493 .35252 .1544 .3573 .14771 .34305 Mtetra
.761 .646 .735 r
.14771 .34305 .1544 .3573 .16622 .34211 .1592 .33103 Mtetra
.425 .543 .872 r
.1592 .33103 .16622 .34211 .17656 .34016 .16918 .33228 Mtetra
.593 .709 .924 r
.16918 .33228 .17656 .34016 .18696 .33815 .17964 .32986 Mtetra
.392 .608 .935 r
.17964 .32986 .18696 .33815 .19887 .32206 .18979 .3308 Mtetra
.558 .855 .539 r
.18979 .3308 .19887 .32206 .20859 .32746 .20135 .31884 Mtetra
.566 .678 .915 r
.20135 .31884 .20859 .32746 .21918 .32489 .21188 .31703 Mtetra
.602 .716 .924 r
.21188 .31703 .21918 .32489 .22978 .32286 .22255 .31436 Mtetra
.286 .546 .921 r
.22255 .31436 .22978 .32286 .24147 .30936 .23281 .3167 Mtetra
.708 .939 .632 r
.23281 .3167 .24147 .30936 .25175 .31174 .24458 .30321 Mtetra
.581 .69 .916 r
.24458 .30321 .25175 .31174 .26256 .3089 .25535 .30102 Mtetra
.615 .723 .923 r
.25535 .30102 .26256 .3089 .27342 .30614 .26624 .29801 Mtetra
.558 .695 .931 r
.26624 .29801 .27342 .30614 .28323 .31753 .27709 .29622 Mtetra
.708 .566 .693 r
.27709 .29622 .28323 .31753 .2957 .29493 .28875 .28461 Mtetra
.501 .608 .891 r
.28875 .28461 .2957 .29493 .30669 .29229 .29958 .28427 Mtetra
.62 .724 .921 r
.29958 .28427 .30669 .29229 .31778 .28898 .31069 .28107 Mtetra
.625 .73 .922 r
.31069 .28107 .31778 .28898 .3289 .28591 .32185 .27774 Mtetra
.578 .705 .929 r
.32185 .27774 .3289 .28591 .33963 .29038 .333 .27547 Mtetra
.766 .65 .734 r
.333 .27547 .33963 .29038 .35162 .27424 .34482 .26281 Mtetra
.465 .565 .872 r
.34482 .26281 .35162 .27424 .36286 .27155 .35589 .2634 Mtetra
.625 .726 .92 r
.35589 .2634 .36286 .27155 .37421 .26796 .36725 .26002 Mtetra
.639 .738 .921 r
.36725 .26002 .37421 .26796 .38562 .2642 .37869 .25627 Mtetra
.64 .74 .921 r
.37869 .25627 .38562 .2642 .39707 .26049 .39017 .25247 Mtetra
.631 .735 .922 r
.39017 .25247 .39707 .26049 .40856 .25733 .40171 .24886 Mtetra
.551 .69 .931 r
.40171 .24886 .40856 .25733 .41619 .36908 .41322 .24712 Mtetra
.551 .333 .537 r
.41322 .24712 .41619 .36908 .43188 .24526 .42514 .23539 Mtetra
.553 .652 .901 r
.42514 .23539 .43188 .24526 .44352 .242 .43675 .23376 Mtetra
.636 .734 .919 r
.43675 .23376 .44352 .242 .45523 .23804 .44849 .22998 Mtetra
.648 .745 .92 r
.44849 .22998 .45523 .23804 .467 .23388 .46029 .22586 Mtetra
.653 .749 .92 r
.46029 .22586 .467 .23388 .47883 .22962 .47214 .2216 Mtetra
.655 .751 .92 r
.47214 .2216 .47883 .22962 .4907 .22527 .48405 .21724 Mtetra
.657 .752 .92 r
.48405 .21724 .4907 .22527 .50263 .22086 .49601 .21282 Mtetra
.658 .753 .92 r
.49601 .21282 .50263 .22086 .51461 .21642 .50803 .20835 Mtetra
.659 .754 .92 r
.50803 .20835 .51461 .21642 .52664 .21194 .5201 .20384 Mtetra
.5201 .20384 .52664 .21194 .53873 .20745 .53222 .19931 Mtetra
.53222 .19931 .53873 .20745 .55087 .20295 .54439 .19477 Mtetra
.54439 .19477 .55087 .20295 .56306 .19843 .55661 .19021 Mtetra
.658 .753 .92 r
.55661 .19021 .56306 .19843 .5753 .1939 .56889 .18564 Mtetra
.56889 .18564 .5753 .1939 .5876 .18936 .58123 .18105 Mtetra
.58123 .18105 .5876 .18936 .59995 .1848 .59361 .17645 Mtetra
.59361 .17645 .59995 .1848 .61235 .18022 .60606 .17184 Mtetra
.60606 .17184 .61235 .18022 .62481 .17562 .61855 .16721 Mtetra
.61855 .16721 .62481 .17562 .63733 .17101 .63111 .16255 Mtetra
.657 .753 .92 r
.63111 .16255 .63733 .17101 .6499 .16638 .64372 .15788 Mtetra
.64372 .15788 .6499 .16638 .66253 .16173 .65639 .1532 Mtetra
.65639 .1532 .66253 .16173 .67521 .15706 .66911 .14849 Mtetra
.66911 .14849 .67521 .15706 .68796 .15238 .68189 .14376 Mtetra
.657 .752 .92 r
.68189 .14376 .68796 .15238 .70075 .14767 .69473 .13901 Mtetra
.69473 .13901 .70075 .14767 .71361 .14294 .70763 .13424 Mtetra
.491 .623 .909 r
.02761 .37193 .03507 .38106 .0448 .37965 .03717 .37166 Mtetra
.471 .651 .937 r
.03717 .37166 .0448 .37965 .06585 .30152 .04678 .37143 Mtetra
.397 .123 .377 r
.04678 .37143 .06585 .30152 .0654 .36999 .05795 .361 Mtetra
.51 .638 .911 r
.05795 .361 .0654 .36999 .0753 .36834 .06771 .36037 Mtetra
.51 .669 .935 r
.06771 .36037 .0753 .36834 .08132 .39517 .07756 .35955 Mtetra
.64 .465 .63 r
.07756 .35955 .08132 .39517 .09614 .35845 .08881 .34892 Mtetra
.489 .615 .903 r
.08881 .34892 .09614 .35845 .1062 .35663 .09865 .34872 Mtetra
.557 .692 .93 r
.09865 .34872 .1062 .35663 .11584 .35849 .10875 .34706 Mtetra
.805 .693 .741 r
.10875 .34706 .11584 .35849 .12732 .34623 .12052 .33282 Mtetra
.299 .419 .816 r
.12052 .33282 .12732 .34623 .13749 .34462 .13 .33667 Mtetra
.582 .702 .925 r
.13 .33667 .13749 .34462 .14771 .34305 .14031 .33449 Mtetra
.028 .385 .847 r
.14031 .33449 .14771 .34305 .1592 .33103 .14985 .33923 Mtetra
.789 .964 .653 r
.14985 .33923 .1592 .33103 .16918 .33228 .1618 .32392 Mtetra
.574 .689 .919 r
.1618 .32392 .16918 .33228 .17964 .32986 .17222 .3219 Mtetra
.574 .702 .929 r
.17222 .3219 .17964 .32986 .18979 .3308 .18271 .31983 Mtetra
.828 .71 .733 r
.18271 .31983 .18979 .3308 .20135 .31884 .19475 .30361 Mtetra
.257 .361 .778 r
.19475 .30361 .20135 .31884 .21188 .31703 .20454 .30897 Mtetra
.6 .711 .922 r
.20454 .30897 .21188 .31703 .22255 .31436 .21523 .30632 Mtetra
.574 .702 .929 r
.21523 .30632 .22255 .31436 .23281 .3167 .22592 .30422 Mtetra
.795 .685 .743 r
.22592 .30422 .23281 .3167 .24458 .30321 .23772 .29061 Mtetra
.385 .491 .844 r
.23772 .29061 .24458 .30321 .25535 .30102 .24809 .29294 Mtetra
.61 .717 .921 r
.24809 .29294 .25535 .30102 .26624 .29801 .259 .29003 Mtetra
.606 .719 .925 r
.259 .29003 .26624 .29801 .27709 .29622 .26995 .28718 Mtetra
0 0 .503 r
.26995 .28718 .27709 .29622 .28875 .28461 .27985 .29855 Mtetra
.728 .861 .438 r
.27985 .29855 .28875 .28461 .29958 .28427 .29245 .2758 Mtetra
.599 .705 .918 r
.29245 .2758 .29958 .28427 .31069 .28107 .30354 .27309 Mtetra
.626 .73 .922 r
.30354 .27309 .31069 .28107 .32185 .27774 .31473 .2697 Mtetra
.615 .725 .924 r
.31473 .2697 .32185 .27774 .333 .27547 .32596 .26655 Mtetra
.132 .443 .878 r
.32596 .26655 .333 .27547 .34482 .26281 .33678 .27098 Mtetra
.727 .92 .57 r
.33678 .27098 .34482 .26281 .35589 .2634 .34889 .2547 Mtetra
.599 .702 .916 r
.34889 .2547 .35589 .2634 .36725 .26002 .36025 .25194 Mtetra
.634 .735 .92 r
.36025 .25194 .36725 .26002 .37869 .25627 .3717 .24826 Mtetra
.64 .74 .921 r
.3717 .24826 .37869 .25627 .39017 .25247 .38322 .24442 Mtetra
.638 .739 .922 r
.38322 .24442 .39017 .25247 .40171 .24886 .39479 .24063 Mtetra
.615 .726 .925 r
.39479 .24063 .40171 .24886 .41322 .24712 .40638 .23738 Mtetra
.966 .644 .332 r
.40638 .23738 .41322 .24712 .42514 .23539 .41401 .34951 Mtetra
0 0 .131 r
.41401 .34951 .42514 .23539 .43675 .23376 .42993 .22513 Mtetra
.618 .718 .917 r
.42993 .22513 .43675 .23376 .44849 .22998 .44169 .22178 Mtetra
.644 .741 .92 r
.44169 .22178 .44849 .22998 .46029 .22586 .45352 .21774 Mtetra
.651 .747 .92 r
.45352 .21774 .46029 .22586 .47214 .2216 .46541 .21349 Mtetra
.654 .75 .92 r
.46541 .21349 .47214 .2216 .48405 .21724 .47735 .20914 Mtetra
.656 .752 .92 r
.47735 .20914 .48405 .21724 .49601 .21282 .48934 .2047 Mtetra
.658 .753 .92 r
.48934 .2047 .49601 .21282 .50803 .20835 .50139 .2002 Mtetra
.659 .754 .92 r
.50139 .2002 .50803 .20835 .5201 .20384 .51349 .19567 Mtetra
.51349 .19567 .5201 .20384 .53222 .19931 .52565 .1911 Mtetra
.52565 .1911 .53222 .19931 .54439 .19477 .53786 .18652 Mtetra
.53786 .18652 .54439 .19477 .55661 .19021 .55012 .18192 Mtetra
.658 .753 .92 r
.55012 .18192 .55661 .19021 .56889 .18564 .56243 .17731 Mtetra
.56243 .17731 .56889 .18564 .58123 .18105 .5748 .17268 Mtetra
.5748 .17268 .58123 .18105 .59361 .17645 .58723 .16805 Mtetra
.58723 .16805 .59361 .17645 .60606 .17184 .59971 .16339 Mtetra
.59971 .16339 .60606 .17184 .61855 .16721 .61224 .15872 Mtetra
.61224 .15872 .61855 .16721 .63111 .16255 .62484 .15403 Mtetra
.62484 .15403 .63111 .16255 .64372 .15788 .63749 .14932 Mtetra
.657 .753 .92 r
.63749 .14932 .64372 .15788 .65639 .1532 .65019 .14459 Mtetra
.65019 .14459 .65639 .1532 .66911 .14849 .66295 .13984 Mtetra
.66295 .13984 .66911 .14849 .68189 .14376 .67578 .13507 Mtetra
.657 .752 .92 r
.67578 .13507 .68189 .14376 .69473 .13901 .68866 .13028 Mtetra
.68866 .13028 .69473 .13901 .70763 .13424 .70159 .12548 Mtetra
.696 .699 .167 r
0 .48963 .02761 .37193 .03717 .37166 .02949 .36361 Mtetra
.549 .683 .927 r
.02949 .36361 .03717 .37166 .04678 .37143 .0393 .36214 Mtetra
.921 .703 .591 r
.0393 .36214 .04678 .37143 .05795 .361 .06066 .28366 Mtetra
0 0 .135 r
.06066 .28366 .05795 .361 .06771 .36037 .06007 .35232 Mtetra
.56 .689 .926 r
.06007 .35232 .06771 .36037 .07756 .35955 .07005 .35061 Mtetra
.931 .549 .214 r
.07005 .35061 .07756 .35955 .08881 .34892 .07607 .3775 Mtetra
.767 .827 .36 r
.07607 .3775 .08881 .34892 .09865 .34872 .09108 .34057 Mtetra
.568 .691 .923 r
.09108 .34057 .09865 .34872 .10875 .34706 .10122 .33868 Mtetra
.312 .565 .928 r
.10122 .33868 .10875 .34706 .12052 .33282 .11093 .34049 Mtetra
.694 .943 .656 r
.11093 .34049 .12052 .33282 .13 .33667 .12253 .32812 Mtetra
.558 .677 .918 r
.12253 .32812 .13 .33667 .14031 .33449 .13279 .32645 Mtetra
.552 .691 .931 r
.13279 .32645 .14031 .33449 .14985 .33923 .14309 .32481 Mtetra
.761 .647 .735 r
.14309 .32481 .14985 .33923 .1618 .32392 .15469 .31268 Mtetra
.424 .543 .872 r
.15469 .31268 .1618 .32392 .17222 .3219 .16476 .31387 Mtetra
.593 .709 .924 r
.16476 .31387 .17222 .3219 .18271 .31983 .1753 .31139 Mtetra
.393 .608 .935 r
.1753 .31139 .18271 .31983 .19475 .30361 .18554 .31227 Mtetra
.571 .865 .553 r
.18554 .31227 .19475 .30361 .20454 .30897 .19721 .3002 Mtetra
.566 .678 .915 r
.19721 .3002 .20454 .30897 .21523 .30632 .20784 .29832 Mtetra
.602 .716 .924 r
.20784 .29832 .21523 .30632 .22592 .30422 .21861 .29558 Mtetra
.287 .546 .921 r
.21861 .29558 .22592 .30422 .23772 .29061 .22895 .29786 Mtetra
.717 .944 .64 r
.22895 .29786 .23772 .29061 .24809 .29294 .24084 .28425 Mtetra
.581 .69 .916 r
.24084 .28425 .24809 .29294 .259 .29003 .2517 .282 Mtetra
.615 .723 .923 r
.2517 .282 .259 .29003 .26995 .28718 .2627 .27891 Mtetra
.558 .694 .931 r
.2627 .27891 .26995 .28718 .27985 .29855 .27365 .27705 Mtetra
.708 .566 .693 r
.27365 .27705 .27985 .29855 .29245 .2758 .28542 .26533 Mtetra
.501 .608 .891 r
.28542 .26533 .29245 .2758 .30354 .27309 .29635 .26492 Mtetra
.62 .724 .921 r
.29635 .26492 .30354 .27309 .31473 .2697 .30756 .26164 Mtetra
.625 .73 .922 r
.30756 .26164 .31473 .2697 .32596 .26655 .31882 .25823 Mtetra
.578 .705 .929 r
.31882 .25823 .32596 .26655 .33678 .27098 .33008 .25588 Mtetra
.766 .651 .734 r
.33008 .25588 .33678 .27098 .34889 .2547 .34202 .2431 Mtetra
.464 .564 .872 r
.34202 .2431 .34889 .2547 .36025 .25194 .35319 .24363 Mtetra
.625 .726 .92 r
.35319 .24363 .36025 .25194 .3717 .24826 .36466 .24016 Mtetra
.639 .738 .921 r
.36466 .24016 .3717 .24826 .38322 .24442 .37621 .23633 Mtetra
.64 .74 .921 r
.37621 .23633 .38322 .24442 .39479 .24063 .38781 .23244 Mtetra
.631 .735 .922 r
.38781 .23244 .39479 .24063 .40638 .23738 .39945 .22876 Mtetra
.551 .69 .931 r
.39945 .22876 .40638 .23738 .41401 .34951 .41108 .22693 Mtetra
.549 .329 .534 r
.41108 .22693 .41401 .34951 .42993 .22513 .42311 .21509 Mtetra
.553 .652 .901 r
.42311 .21509 .42993 .22513 .44169 .22178 .43484 .21338 Mtetra
.636 .734 .919 r
.43484 .21338 .44169 .22178 .45352 .21774 .4467 .20951 Mtetra
.648 .745 .92 r
.4467 .20951 .45352 .21774 .46541 .21349 .45861 .20531 Mtetra
.653 .749 .92 r
.45861 .20531 .46541 .21349 .47735 .20914 .47059 .20095 Mtetra
.655 .751 .92 r
.47059 .20095 .47735 .20914 .48934 .2047 .48262 .1965 Mtetra
.657 .752 .92 r
.48262 .1965 .48934 .2047 .50139 .2002 .4947 .19199 Mtetra
.658 .753 .92 r
.4947 .19199 .50139 .2002 .51349 .19567 .50684 .18743 Mtetra
.659 .754 .92 r
.50684 .18743 .51349 .19567 .52565 .1911 .51903 .18283 Mtetra
.51903 .18283 .52565 .1911 .53786 .18652 .53127 .1782 Mtetra
.53127 .1782 .53786 .18652 .55012 .18192 .54357 .17357 Mtetra
.54357 .17357 .55012 .18192 .56243 .17731 .55592 .16891 Mtetra
.658 .753 .92 r
.55592 .16891 .56243 .17731 .5748 .17268 .56833 .16425 Mtetra
.56833 .16425 .5748 .17268 .58723 .16805 .58079 .15957 Mtetra
.58079 .15957 .58723 .16805 .59971 .16339 .59331 .15487 Mtetra
.59331 .15487 .59971 .16339 .61224 .15872 .60588 .15016 Mtetra
.60588 .15016 .61224 .15872 .62484 .15403 .61851 .14543 Mtetra
.61851 .14543 .62484 .15403 .63749 .14932 .6312 .14068 Mtetra
.657 .753 .92 r
.6312 .14068 .63749 .14932 .65019 .14459 .64395 .13591 Mtetra
.64395 .13591 .65019 .14459 .66295 .13984 .65675 .13112 Mtetra
.65675 .13112 .66295 .13984 .67578 .13507 .66961 .12631 Mtetra
.66961 .12631 .67578 .13507 .68866 .13028 .68253 .12148 Mtetra
.657 .752 .92 r
.68253 .12148 .68866 .13028 .70159 .12548 .69551 .11663 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04U;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo1Eoo`03001oo`0004Yoo`00SGoo0`00HWoo00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_`00003D_`FOol00`00Oomoo`18Ool008Yoo`<000=oo`03001oogoo
05eoo`0GD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBo@0GOol00`00
Oomoo`17Ool008Moo`<006=oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aB
o5;mD_`005;lD_d00U;l5goo00<007ooOol0AWoo0025Ool2001ROol085;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_dFOol00`00Oomoo`16
Ool0089oo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`00e;mD_aoo`0FOol00`00Oomoo`15Ool0081oo`8006=oo`0UD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_`05goo00<007ooOol0A7oo001mOol3001QOol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo003D_eB
o7oo01Eoo`03001oogoo04Aoo`00Ngoo0P000Woo00<007ooOol0GGoo02aBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;m5goo00<007ooOol0@goo001hOol3001ROol2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=B
o005D_eBo5;lD_aBo@0GOol00`00Oomoo`12Ool007Ioo`80065oo`0dD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`12Ool007=oo`<0065oo`9Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo004D_eBo5;lD_`GOol00`00Oomoo`11Ool0075o
o`80069oo`0iD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;l01Eoo`03001oo`00049oo`00KWoo0`00H7oo0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBo@00D_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomoo`10Ool006]oo`<0065o
o`10D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_dGOol00`00Oomoo`0oOol006Uoo`8000=oo`03001oogoo05]oo`03D_aBoE;l009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aB
o5;lD_d00U;l5Woo00<007ooOol0?goo001VOol3001OOol0BE<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m01Ioo`03001oogoo03ioo`00I7oo0P00H7oo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l5Woo00<007ooOol0?Goo001QOol3001POol0Ce;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m01Eoo`03001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P00Ggoo00=Bo5;mD_`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol0
9Woo00<007ooOol04goo000dOol00`00Oomoo`02Ool00`00Oomoo`0POol3001POol0EE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo02Eoo`03
001oogoo01=oo`00>Goo00<007ooOol07Woo0P000Woo00<007ooOol0G7oo0U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;m
D_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Eoo`03001oogoo02Aoo`03
001oo`0001Aoo`00;7oo1P001goo00<007ooOol06goo0`00Ggoo05a>o5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Woo00<007ooOol08goo
00<007oo000057oo000eOol4000LOol2001POol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0FOol00`00Oomoo`0QOol01@00
Oomoogoo00004goo000eOol00`00Oomoo`0JOol3001POol0HU;lD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol2000S
Ool01@00Oomoogoo00004goo000eOol00`00Oomoo`0GOol3001OOol2D_`01E;mC_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d05Goo00<007ooOol07goo0`0000Aoo`000000019oo`00=Goo1@004goo0P00H7oo06U>
g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol0=goo001:Ool300000goo001o
o`1MOol01TkmC]a>g4kLC_e>o09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02
D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo1Eoo`03001oogoo00Qo
o`@002]oo`00B7oo0P00GWoo0755D44`AYa2NdJL@W]BoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkL
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m01Ioo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Qoo`00AGoo0`00Ggoo00=5
D44`AE000TJL00Q2W4JLAYaBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;l
D_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`FOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol004=oo`80065oo`1dAE11<4E@@C15D4[LC]e:_4kM
B]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Ioo`03001oogoo00Eoo`03001oogoo009o
o`03001oogoo02Qoo`00@7oo0`00HWoo00M5D44`AE11<4E@@C000`04C]`01TklD_e>g5;lC_aBo@=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eBo7oo01Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo02Qo
o`00?Woo0P00HGoo07]2_4Jm@[a6_D4`AE11<4E@@C15D003C]e:g4kMB[a>gDkLD_e>g5;mC]aBoDkL
D_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0:7oo
000kOol4001NOol01DkmC]a>oDkLC_d00TJm00M2_DE@@C15D44`AE11<00200<2C]`01TkmC]a>g5;l
D_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol057oo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol0:7oo000iOol20004Ool00`00Oomoo`1HOol0Q5;mC]aBoDkLD_e>g4kmC]aBoD:l
A[e1<4E@@C15D44`AE12NdJL@W]BoDkLD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo1Eoo`03001oogoo00=oo`@002]oo`00=Woo0`00GGoo00E>g4klC]aBoDkL009>o006D_e>g4kl
C]a>gD[L0TJm00I5D44`AE11<4E@@C03AY`014:LC]a>g4km0TkL00=Bo5;mD_`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m01=oo`800003Ool007oo039oo`00<goo0`00G7oo08e>gD[LC_e>g4kMC]aB
oDkLD_e>g5;mC]aBoDkLD_e:g4kM@[a6_D4`AE11<4E@@C15D49kAYa2NdJL@W]BoDkLD_e>g5;mC_aB
oDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d05Goo00<007ooOol0<Goo000aOol2001JOol00f:F
GYHj>`03>S/05TkMC]a>g4kLD_e>g4klC]aBoDkLC_e>o5;mC]a>gDkLA[e2_DE@@C15D44`0dE@1DkL
00ABo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0200000e;lD_eB
o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomo
o`0`Ool002ioo`<005]oo`1eHYMNMV:GGWHj>cHj>S]>g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;m
C]a>oD:lA[e1<4E@@C15D44`AE51<004B[a>gD[LC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m00<0000MD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0_Ool002aoo`@005]oo`05HYINUV:GGYIRUP04>S/0
1dkLC_e>g4klC]aBoDkL009>o006D_e>g4kmC]a>oDkL0TJm00Q5D44`AE11<4E@@C15D0031DkL00E>
o5;lD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00<00006D_eBo5;lD_aBo@000U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol0;goo000Z
Ool2001NOol0LF:GGWIRUeifHYMNMV:GB[a:gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4km
@[a6_D4`AE11<4E@@C15D44`00@00e;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d00`00
02ABoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0^Ool002Yoo`8005]oo`09B]e6_4KMA[eRUejFHYINUV:G
009KT@07B[a:g4ZlB[a>g4kmC]`00Tkl00iBoDkLC_a>o4kmC]a>oDkLC_e2_DE@@C15D44`0dE@00A2
W4JLAYa>o@=>g005C_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`200001E;mD_aBo5;lD_d00e;l00IBoE;lD_aB
o5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`EOol0
0`00Oomoo`0^Ool0011oo`D000=oo`@000Aoo`@000Ioo`03001oo`0005Ioo`1cC]a>oD[LC_e>g4[M
A[a:gEifHYMNMV:GFi5O/E^AC]e:_4[MB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[LA[e1<4E@
@C15D44`AE52NdJL@W]6W49kD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`0002YBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_dEOol00`00Oomoo`0]Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`03Ool200000goo001oo`1@Ool2C]`03TkMC]a>g4kLC]e>g4kMA[e:gDJlA]eN
UV:GGYH2Fi401E^aFi5>g4kLC]d00dkL01=BoDkLC_a>g5;mC]a>oDklC]e:g4kMA[e5D44`AE11<4E@
@C15D005C]`01E;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo003D_eBo000008000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0
5Goo00<007ooOol0;7oo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol00Woo0P000goo00<007ooOol0Bgoo01@nO3iK?W`nFdkmB]a>gD[LC_e>g4kmB]a>oDJlB]e6
_6:GGWIRUeif0cXk05df>TkmC]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LA[e1<4E@@C15D44`
AE11<004B]a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`00`00035Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo00EOol00`00Oomoo`0/Ool000Moo`H000Eoo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`19Ool01UXeESDnG3iK?W`nF`9>
g007C]e>g4kMC]a>gD[LC]d00`fk00=RUUjFHYL013Xk0dkL00I>oDkLC_a>o5;mC]`2C_`02U;mC]a>
oDklA[e2_DE@@C15D44`0dE@00<00`04C]`00dkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`30003D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`00e;mD_aoo`0DOol00`00Oomoo`0[Ool0019oo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`16Ool06EHe
FSIF=EXe?U/nO3iK?W`nFdkmC]a>oDkLC_e:g4kMB]`Af`fkHYMNMV:GGWIRUcHj00<j>`1EC]aBoDkL
D_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkLA[e1<4E@@C15D44`AE51<00400<014kLD_e>g5;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`0003UBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007oo0000;7oo
000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo0P001Woo
0P00AGoo0UXe01QF=EXeFSEJ=DZlB]a:_4[MB[a>gDkLC]e>g4kMC]a>gD[LHYINUV:GGYIRUUjFFi43
B[`01T[LC]a>o4kLC_e>g09>o00?D_e>g4klC]a>oDkLC_e6_DE@@C15D44`AE11<4E@0096W004@Ya6
W4kLC_d2C]`00e;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l0`000e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
01Eoo`03001oogoo02Yoo`0047oo0`0017oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo03ioo`1`A]e2_4Jm@[aJ=UHeFSEF=EXfFdeOKDZlC]e:_4[M
C]a>oDkLC_e>g4[MA[a:gDJlHYMNMV:GGWIK/E^AFk5:_4kMB[a:gDkLD_e>g5;mC]aBoDkLD_e>g5;m
B]a>gD[LA[e1<4E@@C15D44`AE11<4JL@W]6W49kD_e>g5;mC]aBoDklD_e>g5;mC_aBoDkLD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`30000@5;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<007ooOol0:Goo000BOol00`00Oomoo`03Ool4
0004Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`0jOol014kMC]a>gD[L14Jm0eXe01AF=E]]Fde:
gDZlB]a:_4[MC]a>gDkLC]e>g4KMA[e:gEjFHYINUV:G15^A0dkL00I>gDkLC_a>g5;mC]`2C_`02U;m
C]a>oDkLC]e2_DE@@C15D44`0dE@00U2W4JLAYa6W4:LD_a>o5;mC]`00U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_`000020003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001oogoo02Qoo`00:7oo00<007oo
Ool02Woo00<007ooOol0=Goo02E6_4ZmA[a:_DJlC_e:g4kMB]a6gD:lA[eF=EXfESEOKE]=GfeKCDkM
B]a>oD[LC]e:g4kmC]a>oD[LB]e6_4[MGWIRUeifHYLf>P03>S/0BT[LC_e>g4kMC]aBoDkLD_e>g5;m
C]aBoDkLC_e:g4Jm@C15D44`AE11<4EA@E15DDZlC]e:g4kMB[aBoDkLD_e>g5;mD_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d20000Ae;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol0:7oo000XOol3000;
Ool00`00Oomoo`0cOol02e^cFkA6_4ZlA[a:_4[LC]e>g4kMB]`00TJm00=J=EHeFSD00UXe00@nFciL
?U]>g@=>g009C]e:g4kMC]a>gD[L3K]6_F:G00=NUP@j>`06C]e>g4kLC]a>gDkL0Tkl00IBoDkLC_e>
o5;mC]`3A[d01D4`AE15D4E@@E000TE@00<014kLC]`00dkL0U;l00EBoDklD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`3
0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo02Moo`00:7oo00<007ooOol0
1Woo00=b/WooOol00goo00<007ooOol0<Goo021G/e_DFk=:_DJlB[e6_4ZmB]a>gD[LC]e:g4KMESEJ
=E]=FSIF=Cil?U/nO3iK?Wa>g4kmC]a>oD[LC_e:g4kM0Pfk00MNMV:GGWIRUeif>S/f>P02>S/05e;m
C]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a6_D:lAE11<4EA@C15DD4`AE400P0402Y>g5;mC]aBoDkL
D_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_d30000CU;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03
001oogoo02Ioo`00:7oo00<007ooOol01Woo00=b/WooOol017oo00<007ooOol0;goo00=K/fJgH[L0
0Rgj00]>gD[LC]a:g4kMB]a:gD[LC]d03dJm009J=@0@ESEJ=EXeB]e:_4[LB[a:gDkLC]e>g4kMB]a>
gDkLC]d3GYH01F:GGYINUTZlB]`00dZl00I>oDkLC_a>g4kmC]`2C_`02U;mC]a>oDkLC_e>g4Jm@C15
D44`14E@0dJL0dkL00I>oDklD_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aBo0030002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol002Qoo`8000Moo`03L[5oogoo00Eoo`03001oogoo
02eoo`1Z8QaV]f:fI[L]fS7j;MY>gDZlC]e:g4kMB]a>gD[LC]eF=EXfESEJ=EHeFSIKC4[MB[a>gDZl
C_e>g4kmC]a>oDJlB]e6_6:GGWIRUeifHYMGT5^AB[a:gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkL
D_e>g4km@[a5D44`AE11<4EA@E15DD9kAYa2Ne;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDad30000EU<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`0UOol002Qoo`03001o
ogoo00Ioo`03M]9oogoo00Ioo`03001oogoo029oo`=6_005AYa:gD[LB]e:g0028Q`01VJgH[MR]f:g
I[L]fP<]nP04B]a>gDkLC]d3A[d00eXeESEJ=@02FSD045]<Fde:_4[MB[a:g4ZlC]e>g4kMC]a>gDJl
A]e6_F:G0UjF0U^A00EKT5^AB[a:g4Zl009>g006D_e>g4klC]aBoDkL0Tkl00IBoD[LC]e>g4Jm@C03
AE001D5@AE15D4JL@Y`00TJL00EBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m009Bo0<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Eoo`03001oogoo02Aoo`00:7oo00<007ooOol01Goo00=f
dW:bOol027oo00<007ooOol087oo06m;LDM@A[e6W4JmAYa>gD[LC]e:_6JgH[IV]f:FI[MR]TZmA[a:
_DJlB[e:g4kmB]a>gD:lA]e2_5XeESEJ=UHeFfeKC5]]B]a>gD[LC_e:g4kmB]a>oDkLB]e6_4[MGWIR
UeifHYMNMSXk=SXj>dkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4km@[a5D44`AE51<4EA@C15
DDE@C]e:_4kMB]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDad00`0005eC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d04goo0P009Woo000WOol00`00Oomoo`06Ool2L[800goo<6]oo`07Ool0
0`00Oomoo`0NOol016KF7EQ7LDJL0dJl00E6W4JmA[e6gDJl009R]`0=I[MR]e^cFk=:_4JlB[a6_4kM
B]a>gDkLC]d00TJm0UXe00QF=EXeFSDnO3iK?Ua>g4kM0dkL00U>gDkLC]e>g4[MA[a6gEjFHYL00UjF
13Xk00M>g4kMC]a>g4klD_e>g002C_`02U;mC]a>oDklD_e:g4Jm@C15D44`1DE@00<014kLC]`00TkL
00EBoDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l0`000U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo1Aoo`03001oogoo02=oo`009goo0`001Woo00AfdW:aOol/J`Uoo`03001oogoo01aoo`1[
J]MV]V[G7EPMN4ZlC]e:_4[MB[a:gDJlB]eRUVJgH[IK/eNcFkAG/dZmA[a:_DJlC]e:g4kMB]a>gD:l
FSIF=EXeESEJ=SiK?W`nFcilB]a>gD[LC_e:g4kMB]a>oD[L3K/9^f:GGWIRUeifHYLj>SXk=SXj>dkL
D_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkLC_e2_4E@@C15D44`AE51D4EA@E0014[LC]e:_4kMB]aBoDkL
D_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBo@030000I5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
5Goo00<007ooOol08Woo000WOol00`00Oomoo`05Ool2L[800gKBOol`J`0:Ool00`00Oomoo`0JOol0
339MI]IZefJf7GPMF1ehB]a:gD[LB]e6_096_@06A]eR]e^cH[MV]bgJ0Rgj00Y>gD[LC]a:g4[MB]a:
gD[L00mF=@=J=@0@ESEJ=CiK?W`nFciLC]a>gDkLC]e>g4kMB]a>gDkLHYL3GYH01F:GGYI:_4ZlB]`0
0TZl00M>g4kmC]a>o4kLD_e>g002C_`01TkmC]a>oDkLA[e1<0I5D005AE401004C]a>o@03C]`01E;m
C_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo080009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l
57oo00<007ooOol08Woo000EOol40004Ool40006Ool00`00Oomoo`05Ool01G:aM]9b/S1[;4/02goo
00<007ooOol03Woo079RUeif=S/b6T[MB[a:gDJlB]d^GC9mI[IZefJfJ]MV]R5h7EPMN4ZlC]e:_4[M
A[a:gDJl8SeRUVJgH[IV]bgJ<OX]fTkMB[a>gD[LC]e:g4kMB]a6_EHeFSIF=EXeESEKKDZlB]e:_4kM
C]a>oDkLC_e>g4[MA[a:gEifHYMNMV:GGWIKTEM`C]e:_4[MB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4km
C]aBoD:lAE11<4EA@C15DD4`AE55D4JL@W]6W4kLD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;m
D_`30000JU;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<007ooOol08Goo000DOol0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00=fdW:bL[800S1[
37oo0P003Goo00iNUeifGYLb6cHk<Q]:gD[LB]e:_4[MI]IZefJf0VKF00UZeaeH7GPMF1ehB]a:gD[L
B]d00R8L00=R]fJgH[L00V:g00T]nRgJ;OX]nTkMB]a>gDkLC]d00TJm0UXe01EF=EXeFSEKCE]<B]a:
_4[MB[a:g4kLC]e>g4kMC]a:gDJlA]eNUV:GGYH00UN@00YKTDZlB[a:_4[LB[a>o4kLD_e>g09>o00:
D_e>g4klC_a>gD[LA[e1<4E@@C04AE03AY`024:LAYa>o5;mC]aBo4klD_d3D_`015;mD_aBo5;l0`00
00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo01=oo`03001oogoo
021oo`006Goo00@007ooOol000Aoo`03001oogoo00=oo`8000Ioo`05L[9fdW:a<6//J`0>Ool00`00
Oomoo`09Ool0KV:GGWIRUeifHYLb6cHk<QXf>dJlB]e6_4[MI[IZefJfJ]M3D4M`AYa6_DJLA[e:_4kM
B]a>gF:FI[MR]VJgHYIV]f:fB[e6_4ZmA[a>gD[LC_e:g4Jm@[a6gEHeFSEF=EXfEdaKCEM<C_e:g4kM
B]a>oDkLC_e:g4kmA[a:gDJlHYMNMV:GGWIRUcXj>S]:g4kmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;m
C]a>gD:lAE11<4E@@C15DD5@AE51D4kMB]a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mD_`30000LU;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03001oogoo021oo`00
37oo1P001goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Eoo`=b/P0400</Jc1[<6/>
Ool00`00Oomoo`07Ool01UjGGWINUejFGYMNMP96_006A[e6_4JlA[e6gDJl0VKF00IZefJf7GQ7D4Jl
AY`4A[`2A[d01TKMH[MR]f:gI[MR]`9G/`08B[a6_4ZlC]a>gD[LC]e>g096_@=J=@05ESEJ=CiK?W`n
F`02C]`02TkMC]a>gDkLC]e>g4kMA[e:gDJl0UjF00=RUeif>S/00SXk0dkL00I>gDkLC_a>o5;mC]`2
C_`01U;mC]a>oDklA[e1<0I5D003AE4014kL00=>g004D_a>o5;mC_`2D_`300000e;lD_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001B
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo
01moo`005Goo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00MfdW:aM]80
0c1[;4/`S00?Ool00`00Oomoo`03Ool0K4Jm@[a6_EifHYMNMV:GGWISe6>cB[e6_4ZmA[a:gDJlB]e6
_6[GI[IZefJf8GPMF4[MB[a>gDZlB]e6_4[MA[aV]f:FI[MR]U^cEi9K/dJlB[e6_4ZmB]a>gD[LC]e:
g4JmESEJ=UHeFSEF=Cil?U/nO3iKC_e:g4kMB]a>oD[LC]e:g4km2K/=^eifHYMNMV:GGWHj>cXj>S/f
>U;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;m@[a5D44`AE51D4EA@E15DDE@00E:_4kMB]a>gDZlD_e>
g0<0001iD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`057oo00<007ooOol07goo000EOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool20006Ool017:bM]9b/P030c1[47oo0UNd00Y6_DJLA[a6_4Jm@[e6_EjFGYMNMPASe096_006
A[e6_4JmA[e6gBiM0VKF00YZeaeH7GPMF4[MB]a:gD[LA]e6_096_@0BI[MR]f:gH[LanRgJ;OY:g4kM
B]a>g4[LB]e:g4[M00iJ=EHe0eXe015F=CiL?U/nO3iKC]e>g4kMC]a>gDkLC]e:g4kMGYIRUeif009N
UP0:HYM:_4ZlB[a:g4ZlC_a>g4kmC]`2C_`02U;mC]a>o4kLC_e>g4km@C15D44`0TE@00E5DDE@AE40
100500=>g0<00003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;l57oo00<007ooOol07Woo000EOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01gKBL[9fdP03<6//Jc1/00moo`1/EkAG/e_D
EkA6_D:LA[e2W4Jm@[aRUeifHYMNMV:G<Q/f>c8JB]e:_4[MA[`bOBiMJ]MV]V[GI[IZeaeG8GPMF4[M
B[a>gDZlB]e6_4[MH[IV]f:FI[MRUS7j;MXanT[LC]e:_4kMB]a>gD[LC]e2_5XeESEJ=UHeFSEG;4kM
B[a:gDZlC_e>g4kmC]a>oDJlB]e6_6:GGWIRUeifHYMGL5N@B[a>gDZlB]e>g5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4E@@C15DD4`AE55D4EA@E16W49k0`00085>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<0
07ooOol07Goo000EOol50003Ool40005Ool00`00Oomoo`04Ool027KBL[9b/W:b00</J`04<6/>Ool0
65Nd9SeV]fJf9ITQVD[MA[a:_DJlA[e2_EjGGYINUeifGYLb6cHk<Q]:gD[LB]e:_09VeP0=J]MV]VKF
I]HMN1eH7GPMF4[MB]a:gD[L8Sd00R8L00eR]fJgH[MR]bgj<OX]fRgjC]a>gD[LC]e>g002A[d3FSD0
4EHeFSEGC5]<B[a:g4ZlB]e:_4kMC]a>gDkLC]e6_D[MA[`00UjF00ERUeM`Ei1GT4[L00=:_006B]a>
g4klC]aBoDkL0Tkl00IBoDkLC]e>g4kM@[d6AE030002AY`01DkLD_a>o5;mC]`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0
4goo0P007goo000VOol00`00Oomoo`04Ool027:bM]9b/GKB00<`J`03<8`=Ool0JBHm8SaVef:fI[LQ
VBFi8IU:gDJlB]d5NPFJGWIRUeifHYMNMSHk<Q/f>c8JB]e6_4[MA[aZefJfJ]MV]TM@@dm6_DJLA[e6
W4kMB[a>gD[LC]eRUVJgHYIV]f:FI[M6_4ZmA[a:_D[LC]e:g4km@[a6_D:lFSIF=EXeESEKCEM<Fda:
g4kmB]a>gD[LC_e>g4kmB]a:gDJlB]eNMV:GGWIRUeif>S/j>TkMB]a>oDkLC]e>g5;mC]aBoDkLD_e>
g5;mC]a>oD[LA[e1<4EA@E15D@020000R4E@AE5:_4kMB]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo
00<007ooOol077oo000UOol00`00Ool00005Ool2L[800gKBL[800`03<6/00goo<6]oo`04Ool01ElZ
A[e6_4Jm9S`00RHm00=V]fJfI[L00VJg00dQVBFIA[a:gDJlB[eNUUjGGWINUejFGYMNMP02A[`01TJm
A[a6_DJmA]e6_09VeP06J]MV]Qeh@e16_4JL0TJl00E6gDJlA[e6_DKM00=R]`0;I[MGTUNcA[a:_4Jl
C]e>g4kMB]a>g@02A[d01EHeFSEJ=EXeESD00SiK00hnO4kLC]a>g4kMC]a>gDkLC]e>g4KMA[e:gEif
0UjF00ERUcXk>S/j>dkM00=>g00=C]e>g4klC_aBoDkLC_e>o5;mC]a>gDJmAE000`0000E5DDE@AE55
D00500E>g004D_a>o5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00DOol00`00Oomoo`07Ool5000?Ool002Eoo`8000Eo
o`06M]9b/GKBL[9fdP030S1[00<`K7oo<8`017oo06YO:V=;A[a:_DJlA[e6_6KGH[IV]f:fI]MR]RFi
8ITU^D:lA[e2_4JmGWIRUeifHYMNMV?DHk=:_DJlB[e6_4[MA[a:gFJfJ]MV]V[GI[HQN1eHB]e:_4kM
B[a:gDJlB]e6_6JgHYIV]eNBEk=GTTZmA[a:_DJlC]e:g4kMB]a>gD:lFSEF=EXfESEJ=CiK?W`nFcil
B]a>oD[LC]e:g4kmB]a>gD[L3K/9^f:GGWIRUeifHYLf>SXk>SYBoDkLD_e>g5;mC]aBoDkLD_e>g5;m
C]a>o@<0002>AE51<4EAAE15DDE@AG4014kMB[a>gD[LC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00
Oomoo`07Ool01@00Oomoogoo00003goo000UOol00`00Oomoo`04Ool00g:bM]9b/P02L[801P03;6/`
Jc1[Ool`J`Aoo`03Hb]O:V=;00E6_@=V]`06I[IG]5NdA[e6W4Jl0TJm00E2_EjGGYINUeif00=Se005
Hm=6_4JlA[e6_002A[d03TKM;UeVeVKFJ]LMF1eh7EQ:gD[LB]e:g4KMA[`2A[d03fJgEi9R]f:g<OX]
fTkLB]a>gD[LB]e:g4[MB]`03P02FSD015HeFSEJ=EXe0ciK00XnO4kLC]e>g4kMB]a>gDkLC]e:g09N
UP05HYMNMUjFGYI:g003B[`01TkmC]a>o4kLC_e>g09>o006D_d00000001>oD:m1TE@00E5DDE@00D0
14km00=>g005C_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0COol00`00Oomoo`07Ool00`00Oomoo`0@Ool0
02Eoo`03001oogoo00Aoo`0;M]9b/WKBL[5fdP03<6//Jc2<Ool`S003Ool0IF=;CK<nO3YL?Wa2_4KM
@[a6_F:fI]MR]UNdDk=G]4:LA[e2W4Jm@Ya6_D:lHYMNMV:GGWIRUc8K=S/b6T[MB[a:gBiL<Wd^GF[G
I[IZefJfJ]LMEb5h7EQ:gDZlC]e:_4[MA[a:gB8LI[MRUVJg;MXanRgJC]e:g4kMB[a>gD[LC]e:g4KM
ESEJ=EHeFUIF=EM<B[a>gDZlB]e>g4kmC]a>oDJlB]e6_4[MGWIRUeifHYMNMUN@Efm:gDZlC]e:_5;m
C]aBoDkLD_d00`0009IBoDkLD_e>g4Jm@C15DD5@AE51D4EaAE15DD9kAYa2Ne;mC]aBoDkLD_e>g5;m
C_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`07Ool00`00Oomoo`0?Ool002Eoo`8000Eoo`=b/P08M]9b
/P0300=6_DJlMRH`J`9oo`04MRI=de7CCM<3?W`4A[d04FJfEkAV]fJg8ITUVDJlB]e6_4ZmA[a6_Eif
GYMNUUjGGWH00SHK00Hf>dZlB]e:g4[MB[`2I]H01V[GI[IVeVKFA[a6W096_006B]e:g4[MB]`R?B8L
0V:g00]V]f:gH[L]nS7j;MY>gDkLC]e:g4kM0096_@05ESEJ=EXeFSEF=@02Ed`03T[LB[a:g4ZlB]a>
g4kMC]a>gDJlA]e6_D[MGWH2GYH01EN@Eg1GT4ZlB]`00dZl00IBo@00000005;mC]`2C_`015;mB]a>
gDJm14E@00=5DDE@AE400TJL00Q2W4JLAYaBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Aoo`03001o
ogoo00Qoo`03001oogoo00ioo`009Goo00<007ooOol00goo06ib/WKBL[5fdW:bM]800`04A[a6_D:l
<8aoogHVLPEAe4gCDM==/cil>U`nO4:lA]e2_2HmH[IVef:f9KTQVBFiA[a:gDJlB]d1NPFJGWIRUeif
HYMNMSHk<Q/f>dJlB]e6_4[MA[aZefJfJ]MV]T=@@bm6_DJLA[e:g4kMB[a>gD[LI[MRUVJgHYIV]f:F
B[e6_4ZmA[a>oD[LC]e:g4KM@[a6_EHeFUIF=EXeEb]KC5L[C]e:g4kmB]a>gD[LC_e>g4kmA[a:gDJl
HYMNMV:GGWIRUcHj>S]>g4kM0`0009eBoDkLD_e>g5;mC]aBoDkLD_e:g4Jm@C15DD4`AE55D4EAAE15
LD[LC]e:_4kMB]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0DOol00`00Oomoo`08Ool00`00Oomo
o`0=Ool002Eoo`03001oogoo00=oo`9b/P04M]9b/W:bL[8300<2A[d017H6MRIf1U7C0dgC00MAdelZ
A[e6_4Jm9S`V?@02I[L01FJfI[MV]bFi8IT00RFI00U:gDJlB[eNUUjGGWINUejFGYL00dJl00I6_DJl
A[e6_DKMI[H2I]H00f[G7EQ3C`02A[`01DJLA[a6_DKMA[`00TJm00iV]f:gH[MR]eNbEi9:_4JlB[a6
_4kMC]a>gD[L0TJm00=J=EHeFSD00UXe0ciK00i>gDkLC]a>g4kMC]a>gDkLC]e6_4KMA[eRUeif0UjF
00Dj>`00000004kM00=>g00:D_e>g4klC_aBoDkLC_e>o5;mB]`6AE000dEAAE001@05C]`01E;mC_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo00=oo`05001oogooOol0000?Ool002Aoo`1_001o
ogooOom6_D:LA[e2W7KBL[9fdW:aM]9b/T:L?Wa2WCjMMRIb1GHVCM=AddfcDMAO:V=:A[a:_DJlA[eR
]VKGH[IV]f:fI]M2W4Jm@Ya6_D:LA[e2_6:GGWIRUeifHYMO/f?DA[a:_DJlB[e6_4[MA[a:gFJfJ]MV
]V[G7ELQN4ZlB]e:_4kMA[a:gDJlB]eRUVJgHYIG/e>BEk=6_4ZmA[a:_DJlC]e:g4kMB]a6gEHeFSEF
=EYFESDnO3iK?W`nFcilC]a>oDkLC_e:g4kmB]a>g@VJ3K]NMV:G00<0002T>S/f>SXkC]aBoDkLD_e>
g5;mC]aBoDkLC_e>g5;mC]a>oD4`AE51D4EA@E15LDE@AG4014kMB]a>gDkLD_e>g5;mC]aBoDkLD_e>
g5;mD_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo1Aoo`03001oogoo00Aoo`<0011oo`0097oo0`0000EooeJTA[e2_DJm00=b/P05
M]9b/W:b?W`nW002?W`00gH6MRI=d`02CM<00e7CCM=O:P02GbX4A[d02VJfI[MV]fJgDk=G/dJlA[e6
W4Jl0TJm00Q2_EjGGYINUf>cHm=S/f?D0dJl0296_DJlA[e6_C9mI[IVeVJf8GPMF1ehB]a:gD[LB]e:
g4KMA[a6_F:gEk9R]V:g;OXanT[LC]a:g4kMB]a:gD[LB]d03P=J=@0AESEJ=EXeB]a:_4[LB[a:g4kL
C]e>g4kMB]a>gDkLC]eNMP0200001F:GGWINUTZlB]`00TZl00M>g4kmC]a>o4kLD_e>g002C_`014km
C]a>oDkL14E@00A5DDE@AE55D@801@9>g006C_e>g4kLD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;l
D_aBo15oo`800003Ool007oo01Moo`0097oo06X007ooOomooe[5@Ya6_D:LA[djO7KBL[9fdW:aM]96
_4Jm@[a6_G85DM==/e7DCM=SBTfc?W`jFcil@[a6gD:lA[eR]VKGH[IV]b6IEkA2W4Jm@Ya6_D:lA[eN
MV:GGWIRUeif=S/b6cHkA[a:gDZlB]d^G39mI[IZefJfJ]MV]R5h7ELQN4[LC]e:_4kMB]`R?AhL8SeR
UVJgHYHanRgJ<OY:_4kMB]a>gDZlC]e:g4kM@[aJEUHeFSEF=EM<Eb]:gDZlC]e:_4kmC]a>oDkLB]e6
_0<0002[GWIRUeifHYMCKeN@B[a:gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e1<4EA@C15DDE@
AE55D4Ea@W]6W49kD_e>g5;mC]aBoDklD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo
01Eoo`006Woo10001Woo00<007ooOol00eJT13ZM0g:b00=fdW:b00@00TJm00A6_3jMCM=Ad`==d`03
DM<jG3il008nO0=6_@03I[MV]VJg009V]`068ITUVDJlB]e6_4Zm0TJm00ENMUjFGYINUc8K008f6`0;
=S]:_4[MB]a:gFJfI]IV]V[GI[IVeP02A[`02DJLA[a:g4[MB]a:gB8L8SeR]P03H[L02F:f;OX]nS7j
B]a>gDkLC]e:g002A[d00eXeESEJ=@02FSD02EL[Eda:_4[LB[a:g4ZlC]e>g003000034JlA]e6_F:G
GWINUUM_Eg1CKeM`C]a>g@=>g006D_e>g4klC_aBoDkL0Tkl00Y>gD[LAE15D4EAAE15DDE@AE55D0=6
W005@Ya6W4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo01Eoo`00
6Goo00<007ooOol00Woo00<007ooOol00goo06@007ooOomoocil>W`nO3Yl>Yeb/WKBL[5fdW:bM]80
0`04A[a6_D:lDMA=de7CCK=Ae4gCDM=6_4ZmA[a6_B8l9SdV?2HmH[IVef:f9KTQVBFiA[a:gDJl1IX1
NV:GGWIRUeifHYLb6SHk<Q/f>dJlB]e6_4[MI[IZefJfJ]Lo;T=?AYa6_DJLA[e:g4kMB[a>gF:FI[MR
UVJgHYIV]dJlB[e6_4ZmB]a>oD[LC]e2_4KM@[aJ=EHeFUIG:eM<Db]GC4[LC]e:g0<0002cB]a>oDkL
C_e6_4[MGWIRUeifHYLj>SXk=SXj>dkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e2_4EAAE15DD5@
AG55D4EaAE1>gD[LC]e:_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00
Oomoo`0DOol001Uoo`03001oogoo009oo`03001oogoo00=oo`80009oo`05>W`nO3il?W`jO002L[80
2GKBL[9b/W:b00@00`04?Ydn_@03CM<02e7CCM=AddgCGbY6_4JmA[a6_BHl9Sd00VJg00UR]VJgI[LU
^B6I9IU6_4[MA[`00UjF00ENUeifGYIS/f?C00=6_00:A[e6_4JmA[eZefJfI]IV]R5h?bl3A[`01TJL
A[a6_DKMA[a6_@9R]`0<H[IR]e>BEi96_4ZlA[a:_4[LC]e>g4kM0TJm0UXe00EF=EXeFSDnO3iK00<0
00=>g00:C]e:g4kMC]a>gDJlA]eNUV:GGWH4>S/2C]`01TkMC]a>g4klD_e>g09>o005D_e>g4kmC_a6
_@03AE001TEAAE15DDEAAG401@E>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00D
Ool00`00Oomoo`0COol001Uoo`03001oogoo009oo`03001oogoo009oo`04001oogooF/D2Ool05D:L
A[e2W4Jm@YafdW:bM]9b/GKBL[92W3il@YdnWE7CCK=Ae4gCDM==/`03GbX0@DJlB[e6_4JmH[IVef:f
I[MR]VKG@Ya6_D:LA[e2_4Jm@[aRUeifHYMNMV?DGk=SddJlB[e6_4ZmA[a:gDJlJ]MV]V[GI[HQN1eG
C]e:_4[MB[a>gDJlB]e6_6JgHYIV]e>BEk9CTUNbA[a:_DJlB[e:g4kMB]a>gD:lFUIF=EM<ESD00`00
02/nFcil?U]>oDkLC_e>g4kMB]a>oD[L3K/9VV:GGWIRUeif>S/j>SXk=SYBoDkLD_e>g5;mC]aBoDkL
D_e>g4kmC]aBoDkLAE51D4EAAE15DDE@BG55D00200D0SE;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@0COol00`00Oomoo`0COol001Uoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00Aoo`04@[a6_D:mA[d3L[801GKBL[9b/Sil?Y`00Sil00I=de7CCM=AddgCDM<4GbX4
A[d02F:fI[MV]fJgDi=C/dJlA[e6W003A[d034:mGYINUV?CGk=Sdf>cHm=:_4[MB]a:g@<^G@0BJ]MV
]VKF7GPQN1eHB]e:g4[MB]a:gDJmA]e6_6:gDi9R]f:f0Rgj00XanT[LC]a:g4kMB]a:gD[LB]e6_@<0
000AESEJ=DZlB]a:_4[LB[a>gDkLC]e>g4kMB]a>gDkLHYMNMP02GYH02V:GDfm:_4ZlB]a:_4klC]a>
oDkL0Tkl00aBoDkLC_a>g4kmC]a>oDE@AE55D4EAAE03AE42AY`014:LC]a>g4km0TkL00=Bo5;mD_`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01=oo`03001oogoo019oo`006Goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01Woo0516_D:LA[eb/GKBL[9fdW:a00A6_4Jm@[a2_DgCDM==/e7D
GbYAdcYK?W`jFcil@[a6gD:lI[MR]VKGH[IV]b6I9KU2W4Jm@Ya6_D:lA[eNMV:GGk=RUeif=S/b6cHk
A[a:gDZl<Wd^G6[GI[IZefJfJ]LMF25h7ELQN4[LC]e:_4kM8Q`R?AhLI[MRUVJg;MXanRgJC]e:_4kM
B]a>gD:l0`000<5F=EYFESEJ=E<[Eda:_4[MB[a>gDkLC_e>g4kmA[a:gDJlB]eNMV:GGWIRUe=_Eg1C
KdkMB[a:gDZlD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LAE55D4EAAE15LDE@AG52NdJL@W]6W4kLD_e>
g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0AOol001Uoo`03
001oogoo009oo`03001oogoo009oo`8000Qoo`8jW@05M]9b/W:bL[9fdP0200@2A[d02CjMDM==de7C
CM=AddgCDM<jG003?W`3A[d02VJgH[IV]fJg9KTQVBFIA[a:gDJl0P5j00H5NUifGYINMUjG<Q/2=Q/0
2SHkB[a:gD[LJ]MV]VKFI[IZefJf0dJl00E6W4JlB]a:gD[L008R7003H[MR]V:g009R]`<]nP03C]e:
g000008000=6_@0FFSEF=EXeFSEG:e<[Eb]:_4[LB[a:g4kLC]e>g4kMA[e:gDJlA]eNUV:GGWH2Dfl0
2UM_Dfm>g4kLC]e>g4klC]aBoDkL0Tkl00EBoDkLC_e>g4kM00=5D006AE55D4EAAE55LDEA0dJL00E>
g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`COol00`00Oomoo`0AOol0
01Yoo`@000Eoo`03001ooeJT00Moo`1:>WafdW:bM]9b/GKBL[80100300@00dJm?YaAe4gCDM==/e7D
CM=AddJlB[e6_4Jm8S`V?B8lI[MR]VJgH[HU^B6I9KU6_4[MA[a:gEifHYMNMV:GGWIRUdJlB[e6_4Zm
A[a:gDJlJ]MV]V[GI[IZeaeGA[e6W4JmAYa6_D[LC]e:_6JgHYIV]f:FI[MCTE>BA[a:_@800038B]a>
oD[LC]e2_4KMESEJ=EHeFUIF=Cil?U]2O4[LC]e:g4kmC]a>oD[LC_e6_4[MA[aRUeifHYMNMSXk>SXj
>cXjC_e>g4kMB]aBoDkLD_e>g5;mC]aBoDkLC_e:g4EA@E15LDE@AE55D4UaAE19L@05C]e:g4kMC]aB
oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA9oo`<0019oo`001Goo0P0000=oo`00
00006Goo00<007ooOol027oo0g:b00EfdW:bOomoocjL00<nO00>?[e=de7CCM=AddgCDM==delZA[a6
_DJl9SdV?0=V]`06H[IV]bFI9KTQVBFI0TJm00Q2_EjFGWINUeifGYIO/f?C0dJl0196gDJlA[e6_F[G
I[IVeVJf8GPMF25hB]a:gD[LB]e6_DKMA[d3H[L2Di83000024ZlA[a:_4[LB]e:g4[MA[d3FSD015He
FSDnFcil0SiK00=>g4kMC]`00TkL00I>gD[LC]d9^d[MA[`2GYH00f:G>S/j>`03>S/014klC]a>oDkL
0Tkl00aBoDkLC_e>o5;mC]a6_D:mAE55D4EAAE02AE400dEaAE401@04C]`01DklD_aBo5;mC_`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d04goo00<007ooOol047oo0004Ool00`00Oomoo`02
000JOol00`00Oomoo`09Ool017:aM]9b/WKB0goo03]2W3il@YdnWE7CCK=Ae4gCDM==/elZFbUO:TJl
B[e6_6JgH[IV]f:fI[M?TU>c@Ya6_D:LA[e2_4Jm@[aRUeifHYMO/V?CGk=:_DJlB[e6_4[MA[a:gDJl
J]MV]V[GI[HQN1eG8GQ:_4[MB[a:gDJlB]eRUVJg00<0000m<OX]fTkMB[a>gD[LC]e:g4kMB]`03UHe
FUIF=EXeESEJESiK?W`nFd9lC]a>oDkLC_e:g4kMB]a>o@VK3K]NMV:GGWIRUdZlC]e:_4[MB[aBoDkL
D_e>g5;mC]aBoDkLD_e>g4kmC]a6_DE@AE55D4EaAE15LDE@BG400P05091>g5;mC]aBoDkLD_e>g5;m
C]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dCOol00`00Oomoo`0?Ool000Aoo`05001oogoo
Ool0000IOol3000;Ool2L[84Ool02`04?Y`nO3jMCM=AddgCDM==de7CCM<00cil0dJm00]V]f:fI[MV
]e>cDi9CTdJlA[e6W4Jl0096_@05GWINUUifGYMNMP02=Q/01D[MB[a:gD[L<Wd00RiM00aV]V[GI[IV
eQeh8GPMF4[MB]a:gD[LA[d30003H[L03Bgj<OX]nTkMB]a>g4[LB]e:g4[MB]a6_EHe00=J=@0BESE:
g4ZlB]a:_4[LC]a>gDkLC]e>g4kMB]a>gEjFHYMNMUjF0U=_0dZl00I:g4kLC_a>g4kmC]`2C_`01U;m
C]a>oDkLC_e2_@95D006AE55D4EAAE55LDEA0dJL0dkL00E>oE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d04goo00<007ooOol03Woo0004Ool01@00Oomoogoo00006Goo00<007oo
F/D04Goo0P0403=6_D:lDMA=de7CCK=Ae4gCDM@jFcil>U/nO4:lA]e2_6JgH[IC/f:fI[LQVBFiA[a:
gDJlB]e2_4JmGWIRUeifHYLb6SHk<Q]:gDJlB]e:_4[MI[IZefJfJ]MV]V[G7EPQN1eGC]d00`0002PR
?AhLI[MRUVJgHYIV]bgJ<OX]fS7jB[a>gD[LA[e2_4KMESEJ=EHeFUIF=EL[DbY>gDZlB]e:_4kMC]a>
oD[LC_e6_4[MA[a:gEifHYMNMP9CK`2/B]e:_4kMB[a:gDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a6_D5@
AG55D4EaAE19LDE@AYa2NdJL@W]6W4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`COol00`00Oomoo`0>Ool000Aoo`05001oogooOol0000IOol00`00Oomoo`0AOol200@2
A[d02CjMDM==de7CCM=AddgCDM<jG003?W`3A[d02RHmH[IV]fJg9KTUVBFiA[a:gDJl0P5j00INUeif
GYINMUjG<Q/2=Q/02DKMA[a6_DJmA]eV]VKFI[IZe`05000014[MB]a:gD[L0f:g00]R]V:gH[M:_4Jl
B[a6_4ZlB]a>gDkL00=6_@9J=@05ESEJ=E<[Eb]C:`02C]`02TkMC]a>g4kLC]e>g4KMA[e:gDJm0UjF
00ERUeif>S/j>dkM00=>g00>C]e>g4klC]aBoDkLC_e>o5;mC]a>gD:mAE55D095D@04AG55DDEaAG46
C]`00e;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003
001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001o
ogoo00eoo`000goo0P000Woo0P006Goo00<007ooOol04Goo0`0402a6_4Jm?YaAe4gCDM==de7DCM=O
:TJlB[e6_4Jm8S`V?F:fI[MR]VJgH[HU^B6I9KU6_4[MA[aRUeifHYMNMV:GGWI:_DJlB[e6_4[MA[a:
gDJlJ]MV]V[G0`000=i6_DJLA[e6W4[MA[a:gDJlI[MRUVJgHYICTU>AB[e6_4ZmA[a>gD[LC_e:g4Jm
@[aJEUHeFSEF=EYF?U/nO3iKC_e:g4kMB]a>oDkLC_e:g4[MA[a:gDJlHYMNMV:G>SXj>cXjC]e:g4km
C]a>gDkLD_e>g5;mC]aBoDkLD_e>g4JmAE15DDE@AG55D4UaAE19L@05C]e:_4kMB]a>gDkLD_e>g5;m
C]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`COol00`00Oomoo`0<Ool0029oo`80
01=oo`0B?Y`nO3il?Ydn_DgCDM==de7CCM=O:E/YGbY6_4JmA[a6_F:f0fJg00IR]VJgA[a6_DJLA[`2
A[d01D:mGYINMUjGGWH00Unc00M:_DJlA[a6_4ZmA[a6_@03000026KFI[HQN1ehB]e:g4[MB]`2A[d0
0dKMA[eR]`02H[L3Di402TZlA[a:_4JlB]e:g4[MB]a6_EHe0eXe00eF=CiK?U/nO3iKC]e>g4kMC]a>
gDkLC]e:g0022K/01F:GGWINUUjFHYL00cXk00I>oDkLC_a>g4kmC]`2C_`02U;mC]a>oDkLC_e>g4EA
AE15DDE@0TEA00E5LDEA00D01Dkm00=>g005C_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoE;lD_`04goo00<007ooOol037oo000ROol00`00EZAoo`0BOol0:3il@Y`nO4:M
?YeAddfcDMA=de7DF`UO:U/9GbY2_4KM@[a6_F:fI[MR]VJgCi9C/d:LA[e2W4Jm@[a6_EifHYMNMUoC
Gk9SdenbB]e6_4[M0`000>DbOBiMJ]MV]V[G7EPQN1eGC]e:_4[MB[a:gDJlB]eRUVJgHYIV]bgJ<OX]
fTkMB[a>gD[LC]e:g4kM00eJ=EHeFUIF=EXeESE>gDZlB]e:_4kmC]a>oDkLC_e:g4kMB]aRUeifHYMN
MV:GGWI:gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4km@E15LDE@AG55D4UaAE19LD9kAYa2
Ne;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol0
0`00Oomoo`0;Ool0025oo`03001oogoo01Aoo`96_@09A[`nWDgCDM==de7CCM=O:TgC00<nO0=6_@03
I[MR]VJg009V]`059ITU^DJlA[e6W003A[d01EifGk=NMUjG<Q/00SHK0P0000U:gD[L<Wd^GFKFI[IV
efJfI]H00R5h00DMN4[MB]a:gD[L008R700B8QdR76:gH[LanRgj<OX]nTkMB]a>g4[LB]e:g4[MA[eJ
=EHe0UXe00iC:e<ZB]a:_4[LB[a>gDkLC]e>g4KMA[e:gEif0UjF00ERUeifDfmCKd[L00=:_006B]a>
g4klC]aBoDkL0Tkl00IBoDkLC]e>g4EAAE02AE4014EaAE55LDEa0dJL00=>g4kmC]`00TkL00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo019oo`8000aoo`008Goo00<0
07oo00005Goo0256_4Jm@[aAe4gCDMA=delZCM=Ae3YK?W`jFcil@[a6gD:lI[MR]VJgH[HU^B6I9KU6
_4[MA[`5NP5i0GYNMV:GGWH00`000>/b6T[MA[a:gDZlJ]MV]V[GI[IZefJfA[e6W4JmAYa>gD[LC]e:
_28m7QaV]f:FI[MRUS7j;MXanRgJC]e:g4kmB]a6_D:lFUIF=EXeESEJEU<:Db]C2TkMB[a:gDZlC_e>
g4kmB]a:gDJlB]eNMV:GGWICKdm>Dfm?CTkMB]a>oDkLC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDE@AE55
D4EaAE19LDE@BG55DDJL@W]6W4kLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00COol00`00Oomoo`0:Ool0025oo`8001Qoo`0>A[e6_57CCM=Ade/9DM==de7C
A[a6_DJlA[dV?08V?@0<I[MR]VJgI[LU^BFIB[e6_4[MA[a:_Eif0`0000=NMSHk<Q/00SHK00Y6gDJl
A[e6_FKGI[IVeVJf8GP000=6_005AYa:gD[LB]e:g003H[L02f:fDi5?TDZlA[a:_4JlC]e:g4kMC]`0
0TJm0eXe00EF=EXe?U/nO3iK009>g00:C]e>g4kMC]a>gDkLA]e6_F:GGWH2GYH01F:G>S/j>cXkC]d0
0dkL00i>gDkLC_a>o5;mC]a>oDklD_e:g4EAAE15DDE@0TEA00A5LDEAAG401P=>g006C_aBoDkLD_a>
o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0AOol2000;Ool000mo
o`@000Aoo`@000Ioo`03001oogoo01Qoo`0H@[e=de7DCM=Ae4gCDMA=delYA[a:_DJl9SdR?6JgH[IV
]f:fI[LQVBFi8IU6_D:l0`000?=NMV:GGWIO/enbB[e6_4ZmA[a:gDJlB]eV]V[GI[IZefJf8GPMEdkM
B[a:gDZlB]e6_4[MA[aV]f:FI[M?LE>AA[a:_DJlB[e6_4kMB]a>gD[LA[eF=EYFESEJ=EHe@W`nFcil
B]a>oD[LC]e:g4kmB]a>gD[LB]e6_6:GGWIRUeif>S/j>SXk>SYBoDkLD_e>g5;mC]aBoDkLD_e>g5;m
C]aBoD5@AG55D4EaAE19LDEABG55D006B]a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`03Woo0`0000=oo`00Ool02Woo000>Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol067oo00LnWE7CCM=O:DgCDM==d`02F`T0
1U/YA[a6_DJlI[MR]P=V]`9?TP04A[`000000002A[d024:mGYINMUjGGk9O/enbB[d3A[`01dKMA[a6
_BiMI]MV]VKF008QN0047GQ:gD[LB]d3A[d00dKMH[IR]`02H[L03Bgj<OY:g4kMB]a>g4[LB]e:g4[M
A41J=EHe00=J=@0AESDnFciK?Wa>g4kMC]a>gDkLC]e>g4kM2I/9^ejFHYMNMP02GYH02T[LB[a:_4Zl
C_e>g4klC]aBoDkL0Tkl00I>oDkLC_e>g4kmAE02AE402DEaAE55LDEaBG401@06C]a>o@02C]`00e;l
D_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;l
D_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d02Woo1000
17oo00<007ooOol02Goo000COol01000Oomoo`0017oo00<007ooOol00goo0P006Woo015=de7DCM=A
e4gCDMA=dcil>U/nO4:lA]e2_6JgH[IV]f:f00<0003j@Ya6_D:LA[e2_4JmGWIRUenbHYMNMSHk<QY:
gDJlB]e:_39m;UaZefJfJ]MV]V[G7EPQN1eGC]e:_4[MA[a:gDJlB]eRUVJgHYHanRgI<OY:g4kMB[a>
gD[LC]e:g4kM@[aJ=EHeFUIF=E<[C`Y>gDZlB]e>g4kmC]a>oDkLC_e:g4kMGWIRUeifHYMNMU=_Cdi:
gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4EAAE19LDE@BG55D4Ua@W]6W49kAYa>g5;mC]aB
oDklD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d6Ool30008
Ool00`00Oomoo`09Ool001=oo`04001oogoo0004Ool00`00Oomoo`02Ool2000KOol023jMCM=AddgC
DM==de7C>U`3?W`00cYLA[e6_@030002I[L01RFIB[e6_4[MA[a:_@96_@05GWINUUifGYLb6`02=Q/0
2T[MB[a:gD[LI]MV]VKFI[IVefJf0dJl00E6W4[MB]a:gAhL008R700<H[MRUV:gH[LanRgj<OX]nTkM
B]a>gDkL0TJm0eXe015F=EXeD`YC:dZlB]a:_4[LC]a>gDkLC]e>g4KMA[e:gEif009NUP05Dfi?CTm>
Cdi:g002B[`01dkLD_e>g4klC]aBoDkL009>o004C]e:g4kMAE02AE4014EaAE55LDEA1DJL00=>o5;m
C]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0goo0`00
37oo00<007ooOol027oo000?Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0K
Ool02U7DCM=Ae4gCDMA=de7DA[a:_DJl0`0001dR?2HmH[IV]f:f9KTQVD[MA[a:gDJl0GX1FF:GGWIR
UeifHYLb6SHk<QY:gDJlB]e6_6[GI[IZefJf0080003RA[e6W4JmB[a>gD[LC]e:_6JgHYIV]f:FI[M6
_4ZmA[a:_DJlC]e:g4km@[a6_D:lFUIF=EXeC`YC:dl:Db]:g4kmB]a>gD[LC_e>g4kmB]a:gDJlHYMN
MV:GGWIRUcXj>S/j>TkMB]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a5LDE@AG55D4UaAE59LDEAC]e:
g4kMB[a>gDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`2000?Ool00`00Oomoo`08Ool000moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo01]oo`07?YeAddgCDM==de7CCM<00`0000A6_4Jm8S`V?@9V]`0>H[IV]fJg9KTU
VBFiA[a:gDJlGYINMUjGGWINUP9O/P=6_005A]e6_4JmI[IVe`03I[H28GP3A[`3A[d00dKMA[eR]`02
H[L2Cg4024JlB[a6_4ZlA[a>gD[LC]d2A[d01EHeFSEJ=EXeESD00SiK00hnO4kLC]a>g4kMC]a>gDkL
C]e:g4KMA[eRUeif0UjF0cXk00M>g4kMC]a>g4klD_e>g002C_`01U;mC]a>oDklC]e5D095D@06AG55
DDEaAG59L@061DkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l47oo00<007ooOol027oo000?Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0KOol01D:mCM=Ae4gCDM@00P000?mK25/YF`Q:_DJlA[eR]VJgH[IV]f:f
I[M6W4Jm@Ya6_D:lA[e2_6:GGWIRUe^BGk=K/TZmA[a:_DJlB]e6_4[MI[IZefJfJ]LMF25h7EM>gDZl
B]e6_4[MA[a:gF:FI[MRUVJg;MTanT[LC]e:_4kMB]a>gD[LC]e2_5XeESEC:eHeFSDnFd9l?U/nO4kL
C_e>g4kmC]a>oD[LC]d5VPVkGWIRUeifHYMNMSXk>SXj>dkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkL
AE55D4UaAE19LDE@BG55D@0600EBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`000YBoE;lD_eBo5;mD_aBoE;lD_eBo0moo`03001oogoo00Qoo`003goo1@000goo1000
1Goo0P0077oo00<nWE7C00000P0000=Ade/9Ool00Sil00DjG4JmA[e6_F:f00=V]`05Cg5?TTJlA[e6
W003A[d01EifGYINMUjGGWH00SHK00E:gDZlB]e:g2im008^G@04I[IVefJfI[H28GP01D[LB]e:g4[M
B]`00TJm0196gF:FH[MR]c7j;OXanT[LC]e:g4kLB]a:gD[LB]e6_EXeESD3FSD03DZlB]a:_4[LC]a>
gDkLC]e>g4kMC]a>gEif009NUP05GYMNMTm>Cdi:g002B[`00dkLC_e>g002C_`025;mC]a>o4klC_e>
g4km@[d2AE401DEaAE55LDEAAG400dJL0TkL00E>oDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo0moo`03001oogoo00Qoo`0087oo00<007ooOol0
6Woo0`0000AAe4gCDMA=d`9oo`1B?W`jFcil@[a6gD:lI[MR]TnBH[IV]b6I9KU6W4Jm@Ya6_D:lA[eN
MV:GGWIRUc8J=S/b6T[MA[a:gBiM<WeV]V[GI[IZefJf8GPMF25hB[a>gD[LC]e:_28m7QaV]f:FI[MR
US7j;MTanRgJC]e:_4kM@[a6_D:lFUIF=EXeESEJETl:DbY:_4kMB[a:gD[LC_e>g4kmB]a:gDJlB]eN
MV:GGWH2Cdh0]E=^B[a:gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LA[e5D4EaAE19LDEABG55DDJL
@W]6W49kD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m00ioo`03001oogoo00Qoo`0087oo00<007ooOol05goo0`000goo00A=de7CCM=K
2@=oo`<nO0=6_@0:9SeR]VJgI[LU^BFI9KU6_4[MA[`20GX01EjGGWINUUifGYL00cHK00E:gDZlB]eV
]VKG00=V]P8000=6_005B]a:gD[LB]e:g003H[L02V:FH[M6_4ZlA[a:_4JlC]e:g4kM0dJm0eXe00AF
=Dl:C`YC:P=>g00<C]e>g4kMC]a>gDJmA]e6_EjGGWINUUif0cXk00=>g4kMC]`00TkL00YBoDkLC_a>
o5;mC]a>oDklC]e2_@95D@06AG55DDEaAG59LDEa14kL00ABo4klD_e>g09Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00eoo`03001oogoo00Qoo`00
7goo00<007ooOol05Goo0`001goo00==de7DOol017oo0?m:_DJlA[dR72HmH[IV]f:fI[MR]RFi8ITU
^DJlB]e6_6:GGWIRUeifHYMNMTZmA[a:_DJlB]e6_4[MI[IZefJfJ]MV]P00AYa6_DJLA[e6W4[MA[a:
gDJlI[MRUVJgBg1?TDJlB[e6_4ZmB]a>gD[LC_e2_4JmESEJEUHeFSEF=D9l?U/nO4[LC_e:g4kMB]a>
oDkLC_e6_4[MA[aRUeifHYLj>SXk>SXj>dkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLA[e5D4UaAE19
LDE@BG55LDUa00I>gD[LC]e:_5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d000YBo5;mD_aBoE;lD_eBo5;mD_aBo@eoo`03001oogoo00Moo`007goo0P004goo0`002Woo
00=AddgCOol017oo00E6_4JmA[a6_F:f00=V]`06H[IV]dJlA[e6W4Jl0TJm00Q2_EjFGWINUeifGk9K
/TZm0dJl00E6gDJlA[eV]VKG009V]P8QN005B]a:gD[LB]e:g002A[d01DKMHYIR]f:gCg400Tm`00]6
_4ZlA[a:_4[LB]e:g4[MA[eJ=EHe00=J=@<nF`0??Wa>g4kMC]a>gD[LC]e>g4kM2I/9^eifGYMNMUjF
00@j>`03C]a>oDkL009>o008D_e>g4klC]a>oDkLC_e2_@95D@95L@04BG55LDUaAG4200H2C]`01Tkm
C]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo7oo00aoo`03001oogoo00Moo`007goo00<007ooOol03goo0`003Goo00==de/YOol01Goo
0?m2_4KM@[a6_F:fI[MR]VJgBg5?TTJLA[e2W4Jm@[a6_EifHYMNMUnbFi9O/U^BB]e6_4[MB[`bOBiL
<WeV]V[GI[IZeaeH8GQ:_4kMB[a:gDZlB]e6_4[MHYIV]f:F<OX]fC7jB]a>gDZlC]e:g4kMB]a>gEHe
FSEF=EYFESEJ=DZlC]e:_4[MC]a>oDkLC]e:g4kmB]a>gEifHYMNMV:GGWI>gDZlB]e:_4kMC]aBoDkL
D_e>g5;mC]aBoDkLC_e>g5;mAE19LDE@BG55DDUaAE59LD9kAYa2Ne;mC]aBoDkLD_e>o5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`000YBoE;lD_eBo5;mD_aBoE;lD_eBo0aoo`03
001oogoo00Moo`007goo00<007ooOol037oo0`0047oo00=AdgooOol01Woo0dJm00=V]f:fI[L00VJg
00DUVBFiA[a6_DJL00=6_@04GWIO/UifGYL3=Q/01T[MB[a:gD[L;Wd^G@9V]P03I]MV]R5h008QN00:
B]a:gD[LB]e:g28L7Q`R7F:FH[L2<OX01Rgj<OY:g4kMB]a>g0A6_@9J=@0EESEJ=Dl:C`Y:_4[LB[a:
g4kLC]e>g4[MA[e6gDJmB]eNMUjFGWI?CTm=009:_006B]a:_4ZlC]aBoDkL0Tkl00IBoDkLC_a>g4kM
B]`2AE401DEaAE55LDEaBG401DJL00ABo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol02Woo00<007ooOol01goo000OOol0
0`00Oomoo`09Ool3000COol00dgCOomoo`07Ool07d:lA]e2_6Jg8QaV]f:f9KTQVBFiA[a:gDJl0GX1
F@5jGWIRUeif=S/b6SHk<QY:gDJlB]e:_6[GI[IZefJf0080003XB[e6W4JmB[a>gD[LC]dN728mHYIR
]f:FI[L]fS7j;MTanT[LC]e:g4km@[a6_D:lFUIF=EXeESEC2Tl9C`Y:g4kmB]a>gD[LC_e>g4[MA[a:
gDJlHYMNMV:GGWHj>cXjC_e>g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e:g4kMAE19LDE@BG55D4UaAG59
LDZlC]e:g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`:Ool00`00Oomoo`07Ool001moo`8000Qoo`80025oo`058S`V
?B8mI[MR]P02I[L03BFi9IU:_DJlB]e6_4ZmGWINUeifGYINMTZm00=6_005A]e6_4JmA[eVe`03I[H0
0`00AYa6_002A[`01DJLB]e:g4[MHYH00f:g00Y;L4m`A[a:_4JlB[a>g4kMB]a>g@96_@05ESEJ=EXe
FSEF=@02?U/03cilC]a>g4kLC]e>g4kMC]a:gDJmA]e6_EjGGWINUP03>S/2C]`01TkMC]a>g4klD_e>
g09>o006D_e>g4kmC]a5LDEA0TEa00E9LDEaBG55L@0600E>g09Bo005D_e>o5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`08Ool00`00
Oomoo`07Ool001ioo`03001oogoo00Eoo`<002Eoo`0MI[MR]VJgHYIV]bFI9KTQVDJm@[a6_D:lA[eN
MV:GGWIO/U^AB[e6_4ZmA[a:gDJlB]eV]V[GI[IZe`028GP0j4ZlC]e:_4[MB[a:gDJlB]eRUVJgHYI?
L4]@B[e6_4ZmA[a:_D[LC]e:g4kM@[aJ=EHeFUIF=EXe?U]2O3iK?Wa:g4kmB]a>gD[LC_e:g0Vk1IX9
^eifHYMNMV:G>SXj>cXjD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e5D4UaAE19LDEABG55DDUb00H0
1dZlC]e:g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m2Woo00<007ooOol01Woo000NOol00`00Oomoo`02Ool3000YOol3
I[L2Bg400dJlA[e6W003A[d01D:mGYINMUjGFi800U^b00U:_DJlA[a6_4KMA[a6_FJfI]L00VJf0R5h
00E:g4[MB]a:gD[L0096_@0?H[MRUV:gH[LanRgjC]a:g4kMB]a>g4[LB]e:g4A0009J=@0EESEJ=EXe
FSE:_4[LB[a:g4kLC]e>g4kMB]a>gDkLC]eNMUjFGWINUeif009:_006B]a:_4klC]a>oDkL0Tkl00IB
oDkLC_a>g4kmC]`2AE401TEaAE55LDEaBG55L@=6W0=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;l
D_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo0Yoo`03001oogoo
00Ioo`007Woo00<007oo00000P00;7oo00=RUVJgH[H00Woo01PU^BFIA[e2W4Jm@[a6_D:lHYMNMUjG
<QXf>c8JB]e6_4[MB[`bOBiLJ]MV]V[GI[H38GP06QeGC]e:g4kMB[`R?AhL8QeRUVJg;MXanRgIC]e:
g4kMB[a>gD[LC]e:g4KMESEJ=EHeFUH20000bdZlC]e:_4kmC]a>oDkLB]e6_4[MA[aRUeifHYMNMTm>
Bbe>gDZlB]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e2_4UaAE59LDEABG55LDUa@W]6W49kD_e>g5;m
C]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`02Goo00<007ooOol01Woo000NOol3000_Ool01F:fOomoogoo9IT00RFi00=:
gDJlB[d00P5j00ANMUjFGWHf>`<f6`05=S]:_4[MB]aVe`03I[H20003A[`01TJLB]e:g4[M7Q`R709R
]`0:HYIR]c7j<OX]nS7jC]a>gD[LC]d2A[d01EHeFSEJ=EXeESD00`00015:_4[LB[a>gDkLC]e>g4[M
A[e6gDJmGYMNMTm=Bde?CD/]009>g006C]e>g4klC]aBoDkL0Tkl00IBoDkLC_e>g4JmAE42AG401DUa
AG59LDEaBG400dJL00EBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`8Ool00`00Oomoo`06Ool000Aoo`D000=oo`@0
00Aoo`@000Moo`03001oogoo03=oo`3o9ITU^DJlB]e6_4[MGWINUeifHYMNMTZmA[a:_DJlB[e6_4[M
A[aZefJfJ]MV]R5hAYa:_DJLA[a6W4kMB]a>gF:FI[MRUV:gBdm?L4JlB[e6_4ZmB]a>gD[LC_e2_4Jm
ESEJEUHeFSDnFd9l?U/nO4[LC_e:g4kmB]a>oDkLB]e6_4[MGWI?CUifHYLj>SXk>SY>oDkLC]e:g5;m
C]aBoDkLD_e>g5;mC]aBoD:lBG55D4UaAE59LDEABG95L@07B[a>gD[LD_e>g5;mC]aBoDkLD_eBo5;m
C]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0004D_eB
o5;mD_`7Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`05Ool2000cOol00bFi9ITU^@02A[d024:mGYINMUjGGWIK/E^AB[d3A[`01DKMA[a6
_FJfI]L00fJf00HQN4[LB]e:g4[MB]`2A[d04TKMHYIR]f:gBg1;D4ZlA[a:_4JlB[a:g4[MB]a:gDJm
FSEF=@9J=@05?W`nFciK?U/nO003C]`02TkMB]a>gDkL2K/5VUjFGWINUeif13Xk00A>o4kLC_e>g09>
o00:D_e>g4klC]a>oDkLC_e5DDEaAE42AG401DUaAG59L@0600L00dkL00EBoDklD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02
D_`7Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool0
0`00Oomoo`07Ool00`00Oomoo`0aOol05dJm@Ya6_D:lA[e2_6:GGWINUe^AFk9KTE^bA[a:_DJlB]e6
_4[M;UeZefJfJ]L00R5h0>Y:_4kMB[a:gDZlB]e6_6:gHYIV]f:F<OX]fDkMB]a>gDZlC]e:g4kMB]a8
H5HeFSEF=EYFESE:gDZlC]e:_4[MC]a>oDkLC]e:g4kmB]aRUeifHYMNMV:GGWI>gDZlB]e:_5;mC]aB
oDkLD_e>g5;mC]aBoDkLC_e>g4UaAE59LDEABG55LDUaAG56W49kD_e>g5;mC]aBoDkLD_e>g5;mC]aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d6Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`08Ool00`00Oomoo`0aOol00dJmAYa6_002A[d01EifGYIKTEjGGWH00SHK00Hf>dZl
B]e:g2im;Ud2I[H00fKGI[HQN0038GP014[MB]a:gD[L0QhL00<R7F:FH[L00S7j00X]nTkLB]a>gD[L
C]a:g4[MB]a6_@9J=@0EESEJ=@00B]a:_4[LB[a>gDkLC]e>g4[MA[e6gDJmGYMNMUjFGWI;CD/]009:
_006B]a:_4klC]aBoDkL0Tkl00IBoDkLC_a>g4kmAE42AG4014UaAG59LDEa14JL00E>oDkLC]a>g5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aoo`06Ool00`00Oomoo`05Ool000Ioo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`09Ool00`00Oomoo`0aOol054[MA[a:gD:lA[eNMV:GGWINUc8J
=S/b6SHkA[a:gDZlJ]MV]V[GI[H200006dZmAYa6_4JLC]e:g4kM7Q`R?F:FH[MRUVJg;MXanRgI<OY:
g4kMB]a>oD:lA[eF=EYFESEJ=@030000cT[MB[a>gDZlC_e:g4kmC]a:gDJlB]eNMV:GGWIRUcXj>S/j
>TkmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mB]a6_DE@BG55DDUaAG59LTEaAYa2NdJLC]aBoDkLD_e>
g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`6Ool00`00Oomoo`05Ool000Ioo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`0:Ool2000aOol02TJlB]e6_4ZmGWINUeifGYINMUjG0dJl00E:
_DJlA[e6_FKG00=V]P03I]L004Jl0096_005AYa:gD[LB]eRUP03H[L2Bdl024JlB[a6_4ZlC]a>gD[L
C]d2A[d015HeFSEJ=EXe0ciK00i>gDkLC]a>g4kMC]a>gDkLB]e6_DKMGWINUeif13Xk0TkL00i>gDkL
C_a>o5;mC]a>oDklD_e>g4kM@[e5LDEA0TEa00A9LDEaBG401`=>g006C_aBoDkLD_a>o5;m0e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo7oo00Aoo`03001oogoo00Eoo`0017oo0`0017oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00aoo`03001oogoo02moo`3o@[a6_D:lA[eNMUjGGWIRUeNAFk56_4ZmA[a:gDJlB]eV
]V[GI[IZefJf8GPQEdkMB[a:gDZlB]e6_4[MHYIV]f:FBg17CdZmA[a:_DJlB[e:g4kMB]a>gD:lFSEF
=EYFESDnO3iK@W`nFcilB]a>oD[LC]e:g4kmB]`9^`FJHYMNMV:GGWHn>cXj>S/j>U;mC]aBoDkLD_e>
g5;mC]aBoDkLC_e>g4JmAE59LDEABG55LDUaAG401`06C]e:_4kMC]aBoDkLD_e>g5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0004
D_eBo5;mD_`4Ool00`00Oomoo`05Ool000Ioo`03001oogoo00=oo`@000Aoo`@0011oo`03001oogoo
02moo`96_@04@[eNUUifGYL4Fi43A[`01DKMA[a6_BiMI]L00fJf0R5h00A:gD[LB]e:g096_@0?H[MR
UV:gH[LanRgjC]a:g4kMB]a>g4[LB]e:g4QP009J=@0DESEJ=EXeB]a:_4[LB[a:g4kLC]e>g4kMB]a>
gDkLGYMNMUjFGWINU`=:_006B]a:_4klC]a>oDkL0Tkl00IBoDkLC_e>g4km@[d2AG401DUaAG59LDEa
BG400dJL00E>oDkLC]a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo009oo`03001oogoo00Eoo`00
:Goo00<007ooOol0;goo01A2_4Jm@[aRUeNAGYMNMSHk<QXf>dJlB]e:_2im;UaZefJfI]MV]V[G0R5h
0>`QEdkMB]a>gDZl8SdN728MHYIV]bgJ<OX]fDkMB]a>gDZlC]e:g4kMB]a6gEHeFSEF=EYF001:gDZl
C]e:_4[MC]a>oDkLB]e6_4[MA[aRUeifHYM;;4/]B[a>gDZlB]e:_5;mC]aBoDkLD_e>g5;mC]a>oD[L
A[e5D4UaAG59LDEaBG95LDJL@W]6W49kD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0goo00<0
07ooOol01Goo000ZOol00`00Oomoo`0_Ool01P5I0GYNMUjFGWINU`<f6`05=S]:_4[MB]aVe`03I[H0
0fKG00000002A[`014JLB]e:g4[M0QhL0V:g00YRUV:g<OXanRgj<OY>g4kMB]a>g@96_@04ESEJ=EXe
FSD300003dkMC]a>g4kLC]e>g4kMC]a:gDJmA]eNMUjGGWINUP02>S/3C]`04TkMC]a>o4kLD_e>g4km
C_aBoDkLC]e>g4UaAG59LDEaBG55L@99L@A>g005D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`3Ool0
0`00Oomoo`05Ool002]oo`80031oo`3oGWINUeifHYMNMUjGA[a:_DJlB[e6_4[MA[aVefJfJ]MV]VKG
001:_DJLA[a6W4kMB]a>gF:FI[MRUV:gAdm;KdJlB[e6_4ZmB]a>gD[LC_e2_4JmESEJEUHeFSDnFd9l
?U]>gD[LC_e:g4kMB]a>oDkLB]e6_4[MGWIRUeif?S/j>SXkB]a>oDkLC]e:g5;mC]aBoDkLD_e>g5;m
C]a>oDEABG55DDUbAG59LDEaBI801dkMB[a>gD[LD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l005Bo@5B
o0=oo`03001oogoo00Aoo`00;Goo00<007ooOol0;Woo00INMUjGGWINUUNAFi43A[`01DZmA[a6_FJf
I]L00fJf0R5h00A:gD[LB]e:g096_@03A]eRUV:g009R]`8anP0;A[a:_4JlB[a:g4[MB]a:gDJmFSEF
=@02FSD04Sil?U/nFciKC]e>g4kMC]a>gD[LC]e>g0FK1IYNUUifGYMNMP<j>`05C]a>o4kLC_e>g002
C_`01U;mC]a>oDkLC_e>g095L@03BG55LDUa00=9L@0300M>g4km00=>g005D_e>o5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`2Ool00`00Oomoo`04Ool002ioo`03001oogoo02eoo`03HYMNMUjG009oo`3o
=QXf>dJlB]e:_4[M;U`bOBiMI]MV]V[GI[HQN25GC]e:_4[MB[a:gDJlH[MRUVJgHYHanRgI<OY:g4kM
B[a>gD[LC]e:g4kMESEJ=EHeFUIF=D[MB[a>gDZlC_e>g4kmC]a>oD[LC_e:g6:GGWIRUeifBbe734kM
B[a:gDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDE@BG55LDUaAG59TTEaBI92NdJLC]aBoDkLD_e>g5;m
C]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aoo`0000Ioo`00;goo00<007ooOol0;Goo00ANUWooOomo
o`8f6`06=S]:_4[MB]`^OBiM0VJf00=V]fJfI[H00b5h00A:gD[LB]e:g08N7004H[MRUV:gHYL3<OX0
14[LC]e:g4kL14Jm0UXe01AF=EXe001:g4ZlB]a:_4kMC]a>gDkLB]e6_DKMA[eNUeifGYI7;4/]0dZl
00I:g4kLC_a>g5;mC]`2C_`02e;mC]a>gDkLBG55LDUaAG59LDEaBG4014JL00I>o5;mC]aBo4klD_d3
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m009Bo003Ool007oo00Eoo`00<7oo0P00<Woo00/f>cHJ=S]6_4[MB[aV
efJfJ]MV]VKG0080000JAYa6_4JLC]e:g4kMB[aV]f:FH[MRUVJgA[a:_DJlB[e:g4kMB]a>oD:lA[e2
_5YFESEJ=@<0003DC]e:g4kmB]a>oD[LC_e>g4[MA[a:gEifHYMNMV:G>SXj>d[LC_e>g4kMC]aBoDkL
D_e>g5;mC]aBoDkLC_e2_4UaAE59LTEaBG95LDVBB]a>gDZlC]e>g5;mC]aBoE;lD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d000Ioo`00<Woo00<007ooOol0<7oo0TJl00E:_DJlA[e6_FJg00=V]P03I[LQ
N25h0096_00BAYa6_DJmA]e6_F:gHYMR]dM>Adm6_4ZlA[a>gDkLC]e:g4kM0TJm00AF=EXeFSEJ=@<n
F`0>C]e>g4kLC]a>gDkLC]e6_D[MA[e6gEifGYMNMP<j>`=>g00>C]e>g4klC_aBoDkLC_e>o5;mC]a6
_DEaBG55L@A9L@0300M>g4kL009>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGoo
00001Woo000cOol00`00Oomoo`0_Ool0D4JlB[e6_4ZmA[a:gFJfI]MV]V[GI[HQN25g9GQ:_4[MB[a:
gDJlB]eRUVJgHYIR]bgI<OY6_4ZmA[a>gD[LC]e:g4kM@[aJ=EHeFUIF=Cil?U]2O3iKC_e>g4kmC]a>
gD[LC_d5VPFKGWIRUeifHYMNMSiK>SXj>dkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oD:lBG55LDUaAG59
TTEaBI8200L0YdkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`017oo00<007ooOol00goo
000dOol00`00Oomoo`0_Ool014ZlB]e:g4[M0RiM00=V]VJgI[H00VJf0R5h00A:gD[LB]e:g096_@04
A]eRUV:gHYL3<OX024[LC]e:g4[MB]a:gD[LB]d2FSD04eHeFSEJ=D[LB[a:g4ZlC]e>g4kMC]a>gD[L
C]eNMUjGGWINUUif0080009:_006B]a>g4klC]a>oDkL0Tkl00YBoDkLC_e>g4JmAG59LDEaBG55L@99
L@=6W006C]a>oDkLC]aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;l00000e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo00Ioo`03001oogoo00=oo`00=Goo0P00<7oo
00Y6_4[MB[a:gFJfJ]MV]VKGI[IZe`8QN00I8GM>gD[LC]e:_28m7QaR]f:FI[MRUS7j;MTanT[LC]e:
_4KM@[a6_D:lA]eF=EXeESD00P0000i:gDZlC]e:_4kmB]a>oDkLB]e6_4[MGWIRUeif10000;M>gDZl
B]e>g5;mC]aBoDkLD_e>g5;mB]a>oD:lBG55LDUbAG59LTEaBI92NdJL@W]6W4kLD_e>g5;mC_aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_d02goo00<007ooOol00goo000gOol00`00Oomoo`0^Ool014JlA[e6_DKM0fJf00=V]b5h00000TJl
0156W4[MB]a:gD[LH[MRUf:gHYIR]dJlB[a6_4ZlC]a>gD[L00=6_@04ESEJ=EXeFSD300003TkMC]a>
g4kLC]e>g4kMC]a:gDJmGYINMUjGGWH4>S/2C]`03TkMC]a>o4kLD_e>g4kmC_aBoD[LC]e5LDUaAG44
BG45C]`00dklD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@02D_`00`00D_eBo002D_`?Ool00`00Oomoo`03Ool003Qoo`03001oogoo02ioo`3WA[a:gDJlI]MV
]V[GI[IVeb5g9GQ6W4JlAYa:gDJlB]e6_6JgHYIR]d<^Adm6_4ZmA[a:_D[LC]e:g4KM@[a6_EHeFUIF
=EXe?U]2O3iKC]e:g4kmB]a>gD[LC_e:g4[MA[aRUeifHYLj>SiK>SXj>cXjC_e>g4kMC]aBoDkLD_e>
g5;mC]aBoD[LBG55LDUaAG59TTEaBI801dkMB]a>gDZlC]e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00019oo`03001oogoo00=oo`00>Goo00<007oo
Ool0;Woo00A6_4JmA[d^G@=V]P<QN003B]a:gD[L0096_@05A]eRUV:gHYMR]`02<OX01d[LC]e:g4kL
B]a:gD[L0096_@03FSD005Xe009J=@<nF`0=C]e>g4kMC]a>gD[LC]d5VPFKGWINUUifGYL00dZl00I:
g4ZlC_a>g4kmC]`2C_`025;mC]a>oDkLC_e5LDUaAG44BG4200L2C]`01TkmC]a>g5;lD_e>o09Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`017oo00<007ooOol03goo00<007oo
Ool00goo000jOol2000_Ool08RiL;WeV]VKGI[IZefJf8GPQMbEhB[a:gDZlB]e6_4[MHYIV]f:F<OX]
fC7jB]a>gDZlC]e:g4kMB]a6gEHeFSEF=EYF0P0000i:_4kMB[a>oDkLC_e>g4kMB]a>oEifHYMNMV:G
0P000:U:_4kMB[a:gDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a9LDEaBG95LDVBAG59TT9kAYa2Ne;mC]aB
oDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo008Ool00`00Oomoo`0?Ool0
0`00Oomoo`03Ool003aoo`03001oogoo02eoo`=V]P03I[MV]VJf0096_005AYa6_4[LB]e:g0027Q`0
16:gHYIR]f:G0c7j00A>g4kMB]a>g@96_@05ESEJ=EXeFSEF=@0300003DZlB]a:_4kMC]a>gDkLB]e6
_DKMGWINUeif00<000=>g00>C]e>g4klC]aBoDkLC_e>o5;mC]a>gDEaBG55L@99L@03BG99LDVB0096
W005AY]Bo4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`<Ool00`00Oomoo`0?
Ool00`00Oomoo`02Ool003eoo`03001oogoo02eoo`3DI[IZefJfI]Moo`00AYa6_4JLB[e:g4kMB[aV
]f:FH[MRUTM>@bi:_DJlB[e:g4kMB]a>oD:lA[eF=EYFESEJ=CiK@W`nFcilB]a>oD[LC_e:g4kmC]a:
gDJlHYMNMV:GGWHnFcXj>S]:g4kmC]a>gDkLD_e>g5;mC]aBoDkLD_e>g4JmAG59LDEaBI95LDVBAG40
24[LC]e:_5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA5oo`03001oogoo00ioo`03001oogoo
009oo`00?Woo00<007ooOol0;7oo00=V]fJfOol00Woo0R5h00]:g4[MB]a:gDJmA]e6_F:gHYMR]f:F
008anP0:B[a6_4ZlB]a:gD[LB]e6_EXeESD3FSD3?U/03CilC]a>g4kLC]e:g4kMC]a:gDJmGYINMUjG
00@j>`05C]a>o4kLC_e>g002C_`025;mC]a>oDkLC_e2_DUaAG44BG400dVB00L01`03C]`2D_`01E;m
C_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoGooOol04goo00<007ooOol03Goo00<007ooOol00Woo000oOol00`00Oomo
o`0aOol0ab5g9IQ:_4[MB[a>gDJlB]eRUVJgHYIR]bgI<OX]nTkMB[a>gD[LC]e:g4b0ESEJ=EHeFUIF
=D[MB[a>gDZlB]e>g4kmC]a>gD[LC_e:g6:GGWIRUeifHYM:_4kMB[a:gDkLD_e>g5;mC]aBoDkLD_e>
g5;mC]a6_DEaBI95LDVBAG59TTUaAYa2NdJLC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Uoo`03001oogoo00eo
o`03001oogoo009oo`00@7oo0P00<Goo0b5h00Y:g4[MB]a:gAhL7QeRUV:gHYMR]`<anP07C]e:g4kL
B]a:gD[LA[d00UXe019F=EXe001:g4ZlB]a:_4[LC]a>gDkLB]e6_DKMA[eNUeifGYH20003B[`01T[L
C]a>o4kLD_e>g09>o006D_e:g4kM@[e9LDEa0TUa00=9LTUaBI800TJL00E6VdJLC_aBoDkL009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m021oo`03
001oogoo00aoo`03001oogoo009oo`00@Woo00<007ooOol0;goo01U6_4JLB[e:g4kMB[a>gF:FH[MR
UVJgHYI:_DJlB[e6_4kMB]a>oD:lA[eF=EYFESEJ=@030000X4kMB]a>oD[LC]e:g4kmC]a:gDJlB]eN
MV:GGWIRUcXj>S]:g4kmC]a>gDkLD_e>g5;mC]aBoDkLD_e:g4JmAG59LTEaBI95LDVBAG5>gD[LC]e:
_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l9Goo
00<007ooOol02goo00<007ooOol00Woo0013Ool00`00Oomoo`0_Ool01DJlAYa6_4JmA]d00TJm00=R
Uf:gHYH00P0000M:_4JlB[a6_4kMB]a>g@02A[d015HeFSEJ=EXe0ciK00i>gDkLC]a>g4kMC]a>gDkL
B]e6_DKMGWINUeif0cXk0dkL00Y>gDkLC_a>o5;mC]a>oDklD_e:g0I9L@03BI801dkL00=>g09Bo005
D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l:7oo00<007ooOol02goo00<0
07ooOol00Woo0014Ool00`00Oomoo`0_Ool02T[MB[a>gDJlB]e6_6JgHYIR]f:F0S7j0:M>gDZlC]e:
g4kMB]a>gD:lFSEF=EYFESEJ=CiK@W`nFdkmC]a>oDkLC]e:g4kmB]`5V`EjHYMNMV:GGWHnFcXj>S]>
g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e5LDVBAG59TTEaBI99L@0800MBoDkLD_e>g5;mC]aBoDkLD_eB
o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m02eoo`03001oogoo00]oo`03001oogoo005oo`00AGoo
0P00<7oo00U:gD[LB]e6_DKMA[eR]f:GH[L00c7j00M>gD[LC]a:g4[MB]a:g@02FSD045HeFSEJ=@00
B[a:g4ZlC]e>g4kMC]a>gD[LC]e>g5jG0eif0P000TZl00I:g4ZlC_a>g4kmC]`2C_`01U;mC]a>oDkL
BG55L@99L@03BI99LDVB0096W005AY]>g4kLC_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0U;l<Goo00<007ooOol02Woo00<007ooOol00Goo0017Ool00`00Oomoo`0^Ool02TkMB[a>gAhL7QeR
UV:gHYIR]bgI0S7j00Y>gD[LC_e:g4Jm@[a6gEHeFSEF=@<0000=B[a>gDZlC_e:g4kmC]a:gDJlB]eN
MV:GGWH00`00089:g4kmC]a>gD[LD_e>g5;mC]aBoDkLD_e:g4kmAG59LTEaBI95LDVBAG59TT9kAYa2
Ne;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoCEoo`03001oogoo00Uoo`03001oogoo005oo`00
B7oo00<007ooOol0;Woo00M:gD[LB]eRUf:gHYIR]`0200001dJlB[a6_4kMB]a>gDkL0096_@=J=@04
ESDnFciK?W`3C]`02TkMC]a>gDkLB]e6_DKMGWINUeif0cXk0dkL00Y>gDkLC_a>o5;mC]a>oDklD_e>
g0A9L@05BI99LDVBBG402003C]`015;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo3Uoo`03001oogoo00Uoo`03
001oogoo005oo`00BGoo00<007ooOol0;Woo00M:gDJlB]eRUV:gHYIR]`02<OX0VDJlB[e6_4kMB]a>
gD[LA[eF=EYFESEJ=CiK@W`nFd9lB]a>oD[LC]e:g4kmB]a:gDJlHYMNMV:GGWHnFcXj>S]>g5;mC]aB
oDkLD_e>g5;mC]aBoDkLC_e2_4VBAG59TTEaBI99LDVB00L024[LC]e:_5;mC]aBoDkLD_eBo5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00mOol0
0`00Oomoo`08Ool00`00Oomoo`01Ool004Yoo`8002moo`06A]e6_F:gHYMR]f:F0c7j00U:g4kLB]a:
gD[LB]e<P5XeESD00eXe00a:_4[LB[a:g4kLC]e>g4kMB]a>gDkLGYL3GWH20002B[`01T[LC]a>o4kL
C_e>g09>o006D_e>g4kmC]a6_DEa0TUa00U9TTUaBI99TDJLAY]6W4kLC_d00TkL00=Bo5;mD_`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l@Goo00<0
07ooOol01goo00<007ooOol00Goo001<Ool00`00Oomoo`0]Ool01QhM6QaR]f:FH[MRUP<anP0JB[a>
gD[LC]e:g4kM@[aJ=EHeFUIF=@00B[a>gDZlB]e>g4kmC]a:gDJlB]e6_6:GGWIRU`80001dB[a>gDZl
B]e>g5;mC]aBoDkLD_e>g5;mB]a>oD:lBG95LDVBBG59TTUaBI92NdJL@W]BoDkLD_e>g5;mC_aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoDIoo`03001oogoo00Io
o`03001oogoo005oo`00CGoo00<007ooOol0;Goo00aR]f:FH[MRUf:gA[a:_4JlB[a:g4kMC]`2A[d3
FSD015He000000000dkL00U>gDkLC]e>g4kMA[e6gEifGYL00Uif0SXk0dkL019>gDkLC_a>g5;mC]a>
oDklD_e:g4JmBG59LTUaBI99LDVBBG44C]`015;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo04Moo`03001oogoo00Moo`40005oo`5oo`00CWoo00<0
07ooOol0;Goo00=R]f:FH[L00P0008a6_4ZmA[a:_D[LC_e:g4Jm@[aJEUHeFSEF=D9l?U]2O4[LC_e:
g4kMB]a>oD[LC]e6_4[MGWINUeif?U/j>SXk>SY>oDkLC]e>g5;mC]aBoDkLD_e>g5;m@[a9TTEaBI95
LDVBBG59TP07C]e:g4kMB[aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mCGoo00<007ooOol01Woo0@000Goo0Goo001?Ool2000]Ool016:GH[MRUWoo0S7j00U:g4kLB]a>
gD[LB]e:g4JmESD00eXe00eF=CiK?U/nO4kLC]e>g4kMB]a>gDkL1I/5VP02GWH02UjGGWI:_4ZlB]a:
_4klC]a>oDkL0Tkl00EBoDkLC_e>g4km00=9L@04BI99LDVBBI8200P2C]`01TkmC]aBo5;lD_e>o09B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo59oo`03001oogoo00Eoo`40005oo`5oo`00DGoo00<007oo
Ool0:goo00=RUWooOol00c7j00]:_4kMB]a>gD[LC]e:g4JmESEJEUHe0080000>C]e:_4[MC]a>oDkL
C_e:g4kmB]aNUeifHYMNMP80001VC]e:_4[MB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4VBAG59TTUaBI99
LDVB@W]6W49kD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lEGoo00<007ooOol01Goo
0@000Goo0Goo001BOol00`00Oomoo`0^Ool3<OX014[LC]e>g4kM0TJm0UXe00=F=EXe00000P0000]:
g4ZlB]a>g4kMC]a>gDJmA]e6_EjG009NMP<j>`9>g00CC]e>g4klC]aBoDkLC_e>o5;mC]a>gDUaBG99
LDVBBG59TTUaBI800TJL00E6Ve;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo5Uoo`03001oogoo
00Aoo`40005oo`5oo`00Dgoo00<007ooOol0;Woo07i:_DJlB[e:g4kmB]a>gD:lFUIF=EXeESE2O3iK
@W`nFdkmB]a>gD[LC_e>g4kmA[a:gEifGYMNMV:G>SXn>cXjC_e>g4kMB]aBoDkLD_e>g5;mC]aBoDkL
BI95LDVBAG59TTUaBI99L@09B]a>gDZlC]e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aMOol00`00Oomoo`03Ool1
0001Ool1Ool005Aoo`03001oogoo02ioo`04B[a6_4ZlB]`3B]d01DJmFSEJ=EXeESD00SiK00XnO3iK
C]e>g4kMC]a>gDkLC]d5VP9NMP03GYINMSXk00<j>`04C_a>g4kmC]`2C_`01E;mC]a>oDkLC_d00dUa
00=9TTUaBI800TVB00@024kLC]a>o@9>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo01ROol00`00Oomoo`03Ool10001Ool0
05Eoo`8002moo`0JC]e:g4kMB]a>gD[LA[eF=EYFESEJ=DZlC]e:_4[MB[a>oDkLC_e:g4kmB]aNUeif
HYMNMP80001IC]e:_4[LB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4JmAG59TTUaBI99LDVBBG56W49kD_e>
g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@1UOol00`00Oomoo`03Ool10001Ool005Moo`03001oogoo02aoo`04B]a>gDkLC]d2A[d2
FSD045HeFSEJ=@00B[a:g4ZlB]a>g4kMC]a>gDJmA]e6_EjF0Uif0`000TkL00I>gDkLC_a>g5;mC]`2
C_`02e;mB]a>gD:mBG99LDVBBI59TTVABI800TJL00E6Ve;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_aYOol00`00Oomoo`02Ool10001Ool0
05Qoo`03001oogoo02aoo`1ZB]a>oD[LC]e2_4KMESEJ=EHeFUHnFd9lB]a>oD[LC]e:g4kmC]a>oDJl
B]eNMUjGGWIRUcXj?S/j>TkmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g4JmAG59TTEaBI99LDVBBG402D[L
C]e:_5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eaOol01@00Oomo
ogoo00000Goo001IOol00`00Oomoo`0/Ool01D[LB]e:gD[MA[d00eXe00EF=CiK?U/nO3iK009>g009
C]e:g4kMC]a>gDJmA]eNMUjF009NMP<j>`9>g00:C_e>g4klC_aBoDkLC_e>g4km@[d2BG400dVBBG59
TP02BI8200P3C]`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_aeOol01000Oomo
o`000Goo001JOol2000]Ool064[LC]e:g4kMESEJEUHeFSEF=DkMB[a:gDZlC_e>g4kmC]a>oD[LC]eN
MV:GGWINU`800018B[a:g4ZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDEaBI99LDVBBG59TTUaAYa2NdJL
C]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mN7oo00@007ooOol0005oo`00G7oo00<0
07ooOol0:goo14Jm011F=EXeFSEJ=@00B]a:_4[LB[a>gDkLC]e>g4KMA[e:g@=NMP<00007B[a:g4Zl
C_a>g5;mC]`00Tkl00]BoDkLC]e>g4VBBG59TTVABI99TDVB0096W005AY]6W4klD_e>g002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m009Bo7aoo`03001oo`00005oo`00GGoo00<007ooOol0:goo05Y2_4KM@[aJ=EHe
FUIF=D9l?U]>oD[LC]e:g4kmC]a>oD[LB]e6_5jGGWIRUeif?S/j>SiKC]a>gD[LC_e>g5;mC]aBoDkL
D_e>g4kmAG59TTEaBI99LDVBBG5>gD[LC]e:_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_f0Ool10001Ool1
000005ioo`03001oogoo02]oo`96_@9J=@05ESEJ=CiK?W`nF`02C]`02DkMC]a>gDkLC]e:g4KMA[eN
UP02GWH2>S/013Xj>S]>g4km0TkL00=>o5;mC]`00Tkl00IBoDkLBG59LDVBBG43BI800`0800U>g002
C]`2D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoE;lD_`0Q7oo0P00001OOol2000/Ool0DD:lFUIF=EXeESEJESiK@W`nFdkmC]a>
oDkLC_e:g4kMB]aRUeifGYMNMV:GB[a:g4ZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD:lBI99LDVBBG59
TTVAAYa2NdJLC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo028Ool20000065oo`03001oogoo02Yoo`0@A[eJ=EXeFSEF=@00B[a:
g4ZlB]a>g4kMC]a6gDJmB]d3GWH02UjF000004ZlB]a:_4klC]aBoDkL0Tkl00]BoDkLC]e>g4JmBG59
TTVABI99TDVB0096W005AY]6W4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aoo`2:Ool20000069oo`03001oogoo02Uoo`04FSEF=EYFESD3
0000@d[LC]e:g4kmC]a>oD[LC_e6_4[MGWIRUeif?S/j>TkmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g4km
@[e9TTUaBI99LDVBBG5=TT[LC]e:_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;l08Yoo`@0009oo`00Hgoo00<007ooOol0:Goo00EJ=EHeFSEoocil008n
F`03C]a>gDkL009>g005C]e:g4kMA[eNUP02GWH2>S/01CXj>S]>g4kMC]`00Tkl00YBoDkLC_a>o5;m
C]a6_DUaBI99L@A9TP0300U>g4kL009>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00U;lS7oo10001Woo001TOol2000YOol00eHeFSEoo`02Ool0>d9l?U]2O4kLC_e>g4kmB]a>
gD[LHYMNMUjGGWIRUdZlB]a:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e2_4VBBG59TTUaCI99TDVB00P0
2DkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_d0Rgoo10002Woo001VOol00`00
Oomoo`0WOol00eXeOomoo`02Ool02T[LB[a:g4kLC]e>g4KMA[e:gDJm0Uif00ENUP00001:_4[L009:
_003C]aBoDkL009>o006D_e>g4klC]a>oDUa1TVB00I6W4JKAYa>g4kmC]`2D_`01E;mD_aBo5;lD_d0
0e;l00=BoE;lD_`0RWoo10003Woo001WOol00`00Oomoo`0[Ool0=4[LC]e:g4kmC]a>oD[LC_e6_4[M
GWIRUeifGYLj>SiKC]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mB]a9TTUaBI99LDVBBG5=TT[LC]e:_4kM
C]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mRWoo0`004Woo001XOol00`00Oomoo`0[Ool00dkLC]e>g002
C]`01DkMB]a>gDJmB]d00eif00Dj>cXj>S/j>dkM009>g003C_aBoDkL009>o006D_e>g4kMBG59TTUa
14VB00<02DkLC]`00TkL00=Bo5;mC_`00U;l00=BoE;lD_`0RGoo10005Goo001YOol2000/Ool0;4kL
C_e>g4kmB]a>gD[LC_eNMUjGGWIRUeifB]a:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC_e>g4VBBG59TTUa
CI99TTfB00P02DkLD_e>g5;mC]aBoDkLD_f8Ool4000IOol006]oo`03001oogoo02]oo`0:C]e>g4kL
A[e:gDJmA]eNMUjFGWH200001T[LB[a:_4kLD_e>g09>o006D_e>g4klC]a>oD:m1TVB00E6W4JKAYa6
W4km009>g8Moo`@001eoo`00K7oo00<007ooOol0:goo021>oD[LC_e>g4[MA[aRUeifGYLj>SiK>SY>
gD[LC_e>g5;mC]aBoDkLD_e>g5;mB]a6_DUaBI99LDVBBG5=TTVBRGoo10008Goo001]Ool00`00Oomo
o`0[Ool01TkMB]a>gDkLB]e6_@9NMP05GYHj>SXk>S]>g@02C]`00dklD_e>g002C_`01U;mC]a>oD:m
BI99T@E9TXIoo`<002Eoo`00KWoo00<007ooOol0:goo01i>gD[LC_e:g5jGGWIRUeifB]a:_4kMB[aB
oDkLD_e>g5;mC]aBoDkLC_e>g4JmBG59TTUaCI99TTfBBI62Ool4000XOol006moo`8002aoo`06B]e6
_DKMGWINUUif0P0000Y:g4ZlB[a:_5;mC]a>o4kLD_e>g09>o003C_e>g4VB00I9TWioo`@002aoo`00
LGoo00<007ooOol0:Woo011:gDJlB]eNMUjGGWHnFcXjC]e:g4kmC]aBoDkLD_e>g0Eoo`07BG59TTUa
BI99LDfBBI80NWoo1000<7oo001bOol00`00Oomoo`0ZOol01T[MA[eNMUifGYHj>P<j>`=>g0Qoo`03
BI99TDVB00=9TWMoo`@003Aoo`00Lgoo00<007ooOol0:Woo00ENUeifHYMNMUjG00ioo`06BG59TTUa
CI99TTfBLgoo1000>7oo001dOol2000[Ool00ejFGWINMP0?Ool00d:mBI99TP03BI9`Ool3000lOol0
07Ioo`03001oogoo02Qoo`03GWINUeif00moo`06@[a9TTVABI99TDfBK7oo1000?goo001gOol00`00
Oomoo`0XOol00eifOomoo`0>Ool00dJmBI59TP03BI9XOol40013Ool007Qoo`03001oogoo02Moo`03
001oogoo00ioo`06@[e9TTUaCI99TTfBI7oo1000Agoo001iOol2000WOol00`00Oomoo`0>Ool00d:m
BI99TP03BI9POol4001;Ool007]oo`03001oogoo02Aoo`03001oogoo00moo`05CI99TDVBBI5=TP1M
Ool3001?Ool007aoo`03001oogoo02=oo`03001oogoo00moo`E9TUUoo`@0059oo`00OGoo00<007oo
Ool08Woo00<007ooOol03goo00A9TTUaCI99TUIoo`@005Ioo`00OWoo0P008Woo00<007ooOol03goo
14VBDWoo1000FWoo0020Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool014JmBI5=TTVACWoo1000GWoo
0021Ool00`00Oomoo`0NOol00`00Oomoo`0?Ool014:mBI99TTVBBgoo0`00HWoo0022Ool00`00Oomo
o`0MOol00`00Oomoo`0?Ool014JmBG5=TTVBAgoo1000IGoo0023Ool00`00Oomoo`0LOol00`00Oomo
o`0?Ool014:mBI99TTVB@goo1000JGoo0024Ool2000LOol00`00Oomoo`0@Ool00dVBCI99T@0oOol4
001]Ool008Ioo`03001oogoo01Uoo`03001oogoo011oo`=9TS]oo`@0075oo`00Qgoo00<007ooOol0
67oo00<007ooOol047oo00=9LDfBOol0>7oo0`00MGoo0028Ool00`00Oomoo`0GOol00`00Oomoo`0@
Ool2BI8eOol4001hOol008Uoo`8001Moo`03001oogoo011oo`03@[e=TWoo031oo`@007aoo`00Rgoo
00<007ooOol057oo00<007ooOol047oo00=2_DVBOol0;7oo1000P7oo002<Ool00`00Oomoo`0BOol0
0`00Oomoo`0AOol00d:lCI9oo`0XOol40024Ool008eoo`03001oogoo015oo`03001oogoo019oo`03
BI9oogoo02Aoo`<008Qoo`00SWoo0P004Goo00<007ooOol04Woo00==TWooOol087oo1000Rgoo002@
Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol00dVBOomoo`0LOol4002?Ool0095oo`03001oogoo00eo
o`03001oogoo019oo`03CI9oogoo01Qoo`@009=oo`00TWoo00<007ooOol037oo00<007ooOol0:Goo
1000Ugoo002COol2000<Ool00`00Oomoo`0UOol4002KOol009Eoo`03001oogoo00Uoo`03001oogoo
029oo`<009moo`00UWoo00<007ooOol027oo00<007ooOol07Woo1000XWoo002GOol00`00Oomoo`07
Ool00`00Oomoo`0JOol4002VOol009Qoo`03001oogoo00Ioo`03001oogoo01Ioo`@00:Yoo`00VGoo
0P001Woo00<007ooOol04Woo1000[Woo002KOol00`00Oomoo`03Ool00`00Oomoo`0?Ool3002bOol0
09aoo`03001oogoo009oo`03001oogoo00]oo`@00;Eoo`00WGoo00D007ooOomoo`0000Uoo`@00;Uo
o`00WWoo0P0000=oo`00Ool017oo1000_Goo002POol200000goo000000020031Ool00:5oo`800<Eo
o`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003o
OomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.596 .716 .928 r
.39633 .69806 .40165 .70316 .41046 .70421 .40523 .6968 Mtetra
.839 .707 .717 r
.40523 .6968 .41046 .70421 .41963 .69467 .41464 .68043 Mtetra
.292 .339 .739 r
.41464 .68043 .41963 .69467 .42856 .69388 .4233 .68866 Mtetra
.62 .72 .918 r
.4233 .68866 .42856 .69388 .43756 .69189 .43231 .68694 Mtetra
.638 .737 .92 r
.43231 .68694 .43756 .69189 .44659 .68971 .44136 .6848 Mtetra
.64 .74 .921 r
.44136 .6848 .44659 .68971 .45565 .68755 .45044 .68259 Mtetra
.634 .737 .922 r
.45044 .68259 .45565 .68755 .46475 .68573 .45956 .68051 Mtetra
.584 .71 .93 r
.45956 .68051 .46475 .68573 .47377 .69064 .46869 .67945 Mtetra
.758 .64 .73 r
.46869 .67945 .47377 .69064 .48309 .67724 .47798 .66909 Mtetra
.491 .572 .865 r
.47798 .66909 .48309 .67724 .49227 .67582 .48714 .67064 Mtetra
.632 .73 .918 r
.48714 .67064 .49227 .67582 .50149 .67356 .49638 .6686 Mtetra
.647 .744 .92 r
.49638 .6686 .50149 .67356 .51075 .67109 .50565 .66619 Mtetra
.652 .748 .92 r
.50565 .66619 .51075 .67109 .52004 .66851 .51496 .66364 Mtetra
.655 .751 .92 r
.51496 .66364 .52004 .66851 .52936 .66588 .5243 .66101 Mtetra
.657 .752 .92 r
.5243 .66101 .52936 .66588 .53871 .6632 .53367 .65833 Mtetra
.658 .753 .92 r
.53367 .65833 .53871 .6632 .54809 .66048 .54308 .65561 Mtetra
.659 .754 .92 r
.54308 .65561 .54809 .66048 .5575 .65775 .55251 .65287 Mtetra
.55251 .65287 .5575 .65775 .56695 .65501 .56198 .65011 Mtetra
.56198 .65011 .56695 .65501 .57643 .65227 .57148 .64734 Mtetra
.57148 .64734 .57643 .65227 .58594 .64952 .58101 .64457 Mtetra
.658 .753 .92 r
.58101 .64457 .58594 .64952 .59548 .64677 .59058 .6418 Mtetra
.59058 .6418 .59548 .64677 .60506 .64401 .60017 .63903 Mtetra
.60017 .63903 .60506 .64401 .61466 .64125 .6098 .63625 Mtetra
.6098 .63625 .61466 .64125 .6243 .63848 .61947 .63346 Mtetra
.61947 .63346 .6243 .63848 .63398 .63571 .62916 .63067 Mtetra
.62916 .63067 .63398 .63571 .64369 .63293 .63889 .62787 Mtetra
.657 .753 .92 r
.63889 .62787 .64369 .63293 .65343 .63014 .64866 .62506 Mtetra
.64866 .62506 .65343 .63014 .6632 .62735 .65846 .62225 Mtetra
.65846 .62225 .6632 .62735 .67301 .62454 .66829 .61943 Mtetra
.66829 .61943 .67301 .62454 .68285 .62173 .67815 .61659 Mtetra
.657 .752 .92 r
.67815 .61659 .68285 .62173 .69273 .61891 .68805 .61375 Mtetra
.68805 .61375 .69273 .61891 .70264 .61608 .69799 .6109 Mtetra
.69799 .6109 .70264 .61608 .71258 .61324 .70796 .60805 Mtetra
.70796 .60805 .71258 .61324 .72256 .61039 .71796 .60518 Mtetra
.71796 .60518 .72256 .61039 .73258 .60753 .728 .6023 Mtetra
.728 .6023 .73258 .60753 .74263 .60466 .73808 .59942 Mtetra
.73808 .59942 .74263 .60466 .75272 .60179 .74819 .59652 Mtetra
.74819 .59652 .75272 .60179 .76284 .5989 .75833 .59362 Mtetra
.75833 .59362 .76284 .5989 .77299 .59601 .76852 .5907 Mtetra
.76852 .5907 .77299 .59601 .78319 .5931 .77874 .58778 Mtetra
.77874 .58778 .78319 .5931 .79342 .59019 .78899 .58484 Mtetra
.78899 .58484 .79342 .59019 .80368 .58726 .79928 .5819 Mtetra
.79928 .5819 .80368 .58726 .81398 .58433 .80961 .57895 Mtetra
.80961 .57895 .81398 .58433 .82432 .58138 .81997 .57598 Mtetra
.81997 .57598 .82432 .58138 .8347 .57843 .83038 .57301 Mtetra
.83038 .57301 .8347 .57843 .84511 .57546 .84081 .57002 Mtetra
.84081 .57002 .84511 .57546 .85556 .57249 .85129 .56703 Mtetra
.85129 .56703 .85556 .57249 .86605 .5695 .86181 .56402 Mtetra
.86181 .56402 .86605 .5695 .87657 .56651 .87236 .56101 Mtetra
.87236 .56101 .87657 .56651 .88713 .5635 .88295 .55798 Mtetra
.88295 .55798 .88713 .5635 .89773 .56049 .89358 .55495 Mtetra
.89358 .55495 .89773 .56049 .90837 .55746 .90424 .5519 Mtetra
.90424 .5519 .90837 .55746 .91905 .55442 .91495 .54884 Mtetra
.91495 .54884 .91905 .55442 .92977 .55137 .9257 .54577 Mtetra
.9257 .54577 .92977 .55137 .94052 .54831 .93648 .54269 Mtetra
.93648 .54269 .94052 .54831 .95132 .54524 .9473 .5396 Mtetra
.9473 .5396 .95132 .54524 .96215 .54216 .95817 .5365 Mtetra
.95817 .5365 .96215 .54216 .97302 .53907 .96907 .53339 Mtetra
.96907 .53339 .97302 .53907 .98394 .53597 .98001 .53026 Mtetra
.62 .728 .924 r
.39098 .69304 .39633 .69806 .40523 .6968 .39991 .69129 Mtetra
.45 .644 .94 r
.39991 .69129 .40523 .6968 .41464 .68043 .40879 .69232 Mtetra
.085 0 .09 r
.40879 .69232 .41464 .68043 .4233 .68866 .41804 .6827 Mtetra
.581 .68 .909 r
.41804 .6827 .4233 .68866 .43231 .68694 .42703 .68188 Mtetra
.632 .732 .92 r
.42703 .68188 .43231 .68694 .44136 .6848 .4361 .67985 Mtetra
.64 .739 .921 r
.4361 .67985 .44136 .6848 .45044 .68259 .4452 .67763 Mtetra
.639 .739 .922 r
.4452 .67763 .45044 .68259 .45956 .68051 .45433 .67543 Mtetra
.622 .73 .924 r
.45433 .67543 .45956 .68051 .46869 .67945 .46349 .67358 Mtetra
.081 .424 .869 r
.46349 .67358 .46869 .67945 .47798 .66909 .47259 .67848 Mtetra
0 0 0 r
.47259 .67848 .47798 .66909 .48714 .67064 .48198 .66499 Mtetra
.607 .705 .913 r
.48198 .66499 .48714 .67064 .49638 .6686 .49123 .66354 Mtetra
.642 .739 .919 r
.49123 .66354 .49638 .6686 .50565 .66619 .50053 .66123 Mtetra
.65 .746 .92 r
.50053 .66123 .50565 .66619 .51496 .66364 .50985 .65872 Mtetra
.654 .75 .92 r
.50985 .65872 .51496 .66364 .5243 .66101 .51922 .65611 Mtetra
.656 .751 .92 r
.51922 .65611 .5243 .66101 .53367 .65833 .52861 .65343 Mtetra
.658 .753 .92 r
.52861 .65343 .53367 .65833 .54308 .65561 .53803 .65071 Mtetra
.659 .753 .92 r
.53803 .65071 .54308 .65561 .55251 .65287 .54749 .64795 Mtetra
.659 .754 .92 r
.54749 .64795 .55251 .65287 .56198 .65011 .55698 .64517 Mtetra
.55698 .64517 .56198 .65011 .57148 .64734 .5665 .64239 Mtetra
.5665 .64239 .57148 .64734 .58101 .64457 .57605 .6396 Mtetra
.658 .754 .92 r
.57605 .6396 .58101 .64457 .59058 .6418 .58564 .63681 Mtetra
.658 .753 .92 r
.58564 .63681 .59058 .6418 .60017 .63903 .59526 .63401 Mtetra
.59526 .63401 .60017 .63903 .6098 .63625 .60491 .63121 Mtetra
.60491 .63121 .6098 .63625 .61947 .63346 .6146 .62841 Mtetra
.6146 .62841 .61947 .63346 .62916 .63067 .62432 .6256 Mtetra
.62432 .6256 .62916 .63067 .63889 .62787 .63407 .62278 Mtetra
.63407 .62278 .63889 .62787 .64866 .62506 .64386 .61995 Mtetra
.657 .753 .92 r
.64386 .61995 .64866 .62506 .65846 .62225 .65368 .61712 Mtetra
.65368 .61712 .65846 .62225 .66829 .61943 .66353 .61428 Mtetra
.66353 .61428 .66829 .61943 .67815 .61659 .67342 .61143 Mtetra
.67342 .61143 .67815 .61659 .68805 .61375 .68335 .60857 Mtetra
.657 .752 .92 r
.68335 .60857 .68805 .61375 .69799 .6109 .69331 .6057 Mtetra
.69331 .6057 .69799 .6109 .70796 .60805 .7033 .60282 Mtetra
.7033 .60282 .70796 .60805 .71796 .60518 .71333 .59994 Mtetra
.71333 .59994 .71796 .60518 .728 .6023 .72339 .59704 Mtetra
.72339 .59704 .728 .6023 .73808 .59942 .73349 .59414 Mtetra
.73349 .59414 .73808 .59942 .74819 .59652 .74363 .59122 Mtetra
.74363 .59122 .74819 .59652 .75833 .59362 .7538 .5883 Mtetra
.7538 .5883 .75833 .59362 .76852 .5907 .76401 .58536 Mtetra
.76401 .58536 .76852 .5907 .77874 .58778 .77425 .58242 Mtetra
.77425 .58242 .77874 .58778 .78899 .58484 .78453 .57947 Mtetra
.78453 .57947 .78899 .58484 .79928 .5819 .79485 .5765 Mtetra
.79485 .5765 .79928 .5819 .80961 .57895 .80521 .57353 Mtetra
.80521 .57353 .80961 .57895 .81997 .57598 .8156 .57055 Mtetra
.8156 .57055 .81997 .57598 .83038 .57301 .82603 .56755 Mtetra
.82603 .56755 .83038 .57301 .84081 .57002 .83649 .56455 Mtetra
.83649 .56455 .84081 .57002 .85129 .56703 .847 .56153 Mtetra
.847 .56153 .85129 .56703 .86181 .56402 .85754 .55851 Mtetra
.85754 .55851 .86181 .56402 .87236 .56101 .86812 .55547 Mtetra
.86812 .55547 .87236 .56101 .88295 .55798 .87874 .55243 Mtetra
.87874 .55243 .88295 .55798 .89358 .55495 .88939 .54937 Mtetra
.88939 .54937 .89358 .55495 .90424 .5519 .90009 .5463 Mtetra
.90009 .5463 .90424 .5519 .91495 .54884 .91082 .54322 Mtetra
.91082 .54322 .91495 .54884 .9257 .54577 .9216 .54013 Mtetra
.9216 .54013 .9257 .54577 .93648 .54269 .93241 .53703 Mtetra
.93241 .53703 .93648 .54269 .9473 .5396 .94326 .53392 Mtetra
.94326 .53392 .9473 .5396 .95817 .5365 .95416 .5308 Mtetra
.95416 .5308 .95817 .5365 .96907 .53339 .96509 .52766 Mtetra
.96509 .52766 .96907 .53339 .98001 .53026 .97606 .52452 Mtetra
.626 .731 .922 r
.3856 .68801 .39098 .69304 .39991 .69129 .39455 .68611 Mtetra
.596 .716 .928 r
.39455 .68611 .39991 .69129 .40879 .69232 .40352 .68481 Mtetra
.84 .707 .717 r
.40352 .68481 .40879 .69232 .41804 .6827 .41301 .66835 Mtetra
.29 .338 .739 r
.41301 .66835 .41804 .6827 .42703 .68188 .42173 .67658 Mtetra
.62 .72 .918 r
.42173 .67658 .42703 .68188 .4361 .67985 .4308 .67483 Mtetra
.638 .737 .92 r
.4308 .67483 .4361 .67985 .4452 .67763 .43992 .67265 Mtetra
.64 .74 .921 r
.43992 .67265 .4452 .67763 .45433 .67543 .44908 .6704 Mtetra
.634 .737 .922 r
.44908 .6704 .45433 .67543 .46349 .67358 .45826 .66828 Mtetra
.584 .71 .93 r
.45826 .66828 .46349 .67358 .47259 .67848 .46746 .66719 Mtetra
.759 .641 .73 r
.46746 .66719 .47259 .67848 .48198 .66499 .47683 .65675 Mtetra
.491 .572 .865 r
.47683 .65675 .48198 .66499 .49123 .66354 .48606 .65828 Mtetra
.632 .73 .918 r
.48606 .65828 .49123 .66354 .50053 .66123 .49537 .6562 Mtetra
.647 .744 .92 r
.49537 .6562 .50053 .66123 .50985 .65872 .50472 .65375 Mtetra
.652 .748 .92 r
.50472 .65375 .50985 .65872 .51922 .65611 .5141 .65116 Mtetra
.655 .751 .92 r
.5141 .65116 .51922 .65611 .52861 .65343 .52351 .64849 Mtetra
.657 .752 .92 r
.52351 .64849 .52861 .65343 .53803 .65071 .53296 .64576 Mtetra
.658 .753 .92 r
.53296 .64576 .53803 .65071 .54749 .64795 .54244 .643 Mtetra
.659 .754 .92 r
.54244 .643 .54749 .64795 .55698 .64517 .55195 .64021 Mtetra
.55195 .64021 .55698 .64517 .5665 .64239 .56149 .63741 Mtetra
.56149 .63741 .5665 .64239 .57605 .6396 .57107 .6346 Mtetra
.57107 .6346 .57605 .6396 .58564 .63681 .58067 .63178 Mtetra
.658 .753 .92 r
.58067 .63178 .58564 .63681 .59526 .63401 .59032 .62897 Mtetra
.59032 .62897 .59526 .63401 .60491 .63121 .59999 .62615 Mtetra
.59999 .62615 .60491 .63121 .6146 .62841 .6097 .62332 Mtetra
.6097 .62332 .6146 .62841 .62432 .6256 .61944 .62049 Mtetra
.61944 .62049 .62432 .6256 .63407 .62278 .62922 .61766 Mtetra
.62922 .61766 .63407 .62278 .64386 .61995 .63903 .61481 Mtetra
.657 .753 .92 r
.63903 .61481 .64386 .61995 .65368 .61712 .64887 .61196 Mtetra
.64887 .61196 .65368 .61712 .66353 .61428 .65875 .6091 Mtetra
.65875 .6091 .66353 .61428 .67342 .61143 .66866 .60623 Mtetra
.66866 .60623 .67342 .61143 .68335 .60857 .67861 .60335 Mtetra
.657 .752 .92 r
.67861 .60335 .68335 .60857 .69331 .6057 .6886 .60046 Mtetra
.6886 .60046 .69331 .6057 .7033 .60282 .69861 .59757 Mtetra
.69861 .59757 .7033 .60282 .71333 .59994 .70867 .59466 Mtetra
.70867 .59466 .71333 .59994 .72339 .59704 .71876 .59174 Mtetra
.71876 .59174 .72339 .59704 .73349 .59414 .72888 .58882 Mtetra
.72888 .58882 .73349 .59414 .74363 .59122 .73904 .58589 Mtetra
.73904 .58589 .74363 .59122 .7538 .5883 .74924 .58294 Mtetra
.74924 .58294 .7538 .5883 .76401 .58536 .75947 .57999 Mtetra
.75947 .57999 .76401 .58536 .77425 .58242 .76974 .57703 Mtetra
.76974 .57703 .77425 .58242 .78453 .57947 .78005 .57405 Mtetra
.78005 .57405 .78453 .57947 .79485 .5765 .79039 .57107 Mtetra
.79039 .57107 .79485 .5765 .80521 .57353 .80077 .56808 Mtetra
.80077 .56808 .80521 .57353 .8156 .57055 .81119 .56507 Mtetra
.81119 .56507 .8156 .57055 .82603 .56755 .82165 .56206 Mtetra
.82165 .56206 .82603 .56755 .83649 .56455 .83214 .55903 Mtetra
.83214 .55903 .83649 .56455 .847 .56153 .84267 .556 Mtetra
.84267 .556 .847 .56153 .85754 .55851 .85324 .55295 Mtetra
.85324 .55295 .85754 .55851 .86812 .55547 .86385 .5499 Mtetra
.86385 .5499 .86812 .55547 .87874 .55243 .8745 .54683 Mtetra
.8745 .54683 .87874 .55243 .88939 .54937 .88518 .54375 Mtetra
.88518 .54375 .88939 .54937 .90009 .5463 .8959 .54066 Mtetra
.8959 .54066 .90009 .5463 .91082 .54322 .90667 .53756 Mtetra
.90667 .53756 .91082 .54322 .9216 .54013 .91747 .53445 Mtetra
.91747 .53445 .9216 .54013 .93241 .53703 .92831 .53133 Mtetra
.92831 .53133 .93241 .53703 .94326 .53392 .9392 .5282 Mtetra
.9392 .5282 .94326 .53392 .95416 .5308 .95012 .52506 Mtetra
.95012 .52506 .95416 .5308 .96509 .52766 .96108 .5219 Mtetra
.96108 .5219 .96509 .52766 .97606 .52452 .97208 .51873 Mtetra
.625 .728 .921 r
.38019 .6829 .3856 .68801 .39455 .68611 .38916 .68101 Mtetra
.62 .728 .924 r
.38916 .68101 .39455 .68611 .40352 .68481 .39816 .67923 Mtetra
.451 .644 .94 r
.39816 .67923 .40352 .68481 .41301 .66835 .4071 .68024 Mtetra
.074 0 .078 r
.4071 .68024 .41301 .66835 .42173 .67658 .41642 .67055 Mtetra
.581 .681 .909 r
.41642 .67055 .42173 .67658 .4308 .67483 .42548 .66969 Mtetra
.632 .732 .92 r
.42548 .66969 .4308 .67483 .43992 .67265 .43461 .66763 Mtetra
.64 .739 .921 r
.43461 .66763 .43992 .67265 .44908 .6704 .44379 .66537 Mtetra
.639 .739 .922 r
.44379 .66537 .44908 .6704 .45826 .66828 .45299 .66313 Mtetra
.623 .73 .924 r
.45299 .66313 .45826 .66828 .46746 .66719 .46222 .66124 Mtetra
.085 .426 .87 r
.46222 .66124 .46746 .66719 .47683 .65675 .47139 .66613 Mtetra
0 0 0 r
.47139 .66613 .47683 .65675 .48606 .65828 .48086 .65255 Mtetra
.607 .705 .913 r
.48086 .65255 .48606 .65828 .49537 .6562 .49018 .65106 Mtetra
.642 .739 .919 r
.49018 .65106 .49537 .6562 .50472 .65375 .49954 .64871 Mtetra
.65 .746 .92 r
.49954 .64871 .50472 .65375 .5141 .65116 .50895 .64616 Mtetra
.654 .75 .92 r
.50895 .64616 .5141 .65116 .52351 .64849 .51838 .6435 Mtetra
.656 .751 .92 r
.51838 .6435 .52351 .64849 .53296 .64576 .52785 .64078 Mtetra
.658 .753 .92 r
.52785 .64078 .53296 .64576 .54244 .643 .53735 .63801 Mtetra
.659 .753 .92 r
.53735 .63801 .54244 .643 .55195 .64021 .54688 .63521 Mtetra
.659 .754 .92 r
.54688 .63521 .55195 .64021 .56149 .63741 .55645 .63239 Mtetra
.55645 .63239 .56149 .63741 .57107 .6346 .56604 .62956 Mtetra
.56604 .62956 .57107 .6346 .58067 .63178 .57568 .62673 Mtetra
.658 .754 .92 r
.57568 .62673 .58067 .63178 .59032 .62897 .58534 .62389 Mtetra
.658 .753 .92 r
.58534 .62389 .59032 .62897 .59999 .62615 .59504 .62105 Mtetra
.59504 .62105 .59999 .62615 .6097 .62332 .60477 .61821 Mtetra
.60477 .61821 .6097 .62332 .61944 .62049 .61453 .61536 Mtetra
.61453 .61536 .61944 .62049 .62922 .61766 .62433 .6125 Mtetra
.62433 .6125 .62922 .61766 .63903 .61481 .63417 .60963 Mtetra
.63417 .60963 .63903 .61481 .64887 .61196 .64403 .60676 Mtetra
.657 .753 .92 r
.64403 .60676 .64887 .61196 .65875 .6091 .65394 .60388 Mtetra
.65394 .60388 .65875 .6091 .66866 .60623 .66387 .60099 Mtetra
.66387 .60099 .66866 .60623 .67861 .60335 .67385 .5981 Mtetra
.67385 .5981 .67861 .60335 .6886 .60046 .68385 .59519 Mtetra
.657 .752 .92 r
.68385 .59519 .6886 .60046 .69861 .59757 .6939 .59227 Mtetra
.6939 .59227 .69861 .59757 .70867 .59466 .70397 .58935 Mtetra
.70397 .58935 .70867 .59466 .71876 .59174 .71409 .58641 Mtetra
.71409 .58641 .71876 .59174 .72888 .58882 .72424 .58347 Mtetra
.72424 .58347 .72888 .58882 .73904 .58589 .73443 .58052 Mtetra
.73443 .58052 .73904 .58589 .74924 .58294 .74465 .57755 Mtetra
.74465 .57755 .74924 .58294 .75947 .57999 .75491 .57458 Mtetra
.75491 .57458 .75947 .57999 .76974 .57703 .7652 .5716 Mtetra
.7652 .5716 .76974 .57703 .78005 .57405 .77554 .5686 Mtetra
.77554 .5686 .78005 .57405 .79039 .57107 .78591 .5656 Mtetra
.78591 .5656 .79039 .57107 .80077 .56808 .79631 .56259 Mtetra
.79631 .56259 .80077 .56808 .81119 .56507 .80676 .55956 Mtetra
.80676 .55956 .81119 .56507 .82165 .56206 .81724 .55653 Mtetra
.81724 .55653 .82165 .56206 .83214 .55903 .82776 .55348 Mtetra
.82776 .55348 .83214 .55903 .84267 .556 .83832 .55043 Mtetra
.83832 .55043 .84267 .556 .85324 .55295 .84892 .54736 Mtetra
.84892 .54736 .85324 .55295 .86385 .5499 .85955 .54429 Mtetra
.85955 .54429 .86385 .5499 .8745 .54683 .87023 .5412 Mtetra
.87023 .5412 .8745 .54683 .88518 .54375 .88094 .5381 Mtetra
.88094 .5381 .88518 .54375 .8959 .54066 .89169 .53499 Mtetra
.89169 .53499 .8959 .54066 .90667 .53756 .90248 .53187 Mtetra
.90248 .53187 .90667 .53756 .91747 .53445 .91332 .52874 Mtetra
.91332 .52874 .91747 .53445 .92831 .53133 .92419 .52559 Mtetra
.92419 .52559 .92831 .53133 .9392 .5282 .9351 .52244 Mtetra
.9351 .52244 .9392 .5282 .95012 .52506 .94605 .51927 Mtetra
.94605 .51927 .95012 .52506 .96108 .5219 .95704 .5161 Mtetra
.95704 .5161 .96108 .5219 .97208 .51873 .96808 .51291 Mtetra
.616 .719 .919 r
.37475 .67759 .38019 .6829 .38916 .68101 .38373 .67591 Mtetra
.626 .731 .922 r
.38373 .67591 .38916 .68101 .39816 .67923 .39275 .67398 Mtetra
.597 .716 .928 r
.39275 .67398 .39816 .67923 .4071 .68024 .40178 .67264 Mtetra
.841 .708 .717 r
.40178 .67264 .4071 .68024 .41642 .67055 .41135 .65608 Mtetra
.288 .336 .739 r
.41135 .65608 .41642 .67055 .42548 .66969 .42013 .66432 Mtetra
.62 .72 .918 r
.42013 .66432 .42548 .66969 .43461 .66763 .42927 .66253 Mtetra
.638 .737 .92 r
.42927 .66253 .43461 .66763 .44379 .66537 .43846 .66031 Mtetra
.64 .74 .921 r
.43846 .66031 .44379 .66537 .45299 .66313 .44769 .65802 Mtetra
.634 .737 .922 r
.44769 .65802 .45299 .66313 .46222 .66124 .45694 .65586 Mtetra
.584 .71 .93 r
.45694 .65586 .46222 .66124 .47139 .66613 .46622 .65473 Mtetra
.759 .641 .73 r
.46622 .65473 .47139 .66613 .48086 .65255 .47566 .64421 Mtetra
.49 .572 .865 r
.47566 .64421 .48086 .65255 .49018 .65106 .48496 .64572 Mtetra
.632 .73 .918 r
.48496 .64572 .49018 .65106 .49954 .64871 .49434 .6436 Mtetra
.647 .744 .92 r
.49434 .6436 .49954 .64871 .50895 .64616 .50376 .6411 Mtetra
.652 .748 .92 r
.50376 .6411 .50895 .64616 .51838 .6435 .51322 .63847 Mtetra
.655 .751 .92 r
.51322 .63847 .51838 .6435 .52785 .64078 .52271 .63576 Mtetra
.657 .752 .92 r
.52271 .63576 .52785 .64078 .53735 .63801 .53223 .63299 Mtetra
.658 .753 .92 r
.53223 .63299 .53735 .63801 .54688 .63521 .54178 .63018 Mtetra
.659 .754 .92 r
.54178 .63018 .54688 .63521 .55645 .63239 .55137 .62734 Mtetra
.55137 .62734 .55645 .63239 .56604 .62956 .56099 .6245 Mtetra
.56099 .6245 .56604 .62956 .57568 .62673 .57064 .62164 Mtetra
.57064 .62164 .57568 .62673 .58534 .62389 .58033 .61878 Mtetra
.658 .753 .92 r
.58033 .61878 .58534 .62389 .59504 .62105 .59005 .61592 Mtetra
.59005 .61592 .59504 .62105 .60477 .61821 .59981 .61306 Mtetra
.59981 .61306 .60477 .61821 .61453 .61536 .60959 .61019 Mtetra
.60959 .61019 .61453 .61536 .62433 .6125 .61942 .60731 Mtetra
.61942 .60731 .62433 .6125 .63417 .60963 .62927 .60443 Mtetra
.62927 .60443 .63417 .60963 .64403 .60676 .63916 .60153 Mtetra
.657 .753 .92 r
.63916 .60153 .64403 .60676 .65394 .60388 .64909 .59863 Mtetra
.64909 .59863 .65394 .60388 .66387 .60099 .65905 .59573 Mtetra
.65905 .59573 .66387 .60099 .67385 .5981 .66905 .59281 Mtetra
.66905 .59281 .67385 .5981 .68385 .59519 .67908 .58988 Mtetra
.657 .752 .92 r
.67908 .58988 .68385 .59519 .6939 .59227 .68915 .58695 Mtetra
.68915 .58695 .6939 .59227 .70397 .58935 .69925 .584 Mtetra
.69925 .584 .70397 .58935 .71409 .58641 .70939 .58105 Mtetra
.70939 .58105 .71409 .58641 .72424 .58347 .71957 .57809 Mtetra
.71957 .57809 .72424 .58347 .73443 .58052 .72978 .57511 Mtetra
.72978 .57511 .73443 .58052 .74465 .57755 .74003 .57213 Mtetra
.74003 .57213 .74465 .57755 .75491 .57458 .75031 .56914 Mtetra
.75031 .56914 .75491 .57458 .7652 .5716 .76063 .56613 Mtetra
.76063 .56613 .7652 .5716 .77554 .5686 .77099 .56312 Mtetra
.77099 .56312 .77554 .5686 .78591 .5656 .78139 .5601 Mtetra
.78139 .5601 .78591 .5656 .79631 .56259 .79182 .55706 Mtetra
.79182 .55706 .79631 .56259 .80676 .55956 .80229 .55402 Mtetra
.80229 .55402 .80676 .55956 .81724 .55653 .8128 .55096 Mtetra
.8128 .55096 .81724 .55653 .82776 .55348 .82335 .5479 Mtetra
.82335 .5479 .82776 .55348 .83832 .55043 .83394 .54482 Mtetra
.83394 .54482 .83832 .55043 .84892 .54736 .84456 .54173 Mtetra
.84456 .54173 .84892 .54736 .85955 .54429 .85523 .53864 Mtetra
.85523 .53864 .85955 .54429 .87023 .5412 .86593 .53553 Mtetra
.86593 .53553 .87023 .5412 .88094 .5381 .87667 .53241 Mtetra
.87667 .53241 .88094 .5381 .89169 .53499 .88745 .52928 Mtetra
.88745 .52928 .89169 .53499 .90248 .53187 .89827 .52614 Mtetra
.89827 .52614 .90248 .53187 .91332 .52874 .90913 .52298 Mtetra
.90913 .52298 .91332 .52874 .92419 .52559 .92004 .51982 Mtetra
.92004 .51982 .92419 .52559 .9351 .52244 .93098 .51664 Mtetra
.93098 .51664 .9351 .52244 .94605 .51927 .94196 .51345 Mtetra
.94196 .51345 .94605 .51927 .95704 .5161 .95298 .51025 Mtetra
.95298 .51025 .95704 .5161 .96808 .51291 .96405 .50704 Mtetra
.585 .688 .913 r
.3693 .6717 .37475 .67759 .38373 .67591 .37826 .67072 Mtetra
.625 .728 .921 r
.37826 .67072 .38373 .67591 .39275 .67398 .3873 .6688 Mtetra
.62 .728 .924 r
.3873 .6688 .39275 .67398 .40178 .67264 .39637 .66698 Mtetra
.451 .644 .94 r
.39637 .66698 .40178 .67264 .41135 .65608 .40538 .66796 Mtetra
.062 0 .067 r
.40538 .66796 .41135 .65608 .42013 .66432 .41477 .6582 Mtetra
.581 .681 .909 r
.41477 .6582 .42013 .66432 .42927 .66253 .4239 .65731 Mtetra
.632 .732 .92 r
.4239 .65731 .42927 .66253 .43846 .66031 .43311 .6552 Mtetra
.64 .739 .921 r
.43311 .6552 .43846 .66031 .44769 .65802 .44235 .6529 Mtetra
.639 .739 .922 r
.44235 .6529 .44769 .65802 .45694 .65586 .45163 .65062 Mtetra
.623 .73 .924 r
.45163 .65062 .45694 .65586 .46622 .65473 .46093 .6487 Mtetra
.089 .428 .871 r
.46093 .6487 .46622 .65473 .47566 .64421 .47016 .65358 Mtetra
0 0 0 r
.47016 .65358 .47566 .64421 .48496 .64572 .47971 .63991 Mtetra
.607 .705 .913 r
.47971 .63991 .48496 .64572 .49434 .6436 .48911 .63837 Mtetra
.642 .739 .919 r
.48911 .63837 .49434 .6436 .50376 .6411 .49855 .63599 Mtetra
.65 .746 .92 r
.49855 .63599 .50376 .6411 .51322 .63847 .50802 .63339 Mtetra
.654 .75 .92 r
.50802 .63339 .51322 .63847 .52271 .63576 .51753 .63069 Mtetra
.656 .751 .92 r
.51753 .63069 .52271 .63576 .53223 .63299 .52708 .62792 Mtetra
.658 .753 .92 r
.52708 .62792 .53223 .63299 .54178 .63018 .53665 .62511 Mtetra
.659 .753 .92 r
.53665 .62511 .54178 .63018 .55137 .62734 .54626 .62226 Mtetra
.659 .754 .92 r
.54626 .62226 .55137 .62734 .56099 .6245 .5559 .6194 Mtetra
.5559 .6194 .56099 .6245 .57064 .62164 .56558 .61653 Mtetra
.56558 .61653 .57064 .62164 .58033 .61878 .57529 .61365 Mtetra
.658 .754 .92 r
.57529 .61365 .58033 .61878 .59005 .61592 .58503 .61076 Mtetra
.658 .753 .92 r
.58503 .61076 .59005 .61592 .59981 .61306 .59481 .60788 Mtetra
.59481 .60788 .59981 .61306 .60959 .61019 .60462 .60498 Mtetra
.60462 .60498 .60959 .61019 .61942 .60731 .61447 .60209 Mtetra
.61447 .60209 .61942 .60731 .62927 .60443 .62435 .59918 Mtetra
.62435 .59918 .62927 .60443 .63916 .60153 .63426 .59627 Mtetra
.63426 .59627 .63916 .60153 .64909 .59863 .64421 .59335 Mtetra
.657 .753 .92 r
.64421 .59335 .64909 .59863 .65905 .59573 .6542 .59042 Mtetra
.6542 .59042 .65905 .59573 .66905 .59281 .66422 .58749 Mtetra
.66422 .58749 .66905 .59281 .67908 .58988 .67428 .58454 Mtetra
.67428 .58454 .67908 .58988 .68915 .58695 .68437 .58159 Mtetra
.657 .752 .92 r
.68437 .58159 .68915 .58695 .69925 .584 .6945 .57862 Mtetra
.6945 .57862 .69925 .584 .70939 .58105 .70466 .57565 Mtetra
.70466 .57565 .70939 .58105 .71957 .57809 .71486 .57266 Mtetra
.71486 .57266 .71957 .57809 .72978 .57511 .7251 .56967 Mtetra
.7251 .56967 .72978 .57511 .74003 .57213 .73537 .56667 Mtetra
.73537 .56667 .74003 .57213 .75031 .56914 .74568 .56365 Mtetra
.74568 .56365 .75031 .56914 .76063 .56613 .75603 .56063 Mtetra
.75603 .56063 .76063 .56613 .77099 .56312 .76642 .5576 Mtetra
.76642 .5576 .77099 .56312 .78139 .5601 .77684 .55455 Mtetra
.77684 .55455 .78139 .5601 .79182 .55706 .7873 .5515 Mtetra
.7873 .5515 .79182 .55706 .80229 .55402 .7978 .54843 Mtetra
.7978 .54843 .80229 .55402 .8128 .55096 .80834 .54536 Mtetra
.80834 .54536 .8128 .55096 .82335 .5479 .81891 .54227 Mtetra
.81891 .54227 .82335 .5479 .83394 .54482 .82952 .53918 Mtetra
.82952 .53918 .83394 .54482 .84456 .54173 .84018 .53607 Mtetra
.84018 .53607 .84456 .54173 .85523 .53864 .85087 .53295 Mtetra
.85087 .53295 .85523 .53864 .86593 .53553 .8616 .52982 Mtetra
.8616 .52982 .86593 .53553 .87667 .53241 .87237 .52668 Mtetra
.87237 .52668 .87667 .53241 .88745 .52928 .88318 .52353 Mtetra
.88318 .52353 .88745 .52928 .89827 .52614 .89403 .52036 Mtetra
.89403 .52036 .89827 .52614 .90913 .52298 .90492 .51719 Mtetra
.90492 .51719 .90913 .52298 .92004 .51982 .91585 .514 Mtetra
.91585 .514 .92004 .51982 .93098 .51664 .92682 .5108 Mtetra
.92682 .5108 .93098 .51664 .94196 .51345 .93784 .50759 Mtetra
.93784 .50759 .94196 .51345 .95298 .51025 .94889 .50437 Mtetra
.94889 .50437 .95298 .51025 .96405 .50704 .95999 .50114 Mtetra
.387 .466 .82 r
.36403 .66129 .3693 .6717 .37826 .67072 .37278 .66534 Mtetra
.616 .719 .919 r
.37278 .66534 .37826 .67072 .3873 .6688 .38182 .66362 Mtetra
.626 .731 .922 r
.38182 .66362 .3873 .6688 .39637 .66698 .39091 .66165 Mtetra
.597 .716 .928 r
.39091 .66165 .39637 .66698 .40538 .66796 .40001 .66028 Mtetra
.841 .709 .717 r
.40001 .66028 .40538 .66796 .41477 .6582 .40966 .64361 Mtetra
.286 .335 .738 r
.40966 .64361 .41477 .6582 .4239 .65731 .41851 .65185 Mtetra
.62 .72 .918 r
.41851 .65185 .4239 .65731 .43311 .6552 .42772 .65003 Mtetra
.638 .737 .92 r
.42772 .65003 .43311 .6552 .44235 .6529 .43698 .64777 Mtetra
.64 .74 .921 r
.43698 .64777 .44235 .6529 .45163 .65062 .44628 .64543 Mtetra
.634 .737 .922 r
.44628 .64543 .45163 .65062 .46093 .6487 .4556 .64323 Mtetra
.584 .71 .93 r
.4556 .64323 .46093 .6487 .47016 .65358 .46495 .64207 Mtetra
.759 .641 .731 r
.46495 .64207 .47016 .65358 .47971 .63991 .47447 .63147 Mtetra
.49 .572 .865 r
.47447 .63147 .47971 .63991 .48911 .63837 .48384 .63296 Mtetra
.632 .73 .918 r
.48384 .63296 .48911 .63837 .49855 .63599 .4933 .63079 Mtetra
.647 .744 .92 r
.4933 .63079 .49855 .63599 .50802 .63339 .50279 .62825 Mtetra
.652 .748 .92 r
.50279 .62825 .50802 .63339 .51753 .63069 .51233 .62557 Mtetra
.655 .751 .92 r
.51233 .62557 .51753 .63069 .52708 .62792 .52189 .62282 Mtetra
.657 .752 .92 r
.52189 .62282 .52708 .62792 .53665 .62511 .53149 .62 Mtetra
.658 .753 .92 r
.53149 .62 .53665 .62511 .54626 .62226 .54112 .61715 Mtetra
.659 .754 .92 r
.54112 .61715 .54626 .62226 .5559 .6194 .55079 .61427 Mtetra
.55079 .61427 .5559 .6194 .56558 .61653 .56048 .61138 Mtetra
.56048 .61138 .56558 .61653 .57529 .61365 .57022 .60847 Mtetra
.57022 .60847 .57529 .61365 .58503 .61076 .57998 .60557 Mtetra
.658 .753 .92 r
.57998 .60557 .58503 .61076 .59481 .60788 .58978 .60266 Mtetra
.58978 .60266 .59481 .60788 .60462 .60498 .59962 .59975 Mtetra
.59962 .59975 .60462 .60498 .61447 .60209 .60949 .59683 Mtetra
.60949 .59683 .61447 .60209 .62435 .59918 .61939 .59391 Mtetra
.61939 .59391 .62435 .59918 .63426 .59627 .62933 .59097 Mtetra
.62933 .59097 .63426 .59627 .64421 .59335 .6393 .58803 Mtetra
.657 .753 .92 r
.6393 .58803 .64421 .59335 .6542 .59042 .64931 .58509 Mtetra
.64931 .58509 .6542 .59042 .66422 .58749 .65936 .58213 Mtetra
.65936 .58213 .66422 .58749 .67428 .58454 .66944 .57916 Mtetra
.66944 .57916 .67428 .58454 .68437 .58159 .67956 .57619 Mtetra
.657 .752 .92 r
.67956 .57619 .68437 .58159 .6945 .57862 .68971 .5732 Mtetra
.68971 .5732 .6945 .57862 .70466 .57565 .6999 .57021 Mtetra
.6999 .57021 .70466 .57565 .71486 .57266 .71012 .56721 Mtetra
.71012 .56721 .71486 .57266 .7251 .56967 .72039 .56419 Mtetra
.72039 .56419 .7251 .56967 .73537 .56667 .73069 .56117 Mtetra
.73069 .56117 .73537 .56667 .74568 .56365 .74102 .55814 Mtetra
.74102 .55814 .74568 .56365 .75603 .56063 .7514 .55509 Mtetra
.7514 .55509 .75603 .56063 .76642 .5576 .76181 .55204 Mtetra
.76181 .55204 .76642 .5576 .77684 .55455 .77226 .54897 Mtetra
.77226 .54897 .77684 .55455 .7873 .5515 .78275 .5459 Mtetra
.78275 .5459 .7873 .5515 .7978 .54843 .79327 .54281 Mtetra
.79327 .54281 .7978 .54843 .80834 .54536 .80384 .53972 Mtetra
.80384 .53972 .80834 .54536 .81891 .54227 .81444 .53661 Mtetra
.81444 .53661 .81891 .54227 .82952 .53918 .82508 .53349 Mtetra
.82508 .53349 .82952 .53918 .84018 .53607 .83576 .53036 Mtetra
.83576 .53036 .84018 .53607 .85087 .53295 .84648 .52722 Mtetra
.84648 .52722 .85087 .53295 .8616 .52982 .85724 .52407 Mtetra
.85724 .52407 .8616 .52982 .87237 .52668 .86804 .52091 Mtetra
.86804 .52091 .87237 .52668 .88318 .52353 .87888 .51773 Mtetra
.87888 .51773 .88318 .52353 .89403 .52036 .88976 .51455 Mtetra
.88976 .51455 .89403 .52036 .90492 .51719 .90068 .51135 Mtetra
.90068 .51135 .90492 .51719 .91585 .514 .91164 .50814 Mtetra
.91164 .50814 .91585 .514 .92682 .5108 .92264 .50492 Mtetra
.92264 .50492 .92682 .5108 .93784 .50759 .93369 .50169 Mtetra
.93369 .50169 .93784 .50759 .94889 .50437 .94477 .49845 Mtetra
.94477 .49845 .94889 .50437 .95999 .50114 .9559 .49519 Mtetra
0 0 0 r
.35783 .67002 .36403 .66129 .37278 .66534 .36728 .65937 Mtetra
.585 .688 .913 r
.36728 .65937 .37278 .66534 .38182 .66362 .37631 .65835 Mtetra
.625 .728 .921 r
.37631 .65835 .38182 .66362 .39091 .66165 .38542 .65639 Mtetra
.62 .728 .924 r
.38542 .65639 .39091 .66165 .40001 .66028 .39455 .65453 Mtetra
.452 .644 .94 r
.39455 .65453 .40001 .66028 .40966 .64361 .40363 .65549 Mtetra
.051 0 .056 r
.40363 .65549 .40966 .64361 .41851 .65185 .4131 .64565 Mtetra
.581 .681 .909 r
.4131 .64565 .41851 .65185 .42772 .65003 .4223 .64473 Mtetra
.632 .732 .92 r
.4223 .64473 .42772 .65003 .43698 .64777 .43158 .64258 Mtetra
.64 .739 .921 r
.43158 .64258 .43698 .64777 .44628 .64543 .44089 .64024 Mtetra
.639 .739 .921 r
.44089 .64024 .44628 .64543 .4556 .64323 .45024 .63792 Mtetra
.623 .73 .924 r
.45024 .63792 .4556 .64323 .46495 .64207 .45962 .63595 Mtetra
.093 .43 .872 r
.45962 .63595 .46495 .64207 .47447 .63147 .46892 .64082 Mtetra
0 0 0 r
.46892 .64082 .47447 .63147 .48384 .63296 .47855 .62705 Mtetra
.607 .705 .913 r
.47855 .62705 .48384 .63296 .4933 .63079 .48802 .62548 Mtetra
.642 .739 .919 r
.48802 .62548 .4933 .63079 .50279 .62825 .49753 .62305 Mtetra
.65 .746 .92 r
.49753 .62305 .50279 .62825 .51233 .62557 .50709 .62041 Mtetra
.654 .75 .92 r
.50709 .62041 .51233 .62557 .52189 .62282 .51667 .61767 Mtetra
.656 .751 .92 r
.51667 .61767 .52189 .62282 .53149 .62 .52629 .61485 Mtetra
.658 .753 .92 r
.52629 .61485 .53149 .62 .54112 .61715 .53595 .612 Mtetra
.659 .753 .92 r
.53595 .612 .54112 .61715 .55079 .61427 .54563 .6091 Mtetra
.659 .754 .92 r
.54563 .6091 .55079 .61427 .56048 .61138 .55535 .60619 Mtetra
.55535 .60619 .56048 .61138 .57022 .60847 .56511 .60327 Mtetra
.56511 .60327 .57022 .60847 .57998 .60557 .5749 .60034 Mtetra
.658 .754 .92 r
.5749 .60034 .57998 .60557 .58978 .60266 .58472 .59741 Mtetra
.658 .753 .92 r
.58472 .59741 .58978 .60266 .59962 .59975 .59458 .59448 Mtetra
.59458 .59448 .59962 .59975 .60949 .59683 .60447 .59154 Mtetra
.60447 .59154 .60949 .59683 .61939 .59391 .6144 .5886 Mtetra
.6144 .5886 .61939 .59391 .62933 .59097 .62436 .58564 Mtetra
.62436 .58564 .62933 .59097 .6393 .58803 .63436 .58268 Mtetra
.63436 .58268 .6393 .58803 .64931 .58509 .64439 .57972 Mtetra
.657 .753 .92 r
.64439 .57972 .64931 .58509 .65936 .58213 .65446 .57674 Mtetra
.65446 .57674 .65936 .58213 .66944 .57916 .66457 .57375 Mtetra
.66457 .57375 .66944 .57916 .67956 .57619 .67471 .57076 Mtetra
.67471 .57076 .67956 .57619 .68971 .5732 .68489 .56775 Mtetra
.657 .752 .92 r
.68489 .56775 .68971 .5732 .6999 .57021 .69511 .56474 Mtetra
.69511 .56474 .6999 .57021 .71012 .56721 .70536 .56171 Mtetra
.70536 .56171 .71012 .56721 .72039 .56419 .71565 .55868 Mtetra
.71565 .55868 .72039 .56419 .73069 .56117 .72597 .55564 Mtetra
.72597 .55564 .73069 .56117 .74102 .55814 .73633 .55258 Mtetra
.73633 .55258 .74102 .55814 .7514 .55509 .74673 .54952 Mtetra
.74673 .54952 .7514 .55509 .76181 .55204 .75717 .54644 Mtetra
.75717 .54644 .76181 .55204 .77226 .54897 .76765 .54336 Mtetra
.76765 .54336 .77226 .54897 .78275 .5459 .77816 .54026 Mtetra
.77816 .54026 .78275 .5459 .79327 .54281 .78872 .53715 Mtetra
.78872 .53715 .79327 .54281 .80384 .53972 .79931 .53404 Mtetra
.79931 .53404 .80384 .53972 .81444 .53661 .80994 .53091 Mtetra
.80994 .53091 .81444 .53661 .82508 .53349 .82061 .52777 Mtetra
.82061 .52777 .82508 .53349 .83576 .53036 .83132 .52462 Mtetra
.83132 .52462 .83576 .53036 .84648 .52722 .84207 .52146 Mtetra
.84207 .52146 .84648 .52722 .85724 .52407 .85286 .51828 Mtetra
.85286 .51828 .85724 .52407 .86804 .52091 .86369 .5151 Mtetra
.86369 .5151 .86804 .52091 .87888 .51773 .87455 .5119 Mtetra
.87455 .5119 .87888 .51773 .88976 .51455 .88546 .5087 Mtetra
.88546 .5087 .88976 .51455 .90068 .51135 .89641 .50548 Mtetra
.89641 .50548 .90068 .51135 .91164 .50814 .9074 .50225 Mtetra
.9074 .50225 .91164 .50814 .92264 .50492 .91844 .499 Mtetra
.91844 .499 .92264 .50492 .93369 .50169 .92951 .49575 Mtetra
.92951 .49575 .93369 .50169 .94477 .49845 .94062 .49248 Mtetra
.94062 .49248 .94477 .49845 .9559 .49519 .95178 .48921 Mtetra
.8 .685 .738 r
.35241 .66124 .35783 .67002 .36728 .65937 .36197 .64886 Mtetra
.386 .465 .82 r
.36197 .64886 .36728 .65937 .37631 .65835 .37077 .65289 Mtetra
.616 .719 .919 r
.37077 .65289 .37631 .65835 .38542 .65639 .37989 .65113 Mtetra
.626 .731 .922 r
.37989 .65113 .38542 .65639 .39455 .65453 .38905 .64912 Mtetra
.597 .716 .928 r
.38905 .64912 .39455 .65453 .40363 .65549 .39822 .64772 Mtetra
.842 .71 .717 r
.39822 .64772 .40363 .65549 .4131 .64565 .40795 .63094 Mtetra
.284 .334 .738 r
.40795 .63094 .4131 .64565 .4223 .64473 .41686 .63919 Mtetra
.62 .72 .918 r
.41686 .63919 .4223 .64473 .43158 .64258 .42614 .63732 Mtetra
.638 .737 .92 r
.42614 .63732 .43158 .64258 .44089 .64024 .43547 .63502 Mtetra
.64 .74 .921 r
.43547 .63502 .44089 .64024 .45024 .63792 .44484 .63264 Mtetra
.634 .737 .922 r
.44484 .63264 .45024 .63792 .45962 .63595 .45424 .6304 Mtetra
.585 .71 .93 r
.45424 .6304 .45962 .63595 .46892 .64082 .46366 .6292 Mtetra
.76 .642 .731 r
.46366 .6292 .46892 .64082 .47855 .62705 .47326 .61852 Mtetra
.489 .572 .866 r
.47326 .61852 .47855 .62705 .48802 .62548 .4827 .61998 Mtetra
.632 .73 .918 r
.4827 .61998 .48802 .62548 .49753 .62305 .49224 .61777 Mtetra
.647 .744 .92 r
.49224 .61777 .49753 .62305 .50709 .62041 .50181 .61519 Mtetra
.652 .748 .92 r
.50181 .61519 .50709 .62041 .51667 .61767 .51142 .61247 Mtetra
.655 .751 .92 r
.51142 .61247 .51667 .61767 .52629 .61485 .52106 .60966 Mtetra
.657 .752 .92 r
.52106 .60966 .52629 .61485 .53595 .612 .53074 .6068 Mtetra
.658 .753 .92 r
.53074 .6068 .53595 .612 .54563 .6091 .54045 .6039 Mtetra
.659 .754 .92 r
.54045 .6039 .54563 .6091 .55535 .60619 .55019 .60098 Mtetra
.55019 .60098 .55535 .60619 .56511 .60327 .55997 .59804 Mtetra
.55997 .59804 .56511 .60327 .5749 .60034 .56978 .59509 Mtetra
.56978 .59509 .5749 .60034 .58472 .59741 .57963 .59213 Mtetra
.658 .753 .92 r
.57963 .59213 .58472 .59741 .59458 .59448 .58951 .58918 Mtetra
.58951 .58918 .59458 .59448 .60447 .59154 .59942 .58622 Mtetra
.59942 .58622 .60447 .59154 .6144 .5886 .60938 .58325 Mtetra
.60938 .58325 .6144 .5886 .62436 .58564 .61936 .58028 Mtetra
.61936 .58028 .62436 .58564 .63436 .58268 .62939 .5773 Mtetra
.62939 .5773 .63436 .58268 .64439 .57972 .63944 .57431 Mtetra
.657 .753 .92 r
.63944 .57431 .64439 .57972 .65446 .57674 .64954 .57131 Mtetra
.64954 .57131 .65446 .57674 .66457 .57375 .65967 .5683 Mtetra
.65967 .5683 .66457 .57375 .67471 .57076 .66984 .56529 Mtetra
.66984 .56529 .67471 .57076 .68489 .56775 .68004 .56226 Mtetra
.657 .752 .92 r
.68004 .56226 .68489 .56775 .69511 .56474 .69028 .55923 Mtetra
.69028 .55923 .69511 .56474 .70536 .56171 .70056 .55618 Mtetra
.70056 .55618 .70536 .56171 .71565 .55868 .71087 .55313 Mtetra
.71087 .55313 .71565 .55868 .72597 .55564 .72122 .55007 Mtetra
.72122 .55007 .72597 .55564 .73633 .55258 .73161 .54699 Mtetra
.73161 .54699 .73633 .55258 .74673 .54952 .74204 .5439 Mtetra
.74204 .5439 .74673 .54952 .75717 .54644 .75251 .54081 Mtetra
.75251 .54081 .75717 .54644 .76765 .54336 .76301 .5377 Mtetra
.76301 .5377 .76765 .54336 .77816 .54026 .77355 .53459 Mtetra
.77355 .53459 .77816 .54026 .78872 .53715 .78413 .53146 Mtetra
.78413 .53146 .78872 .53715 .79931 .53404 .79475 .52832 Mtetra
.79475 .52832 .79931 .53404 .80994 .53091 .80541 .52517 Mtetra
.80541 .52517 .80994 .53091 .82061 .52777 .81611 .52201 Mtetra
.81611 .52201 .82061 .52777 .83132 .52462 .82685 .51883 Mtetra
.82685 .51883 .83132 .52462 .84207 .52146 .83762 .51565 Mtetra
.83762 .51565 .84207 .52146 .85286 .51828 .84844 .51246 Mtetra
.84844 .51246 .85286 .51828 .86369 .5151 .8593 .50925 Mtetra
.8593 .50925 .86369 .5151 .87455 .5119 .8702 .50603 Mtetra
.8702 .50603 .87455 .5119 .88546 .5087 .88113 .5028 Mtetra
.88113 .5028 .88546 .5087 .89641 .50548 .89211 .49956 Mtetra
.89211 .49956 .89641 .50548 .9074 .50225 .90313 .49631 Mtetra
.90313 .49631 .9074 .50225 .91844 .499 .9142 .49304 Mtetra
.9142 .49304 .91844 .499 .92951 .49575 .9253 .48977 Mtetra
.9253 .48977 .92951 .49575 .94062 .49248 .93645 .48648 Mtetra
.93645 .48648 .94062 .49248 .95178 .48921 .94763 .48318 Mtetra
.338 .584 .934 r
.34683 .65533 .35241 .66124 .36197 .64886 .3557 .65757 Mtetra
0 0 0 r
.3557 .65757 .36197 .64886 .37077 .65289 .36523 .64684 Mtetra
.585 .688 .913 r
.36523 .64684 .37077 .65289 .37989 .65113 .37433 .64578 Mtetra
.625 .728 .921 r
.37433 .64578 .37989 .65113 .38905 .64912 .3835 .64379 Mtetra
.62 .728 .924 r
.3835 .64379 .38905 .64912 .39822 .64772 .39271 .64188 Mtetra
.453 .644 .94 r
.39271 .64188 .39822 .64772 .40795 .63094 .40185 .64281 Mtetra
.039 0 .044 r
.40185 .64281 .40795 .63094 .41686 .63919 .4114 .6329 Mtetra
.58 .681 .909 r
.4114 .6329 .41686 .63919 .42614 .63732 .42067 .63194 Mtetra
.632 .732 .92 r
.42067 .63194 .42614 .63732 .43547 .63502 .43002 .62975 Mtetra
.64 .739 .921 r
.43002 .62975 .43547 .63502 .44484 .63264 .43941 .62737 Mtetra
.639 .739 .921 r
.43941 .62737 .44484 .63264 .45424 .6304 .44883 .625 Mtetra
.623 .73 .924 r
.44883 .625 .45424 .6304 .46366 .6292 .45828 .62299 Mtetra
.098 .432 .873 r
.45828 .62299 .46366 .6292 .47326 .61852 .46766 .62785 Mtetra
0 0 0 r
.46766 .62785 .47326 .61852 .4827 .61998 .47737 .61399 Mtetra
.607 .705 .913 r
.47737 .61399 .4827 .61998 .49224 .61777 .48691 .61238 Mtetra
.642 .739 .919 r
.48691 .61238 .49224 .61777 .50181 .61519 .4965 .60991 Mtetra
.65 .746 .92 r
.4965 .60991 .50181 .61519 .51142 .61247 .50613 .60722 Mtetra
.654 .75 .92 r
.50613 .60722 .51142 .61247 .52106 .60966 .5158 .60443 Mtetra
.656 .751 .92 r
.5158 .60443 .52106 .60966 .53074 .6068 .52549 .60157 Mtetra
.658 .753 .92 r
.52549 .60157 .53074 .6068 .54045 .6039 .53523 .59866 Mtetra
.659 .753 .92 r
.53523 .59866 .54045 .6039 .55019 .60098 .54499 .59572 Mtetra
.659 .754 .92 r
.54499 .59572 .55019 .60098 .55997 .59804 .55479 .59277 Mtetra
.55479 .59277 .55997 .59804 .56978 .59509 .56463 .5898 Mtetra
.56463 .5898 .56978 .59509 .57963 .59213 .5745 .58682 Mtetra
.658 .754 .92 r
.5745 .58682 .57963 .59213 .58951 .58918 .5844 .58384 Mtetra
.658 .753 .92 r
.5844 .58384 .58951 .58918 .59942 .58622 .59434 .58086 Mtetra
.59434 .58086 .59942 .58622 .60938 .58325 .60432 .57787 Mtetra
.60432 .57787 .60938 .58325 .61936 .58028 .61433 .57488 Mtetra
.61433 .57488 .61936 .58028 .62939 .5773 .62438 .57188 Mtetra
.62438 .57188 .62939 .5773 .63944 .57431 .63446 .56887 Mtetra
.63446 .56887 .63944 .57431 .64954 .57131 .64458 .56585 Mtetra
.657 .753 .92 r
.64458 .56585 .64954 .57131 .65967 .5683 .65474 .56282 Mtetra
.65474 .56282 .65967 .5683 .66984 .56529 .66493 .55978 Mtetra
.66493 .55978 .66984 .56529 .68004 .56226 .67516 .55674 Mtetra
.67516 .55674 .68004 .56226 .69028 .55923 .68542 .55368 Mtetra
.657 .752 .92 r
.68542 .55368 .69028 .55923 .70056 .55618 .69572 .55062 Mtetra
.69572 .55062 .70056 .55618 .71087 .55313 .70607 .54754 Mtetra
.70607 .54754 .71087 .55313 .72122 .55007 .71644 .54446 Mtetra
.71644 .54446 .72122 .55007 .73161 .54699 .72686 .54136 Mtetra
.72686 .54136 .73161 .54699 .74204 .5439 .73731 .53825 Mtetra
.73731 .53825 .74204 .5439 .75251 .54081 .74781 .53514 Mtetra
.74781 .53514 .75251 .54081 .76301 .5377 .75834 .53201 Mtetra
.75834 .53201 .76301 .5377 .77355 .53459 .76891 .52887 Mtetra
.76891 .52887 .77355 .53459 .78413 .53146 .77951 .52572 Mtetra
.77951 .52572 .78413 .53146 .79475 .52832 .79016 .52256 Mtetra
.79016 .52256 .79475 .52832 .80541 .52517 .80085 .51939 Mtetra
.80085 .51939 .80541 .52517 .81611 .52201 .81157 .51621 Mtetra
.81157 .51621 .81611 .52201 .82685 .51883 .82234 .51301 Mtetra
.82234 .51301 .82685 .51883 .83762 .51565 .83315 .50981 Mtetra
.83315 .50981 .83762 .51565 .84844 .51246 .84399 .50659 Mtetra
.84399 .50659 .84844 .51246 .8593 .50925 .85488 .50336 Mtetra
.85488 .50336 .8593 .50925 .8702 .50603 .86581 .50012 Mtetra
.86581 .50012 .8702 .50603 .88113 .5028 .87678 .49687 Mtetra
.87678 .49687 .88113 .5028 .89211 .49956 .88778 .4936 Mtetra
.88778 .4936 .89211 .49956 .90313 .49631 .89884 .49033 Mtetra
.89884 .49033 .90313 .49631 .9142 .49304 .90993 .48704 Mtetra
.90993 .48704 .9142 .49304 .9253 .48977 .92106 .48374 Mtetra
.92106 .48374 .9253 .48977 .93645 .48648 .93224 .48043 Mtetra
.93224 .48043 .93645 .48648 .94763 .48318 .94346 .47711 Mtetra
.583 .708 .929 r
.34118 .64983 .34683 .65533 .3557 .65757 .35024 .64869 Mtetra
.8 .685 .738 r
.35024 .64869 .3557 .65757 .36523 .64684 .35987 .63622 Mtetra
.385 .465 .82 r
.35987 .63622 .36523 .64684 .37433 .64578 .36874 .64024 Mtetra
.616 .719 .919 r
.36874 .64024 .37433 .64578 .3835 .64379 .37792 .63844 Mtetra
.626 .731 .922 r
.37792 .63844 .3835 .64379 .39271 .64188 .38715 .63639 Mtetra
.597 .716 .928 r
.38715 .63639 .39271 .64188 .40185 .64281 .39639 .63495 Mtetra
.843 .71 .717 r
.39639 .63495 .40185 .64281 .4114 .6329 .40621 .61807 Mtetra
.282 .332 .738 r
.40621 .61807 .4114 .6329 .42067 .63194 .41518 .62632 Mtetra
.62 .72 .918 r
.41518 .62632 .42067 .63194 .43002 .62975 .42454 .62441 Mtetra
.638 .737 .92 r
.42454 .62441 .43002 .62975 .43941 .62737 .43394 .62206 Mtetra
.64 .74 .921 r
.43394 .62206 .43941 .62737 .44883 .625 .44339 .61965 Mtetra
.634 .737 .922 r
.44339 .61965 .44883 .625 .45828 .62299 .45286 .61736 Mtetra
.585 .71 .93 r
.45286 .61736 .45828 .62299 .46766 .62785 .46235 .61612 Mtetra
.76 .642 .731 r
.46235 .61612 .46766 .62785 .47737 .61399 .47203 .60536 Mtetra
.489 .572 .866 r
.47203 .60536 .47737 .61399 .48691 .61238 .48155 .60679 Mtetra
.632 .73 .918 r
.48155 .60679 .48691 .61238 .4965 .60991 .49116 .60454 Mtetra
.647 .744 .92 r
.49116 .60454 .4965 .60991 .50613 .60722 .50081 .60191 Mtetra
.652 .748 .92 r
.50081 .60191 .50613 .60722 .5158 .60443 .5105 .59914 Mtetra
.655 .751 .92 r
.5105 .59914 .5158 .60443 .52549 .60157 .52022 .59629 Mtetra
.657 .752 .92 r
.52022 .59629 .52549 .60157 .53523 .59866 .52997 .59338 Mtetra
.658 .753 .92 r
.52997 .59338 .53523 .59866 .54499 .59572 .53976 .59044 Mtetra
.659 .754 .92 r
.53976 .59044 .54499 .59572 .55479 .59277 .54959 .58746 Mtetra
.54959 .58746 .55479 .59277 .56463 .5898 .55944 .58447 Mtetra
.55944 .58447 .56463 .5898 .5745 .58682 .56934 .58148 Mtetra
.56934 .58148 .5745 .58682 .5844 .58384 .57927 .57847 Mtetra
.658 .753 .92 r
.57927 .57847 .5844 .58384 .59434 .58086 .58923 .57547 Mtetra
.58923 .57547 .59434 .58086 .60432 .57787 .59923 .57246 Mtetra
.59923 .57246 .60432 .57787 .61433 .57488 .60927 .56944 Mtetra
.60927 .56944 .61433 .57488 .62438 .57188 .61934 .56642 Mtetra
.61934 .56642 .62438 .57188 .63446 .56887 .62944 .56339 Mtetra
.62944 .56339 .63446 .56887 .64458 .56585 .63959 .56035 Mtetra
.657 .753 .92 r
.63959 .56035 .64458 .56585 .65474 .56282 .64977 .5573 Mtetra
.64977 .5573 .65474 .56282 .66493 .55978 .65999 .55424 Mtetra
.65999 .55424 .66493 .55978 .67516 .55674 .67024 .55118 Mtetra
.67024 .55118 .67516 .55674 .68542 .55368 .68053 .5481 Mtetra
.657 .752 .92 r
.68053 .5481 .68542 .55368 .69572 .55062 .69086 .54501 Mtetra
.69086 .54501 .69572 .55062 .70607 .54754 .70123 .54192 Mtetra
.70123 .54192 .70607 .54754 .71644 .54446 .71163 .53881 Mtetra
.71163 .53881 .71644 .54446 .72686 .54136 .72207 .53569 Mtetra
.72207 .53569 .72686 .54136 .73731 .53825 .73255 .53257 Mtetra
.73255 .53257 .73731 .53825 .74781 .53514 .74307 .52943 Mtetra
.74307 .52943 .74781 .53514 .75834 .53201 .75363 .52628 Mtetra
.75363 .52628 .75834 .53201 .76891 .52887 .76423 .52312 Mtetra
.76423 .52312 .76891 .52887 .77951 .52572 .77486 .51995 Mtetra
.77486 .51995 .77951 .52572 .79016 .52256 .78554 .51676 Mtetra
.78554 .51676 .79016 .52256 .80085 .51939 .79625 .51357 Mtetra
.79625 .51357 .80085 .51939 .81157 .51621 .80701 .51036 Mtetra
.80701 .51036 .81157 .51621 .82234 .51301 .8178 .50715 Mtetra
.8178 .50715 .82234 .51301 .83315 .50981 .82864 .50392 Mtetra
.82864 .50392 .83315 .50981 .84399 .50659 .83951 .50068 Mtetra
.83951 .50068 .84399 .50659 .85488 .50336 .85043 .49743 Mtetra
.85043 .49743 .85488 .50336 .86581 .50012 .86139 .49417 Mtetra
.86139 .49417 .86581 .50012 .87678 .49687 .87239 .49089 Mtetra
.87239 .49089 .87678 .49687 .88778 .4936 .88343 .48761 Mtetra
.88343 .48761 .88778 .4936 .89884 .49033 .89451 .48431 Mtetra
.89451 .48431 .89884 .49033 .90993 .48704 .90563 .481 Mtetra
.90563 .481 .90993 .48704 .92106 .48374 .9168 .47767 Mtetra
.9168 .47767 .92106 .48374 .93224 .48043 .928 .47434 Mtetra
.928 .47434 .93224 .48043 .94346 .47711 .93925 .47099 Mtetra
.611 .722 .924 r
.3355 .6444 .34118 .64983 .35024 .64869 .3446 .64269 Mtetra
.339 .584 .934 r
.3446 .64269 .35024 .64869 .35987 .63622 .35354 .64491 Mtetra
0 0 0 r
.35354 .64491 .35987 .63622 .36874 .64024 .36314 .6341 Mtetra
.585 .688 .913 r
.36314 .6341 .36874 .64024 .37792 .63844 .37231 .63301 Mtetra
.625 .728 .921 r
.37231 .63301 .37792 .63844 .38715 .63639 .38156 .63097 Mtetra
.62 .728 .924 r
.38156 .63097 .38715 .63639 .39639 .63495 .39083 .62903 Mtetra
.453 .644 .939 r
.39083 .62903 .39639 .63495 .40621 .61807 .40005 .62993 Mtetra
.027 0 .031 r
.40005 .62993 .40621 .61807 .41518 .62632 .40967 .61994 Mtetra
.58 .681 .909 r
.40967 .61994 .41518 .62632 .42454 .62441 .41902 .61895 Mtetra
.632 .732 .92 r
.41902 .61895 .42454 .62441 .43394 .62206 .42844 .61671 Mtetra
.64 .739 .921 r
.42844 .61671 .43394 .62206 .44339 .61965 .4379 .61428 Mtetra
.639 .739 .921 r
.4379 .61428 .44339 .61965 .45286 .61736 .4474 .61188 Mtetra
.623 .73 .924 r
.4474 .61188 .45286 .61736 .46235 .61612 .45693 .60982 Mtetra
.102 .434 .874 r
.45693 .60982 .46235 .61612 .47203 .60536 .46637 .61467 Mtetra
0 0 0 r
.46637 .61467 .47203 .60536 .48155 .60679 .47616 .60071 Mtetra
.607 .705 .913 r
.47616 .60071 .48155 .60679 .49116 .60454 .48578 .59906 Mtetra
.642 .739 .919 r
.48578 .59906 .49116 .60454 .50081 .60191 .49545 .59654 Mtetra
.65 .746 .92 r
.49545 .59654 .50081 .60191 .5105 .59914 .50516 .59381 Mtetra
.654 .75 .92 r
.50516 .59381 .5105 .59914 .52022 .59629 .5149 .59097 Mtetra
.656 .751 .92 r
.5149 .59097 .52022 .59629 .52997 .59338 .52468 .58806 Mtetra
.658 .753 .92 r
.52468 .58806 .52997 .59338 .53976 .59044 .5345 .58511 Mtetra
.659 .753 .92 r
.5345 .58511 .53976 .59044 .54959 .58746 .54434 .58212 Mtetra
.659 .754 .92 r
.54434 .58212 .54959 .58746 .55944 .58447 .55422 .57911 Mtetra
.55422 .57911 .55944 .58447 .56934 .58148 .56414 .57609 Mtetra
.56414 .57609 .56934 .58148 .57927 .57847 .57409 .57307 Mtetra
.658 .754 .92 r
.57409 .57307 .57927 .57847 .58923 .57547 .58408 .57004 Mtetra
.658 .753 .92 r
.58408 .57004 .58923 .57547 .59923 .57246 .59411 .56701 Mtetra
.59411 .56701 .59923 .57246 .60927 .56944 .60417 .56397 Mtetra
.60417 .56397 .60927 .56944 .61934 .56642 .61426 .56093 Mtetra
.61426 .56093 .61934 .56642 .62944 .56339 .62439 .55787 Mtetra
.62439 .55787 .62944 .56339 .63959 .56035 .63456 .55481 Mtetra
.63456 .55481 .63959 .56035 .64977 .5573 .64477 .55174 Mtetra
.657 .753 .92 r
.64477 .55174 .64977 .5573 .65999 .55424 .65501 .54867 Mtetra
.65501 .54867 .65999 .55424 .67024 .55118 .66529 .54558 Mtetra
.66529 .54558 .67024 .55118 .68053 .5481 .67561 .54248 Mtetra
.67561 .54248 .68053 .5481 .69086 .54501 .68596 .53937 Mtetra
.657 .752 .92 r
.68596 .53937 .69086 .54501 .70123 .54192 .69636 .53625 Mtetra
.69636 .53625 .70123 .54192 .71163 .53881 .70679 .53313 Mtetra
.70679 .53313 .71163 .53881 .72207 .53569 .71726 .52999 Mtetra
.71726 .52999 .72207 .53569 .73255 .53257 .72776 .52684 Mtetra
.72776 .52684 .73255 .53257 .74307 .52943 .73831 .52368 Mtetra
.73831 .52368 .74307 .52943 .75363 .52628 .74889 .52051 Mtetra
.74889 .52051 .75363 .52628 .76423 .52312 .75952 .51732 Mtetra
.75952 .51732 .76423 .52312 .77486 .51995 .77018 .51413 Mtetra
.77018 .51413 .77486 .51995 .78554 .51676 .78089 .51093 Mtetra
.78089 .51093 .78554 .51676 .79625 .51357 .79163 .50771 Mtetra
.79163 .50771 .79625 .51357 .80701 .51036 .80241 .50448 Mtetra
.80241 .50448 .80701 .51036 .8178 .50715 .81324 .50125 Mtetra
.81324 .50125 .8178 .50715 .82864 .50392 .8241 .49799 Mtetra
.8241 .49799 .82864 .50392 .83951 .50068 .835 .49473 Mtetra
.835 .49473 .83951 .50068 .85043 .49743 .84595 .49146 Mtetra
.84595 .49146 .85043 .49743 .86139 .49417 .85694 .48817 Mtetra
.85694 .48817 .86139 .49417 .87239 .49089 .86797 .48488 Mtetra
.86797 .48488 .87239 .49089 .88343 .48761 .87904 .48157 Mtetra
.87904 .48157 .88343 .48761 .89451 .48431 .89015 .47824 Mtetra
.89015 .47824 .89451 .48431 .90563 .481 .9013 .47491 Mtetra
.9013 .47491 .90563 .481 .9168 .47767 .9125 .47156 Mtetra
.9125 .47156 .9168 .47767 .928 .47434 .92374 .46821 Mtetra
.92374 .46821 .928 .47434 .93925 .47099 .93502 .46483 Mtetra
.615 .722 .922 r
.32978 .63891 .3355 .6444 .3446 .64269 .3389 .63711 Mtetra
.583 .708 .929 r
.3389 .63711 .3446 .64269 .35354 .64491 .34802 .63593 Mtetra
.801 .686 .738 r
.34802 .63593 .35354 .64491 .36314 .6341 .35774 .62338 Mtetra
.383 .464 .82 r
.35774 .62338 .36314 .6341 .37231 .63301 .36667 .62738 Mtetra
.616 .719 .919 r
.36667 .62738 .37231 .63301 .38156 .63097 .37592 .62554 Mtetra
.626 .731 .922 r
.37592 .62554 .38156 .63097 .39083 .62903 .38523 .62345 Mtetra
.597 .716 .927 r
.38523 .62345 .39083 .62903 .40005 .62993 .39454 .62197 Mtetra
.844 .711 .717 r
.39454 .62197 .40005 .62993 .40967 .61994 .40444 .60498 Mtetra
.28 .331 .737 r
.40444 .60498 .40967 .61994 .41902 .61895 .41347 .61323 Mtetra
.62 .72 .918 r
.41347 .61323 .41902 .61895 .42844 .61671 .4229 .61128 Mtetra
.638 .737 .92 r
.4229 .61128 .42844 .61671 .4379 .61428 .43239 .60889 Mtetra
.64 .74 .921 r
.43239 .60889 .4379 .61428 .4474 .61188 .4419 .60643 Mtetra
.634 .737 .922 r
.4419 .60643 .4474 .61188 .45693 .60982 .45145 .6041 Mtetra
.585 .71 .929 r
.45145 .6041 .45693 .60982 .46637 .61467 .46102 .60282 Mtetra
.76 .643 .731 r
.46102 .60282 .46637 .61467 .47616 .60071 .47079 .59198 Mtetra
.488 .572 .866 r
.47079 .59198 .47616 .60071 .48578 .59906 .48038 .59338 Mtetra
.632 .73 .918 r
.48038 .59338 .48578 .59906 .49545 .59654 .49006 .59109 Mtetra
.647 .744 .92 r
.49006 .59109 .49545 .59654 .50516 .59381 .49979 .58841 Mtetra
.652 .748 .92 r
.49979 .58841 .50516 .59381 .5149 .59097 .50956 .5856 Mtetra
.655 .751 .92 r
.50956 .5856 .5149 .59097 .52468 .58806 .51936 .5827 Mtetra
.657 .752 .92 r
.51936 .5827 .52468 .58806 .5345 .58511 .52919 .57974 Mtetra
.658 .753 .92 r
.52919 .57974 .5345 .58511 .54434 .58212 .53906 .57674 Mtetra
.659 .754 .92 r
.53906 .57674 .54434 .58212 .55422 .57911 .54897 .57372 Mtetra
.54897 .57372 .55422 .57911 .56414 .57609 .55891 .57068 Mtetra
.55891 .57068 .56414 .57609 .57409 .57307 .56889 .56763 Mtetra
.56889 .56763 .57409 .57307 .58408 .57004 .5789 .56458 Mtetra
.658 .753 .92 r
.5789 .56458 .58408 .57004 .59411 .56701 .58895 .56153 Mtetra
.58895 .56153 .59411 .56701 .60417 .56397 .59903 .55846 Mtetra
.59903 .55846 .60417 .56397 .61426 .56093 .60915 .5554 Mtetra
.60915 .5554 .61426 .56093 .62439 .55787 .61931 .55232 Mtetra
.61931 .55232 .62439 .55787 .63456 .55481 .6295 .54924 Mtetra
.6295 .54924 .63456 .55481 .64477 .55174 .63973 .54615 Mtetra
.657 .753 .92 r
.63973 .54615 .64477 .55174 .65501 .54867 .65 .54305 Mtetra
.65 .54305 .65501 .54867 .66529 .54558 .66031 .53994 Mtetra
.66031 .53994 .66529 .54558 .67561 .54248 .67065 .53682 Mtetra
.67065 .53682 .67561 .54248 .68596 .53937 .68103 .53369 Mtetra
.657 .752 .92 r
.68103 .53369 .68596 .53937 .69636 .53625 .69145 .53055 Mtetra
.69145 .53055 .69636 .53625 .70679 .53313 .70191 .5274 Mtetra
.70191 .5274 .70679 .53313 .71726 .52999 .7124 .52424 Mtetra
.7124 .52424 .71726 .52999 .72776 .52684 .72294 .52107 Mtetra
.72294 .52107 .72776 .52684 .73831 .52368 .73351 .51789 Mtetra
.73351 .51789 .73831 .52368 .74889 .52051 .74412 .5147 Mtetra
.74412 .5147 .74889 .52051 .75952 .51732 .75478 .51149 Mtetra
.75478 .51149 .75952 .51732 .77018 .51413 .76547 .50828 Mtetra
.76547 .50828 .77018 .51413 .78089 .51093 .7762 .50505 Mtetra
.7762 .50505 .78089 .51093 .79163 .50771 .78697 .50181 Mtetra
.78697 .50181 .79163 .50771 .80241 .50448 .79778 .49856 Mtetra
.79778 .49856 .80241 .50448 .81324 .50125 .80864 .4953 Mtetra
.80864 .4953 .81324 .50125 .8241 .49799 .81953 .49203 Mtetra
.81953 .49203 .8241 .49799 .835 .49473 .83046 .48874 Mtetra
.83046 .48874 .835 .49473 .84595 .49146 .84144 .48545 Mtetra
.84144 .48545 .84595 .49146 .85694 .48817 .85246 .48214 Mtetra
.85246 .48214 .85694 .48817 .86797 .48488 .86351 .47882 Mtetra
.86351 .47882 .86797 .48488 .87904 .48157 .87461 .47548 Mtetra
.87461 .47548 .87904 .48157 .89015 .47824 .88576 .47214 Mtetra
.88576 .47214 .89015 .47824 .9013 .47491 .89694 .46878 Mtetra
.89694 .46878 .9013 .47491 .9125 .47156 .90817 .46541 Mtetra
.90817 .46541 .9125 .47156 .92374 .46821 .91944 .46203 Mtetra
.91944 .46203 .92374 .46821 .93502 .46483 .93075 .45863 Mtetra
.605 .711 .919 r
.32404 .63318 .32978 .63891 .3389 .63711 .33316 .6316 Mtetra
.611 .722 .924 r
.33316 .6316 .3389 .63711 .34802 .63593 .34233 .62985 Mtetra
.34 .584 .934 r
.34233 .62985 .34802 .63593 .35774 .62338 .35134 .63205 Mtetra
0 0 0 r
.35134 .63205 .35774 .62338 .36667 .62738 .36102 .62116 Mtetra
.585 .688 .913 r
.36102 .62116 .36667 .62738 .37592 .62554 .37026 .62003 Mtetra
.625 .728 .921 r
.37026 .62003 .37592 .62554 .38523 .62345 .37958 .61795 Mtetra
.62 .728 .924 r
.37958 .61795 .38523 .62345 .39454 .62197 .38893 .61596 Mtetra
.454 .644 .939 r
.38893 .61596 .39454 .62197 .40444 .60498 .39821 .61683 Mtetra
.014 0 .019 r
.39821 .61683 .40444 .60498 .41347 .61323 .40792 .60677 Mtetra
.58 .681 .909 r
.40792 .60677 .41347 .61323 .4229 .61128 .41734 .60573 Mtetra
.632 .732 .92 r
.41734 .60573 .4229 .61128 .43239 .60889 .42683 .60346 Mtetra
.64 .739 .921 r
.42683 .60346 .43239 .60889 .4419 .60643 .43637 .60098 Mtetra
.639 .739 .921 r
.43637 .60098 .4419 .60643 .45145 .6041 .44594 .59853 Mtetra
.623 .73 .924 r
.44594 .59853 .45145 .6041 .46102 .60282 .45555 .59643 Mtetra
.105 .436 .875 r
.45555 .59643 .46102 .60282 .47079 .59198 .46507 .60127 Mtetra
0 0 0 r
.46507 .60127 .47079 .59198 .48038 .59338 .47494 .58722 Mtetra
.607 .705 .913 r
.47494 .58722 .48038 .59338 .49006 .59109 .48464 .58552 Mtetra
.642 .739 .919 r
.48464 .58552 .49006 .59109 .49979 .58841 .49439 .58295 Mtetra
.65 .746 .92 r
.49439 .58295 .49979 .58841 .50956 .5856 .50418 .58017 Mtetra
.654 .75 .92 r
.50418 .58017 .50956 .5856 .51936 .5827 .514 .57728 Mtetra
.656 .751 .92 r
.514 .57728 .51936 .5827 .52919 .57974 .52386 .57433 Mtetra
.658 .753 .92 r
.52386 .57433 .52919 .57974 .53906 .57674 .53375 .57132 Mtetra
.659 .753 .92 r
.53375 .57132 .53906 .57674 .54897 .57372 .54368 .56829 Mtetra
.659 .754 .92 r
.54368 .56829 .54897 .57372 .55891 .57068 .55365 .56523 Mtetra
.55365 .56523 .55891 .57068 .56889 .56763 .56365 .56216 Mtetra
.56365 .56216 .56889 .56763 .5789 .56458 .57368 .55909 Mtetra
.658 .754 .92 r
.57368 .55909 .5789 .56458 .58895 .56153 .58375 .55601 Mtetra
.658 .753 .92 r
.58375 .55601 .58895 .56153 .59903 .55846 .59386 .55292 Mtetra
.59386 .55292 .59903 .55846 .60915 .5554 .60401 .54983 Mtetra
.60401 .54983 .60915 .5554 .61931 .55232 .61419 .54674 Mtetra
.61419 .54674 .61931 .55232 .6295 .54924 .62441 .54363 Mtetra
.62441 .54363 .6295 .54924 .63973 .54615 .63467 .54052 Mtetra
.63467 .54052 .63973 .54615 .65 .54305 .64496 .5374 Mtetra
.657 .753 .92 r
.64496 .5374 .65 .54305 .66031 .53994 .65529 .53427 Mtetra
.65529 .53427 .66031 .53994 .67065 .53682 .66566 .53113 Mtetra
.66566 .53113 .67065 .53682 .68103 .53369 .67607 .52797 Mtetra
.67607 .52797 .68103 .53369 .69145 .53055 .68651 .52481 Mtetra
.657 .752 .92 r
.68651 .52481 .69145 .53055 .70191 .5274 .697 .52164 Mtetra
.697 .52164 .70191 .5274 .7124 .52424 .70752 .51846 Mtetra
.70752 .51846 .7124 .52424 .72294 .52107 .71808 .51526 Mtetra
.71808 .51526 .72294 .52107 .73351 .51789 .72868 .51206 Mtetra
.72868 .51206 .73351 .51789 .74412 .5147 .73932 .50885 Mtetra
.73932 .50885 .74412 .5147 .75478 .51149 .75 .50562 Mtetra
.75 .50562 .75478 .51149 .76547 .50828 .76072 .50238 Mtetra
.76072 .50238 .76547 .50828 .7762 .50505 .77148 .49913 Mtetra
.77148 .49913 .7762 .50505 .78697 .50181 .78228 .49587 Mtetra
.78228 .49587 .78697 .50181 .79778 .49856 .79312 .4926 Mtetra
.79312 .4926 .79778 .49856 .80864 .4953 .804 .48931 Mtetra
.804 .48931 .80864 .4953 .81953 .49203 .81493 .48602 Mtetra
.81493 .48602 .81953 .49203 .83046 .48874 .82589 .48271 Mtetra
.82589 .48271 .83046 .48874 .84144 .48545 .8369 .47939 Mtetra
.8369 .47939 .84144 .48545 .85246 .48214 .84794 .47606 Mtetra
.84794 .47606 .85246 .48214 .86351 .47882 .85903 .47271 Mtetra
.85903 .47271 .86351 .47882 .87461 .47548 .87016 .46936 Mtetra
.87016 .46936 .87461 .47548 .88576 .47214 .88134 .46599 Mtetra
.88134 .46599 .88576 .47214 .89694 .46878 .89255 .46261 Mtetra
.89255 .46261 .89694 .46878 .90817 .46541 .90381 .45921 Mtetra
.90381 .45921 .90817 .46541 .91944 .46203 .91511 .45581 Mtetra
.91511 .45581 .91944 .46203 .93075 .45863 .92646 .45239 Mtetra
.557 .664 .908 r
.31832 .62655 .32404 .63318 .33316 .6316 .32739 .62602 Mtetra
.615 .722 .922 r
.32739 .62602 .33316 .6316 .34233 .62985 .33658 .62418 Mtetra
.583 .708 .929 r
.33658 .62418 .34233 .62985 .35134 .63205 .34577 .62297 Mtetra
.801 .687 .738 r
.34577 .62297 .35134 .63205 .36102 .62116 .35557 .61033 Mtetra
.382 .464 .82 r
.35557 .61033 .36102 .62116 .37026 .62003 .36457 .61432 Mtetra
.616 .719 .919 r
.36457 .61432 .37026 .62003 .37958 .61795 .37389 .61243 Mtetra
.626 .731 .922 r
.37389 .61243 .37958 .61795 .38893 .61596 .38327 .6103 Mtetra
.597 .716 .927 r
.38327 .6103 .38893 .61596 .39821 .61683 .39265 .60877 Mtetra
.844 .712 .717 r
.39265 .60877 .39821 .61683 .40792 .60677 .40264 .59168 Mtetra
.277 .33 .737 r
.40264 .59168 .40792 .60677 .41734 .60573 .41174 .59993 Mtetra
.62 .72 .918 r
.41174 .59993 .41734 .60573 .42683 .60346 .42125 .59794 Mtetra
.638 .737 .92 r
.42125 .59794 .42683 .60346 .43637 .60098 .4308 .59551 Mtetra
.64 .74 .921 r
.4308 .59551 .43637 .60098 .44594 .59853 .4404 .593 Mtetra
.634 .737 .922 r
.4404 .593 .44594 .59853 .45555 .59643 .45003 .59062 Mtetra
.585 .71 .929 r
.45003 .59062 .45555 .59643 .46507 .60127 .45967 .5893 Mtetra
.761 .643 .731 r
.45967 .5893 .46507 .60127 .47494 .58722 .46952 .57838 Mtetra
.488 .572 .866 r
.46952 .57838 .47494 .58722 .48464 .58552 .47918 .57975 Mtetra
.632 .73 .918 r
.47918 .57975 .48464 .58552 .49439 .58295 .48895 .57741 Mtetra
.647 .744 .92 r
.48895 .57741 .49439 .58295 .50418 .58017 .49876 .57468 Mtetra
.652 .748 .92 r
.49876 .57468 .50418 .58017 .514 .57728 .5086 .57182 Mtetra
.655 .751 .92 r
.5086 .57182 .514 .57728 .52386 .57433 .51849 .56887 Mtetra
.657 .752 .92 r
.51849 .56887 .52386 .57433 .53375 .57132 .5284 .56586 Mtetra
.658 .753 .92 r
.5284 .56586 .53375 .57132 .54368 .56829 .53836 .56282 Mtetra
.659 .754 .92 r
.53836 .56282 .54368 .56829 .55365 .56523 .54834 .55974 Mtetra
.54834 .55974 .55365 .56523 .56365 .56216 .55837 .55665 Mtetra
.55837 .55665 .56365 .56216 .57368 .55909 .56843 .55355 Mtetra
.56843 .55355 .57368 .55909 .58375 .55601 .57853 .55045 Mtetra
.658 .753 .92 r
.57853 .55045 .58375 .55601 .59386 .55292 .58866 .54734 Mtetra
.58866 .54734 .59386 .55292 .60401 .54983 .59883 .54423 Mtetra
.59883 .54423 .60401 .54983 .61419 .54674 .60904 .54111 Mtetra
.60904 .54111 .61419 .54674 .62441 .54363 .61928 .53799 Mtetra
.61928 .53799 .62441 .54363 .63467 .54052 .62956 .53485 Mtetra
.62956 .53485 .63467 .54052 .64496 .5374 .63988 .53171 Mtetra
.657 .753 .92 r
.63988 .53171 .64496 .5374 .65529 .53427 .65024 .52855 Mtetra
.65024 .52855 .65529 .53427 .66566 .53113 .66063 .52539 Mtetra
.66063 .52539 .66566 .53113 .67607 .52797 .67107 .52222 Mtetra
.67107 .52222 .67607 .52797 .68651 .52481 .68154 .51903 Mtetra
.657 .752 .92 r
.68154 .51903 .68651 .52481 .697 .52164 .69205 .51584 Mtetra
.69205 .51584 .697 .52164 .70752 .51846 .7026 .51263 Mtetra
.7026 .51263 .70752 .51846 .71808 .51526 .71319 .50942 Mtetra
.71319 .50942 .71808 .51526 .72868 .51206 .72382 .50619 Mtetra
.72382 .50619 .72868 .51206 .73932 .50885 .73449 .50295 Mtetra
.73449 .50295 .73932 .50885 .75 .50562 .74519 .49971 Mtetra
.74519 .49971 .75 .50562 .76072 .50238 .75594 .49645 Mtetra
.75594 .49645 .76072 .50238 .77148 .49913 .76673 .49317 Mtetra
.76673 .49317 .77148 .49913 .78228 .49587 .77756 .48989 Mtetra
.77756 .48989 .78228 .49587 .79312 .4926 .78843 .48659 Mtetra
.78843 .48659 .79312 .4926 .804 .48931 .79934 .48329 Mtetra
.79934 .48329 .804 .48931 .81493 .48602 .81029 .47997 Mtetra
.81029 .47997 .81493 .48602 .82589 .48271 .82129 .47664 Mtetra
.82129 .47664 .82589 .48271 .8369 .47939 .83232 .47329 Mtetra
.83232 .47329 .8369 .47939 .84794 .47606 .8434 .46994 Mtetra
.8434 .46994 .84794 .47606 .85903 .47271 .85452 .46657 Mtetra
.85452 .46657 .85903 .47271 .87016 .46936 .86568 .46319 Mtetra
.86568 .46319 .87016 .46936 .88134 .46599 .87688 .4598 Mtetra
.87688 .4598 .88134 .46599 .89255 .46261 .88813 .45639 Mtetra
.88813 .45639 .89255 .46261 .90381 .45921 .89942 .45297 Mtetra
.89942 .45297 .90381 .45921 .91511 .45581 .91076 .44954 Mtetra
.91076 .44954 .91511 .45581 .92646 .45239 .92213 .4461 Mtetra
.065 .094 .58 r
.31371 .60134 .31832 .62655 .32739 .62602 .3216 .6202 Mtetra
.605 .711 .919 r
.3216 .6202 .32739 .62602 .33658 .62418 .33079 .61859 Mtetra
.611 .722 .924 r
.33079 .61859 .33658 .62418 .34577 .62297 .34003 .6168 Mtetra
.342 .585 .934 r
.34003 .6168 .34577 .62297 .35557 .61033 .3491 .61897 Mtetra
0 0 0 r
.3491 .61897 .35557 .61033 .36457 .61432 .35887 .608 Mtetra
.584 .688 .913 r
.35887 .608 .36457 .61432 .37389 .61243 .36818 .60683 Mtetra
.625 .728 .921 r
.36818 .60683 .37389 .61243 .38327 .6103 .37757 .60471 Mtetra
.62 .728 .924 r
.37757 .60471 .38327 .6103 .39265 .60877 .38699 .60268 Mtetra
.454 .644 .939 r
.38699 .60268 .39265 .60877 .40264 .59168 .39634 .60352 Mtetra
.001 0 .006 r
.39634 .60352 .40264 .59168 .41174 .59993 .40613 .59337 Mtetra
.58 .681 .909 r
.40613 .59337 .41174 .59993 .42125 .59794 .41563 .5923 Mtetra
.632 .732 .92 r
.41563 .5923 .42125 .59794 .4308 .59551 .4252 .58998 Mtetra
.64 .739 .921 r
.4252 .58998 .4308 .59551 .4404 .593 .43481 .58746 Mtetra
.639 .739 .921 r
.43481 .58746 .4404 .593 .45003 .59062 .44446 .58496 Mtetra
.623 .73 .924 r
.44446 .58496 .45003 .59062 .45967 .5893 .45414 .58282 Mtetra
.109 .438 .876 r
.45414 .58282 .45967 .5893 .46952 .57838 .46374 .58764 Mtetra
0 0 0 r
.46374 .58764 .46952 .57838 .47918 .57975 .4737 .57349 Mtetra
.607 .705 .913 r
.4737 .57349 .47918 .57975 .48895 .57741 .48348 .57175 Mtetra
.642 .739 .919 r
.48348 .57175 .48895 .57741 .49876 .57468 .49331 .56913 Mtetra
.65 .746 .92 r
.49331 .56913 .49876 .57468 .5086 .57182 .50317 .5663 Mtetra
.654 .75 .92 r
.50317 .5663 .5086 .57182 .51849 .56887 .51308 .56337 Mtetra
.656 .751 .92 r
.51308 .56337 .51849 .56887 .5284 .56586 .52302 .56036 Mtetra
.658 .753 .92 r
.52302 .56036 .5284 .56586 .53836 .56282 .533 .55731 Mtetra
.659 .753 .92 r
.533 .55731 .53836 .56282 .54834 .55974 .54301 .55422 Mtetra
.659 .754 .92 r
.54301 .55422 .54834 .55974 .55837 .55665 .55306 .55111 Mtetra
.55306 .55111 .55837 .55665 .56843 .55355 .56314 .54799 Mtetra
.56314 .54799 .56843 .55355 .57853 .55045 .57326 .54486 Mtetra
.658 .754 .92 r
.57326 .54486 .57853 .55045 .58866 .54734 .58342 .54173 Mtetra
.658 .753 .92 r
.58342 .54173 .58866 .54734 .59883 .54423 .59362 .53859 Mtetra
.59362 .53859 .59883 .54423 .60904 .54111 .60385 .53545 Mtetra
.60385 .53545 .60904 .54111 .61928 .53799 .61412 .5323 Mtetra
.61412 .5323 .61928 .53799 .62956 .53485 .62443 .52914 Mtetra
.62443 .52914 .62956 .53485 .63988 .53171 .63477 .52598 Mtetra
.63477 .52598 .63988 .53171 .65024 .52855 .64515 .5228 Mtetra
.657 .753 .92 r
.64515 .5228 .65024 .52855 .66063 .52539 .65558 .51962 Mtetra
.65558 .51962 .66063 .52539 .67107 .52222 .66604 .51642 Mtetra
.66604 .51642 .67107 .52222 .68154 .51903 .67653 .51321 Mtetra
.67653 .51321 .68154 .51903 .69205 .51584 .68707 .51 Mtetra
.657 .752 .92 r
.68707 .51 .69205 .51584 .7026 .51263 .69765 .50677 Mtetra
.69765 .50677 .7026 .51263 .71319 .50942 .70827 .50353 Mtetra
.70827 .50353 .71319 .50942 .72382 .50619 .71892 .50028 Mtetra
.71892 .50028 .72382 .50619 .73449 .50295 .72962 .49702 Mtetra
.72962 .49702 .73449 .50295 .74519 .49971 .74035 .49375 Mtetra
.74035 .49375 .74519 .49971 .75594 .49645 .75113 .49047 Mtetra
.75113 .49047 .75594 .49645 .76673 .49317 .76195 .48717 Mtetra
.76195 .48717 .76673 .49317 .77756 .48989 .77281 .48387 Mtetra
.77281 .48387 .77756 .48989 .78843 .48659 .7837 .48055 Mtetra
.7837 .48055 .78843 .48659 .79934 .48329 .79464 .47722 Mtetra
.79464 .47722 .79934 .48329 .81029 .47997 .80563 .47387 Mtetra
.80563 .47387 .81029 .47997 .82129 .47664 .81665 .47052 Mtetra
.81665 .47052 .82129 .47664 .83232 .47329 .82771 .46715 Mtetra
.82771 .46715 .83232 .47329 .8434 .46994 .83882 .46377 Mtetra
.83882 .46377 .8434 .46994 .85452 .46657 .84997 .46038 Mtetra
.84997 .46038 .85452 .46657 .86568 .46319 .86116 .45698 Mtetra
.86116 .45698 .86568 .46319 .87688 .4598 .8724 .45356 Mtetra
.8724 .45356 .87688 .4598 .88813 .45639 .88368 .45013 Mtetra
.88368 .45013 .88813 .45639 .89942 .45297 .895 .44669 Mtetra
.895 .44669 .89942 .45297 .91076 .44954 .90637 .44323 Mtetra
.90637 .44323 .91076 .44954 .92213 .4461 .91778 .43976 Mtetra
.312 .02 .298 r
.30616 .62295 .31371 .60134 .3216 .6202 .31582 .61349 Mtetra
.557 .664 .908 r
.31582 .61349 .3216 .6202 .33079 .61859 .32497 .61293 Mtetra
.615 .722 .922 r
.32497 .61293 .33079 .61859 .34003 .6168 .33422 .61104 Mtetra
.583 .708 .929 r
.33422 .61104 .34003 .6168 .3491 .61897 .34349 .60979 Mtetra
.802 .687 .738 r
.34349 .60979 .3491 .61897 .35887 .608 .35336 .59706 Mtetra
.381 .463 .82 r
.35336 .59706 .35887 .608 .36818 .60683 .36243 .60103 Mtetra
.616 .719 .919 r
.36243 .60103 .36818 .60683 .37757 .60471 .37183 .59911 Mtetra
.626 .731 .922 r
.37183 .59911 .37757 .60471 .38699 .60268 .38128 .59693 Mtetra
.597 .716 .927 r
.38128 .59693 .38699 .60268 .39634 .60352 .39074 .59536 Mtetra
.845 .713 .717 r
.39074 .59536 .39634 .60352 .40613 .59337 .40081 .57816 Mtetra
.275 .328 .737 r
.40081 .57816 .40613 .59337 .41563 .5923 .40998 .58641 Mtetra
.62 .72 .918 r
.40998 .58641 .41563 .5923 .4252 .58998 .41956 .58437 Mtetra
.638 .737 .92 r
.41956 .58437 .4252 .58998 .43481 .58746 .42919 .58189 Mtetra
.64 .74 .921 r
.42919 .58189 .43481 .58746 .44446 .58496 .43887 .57934 Mtetra
.634 .737 .922 r
.43887 .57934 .44446 .58496 .45414 .58282 .44857 .57691 Mtetra
.585 .71 .929 r
.44857 .57691 .45414 .58282 .46374 .58764 .4583 .57555 Mtetra
.761 .644 .731 r
.4583 .57555 .46374 .58764 .4737 .57349 .46822 .56454 Mtetra
.487 .571 .866 r
.46822 .56454 .4737 .57349 .48348 .57175 .47797 .56589 Mtetra
.632 .73 .918 r
.47797 .56589 .48348 .57175 .49331 .56913 .48782 .5635 Mtetra
.647 .744 .92 r
.48782 .5635 .49331 .56913 .50317 .5663 .49771 .56072 Mtetra
.652 .748 .92 r
.49771 .56072 .50317 .5663 .51308 .56337 .50763 .55781 Mtetra
.655 .751 .92 r
.50763 .55781 .51308 .56337 .52302 .56036 .5176 .55481 Mtetra
.657 .752 .92 r
.5176 .55481 .52302 .56036 .533 .55731 .5276 .55175 Mtetra
.658 .753 .92 r
.5276 .55175 .533 .55731 .54301 .55422 .53764 .54865 Mtetra
.659 .754 .92 r
.53764 .54865 .54301 .55422 .55306 .55111 .54771 .54553 Mtetra
.54771 .54553 .55306 .55111 .56314 .54799 .55782 .54238 Mtetra
.55782 .54238 .56314 .54799 .57326 .54486 .56796 .53923 Mtetra
.56796 .53923 .57326 .54486 .58342 .54173 .57815 .53608 Mtetra
.658 .753 .92 r
.57815 .53608 .58342 .54173 .59362 .53859 .58837 .53292 Mtetra
.58837 .53292 .59362 .53859 .60385 .53545 .59862 .52975 Mtetra
.59862 .52975 .60385 .53545 .61412 .5323 .60892 .52658 Mtetra
.60892 .52658 .61412 .5323 .62443 .52914 .61925 .5234 Mtetra
.61925 .5234 .62443 .52914 .63477 .52598 .62962 .52021 Mtetra
.62962 .52021 .63477 .52598 .64515 .5228 .64003 .51701 Mtetra
.657 .753 .92 r
.64003 .51701 .64515 .5228 .65558 .51962 .65048 .5138 Mtetra
.65048 .5138 .65558 .51962 .66604 .51642 .66097 .51058 Mtetra
.66097 .51058 .66604 .51642 .67653 .51321 .67149 .50736 Mtetra
.67149 .50736 .67653 .51321 .68707 .51 .68206 .50412 Mtetra
.657 .752 .92 r
.68206 .50412 .68707 .51 .69765 .50677 .69266 .50087 Mtetra
.69266 .50087 .69765 .50677 .70827 .50353 .70331 .49761 Mtetra
.70331 .49761 .70827 .50353 .71892 .50028 .71399 .49433 Mtetra
.71399 .49433 .71892 .50028 .72962 .49702 .72471 .49105 Mtetra
.72471 .49105 .72962 .49702 .74035 .49375 .73548 .48776 Mtetra
.73548 .48776 .74035 .49375 .75113 .49047 .74628 .48445 Mtetra
.74628 .48445 .75113 .49047 .76195 .48717 .75713 .48113 Mtetra
.75713 .48113 .76195 .48717 .77281 .48387 .76802 .4778 Mtetra
.76802 .4778 .77281 .48387 .7837 .48055 .77894 .47446 Mtetra
.77894 .47446 .7837 .48055 .79464 .47722 .78991 .4711 Mtetra
.78991 .4711 .79464 .47722 .80563 .47387 .80093 .46774 Mtetra
.80093 .46774 .80563 .47387 .81665 .47052 .81198 .46436 Mtetra
.81198 .46436 .81665 .47052 .82771 .46715 .82307 .46097 Mtetra
.82307 .46097 .82771 .46715 .83882 .46377 .83421 .45757 Mtetra
.83421 .45757 .83882 .46377 .84997 .46038 .84539 .45415 Mtetra
.84539 .45415 .84997 .46038 .86116 .45698 .85662 .45072 Mtetra
.85662 .45072 .86116 .45698 .8724 .45356 .86788 .44728 Mtetra
.86788 .44728 .8724 .45356 .88368 .45013 .8792 .44382 Mtetra
.8792 .44382 .88368 .45013 .895 .44669 .89055 .44036 Mtetra
.89055 .44036 .895 .44669 .90637 .44323 .90195 .43688 Mtetra
.90195 .43688 .90637 .44323 .91778 .43976 .91339 .43338 Mtetra
.879 .713 .671 r
.30038 .61542 .30616 .62295 .31582 .61349 .31118 .58811 Mtetra
.06 .09 .578 r
.31118 .58811 .31582 .61349 .32497 .61293 .31912 .60702 Mtetra
.604 .711 .92 r
.31912 .60702 .32497 .61293 .33422 .61104 .32838 .60536 Mtetra
.611 .722 .924 r
.32838 .60536 .33422 .61104 .34349 .60979 .33769 .60353 Mtetra
.343 .585 .933 r
.33769 .60353 .34349 .60979 .35336 .59706 .34683 .60568 Mtetra
0 0 0 r
.34683 .60568 .35336 .59706 .36243 .60103 .35668 .59462 Mtetra
.584 .688 .913 r
.35668 .59462 .36243 .60103 .37183 .59911 .36606 .59342 Mtetra
.625 .729 .921 r
.36606 .59342 .37183 .59911 .38128 .59693 .37552 .59125 Mtetra
.62 .728 .924 r
.37552 .59125 .38128 .59693 .39074 .59536 .38502 .58918 Mtetra
.455 .644 .939 r
.38502 .58918 .39074 .59536 .40081 .57816 .39445 .58998 Mtetra
0 0 0 r
.39445 .58998 .40081 .57816 .40998 .58641 .40432 .57976 Mtetra
.58 .681 .909 r
.40432 .57976 .40998 .58641 .41956 .58437 .41389 .57865 Mtetra
.632 .732 .92 r
.41389 .57865 .41956 .58437 .42919 .58189 .42354 .57627 Mtetra
.64 .739 .921 r
.42354 .57627 .42919 .58189 .43887 .57934 .43323 .57371 Mtetra
.639 .739 .921 r
.43323 .57371 .43887 .57934 .44857 .57691 .44296 .57116 Mtetra
.623 .73 .924 r
.44296 .57116 .44857 .57691 .4583 .57555 .45272 .56897 Mtetra
.113 .439 .877 r
.45272 .56897 .4583 .57555 .46822 .56454 .46239 .57378 Mtetra
0 0 0 r
.46239 .57378 .46822 .56454 .47797 .56589 .47243 .55953 Mtetra
.607 .705 .914 r
.47243 .55953 .47797 .56589 .48782 .5635 .48229 .55774 Mtetra
.642 .739 .919 r
.48229 .55774 .48782 .5635 .49771 .56072 .4922 .55508 Mtetra
.65 .746 .92 r
.4922 .55508 .49771 .56072 .50763 .55781 .50215 .5522 Mtetra
.654 .75 .92 r
.50215 .5522 .50763 .55781 .5176 .55481 .51214 .54921 Mtetra
.656 .751 .92 r
.51214 .54921 .5176 .55481 .5276 .55175 .52217 .54615 Mtetra
.658 .753 .92 r
.52217 .54615 .5276 .55175 .53764 .54865 .53223 .54305 Mtetra
.659 .753 .92 r
.53223 .54305 .53764 .54865 .54771 .54553 .54232 .53991 Mtetra
.659 .754 .92 r
.54232 .53991 .54771 .54553 .55782 .54238 .55246 .53674 Mtetra
.55246 .53674 .55782 .54238 .56796 .53923 .56263 .53357 Mtetra
.56263 .53357 .56796 .53923 .57815 .53608 .57284 .53039 Mtetra
.658 .754 .92 r
.57284 .53039 .57815 .53608 .58837 .53292 .58308 .5272 Mtetra
.658 .753 .92 r
.58308 .5272 .58837 .53292 .59862 .52975 .59336 .52401 Mtetra
.59336 .52401 .59862 .52975 .60892 .52658 .60369 .52082 Mtetra
.60369 .52082 .60892 .52658 .61925 .5234 .61404 .51761 Mtetra
.61404 .51761 .61925 .5234 .62962 .52021 .62444 .5144 Mtetra
.62444 .5144 .62962 .52021 .64003 .51701 .63488 .51118 Mtetra
.63488 .51118 .64003 .51701 .65048 .5138 .64535 .50795 Mtetra
.657 .753 .92 r
.64535 .50795 .65048 .5138 .66097 .51058 .65586 .50471 Mtetra
.65586 .50471 .66097 .51058 .67149 .50736 .66642 .50146 Mtetra
.66642 .50146 .67149 .50736 .68206 .50412 .67701 .4982 Mtetra
.67701 .4982 .68206 .50412 .69266 .50087 .68764 .49492 Mtetra
.657 .752 .92 r
.68764 .49492 .69266 .50087 .70331 .49761 .69831 .49164 Mtetra
.69831 .49164 .70331 .49761 .71399 .49433 .70902 .48834 Mtetra
.70902 .48834 .71399 .49433 .72471 .49105 .71978 .48504 Mtetra
.71978 .48504 .72471 .49105 .73548 .48776 .73057 .48172 Mtetra
.73057 .48172 .73548 .48776 .74628 .48445 .7414 .47839 Mtetra
.7414 .47839 .74628 .48445 .75713 .48113 .75228 .47505 Mtetra
.75228 .47505 .75713 .48113 .76802 .4778 .76319 .47169 Mtetra
.76319 .47169 .76802 .4778 .77894 .47446 .77415 .46833 Mtetra
.77415 .46833 .77894 .47446 .78991 .4711 .78515 .46495 Mtetra
.78515 .46495 .78991 .4711 .80093 .46774 .79619 .46156 Mtetra
.79619 .46156 .80093 .46774 .81198 .46436 .80728 .45816 Mtetra
.80728 .45816 .81198 .46436 .82307 .46097 .8184 .45474 Mtetra
.8184 .45474 .82307 .46097 .83421 .45757 .82957 .45131 Mtetra
.82957 .45131 .83421 .45757 .84539 .45415 .84078 .44787 Mtetra
.84078 .44787 .84539 .45415 .85662 .45072 .85204 .44442 Mtetra
.85204 .44442 .85662 .45072 .86788 .44728 .86334 .44095 Mtetra
.86334 .44095 .86788 .44728 .8792 .44382 .87468 .43747 Mtetra
.87468 .43747 .8792 .44382 .89055 .44036 .88606 .43398 Mtetra
.88606 .43398 .89055 .44036 .90195 .43688 .8975 .43048 Mtetra
.8975 .43048 .90195 .43688 .91339 .43338 .90897 .42696 Mtetra
.481 .658 .939 r
.29446 .60935 .30038 .61542 .31118 .58811 .30354 .60975 Mtetra
.304 .01 .29 r
.30354 .60975 .31118 .58811 .31912 .60702 .31329 .60021 Mtetra
.557 .664 .908 r
.31329 .60021 .31912 .60702 .32838 .60536 .3225 .59961 Mtetra
.615 .722 .922 r
.3225 .59961 .32838 .60536 .33769 .60353 .33183 .59769 Mtetra
.583 .708 .929 r
.33183 .59769 .33769 .60353 .34683 .60568 .34116 .59639 Mtetra
.802 .688 .739 r
.34116 .59639 .34683 .60568 .35668 .59462 .35112 .58357 Mtetra
.38 .463 .82 r
.35112 .58357 .35668 .59462 .36606 .59342 .36026 .58753 Mtetra
.616 .719 .919 r
.36026 .58753 .36606 .59342 .37552 .59125 .36973 .58556 Mtetra
.626 .731 .922 r
.36973 .58556 .37552 .59125 .38502 .58918 .37925 .58333 Mtetra
.597 .716 .927 r
.37925 .58333 .38502 .58918 .39445 .58998 .38879 .58172 Mtetra
.846 .714 .717 r
.38879 .58172 .39445 .58998 .40432 .57976 .39895 .56441 Mtetra
.273 .327 .736 r
.39895 .56441 .40432 .57976 .41389 .57865 .40819 .57266 Mtetra
.62 .72 .918 r
.40819 .57266 .41389 .57865 .42354 .57627 .41785 .57058 Mtetra
.638 .737 .92 r
.41785 .57058 .42354 .57627 .43323 .57371 .42756 .56805 Mtetra
.64 .74 .921 r
.42756 .56805 .43323 .57371 .44296 .57116 .43731 .56545 Mtetra
.634 .737 .922 r
.43731 .56545 .44296 .57116 .45272 .56897 .44709 .56298 Mtetra
.585 .71 .929 r
.44709 .56298 .45272 .56897 .46239 .57378 .4569 .56157 Mtetra
.762 .644 .732 r
.4569 .56157 .46239 .57378 .47243 .55953 .46691 .55048 Mtetra
.487 .571 .866 r
.46691 .55048 .47243 .55953 .48229 .55774 .47674 .55179 Mtetra
.632 .73 .918 r
.47674 .55179 .48229 .55774 .4922 .55508 .48666 .54935 Mtetra
.647 .744 .92 r
.48666 .54935 .4922 .55508 .50215 .5522 .49664 .54652 Mtetra
.652 .748 .92 r
.49664 .54652 .50215 .5522 .51214 .54921 .50665 .54356 Mtetra
.655 .751 .92 r
.50665 .54356 .51214 .54921 .52217 .54615 .5167 .54051 Mtetra
.657 .752 .92 r
.5167 .54051 .52217 .54615 .53223 .54305 .52678 .5374 Mtetra
.658 .753 .92 r
.52678 .5374 .53223 .54305 .54232 .53991 .5369 .53424 Mtetra
.659 .754 .92 r
.5369 .53424 .54232 .53991 .55246 .53674 .54706 .53106 Mtetra
.54706 .53106 .55246 .53674 .56263 .53357 .55726 .52787 Mtetra
.55726 .52787 .56263 .53357 .57284 .53039 .56749 .52466 Mtetra
.56749 .52466 .57284 .53039 .58308 .5272 .57776 .52145 Mtetra
.658 .753 .92 r
.57776 .52145 .58308 .5272 .59336 .52401 .58807 .51824 Mtetra
.58807 .51824 .59336 .52401 .60369 .52082 .59842 .51502 Mtetra
.59842 .51502 .60369 .52082 .61404 .51761 .6088 .51179 Mtetra
.6088 .51179 .61404 .51761 .62444 .5144 .61922 .50856 Mtetra
.61922 .50856 .62444 .5144 .63488 .51118 .62969 .50531 Mtetra
.62969 .50531 .63488 .51118 .64535 .50795 .64019 .50206 Mtetra
.657 .753 .92 r
.64019 .50206 .64535 .50795 .65586 .50471 .65073 .49879 Mtetra
.65073 .49879 .65586 .50471 .66642 .50146 .66131 .49552 Mtetra
.66131 .49552 .66642 .50146 .67701 .4982 .67193 .49223 Mtetra
.67193 .49223 .67701 .4982 .68764 .49492 .68259 .48894 Mtetra
.657 .752 .92 r
.68259 .48894 .68764 .49492 .69831 .49164 .69328 .48563 Mtetra
.69328 .48563 .69831 .49164 .70902 .48834 .70402 .48231 Mtetra
.70402 .48231 .70902 .48834 .71978 .48504 .7148 .47898 Mtetra
.7148 .47898 .71978 .48504 .73057 .48172 .72563 .47564 Mtetra
.72563 .47564 .73057 .48172 .7414 .47839 .73649 .47228 Mtetra
.73649 .47228 .7414 .47839 .75228 .47505 .74739 .46892 Mtetra
.74739 .46892 .75228 .47505 .76319 .47169 .75834 .46554 Mtetra
.75834 .46554 .76319 .47169 .77415 .46833 .76932 .46215 Mtetra
.76932 .46215 .77415 .46833 .78515 .46495 .78035 .45875 Mtetra
.78035 .45875 .78515 .46495 .79619 .46156 .79143 .45534 Mtetra
.79143 .45534 .79619 .46156 .80728 .45816 .80254 .45191 Mtetra
.80254 .45191 .80728 .45816 .8184 .45474 .8137 .44847 Mtetra
.8137 .44847 .8184 .45474 .82957 .45131 .8249 .44502 Mtetra
.8249 .44502 .82957 .45131 .84078 .44787 .83614 .44155 Mtetra
.83614 .44155 .84078 .44787 .85204 .44442 .84742 .43807 Mtetra
.84742 .43807 .85204 .44442 .86334 .44095 .85876 .43458 Mtetra
.85876 .43458 .86334 .44095 .87468 .43747 .87013 .43108 Mtetra
.87013 .43108 .87468 .43747 .88606 .43398 .88155 .42756 Mtetra
.88155 .42756 .88606 .43398 .8975 .43048 .89301 .42403 Mtetra
.89301 .42403 .8975 .43048 .90897 .42696 .90452 .42048 Mtetra
.589 .71 .927 r
.2885 .60352 .29446 .60935 .30354 .60975 .2977 .60212 Mtetra
.88 .713 .671 r
.2977 .60212 .30354 .60975 .31329 .60021 .30861 .57466 Mtetra
.056 .086 .576 r
.30861 .57466 .31329 .60021 .3225 .59961 .31659 .59361 Mtetra
.604 .711 .92 r
.31659 .59361 .3225 .59961 .33183 .59769 .32592 .59191 Mtetra
.611 .722 .924 r
.32592 .59191 .33183 .59769 .34116 .59639 .33531 .59004 Mtetra
.345 .586 .933 r
.33531 .59004 .34116 .59639 .35112 .58357 .34451 .59216 Mtetra
0 0 0 r
.34451 .59216 .35112 .58357 .36026 .58753 .35445 .58102 Mtetra
.584 .688 .913 r
.35445 .58102 .36026 .58753 .36973 .58556 .3639 .57978 Mtetra
.625 .729 .921 r
.3639 .57978 .36973 .58556 .37925 .58333 .37344 .57756 Mtetra
.62 .728 .924 r
.37344 .57756 .37925 .58333 .38879 .58172 .38302 .57544 Mtetra
.456 .644 .939 r
.38302 .57544 .38879 .58172 .39895 .56441 .39252 .57622 Mtetra
0 0 0 r
.39252 .57622 .39895 .56441 .40819 .57266 .40247 .56591 Mtetra
.58 .681 .909 r
.40247 .56591 .40819 .57266 .41785 .57058 .41212 .56476 Mtetra
.632 .732 .92 r
.41212 .56476 .41785 .57058 .42756 .56805 .42185 .56234 Mtetra
.64 .739 .921 r
.42185 .56234 .42756 .56805 .43731 .56545 .43162 .55972 Mtetra
.639 .739 .921 r
.43162 .55972 .43731 .56545 .44709 .56298 .44143 .55713 Mtetra
.623 .73 .924 r
.44143 .55713 .44709 .56298 .4569 .56157 .45127 .55489 Mtetra
.117 .441 .878 r
.45127 .55489 .4569 .56157 .46691 .55048 .46101 .55968 Mtetra
0 0 0 r
.46101 .55968 .46691 .55048 .47674 .55179 .47115 .54533 Mtetra
.607 .705 .914 r
.47115 .54533 .47674 .55179 .48666 .54935 .48109 .5435 Mtetra
.642 .739 .919 r
.48109 .5435 .48666 .54935 .49664 .54652 .49108 .54078 Mtetra
.65 .746 .92 r
.49108 .54078 .49664 .54652 .50665 .54356 .50112 .53785 Mtetra
.654 .75 .92 r
.50112 .53785 .50665 .54356 .5167 .54051 .51119 .53481 Mtetra
.656 .751 .92 r
.51119 .53481 .5167 .54051 .52678 .5374 .5213 .5317 Mtetra
.658 .753 .92 r
.5213 .5317 .52678 .5374 .5369 .53424 .53144 .52854 Mtetra
.659 .753 .92 r
.53144 .52854 .5369 .53424 .54706 .53106 .54163 .52535 Mtetra
.659 .754 .92 r
.54163 .52535 .54706 .53106 .55726 .52787 .55185 .52213 Mtetra
.55185 .52213 .55726 .52787 .56749 .52466 .56211 .5189 Mtetra
.56211 .5189 .56749 .52466 .57776 .52145 .5724 .51567 Mtetra
.658 .754 .92 r
.5724 .51567 .57776 .52145 .58807 .51824 .58274 .51243 Mtetra
.658 .753 .92 r
.58274 .51243 .58807 .51824 .59842 .51502 .59311 .50918 Mtetra
.59311 .50918 .59842 .51502 .6088 .51179 .60352 .50593 Mtetra
.60352 .50593 .6088 .51179 .61922 .50856 .61397 .50267 Mtetra
.61397 .50267 .61922 .50856 .62969 .50531 .62446 .4994 Mtetra
.62446 .4994 .62969 .50531 .64019 .50206 .63499 .49612 Mtetra
.63499 .49612 .64019 .50206 .65073 .49879 .64555 .49284 Mtetra
.657 .753 .92 r
.64555 .49284 .65073 .49879 .66131 .49552 .65616 .48954 Mtetra
.65616 .48954 .66131 .49552 .67193 .49223 .66681 .48623 Mtetra
.66681 .48623 .67193 .49223 .68259 .48894 .67749 .48291 Mtetra
.67749 .48291 .68259 .48894 .69328 .48563 .68822 .47958 Mtetra
.657 .752 .92 r
.68822 .47958 .69328 .48563 .70402 .48231 .69899 .47624 Mtetra
.69899 .47624 .70402 .48231 .7148 .47898 .7098 .47288 Mtetra
.7098 .47288 .7148 .47898 .72563 .47564 .72065 .46952 Mtetra
.72065 .46952 .72563 .47564 .73649 .47228 .73154 .46614 Mtetra
.73154 .46614 .73649 .47228 .74739 .46892 .74247 .46275 Mtetra
.74247 .46275 .74739 .46892 .75834 .46554 .75345 .45935 Mtetra
.75345 .45935 .75834 .46554 .76932 .46215 .76446 .45593 Mtetra
.76446 .45593 .76932 .46215 .78035 .45875 .77552 .45251 Mtetra
.77552 .45251 .78035 .45875 .79143 .45534 .78662 .44907 Mtetra
.78662 .44907 .79143 .45534 .80254 .45191 .79777 .44562 Mtetra
.79777 .44562 .80254 .45191 .8137 .44847 .80896 .44215 Mtetra
.80896 .44215 .8137 .44847 .8249 .44502 .82019 .43867 Mtetra
.82019 .43867 .8249 .44502 .83614 .44155 .83146 .43518 Mtetra
.83146 .43518 .83614 .44155 .84742 .43807 .84278 .43168 Mtetra
.84278 .43168 .84742 .43807 .85876 .43458 .85414 .42816 Mtetra
.85414 .42816 .85876 .43458 .87013 .43108 .86555 .42464 Mtetra
.86555 .42464 .87013 .43108 .88155 .42756 .877 .42109 Mtetra
.877 .42109 .88155 .42756 .89301 .42403 .88849 .41754 Mtetra
.88849 .41754 .89301 .42403 .90452 .42048 .90004 .41397 Mtetra
.604 .716 .923 r
.28249 .59767 .2885 .60352 .2977 .60212 .29173 .59596 Mtetra
.481 .658 .939 r
.29173 .59596 .2977 .60212 .30861 .57466 .30088 .59632 Mtetra
.296 .001 .282 r
.30088 .59632 .30861 .57466 .31659 .59361 .3107 .58671 Mtetra
.557 .664 .908 r
.3107 .58671 .31659 .59361 .32592 .59191 .31999 .58607 Mtetra
.615 .722 .922 r
.31999 .58607 .32592 .59191 .33531 .59004 .32939 .58411 Mtetra
.583 .708 .929 r
.32939 .58411 .33531 .59004 .34451 .59216 .3388 .58277 Mtetra
.803 .689 .739 r
.3388 .58277 .34451 .59216 .35445 .58102 .34885 .56986 Mtetra
.379 .462 .82 r
.34885 .56986 .35445 .58102 .3639 .57978 .35805 .57379 Mtetra
.616 .719 .92 r
.35805 .57379 .3639 .57978 .37344 .57756 .3676 .57178 Mtetra
.626 .731 .922 r
.3676 .57178 .37344 .57756 .38302 .57544 .37719 .5695 Mtetra
.597 .716 .927 r
.37719 .5695 .38302 .57544 .39252 .57622 .38681 .56785 Mtetra
.847 .714 .717 r
.38681 .56785 .39252 .57622 .40247 .56591 .39706 .55043 Mtetra
.271 .325 .736 r
.39706 .55043 .40247 .56591 .41212 .56476 .40636 .55868 Mtetra
.62 .72 .918 r
.40636 .55868 .41212 .56476 .42185 .56234 .4161 .55655 Mtetra
.638 .737 .921 r
.4161 .55655 .42185 .56234 .43162 .55972 .42589 .55397 Mtetra
.64 .74 .921 r
.42589 .55397 .43162 .55972 .44143 .55713 .43572 .55132 Mtetra
.634 .737 .922 r
.43572 .55132 .44143 .55713 .45127 .55489 .44559 .5488 Mtetra
.585 .71 .929 r
.44559 .5488 .45127 .55489 .46101 .55968 .45547 .54734 Mtetra
.762 .645 .732 r
.45547 .54734 .46101 .55968 .47115 .54533 .46557 .53617 Mtetra
.486 .571 .867 r
.46557 .53617 .47115 .54533 .48109 .5435 .47548 .53744 Mtetra
.632 .73 .918 r
.47548 .53744 .48109 .5435 .49108 .54078 .48549 .53495 Mtetra
.647 .744 .92 r
.48549 .53495 .49108 .54078 .50112 .53785 .49555 .53208 Mtetra
.652 .748 .92 r
.49555 .53208 .50112 .53785 .51119 .53481 .50564 .52906 Mtetra
.655 .751 .92 r
.50564 .52906 .51119 .53481 .5213 .5317 .51578 .52595 Mtetra
.657 .752 .92 r
.51578 .52595 .5213 .5317 .53144 .52854 .52595 .52279 Mtetra
.658 .753 .92 r
.52595 .52279 .53144 .52854 .54163 .52535 .53616 .51958 Mtetra
.659 .754 .92 r
.53616 .51958 .54163 .52535 .55185 .52213 .5464 .51635 Mtetra
.5464 .51635 .55185 .52213 .56211 .5189 .55669 .5131 Mtetra
.55669 .5131 .56211 .5189 .5724 .51567 .56701 .50984 Mtetra
.56701 .50984 .5724 .51567 .58274 .51243 .57737 .50657 Mtetra
.658 .753 .92 r
.57737 .50657 .58274 .51243 .59311 .50918 .58777 .5033 Mtetra
.58777 .5033 .59311 .50918 .60352 .50593 .5982 .50003 Mtetra
.5982 .50003 .60352 .50593 .61397 .50267 .60868 .49674 Mtetra
.60868 .49674 .61397 .50267 .62446 .4994 .61919 .49345 Mtetra
.61919 .49345 .62446 .4994 .63499 .49612 .62975 .49015 Mtetra
.62975 .49015 .63499 .49612 .64555 .49284 .64034 .48684 Mtetra
.657 .753 .92 r
.64034 .48684 .64555 .49284 .65616 .48954 .65098 .48352 Mtetra
.65098 .48352 .65616 .48954 .66681 .48623 .66165 .48018 Mtetra
.66165 .48018 .66681 .48623 .67749 .48291 .67237 .47684 Mtetra
.67237 .47684 .67749 .48291 .68822 .47958 .68312 .47348 Mtetra
.657 .752 .92 r
.68312 .47348 .68822 .47958 .69899 .47624 .69392 .47012 Mtetra
.69392 .47012 .69899 .47624 .7098 .47288 .70476 .46674 Mtetra
.70476 .46674 .7098 .47288 .72065 .46952 .71563 .46335 Mtetra
.71563 .46335 .72065 .46952 .73154 .46614 .72655 .45995 Mtetra
.72655 .45995 .73154 .46614 .74247 .46275 .73752 .45653 Mtetra
.73752 .45653 .74247 .46275 .75345 .45935 .74852 .45311 Mtetra
.74852 .45311 .75345 .45935 .76446 .45593 .75957 .44967 Mtetra
.75957 .44967 .76446 .45593 .77552 .45251 .77066 .44622 Mtetra
.77066 .44622 .77552 .45251 .78662 .44907 .78179 .44276 Mtetra
.78179 .44276 .78662 .44907 .79777 .44562 .79296 .43928 Mtetra
.79296 .43928 .79777 .44562 .80896 .44215 .80418 .43579 Mtetra
.80418 .43579 .80896 .44215 .82019 .43867 .81544 .43229 Mtetra
.81544 .43229 .82019 .43867 .83146 .43518 .82675 .42877 Mtetra
.82675 .42877 .83146 .43518 .84278 .43168 .8381 .42524 Mtetra
.8381 .42524 .84278 .43168 .85414 .42816 .84949 .4217 Mtetra
.84949 .4217 .85414 .42816 .86555 .42464 .86093 .41815 Mtetra
.86093 .41815 .86555 .42464 .877 .42109 .87242 .41458 Mtetra
.87242 .41458 .877 .42109 .88849 .41754 .88394 .41099 Mtetra
.88394 .41099 .88849 .41754 .90004 .41397 .89552 .4074 Mtetra
.595 .704 .92 r
.27646 .59155 .28249 .59767 .29173 .59596 .28571 .59004 Mtetra
.589 .71 .927 r
.28571 .59004 .29173 .59596 .30088 .59632 .29499 .5886 Mtetra
.881 .714 .67 r
.29499 .5886 .30088 .59632 .3107 .58671 .306 .56098 Mtetra
.051 .082 .574 r
.306 .56098 .3107 .58671 .31999 .58607 .31402 .57999 Mtetra
.604 .711 .92 r
.31402 .57999 .31999 .58607 .32939 .58411 .32343 .57824 Mtetra
.611 .722 .924 r
.32343 .57824 .32939 .58411 .3388 .58277 .33288 .57633 Mtetra
.346 .586 .933 r
.33288 .57633 .3388 .58277 .34885 .56986 .34216 .57842 Mtetra
0 0 0 r
.34216 .57842 .34885 .56986 .35805 .57379 .35218 .56719 Mtetra
.584 .688 .913 r
.35218 .56719 .35805 .57379 .3676 .57178 .36171 .5659 Mtetra
.625 .729 .921 r
.36171 .5659 .3676 .57178 .37719 .5695 .37133 .56364 Mtetra
.62 .728 .924 r
.37133 .56364 .37719 .5695 .38681 .56785 .38098 .56148 Mtetra
.456 .644 .938 r
.38098 .56148 .38681 .56785 .39706 .55043 .39056 .56222 Mtetra
0 0 0 r
.39056 .56222 .39706 .55043 .40636 .55868 .4006 .55183 Mtetra
.58 .681 .91 r
.4006 .55183 .40636 .55868 .4161 .55655 .41032 .55063 Mtetra
.632 .732 .92 r
.41032 .55063 .4161 .55655 .42589 .55397 .42013 .54816 Mtetra
.64 .739 .921 r
.42013 .54816 .42589 .55397 .43572 .55132 .42998 .5455 Mtetra
.639 .739 .921 r
.42998 .5455 .43572 .55132 .44559 .5488 .43987 .54285 Mtetra
.623 .73 .924 r
.43987 .54285 .44559 .5488 .45547 .54734 .44979 .54057 Mtetra
.121 .443 .879 r
.44979 .54057 .45547 .54734 .46557 .53617 .45962 .54533 Mtetra
0 0 0 r
.45962 .54533 .46557 .53617 .47548 .53744 .46984 .53088 Mtetra
.607 .705 .914 r
.46984 .53088 .47548 .53744 .48549 .53495 .47987 .529 Mtetra
.642 .739 .92 r
.47987 .529 .48549 .53495 .49555 .53208 .48994 .52624 Mtetra
.65 .746 .92 r
.48994 .52624 .49555 .53208 .50564 .52906 .50006 .52325 Mtetra
.654 .75 .92 r
.50006 .52325 .50564 .52906 .51578 .52595 .51022 .52016 Mtetra
.656 .751 .92 r
.51022 .52016 .51578 .52595 .52595 .52279 .52041 .51699 Mtetra
.658 .753 .92 r
.52041 .51699 .52595 .52279 .53616 .51958 .53065 .51378 Mtetra
.659 .753 .92 r
.53065 .51378 .53616 .51958 .5464 .51635 .54092 .51053 Mtetra
.659 .754 .92 r
.54092 .51053 .5464 .51635 .55669 .5131 .55123 .50726 Mtetra
.55123 .50726 .55669 .5131 .56701 .50984 .56158 .50397 Mtetra
.56158 .50397 .56701 .50984 .57737 .50657 .57196 .50068 Mtetra
.658 .754 .92 r
.57196 .50068 .57737 .50657 .58777 .5033 .58239 .49739 Mtetra
.658 .753 .92 r
.58239 .49739 .58777 .5033 .5982 .50003 .59285 .49408 Mtetra
.59285 .49408 .5982 .50003 .60868 .49674 .60335 .49078 Mtetra
.60335 .49078 .60868 .49674 .61919 .49345 .61389 .48746 Mtetra
.61389 .48746 .61919 .49345 .62975 .49015 .62447 .48413 Mtetra
.62447 .48413 .62975 .49015 .64034 .48684 .6351 .4808 Mtetra
.6351 .4808 .64034 .48684 .65098 .48352 .64576 .47745 Mtetra
.657 .753 .92 r
.64576 .47745 .65098 .48352 .66165 .48018 .65646 .47409 Mtetra
.65646 .47409 .66165 .48018 .67237 .47684 .6672 .47073 Mtetra
.6672 .47073 .67237 .47684 .68312 .47348 .67799 .46735 Mtetra
.67799 .46735 .68312 .47348 .69392 .47012 .68881 .46396 Mtetra
.657 .752 .92 r
.68881 .46396 .69392 .47012 .70476 .46674 .69968 .46056 Mtetra
.69968 .46056 .70476 .46674 .71563 .46335 .71058 .45714 Mtetra
.71058 .45714 .71563 .46335 .72655 .45995 .72153 .45372 Mtetra
.72153 .45372 .72655 .45995 .73752 .45653 .73253 .45028 Mtetra
.73253 .45028 .73752 .45653 .74852 .45311 .74356 .44683 Mtetra
.74356 .44683 .74852 .45311 .75957 .44967 .75464 .44336 Mtetra
.75464 .44336 .75957 .44967 .77066 .44622 .76576 .43989 Mtetra
.76576 .43989 .77066 .44622 .78179 .44276 .77692 .4364 Mtetra
.77692 .4364 .78179 .44276 .79296 .43928 .78812 .4329 Mtetra
.78812 .4329 .79296 .43928 .80418 .43579 .79937 .42938 Mtetra
.79937 .42938 .80418 .43579 .81544 .43229 .81067 .42585 Mtetra
.81067 .42585 .81544 .43229 .82675 .42877 .822 .42231 Mtetra
.822 .42231 .82675 .42877 .8381 .42524 .83339 .41876 Mtetra
.83339 .41876 .8381 .42524 .84949 .4217 .84481 .41519 Mtetra
.84481 .41519 .84949 .4217 .86093 .41815 .85628 .41161 Mtetra
.85628 .41161 .86093 .41815 .87242 .41458 .8678 .40801 Mtetra
.8678 .40801 .87242 .41458 .88394 .41099 .87936 .40441 Mtetra
.87936 .40441 .88394 .41099 .89552 .4074 .89097 .40078 Mtetra
.534 .644 .904 r
.27048 .58429 .27646 .59155 .28571 .59004 .27964 .5841 Mtetra
.604 .716 .923 r
.27964 .5841 .28571 .59004 .29499 .5886 .28896 .58235 Mtetra
.481 .658 .939 r
.28896 .58235 .29499 .5886 .306 .56098 .29817 .58268 Mtetra
.288 0 .274 r
.29817 .58268 .306 .56098 .31402 .57999 .30808 .57298 Mtetra
.557 .664 .908 r
.30808 .57298 .31402 .57999 .32343 .57824 .31743 .57231 Mtetra
.615 .722 .922 r
.31743 .57231 .32343 .57824 .33288 .57633 .32691 .57029 Mtetra
.583 .708 .929 r
.32691 .57029 .33288 .57633 .34216 .57842 .33639 .56892 Mtetra
.803 .689 .739 r
.33639 .56892 .34216 .57842 .35218 .56719 .34653 .55591 Mtetra
.378 .462 .82 r
.34653 .55591 .35218 .56719 .36171 .5659 .3558 .55982 Mtetra
.616 .719 .92 r
.3558 .55982 .36171 .5659 .37133 .56364 .36542 .55776 Mtetra
.626 .731 .922 r
.36542 .55776 .37133 .56364 .38098 .56148 .3751 .55544 Mtetra
.597 .716 .927 r
.3751 .55544 .38098 .56148 .39056 .56222 .38479 .55375 Mtetra
.848 .715 .717 r
.38479 .55375 .39056 .56222 .4006 .55183 .39514 .53621 Mtetra
.268 .324 .736 r
.39514 .53621 .4006 .55183 .41032 .55063 .40451 .54445 Mtetra
.62 .72 .918 r
.40451 .54445 .41032 .55063 .42013 .54816 .41433 .54228 Mtetra
.638 .737 .921 r
.41433 .54228 .42013 .54816 .42998 .5455 .4242 .53965 Mtetra
.64 .74 .921 r
.4242 .53965 .42998 .5455 .43987 .54285 .43411 .53694 Mtetra
.634 .737 .922 r
.43411 .53694 .43987 .54285 .44979 .54057 .44406 .53437 Mtetra
.585 .71 .929 r
.44406 .53437 .44979 .54057 .45962 .54533 .45403 .53287 Mtetra
.762 .645 .732 r
.45403 .53287 .45962 .54533 .46984 .53088 .46422 .52161 Mtetra
.486 .571 .867 r
.46422 .52161 .46984 .53088 .47987 .529 .4742 .52285 Mtetra
.632 .73 .918 r
.4742 .52285 .47987 .529 .48994 .52624 .4843 .52031 Mtetra
.647 .744 .92 r
.4843 .52031 .48994 .52624 .50006 .52325 .49444 .51738 Mtetra
.652 .748 .92 r
.49444 .51738 .50006 .52325 .51022 .52016 .50462 .51431 Mtetra
.655 .751 .92 r
.50462 .51431 .51022 .52016 .52041 .51699 .51484 .51115 Mtetra
.657 .752 .92 r
.51484 .51115 .52041 .51699 .53065 .51378 .5251 .50793 Mtetra
.658 .753 .92 r
.5251 .50793 .53065 .51378 .54092 .51053 .5354 .50467 Mtetra
.659 .754 .92 r
.5354 .50467 .54092 .51053 .55123 .50726 .54573 .50138 Mtetra
.54573 .50138 .55123 .50726 .56158 .50397 .55611 .49807 Mtetra
.55611 .49807 .56158 .50397 .57196 .50068 .56652 .49475 Mtetra
.56652 .49475 .57196 .50068 .58239 .49739 .57697 .49143 Mtetra
.658 .753 .92 r
.57697 .49143 .58239 .49739 .59285 .49408 .58746 .4881 Mtetra
.58746 .4881 .59285 .49408 .60335 .49078 .59799 .48477 Mtetra
.59799 .48477 .60335 .49078 .61389 .48746 .60856 .48143 Mtetra
.60856 .48143 .61389 .48746 .62447 .48413 .61916 .47808 Mtetra
.61916 .47808 .62447 .48413 .6351 .4808 .62981 .47472 Mtetra
.62981 .47472 .6351 .4808 .64576 .47745 .6405 .47135 Mtetra
.657 .753 .92 r
.6405 .47135 .64576 .47745 .65646 .47409 .65123 .46796 Mtetra
.65123 .46796 .65646 .47409 .6672 .47073 .662 .46457 Mtetra
.662 .46457 .6672 .47073 .67799 .46735 .67281 .46117 Mtetra
.67281 .46117 .67799 .46735 .68881 .46396 .68367 .45775 Mtetra
.657 .752 .92 r
.68367 .45775 .68881 .46396 .69968 .46056 .69456 .45433 Mtetra
.69456 .45433 .69968 .46056 .71058 .45714 .7055 .45089 Mtetra
.7055 .45089 .71058 .45714 .72153 .45372 .71648 .44744 Mtetra
.71648 .44744 .72153 .45372 .73253 .45028 .7275 .44397 Mtetra
.7275 .44397 .73253 .45028 .74356 .44683 .73856 .4405 Mtetra
.73856 .4405 .74356 .44683 .75464 .44336 .74967 .43701 Mtetra
.74967 .43701 .75464 .44336 .76576 .43989 .76082 .43351 Mtetra
.76082 .43351 .76576 .43989 .77692 .4364 .77201 .42999 Mtetra
.77201 .42999 .77692 .4364 .78812 .4329 .78325 .42647 Mtetra
.78325 .42647 .78812 .4329 .79937 .42938 .79453 .42293 Mtetra
.79453 .42293 .79937 .42938 .81067 .42585 .80585 .41937 Mtetra
.80585 .41937 .81067 .42585 .822 .42231 .81722 .41581 Mtetra
.81722 .41581 .822 .42231 .83339 .41876 .82864 .41223 Mtetra
.82864 .41223 .83339 .41876 .84481 .41519 .8401 .40863 Mtetra
.8401 .40863 .84481 .41519 .85628 .41161 .8516 .40503 Mtetra
.8516 .40503 .85628 .41161 .8678 .40801 .86315 .4014 Mtetra
.86315 .4014 .8678 .40801 .87936 .40441 .87474 .39777 Mtetra
.87474 .39777 .87936 .40441 .89097 .40078 .88639 .39412 Mtetra
0 0 .3 r
.2723 .47474 .27048 .58429 .27964 .5841 .27355 .57789 Mtetra
.595 .704 .92 r
.27355 .57789 .27964 .5841 .28896 .58235 .28287 .57634 Mtetra
.589 .71 .927 r
.28287 .57634 .28896 .58235 .29817 .58268 .29222 .57485 Mtetra
.882 .715 .67 r
.29222 .57485 .29817 .58268 .30808 .57298 .30334 .54708 Mtetra
.046 .079 .572 r
.30334 .54708 .30808 .57298 .31743 .57231 .31141 .56613 Mtetra
.604 .711 .92 r
.31141 .56613 .31743 .57231 .32691 .57029 .32089 .56434 Mtetra
.611 .722 .924 r
.32089 .56434 .32691 .57029 .33639 .56892 .33042 .56238 Mtetra
.347 .586 .933 r
.33042 .56238 .33639 .56892 .34653 .55591 .33977 .56444 Mtetra
0 0 0 r
.33977 .56444 .34653 .55591 .3558 .55982 .34988 .55313 Mtetra
.584 .688 .913 r
.34988 .55313 .3558 .55982 .36542 .55776 .35948 .55179 Mtetra
.625 .729 .921 r
.35948 .55179 .36542 .55776 .3751 .55544 .36918 .54948 Mtetra
.62 .728 .924 r
.36918 .54948 .3751 .55544 .38479 .55375 .37891 .54727 Mtetra
.457 .644 .938 r
.37891 .54727 .38479 .55375 .39514 .53621 .38856 .54798 Mtetra
0 0 0 r
.38856 .54798 .39514 .53621 .40451 .54445 .39869 .5375 Mtetra
.58 .681 .91 r
.39869 .5375 .40451 .54445 .41433 .54228 .40849 .53626 Mtetra
.632 .732 .92 r
.40849 .53626 .41433 .54228 .4242 .53965 .41838 .53374 Mtetra
.64 .739 .921 r
.41838 .53374 .4242 .53965 .43411 .53694 .42831 .53103 Mtetra
.639 .739 .921 r
.42831 .53103 .43411 .53694 .44406 .53437 .43829 .52833 Mtetra
.623 .73 .924 r
.43829 .52833 .44406 .53437 .45403 .53287 .44829 .52599 Mtetra
.125 .445 .88 r
.44829 .52599 .45403 .53287 .46422 .52161 .4582 .53074 Mtetra
0 0 0 r
.4582 .53074 .46422 .52161 .4742 .52285 .46851 .51619 Mtetra
.607 .705 .914 r
.46851 .51619 .4742 .52285 .4843 .52031 .47862 .51426 Mtetra
.642 .739 .92 r
.47862 .51426 .4843 .52031 .49444 .51738 .48878 .51144 Mtetra
.65 .746 .92 r
.48878 .51144 .49444 .51738 .50462 .51431 .49899 .5084 Mtetra
.654 .75 .92 r
.49899 .5084 .50462 .51431 .51484 .51115 .50923 .50525 Mtetra
.656 .751 .92 r
.50923 .50525 .51484 .51115 .5251 .50793 .51952 .50203 Mtetra
.658 .753 .92 r
.51952 .50203 .5251 .50793 .5354 .50467 .52984 .49876 Mtetra
.659 .753 .92 r
.52984 .49876 .5354 .50467 .54573 .50138 .5402 .49545 Mtetra
.659 .754 .92 r
.5402 .49545 .54573 .50138 .55611 .49807 .5506 .49212 Mtetra
.5506 .49212 .55611 .49807 .56652 .49475 .56103 .48878 Mtetra
.56103 .48878 .56652 .49475 .57697 .49143 .57151 .48543 Mtetra
.658 .754 .92 r
.57151 .48543 .57697 .49143 .58746 .4881 .58203 .48208 Mtetra
.658 .753 .92 r
.58203 .48208 .58746 .4881 .59799 .48477 .59258 .47872 Mtetra
.59258 .47872 .59799 .48477 .60856 .48143 .60318 .47535 Mtetra
.60318 .47535 .60856 .48143 .61916 .47808 .61382 .47198 Mtetra
.61382 .47198 .61916 .47808 .62981 .47472 .62449 .46859 Mtetra
.62449 .46859 .62981 .47472 .6405 .47135 .63521 .4652 Mtetra
.63521 .4652 .6405 .47135 .65123 .46796 .64597 .46179 Mtetra
.657 .753 .92 r
.64597 .46179 .65123 .46796 .662 .46457 .65677 .45837 Mtetra
.65677 .45837 .662 .46457 .67281 .46117 .66761 .45495 Mtetra
.66761 .45495 .67281 .46117 .68367 .45775 .67849 .45151 Mtetra
.67849 .45151 .68367 .45775 .69456 .45433 .68941 .44805 Mtetra
.657 .752 .92 r
.68941 .44805 .69456 .45433 .7055 .45089 .70038 .44459 Mtetra
.70038 .44459 .7055 .45089 .71648 .44744 .71139 .44111 Mtetra
.71139 .44111 .71648 .44744 .7275 .44397 .72244 .43763 Mtetra
.72244 .43763 .7275 .44397 .73856 .4405 .73353 .43413 Mtetra
.73353 .43413 .73856 .4405 .74967 .43701 .74467 .43061 Mtetra
.74467 .43061 .74967 .43701 .76082 .43351 .75585 .42708 Mtetra
.75585 .42708 .76082 .43351 .77201 .42999 .76707 .42354 Mtetra
.76707 .42354 .77201 .42999 .78325 .42647 .77834 .41999 Mtetra
.77834 .41999 .78325 .42647 .79453 .42293 .78965 .41643 Mtetra
.78965 .41643 .79453 .42293 .80585 .41937 .80101 .41285 Mtetra
.80101 .41285 .80585 .41937 .81722 .41581 .81241 .40925 Mtetra
.81241 .40925 .81722 .41581 .82864 .41223 .82386 .40565 Mtetra
.82386 .40565 .82864 .41223 .8401 .40863 .83535 .40203 Mtetra
.83535 .40203 .8401 .40863 .8516 .40503 .84688 .39839 Mtetra
.84688 .39839 .8516 .40503 .86315 .4014 .85847 .39474 Mtetra
.85847 .39474 .86315 .4014 .87474 .39777 .87009 .39108 Mtetra
.87009 .39108 .87474 .39777 .88639 .39412 .88177 .38741 Mtetra
.508 .275 .495 r
.2576 .58 .2723 .47474 .27355 .57789 .26751 .57052 Mtetra
.534 .644 .904 r
.26751 .57052 .27355 .57789 .28287 .57634 .27674 .5703 Mtetra
.604 .716 .923 r
.27674 .5703 .28287 .57634 .29222 .57485 .28613 .5685 Mtetra
.482 .658 .939 r
.28613 .5685 .29222 .57485 .30334 .54708 .29542 .5688 Mtetra
.28 0 .266 r
.29542 .5688 .30334 .54708 .31141 .56613 .30541 .55903 Mtetra
.557 .664 .908 r
.30541 .55903 .31141 .56613 .32089 .56434 .31484 .55831 Mtetra
.615 .722 .922 r
.31484 .55831 .32089 .56434 .33042 .56238 .32439 .55625 Mtetra
.583 .708 .929 r
.32439 .55625 .33042 .56238 .33977 .56444 .33395 .55482 Mtetra
.804 .69 .739 r
.33395 .55482 .33977 .56444 .34988 .55313 .34417 .54172 Mtetra
.376 .461 .82 r
.34417 .54172 .34988 .55313 .35948 .55179 .35351 .54562 Mtetra
.616 .719 .92 r
.35351 .54562 .35948 .55179 .36918 .54948 .36322 .54351 Mtetra
.626 .731 .922 r
.36322 .54351 .36918 .54948 .37891 .54727 .37297 .54114 Mtetra
.597 .716 .927 r
.37297 .54114 .37891 .54727 .38856 .54798 .38274 .5394 Mtetra
.848 .716 .717 r
.38274 .5394 .38856 .54798 .39869 .5375 .39318 .52174 Mtetra
.266 .323 .735 r
.39318 .52174 .39869 .5375 .40849 .53626 .40262 .52998 Mtetra
.619 .72 .918 r
.40262 .52998 .40849 .53626 .41838 .53374 .41252 .52776 Mtetra
.638 .737 .921 r
.41252 .52776 .41838 .53374 .42831 .53103 .42248 .52508 Mtetra
.64 .74 .921 r
.42248 .52508 .42831 .53103 .43829 .52833 .43247 .52232 Mtetra
.634 .737 .922 r
.43247 .52232 .43829 .52833 .44829 .52599 .44251 .5197 Mtetra
.585 .71 .929 r
.44251 .5197 .44829 .52599 .4582 .53074 .45255 .51815 Mtetra
.763 .646 .732 r
.45255 .51815 .4582 .53074 .46851 .51619 .46283 .5068 Mtetra
.485 .571 .867 r
.46283 .5068 .46851 .51619 .47862 .51426 .4729 .508 Mtetra
.632 .73 .918 r
.4729 .508 .47862 .51426 .48878 .51144 .48309 .50541 Mtetra
.647 .744 .92 r
.48309 .50541 .48878 .51144 .49899 .5084 .49331 .50243 Mtetra
.652 .748 .92 r
.49331 .50243 .49899 .5084 .50923 .50525 .50358 .4993 Mtetra
.655 .751 .92 r
.50358 .4993 .50923 .50525 .51952 .50203 .51389 .49608 Mtetra
.657 .752 .92 r
.51389 .49608 .51952 .50203 .52984 .49876 .52424 .4928 Mtetra
.658 .753 .92 r
.52424 .4928 .52984 .49876 .5402 .49545 .53463 .48949 Mtetra
.659 .754 .92 r
.53463 .48949 .5402 .49545 .5506 .49212 .54505 .48614 Mtetra
.54505 .48614 .5506 .49212 .56103 .48878 .55551 .48277 Mtetra
.55551 .48277 .56103 .48878 .57151 .48543 .56602 .4794 Mtetra
.56602 .4794 .57151 .48543 .58203 .48208 .57656 .47602 Mtetra
.658 .753 .92 r
.57656 .47602 .58203 .48208 .59258 .47872 .58714 .47263 Mtetra
.58714 .47263 .59258 .47872 .60318 .47535 .59777 .46924 Mtetra
.59777 .46924 .60318 .47535 .61382 .47198 .60843 .46583 Mtetra
.60843 .46583 .61382 .47198 .62449 .46859 .61913 .46242 Mtetra
.61913 .46242 .62449 .46859 .63521 .4652 .62988 .459 Mtetra
.62988 .459 .63521 .4652 .64597 .46179 .64066 .45557 Mtetra
.657 .753 .92 r
.64066 .45557 .64597 .46179 .65677 .45837 .65149 .45213 Mtetra
.65149 .45213 .65677 .45837 .66761 .45495 .66236 .44868 Mtetra
.66236 .44868 .66761 .45495 .67849 .45151 .67327 .44521 Mtetra
.67327 .44521 .67849 .45151 .68941 .44805 .68422 .44174 Mtetra
.657 .752 .92 r
.68422 .44174 .68941 .44805 .70038 .44459 .69522 .43825 Mtetra
.69522 .43825 .70038 .44459 .71139 .44111 .70626 .43475 Mtetra
.70626 .43475 .71139 .44111 .72244 .43763 .71734 .43123 Mtetra
.71734 .43123 .72244 .43763 .73353 .43413 .72846 .42771 Mtetra
.72846 .42771 .73353 .43413 .74467 .43061 .73963 .42417 Mtetra
.73963 .42417 .74467 .43061 .75585 .42708 .75084 .42061 Mtetra
.75084 .42061 .75585 .42708 .76707 .42354 .7621 .41705 Mtetra
.7621 .41705 .76707 .42354 .77834 .41999 .77339 .41347 Mtetra
.77339 .41347 .77834 .41999 .78965 .41643 .78474 .40988 Mtetra
.78474 .40988 .78965 .41643 .80101 .41285 .79613 .40627 Mtetra
.79613 .40627 .80101 .41285 .81241 .40925 .80756 .40265 Mtetra
.80756 .40265 .81241 .40925 .82386 .40565 .81904 .39902 Mtetra
.81904 .39902 .82386 .40565 .83535 .40203 .83056 .39537 Mtetra
.83056 .39537 .83535 .40203 .84688 .39839 .84213 .39171 Mtetra
.84213 .39171 .84688 .39839 .85847 .39474 .85375 .38804 Mtetra
.85375 .38804 .85847 .39474 .87009 .39108 .86541 .38435 Mtetra
.86541 .38435 .87009 .39108 .88177 .38741 .87712 .38064 Mtetra
.925 .697 .574 r
.25151 .57257 .2576 .58 .26751 .57052 .26943 .46046 Mtetra
0 0 .295 r
.26943 .46046 .26751 .57052 .27674 .5703 .2706 .56399 Mtetra
.595 .704 .92 r
.2706 .56399 .27674 .5703 .28613 .5685 .27998 .5624 Mtetra
.589 .71 .927 r
.27998 .5624 .28613 .5685 .29542 .5688 .28941 .56087 Mtetra
.883 .716 .669 r
.28941 .56087 .29542 .5688 .30541 .55903 .30064 .53294 Mtetra
.041 .075 .57 r
.30064 .53294 .30541 .55903 .31484 .55831 .30876 .55203 Mtetra
.604 .711 .92 r
.30876 .55203 .31484 .55831 .32439 .55625 .31831 .55019 Mtetra
.611 .722 .924 r
.31831 .55019 .32439 .55625 .33395 .55482 .32792 .54819 Mtetra
.349 .587 .933 r
.32792 .54819 .33395 .55482 .34417 .54172 .33734 .55022 Mtetra
0 0 0 r
.33734 .55022 .34417 .54172 .35351 .54562 .34753 .53882 Mtetra
.584 .688 .913 r
.34753 .53882 .35351 .54562 .36322 .54351 .35722 .53744 Mtetra
.625 .729 .921 r
.35722 .53744 .36322 .54351 .37297 .54114 .36699 .53508 Mtetra
.62 .728 .924 r
.36699 .53508 .37297 .54114 .38274 .5394 .3768 .53282 Mtetra
.458 .644 .938 r
.3768 .53282 .38274 .5394 .39318 .52174 .38653 .53349 Mtetra
0 0 0 r
.38653 .53349 .39318 .52174 .40262 .52998 .39675 .52293 Mtetra
.58 .681 .91 r
.39675 .52293 .40262 .52998 .41252 .52776 .40663 .52164 Mtetra
.632 .732 .92 r
.40663 .52164 .41252 .52776 .42248 .52508 .4166 .51907 Mtetra
.64 .739 .921 r
.4166 .51907 .42248 .52508 .43247 .52232 .42662 .5163 Mtetra
.639 .739 .921 r
.42662 .5163 .43247 .52232 .44251 .5197 .43668 .51355 Mtetra
.623 .73 .924 r
.43668 .51355 .44251 .5197 .45255 .51815 .44676 .51117 Mtetra
.129 .446 .881 r
.44676 .51117 .45255 .51815 .46283 .5068 .45675 .51589 Mtetra
0 0 0 r
.45675 .51589 .46283 .5068 .4729 .508 .46716 .50123 Mtetra
.606 .705 .914 r
.46716 .50123 .4729 .508 .48309 .50541 .47735 .49925 Mtetra
.642 .739 .92 r
.47735 .49925 .48309 .50541 .49331 .50243 .4876 .49638 Mtetra
.65 .746 .92 r
.4876 .49638 .49331 .50243 .50358 .4993 .49789 .49328 Mtetra
.654 .75 .92 r
.49789 .49328 .50358 .4993 .51389 .49608 .50823 .49008 Mtetra
.656 .751 .92 r
.50823 .49008 .51389 .49608 .52424 .4928 .5186 .4868 Mtetra
.658 .753 .92 r
.5186 .4868 .52424 .4928 .53463 .48949 .52901 .48347 Mtetra
.659 .753 .92 r
.52901 .48347 .53463 .48949 .54505 .48614 .53946 .48011 Mtetra
.659 .754 .92 r
.53946 .48011 .54505 .48614 .55551 .48277 .54995 .47672 Mtetra
.54995 .47672 .55551 .48277 .56602 .4794 .56048 .47332 Mtetra
.56048 .47332 .56602 .4794 .57656 .47602 .57105 .46991 Mtetra
.658 .754 .92 r
.57105 .46991 .57656 .47602 .58714 .47263 .58166 .4665 Mtetra
.658 .753 .92 r
.58166 .4665 .58714 .47263 .59777 .46924 .59231 .46308 Mtetra
.59231 .46308 .59777 .46924 .60843 .46583 .603 .45965 Mtetra
.603 .45965 .60843 .46583 .61913 .46242 .61374 .45621 Mtetra
.61374 .45621 .61913 .46242 .62988 .459 .62451 .45277 Mtetra
.62451 .45277 .62988 .459 .64066 .45557 .63532 .44931 Mtetra
.63532 .44931 .64066 .45557 .65149 .45213 .64618 .44585 Mtetra
.657 .753 .92 r
.64618 .44585 .65149 .45213 .66236 .44868 .65708 .44237 Mtetra
.65708 .44237 .66236 .44868 .67327 .44521 .66802 .43888 Mtetra
.66802 .43888 .67327 .44521 .68422 .44174 .679 .43537 Mtetra
.679 .43537 .68422 .44174 .69522 .43825 .69002 .43186 Mtetra
.657 .752 .92 r
.69002 .43186 .69522 .43825 .70626 .43475 .70109 .42833 Mtetra
.70109 .42833 .70626 .43475 .71734 .43123 .7122 .42479 Mtetra
.7122 .42479 .71734 .43123 .72846 .42771 .72336 .42124 Mtetra
.72336 .42124 .72846 .42771 .73963 .42417 .73455 .41768 Mtetra
.73455 .41768 .73963 .42417 .75084 .42061 .7458 .4141 Mtetra
.7458 .4141 .75084 .42061 .7621 .41705 .75708 .41051 Mtetra
.75708 .41051 .7621 .41705 .77339 .41347 .76841 .4069 Mtetra
.76841 .4069 .77339 .41347 .78474 .40988 .77979 .40328 Mtetra
.77979 .40328 .78474 .40988 .79613 .40627 .79121 .39965 Mtetra
.79121 .39965 .79613 .40627 .80756 .40265 .80267 .396 Mtetra
.80267 .396 .80756 .40265 .81904 .39902 .81418 .39234 Mtetra
.81418 .39234 .81904 .39902 .83056 .39537 .82574 .38867 Mtetra
.82574 .38867 .83056 .39537 .84213 .39171 .83734 .38498 Mtetra
.83734 .38498 .84213 .39171 .85375 .38804 .84899 .38128 Mtetra
.84899 .38128 .85375 .38804 .86541 .38435 .86069 .37756 Mtetra
.86069 .37756 .86541 .38435 .87712 .38064 .87243 .37383 Mtetra
.509 .671 .937 r
.24528 .56622 .25151 .57257 .26943 .46046 .2545 .56608 Mtetra
.505 .27 .492 r
.2545 .56608 .26943 .46046 .2706 .56399 .2645 .55653 Mtetra
.534 .644 .904 r
.2645 .55653 .2706 .56399 .27998 .5624 .2738 .55626 Mtetra
.604 .716 .923 r
.2738 .55626 .27998 .5624 .28941 .56087 .28326 .55442 Mtetra
.482 .658 .938 r
.28326 .55442 .28941 .56087 .30064 .53294 .29262 .55468 Mtetra
.271 0 .257 r
.29262 .55468 .30064 .53294 .30876 .55203 .3027 .54483 Mtetra
.556 .664 .908 r
.3027 .54483 .30876 .55203 .31831 .55019 .3122 .54407 Mtetra
.615 .722 .922 r
.3122 .54407 .31831 .55019 .32792 .54819 .32183 .54196 Mtetra
.583 .708 .929 r
.32183 .54196 .32792 .54819 .33734 .55022 .33146 .54049 Mtetra
.805 .691 .739 r
.33146 .54049 .33734 .55022 .34753 .53882 .34178 .52729 Mtetra
.375 .461 .82 r
.34178 .52729 .34753 .53882 .35722 .53744 .35119 .53116 Mtetra
.616 .719 .92 r
.35119 .53116 .35722 .53744 .36699 .53508 .36097 .52901 Mtetra
.626 .731 .922 r
.36097 .52901 .36699 .53508 .3768 .53282 .37081 .52659 Mtetra
.597 .716 .927 r
.37081 .52659 .3768 .53282 .38653 .53349 .38065 .5248 Mtetra
.849 .717 .717 r
.38065 .5248 .38653 .53349 .39675 .52293 .39119 .50702 Mtetra
.264 .321 .735 r
.39119 .50702 .39675 .52293 .40663 .52164 .40071 .51526 Mtetra
.619 .72 .918 r
.40071 .51526 .40663 .52164 .4166 .51907 .41069 .51298 Mtetra
.638 .737 .921 r
.41069 .51298 .4166 .51907 .42662 .5163 .42073 .51025 Mtetra
.64 .74 .921 r
.42073 .51025 .42662 .5163 .43668 .51355 .43081 .50744 Mtetra
.634 .737 .922 r
.43081 .50744 .43668 .51355 .44676 .51117 .44092 .50477 Mtetra
.585 .71 .929 r
.44092 .50477 .44676 .51117 .45675 .51589 .45106 .50317 Mtetra
.763 .646 .732 r
.45106 .50317 .45675 .51589 .46716 .50123 .46143 .49172 Mtetra
.485 .571 .867 r
.46143 .49172 .46716 .50123 .47735 .49925 .47158 .49289 Mtetra
.632 .73 .918 r
.47158 .49289 .47735 .49925 .4876 .49638 .48185 .49024 Mtetra
.647 .744 .92 r
.48185 .49024 .4876 .49638 .49789 .49328 .49217 .4872 Mtetra
.652 .748 .92 r
.49217 .4872 .49789 .49328 .50823 .49008 .50253 .48402 Mtetra
.655 .751 .92 r
.50253 .48402 .50823 .49008 .5186 .4868 .51292 .48074 Mtetra
.657 .752 .92 r
.51292 .48074 .5186 .4868 .52901 .48347 .52336 .47741 Mtetra
.658 .753 .92 r
.52336 .47741 .52901 .48347 .53946 .48011 .53384 .47403 Mtetra
.659 .754 .92 r
.53384 .47403 .53946 .48011 .54995 .47672 .54436 .47063 Mtetra
.54436 .47063 .54995 .47672 .56048 .47332 .55491 .4672 Mtetra
.55491 .4672 .56048 .47332 .57105 .46991 .56551 .46377 Mtetra
.56551 .46377 .57105 .46991 .58166 .4665 .57615 .46033 Mtetra
.658 .753 .92 r
.57615 .46033 .58166 .4665 .59231 .46308 .58682 .45688 Mtetra
.58682 .45688 .59231 .46308 .603 .45965 .59754 .45342 Mtetra
.59754 .45342 .603 .45965 .61374 .45621 .6083 .44996 Mtetra
.6083 .44996 .61374 .45621 .62451 .45277 .6191 .44649 Mtetra
.6191 .44649 .62451 .45277 .63532 .44931 .62994 .44301 Mtetra
.62994 .44301 .63532 .44931 .64618 .44585 .64083 .43951 Mtetra
.657 .753 .92 r
.64083 .43951 .64618 .44585 .65708 .44237 .65176 .43601 Mtetra
.65176 .43601 .65708 .44237 .66802 .43888 .66272 .43249 Mtetra
.66272 .43249 .66802 .43888 .679 .43537 .67374 .42897 Mtetra
.67374 .42897 .679 .43537 .69002 .43186 .68479 .42543 Mtetra
.657 .752 .92 r
.68479 .42543 .69002 .43186 .70109 .42833 .69589 .42187 Mtetra
.69589 .42187 .70109 .42833 .7122 .42479 .70703 .41831 Mtetra
.70703 .41831 .7122 .42479 .72336 .42124 .71821 .41473 Mtetra
.71821 .41473 .72336 .42124 .73455 .41768 .72944 .41114 Mtetra
.72944 .41114 .73455 .41768 .7458 .4141 .74072 .40753 Mtetra
.74072 .40753 .7458 .4141 .75708 .41051 .75203 .40391 Mtetra
.75203 .40391 .75708 .41051 .76841 .4069 .76339 .40028 Mtetra
.76339 .40028 .76841 .4069 .77979 .40328 .7748 .39664 Mtetra
.7748 .39664 .77979 .40328 .79121 .39965 .78625 .39298 Mtetra
.78625 .39298 .79121 .39965 .80267 .396 .79775 .3893 Mtetra
.79775 .3893 .80267 .396 .81418 .39234 .8093 .38562 Mtetra
.8093 .38562 .81418 .39234 .82574 .38867 .82089 .38192 Mtetra
.82089 .38192 .82574 .38867 .83734 .38498 .83252 .3782 Mtetra
.83252 .3782 .83734 .38498 .84899 .38128 .8442 .37447 Mtetra
.8442 .37447 .84899 .38128 .86069 .37756 .85593 .37073 Mtetra
.85593 .37073 .86069 .37756 .87243 .37383 .86771 .36697 Mtetra
.586 .707 .927 r
.23901 .56003 .24528 .56622 .2545 .56608 .24835 .55855 Mtetra
.926 .697 .572 r
.24835 .55855 .2545 .56608 .2645 .55653 .26651 .44595 Mtetra
0 0 .289 r
.26651 .44595 .2645 .55653 .2738 .55626 .26759 .54986 Mtetra
.595 .704 .92 r
.26759 .54986 .2738 .55626 .28326 .55442 .27705 .54822 Mtetra
.589 .71 .927 r
.27705 .54822 .28326 .55442 .29262 .55468 .28655 .54665 Mtetra
.884 .716 .669 r
.28655 .54665 .29262 .55468 .3027 .54483 .29789 .51856 Mtetra
.036 .071 .567 r
.29789 .51856 .3027 .54483 .3122 .54407 .30606 .53769 Mtetra
.604 .711 .92 r
.30606 .53769 .3122 .54407 .32183 .54196 .31569 .53581 Mtetra
.611 .722 .924 r
.31569 .53581 .32183 .54196 .33146 .54049 .32537 .53375 Mtetra
.35 .587 .933 r
.32537 .53375 .33146 .54049 .34178 .52729 .33487 .53575 Mtetra
0 0 0 r
.33487 .53575 .34178 .52729 .35119 .53116 .34515 .52427 Mtetra
.584 .688 .913 r
.34515 .52427 .35119 .53116 .36097 .52901 .35491 .52284 Mtetra
.625 .729 .921 r
.35491 .52284 .36097 .52901 .37081 .52659 .36477 .52043 Mtetra
.62 .728 .923 r
.36477 .52043 .37081 .52659 .38065 .5248 .37466 .51812 Mtetra
.458 .644 .938 r
.37466 .51812 .38065 .5248 .39119 .50702 .38446 .51875 Mtetra
0 0 0 r
.38446 .51875 .39119 .50702 .40071 .51526 .39477 .5081 Mtetra
.58 .681 .91 r
.39477 .5081 .40071 .51526 .41069 .51298 .40474 .50676 Mtetra
.632 .732 .92 r
.40474 .50676 .41069 .51298 .42073 .51025 .41479 .50414 Mtetra
.64 .739 .921 r
.41479 .50414 .42073 .51025 .43081 .50744 .42489 .50132 Mtetra
.639 .739 .921 r
.42489 .50132 .43081 .50744 .44092 .50477 .43504 .49851 Mtetra
.623 .73 .924 r
.43504 .49851 .44092 .50477 .45106 .50317 .44521 .49608 Mtetra
.132 .448 .881 r
.44521 .49608 .45106 .50317 .46143 .49172 .45528 .50078 Mtetra
0 0 0 r
.45528 .50078 .46143 .49172 .47158 .49289 .46578 .48601 Mtetra
.606 .705 .914 r
.46578 .48601 .47158 .49289 .48185 .49024 .47606 .48398 Mtetra
.642 .739 .92 r
.47606 .48398 .48185 .49024 .49217 .4872 .4864 .48105 Mtetra
.65 .746 .92 r
.4864 .48105 .49217 .4872 .50253 .48402 .49678 .4779 Mtetra
.654 .75 .92 r
.49678 .4779 .50253 .48402 .51292 .48074 .50721 .47463 Mtetra
.656 .751 .92 r
.50721 .47463 .51292 .48074 .52336 .47741 .51767 .4713 Mtetra
.658 .753 .92 r
.51767 .4713 .52336 .47741 .53384 .47403 .52817 .46791 Mtetra
.659 .753 .92 r
.52817 .46791 .53384 .47403 .54436 .47063 .53872 .46449 Mtetra
.659 .754 .92 r
.53872 .46449 .54436 .47063 .55491 .4672 .5493 .46104 Mtetra
.5493 .46104 .55491 .4672 .56551 .46377 .55992 .45758 Mtetra
.55992 .45758 .56551 .46377 .57615 .46033 .57059 .45411 Mtetra
.658 .754 .92 r
.57059 .45411 .57615 .46033 .58682 .45688 .58129 .45063 Mtetra
.658 .753 .92 r
.58129 .45063 .58682 .45688 .59754 .45342 .59204 .44715 Mtetra
.59204 .44715 .59754 .45342 .6083 .44996 .60283 .44366 Mtetra
.60283 .44366 .6083 .44996 .6191 .44649 .61366 .44017 Mtetra
.61366 .44017 .6191 .44649 .62994 .44301 .62453 .43666 Mtetra
.62453 .43666 .62994 .44301 .64083 .43951 .63544 .43314 Mtetra
.63544 .43314 .64083 .43951 .65176 .43601 .6464 .42961 Mtetra
.657 .753 .92 r
.6464 .42961 .65176 .43601 .66272 .43249 .65739 .42607 Mtetra
.65739 .42607 .66272 .43249 .67374 .42897 .66843 .42251 Mtetra
.66843 .42251 .67374 .42897 .68479 .42543 .67952 .41894 Mtetra
.67952 .41894 .68479 .42543 .69589 .42187 .69065 .41537 Mtetra
.657 .752 .92 r
.69065 .41537 .69589 .42187 .70703 .41831 .70182 .41177 Mtetra
.70182 .41177 .70703 .41831 .71821 .41473 .71303 .40817 Mtetra
.71303 .40817 .71821 .41473 .72944 .41114 .72429 .40455 Mtetra
.72429 .40455 .72944 .41114 .74072 .40753 .7356 .40092 Mtetra
.7356 .40092 .74072 .40753 .75203 .40391 .74695 .39727 Mtetra
.74695 .39727 .75203 .40391 .76339 .40028 .75834 .39362 Mtetra
.75834 .39362 .76339 .40028 .7748 .39664 .76978 .38994 Mtetra
.76978 .38994 .7748 .39664 .78625 .39298 .78126 .38626 Mtetra
.78126 .38626 .78625 .39298 .79775 .3893 .79279 .38256 Mtetra
.79279 .38256 .79775 .3893 .8093 .38562 .80437 .37884 Mtetra
.80437 .37884 .8093 .38562 .82089 .38192 .81599 .37511 Mtetra
.81599 .37511 .82089 .38192 .83252 .3782 .82766 .37137 Mtetra
.82766 .37137 .83252 .3782 .8442 .37447 .83938 .36761 Mtetra
.83938 .36761 .8442 .37447 .85593 .37073 .85114 .36384 Mtetra
.85114 .36384 .85593 .37073 .86771 .36697 .86296 .36005 Mtetra
.591 .705 .922 r
.2327 .5537 .23901 .56003 .24835 .55855 .24206 .55211 Mtetra
.509 .671 .937 r
.24206 .55211 .24835 .55855 .26651 .44595 .25135 .55193 Mtetra
.502 .265 .488 r
.25135 .55193 .26651 .44595 .26759 .54986 .26143 .54229 Mtetra
.534 .644 .904 r
.26143 .54229 .26759 .54986 .27705 .54822 .2708 .54199 Mtetra
.604 .716 .923 r
.2708 .54199 .27705 .54822 .28655 .54665 .28034 .5401 Mtetra
.483 .658 .938 r
.28034 .5401 .28655 .54665 .29789 .51856 .28977 .54032 Mtetra
.262 0 .248 r
.28977 .54032 .29789 .51856 .30606 .53769 .29993 .53038 Mtetra
.556 .664 .909 r
.29993 .53038 .30606 .53769 .31569 .53581 .30951 .52958 Mtetra
.615 .722 .922 r
.30951 .52958 .31569 .53581 .32537 .53375 .31922 .52742 Mtetra
.583 .708 .929 r
.31922 .52742 .32537 .53375 .33487 .53575 .32893 .52591 Mtetra
.805 .691 .739 r
.32893 .52591 .33487 .53575 .34515 .52427 .33934 .51261 Mtetra
.374 .46 .821 r
.33934 .51261 .34515 .52427 .35491 .52284 .34882 .51646 Mtetra
.616 .72 .92 r
.34882 .51646 .35491 .52284 .36477 .52043 .35868 .51425 Mtetra
.626 .731 .922 r
.35868 .51425 .36477 .52043 .37466 .51812 .3686 .51178 Mtetra
.597 .716 .927 r
.3686 .51178 .37466 .51812 .38446 .51875 .37853 .50994 Mtetra
.85 .718 .717 r
.37853 .50994 .38446 .51875 .39477 .5081 .38916 .49205 Mtetra
.261 .32 .735 r
.38916 .49205 .39477 .5081 .40474 .50676 .39875 .50028 Mtetra
.619 .72 .918 r
.39875 .50028 .40474 .50676 .41479 .50414 .40882 .49795 Mtetra
.638 .737 .921 r
.40882 .49795 .41479 .50414 .42489 .50132 .41894 .49516 Mtetra
.64 .74 .921 r
.41894 .49516 .42489 .50132 .43504 .49851 .42911 .4923 Mtetra
.634 .737 .922 r
.42911 .4923 .43504 .49851 .44521 .49608 .43931 .48957 Mtetra
.585 .71 .929 r
.43931 .48957 .44521 .49608 .45528 .50078 .44953 .48792 Mtetra
.764 .647 .732 r
.44953 .48792 .45528 .50078 .46578 .48601 .45999 .47638 Mtetra
.484 .571 .867 r
.45999 .47638 .46578 .48601 .47606 .48398 .47023 .47751 Mtetra
.632 .73 .918 r
.47023 .47751 .47606 .48398 .4864 .48105 .48059 .47481 Mtetra
.647 .744 .92 r
.48059 .47481 .4864 .48105 .49678 .4779 .491 .47171 Mtetra
.652 .748 .92 r
.491 .47171 .49678 .4779 .50721 .47463 .50145 .46847 Mtetra
.655 .751 .92 r
.50145 .46847 .50721 .47463 .51767 .4713 .51194 .46513 Mtetra
.657 .752 .92 r
.51194 .46513 .51767 .4713 .52817 .46791 .52247 .46174 Mtetra
.658 .753 .92 r
.52247 .46174 .52817 .46791 .53872 .46449 .53304 .4583 Mtetra
.659 .754 .92 r
.53304 .4583 .53872 .46449 .5493 .46104 .54365 .45483 Mtetra
.54365 .45483 .5493 .46104 .55992 .45758 .5543 .45135 Mtetra
.5543 .45135 .55992 .45758 .57059 .45411 .56499 .44785 Mtetra
.56499 .44785 .57059 .45411 .58129 .45063 .57572 .44435 Mtetra
.658 .753 .92 r
.57572 .44435 .58129 .45063 .59204 .44715 .5865 .44084 Mtetra
.5865 .44084 .59204 .44715 .60283 .44366 .59731 .43732 Mtetra
.59731 .43732 .60283 .44366 .61366 .44017 .60817 .4338 Mtetra
.60817 .4338 .61366 .44017 .62453 .43666 .61907 .43026 Mtetra
.61907 .43026 .62453 .43666 .63544 .43314 .63001 .42672 Mtetra
.63001 .42672 .63544 .43314 .6464 .42961 .641 .42316 Mtetra
.657 .753 .92 r
.641 .42316 .6464 .42961 .65739 .42607 .65202 .41959 Mtetra
.65202 .41959 .65739 .42607 .66843 .42251 .6631 .41601 Mtetra
.6631 .41601 .66843 .42251 .67952 .41894 .67421 .41242 Mtetra
.67421 .41242 .67952 .41894 .69065 .41537 .68537 .40881 Mtetra
.657 .752 .92 r
.68537 .40881 .69065 .41537 .70182 .41177 .69657 .40519 Mtetra
.69657 .40519 .70182 .41177 .71303 .40817 .70781 .40156 Mtetra
.70781 .40156 .71303 .40817 .72429 .40455 .71911 .39792 Mtetra
.71911 .39792 .72429 .40455 .7356 .40092 .73044 .39426 Mtetra
.73044 .39426 .7356 .40092 .74695 .39727 .74182 .39059 Mtetra
.74182 .39059 .74695 .39727 .75834 .39362 .75325 .3869 Mtetra
.75325 .3869 .75834 .39362 .76978 .38994 .76472 .3832 Mtetra
.76472 .3832 .76978 .38994 .78126 .38626 .77624 .37949 Mtetra
.77624 .37949 .78126 .38626 .79279 .38256 .7878 .37576 Mtetra
.7878 .37576 .79279 .38256 .80437 .37884 .79941 .37202 Mtetra
.79941 .37202 .80437 .37884 .81599 .37511 .81106 .36826 Mtetra
.81106 .36826 .81599 .37511 .82766 .37137 .82277 .36449 Mtetra
.82277 .36449 .82766 .37137 .83938 .36761 .83452 .3607 Mtetra
.83452 .3607 .83938 .36761 .85114 .36384 .84632 .3569 Mtetra
.84632 .3569 .85114 .36384 .86296 .36005 .85816 .35309 Mtetra
.555 .669 .913 r
.22641 .54662 .2327 .5537 .24206 .55211 .23572 .54582 Mtetra
.586 .707 .927 r
.23572 .54582 .24206 .55211 .25135 .55193 .24513 .54429 Mtetra
.927 .698 .571 r
.24513 .54429 .25135 .55193 .26143 .54229 .26355 .43119 Mtetra
0 0 .283 r
.26355 .43119 .26143 .54229 .2708 .54199 .26453 .53548 Mtetra
.595 .705 .92 r
.26453 .53548 .2708 .54199 .28034 .5401 .27407 .5338 Mtetra
.589 .71 .927 r
.27407 .5338 .28034 .5401 .28977 .54032 .28364 .53218 Mtetra
.885 .717 .668 r
.28364 .53218 .28977 .54032 .29993 .53038 .2951 .50393 Mtetra
.031 .067 .565 r
.2951 .50393 .29993 .53038 .30951 .52958 .30331 .5231 Mtetra
.604 .711 .92 r
.30331 .5231 .30951 .52958 .31922 .52742 .31302 .52117 Mtetra
.611 .722 .924 r
.31302 .52117 .31922 .52742 .32893 .52591 .32278 .51906 Mtetra
.351 .587 .933 r
.32278 .51906 .32893 .52591 .33934 .51261 .33235 .52103 Mtetra
0 0 0 r
.33235 .52103 .33934 .51261 .34882 .51646 .34272 .50946 Mtetra
.584 .688 .913 r
.34272 .50946 .34882 .51646 .35868 .51425 .35257 .50798 Mtetra
.625 .729 .921 r
.35257 .50798 .35868 .51425 .3686 .51178 .3625 .50552 Mtetra
.62 .728 .923 r
.3625 .50552 .3686 .51178 .37853 .50994 .37247 .50315 Mtetra
.459 .644 .938 r
.37247 .50315 .37853 .50994 .38916 .49205 .38236 .50374 Mtetra
0 0 0 r
.38236 .50374 .38916 .49205 .39875 .50028 .39276 .49301 Mtetra
.579 .681 .91 r
.39276 .49301 .39875 .50028 .40882 .49795 .40281 .49163 Mtetra
.632 .732 .92 r
.40281 .49163 .40882 .49795 .41894 .49516 .41295 .48895 Mtetra
.64 .739 .921 r
.41295 .48895 .41894 .49516 .42911 .4923 .42314 .48607 Mtetra
.639 .739 .921 r
.42314 .48607 .42911 .4923 .43931 .48957 .43337 .48321 Mtetra
.623 .73 .924 r
.43337 .48321 .43931 .48957 .44953 .48792 .44363 .48072 Mtetra
.136 .45 .882 r
.44363 .48072 .44953 .48792 .45999 .47638 .45378 .48539 Mtetra
0 0 0 r
.45378 .48539 .45999 .47638 .47023 .47751 .46438 .47052 Mtetra
.606 .705 .914 r
.46438 .47052 .47023 .47751 .48059 .47481 .47475 .46844 Mtetra
.642 .739 .92 r
.47475 .46844 .48059 .47481 .491 .47171 .48518 .46545 Mtetra
.65 .746 .92 r
.48518 .46545 .491 .47171 .50145 .46847 .49565 .46223 Mtetra
.654 .75 .92 r
.49565 .46223 .50145 .46847 .51194 .46513 .50617 .45891 Mtetra
.656 .751 .92 r
.50617 .45891 .51194 .46513 .52247 .46174 .51672 .45552 Mtetra
.658 .753 .92 r
.51672 .45552 .52247 .46174 .53304 .4583 .52732 .45207 Mtetra
.659 .753 .92 r
.52732 .45207 .53304 .4583 .54365 .45483 .53796 .44858 Mtetra
.659 .754 .92 r
.53796 .44858 .54365 .45483 .5543 .45135 .54863 .44507 Mtetra
.54863 .44507 .5543 .45135 .56499 .44785 .55935 .44155 Mtetra
.55935 .44155 .56499 .44785 .57572 .44435 .57011 .43802 Mtetra
.658 .754 .92 r
.57011 .43802 .57572 .44435 .5865 .44084 .58092 .43448 Mtetra
.658 .753 .92 r
.58092 .43448 .5865 .44084 .59731 .43732 .59176 .43094 Mtetra
.59176 .43094 .59731 .43732 .60817 .4338 .60265 .42738 Mtetra
.60265 .42738 .60817 .4338 .61907 .43026 .61357 .42382 Mtetra
.61357 .42382 .61907 .43026 .63001 .42672 .62455 .42025 Mtetra
.62455 .42025 .63001 .42672 .641 .42316 .63556 .41667 Mtetra
.63556 .41667 .641 .42316 .65202 .41959 .64662 .41307 Mtetra
.657 .753 .92 r
.64662 .41307 .65202 .41959 .6631 .41601 .65772 .40946 Mtetra
.65772 .40946 .6631 .41601 .67421 .41242 .66886 .40584 Mtetra
.66886 .40584 .67421 .41242 .68537 .40881 .68005 .40221 Mtetra
.68005 .40221 .68537 .40881 .69657 .40519 .69128 .39856 Mtetra
.657 .752 .92 r
.69128 .39856 .69657 .40519 .70781 .40156 .70256 .39491 Mtetra
.70256 .39491 .70781 .40156 .71911 .39792 .71388 .39123 Mtetra
.71388 .39123 .71911 .39792 .73044 .39426 .72525 .38755 Mtetra
.72525 .38755 .73044 .39426 .74182 .39059 .73666 .38385 Mtetra
.73666 .38385 .74182 .39059 .75325 .3869 .74812 .38014 Mtetra
.74812 .38014 .75325 .3869 .76472 .3832 .75962 .37641 Mtetra
.75962 .37641 .76472 .3832 .77624 .37949 .77117 .37267 Mtetra
.77117 .37267 .77624 .37949 .7878 .37576 .78277 .36891 Mtetra
.78277 .36891 .7878 .37576 .79941 .37202 .79441 .36514 Mtetra
.79441 .36514 .79941 .37202 .81106 .36826 .8061 .36135 Mtetra
.8061 .36135 .81106 .36826 .82277 .36449 .81784 .35756 Mtetra
.81784 .35756 .82277 .36449 .83452 .3607 .82962 .35374 Mtetra
.82962 .35374 .83452 .3607 .84632 .3569 .84145 .34991 Mtetra
.84145 .34991 .84632 .3569 .85816 .35309 .85333 .34607 Mtetra
.175 .257 .709 r
.22091 .53043 .22641 .54662 .23572 .54582 .22934 .53938 Mtetra
.591 .705 .922 r
.22934 .53938 .23572 .54582 .24513 .54429 .23878 .53775 Mtetra
.509 .671 .937 r
.23878 .53775 .24513 .54429 .26355 .43119 .24814 .53753 Mtetra
.498 .261 .485 r
.24814 .53753 .26355 .43119 .26453 .53548 .25831 .52781 Mtetra
.534 .644 .905 r
.25831 .52781 .26453 .53548 .27407 .5338 .26775 .52746 Mtetra
.604 .716 .923 r
.26775 .52746 .27407 .5338 .28364 .53218 .27736 .52553 Mtetra
.483 .658 .938 r
.27736 .52553 .28364 .53218 .2951 .50393 .28687 .52571 Mtetra
.253 0 .238 r
.28687 .52571 .2951 .50393 .30331 .5231 .29712 .51569 Mtetra
.556 .664 .909 r
.29712 .51569 .30331 .5231 .31302 .52117 .30678 .51484 Mtetra
.615 .722 .922 r
.30678 .51484 .31302 .52117 .32278 .51906 .31656 .51263 Mtetra
.583 .708 .929 r
.31656 .51263 .32278 .51906 .33235 .52103 .32635 .51107 Mtetra
.806 .692 .739 r
.32635 .51107 .33235 .52103 .34272 .50946 .33686 .49768 Mtetra
.373 .46 .821 r
.33686 .49768 .34272 .50946 .35257 .50798 .34641 .5015 Mtetra
.616 .72 .92 r
.34641 .5015 .35257 .50798 .3625 .50552 .35636 .49924 Mtetra
.626 .731 .922 r
.35636 .49924 .3625 .50552 .37247 .50315 .36636 .49671 Mtetra
.597 .716 .927 r
.36636 .49671 .37247 .50315 .38236 .50374 .37637 .49482 Mtetra
.851 .718 .716 r
.37637 .49482 .38236 .50374 .39276 .49301 .3871 .47681 Mtetra
.259 .318 .734 r
.3871 .47681 .39276 .49301 .40281 .49163 .39677 .48503 Mtetra
.619 .72 .918 r
.39677 .48503 .40281 .49163 .41295 .48895 .40692 .48265 Mtetra
.638 .737 .921 r
.40692 .48265 .41295 .48895 .42314 .48607 .41713 .47981 Mtetra
.64 .74 .921 r
.41713 .47981 .42314 .48607 .43337 .48321 .42738 .47688 Mtetra
.634 .737 .922 r
.42738 .47688 .43337 .48321 .44363 .48072 .43767 .4741 Mtetra
.586 .71 .929 r
.43767 .4741 .44363 .48072 .45378 .48539 .44798 .4724 Mtetra
.764 .647 .733 r
.44798 .4724 .45378 .48539 .46438 .47052 .45854 .46077 Mtetra
.484 .571 .868 r
.45854 .46077 .46438 .47052 .47475 .46844 .46886 .46185 Mtetra
.632 .73 .918 r
.46886 .46185 .47475 .46844 .48518 .46545 .47931 .45909 Mtetra
.647 .744 .92 r
.47931 .45909 .48518 .46545 .49565 .46223 .48981 .45594 Mtetra
.652 .748 .92 r
.48981 .45594 .49565 .46223 .50617 .45891 .50035 .45263 Mtetra
.655 .751 .92 r
.50035 .45263 .50617 .45891 .51672 .45552 .51093 .44924 Mtetra
.657 .752 .92 r
.51093 .44924 .51672 .45552 .52732 .45207 .52156 .44578 Mtetra
.658 .753 .92 r
.52156 .44578 .52732 .45207 .53796 .44858 .53222 .44228 Mtetra
.659 .754 .92 r
.53222 .44228 .53796 .44858 .54863 .44507 .54293 .43875 Mtetra
.54293 .43875 .54863 .44507 .55935 .44155 .55368 .4352 Mtetra
.55368 .4352 .55935 .44155 .57011 .43802 .56446 .43164 Mtetra
.56446 .43164 .57011 .43802 .58092 .43448 .57529 .42808 Mtetra
.658 .753 .92 r
.57529 .42808 .58092 .43448 .59176 .43094 .58617 .4245 Mtetra
.58617 .4245 .59176 .43094 .60265 .42738 .59708 .42092 Mtetra
.59708 .42092 .60265 .42738 .61357 .42382 .60804 .41733 Mtetra
.60804 .41733 .61357 .42382 .62455 .42025 .61904 .41373 Mtetra
.61904 .41373 .62455 .42025 .63556 .41667 .63008 .41012 Mtetra
.63008 .41012 .63556 .41667 .64662 .41307 .64117 .4065 Mtetra
.657 .753 .92 r
.64117 .4065 .64662 .41307 .65772 .40946 .6523 .40287 Mtetra
.6523 .40287 .65772 .40946 .66886 .40584 .66347 .39922 Mtetra
.66347 .39922 .66886 .40584 .68005 .40221 .67469 .39556 Mtetra
.67469 .39556 .68005 .40221 .69128 .39856 .68595 .39189 Mtetra
.657 .752 .92 r
.68595 .39189 .69128 .39856 .70256 .39491 .69726 .3882 Mtetra
.69726 .3882 .70256 .39491 .71388 .39123 .70862 .3845 Mtetra
.70862 .3845 .71388 .39123 .72525 .38755 .72001 .38079 Mtetra
.72001 .38079 .72525 .38755 .73666 .38385 .73146 .37706 Mtetra
.73146 .37706 .73666 .38385 .74812 .38014 .74295 .37332 Mtetra
.74295 .37332 .74812 .38014 .75962 .37641 .75448 .36956 Mtetra
.75448 .36956 .75962 .37641 .77117 .37267 .76607 .36579 Mtetra
.76607 .36579 .77117 .37267 .78277 .36891 .7777 .36201 Mtetra
.7777 .36201 .78277 .36891 .79441 .36514 .78937 .35821 Mtetra
.78937 .35821 .79441 .36514 .8061 .36135 .8011 .3544 Mtetra
.8011 .3544 .8061 .36135 .81784 .35756 .81287 .35057 Mtetra
.81287 .35057 .81784 .35756 .82962 .35374 .82469 .34673 Mtetra
.82469 .34673 .82962 .35374 .84145 .34991 .83655 .34287 Mtetra
.83655 .34287 .84145 .34991 .85333 .34607 .84847 .33899 Mtetra
0 0 0 r
.2128 .54238 .22091 .53043 .22934 .53938 .22299 .53221 Mtetra
.555 .669 .913 r
.22299 .53221 .22934 .53938 .23878 .53775 .23237 .53136 Mtetra
.586 .707 .927 r
.23237 .53136 .23878 .53775 .24814 .53753 .24186 .52978 Mtetra
.928 .698 .569 r
.24186 .52978 .24814 .53753 .25831 .52781 .26053 .41619 Mtetra
0 0 .277 r
.26053 .41619 .25831 .52781 .26775 .52746 .26142 .52086 Mtetra
.594 .705 .92 r
.26142 .52086 .26775 .52746 .27736 .52553 .27103 .51912 Mtetra
.589 .71 .927 r
.27103 .51912 .27736 .52553 .28687 .52571 .28068 .51745 Mtetra
.886 .718 .668 r
.28068 .51745 .28687 .52571 .29712 .51569 .29225 .48904 Mtetra
.025 .063 .563 r
.29225 .48904 .29712 .51569 .30678 .51484 .30051 .50826 Mtetra
.604 .711 .92 r
.30051 .50826 .30678 .51484 .31656 .51263 .3103 .50627 Mtetra
.611 .722 .924 r
.3103 .50627 .31656 .51263 .32635 .51107 .32014 .50412 Mtetra
.353 .588 .933 r
.32014 .50412 .32635 .51107 .33686 .49768 .32979 .50605 Mtetra
0 0 0 r
.32979 .50605 .33686 .49768 .34641 .5015 .34026 .49438 Mtetra
.584 .689 .913 r
.34026 .49438 .34641 .5015 .35636 .49924 .35018 .49286 Mtetra
.625 .729 .921 r
.35018 .49286 .35636 .49924 .36636 .49671 .3602 .49034 Mtetra
.62 .728 .923 r
.3602 .49034 .36636 .49671 .37637 .49482 .37025 .48793 Mtetra
.459 .644 .937 r
.37025 .48793 .37637 .49482 .3871 .47681 .38022 .48847 Mtetra
0 0 0 r
.38022 .48847 .3871 .47681 .39677 .48503 .39071 .47765 Mtetra
.579 .681 .91 r
.39071 .47765 .39677 .48503 .40692 .48265 .40085 .47622 Mtetra
.632 .732 .92 r
.40085 .47622 .40692 .48265 .41713 .47981 .41107 .47348 Mtetra
.64 .739 .921 r
.41107 .47348 .41713 .47981 .42738 .47688 .42135 .47055 Mtetra
.639 .739 .921 r
.42135 .47055 .42738 .47688 .43767 .4741 .43167 .46763 Mtetra
.623 .73 .924 r
.43167 .46763 .43767 .4741 .44798 .4724 .44202 .46508 Mtetra
.14 .452 .883 r
.44202 .46508 .44798 .4724 .45854 .46077 .45225 .46973 Mtetra
0 0 0 r
.45225 .46973 .45854 .46077 .46886 .46185 .46295 .45475 Mtetra
.606 .705 .914 r
.46295 .45475 .46886 .46185 .47931 .45909 .47341 .45261 Mtetra
.642 .739 .92 r
.47341 .45261 .47931 .45909 .48981 .45594 .48393 .44956 Mtetra
.65 .746 .92 r
.48393 .44956 .48981 .45594 .50035 .45263 .4945 .44629 Mtetra
.654 .75 .92 r
.4945 .44629 .50035 .45263 .51093 .44924 .50511 .4429 Mtetra
.656 .751 .92 r
.50511 .4429 .51093 .44924 .52156 .44578 .51576 .43945 Mtetra
.658 .753 .92 r
.51576 .43945 .52156 .44578 .53222 .44228 .52645 .43593 Mtetra
.659 .753 .92 r
.52645 .43593 .53222 .44228 .54293 .43875 .53718 .43239 Mtetra
.659 .754 .92 r
.53718 .43239 .54293 .43875 .55368 .4352 .54796 .42881 Mtetra
.54796 .42881 .55368 .4352 .56446 .43164 .55877 .42523 Mtetra
.55877 .42523 .56446 .43164 .57529 .42808 .56963 .42163 Mtetra
.658 .754 .92 r
.56963 .42163 .57529 .42808 .58617 .4245 .58053 .41803 Mtetra
.658 .753 .92 r
.58053 .41803 .58617 .4245 .59708 .42092 .59148 .41442 Mtetra
.59148 .41442 .59708 .42092 .60804 .41733 .60246 .4108 Mtetra
.60246 .4108 .60804 .41733 .61904 .41373 .61349 .40717 Mtetra
.61349 .40717 .61904 .41373 .63008 .41012 .62456 .40353 Mtetra
.62456 .40353 .63008 .41012 .64117 .4065 .63568 .39989 Mtetra
.63568 .39989 .64117 .4065 .6523 .40287 .64684 .39622 Mtetra
.657 .753 .92 r
.64684 .39622 .6523 .40287 .66347 .39922 .65805 .39255 Mtetra
.65805 .39255 .66347 .39922 .67469 .39556 .66929 .38886 Mtetra
.66929 .38886 .67469 .39556 .68595 .39189 .68059 .38516 Mtetra
.68059 .38516 .68595 .39189 .69726 .3882 .69193 .38145 Mtetra
.657 .752 .92 r
.69193 .38145 .69726 .3882 .70862 .3845 .70331 .37772 Mtetra
.70331 .37772 .70862 .3845 .72001 .38079 .71474 .37398 Mtetra
.71474 .37398 .72001 .38079 .73146 .37706 .72622 .37022 Mtetra
.72622 .37022 .73146 .37706 .74295 .37332 .73774 .36645 Mtetra
.73774 .36645 .74295 .37332 .75448 .36956 .74931 .36267 Mtetra
.74931 .36267 .75448 .36956 .76607 .36579 .76093 .35887 Mtetra
.76093 .35887 .76607 .36579 .7777 .36201 .77259 .35506 Mtetra
.77259 .35506 .7777 .36201 .78937 .35821 .7843 .35123 Mtetra
.7843 .35123 .78937 .35821 .8011 .3544 .79606 .34739 Mtetra
.79606 .34739 .8011 .3544 .81287 .35057 .80786 .34353 Mtetra
.80786 .34353 .81287 .35057 .82469 .34673 .81972 .33966 Mtetra
.81972 .33966 .82469 .34673 .83655 .34287 .83162 .33577 Mtetra
.83162 .33577 .83655 .34287 .84847 .33899 .84357 .33187 Mtetra
.841 .708 .716 r
.20652 .53365 .2128 .54238 .22299 .53221 .21744 .51587 Mtetra
.172 .255 .709 r
.21744 .51587 .22299 .53221 .23237 .53136 .22593 .52482 Mtetra
.591 .705 .922 r
.22593 .52482 .23237 .53136 .24186 .52978 .23544 .52314 Mtetra
.509 .671 .937 r
.23544 .52314 .24186 .52978 .26053 .41619 .24487 .52287 Mtetra
.495 .256 .481 r
.24487 .52287 .26053 .41619 .26142 .52086 .25513 .51308 Mtetra
.533 .644 .905 r
.25513 .51308 .26142 .52086 .27103 .51912 .26465 .51269 Mtetra
.604 .716 .923 r
.26465 .51269 .27103 .51912 .28068 .51745 .27434 .5107 Mtetra
.483 .658 .938 r
.27434 .5107 .28068 .51745 .29225 .48904 .28392 .51084 Mtetra
.244 0 .229 r
.28392 .51084 .29225 .48904 .30051 .50826 .29427 .50074 Mtetra
.556 .664 .909 r
.29427 .50074 .30051 .50826 .3103 .50627 .30399 .49984 Mtetra
.615 .722 .922 r
.30399 .49984 .3103 .50627 .32014 .50412 .31386 .49758 Mtetra
.583 .708 .929 r
.31386 .49758 .32014 .50412 .32979 .50605 .32373 .49597 Mtetra
.806 .693 .74 r
.32373 .49597 .32979 .50605 .34026 .49438 .33433 .48248 Mtetra
.372 .459 .821 r
.33433 .48248 .34026 .49438 .35018 .49286 .34396 .48627 Mtetra
.616 .72 .92 r
.34396 .48627 .35018 .49286 .3602 .49034 .35399 .48395 Mtetra
.626 .731 .922 r
.35399 .48395 .3602 .49034 .37025 .48793 .36408 .48137 Mtetra
.597 .716 .927 r
.36408 .48137 .37025 .48793 .38022 .48847 .37417 .47943 Mtetra
.852 .719 .716 r
.37417 .47943 .38022 .48847 .39071 .47765 .385 .4613 Mtetra
.257 .317 .734 r
.385 .4613 .39071 .47765 .40085 .47622 .39474 .46951 Mtetra
.619 .72 .918 r
.39474 .46951 .40085 .47622 .41107 .47348 .40498 .46707 Mtetra
.638 .737 .921 r
.40498 .46707 .41107 .47348 .42135 .47055 .41528 .46417 Mtetra
.64 .74 .921 r
.41528 .46417 .42135 .47055 .43167 .46763 .42562 .46119 Mtetra
.634 .737 .922 r
.42562 .46119 .43167 .46763 .44202 .46508 .436 .45835 Mtetra
.586 .71 .929 r
.436 .45835 .44202 .46508 .45225 .46973 .4464 .4566 Mtetra
.764 .648 .733 r
.4464 .4566 .45225 .46973 .46295 .45475 .45705 .44487 Mtetra
.483 .571 .868 r
.45705 .44487 .46295 .45475 .47341 .45261 .46747 .44591 Mtetra
.632 .73 .918 r
.46747 .44591 .47341 .45261 .48393 .44956 .47801 .44309 Mtetra
.647 .744 .92 r
.47801 .44309 .48393 .44956 .4945 .44629 .4886 .43988 Mtetra
.652 .748 .92 r
.4886 .43988 .4945 .44629 .50511 .4429 .49924 .43651 Mtetra
.655 .751 .92 r
.49924 .43651 .50511 .4429 .51576 .43945 .50991 .43305 Mtetra
.657 .752 .92 r
.50991 .43305 .51576 .43945 .52645 .43593 .52063 .42953 Mtetra
.658 .753 .92 r
.52063 .42953 .52645 .43593 .53718 .43239 .53139 .42597 Mtetra
.659 .754 .92 r
.53139 .42597 .53718 .43239 .54796 .42881 .5422 .42238 Mtetra
.5422 .42238 .54796 .42881 .55877 .42523 .55304 .41876 Mtetra
.55304 .41876 .55877 .42523 .56963 .42163 .56393 .41514 Mtetra
.56393 .41514 .56963 .42163 .58053 .41803 .57486 .41151 Mtetra
.658 .753 .92 r
.57486 .41151 .58053 .41803 .59148 .41442 .58583 .40787 Mtetra
.58583 .40787 .59148 .41442 .60246 .4108 .59684 .40422 Mtetra
.59684 .40422 .60246 .4108 .61349 .40717 .6079 .40057 Mtetra
.6079 .40057 .61349 .40717 .62456 .40353 .61901 .3969 Mtetra
.61901 .3969 .62456 .40353 .63568 .39989 .63015 .39322 Mtetra
.63015 .39322 .63568 .39989 .64684 .39622 .64134 .38953 Mtetra
.657 .753 .92 r
.64134 .38953 .64684 .39622 .65805 .39255 .65258 .38583 Mtetra
.65258 .38583 .65805 .39255 .66929 .38886 .66386 .38211 Mtetra
.66386 .38211 .66929 .38886 .68059 .38516 .67518 .37839 Mtetra
.67518 .37839 .68059 .38516 .69193 .38145 .68655 .37464 Mtetra
.657 .752 .92 r
.68655 .37464 .69193 .38145 .70331 .37772 .69797 .37089 Mtetra
.69797 .37089 .70331 .37772 .71474 .37398 .70943 .36712 Mtetra
.70943 .36712 .71474 .37398 .72622 .37022 .72094 .36333 Mtetra
.72094 .36333 .72622 .37022 .73774 .36645 .7325 .35954 Mtetra
.7325 .35954 .73774 .36645 .74931 .36267 .7441 .35572 Mtetra
.7441 .35572 .74931 .36267 .76093 .35887 .75575 .3519 Mtetra
.75575 .3519 .76093 .35887 .77259 .35506 .76744 .34806 Mtetra
.76744 .34806 .77259 .35506 .7843 .35123 .77919 .3442 Mtetra
.77919 .3442 .7843 .35123 .79606 .34739 .79098 .34033 Mtetra
.79098 .34033 .79606 .34739 .80786 .34353 .80282 .33644 Mtetra
.80282 .33644 .80786 .34353 .81972 .33966 .81471 .33254 Mtetra
.81471 .33254 .81972 .33966 .83162 .33577 .82664 .32862 Mtetra
.82664 .32862 .83162 .33577 .84357 .33187 .83863 .32469 Mtetra
.421 .627 .939 r
.20003 .52684 .20652 .53365 .21744 .51587 .20923 .5278 Mtetra
0 0 0 r
.20923 .5278 .21744 .51587 .22593 .52482 .21952 .51754 Mtetra
.555 .669 .913 r
.21952 .51754 .22593 .52482 .23544 .52314 .22897 .51664 Mtetra
.586 .707 .927 r
.22897 .51664 .23544 .52314 .24487 .52287 .23853 .51502 Mtetra
.93 .699 .568 r
.23853 .51502 .24487 .52287 .25513 .51308 .25746 .40093 Mtetra
0 0 .271 r
.25746 .40093 .25513 .51308 .26465 .51269 .25825 .50598 Mtetra
.594 .705 .92 r
.25825 .50598 .26465 .51269 .27434 .5107 .26794 .50419 Mtetra
.589 .71 .927 r
.26794 .50419 .27434 .5107 .28392 .51084 .27767 .50247 Mtetra
.887 .719 .667 r
.27767 .50247 .28392 .51084 .29427 .50074 .28936 .4739 Mtetra
.02 .059 .561 r
.28936 .4739 .29427 .50074 .30399 .49984 .29766 .49315 Mtetra
.604 .711 .92 r
.29766 .49315 .30399 .49984 .31386 .49758 .30753 .49112 Mtetra
.611 .722 .924 r
.30753 .49112 .31386 .49758 .32373 .49597 .31746 .48891 Mtetra
.354 .588 .933 r
.31746 .48891 .32373 .49597 .33433 .48248 .32718 .49081 Mtetra
0 0 0 r
.32718 .49081 .33433 .48248 .34396 .48627 .33774 .47904 Mtetra
.584 .689 .914 r
.33774 .47904 .34396 .48627 .35399 .48395 .34775 .47747 Mtetra
.625 .729 .921 r
.34775 .47747 .35399 .48395 .36408 .48137 .35785 .4749 Mtetra
.62 .728 .923 r
.35785 .4749 .36408 .48137 .37417 .47943 .36799 .47243 Mtetra
.46 .644 .937 r
.36799 .47243 .37417 .47943 .385 .4613 .37804 .47293 Mtetra
0 0 0 r
.37804 .47293 .385 .4613 .39474 .46951 .38863 .46201 Mtetra
.579 .681 .91 r
.38863 .46201 .39474 .46951 .40498 .46707 .39885 .46053 Mtetra
.632 .732 .92 r
.39885 .46053 .40498 .46707 .41528 .46417 .40917 .45774 Mtetra
.64 .739 .921 r
.40917 .45774 .41528 .46417 .42562 .46119 .41953 .45474 Mtetra
.639 .739 .921 r
.41953 .45474 .42562 .46119 .436 .45835 .42994 .45177 Mtetra
.623 .73 .924 r
.42994 .45177 .436 .45835 .4464 .4566 .44038 .44916 Mtetra
.143 .453 .884 r
.44038 .44916 .4464 .4566 .45705 .44487 .4507 .45378 Mtetra
0 0 0 r
.4507 .45378 .45705 .44487 .46747 .44591 .46149 .43869 Mtetra
.606 .705 .914 r
.46149 .43869 .46747 .44591 .47801 .44309 .47205 .43649 Mtetra
.642 .739 .92 r
.47205 .43649 .47801 .44309 .4886 .43988 .48266 .43338 Mtetra
.65 .746 .92 r
.48266 .43338 .4886 .43988 .49924 .43651 .49332 .43005 Mtetra
.654 .75 .92 r
.49332 .43005 .49924 .43651 .50991 .43305 .50403 .4266 Mtetra
.656 .751 .92 r
.50403 .4266 .50991 .43305 .52063 .42953 .51477 .42308 Mtetra
.658 .753 .92 r
.51477 .42308 .52063 .42953 .53139 .42597 .52556 .4195 Mtetra
.659 .753 .92 r
.52556 .4195 .53139 .42597 .5422 .42238 .53639 .41589 Mtetra
.659 .754 .92 r
.53639 .41589 .5422 .42238 .55304 .41876 .54727 .41225 Mtetra
.54727 .41225 .55304 .41876 .56393 .41514 .55818 .4086 Mtetra
.55818 .4086 .56393 .41514 .57486 .41151 .56914 .40494 Mtetra
.658 .754 .92 r
.56914 .40494 .57486 .41151 .58583 .40787 .58014 .40127 Mtetra
.658 .753 .92 r
.58014 .40127 .58583 .40787 .59684 .40422 .59119 .39759 Mtetra
.59119 .39759 .59684 .40422 .6079 .40057 .60227 .39391 Mtetra
.60227 .39391 .6079 .40057 .61901 .3969 .61341 .39021 Mtetra
.61341 .39021 .61901 .3969 .63015 .39322 .62458 .38651 Mtetra
.62458 .38651 .63015 .39322 .64134 .38953 .6358 .38279 Mtetra
.6358 .38279 .64134 .38953 .65258 .38583 .64707 .37906 Mtetra
.657 .753 .92 r
.64707 .37906 .65258 .38583 .66386 .38211 .65838 .37532 Mtetra
.65838 .37532 .66386 .38211 .67518 .37839 .66974 .37156 Mtetra
.66974 .37156 .67518 .37839 .68655 .37464 .68114 .36779 Mtetra
.68114 .36779 .68655 .37464 .69797 .37089 .69259 .364 Mtetra
.657 .752 .92 r
.69259 .364 .69797 .37089 .70943 .36712 .70408 .36021 Mtetra
.70408 .36021 .70943 .36712 .72094 .36333 .71562 .35639 Mtetra
.71562 .35639 .72094 .36333 .7325 .35954 .72721 .35257 Mtetra
.72721 .35257 .7325 .35954 .7441 .35572 .73884 .34873 Mtetra
.73884 .34873 .7441 .35572 .75575 .3519 .75053 .34487 Mtetra
.75053 .34487 .75575 .3519 .76744 .34806 .76226 .341 Mtetra
.76226 .341 .76744 .34806 .77919 .3442 .77403 .33711 Mtetra
.77403 .33711 .77919 .3442 .79098 .34033 .78586 .33321 Mtetra
.78586 .33321 .79098 .34033 .80282 .33644 .79773 .3293 Mtetra
.79773 .3293 .80282 .33644 .81471 .33254 .80966 .32536 Mtetra
.80966 .32536 .81471 .33254 .82664 .32862 .82163 .32142 Mtetra
.82163 .32142 .82664 .32862 .83863 .32469 .83365 .31745 Mtetra
.571 .699 .929 r
.19346 .52028 .20003 .52684 .20923 .5278 .20289 .51895 Mtetra
.842 .709 .716 r
.20289 .51895 .20923 .5278 .21952 .51754 .21392 .50105 Mtetra
.169 .253 .708 r
.21392 .50105 .21952 .51754 .22897 .51664 .22246 .51 Mtetra
.591 .705 .922 r
.22246 .51 .22897 .51664 .23853 .51502 .23204 .50827 Mtetra
.51 .671 .936 r
.23204 .50827 .23853 .51502 .25746 .40093 .24155 .50797 Mtetra
.491 .25 .477 r
.24155 .50797 .25746 .40093 .25825 .50598 .2519 .49808 Mtetra
.533 .644 .905 r
.2519 .49808 .25825 .50598 .26794 .50419 .26149 .49765 Mtetra
.604 .716 .923 r
.26149 .49765 .26794 .50419 .27767 .50247 .27126 .49561 Mtetra
.484 .658 .938 r
.27126 .49561 .27767 .50247 .28936 .4739 .28092 .4957 Mtetra
.234 0 .219 r
.28092 .4957 .28936 .4739 .29766 .49315 .29136 .48552 Mtetra
.556 .664 .909 r
.29136 .48552 .29766 .49315 .30753 .49112 .30116 .48458 Mtetra
.615 .722 .922 r
.30116 .48458 .30753 .49112 .31746 .48891 .31111 .48226 Mtetra
.583 .708 .929 r
.31111 .48226 .31746 .48891 .32718 .49081 .32106 .4806 Mtetra
.807 .694 .74 r
.32106 .4806 .32718 .49081 .33774 .47904 .33176 .467 Mtetra
.37 .459 .821 r
.33176 .467 .33774 .47904 .34775 .47747 .34147 .47077 Mtetra
.616 .72 .92 r
.34147 .47077 .34775 .47747 .35785 .4749 .35158 .4684 Mtetra
.626 .731 .922 r
.35158 .4684 .35785 .4749 .36799 .47243 .36175 .46576 Mtetra
.597 .716 .927 r
.36175 .46576 .36799 .47243 .37804 .47293 .37193 .46377 Mtetra
.852 .72 .716 r
.37193 .46377 .37804 .47293 .38863 .46201 .38287 .44551 Mtetra
.254 .315 .733 r
.38287 .44551 .38863 .46201 .39885 .46053 .39269 .45371 Mtetra
.619 .721 .918 r
.39269 .45371 .39885 .46053 .40917 .45774 .40301 .45122 Mtetra
.638 .737 .921 r
.40301 .45122 .40917 .45774 .41953 .45474 .4134 .44826 Mtetra
.64 .74 .921 r
.4134 .44826 .41953 .45474 .42994 .45177 .42383 .44522 Mtetra
.634 .737 .922 r
.42383 .44522 .42994 .45177 .44038 .44916 .4343 .44231 Mtetra
.586 .71 .929 r
.4343 .44231 .44038 .44916 .4507 .45378 .44479 .4405 Mtetra
.765 .648 .733 r
.44479 .4405 .4507 .45378 .46149 .43869 .45554 .42868 Mtetra
.483 .571 .868 r
.45554 .42868 .46149 .43869 .47205 .43649 .46605 .42968 Mtetra
.632 .73 .919 r
.46605 .42968 .47205 .43649 .48266 .43338 .47668 .4268 Mtetra
.647 .744 .92 r
.47668 .4268 .48266 .43338 .49332 .43005 .48737 .42352 Mtetra
.652 .748 .92 r
.48737 .42352 .49332 .43005 .50403 .4266 .4981 .42009 Mtetra
.655 .751 .92 r
.4981 .42009 .50403 .4266 .51477 .42308 .50887 .41657 Mtetra
.657 .752 .92 r
.50887 .41657 .51477 .42308 .52556 .4195 .51969 .41298 Mtetra
.658 .753 .92 r
.51969 .41298 .52556 .4195 .53639 .41589 .53055 .40935 Mtetra
.659 .754 .92 r
.53055 .40935 .53639 .41589 .54727 .41225 .54145 .40569 Mtetra
.54145 .40569 .54727 .41225 .55818 .4086 .55239 .40201 Mtetra
.55239 .40201 .55818 .4086 .56914 .40494 .56338 .39832 Mtetra
.56338 .39832 .56914 .40494 .58014 .40127 .57441 .39463 Mtetra
.658 .753 .92 r
.57441 .39463 .58014 .40127 .59119 .39759 .58548 .39092 Mtetra
.58548 .39092 .59119 .39759 .60227 .39391 .5966 .3872 Mtetra
.5966 .3872 .60227 .39391 .61341 .39021 .60776 .38348 Mtetra
.60776 .38348 .61341 .39021 .62458 .38651 .61897 .37975 Mtetra
.61897 .37975 .62458 .38651 .6358 .38279 .63022 .376 Mtetra
.63022 .376 .6358 .38279 .64707 .37906 .64152 .37224 Mtetra
.657 .753 .92 r
.64152 .37224 .64707 .37906 .65838 .37532 .65286 .36847 Mtetra
.65286 .36847 .65838 .37532 .66974 .37156 .66425 .36468 Mtetra
.66425 .36468 .66974 .37156 .68114 .36779 .67568 .36088 Mtetra
.67568 .36088 .68114 .36779 .69259 .364 .68716 .35707 Mtetra
.657 .752 .92 r
.68716 .35707 .69259 .364 .70408 .36021 .69869 .35324 Mtetra
.69869 .35324 .70408 .36021 .71562 .35639 .71026 .3494 Mtetra
.71026 .3494 .71562 .35639 .72721 .35257 .72188 .34555 Mtetra
.72188 .34555 .72721 .35257 .73884 .34873 .73355 .34168 Mtetra
.73355 .34168 .73884 .34873 .75053 .34487 .74527 .33779 Mtetra
.74527 .33779 .75053 .34487 .76226 .341 .75703 .33389 Mtetra
.75703 .33389 .76226 .341 .77403 .33711 .76884 .32997 Mtetra
.76884 .32997 .77403 .33711 .78586 .33321 .7807 .32604 Mtetra
.7807 .32604 .78586 .33321 .79773 .3293 .79261 .3221 Mtetra
.79261 .3221 .79773 .3293 .80966 .32536 .80457 .31813 Mtetra
.80457 .31813 .80966 .32536 .82163 .32142 .81658 .31416 Mtetra
.81658 .31416 .82163 .32142 .83365 .31745 .82864 .31016 Mtetra
.581 .698 .923 r
.18687 .51355 .19346 .52028 .20289 .51895 .19633 .51204 Mtetra
.421 .627 .939 r
.19633 .51204 .20289 .51895 .21392 .50105 .2056 .51296 Mtetra
0 0 0 r
.2056 .51296 .21392 .50105 .22246 .51 .21598 .50261 Mtetra
.555 .669 .913 r
.21598 .50261 .22246 .51 .23204 .50827 .2255 .50167 Mtetra
.586 .707 .927 r
.2255 .50167 .23204 .50827 .24155 .50797 .23514 .5 Mtetra
.931 .699 .566 r
.23514 .5 .24155 .50797 .2519 .49808 .25435 .38541 Mtetra
0 0 .265 r
.25435 .38541 .2519 .49808 .26149 .49765 .25502 .49083 Mtetra
.594 .705 .92 r
.25502 .49083 .26149 .49765 .27126 .49561 .26479 .48899 Mtetra
.589 .71 .927 r
.26479 .48899 .27126 .49561 .28092 .4957 .2746 .48723 Mtetra
.888 .719 .667 r
.2746 .48723 .28092 .4957 .29136 .48552 .28642 .45849 Mtetra
.015 .055 .558 r
.28642 .45849 .29136 .48552 .30116 .48458 .29477 .47777 Mtetra
.604 .711 .92 r
.29477 .47777 .30116 .48458 .31111 .48226 .30472 .47569 Mtetra
.611 .722 .924 r
.30472 .47569 .31111 .48226 .32106 .4806 .31472 .47342 Mtetra
.355 .588 .932 r
.31472 .47342 .32106 .4806 .33176 .467 .32452 .47529 Mtetra
0 0 0 r
.32452 .47529 .33176 .467 .34147 .47077 .33518 .46343 Mtetra
.584 .689 .914 r
.33518 .46343 .34147 .47077 .35158 .4684 .34527 .4618 Mtetra
.625 .729 .921 r
.34527 .4618 .35158 .4684 .36175 .46576 .35546 .45917 Mtetra
.62 .728 .923 r
.35546 .45917 .36175 .46576 .37193 .46377 .36569 .45664 Mtetra
.461 .644 .937 r
.36569 .45664 .37193 .46377 .38287 .44551 .37583 .4571 Mtetra
0 0 0 r
.37583 .4571 .38287 .44551 .39269 .45371 .38651 .44609 Mtetra
.579 .681 .91 r
.38651 .44609 .39269 .45371 .40301 .45122 .39682 .44456 Mtetra
.632 .732 .92 r
.39682 .44456 .40301 .45122 .4134 .44826 .40722 .44171 Mtetra
.64 .739 .921 r
.40722 .44171 .4134 .44826 .42383 .44522 .41768 .43865 Mtetra
.639 .739 .921 r
.41768 .43865 .42383 .44522 .4343 .44231 .42817 .43561 Mtetra
.623 .73 .924 r
.42817 .43561 .4343 .44231 .44479 .4405 .43871 .43295 Mtetra
.147 .455 .884 r
.43871 .43295 .44479 .4405 .45554 .42868 .44911 .43754 Mtetra
.583 .812 .419 r
.44911 .43754 .45554 .42868 .46605 .42968 .46001 .42234 Mtetra
.606 .705 .914 r
.46001 .42234 .46605 .42968 .47668 .4268 .47066 .42008 Mtetra
.642 .739 .92 r
.47066 .42008 .47668 .4268 .48737 .42352 .48137 .41691 Mtetra
.65 .746 .92 r
.48137 .41691 .48737 .42352 .4981 .42009 .49213 .41351 Mtetra
.654 .75 .92 r
.49213 .41351 .4981 .42009 .50887 .41657 .50293 .41 Mtetra
.656 .751 .92 r
.50293 .41 .50887 .41657 .51969 .41298 .51377 .40641 Mtetra
.658 .753 .92 r
.51377 .40641 .51969 .41298 .53055 .40935 .52466 .40277 Mtetra
.659 .753 .92 r
.52466 .40277 .53055 .40935 .54145 .40569 .53559 .39909 Mtetra
.659 .754 .92 r
.53559 .39909 .54145 .40569 .55239 .40201 .54656 .39538 Mtetra
.54656 .39538 .55239 .40201 .56338 .39832 .55758 .39166 Mtetra
.55758 .39166 .56338 .39832 .57441 .39463 .56864 .38793 Mtetra
.658 .754 .92 r
.56864 .38793 .57441 .39463 .58548 .39092 .57974 .3842 Mtetra
.658 .753 .92 r
.57974 .3842 .58548 .39092 .5966 .3872 .59089 .38045 Mtetra
.59089 .38045 .5966 .3872 .60776 .38348 .60208 .3767 Mtetra
.60208 .3767 .60776 .38348 .61897 .37975 .61332 .37293 Mtetra
.61332 .37293 .61897 .37975 .63022 .376 .6246 .36916 Mtetra
.6246 .36916 .63022 .376 .64152 .37224 .63593 .36537 Mtetra
.63593 .36537 .64152 .37224 .65286 .36847 .6473 .36157 Mtetra
.657 .753 .92 r
.6473 .36157 .65286 .36847 .66425 .36468 .65872 .35775 Mtetra
.65872 .35775 .66425 .36468 .67568 .36088 .67019 .35393 Mtetra
.67019 .35393 .67568 .36088 .68716 .35707 .6817 .35008 Mtetra
.6817 .35008 .68716 .35707 .69869 .35324 .69326 .34623 Mtetra
.657 .752 .92 r
.69326 .34623 .69869 .35324 .71026 .3494 .70486 .34236 Mtetra
.70486 .34236 .71026 .3494 .72188 .34555 .71652 .33847 Mtetra
.71652 .33847 .72188 .34555 .73355 .34168 .72822 .33457 Mtetra
.72822 .33457 .73355 .34168 .74527 .33779 .73997 .33066 Mtetra
.73997 .33066 .74527 .33779 .75703 .33389 .75177 .32673 Mtetra
.75177 .32673 .75703 .33389 .76884 .32997 .76361 .32278 Mtetra
.76361 .32278 .76884 .32997 .7807 .32604 .77551 .31882 Mtetra
.77551 .31882 .7807 .32604 .79261 .3221 .78745 .31484 Mtetra
.78745 .31484 .79261 .3221 .80457 .31813 .79945 .31085 Mtetra
.79945 .31085 .80457 .31813 .81658 .31416 .81149 .30684 Mtetra
.81149 .30684 .81658 .31416 .82864 .31016 .82358 .30281 Mtetra
.53 .648 .909 r
.18033 .50581 .18687 .51355 .19633 .51204 .18969 .50537 Mtetra
.571 .699 .928 r
.18969 .50537 .19633 .51204 .2056 .51296 .1992 .50399 Mtetra
.843 .709 .716 r
.1992 .50399 .2056 .51296 .21598 .50261 .21033 .48598 Mtetra
.165 .251 .707 r
.21033 .48598 .21598 .50261 .2255 .50167 .21893 .49492 Mtetra
.591 .705 .922 r
.21893 .49492 .2255 .50167 .23514 .5 .22859 .49314 Mtetra
.51 .671 .936 r
.22859 .49314 .23514 .5 .25435 .38541 .23817 .49279 Mtetra
.487 .245 .473 r
.23817 .49279 .25435 .38541 .25502 .49083 .24861 .48282 Mtetra
.533 .644 .905 r
.24861 .48282 .25502 .49083 .26479 .48899 .25828 .48234 Mtetra
.604 .716 .923 r
.25828 .48234 .26479 .48899 .2746 .48723 .26813 .48025 Mtetra
.484 .658 .938 r
.26813 .48025 .2746 .48723 .28642 .45849 .27786 .4803 Mtetra
.224 0 .208 r
.27786 .4803 .28642 .45849 .29477 .47777 .28839 .47003 Mtetra
.556 .664 .909 r
.28839 .47003 .29477 .47777 .30472 .47569 .29828 .46904 Mtetra
.615 .722 .922 r
.29828 .46904 .30472 .47569 .31472 .47342 .30831 .46667 Mtetra
.583 .708 .929 r
.30831 .46667 .31472 .47342 .32452 .47529 .31835 .46495 Mtetra
.808 .694 .74 r
.31835 .46495 .32452 .47529 .33518 .46343 .32915 .45125 Mtetra
.369 .458 .821 r
.32915 .45125 .33518 .46343 .34527 .4618 .33893 .45499 Mtetra
.616 .72 .92 r
.33893 .45499 .34527 .4618 .35546 .45917 .34913 .45256 Mtetra
.626 .731 .922 r
.34913 .45256 .35546 .45917 .36569 .45664 .35938 .44987 Mtetra
.597 .716 .927 r
.35938 .44987 .36569 .45664 .37583 .4571 .36965 .44781 Mtetra
.853 .721 .716 r
.36965 .44781 .37583 .4571 .38651 .44609 .3807 .42944 Mtetra
.252 .314 .733 r
.3807 .42944 .38651 .44609 .39682 .44456 .39059 .43762 Mtetra
.619 .721 .918 r
.39059 .43762 .39682 .44456 .40722 .44171 .401 .43507 Mtetra
.638 .737 .921 r
.401 .43507 .40722 .44171 .41768 .43865 .41148 .43205 Mtetra
.64 .74 .921 r
.41148 .43205 .41768 .43865 .42817 .43561 .422 .42895 Mtetra
.634 .737 .922 r
.422 .42895 .42817 .43561 .43871 .43295 .43257 .42598 Mtetra
.586 .71 .929 r
.43257 .42598 .43871 .43295 .44911 .43754 .44315 .42412 Mtetra
.765 .649 .733 r
.44315 .42412 .44911 .43754 .46001 .42234 .454 .41219 Mtetra
.482 .57 .868 r
.454 .41219 .46001 .42234 .47066 .42008 .4646 .41314 Mtetra
.632 .73 .919 r
.4646 .41314 .47066 .42008 .48137 .41691 .47533 .4102 Mtetra
.647 .744 .92 r
.47533 .4102 .48137 .41691 .49213 .41351 .48611 .40686 Mtetra
.652 .748 .92 r
.48611 .40686 .49213 .41351 .50293 .41 .49694 .40336 Mtetra
.655 .751 .92 r
.49694 .40336 .50293 .41 .51377 .40641 .50781 .39977 Mtetra
.657 .752 .92 r
.50781 .39977 .51377 .40641 .52466 .40277 .51873 .39612 Mtetra
.658 .753 .92 r
.51873 .39612 .52466 .40277 .53559 .39909 .52969 .39243 Mtetra
.659 .754 .92 r
.52969 .39243 .53559 .39909 .54656 .39538 .54069 .3887 Mtetra
.54069 .3887 .54656 .39538 .55758 .39166 .55173 .38495 Mtetra
.55173 .38495 .55758 .39166 .56864 .38793 .56282 .38119 Mtetra
.56282 .38119 .56864 .38793 .57974 .3842 .57396 .37743 Mtetra
.658 .753 .92 r
.57396 .37743 .57974 .3842 .59089 .38045 .58513 .37365 Mtetra
.58513 .37365 .59089 .38045 .60208 .3767 .59636 .36987 Mtetra
.59636 .36987 .60208 .3767 .61332 .37293 .60762 .36607 Mtetra
.60762 .36607 .61332 .37293 .6246 .36916 .61894 .36227 Mtetra
.61894 .36227 .6246 .36916 .63593 .36537 .6303 .35845 Mtetra
.6303 .35845 .63593 .36537 .6473 .36157 .6417 .35462 Mtetra
.657 .753 .92 r
.6417 .35462 .6473 .36157 .65872 .35775 .65315 .35077 Mtetra
.65315 .35077 .65872 .35775 .67019 .35393 .66465 .34692 Mtetra
.66465 .34692 .67019 .35393 .6817 .35008 .67619 .34304 Mtetra
.67619 .34304 .6817 .35008 .69326 .34623 .68779 .33916 Mtetra
.657 .752 .92 r
.68779 .33916 .69326 .34623 .70486 .34236 .69942 .33526 Mtetra
.69942 .33526 .70486 .34236 .71652 .33847 .71111 .33134 Mtetra
.71111 .33134 .71652 .33847 .72822 .33457 .72285 .32741 Mtetra
.72285 .32741 .72822 .33457 .73997 .33066 .73463 .32347 Mtetra
.73463 .32347 .73997 .33066 .75177 .32673 .74646 .31951 Mtetra
.74646 .31951 .75177 .32673 .76361 .32278 .75834 .31553 Mtetra
.75834 .31553 .76361 .32278 .77551 .31882 .77027 .31154 Mtetra
.77027 .31154 .77551 .31882 .78745 .31484 .78225 .30753 Mtetra
.78225 .30753 .78745 .31484 .79945 .31085 .79428 .30351 Mtetra
.79428 .30351 .79945 .31085 .81149 .30684 .80636 .29947 Mtetra
.80636 .29947 .81149 .30684 .82358 .30281 .81849 .29541 Mtetra
0 0 .35 r
.17795 .45837 .18033 .50581 .18969 .50537 .18303 .49853 Mtetra
.58 .698 .923 r
.18303 .49853 .18969 .50537 .1992 .50399 .19256 .49697 Mtetra
.422 .627 .938 r
.19256 .49697 .1992 .50399 .21033 .48598 .20191 .49785 Mtetra
0 0 0 r
.20191 .49785 .21033 .48598 .21893 .49492 .21238 .48742 Mtetra
.554 .669 .914 r
.21238 .48742 .21893 .49492 .22859 .49314 .22198 .48643 Mtetra
.586 .707 .927 r
.22198 .48643 .22859 .49314 .23817 .49279 .23169 .48471 Mtetra
.932 .7 .564 r
.23169 .48471 .23817 .49279 .24861 .48282 .25117 .36962 Mtetra
0 0 .259 r
.25117 .36962 .24861 .48282 .25828 .48234 .25174 .47541 Mtetra
.594 .705 .92 r
.25174 .47541 .25828 .48234 .26813 .48025 .26159 .47352 Mtetra
.589 .71 .927 r
.26159 .47352 .26813 .48025 .27786 .4803 .27148 .4717 Mtetra
.889 .72 .666 r
.27148 .4717 .27786 .4803 .28839 .47003 .28342 .4428 Mtetra
.009 .051 .556 r
.28342 .4428 .28839 .47003 .29828 .46904 .29182 .46212 Mtetra
.604 .711 .92 r
.29182 .46212 .29828 .46904 .30831 .46667 .30185 .45998 Mtetra
.611 .722 .924 r
.30185 .45998 .30831 .46667 .31835 .46495 .31194 .45766 Mtetra
.357 .589 .932 r
.31194 .45766 .31835 .46495 .32915 .45125 .32182 .45949 Mtetra
0 0 0 r
.32182 .45949 .32915 .45125 .33893 .45499 .33258 .44753 Mtetra
.584 .689 .914 r
.33258 .44753 .33893 .45499 .34913 .45256 .34275 .44585 Mtetra
.625 .729 .921 r
.34275 .44585 .34913 .45256 .35938 .44987 .35303 .44316 Mtetra
.62 .728 .923 r
.35303 .44316 .35938 .44987 .36965 .44781 .36335 .44057 Mtetra
.461 .645 .937 r
.36335 .44057 .36965 .44781 .3807 .42944 .37357 .44099 Mtetra
0 0 0 r
.37357 .44099 .3807 .42944 .39059 .43762 .38435 .42988 Mtetra
.579 .681 .91 r
.38435 .42988 .39059 .43762 .401 .43507 .39475 .42829 Mtetra
.632 .732 .92 r
.39475 .42829 .401 .43507 .41148 .43205 .40524 .42538 Mtetra
.64 .739 .921 r
.40524 .42538 .41148 .43205 .422 .42895 .41579 .42226 Mtetra
.639 .739 .921 r
.41579 .42226 .422 .42895 .43257 .42598 .42638 .41916 Mtetra
.623 .73 .924 r
.42638 .41916 .43257 .42598 .44315 .42412 .43701 .41643 Mtetra
.151 .456 .885 r
.43701 .41643 .44315 .42412 .454 .41219 .4475 .421 Mtetra
.593 .82 .43 r
.4475 .421 .454 .41219 .4646 .41314 .45851 .40568 Mtetra
.606 .705 .914 r
.45851 .40568 .4646 .41314 .47533 .4102 .46925 .40336 Mtetra
.642 .739 .92 r
.46925 .40336 .47533 .4102 .48611 .40686 .48006 .40013 Mtetra
.65 .746 .92 r
.48006 .40013 .48611 .40686 .49694 .40336 .49091 .39666 Mtetra
.654 .75 .92 r
.49091 .39666 .49694 .40336 .50781 .39977 .50181 .39308 Mtetra
.656 .751 .92 r
.50181 .39308 .50781 .39977 .51873 .39612 .51275 .38943 Mtetra
.658 .753 .92 r
.51275 .38943 .51873 .39612 .52969 .39243 .52374 .38572 Mtetra
.659 .753 .92 r
.52374 .38572 .52969 .39243 .54069 .3887 .53477 .38197 Mtetra
.659 .754 .92 r
.53477 .38197 .54069 .3887 .55173 .38495 .54585 .37819 Mtetra
.54585 .37819 .55173 .38495 .56282 .38119 .55696 .3744 Mtetra
.55696 .3744 .56282 .38119 .57396 .37743 .56813 .37061 Mtetra
.658 .754 .92 r
.56813 .37061 .57396 .37743 .58513 .37365 .57934 .3668 Mtetra
.658 .753 .92 r
.57934 .3668 .58513 .37365 .59636 .36987 .59059 .36298 Mtetra
.59059 .36298 .59636 .36987 .60762 .36607 .60189 .35916 Mtetra
.60189 .35916 .60762 .36607 .61894 .36227 .61323 .35532 Mtetra
.61323 .35532 .61894 .36227 .6303 .35845 .62462 .35148 Mtetra
.62462 .35148 .6303 .35845 .6417 .35462 .63606 .34762 Mtetra
.63606 .34762 .6417 .35462 .65315 .35077 .64754 .34374 Mtetra
.657 .753 .92 r
.64754 .34374 .65315 .35077 .66465 .34692 .65907 .33985 Mtetra
.65907 .33985 .66465 .34692 .67619 .34304 .67065 .33595 Mtetra
.67065 .33595 .67619 .34304 .68779 .33916 .68227 .33204 Mtetra
.68227 .33204 .68779 .33916 .69942 .33526 .69394 .32811 Mtetra
.657 .752 .92 r
.69394 .32811 .69942 .33526 .71111 .33134 .70566 .32416 Mtetra
.70566 .32416 .71111 .33134 .72285 .32741 .71743 .3202 Mtetra
.71743 .3202 .72285 .32741 .73463 .32347 .72925 .31622 Mtetra
.72925 .31622 .73463 .32347 .74646 .31951 .74111 .31223 Mtetra
.74111 .31223 .74646 .31951 .75834 .31553 .75303 .30823 Mtetra
.75303 .30823 .75834 .31553 .77027 .31154 .76499 .3042 Mtetra
.76499 .3042 .77027 .31154 .78225 .30753 .77701 .30016 Mtetra
.77701 .30016 .78225 .30753 .79428 .30351 .78907 .29611 Mtetra
.78907 .29611 .79428 .30351 .80636 .29947 .80119 .29204 Mtetra
.80119 .29204 .80636 .29947 .81849 .29541 .81336 .28795 Mtetra
.39 .116 .373 r
.16603 .50053 .17795 .45837 .18303 .49853 .17642 .49068 Mtetra
.529 .648 .909 r
.17642 .49068 .18303 .49853 .19256 .49697 .18586 .4902 Mtetra
.571 .699 .928 r
.18586 .4902 .19256 .49697 .20191 .49785 .19544 .48877 Mtetra
.844 .71 .716 r
.19544 .48877 .20191 .49785 .21238 .48742 .20668 .47064 Mtetra
.162 .248 .706 r
.20668 .47064 .21238 .48742 .22198 .48643 .21533 .47957 Mtetra
.591 .705 .922 r
.21533 .47957 .22198 .48643 .23169 .48471 .22507 .47774 Mtetra
.51 .671 .936 r
.22507 .47774 .23169 .48471 .25117 .36962 .23473 .47735 Mtetra
.483 .24 .469 r
.23473 .47735 .25117 .36962 .25174 .47541 .24526 .46729 Mtetra
.533 .644 .905 r
.24526 .46729 .25174 .47541 .26159 .47352 .25501 .46676 Mtetra
.604 .716 .923 r
.25501 .46676 .26159 .47352 .27148 .4717 .26494 .46462 Mtetra
.485 .658 .937 r
.26494 .46462 .27148 .4717 .28342 .4428 .27475 .46462 Mtetra
.213 0 .198 r
.27475 .46462 .28342 .4428 .29182 .46212 .28538 .45426 Mtetra
.556 .664 .909 r
.28538 .45426 .29182 .46212 .30185 .45998 .29535 .45322 Mtetra
.615 .722 .922 r
.29535 .45322 .30185 .45998 .31194 .45766 .30546 .45079 Mtetra
.583 .708 .928 r
.30546 .45079 .31194 .45766 .32182 .45949 .31558 .44902 Mtetra
.808 .695 .74 r
.31558 .44902 .32182 .45949 .33258 .44753 .32648 .43522 Mtetra
.368 .457 .821 r
.32648 .43522 .33258 .44753 .34275 .44585 .33634 .43892 Mtetra
.616 .72 .92 r
.33634 .43892 .34275 .44585 .35303 .44316 .34663 .43643 Mtetra
.626 .731 .922 r
.34663 .43643 .35303 .44316 .36335 .44057 .35697 .43368 Mtetra
.597 .716 .927 r
.35697 .43368 .36335 .44057 .37357 .44099 .36733 .43157 Mtetra
.854 .722 .716 r
.36733 .43157 .37357 .44099 .38435 .42988 .37848 .41307 Mtetra
.249 .312 .732 r
.37848 .41307 .38435 .42988 .39475 .42829 .38845 .42124 Mtetra
.619 .721 .918 r
.38845 .42124 .39475 .42829 .40524 .42538 .39896 .41862 Mtetra
.638 .737 .921 r
.39896 .41862 .40524 .42538 .41579 .42226 .40953 .41554 Mtetra
.64 .74 .921 r
.40953 .41554 .41579 .42226 .42638 .41916 .42015 .41237 Mtetra
.634 .737 .922 r
.42015 .41237 .42638 .41916 .43701 .41643 .4308 .40935 Mtetra
.586 .71 .928 r
.4308 .40935 .43701 .41643 .4475 .421 .44148 .40742 Mtetra
.766 .649 .733 r
.44148 .40742 .4475 .421 .45851 .40568 .45243 .3954 Mtetra
.482 .57 .868 r
.45243 .3954 .45851 .40568 .46925 .40336 .46313 .3963 Mtetra
.632 .73 .919 r
.46313 .3963 .46925 .40336 .48006 .40013 .47395 .3933 Mtetra
.647 .744 .92 r
.47395 .3933 .48006 .40013 .49091 .39666 .48483 .38988 Mtetra
.652 .748 .92 r
.48483 .38988 .49091 .39666 .50181 .39308 .49576 .38632 Mtetra
.655 .751 .92 r
.49576 .38632 .50181 .39308 .51275 .38943 .50673 .38267 Mtetra
.657 .752 .92 r
.50673 .38267 .51275 .38943 .52374 .38572 .51775 .37895 Mtetra
.658 .753 .92 r
.51775 .37895 .52374 .38572 .53477 .38197 .52881 .37518 Mtetra
.659 .754 .92 r
.52881 .37518 .53477 .38197 .54585 .37819 .53991 .37138 Mtetra
.53991 .37138 .54585 .37819 .55696 .3744 .55106 .36757 Mtetra
.55106 .36757 .55696 .3744 .56813 .37061 .56226 .36374 Mtetra
.56226 .36374 .56813 .37061 .57934 .3668 .57349 .3599 Mtetra
.658 .753 .92 r
.57349 .3599 .57934 .3668 .59059 .36298 .58478 .35605 Mtetra
.58478 .35605 .59059 .36298 .60189 .35916 .59611 .3522 Mtetra
.59611 .3522 .60189 .35916 .61323 .35532 .60748 .34833 Mtetra
.60748 .34833 .61323 .35532 .62462 .35148 .6189 .34445 Mtetra
.6189 .34445 .62462 .35148 .63606 .34762 .63037 .34056 Mtetra
.63037 .34056 .63606 .34762 .64754 .34374 .64189 .33666 Mtetra
.657 .753 .92 r
.64189 .33666 .64754 .34374 .65907 .33985 .65345 .33274 Mtetra
.65345 .33274 .65907 .33985 .67065 .33595 .66506 .32881 Mtetra
.66506 .32881 .67065 .33595 .68227 .33204 .67671 .32486 Mtetra
.67671 .32486 .68227 .33204 .69394 .32811 .68842 .3209 Mtetra
.657 .752 .92 r
.68842 .3209 .69394 .32811 .70566 .32416 .70017 .31692 Mtetra
.70017 .31692 .70566 .32416 .71743 .3202 .71198 .31293 Mtetra
.71198 .31293 .71743 .3202 .72925 .31622 .72383 .30892 Mtetra
.72383 .30892 .72925 .31622 .74111 .31223 .73573 .3049 Mtetra
.73573 .3049 .74111 .31223 .75303 .30823 .74768 .30086 Mtetra
.74768 .30086 .75303 .30823 .76499 .3042 .75968 .29681 Mtetra
.75968 .29681 .76499 .3042 .77701 .30016 .77173 .29274 Mtetra
.77173 .29274 .77701 .30016 .78907 .29611 .78383 .28865 Mtetra
.78383 .28865 .78907 .29611 .80119 .29204 .79598 .28455 Mtetra
.79598 .28455 .80119 .29204 .81336 .28795 .80818 .28043 Mtetra
.906 .707 .622 r
.1594 .49222 .16603 .50053 .17642 .49068 .17406 .44296 Mtetra
0 0 .344 r
.17406 .44296 .17642 .49068 .18586 .4902 .17912 .48325 Mtetra
.58 .698 .923 r
.17912 .48325 .18586 .4902 .19544 .48877 .18873 .48164 Mtetra
.423 .627 .938 r
.18873 .48164 .19544 .48877 .20668 .47064 .19815 .48248 Mtetra
0 0 0 r
.19815 .48248 .20668 .47064 .21533 .47957 .20871 .47196 Mtetra
.554 .669 .914 r
.20871 .47196 .21533 .47957 .22507 .47774 .21839 .47092 Mtetra
.586 .707 .927 r
.21839 .47092 .22507 .47774 .23473 .47735 .22818 .46915 Mtetra
.933 .7 .563 r
.22818 .46915 .23473 .47735 .24526 .46729 .24795 .35356 Mtetra
0 0 .253 r
.24795 .35356 .24526 .46729 .25501 .46676 .2484 .45972 Mtetra
.594 .705 .92 r
.2484 .45972 .25501 .46676 .26494 .46462 .25833 .45777 Mtetra
.589 .71 .927 r
.25833 .45777 .26494 .46462 .27475 .46462 .2683 .4559 Mtetra
.89 .721 .666 r
.2683 .4559 .27475 .46462 .28538 .45426 .28037 .42683 Mtetra
.004 .046 .553 r
.28037 .42683 .28538 .45426 .29535 .45322 .28882 .44619 Mtetra
.604 .711 .92 r
.28882 .44619 .29535 .45322 .30546 .45079 .29893 .44399 Mtetra
.611 .722 .924 r
.29893 .44399 .30546 .45079 .31558 .44902 .30911 .44161 Mtetra
.358 .589 .932 r
.30911 .44161 .31558 .44902 .32648 .43522 .31907 .4434 Mtetra
.53 .819 .478 r
.31907 .4434 .32648 .43522 .33634 .43892 .32993 .43134 Mtetra
.584 .689 .914 r
.32993 .43134 .33634 .43892 .34663 .43643 .34019 .42961 Mtetra
.625 .729 .921 r
.34019 .42961 .34663 .43643 .35697 .43368 .35055 .42686 Mtetra
.62 .728 .923 r
.35055 .42686 .35697 .43368 .36733 .43157 .36096 .42421 Mtetra
.462 .645 .937 r
.36096 .42421 .36733 .43157 .37848 .41307 .37127 .42458 Mtetra
0 0 0 r
.37127 .42458 .37848 .41307 .38845 .42124 .38215 .41338 Mtetra
.579 .681 .91 r
.38215 .41338 .38845 .42124 .39896 .41862 .39264 .41172 Mtetra
.632 .732 .92 r
.39264 .41172 .39896 .41862 .40953 .41554 .40323 .40875 Mtetra
.64 .739 .921 r
.40323 .40875 .40953 .41554 .42015 .41237 .41387 .40557 Mtetra
.639 .739 .921 r
.41387 .40557 .42015 .41237 .4308 .40935 .42455 .4024 Mtetra
.623 .73 .924 r
.42455 .4024 .4308 .40935 .44148 .40742 .43527 .39961 Mtetra
.154 .458 .886 r
.43527 .39961 .44148 .40742 .45243 .3954 .44586 .40414 Mtetra
.603 .828 .44 r
.44586 .40414 .45243 .3954 .46313 .3963 .45697 .38871 Mtetra
.606 .705 .914 r
.45697 .38871 .46313 .3963 .47395 .3933 .46781 .38633 Mtetra
.642 .739 .92 r
.46781 .38633 .47395 .3933 .48483 .38988 .47871 .38303 Mtetra
.65 .746 .92 r
.47871 .38303 .48483 .38988 .49576 .38632 .48967 .37949 Mtetra
.654 .75 .92 r
.48967 .37949 .49576 .38632 .50673 .38267 .50067 .37584 Mtetra
.656 .751 .92 r
.50067 .37584 .50673 .38267 .51775 .37895 .51171 .37212 Mtetra
.658 .753 .92 r
.51171 .37212 .51775 .37895 .52881 .37518 .5228 .36834 Mtetra
.659 .753 .92 r
.5228 .36834 .52881 .37518 .53991 .37138 .53394 .36452 Mtetra
.659 .754 .92 r
.53394 .36452 .53991 .37138 .55106 .36757 .54512 .36068 Mtetra
.54512 .36068 .55106 .36757 .56226 .36374 .55634 .35682 Mtetra
.55634 .35682 .56226 .36374 .57349 .3599 .56761 .35295 Mtetra
.658 .754 .92 r
.56761 .35295 .57349 .3599 .58478 .35605 .57892 .34907 Mtetra
.658 .753 .92 r
.57892 .34907 .58478 .35605 .59611 .3522 .59028 .34518 Mtetra
.59028 .34518 .59611 .3522 .60748 .34833 .60169 .34128 Mtetra
.60169 .34128 .60748 .34833 .6189 .34445 .61314 .33737 Mtetra
.61314 .33737 .6189 .34445 .63037 .34056 .62464 .33345 Mtetra
.62464 .33345 .63037 .34056 .64189 .33666 .63619 .32952 Mtetra
.63619 .32952 .64189 .33666 .65345 .33274 .64778 .32557 Mtetra
.657 .753 .92 r
.64778 .32557 .65345 .33274 .66506 .32881 .65942 .32161 Mtetra
.65942 .32161 .66506 .32881 .67671 .32486 .67111 .31763 Mtetra
.67111 .31763 .67671 .32486 .68842 .3209 .68285 .31364 Mtetra
.68285 .31364 .68842 .3209 .70017 .31692 .69464 .30963 Mtetra
.657 .752 .92 r
.69464 .30963 .70017 .31692 .71198 .31293 .70648 .30561 Mtetra
.70648 .30561 .71198 .31293 .72383 .30892 .71836 .30157 Mtetra
.71836 .30157 .72383 .30892 .73573 .3049 .7303 .29752 Mtetra
.7303 .29752 .73573 .3049 .74768 .30086 .74228 .29345 Mtetra
.74228 .29345 .74768 .30086 .75968 .29681 .75432 .28936 Mtetra
.75432 .28936 .75968 .29681 .77173 .29274 .7664 .28526 Mtetra
.7664 .28526 .77173 .29274 .78383 .28865 .77854 .28114 Mtetra
.77854 .28114 .78383 .28865 .79598 .28455 .79073 .277 Mtetra
.79073 .277 .79598 .28455 .80818 .28043 .80297 .27285 Mtetra
.479 .655 .938 r
.15259 .48517 .1594 .49222 .17406 .44296 .16196 .48522 Mtetra
.384 .108 .366 r
.16196 .48522 .17406 .44296 .17912 .48325 .17244 .47528 Mtetra
.529 .648 .91 r
.17244 .47528 .17912 .48325 .18873 .48164 .18195 .47475 Mtetra
.571 .699 .928 r
.18195 .47475 .18873 .48164 .19815 .48248 .19161 .47328 Mtetra
.844 .711 .716 r
.19161 .47328 .19815 .48248 .20871 .47196 .20296 .45502 Mtetra
.159 .246 .705 r
.20296 .45502 .20871 .47196 .21839 .47092 .21167 .46395 Mtetra
.591 .705 .922 r
.21167 .46395 .21839 .47092 .22818 .46915 .22149 .46206 Mtetra
.51 .671 .936 r
.22149 .46206 .22818 .46915 .24795 .35356 .23122 .46162 Mtetra
.479 .234 .465 r
.23122 .46162 .24795 .35356 .2484 .45972 .24185 .45147 Mtetra
.532 .644 .905 r
.24185 .45147 .2484 .45972 .25833 .45777 .25168 .4509 Mtetra
.604 .716 .923 r
.25168 .4509 .25833 .45777 .2683 .4559 .26169 .4487 Mtetra
.485 .658 .937 r
.26169 .4487 .2683 .4559 .28037 .42683 .27158 .44866 Mtetra
.203 0 .187 r
.27158 .44866 .28037 .42683 .28882 .44619 .28231 .4382 Mtetra
.555 .664 .909 r
.28231 .4382 .28882 .44619 .29893 .44399 .29236 .43711 Mtetra
.615 .722 .922 r
.29236 .43711 .29893 .44399 .30911 .44161 .30256 .43462 Mtetra
.584 .708 .928 r
.30256 .43462 .30911 .44161 .31907 .4434 .31277 .43279 Mtetra
.809 .696 .74 r
.31277 .43279 .31907 .4434 .32993 .43134 .32377 .41889 Mtetra
.367 .457 .821 r
.32377 .41889 .32993 .43134 .34019 .42961 .33371 .42255 Mtetra
.616 .72 .92 r
.33371 .42255 .34019 .42961 .35055 .42686 .34409 .42001 Mtetra
.626 .731 .922 r
.34409 .42001 .35055 .42686 .36096 .42421 .35452 .41719 Mtetra
.597 .716 .927 r
.35452 .41719 .36096 .42421 .37127 .42458 .36497 .41502 Mtetra
.855 .723 .716 r
.36497 .41502 .37127 .42458 .38215 .41338 .37623 .3964 Mtetra
.247 .31 .732 r
.37623 .3964 .38215 .41338 .39264 .41172 .38628 .40455 Mtetra
.619 .721 .919 r
.38628 .40455 .39264 .41172 .40323 .40875 .39688 .40187 Mtetra
.638 .737 .921 r
.39688 .40187 .40323 .40875 .41387 .40557 .40754 .39872 Mtetra
.64 .74 .921 r
.40754 .39872 .41387 .40557 .42455 .4024 .41825 .39549 Mtetra
.634 .737 .922 r
.41825 .39549 .42455 .4024 .43527 .39961 .42901 .3924 Mtetra
.586 .71 .928 r
.42901 .3924 .43527 .39961 .44586 .40414 .43978 .39041 Mtetra
.766 .65 .733 r
.43978 .39041 .44586 .40414 .45697 .38871 .45083 .37829 Mtetra
.481 .57 .868 r
.45083 .37829 .45697 .38871 .46781 .38633 .46162 .37914 Mtetra
.632 .73 .919 r
.46162 .37914 .46781 .38633 .47871 .38303 .47255 .37607 Mtetra
.647 .744 .92 r
.47255 .37607 .47871 .38303 .48967 .37949 .48353 .37259 Mtetra
.652 .748 .92 r
.48353 .37259 .48967 .37949 .50067 .37584 .49456 .36896 Mtetra
.655 .751 .92 r
.49456 .36896 .50067 .37584 .51171 .37212 .50563 .36523 Mtetra
.657 .752 .92 r
.50563 .36523 .51171 .37212 .5228 .36834 .51675 .36144 Mtetra
.658 .753 .92 r
.51675 .36144 .5228 .36834 .53394 .36452 .52791 .35761 Mtetra
.659 .754 .92 r
.52791 .35761 .53394 .36452 .54512 .36068 .53912 .35374 Mtetra
.53912 .35374 .54512 .36068 .55634 .35682 .55038 .34985 Mtetra
.55038 .34985 .55634 .35682 .56761 .35295 .56168 .34595 Mtetra
.56168 .34595 .56761 .35295 .57892 .34907 .57302 .34203 Mtetra
.658 .753 .92 r
.57302 .34203 .57892 .34907 .59028 .34518 .58441 .33811 Mtetra
.58441 .33811 .59028 .34518 .60169 .34128 .59585 .33418 Mtetra
.59585 .33418 .60169 .34128 .61314 .33737 .60734 .33024 Mtetra
.60734 .33024 .61314 .33737 .62464 .33345 .61887 .32629 Mtetra
.61887 .32629 .62464 .33345 .63619 .32952 .63045 .32232 Mtetra
.63045 .32232 .63619 .32952 .64778 .32557 .64207 .31835 Mtetra
.657 .753 .92 r
.64207 .31835 .64778 .32557 .65942 .32161 .65375 .31435 Mtetra
.65375 .31435 .65942 .32161 .67111 .31763 .66547 .31034 Mtetra
.66547 .31034 .67111 .31763 .68285 .31364 .67724 .30632 Mtetra
.67724 .30632 .68285 .31364 .69464 .30963 .68907 .30228 Mtetra
.657 .752 .92 r
.68907 .30228 .69464 .30963 .70648 .30561 .70094 .29823 Mtetra
.70094 .29823 .70648 .30561 .71836 .30157 .71286 .29416 Mtetra
.71286 .29416 .71836 .30157 .7303 .29752 .72483 .29007 Mtetra
.72483 .29007 .7303 .29752 .74228 .29345 .73685 .28597 Mtetra
.73685 .28597 .74228 .29345 .75432 .28936 .74892 .28185 Mtetra
.74892 .28185 .75432 .28936 .7664 .28526 .76104 .27772 Mtetra
.76104 .27772 .7664 .28526 .77854 .28114 .77321 .27357 Mtetra
.77321 .27357 .77854 .28114 .79073 .277 .78544 .2694 Mtetra
.78544 .2694 .79073 .277 .80297 .27285 .79772 .26521 Mtetra
.568 .696 .927 r
.14572 .47822 .15259 .48517 .16196 .48522 .15526 .47679 Mtetra
.908 .708 .621 r
.15526 .47679 .16196 .48522 .17244 .47528 .17009 .42729 Mtetra
0 0 .339 r
.17009 .42729 .17244 .47528 .18195 .47475 .17514 .46769 Mtetra
.58 .698 .923 r
.17514 .46769 .18195 .47475 .19161 .47328 .18483 .46603 Mtetra
.423 .627 .938 r
.18483 .46603 .19161 .47328 .20296 .45502 .19432 .46683 Mtetra
0 0 0 r
.19432 .46683 .20296 .45502 .21167 .46395 .20498 .45622 Mtetra
.554 .669 .914 r
.20498 .45622 .21167 .46395 .22149 .46206 .21473 .45513 Mtetra
.586 .707 .927 r
.21473 .45513 .22149 .46206 .23122 .46162 .22461 .4533 Mtetra
.934 .701 .561 r
.22461 .4533 .23122 .46162 .24185 .45147 .24466 .33722 Mtetra
0 0 .246 r
.24466 .33722 .24185 .45147 .25168 .4509 .245 .44374 Mtetra
.594 .705 .92 r
.245 .44374 .25168 .4509 .26169 .4487 .25501 .44174 Mtetra
.589 .71 .927 r
.25501 .44174 .26169 .4487 .27158 .44866 .26507 .43981 Mtetra
.891 .722 .665 r
.26507 .43981 .27158 .44866 .28231 .4382 .27726 .41057 Mtetra
0 .042 .551 r
.27726 .41057 .28231 .4382 .29236 .43711 .28576 .42996 Mtetra
.604 .711 .92 r
.28576 .42996 .29236 .43711 .30256 .43462 .29596 .4277 Mtetra
.611 .722 .924 r
.29596 .4277 .30256 .43462 .31277 .43279 .30622 .42526 Mtetra
.359 .589 .932 r
.30622 .42526 .31277 .43279 .32377 .41889 .31627 .42701 Mtetra
.542 .829 .49 r
.31627 .42701 .32377 .41889 .33371 .42255 .32723 .41485 Mtetra
.583 .689 .914 r
.32723 .41485 .33371 .42255 .34409 .42001 .33758 .41306 Mtetra
.625 .729 .921 r
.33758 .41306 .34409 .42001 .35452 .41719 .34803 .41025 Mtetra
.62 .728 .923 r
.34803 .41025 .35452 .41719 .36497 .41502 .35853 .40754 Mtetra
.462 .645 .937 r
.35853 .40754 .36497 .41502 .37623 .3964 .36892 .40786 Mtetra
0 0 0 r
.36892 .40786 .37623 .3964 .38628 .40455 .37991 .39656 Mtetra
.579 .681 .91 r
.37991 .39656 .38628 .40455 .39688 .40187 .39049 .39485 Mtetra
.632 .732 .92 r
.39049 .39485 .39688 .40187 .40754 .39872 .40117 .39181 Mtetra
.64 .739 .921 r
.40117 .39181 .40754 .39872 .41825 .39549 .41191 .38856 Mtetra
.639 .739 .921 r
.41191 .38856 .41825 .39549 .42901 .3924 .42269 .38533 Mtetra
.623 .73 .924 r
.42269 .38533 .42901 .3924 .43978 .39041 .43351 .38247 Mtetra
.158 .46 .886 r
.43351 .38247 .43978 .39041 .45083 .37829 .44419 .38697 Mtetra
.613 .836 .45 r
.44419 .38697 .45083 .37829 .46162 .37914 .4554 .37142 Mtetra
.606 .705 .914 r
.4554 .37142 .46162 .37914 .47255 .37607 .46634 .36898 Mtetra
.642 .739 .92 r
.46634 .36898 .47255 .37607 .48353 .37259 .47735 .3656 Mtetra
.65 .746 .92 r
.47735 .3656 .48353 .37259 .49456 .36896 .4884 .362 Mtetra
.654 .75 .92 r
.4884 .362 .49456 .36896 .50563 .36523 .49951 .35828 Mtetra
.656 .751 .92 r
.49951 .35828 .50563 .36523 .51675 .36144 .51065 .35449 Mtetra
.658 .753 .92 r
.51065 .35449 .51675 .36144 .52791 .35761 .52185 .35063 Mtetra
.659 .753 .92 r
.52185 .35063 .52791 .35761 .53912 .35374 .53309 .34674 Mtetra
.659 .754 .92 r
.53309 .34674 .53912 .35374 .55038 .34985 .54437 .34283 Mtetra
.54437 .34283 .55038 .34985 .56168 .34595 .5557 .33889 Mtetra
.5557 .33889 .56168 .34595 .57302 .34203 .56708 .33495 Mtetra
.658 .754 .92 r
.56708 .33495 .57302 .34203 .58441 .33811 .5785 .33099 Mtetra
.658 .753 .92 r
.5785 .33099 .58441 .33811 .59585 .33418 .58997 .32703 Mtetra
.58997 .32703 .59585 .33418 .60734 .33024 .60149 .32306 Mtetra
.60149 .32306 .60734 .33024 .61887 .32629 .61305 .31907 Mtetra
.61305 .31907 .61887 .32629 .63045 .32232 .62466 .31508 Mtetra
.62466 .31508 .63045 .32232 .64207 .31835 .63632 .31107 Mtetra
.63632 .31107 .64207 .31835 .65375 .31435 .64803 .30704 Mtetra
.657 .753 .92 r
.64803 .30704 .65375 .31435 .66547 .31034 .65979 .303 Mtetra
.65979 .303 .66547 .31034 .67724 .30632 .67159 .29895 Mtetra
.67159 .29895 .67724 .30632 .68907 .30228 .68345 .29488 Mtetra
.68345 .29488 .68907 .30228 .70094 .29823 .69535 .29079 Mtetra
.657 .752 .92 r
.69535 .29079 .70094 .29823 .71286 .29416 .70731 .28669 Mtetra
.70731 .28669 .71286 .29416 .72483 .29007 .71931 .28257 Mtetra
.71931 .28257 .72483 .29007 .73685 .28597 .73137 .27844 Mtetra
.73137 .27844 .73685 .28597 .74892 .28185 .74348 .27428 Mtetra
.74348 .27428 .74892 .28185 .76104 .27772 .75563 .27012 Mtetra
.75563 .27012 .76104 .27772 .77321 .27357 .76784 .26593 Mtetra
.76784 .26593 .77321 .27357 .78544 .2694 .78011 .26173 Mtetra
.78011 .26173 .78544 .2694 .79772 .26521 .79242 .25751 Mtetra
.558 .679 .92 r
.13885 .47082 .14572 .47822 .15526 .47679 .14837 .46963 Mtetra
.479 .655 .938 r
.14837 .46963 .15526 .47679 .17009 .42729 .15781 .46963 Mtetra
.377 .099 .359 r
.15781 .46963 .17009 .42729 .17514 .46769 .1684 .45961 Mtetra
.529 .648 .91 r
.1684 .45961 .17514 .46769 .18483 .46603 .17798 .45903 Mtetra
.571 .699 .928 r
.17798 .45903 .18483 .46603 .19432 .46683 .18771 .4575 Mtetra
.845 .712 .716 r
.18771 .4575 .19432 .46683 .20498 .45622 .19918 .43912 Mtetra
.156 .244 .705 r
.19918 .43912 .20498 .45622 .21473 .45513 .20794 .44804 Mtetra
.591 .705 .922 r
.20794 .44804 .21473 .45513 .22461 .4533 .21784 .4461 Mtetra
.511 .671 .936 r
.21784 .4461 .22461 .4533 .24466 .33722 .22766 .44561 Mtetra
.475 .229 .46 r
.22766 .44561 .24466 .33722 .245 .44374 .23838 .43537 Mtetra
.532 .644 .905 r
.23838 .43537 .245 .44374 .25501 .44174 .24829 .43475 Mtetra
.604 .716 .923 r
.24829 .43475 .25501 .44174 .26507 .43981 .25839 .43249 Mtetra
.486 .658 .937 r
.25839 .43249 .26507 .43981 .27726 .41057 .26836 .4324 Mtetra
.192 0 .175 r
.26836 .4324 .27726 .41057 .28576 .42996 .27918 .42185 Mtetra
.555 .664 .909 r
.27918 .42185 .28576 .42996 .29596 .4277 .28932 .4207 Mtetra
.615 .722 .922 r
.28932 .4207 .29596 .4277 .30622 .42526 .29961 .41816 Mtetra
.584 .708 .928 r
.29961 .41816 .30622 .42526 .31627 .42701 .3099 .41627 Mtetra
.809 .697 .74 r
.3099 .41627 .31627 .42701 .32723 .41485 .32101 .40225 Mtetra
.365 .456 .821 r
.32101 .40225 .32723 .41485 .33758 .41306 .33103 .40588 Mtetra
.616 .72 .92 r
.33103 .40588 .33758 .41306 .34803 .41025 .34149 .40328 Mtetra
.626 .731 .922 r
.34149 .40328 .34803 .41025 .35853 .40754 .35202 .4004 Mtetra
.598 .716 .927 r
.35202 .4004 .35853 .40754 .36892 .40786 .36256 .39817 Mtetra
.856 .724 .716 r
.36256 .39817 .36892 .40786 .37991 .39656 .37393 .37942 Mtetra
.244 .309 .732 r
.37393 .37942 .37991 .39656 .39049 .39485 .38406 .38755 Mtetra
.619 .721 .919 r
.38406 .38755 .39049 .39485 .40117 .39181 .39476 .3848 Mtetra
.638 .737 .921 r
.39476 .3848 .40117 .39181 .41191 .38856 .40552 .38159 Mtetra
.64 .74 .921 r
.40552 .38159 .41191 .38856 .42269 .38533 .41633 .37829 Mtetra
.634 .737 .922 r
.41633 .37829 .42269 .38533 .43351 .38247 .42718 .37513 Mtetra
.586 .71 .928 r
.42718 .37513 .43351 .38247 .44419 .38697 .43804 .37308 Mtetra
.767 .65 .734 r
.43804 .37308 .44419 .38697 .4554 .37142 .44921 .36085 Mtetra
.48 .57 .869 r
.44921 .36085 .4554 .37142 .46634 .36898 .46009 .36166 Mtetra
.632 .73 .919 r
.46009 .36166 .46634 .36898 .47735 .3656 .47112 .35851 Mtetra
.647 .744 .92 r
.47112 .35851 .47735 .3656 .4884 .362 .4822 .35497 Mtetra
.652 .748 .92 r
.4822 .35497 .4884 .362 .49951 .35828 .49333 .35126 Mtetra
.655 .751 .92 r
.49333 .35126 .49951 .35828 .51065 .35449 .50451 .34747 Mtetra
.657 .752 .92 r
.50451 .34747 .51065 .35449 .52185 .35063 .51573 .3436 Mtetra
.658 .753 .92 r
.51573 .3436 .52185 .35063 .53309 .34674 .527 .33969 Mtetra
.659 .754 .92 r
.527 .33969 .53309 .34674 .54437 .34283 .53832 .33575 Mtetra
.53832 .33575 .54437 .34283 .5557 .33889 .54968 .33179 Mtetra
.54968 .33179 .5557 .33889 .56708 .33495 .56109 .32781 Mtetra
.56109 .32781 .56708 .33495 .5785 .33099 .57254 .32382 Mtetra
.658 .753 .92 r
.57254 .32382 .5785 .33099 .58997 .32703 .58404 .31983 Mtetra
.58404 .31983 .58997 .32703 .60149 .32306 .59559 .31582 Mtetra
.59559 .31582 .60149 .32306 .61305 .31907 .60719 .3118 Mtetra
.60719 .3118 .61305 .31907 .62466 .31508 .61883 .30777 Mtetra
.61883 .30777 .62466 .31508 .63632 .31107 .63052 .30373 Mtetra
.63052 .30373 .63632 .31107 .64803 .30704 .64227 .29967 Mtetra
.657 .753 .92 r
.64227 .29967 .64803 .30704 .65979 .303 .65406 .2956 Mtetra
.65406 .2956 .65979 .303 .67159 .29895 .6659 .29152 Mtetra
.6659 .29152 .67159 .29895 .68345 .29488 .67779 .28741 Mtetra
.67779 .28741 .68345 .29488 .69535 .29079 .68973 .28329 Mtetra
.657 .752 .92 r
.68973 .28329 .69535 .29079 .70731 .28669 .70171 .27916 Mtetra
.70171 .27916 .70731 .28669 .71931 .28257 .71376 .27501 Mtetra
.71376 .27501 .71931 .28257 .73137 .27844 .72585 .27084 Mtetra
.72585 .27084 .73137 .27844 .74348 .27428 .73799 .26666 Mtetra
.73799 .26666 .74348 .27428 .75563 .27012 .75018 .26246 Mtetra
.75018 .26246 .75563 .27012 .76784 .26593 .76243 .25824 Mtetra
.76243 .25824 .76784 .26593 .78011 .26173 .77473 .25401 Mtetra
.77473 .25401 .78011 .26173 .79242 .25751 .78708 .24975 Mtetra
.376 .497 .854 r
.13234 .46 .13885 .47082 .14837 .46963 .14143 .46256 Mtetra
.568 .696 .927 r
.14143 .46256 .14837 .46963 .15781 .46963 .15104 .46109 Mtetra
.909 .709 .62 r
.15104 .46109 .15781 .46963 .1684 .45961 .16606 .41133 Mtetra
0 0 .334 r
.16606 .41133 .1684 .45961 .17798 .45903 .17109 .45186 Mtetra
.58 .698 .923 r
.17109 .45186 .17798 .45903 .18771 .4575 .18086 .45014 Mtetra
.424 .627 .938 r
.18086 .45014 .18771 .4575 .19918 .43912 .19042 .4509 Mtetra
0 0 0 r
.19042 .4509 .19918 .43912 .20794 .44804 .20118 .44019 Mtetra
.554 .669 .914 r
.20118 .44019 .20794 .44804 .21784 .4461 .21101 .43905 Mtetra
.586 .707 .927 r
.21101 .43905 .21784 .4461 .22766 .44561 .22097 .43717 Mtetra
.935 .701 .559 r
.22097 .43717 .22766 .44561 .23838 .43537 .24132 .32059 Mtetra
0 0 .24 r
.24132 .32059 .23838 .43537 .24829 .43475 .24154 .42747 Mtetra
.594 .705 .92 r
.24154 .42747 .24829 .43475 .25839 .43249 .25163 .42541 Mtetra
.589 .71 .927 r
.25163 .42541 .25839 .43249 .26836 .4324 .26177 .42342 Mtetra
.892 .723 .664 r
.26177 .42342 .26836 .4324 .27918 .42185 .2741 .39402 Mtetra
0 .038 .549 r
.2741 .39402 .27918 .42185 .28932 .4207 .28265 .41343 Mtetra
.604 .711 .92 r
.28265 .41343 .28932 .4207 .29961 .41816 .29294 .41111 Mtetra
.611 .722 .924 r
.29294 .41111 .29961 .41816 .3099 .41627 .30329 .40862 Mtetra
.361 .59 .932 r
.30329 .40862 .3099 .41627 .32101 .40225 .31341 .41031 Mtetra
.555 .839 .502 r
.31341 .41031 .32101 .40225 .33103 .40588 .32448 .39806 Mtetra
.583 .689 .914 r
.32448 .39806 .33103 .40588 .34149 .40328 .33491 .3962 Mtetra
.625 .729 .921 r
.33491 .3962 .34149 .40328 .35202 .4004 .34546 .39333 Mtetra
.62 .728 .923 r
.34546 .39333 .35202 .4004 .36256 .39817 .35605 .39056 Mtetra
.463 .645 .936 r
.35605 .39056 .36256 .39817 .37393 .37942 .36654 .39082 Mtetra
0 0 0 r
.36654 .39082 .37393 .37942 .38406 .38755 .37763 .37942 Mtetra
.579 .681 .91 r
.37763 .37942 .38406 .38755 .39476 .3848 .3883 .37765 Mtetra
.632 .732 .92 r
.3883 .37765 .39476 .3848 .40552 .38159 .39908 .37455 Mtetra
.64 .739 .921 r
.39908 .37455 .40552 .38159 .41633 .37829 .40991 .37123 Mtetra
.639 .739 .921 r
.40991 .37123 .41633 .37829 .42718 .37513 .42079 .36793 Mtetra
.623 .73 .924 r
.42079 .36793 .42718 .37513 .43804 .37308 .43171 .36501 Mtetra
.161 .461 .887 r
.43171 .36501 .43804 .37308 .44921 .36085 .44248 .36947 Mtetra
.623 .844 .46 r
.44248 .36947 .44921 .36085 .46009 .36166 .45381 .3538 Mtetra
.606 .705 .914 r
.45381 .3538 .46009 .36166 .47112 .35851 .46485 .35129 Mtetra
.642 .739 .92 r
.46485 .35129 .47112 .35851 .4822 .35497 .47596 .34785 Mtetra
.65 .746 .92 r
.47596 .34785 .4822 .35497 .49333 .35126 .48711 .34417 Mtetra
.654 .75 .92 r
.48711 .34417 .49333 .35126 .50451 .34747 .49832 .34038 Mtetra
.656 .751 .92 r
.49832 .34038 .50451 .34747 .51573 .3436 .50957 .33651 Mtetra
.658 .753 .92 r
.50957 .33651 .51573 .3436 .527 .33969 .52087 .33258 Mtetra
.659 .753 .92 r
.52087 .33258 .527 .33969 .53832 .33575 .53222 .32862 Mtetra
.659 .754 .92 r
.53222 .32862 .53832 .33575 .54968 .33179 .54361 .32463 Mtetra
.54361 .32463 .54968 .33179 .56109 .32781 .55505 .32062 Mtetra
.55505 .32062 .56109 .32781 .57254 .32382 .56654 .3166 Mtetra
.658 .754 .92 r
.56654 .3166 .57254 .32382 .58404 .31983 .57807 .31257 Mtetra
.658 .753 .92 r
.57807 .31257 .58404 .31983 .59559 .31582 .58965 .30853 Mtetra
.58965 .30853 .59559 .31582 .60719 .3118 .60128 .30448 Mtetra
.60128 .30448 .60719 .3118 .61883 .30777 .61296 .30042 Mtetra
.61296 .30042 .61883 .30777 .63052 .30373 .62468 .29634 Mtetra
.62468 .29634 .63052 .30373 .64227 .29967 .63646 .29225 Mtetra
.63646 .29225 .64227 .29967 .65406 .2956 .64828 .28815 Mtetra
.657 .753 .92 r
.64828 .28815 .65406 .2956 .6659 .29152 .66016 .28403 Mtetra
.66016 .28403 .6659 .29152 .67779 .28741 .67208 .27989 Mtetra
.67208 .27989 .67779 .28741 .68973 .28329 .68405 .27574 Mtetra
.68405 .27574 .68973 .28329 .70171 .27916 .69608 .27157 Mtetra
.657 .752 .92 r
.69608 .27157 .70171 .27916 .71376 .27501 .70815 .26739 Mtetra
.70815 .26739 .71376 .27501 .72585 .27084 .72028 .26319 Mtetra
.72028 .26319 .72585 .27084 .73799 .26666 .73246 .25897 Mtetra
.73246 .25897 .73799 .26666 .75018 .26246 .74469 .25474 Mtetra
.74469 .25474 .75018 .26246 .76243 .25824 .75697 .25049 Mtetra
.75697 .25049 .76243 .25824 .77473 .25401 .76931 .24622 Mtetra
.76931 .24622 .77473 .25401 .78708 .24975 .7817 .24193 Mtetra
.73 .948 .643 r
.12352 .46789 .13234 .46 .14143 .46256 .13448 .45505 Mtetra
.558 .679 .92 r
.13448 .45505 .14143 .46256 .15104 .46109 .14408 .45381 Mtetra
.48 .655 .938 r
.14408 .45381 .15104 .46109 .16606 .41133 .15359 .45376 Mtetra
.37 .09 .352 r
.15359 .45376 .16606 .41133 .17109 .45186 .16427 .44365 Mtetra
.529 .648 .91 r
.16427 .44365 .17109 .45186 .18086 .45014 .17393 .44303 Mtetra
.571 .699 .928 r
.17393 .44303 .18086 .45014 .19042 .4509 .18374 .44144 Mtetra
.846 .713 .716 r
.18374 .44144 .19042 .4509 .20118 .44019 .19532 .42294 Mtetra
.152 .242 .704 r
.19532 .42294 .20118 .44019 .21101 .43905 .20415 .43184 Mtetra
.591 .705 .922 r
.20415 .43184 .21101 .43905 .22097 .43717 .21413 .42984 Mtetra
.511 .671 .936 r
.21413 .42984 .22097 .43717 .24132 .32059 .22402 .4293 Mtetra
.471 .223 .456 r
.22402 .4293 .24132 .32059 .24154 .42747 .23485 .41897 Mtetra
.532 .644 .905 r
.23485 .41897 .24154 .42747 .25163 .42541 .24484 .4183 Mtetra
.604 .716 .923 r
.24484 .4183 .25163 .42541 .26177 .42342 .25502 .41598 Mtetra
.486 .658 .937 r
.25502 .41598 .26177 .42342 .2741 .39402 .26507 .41583 Mtetra
.18 0 .164 r
.26507 .41583 .2741 .39402 .28265 .41343 .276 .40519 Mtetra
.555 .664 .909 r
.276 .40519 .28265 .41343 .29294 .41111 .28622 .40399 Mtetra
.615 .722 .922 r
.28622 .40399 .29294 .41111 .30329 .40862 .2966 .40138 Mtetra
.584 .708 .928 r
.2966 .40138 .30329 .40862 .31341 .41031 .30698 .39944 Mtetra
.81 .697 .741 r
.30698 .39944 .31341 .41031 .32448 .39806 .31819 .38531 Mtetra
.364 .456 .821 r
.31819 .38531 .32448 .39806 .33491 .3962 .3283 .3889 Mtetra
.616 .72 .92 r
.3283 .3889 .33491 .3962 .34546 .39333 .33885 .38623 Mtetra
.626 .731 .922 r
.33885 .38623 .34546 .39333 .35605 .39056 .34947 .38329 Mtetra
.598 .716 .927 r
.34947 .38329 .35605 .39056 .36654 .39082 .36011 .381 Mtetra
.857 .725 .716 r
.36011 .381 .36654 .39082 .37763 .37942 .37159 .36211 Mtetra
.242 .307 .731 r
.37159 .36211 .37763 .37942 .3883 .37765 .3818 .37022 Mtetra
.619 .721 .919 r
.3818 .37022 .3883 .37765 .39908 .37455 .39259 .36741 Mtetra
.638 .737 .921 r
.39259 .36741 .39908 .37455 .40991 .37123 .40345 .36413 Mtetra
.64 .74 .921 r
.40345 .36413 .40991 .37123 .42079 .36793 .41436 .36076 Mtetra
.634 .737 .922 r
.41436 .36076 .42079 .36793 .43171 .36501 .42531 .35753 Mtetra
.586 .71 .928 r
.42531 .35753 .43171 .36501 .44248 .36947 .43628 .35542 Mtetra
.767 .651 .734 r
.43628 .35542 .44248 .36947 .45381 .3538 .44755 .34309 Mtetra
.48 .57 .869 r
.44755 .34309 .45381 .3538 .46485 .35129 .45853 .34383 Mtetra
.632 .73 .919 r
.45853 .34383 .46485 .35129 .47596 .34785 .46966 .34062 Mtetra
.647 .744 .92 r
.46966 .34062 .47596 .34785 .48711 .34417 .48085 .337 Mtetra
.652 .748 .92 r
.48085 .337 .48711 .34417 .49832 .34038 .49208 .33322 Mtetra
.655 .751 .92 r
.49208 .33322 .49832 .34038 .50957 .33651 .50337 .32935 Mtetra
.657 .752 .92 r
.50337 .32935 .50957 .33651 .52087 .33258 .5147 .32542 Mtetra
.658 .753 .92 r
.5147 .32542 .52087 .33258 .53222 .32862 .52607 .32143 Mtetra
.659 .754 .92 r
.52607 .32143 .53222 .32862 .54361 .32463 .5375 .31741 Mtetra
.5375 .31741 .54361 .32463 .55505 .32062 .54897 .31337 Mtetra
.54897 .31337 .55505 .32062 .56654 .3166 .56049 .30932 Mtetra
.56049 .30932 .56654 .3166 .57807 .31257 .57205 .30525 Mtetra
.658 .753 .92 r
.57205 .30525 .57807 .31257 .58965 .30853 .58366 .30118 Mtetra
.58366 .30118 .58965 .30853 .60128 .30448 .59532 .2971 Mtetra
.59532 .2971 .60128 .30448 .61296 .30042 .60704 .293 Mtetra
.60704 .293 .61296 .30042 .62468 .29634 .61879 .28889 Mtetra
.61879 .28889 .62468 .29634 .63646 .29225 .6306 .28477 Mtetra
.6306 .28477 .63646 .29225 .64828 .28815 .64246 .28063 Mtetra
.657 .753 .92 r
.64246 .28063 .64828 .28815 .66016 .28403 .65437 .27648 Mtetra
.65437 .27648 .66016 .28403 .67208 .27989 .66633 .27231 Mtetra
.66633 .27231 .67208 .27989 .68405 .27574 .67834 .26813 Mtetra
.67834 .26813 .68405 .27574 .69608 .27157 .6904 .26393 Mtetra
.657 .752 .92 r
.6904 .26393 .69608 .27157 .70815 .26739 .70251 .25971 Mtetra
.70251 .25971 .70815 .26739 .72028 .26319 .71467 .25548 Mtetra
.71467 .25548 .72028 .26319 .73246 .25897 .72689 .25123 Mtetra
.72689 .25123 .73246 .25897 .74469 .25474 .73916 .24696 Mtetra
.73916 .24696 .74469 .25474 .75697 .25049 .75148 .24267 Mtetra
.75148 .24267 .75697 .25049 .76931 .24622 .76385 .23837 Mtetra
.76385 .23837 .76931 .24622 .7817 .24193 .77628 .23405 Mtetra
.775 .664 .74 r
.11703 .45604 .12352 .46789 .13448 .45505 .12791 .4441 Mtetra
.375 .497 .854 r
.12791 .4441 .13448 .45505 .14408 .45381 .13706 .44662 Mtetra
.568 .696 .927 r
.13706 .44662 .14408 .45381 .15359 .45376 .14675 .4451 Mtetra
.91 .709 .619 r
.14675 .4451 .15359 .45376 .16427 .44365 .16196 .39509 Mtetra
0 0 .328 r
.16196 .39509 .16427 .44365 .17393 .44303 .16697 .43573 Mtetra
.58 .698 .923 r
.16697 .43573 .17393 .44303 .18374 .44144 .17682 .43396 Mtetra
.425 .627 .938 r
.17682 .43396 .18374 .44144 .19532 .42294 .18645 .43467 Mtetra
0 0 0 r
.18645 .43467 .19532 .42294 .20415 .43184 .19731 .42387 Mtetra
.554 .669 .914 r
.19731 .42387 .20415 .43184 .21413 .42984 .20722 .42268 Mtetra
.586 .707 .927 r
.20722 .42268 .21413 .42984 .22402 .4293 .21726 .42073 Mtetra
.936 .701 .558 r
.21726 .42073 .22402 .4293 .23485 .41897 .23792 .30366 Mtetra
0 0 .233 r
.23792 .30366 .23485 .41897 .24484 .4183 .23801 .41089 Mtetra
.594 .705 .92 r
.23801 .41089 .24484 .4183 .25502 .41598 .24819 .40878 Mtetra
.589 .71 .927 r
.24819 .40878 .25502 .41598 .26507 .41583 .25842 .40673 Mtetra
.894 .724 .664 r
.25842 .40673 .26507 .41583 .276 .40519 .27087 .37715 Mtetra
0 .034 .546 r
.27087 .37715 .276 .40519 .28622 .40399 .27947 .39659 Mtetra
.604 .711 .92 r
.27947 .39659 .28622 .40399 .2966 .40138 .28985 .39421 Mtetra
.611 .722 .924 r
.28985 .39421 .2966 .40138 .30698 .39944 .30029 .39165 Mtetra
.362 .59 .932 r
.30029 .39165 .30698 .39944 .31819 .38531 .3105 .39331 Mtetra
.567 .848 .515 r
.3105 .39331 .31819 .38531 .3283 .3889 .32167 .38095 Mtetra
.583 .689 .914 r
.32167 .38095 .3283 .3889 .33885 .38623 .3322 .37903 Mtetra
.625 .729 .921 r
.3322 .37903 .33885 .38623 .34947 .38329 .34284 .37609 Mtetra
.62 .728 .923 r
.34284 .37609 .34947 .38329 .36011 .381 .35353 .37325 Mtetra
.464 .645 .936 r
.35353 .37325 .36011 .381 .37159 .36211 .3641 .37346 Mtetra
0 0 0 r
.3641 .37346 .37159 .36211 .3818 .37022 .3753 .36196 Mtetra
.579 .681 .911 r
.3753 .36196 .3818 .37022 .39259 .36741 .38607 .36013 Mtetra
.632 .732 .92 r
.38607 .36013 .39259 .36741 .40345 .36413 .39695 .35696 Mtetra
.64 .739 .921 r
.39695 .35696 .40345 .36413 .41436 .36076 .40788 .35357 Mtetra
.639 .739 .921 r
.40788 .35357 .41436 .36076 .42531 .35753 .41886 .3502 Mtetra
.623 .73 .924 r
.41886 .3502 .42531 .35753 .43628 .35542 .42987 .34721 Mtetra
.165 .463 .887 r
.42987 .34721 .43628 .35542 .44755 .34309 .44074 .35163 Mtetra
.633 .852 .47 r
.44074 .35163 .44755 .34309 .45853 .34383 .45218 .33584 Mtetra
.606 .705 .914 r
.45218 .33584 .45853 .34383 .46966 .34062 .46332 .33326 Mtetra
.642 .739 .92 r
.46332 .33326 .46966 .34062 .48085 .337 .47454 .32974 Mtetra
.65 .746 .92 r
.47454 .32974 .48085 .337 .49208 .33322 .4858 .32599 Mtetra
.654 .75 .92 r
.4858 .32599 .49208 .33322 .50337 .32935 .49711 .32213 Mtetra
.656 .751 .92 r
.49711 .32213 .50337 .32935 .5147 .32542 .50847 .31818 Mtetra
.658 .753 .92 r
.50847 .31818 .5147 .32542 .52607 .32143 .51988 .31418 Mtetra
.659 .753 .92 r
.51988 .31418 .52607 .32143 .5375 .31741 .53134 .31014 Mtetra
.659 .754 .92 r
.53134 .31014 .5375 .31741 .54897 .31337 .54284 .30607 Mtetra
.54284 .30607 .54897 .31337 .56049 .30932 .55439 .30198 Mtetra
.55439 .30198 .56049 .30932 .57205 .30525 .56598 .29789 Mtetra
.658 .754 .92 r
.56598 .29789 .57205 .30525 .58366 .30118 .57763 .29378 Mtetra
.658 .753 .92 r
.57763 .29378 .58366 .30118 .59532 .2971 .58932 .28966 Mtetra
.58932 .28966 .59532 .2971 .60704 .293 .60107 .28553 Mtetra
.60107 .28553 .60704 .293 .61879 .28889 .61286 .28139 Mtetra
.61286 .28139 .61879 .28889 .6306 .28477 .6247 .27723 Mtetra
.6247 .27723 .6306 .28477 .64246 .28063 .6366 .27306 Mtetra
.6366 .27306 .64246 .28063 .65437 .27648 .64854 .26887 Mtetra
.657 .753 .92 r
.64854 .26887 .65437 .27648 .66633 .27231 .66053 .26467 Mtetra
.66053 .26467 .66633 .27231 .67834 .26813 .67258 .26045 Mtetra
.67258 .26045 .67834 .26813 .6904 .26393 .68467 .25622 Mtetra
.68467 .25622 .6904 .26393 .70251 .25971 .69682 .25197 Mtetra
.657 .752 .92 r
.69682 .25197 .70251 .25971 .71467 .25548 .70902 .2477 Mtetra
.70902 .2477 .71467 .25548 .72689 .25123 .72127 .24342 Mtetra
.72127 .24342 .72689 .25123 .73916 .24696 .73357 .23912 Mtetra
.73357 .23912 .73916 .24696 .75148 .24267 .74593 .2348 Mtetra
.74593 .2348 .75148 .24267 .76385 .23837 .75834 .23046 Mtetra
.75834 .23046 .76385 .23837 .77628 .23405 .77081 .2261 Mtetra
.141 .466 .891 r
.10998 .44836 .11703 .45604 .12791 .4441 .11897 .45194 Mtetra
.737 .953 .651 r
.11897 .45194 .12791 .4441 .13706 .44662 .13004 .43899 Mtetra
.558 .679 .92 r
.13004 .43899 .13706 .44662 .14675 .4451 .13971 .43769 Mtetra
.48 .655 .937 r
.13971 .43769 .14675 .4451 .16196 .39509 .1493 .4376 Mtetra
.363 .081 .345 r
.1493 .4376 .16196 .39509 .16697 .43573 .16008 .4274 Mtetra
.529 .648 .91 r
.16008 .4274 .16697 .43573 .17682 .43396 .16981 .42672 Mtetra
.571 .699 .928 r
.16981 .42672 .17682 .43396 .18645 .43467 .1797 .42508 Mtetra
.847 .713 .716 r
.1797 .42508 .18645 .43467 .19731 .42387 .1914 .40645 Mtetra
.149 .24 .703 r
.1914 .40645 .19731 .42387 .20722 .42268 .20028 .41535 Mtetra
.591 .705 .923 r
.20028 .41535 .20722 .42268 .21726 .42073 .21035 .41329 Mtetra
.511 .671 .936 r
.21035 .41329 .21726 .42073 .23792 .30366 .22032 .41269 Mtetra
.466 .217 .451 r
.22032 .41269 .23792 .30366 .23801 .41089 .23125 .40227 Mtetra
.532 .644 .905 r
.23125 .40227 .23801 .41089 .24819 .40878 .24132 .40154 Mtetra
.604 .716 .923 r
.24132 .40154 .24819 .40878 .25842 .40673 .25159 .39916 Mtetra
.486 .658 .937 r
.25159 .39916 .25842 .40673 .27087 .37715 .26172 .39896 Mtetra
.168 0 .152 r
.26172 .39896 .27087 .37715 .27947 .39659 .27275 .38822 Mtetra
.555 .664 .909 r
.27275 .38822 .27947 .39659 .28985 .39421 .28306 .38696 Mtetra
.615 .722 .922 r
.28306 .38696 .28985 .39421 .30029 .39165 .29353 .38429 Mtetra
.584 .708 .928 r
.29353 .38429 .30029 .39165 .3105 .39331 .304 .38229 Mtetra
.811 .698 .741 r
.304 .38229 .3105 .39331 .32167 .38095 .31533 .36805 Mtetra
.363 .455 .821 r
.31533 .36805 .32167 .38095 .3322 .37903 .32551 .3716 Mtetra
.616 .72 .92 r
.32551 .3716 .3322 .37903 .34284 .37609 .33616 .36887 Mtetra
.626 .731 .922 r
.33616 .36887 .34284 .37609 .35353 .37325 .34688 .36585 Mtetra
.598 .716 .927 r
.34688 .36585 .35353 .37325 .3641 .37346 .35761 .3635 Mtetra
.858 .726 .716 r
.35761 .3635 .3641 .37346 .3753 .36196 .3692 .34448 Mtetra
.239 .306 .731 r
.3692 .34448 .3753 .36196 .38607 .36013 .3795 .35257 Mtetra
.619 .721 .919 r
.3795 .35257 .38607 .36013 .39695 .35696 .39039 .34969 Mtetra
.638 .737 .921 r
.39039 .34969 .39695 .35696 .40788 .35357 .40135 .34634 Mtetra
.64 .74 .921 r
.40135 .34634 .40788 .35357 .41886 .3502 .41236 .3429 Mtetra
.634 .737 .922 r
.41236 .3429 .41886 .3502 .42987 .34721 .42341 .3396 Mtetra
.586 .71 .928 r
.42341 .3396 .42987 .34721 .44074 .35163 .43448 .33742 Mtetra
.768 .652 .734 r
.43448 .33742 .44074 .35163 .45218 .33584 .44586 .32497 Mtetra
.479 .57 .869 r
.44586 .32497 .45218 .33584 .46332 .33326 .45694 .32567 Mtetra
.632 .73 .919 r
.45694 .32567 .46332 .33326 .47454 .32974 .46818 .32238 Mtetra
.647 .744 .92 r
.46818 .32238 .47454 .32974 .4858 .32599 .47947 .31869 Mtetra
.652 .748 .92 r
.47947 .31869 .4858 .32599 .49711 .32213 .49081 .31483 Mtetra
.655 .751 .92 r
.49081 .31483 .49711 .32213 .50847 .31818 .5022 .31089 Mtetra
.657 .752 .92 r
.5022 .31089 .50847 .31818 .51988 .31418 .51364 .30687 Mtetra
.658 .753 .92 r
.51364 .30687 .51988 .31418 .53134 .31014 .52513 .30281 Mtetra
.659 .754 .92 r
.52513 .30281 .53134 .31014 .54284 .30607 .53666 .29871 Mtetra
.53666 .29871 .54284 .30607 .55439 .30198 .54824 .29459 Mtetra
.54824 .29459 .55439 .30198 .56598 .29789 .55987 .29046 Mtetra
.55987 .29046 .56598 .29789 .57763 .29378 .57155 .28632 Mtetra
.658 .753 .92 r
.57155 .28632 .57763 .29378 .58932 .28966 .58328 .28216 Mtetra
.58328 .28216 .58932 .28966 .60107 .28553 .59505 .278 Mtetra
.59505 .278 .60107 .28553 .61286 .28139 .60688 .27382 Mtetra
.60688 .27382 .61286 .28139 .6247 .27723 .61876 .26963 Mtetra
.61876 .26963 .6247 .27723 .6366 .27306 .63068 .26543 Mtetra
.63068 .26543 .6366 .27306 .64854 .26887 .64266 .26121 Mtetra
.657 .753 .92 r
.64266 .26121 .64854 .26887 .66053 .26467 .65469 .25697 Mtetra
.65469 .25697 .66053 .26467 .67258 .26045 .66677 .25272 Mtetra
.66677 .25272 .67258 .26045 .68467 .25622 .6789 .24845 Mtetra
.6789 .24845 .68467 .25622 .69682 .25197 .69108 .24417 Mtetra
.657 .752 .92 r
.69108 .24417 .69682 .25197 .70902 .2477 .70332 .23987 Mtetra
.70332 .23987 .70902 .2477 .72127 .24342 .71561 .23555 Mtetra
.71561 .23555 .72127 .24342 .73357 .23912 .72795 .23121 Mtetra
.72795 .23121 .73357 .23912 .74593 .2348 .74034 .22685 Mtetra
.74034 .22685 .74593 .2348 .75834 .23046 .75279 .22248 Mtetra
.75279 .22248 .75834 .23046 .77081 .2261 .7653 .21809 Mtetra
.543 .685 .931 r
.10283 .44106 .10998 .44836 .11897 .45194 .11241 .43995 Mtetra
.776 .665 .741 r
.11241 .43995 .11897 .45194 .13004 .43899 .12339 .42791 Mtetra
.374 .496 .854 r
.12339 .42791 .13004 .43899 .13971 .43769 .13261 .43039 Mtetra
.568 .696 .927 r
.13261 .43039 .13971 .43769 .1493 .4376 .14238 .42881 Mtetra
.911 .71 .618 r
.14238 .42881 .1493 .4376 .16008 .4274 .15778 .37855 Mtetra
0 0 .323 r
.15778 .37855 .16008 .4274 .16981 .42672 .16277 .41931 Mtetra
.58 .698 .923 r
.16277 .41931 .16981 .42672 .1797 .42508 .1727 .41748 Mtetra
.426 .627 .938 r
.1727 .41748 .1797 .42508 .1914 .40645 .18241 .41814 Mtetra
0 0 0 r
.18241 .41814 .1914 .40645 .20028 .41535 .19337 .40725 Mtetra
.554 .669 .914 r
.19337 .40725 .20028 .41535 .21035 .41329 .20337 .406 Mtetra
.586 .707 .926 r
.20337 .406 .21035 .41329 .22032 .41269 .21349 .40399 Mtetra
.938 .702 .556 r
.21349 .40399 .22032 .41269 .23125 .40227 .23445 .28642 Mtetra
0 0 .227 r
.23445 .28642 .23125 .40227 .24132 .40154 .23442 .39401 Mtetra
.594 .705 .92 r
.23442 .39401 .24132 .40154 .25159 .39916 .24469 .39183 Mtetra
.589 .71 .927 r
.24469 .39183 .25159 .39916 .26172 .39896 .255 .38972 Mtetra
.895 .724 .663 r
.255 .38972 .26172 .39896 .27275 .38822 .26759 .35997 Mtetra
0 .029 .543 r
.26759 .35997 .27275 .38822 .28306 .38696 .27624 .37944 Mtetra
.604 .711 .92 r
.27624 .37944 .28306 .38696 .29353 .38429 .28671 .377 Mtetra
.611 .722 .924 r
.28671 .377 .29353 .38429 .304 .38229 .29724 .37437 Mtetra
.363 .59 .932 r
.29724 .37437 .304 .38229 .31533 .36805 .30754 .37597 Mtetra
.579 .858 .527 r
.30754 .37597 .31533 .36805 .32551 .3716 .31882 .36351 Mtetra
.583 .689 .914 r
.31882 .36351 .32551 .3716 .33616 .36887 .32944 .36153 Mtetra
.625 .729 .921 r
.32944 .36153 .33616 .36887 .34688 .36585 .34017 .35853 Mtetra
.62 .728 .923 r
.34017 .35853 .34688 .36585 .35761 .3635 .35095 .35562 Mtetra
.464 .645 .936 r
.35095 .35562 .35761 .3635 .3692 .34448 .36162 .35577 Mtetra
0 0 0 r
.36162 .35577 .3692 .34448 .3795 .35257 .37293 .34417 Mtetra
.579 .681 .911 r
.37293 .34417 .3795 .35257 .39039 .34969 .38379 .34227 Mtetra
.632 .732 .92 r
.38379 .34227 .39039 .34969 .40135 .34634 .39477 .33903 Mtetra
.64 .739 .921 r
.39477 .33903 .40135 .34634 .41236 .3429 .40581 .33557 Mtetra
.639 .739 .921 r
.40581 .33557 .41236 .3429 .42341 .3396 .41689 .33213 Mtetra
.623 .73 .924 r
.41689 .33213 .42341 .3396 .43448 .33742 .42801 .32907 Mtetra
.168 .464 .888 r
.42801 .32907 .43448 .33742 .44586 .32497 .43897 .33344 Mtetra
.643 .859 .48 r
.43897 .33344 .44586 .32497 .45694 .32567 .45052 .31753 Mtetra
.606 .705 .914 r
.45052 .31753 .45694 .32567 .46818 .32238 .46177 .31488 Mtetra
.642 .739 .92 r
.46177 .31488 .46818 .32238 .47947 .31869 .47309 .31129 Mtetra
.65 .746 .92 r
.47309 .31129 .47947 .31869 .49081 .31483 .48446 .30746 Mtetra
.654 .75 .92 r
.48446 .30746 .49081 .31483 .5022 .31089 .49588 .30352 Mtetra
.656 .751 .92 r
.49588 .30352 .5022 .31089 .51364 .30687 .50735 .2995 Mtetra
.658 .753 .92 r
.50735 .2995 .51364 .30687 .52513 .30281 .51887 .29542 Mtetra
.659 .753 .92 r
.51887 .29542 .52513 .30281 .53666 .29871 .53043 .2913 Mtetra
.659 .754 .92 r
.53043 .2913 .53666 .29871 .54824 .29459 .54205 .28715 Mtetra
.54205 .28715 .54824 .29459 .55987 .29046 .55371 .28298 Mtetra
.55371 .28298 .55987 .29046 .57155 .28632 .56542 .2788 Mtetra
.658 .754 .92 r
.56542 .2788 .57155 .28632 .58328 .28216 .57718 .27461 Mtetra
.658 .753 .92 r
.57718 .27461 .58328 .28216 .59505 .278 .58899 .27041 Mtetra
.58899 .27041 .59505 .278 .60688 .27382 .60085 .2662 Mtetra
.60085 .2662 .60688 .27382 .61876 .26963 .61276 .26198 Mtetra
.61276 .26198 .61876 .26963 .63068 .26543 .62472 .25774 Mtetra
.62472 .25774 .63068 .26543 .64266 .26121 .63674 .25348 Mtetra
.63674 .25348 .64266 .26121 .65469 .25697 .6488 .24921 Mtetra
.657 .753 .92 r
.6488 .24921 .65469 .25697 .66677 .25272 .66092 .24493 Mtetra
.66092 .24493 .66677 .25272 .6789 .24845 .67308 .24062 Mtetra
.67308 .24062 .6789 .24845 .69108 .24417 .6853 .2363 Mtetra
.6853 .2363 .69108 .24417 .70332 .23987 .69757 .23197 Mtetra
.657 .752 .92 r
.69757 .23197 .70332 .23987 .71561 .23555 .7099 .22761 Mtetra
.7099 .22761 .71561 .23555 .72795 .23121 .72228 .22324 Mtetra
.72228 .22324 .72795 .23121 .74034 .22685 .73471 .21885 Mtetra
.73471 .21885 .74034 .22685 .75279 .22248 .7472 .21444 Mtetra
.7472 .21444 .75279 .22248 .7653 .21809 .75974 .21002 Mtetra
.556 .682 .923 r
.09566 .43346 .10283 .44106 .11241 .43995 .10528 .43214 Mtetra
.144 .467 .891 r
.10528 .43214 .11241 .43995 .12339 .42791 .11433 .43569 Mtetra
.744 .957 .658 r
.11433 .43569 .12339 .42791 .13261 .43039 .12551 .42264 Mtetra
.558 .679 .92 r
.12551 .42264 .13261 .43039 .14238 .42881 .13526 .42129 Mtetra
.48 .655 .937 r
.13526 .42129 .14238 .42881 .15778 .37855 .14492 .42115 Mtetra
.356 .072 .337 r
.14492 .42115 .15778 .37855 .16277 .41931 .1558 .41085 Mtetra
.529 .648 .91 r
.1558 .41085 .16277 .41931 .1727 .41748 .16561 .41012 Mtetra
.571 .699 .928 r
.16561 .41012 .1727 .41748 .18241 .41814 .17559 .40842 Mtetra
.848 .714 .716 r
.17559 .40842 .18241 .41814 .19337 .40725 .1874 .38966 Mtetra
.146 .238 .702 r
.1874 .38966 .19337 .40725 .20337 .406 .19635 .39854 Mtetra
.591 .705 .923 r
.19635 .39854 .20337 .406 .21349 .40399 .20649 .39642 Mtetra
.511 .671 .935 r
.20649 .39642 .21349 .40399 .23445 .28642 .21655 .39577 Mtetra
.462 .21 .446 r
.21655 .39577 .23445 .28642 .23442 .39401 .22758 .38525 Mtetra
.532 .644 .906 r
.22758 .38525 .23442 .39401 .24469 .39183 .23773 .38447 Mtetra
.604 .716 .923 r
.23773 .38447 .24469 .39183 .255 .38972 .24809 .38202 Mtetra
.487 .658 .937 r
.24809 .38202 .255 .38972 .26759 .35997 .25831 .38177 Mtetra
.156 0 .139 r
.25831 .38177 .26759 .35997 .27624 .37944 .26945 .37093 Mtetra
.555 .664 .909 r
.26945 .37093 .27624 .37944 .28671 .377 .27985 .36961 Mtetra
.615 .722 .922 r
.27985 .36961 .28671 .377 .29724 .37437 .2904 .36688 Mtetra
.584 .708 .928 r
.2904 .36688 .29724 .37437 .30754 .37597 .30097 .36481 Mtetra
.811 .699 .741 r
.30097 .36481 .30754 .37597 .31882 .36351 .3124 .35046 Mtetra
.362 .455 .821 r
.3124 .35046 .31882 .36351 .32944 .36153 .32268 .35397 Mtetra
.616 .72 .92 r
.32268 .35397 .32944 .36153 .34017 .35853 .33342 .35116 Mtetra
.626 .731 .922 r
.33342 .35116 .34017 .35853 .35095 .35562 .34423 .34808 Mtetra
.598 .716 .927 r
.34423 .34808 .35095 .35562 .36162 .35577 .35506 .34566 Mtetra
.859 .726 .716 r
.35506 .34566 .36162 .35577 .37293 .34417 .36677 .32651 Mtetra
.237 .304 .73 r
.36677 .32651 .37293 .34417 .38379 .34227 .37716 .33457 Mtetra
.619 .721 .919 r
.37716 .33457 .38379 .34227 .39477 .33903 .38815 .33162 Mtetra
.638 .737 .921 r
.38815 .33162 .39477 .33903 .40581 .33557 .3992 .3282 Mtetra
.64 .74 .921 r
.3992 .3282 .40581 .33557 .41689 .33213 .41031 .32469 Mtetra
.634 .737 .922 r
.41031 .32469 .41689 .33213 .42801 .32907 .42147 .32131 Mtetra
.586 .71 .928 r
.42147 .32131 .42801 .32907 .43897 .33344 .43264 .31906 Mtetra
.768 .652 .734 r
.43264 .31906 .43897 .33344 .45052 .31753 .44413 .30651 Mtetra
.479 .57 .869 r
.44413 .30651 .45052 .31753 .46177 .31488 .45532 .30714 Mtetra
.632 .73 .919 r
.45532 .30714 .46177 .31488 .47309 .31129 .46666 .30378 Mtetra
.647 .744 .92 r
.46666 .30378 .47309 .31129 .48446 .30746 .47806 .30001 Mtetra
.652 .748 .92 r
.47806 .30001 .48446 .30746 .49588 .30352 .48951 .29608 Mtetra
.655 .751 .92 r
.48951 .29608 .49588 .30352 .50735 .2995 .50101 .29206 Mtetra
.657 .752 .92 r
.50101 .29206 .50735 .2995 .51887 .29542 .51256 .28796 Mtetra
.658 .753 .92 r
.51256 .28796 .51887 .29542 .53043 .2913 .52416 .28382 Mtetra
.659 .754 .92 r
.52416 .28382 .53043 .2913 .54205 .28715 .53581 .27964 Mtetra
.53581 .27964 .54205 .28715 .55371 .28298 .5475 .27544 Mtetra
.5475 .27544 .55371 .28298 .56542 .2788 .55925 .27123 Mtetra
.55925 .27123 .56542 .2788 .57718 .27461 .57104 .267 Mtetra
.658 .753 .92 r
.57104 .267 .57718 .27461 .58899 .27041 .58288 .26277 Mtetra
.58288 .26277 .58899 .27041 .60085 .2662 .59478 .25852 Mtetra
.59478 .25852 .60085 .2662 .61276 .26198 .60672 .25426 Mtetra
.60672 .25426 .61276 .26198 .62472 .25774 .61872 .24999 Mtetra
.61872 .24999 .62472 .25774 .63674 .25348 .63077 .2457 Mtetra
.63077 .2457 .63674 .25348 .6488 .24921 .64286 .24139 Mtetra
.657 .753 .92 r
.64286 .24139 .6488 .24921 .66092 .24493 .65502 .23707 Mtetra
.65502 .23707 .66092 .24493 .67308 .24062 .66722 .23273 Mtetra
.66722 .23273 .67308 .24062 .6853 .2363 .67947 .22838 Mtetra
.67947 .22838 .6853 .2363 .69757 .23197 .69178 .22401 Mtetra
.657 .752 .92 r
.69178 .22401 .69757 .23197 .7099 .22761 .70415 .21962 Mtetra
.70415 .21962 .7099 .22761 .72228 .22324 .71656 .21521 Mtetra
.71656 .21521 .72228 .22324 .73471 .21885 .72903 .21078 Mtetra
.72903 .21078 .73471 .21885 .7472 .21444 .74156 .20634 Mtetra
.74156 .20634 .7472 .21444 .75974 .21002 .75414 .20187 Mtetra
.437 .565 .886 r
.08874 .42365 .09566 .43346 .10528 .43214 .09805 .42472 Mtetra
.543 .685 .931 r
.09805 .42472 .10528 .43214 .11433 .43569 .1077 .42355 Mtetra
.776 .665 .741 r
.1077 .42355 .11433 .43569 .12551 .42264 .11879 .41142 Mtetra
.373 .496 .854 r
.11879 .41142 .12551 .42264 .13526 .42129 .12808 .41386 Mtetra
.568 .696 .927 r
.12808 .41386 .13526 .42129 .14492 .42115 .13793 .41222 Mtetra
.912 .711 .617 r
.13793 .41222 .14492 .42115 .1558 .41085 .15352 .36171 Mtetra
0 0 .317 r
.15352 .36171 .1558 .41085 .16561 .41012 .1585 .40258 Mtetra
.58 .698 .923 r
.1585 .40258 .16561 .41012 .17559 .40842 .1685 .40069 Mtetra
.426 .628 .938 r
.1685 .40069 .17559 .40842 .1874 .38966 .17829 .4013 Mtetra
0 0 0 r
.17829 .4013 .1874 .38966 .19635 .39854 .18936 .39031 Mtetra
.554 .669 .914 r
.18936 .39031 .19635 .39854 .20649 .39642 .19943 .389 Mtetra
.586 .707 .926 r
.19943 .389 .20649 .39642 .21655 .39577 .20964 .38694 Mtetra
.939 .702 .554 r
.20964 .38694 .21655 .39577 .22758 .38525 .23093 .26888 Mtetra
0 0 .22 r
.23093 .26888 .22758 .38525 .23773 .38447 .23076 .37681 Mtetra
.594 .705 .92 r
.23076 .37681 .23773 .38447 .24809 .38202 .24111 .37457 Mtetra
.589 .71 .927 r
.24111 .37457 .24809 .38202 .25831 .38177 .25151 .37239 Mtetra
.896 .725 .663 r
.25151 .37239 .25831 .38177 .26945 .37093 .26425 .34247 Mtetra
0 .025 .541 r
.26425 .34247 .26945 .37093 .27985 .36961 .27295 .36196 Mtetra
.604 .711 .92 r
.27295 .36196 .27985 .36961 .2904 .36688 .28351 .35945 Mtetra
.611 .722 .924 r
.28351 .35945 .2904 .36688 .30097 .36481 .29413 .35676 Mtetra
.364 .59 .931 r
.29413 .35676 .30097 .36481 .3124 .35046 .30451 .35831 Mtetra
.59 .867 .538 r
.30451 .35831 .3124 .35046 .32268 .35397 .31591 .34574 Mtetra
.583 .689 .914 r
.31591 .34574 .32268 .35397 .33342 .35116 .32662 .3437 Mtetra
.625 .729 .921 r
.32662 .3437 .33342 .35116 .34423 .34808 .33746 .34062 Mtetra
.62 .728 .923 r
.33746 .34062 .34423 .34808 .35506 .34566 .34833 .33764 Mtetra
.465 .645 .936 r
.34833 .33764 .35506 .34566 .36677 .32651 .3591 .33774 Mtetra
0 0 0 r
.3591 .33774 .36677 .32651 .37716 .33457 .37051 .32603 Mtetra
.578 .681 .911 r
.37051 .32603 .37716 .33457 .38815 .33162 .38148 .32407 Mtetra
.632 .732 .92 r
.38148 .32407 .38815 .33162 .3992 .3282 .39256 .32075 Mtetra
.64 .739 .921 r
.39256 .32075 .3992 .3282 .41031 .32469 .40369 .31722 Mtetra
.639 .739 .921 r
.40369 .31722 .41031 .32469 .42147 .32131 .41488 .3137 Mtetra
.623 .73 .924 r
.41488 .3137 .42147 .32131 .43264 .31906 .4261 .31056 Mtetra
.172 .466 .888 r
.4261 .31056 .43264 .31906 .44413 .30651 .43717 .3149 Mtetra
.652 .866 .49 r
.43717 .3149 .44413 .30651 .45532 .30714 .44883 .29886 Mtetra
.606 .705 .914 r
.44883 .29886 .45532 .30714 .46666 .30378 .46019 .29614 Mtetra
.642 .739 .92 r
.46019 .29614 .46666 .30378 .47806 .30001 .47161 .29247 Mtetra
.65 .746 .92 r
.47161 .29247 .47806 .30001 .48951 .29608 .48309 .28857 Mtetra
.654 .75 .92 r
.48309 .28857 .48951 .29608 .50101 .29206 .49463 .28454 Mtetra
.656 .751 .92 r
.49463 .28454 .50101 .29206 .51256 .28796 .50621 .28044 Mtetra
.658 .753 .92 r
.50621 .28044 .51256 .28796 .52416 .28382 .51784 .27628 Mtetra
.659 .753 .92 r
.51784 .27628 .52416 .28382 .53581 .27964 .52952 .27208 Mtetra
.659 .754 .92 r
.52952 .27208 .53581 .27964 .5475 .27544 .54124 .26785 Mtetra
.54124 .26785 .5475 .27544 .55925 .27123 .55302 .2636 Mtetra
.55302 .2636 .55925 .27123 .57104 .267 .56485 .25934 Mtetra
.658 .754 .92 r
.56485 .25934 .57104 .267 .58288 .26277 .57673 .25506 Mtetra
.658 .753 .92 r
.57673 .25506 .58288 .26277 .59478 .25852 .58865 .25078 Mtetra
.58865 .25078 .59478 .25852 .60672 .25426 .60063 .24648 Mtetra
.60063 .24648 .60672 .25426 .61872 .24999 .61266 .24217 Mtetra
.61266 .24217 .61872 .24999 .63077 .2457 .62475 .23785 Mtetra
.62475 .23785 .63077 .2457 .64286 .24139 .63688 .23351 Mtetra
.63688 .23351 .64286 .24139 .65502 .23707 .64907 .22915 Mtetra
.657 .753 .92 r
.64907 .22915 .65502 .23707 .66722 .23273 .66131 .22478 Mtetra
.66131 .22478 .66722 .23273 .67947 .22838 .6736 .22039 Mtetra
.6736 .22039 .67947 .22838 .69178 .22401 .68595 .21598 Mtetra
.68595 .21598 .69178 .22401 .70415 .21962 .69835 .21155 Mtetra
.657 .752 .92 r
.69835 .21155 .70415 .21962 .71656 .21521 .7108 .20711 Mtetra
.7108 .20711 .71656 .21521 .72903 .21078 .72331 .20265 Mtetra
.72331 .20265 .72903 .21078 .74156 .20634 .73587 .19817 Mtetra
.73587 .19817 .74156 .20634 .75414 .20187 .74849 .19367 Mtetra
.811 .954 .614 r
.079 .43415 .08874 .42365 .09805 .42472 .0908 .417 Mtetra
.556 .682 .923 r
.0908 .417 .09805 .42472 .1077 .42355 .10049 .41563 Mtetra
.147 .468 .892 r
.10049 .41563 .1077 .42355 .11879 .41142 .10961 .41914 Mtetra
.752 .961 .666 r
.10961 .41914 .11879 .41142 .12808 .41386 .1209 .40598 Mtetra
.558 .679 .92 r
.1209 .40598 .12808 .41386 .13793 .41222 .13073 .40457 Mtetra
.481 .655 .937 r
.13073 .40457 .13793 .41222 .15352 .36171 .14046 .40438 Mtetra
.348 .062 .329 r
.14046 .40438 .15352 .36171 .1585 .40258 .15144 .39399 Mtetra
.528 .648 .91 r
.15144 .39399 .1585 .40258 .1685 .40069 .16134 .3932 Mtetra
.571 .699 .928 r
.16134 .3932 .1685 .40069 .17829 .4013 .17139 .39145 Mtetra
.848 .715 .716 r
.17139 .39145 .17829 .4013 .18936 .39031 .18333 .37256 Mtetra
.142 .235 .701 r
.18333 .37256 .18936 .39031 .19943 .389 .19234 .38142 Mtetra
.591 .705 .923 r
.19234 .38142 .19943 .389 .20964 .38694 .20257 .37924 Mtetra
.512 .671 .935 r
.20257 .37924 .20964 .38694 .23093 .26888 .21271 .37853 Mtetra
.457 .204 .441 r
.21271 .37853 .23093 .26888 .23076 .37681 .22384 .36792 Mtetra
.531 .644 .906 r
.22384 .36792 .23076 .37681 .24111 .37457 .23408 .36707 Mtetra
.604 .716 .923 r
.23408 .36707 .24111 .37457 .25151 .37239 .24453 .36456 Mtetra
.487 .658 .936 r
.24453 .36456 .25151 .37239 .26425 .34247 .25484 .36425 Mtetra
.143 0 .126 r
.25484 .36425 .26425 .34247 .27295 .36196 .26608 .35332 Mtetra
.555 .664 .91 r
.26608 .35332 .27295 .36196 .28351 .35945 .27657 .35193 Mtetra
.615 .722 .922 r
.27657 .35193 .28351 .35945 .29413 .35676 .28722 .34913 Mtetra
.584 .708 .928 r
.28722 .34913 .29413 .35676 .30451 .35831 .29787 .34699 Mtetra
.812 .7 .741 r
.29787 .34699 .30451 .35831 .31591 .34574 .30943 .33253 Mtetra
.36 .454 .821 r
.30943 .33253 .31591 .34574 .32662 .3437 .31978 .33599 Mtetra
.616 .72 .92 r
.31978 .33599 .32662 .3437 .33746 .34062 .33063 .33312 Mtetra
.626 .731 .922 r
.33063 .33312 .33746 .34062 .34833 .33764 .34154 .32997 Mtetra
.598 .716 .927 r
.34154 .32997 .34833 .33764 .3591 .33774 .35246 .32748 Mtetra
.86 .727 .716 r
.35246 .32748 .3591 .33774 .37051 .32603 .3643 .3082 Mtetra
.234 .302 .73 r
.3643 .3082 .37051 .32603 .38148 .32407 .37477 .31622 Mtetra
.619 .721 .919 r
.37477 .31622 .38148 .32407 .39256 .32075 .38586 .3132 Mtetra
.638 .737 .921 r
.38586 .3132 .39256 .32075 .40369 .31722 .39702 .3097 Mtetra
.64 .74 .921 r
.39702 .3097 .40369 .31722 .41488 .3137 .40823 .30612 Mtetra
.634 .737 .922 r
.40823 .30612 .41488 .3137 .4261 .31056 .41949 .30267 Mtetra
.587 .71 .928 r
.41949 .30267 .4261 .31056 .43717 .3149 .43077 .30035 Mtetra
.769 .653 .734 r
.43077 .30035 .43717 .3149 .44883 .29886 .44238 .28768 Mtetra
.478 .57 .869 r
.44238 .28768 .44883 .29886 .46019 .29614 .45367 .28825 Mtetra
.632 .73 .919 r
.45367 .28825 .46019 .29614 .47161 .29247 .46512 .28482 Mtetra
.647 .744 .92 r
.46512 .28482 .47161 .29247 .48309 .28857 .47663 .28097 Mtetra
.652 .748 .92 r
.47663 .28097 .48309 .28857 .49463 .28454 .48819 .27696 Mtetra
.655 .751 .92 r
.48819 .27696 .49463 .28454 .50621 .28044 .4998 .27285 Mtetra
.657 .752 .92 r
.4998 .27285 .50621 .28044 .51784 .27628 .51146 .26867 Mtetra
.658 .753 .92 r
.51146 .26867 .51784 .27628 .52952 .27208 .52317 .26445 Mtetra
.659 .754 .92 r
.52317 .26445 .52952 .27208 .54124 .26785 .53494 .26019 Mtetra
.53494 .26019 .54124 .26785 .55302 .2636 .54675 .25591 Mtetra
.54675 .25591 .55302 .2636 .56485 .25934 .55861 .25161 Mtetra
.55861 .25161 .56485 .25934 .57673 .25506 .57052 .2473 Mtetra
.658 .753 .92 r
.57052 .2473 .57673 .25506 .58865 .25078 .58248 .24298 Mtetra
.58248 .24298 .58865 .25078 .60063 .24648 .5945 .23864 Mtetra
.5945 .23864 .60063 .24648 .61266 .24217 .60656 .2343 Mtetra
.60656 .2343 .61266 .24217 .62475 .23785 .61868 .22994 Mtetra
.61868 .22994 .62475 .23785 .63688 .23351 .63085 .22556 Mtetra
.63085 .22556 .63688 .23351 .64907 .22915 .64307 .22117 Mtetra
.657 .753 .92 r
.64307 .22117 .64907 .22915 .66131 .22478 .65535 .21676 Mtetra
.65535 .21676 .66131 .22478 .6736 .22039 .66768 .21233 Mtetra
.66768 .21233 .6736 .22039 .68595 .21598 .68006 .20789 Mtetra
.68006 .20789 .68595 .21598 .69835 .21155 .6925 .20343 Mtetra
.657 .752 .92 r
.6925 .20343 .69835 .21155 .7108 .20711 .70499 .19895 Mtetra
.70499 .19895 .7108 .20711 .72331 .20265 .71754 .19445 Mtetra
.71754 .19445 .72331 .20265 .73587 .19817 .73014 .18993 Mtetra
.73014 .18993 .73587 .19817 .74849 .19367 .7428 .18539 Mtetra
.731 .606 .718 r
.07283 .4179 .079 .43415 .0908 .417 .0838 .40706 Mtetra
.436 .565 .886 r
.0838 .40706 .0908 .417 .10049 .41563 .09318 .40808 Mtetra
.543 .685 .931 r
.09318 .40808 .10049 .41563 .10961 .41914 .10291 .40686 Mtetra
.777 .666 .741 r
.10291 .40686 .10961 .41914 .1209 .40598 .11411 .39462 Mtetra
.372 .495 .854 r
.11411 .39462 .1209 .40598 .13073 .40457 .12346 .39702 Mtetra
.569 .696 .927 r
.12346 .39702 .13073 .40457 .14046 .40438 .13339 .39532 Mtetra
.913 .711 .616 r
.13339 .39532 .14046 .40438 .15144 .39399 .14919 .34456 Mtetra
0 0 .311 r
.14919 .34456 .15144 .39399 .16134 .3932 .15414 .38553 Mtetra
.58 .698 .923 r
.15414 .38553 .16134 .3932 .17139 .39145 .16423 .38358 Mtetra
.427 .628 .937 r
.16423 .38358 .17139 .39145 .18333 .37256 .17409 .38415 Mtetra
0 0 0 r
.17409 .38415 .18333 .37256 .19234 .38142 .18527 .37306 Mtetra
.554 .669 .914 r
.18527 .37306 .19234 .38142 .20257 .37924 .19543 .37169 Mtetra
.586 .707 .926 r
.19543 .37169 .20257 .37924 .21271 .37853 .20572 .36956 Mtetra
.94 .703 .552 r
.20572 .36956 .21271 .37853 .22384 .36792 .22734 .25101 Mtetra
0 0 .213 r
.22734 .25101 .22384 .36792 .23408 .36707 .22703 .35928 Mtetra
.594 .705 .92 r
.22703 .35928 .23408 .36707 .24453 .36456 .23747 .35697 Mtetra
.589 .71 .927 r
.23747 .35697 .24453 .36456 .25484 .36425 .24796 .35473 Mtetra
.897 .726 .662 r
.24796 .35473 .25484 .36425 .26608 .35332 .26084 .32464 Mtetra
0 .02 .538 r
.26084 .32464 .26608 .35332 .27657 .35193 .26959 .34414 Mtetra
.604 .711 .92 r
.26959 .34414 .27657 .35193 .28722 .34913 .28025 .34156 Mtetra
.611 .722 .924 r
.28025 .34156 .28722 .34913 .29787 .34699 .29097 .3388 Mtetra
.366 .591 .931 r
.29097 .3388 .29787 .34699 .30943 .33253 .30144 .34031 Mtetra
.602 .875 .55 r
.30144 .34031 .30943 .33253 .31978 .33599 .31294 .32763 Mtetra
.583 .689 .914 r
.31294 .32763 .31978 .33599 .33063 .33312 .32375 .32552 Mtetra
.625 .729 .921 r
.32375 .32552 .33063 .33312 .34154 .32997 .33468 .32237 Mtetra
.62 .728 .923 r
.33468 .32237 .34154 .32997 .35246 .32748 .34566 .31932 Mtetra
.465 .645 .936 r
.34566 .31932 .35246 .32748 .3643 .3082 .35652 .31935 Mtetra
0 0 0 r
.35652 .31935 .3643 .3082 .37477 .31622 .36805 .30754 Mtetra
.578 .681 .911 r
.36805 .30754 .37477 .31622 .38586 .3132 .37911 .3055 Mtetra
.632 .732 .92 r
.37911 .3055 .38586 .3132 .39702 .3097 .3903 .30211 Mtetra
.64 .739 .921 r
.3903 .30211 .39702 .3097 .40823 .30612 .40154 .29851 Mtetra
.639 .739 .921 r
.40154 .29851 .40823 .30612 .41949 .30267 .41283 .29491 Mtetra
.623 .73 .924 r
.41283 .29491 .41949 .30267 .43077 .30035 .42416 .2917 Mtetra
.175 .467 .889 r
.42416 .2917 .43077 .30035 .44238 .28768 .43532 .29598 Mtetra
.661 .873 .499 r
.43532 .29598 .44238 .28768 .45367 .28825 .44711 .27982 Mtetra
.606 .705 .914 r
.44711 .27982 .45367 .28825 .46512 .28482 .45857 .27702 Mtetra
.642 .739 .92 r
.45857 .27702 .46512 .28482 .47663 .28097 .47011 .27327 Mtetra
.65 .746 .92 r
.47011 .27327 .47663 .28097 .48819 .27696 .4817 .26929 Mtetra
.654 .75 .92 r
.4817 .26929 .48819 .27696 .4998 .27285 .49334 .26519 Mtetra
.656 .751 .92 r
.49334 .26519 .4998 .27285 .51146 .26867 .50504 .261 Mtetra
.658 .753 .92 r
.50504 .261 .51146 .26867 .52317 .26445 .51678 .25676 Mtetra
.659 .753 .92 r
.51678 .25676 .52317 .26445 .53494 .26019 .52858 .25247 Mtetra
.659 .754 .92 r
.52858 .25247 .53494 .26019 .54675 .25591 .54042 .24815 Mtetra
.54042 .24815 .54675 .25591 .55861 .25161 .55232 .24382 Mtetra
.55232 .24382 .55861 .25161 .57052 .2473 .56426 .23947 Mtetra
.658 .754 .92 r
.56426 .23947 .57052 .2473 .58248 .24298 .57626 .23512 Mtetra
.658 .753 .92 r
.57626 .23512 .58248 .24298 .5945 .23864 .58831 .23074 Mtetra
.58831 .23074 .5945 .23864 .60656 .2343 .60041 .22636 Mtetra
.60041 .22636 .60656 .2343 .61868 .22994 .61256 .22196 Mtetra
.61256 .22196 .61868 .22994 .63085 .22556 .62477 .21755 Mtetra
.62477 .21755 .63085 .22556 .64307 .22117 .63703 .21312 Mtetra
.63703 .21312 .64307 .22117 .65535 .21676 .64934 .20868 Mtetra
.657 .753 .92 r
.64934 .20868 .65535 .21676 .66768 .21233 .66171 .20421 Mtetra
.66171 .20421 .66768 .21233 .68006 .20789 .67413 .19973 Mtetra
.67413 .19973 .68006 .20789 .6925 .20343 .6866 .19523 Mtetra
.6866 .19523 .6925 .20343 .70499 .19895 .69913 .19072 Mtetra
.657 .752 .92 r
.69913 .19072 .70499 .19895 .71754 .19445 .71172 .18618 Mtetra
.71172 .18618 .71754 .19445 .73014 .18993 .72436 .18162 Mtetra
.72436 .18162 .73014 .18993 .7428 .18539 .73706 .17705 Mtetra
0 .078 .599 r
.06552 .4097 .07283 .4179 .0838 .40706 .07392 .41751 Mtetra
.817 .957 .621 r
.07392 .41751 .0838 .40706 .09318 .40808 .08585 .40024 Mtetra
.556 .682 .923 r
.08585 .40024 .09318 .40808 .10291 .40686 .09562 .3988 Mtetra
.15 .469 .892 r
.09562 .3988 .10291 .40686 .11411 .39462 .1048 .40227 Mtetra
.758 .965 .673 r
.1048 .40227 .11411 .39462 .12346 .39702 .1162 .38901 Mtetra
.558 .679 .92 r
.1162 .38901 .12346 .39702 .13339 .39532 .12611 .38755 Mtetra
.481 .656 .937 r
.12611 .38755 .13339 .39532 .14919 .34456 .13592 .3873 Mtetra
.34 .052 .321 r
.13592 .3873 .14919 .34456 .15414 .38553 .14701 .37681 Mtetra
.528 .648 .91 r
.14701 .37681 .15414 .38553 .16423 .38358 .15698 .37597 Mtetra
.571 .699 .928 r
.15698 .37597 .16423 .38358 .17409 .38415 .16712 .37415 Mtetra
.849 .716 .715 r
.16712 .37415 .17409 .38415 .18527 .37306 .17918 .35513 Mtetra
.139 .233 .7 r
.17918 .35513 .18527 .37306 .19543 .37169 .18825 .36397 Mtetra
.591 .705 .923 r
.18825 .36397 .19543 .37169 .20572 .36956 .19857 .36173 Mtetra
.512 .671 .935 r
.19857 .36173 .20572 .36956 .22734 .25101 .20879 .36096 Mtetra
.452 .197 .436 r
.20879 .36096 .22734 .25101 .22703 .35928 .22003 .35025 Mtetra
.531 .644 .906 r
.22003 .35025 .22703 .35928 .23747 .35697 .23036 .34934 Mtetra
.604 .716 .923 r
.23036 .34934 .23747 .35697 .24796 .35473 .2409 .34676 Mtetra
.488 .658 .936 r
.2409 .34676 .24796 .35473 .26084 .32464 .2513 .3464 Mtetra
.13 0 .113 r
.2513 .3464 .26084 .32464 .26959 .34414 .26264 .33536 Mtetra
.555 .664 .91 r
.26264 .33536 .26959 .34414 .28025 .34156 .27322 .33391 Mtetra
.615 .722 .922 r
.27322 .33391 .28025 .34156 .29097 .3388 .28397 .33104 Mtetra
.584 .708 .928 r
.28397 .33104 .29097 .3388 .30144 .34031 .29472 .32883 Mtetra
.813 .701 .741 r
.29472 .32883 .30144 .34031 .31294 .32763 .30639 .31425 Mtetra
.359 .453 .821 r
.30639 .31425 .31294 .32763 .32375 .32552 .31684 .31767 Mtetra
.616 .72 .92 r
.31684 .31767 .32375 .32552 .33468 .32237 .32778 .31473 Mtetra
.626 .731 .922 r
.32778 .31473 .33468 .32237 .34566 .31932 .33879 .3115 Mtetra
.598 .716 .927 r
.33879 .3115 .34566 .31932 .35652 .31935 .34981 .30894 Mtetra
.861 .728 .715 r
.34981 .30894 .35652 .31935 .36805 .30754 .36177 .28952 Mtetra
.231 .301 .729 r
.36177 .28952 .36805 .30754 .37911 .3055 .37233 .29751 Mtetra
.619 .721 .919 r
.37233 .29751 .37911 .3055 .3903 .30211 .38352 .29442 Mtetra
.638 .737 .921 r
.38352 .29442 .3903 .30211 .40154 .29851 .39479 .29084 Mtetra
.64 .74 .921 r
.39479 .29084 .40154 .29851 .41283 .29491 .40611 .28718 Mtetra
.634 .737 .922 r
.40611 .28718 .41283 .29491 .42416 .2917 .41748 .28365 Mtetra
.587 .71 .928 r
.41748 .28365 .42416 .2917 .43532 .29598 .42886 .28126 Mtetra
.769 .653 .735 r
.42886 .28126 .43532 .29598 .44711 .27982 .44058 .26848 Mtetra
.478 .57 .87 r
.44058 .26848 .44711 .27982 .45857 .27702 .45198 .26899 Mtetra
.632 .73 .919 r
.45198 .26899 .45857 .27702 .47011 .27327 .46354 .26547 Mtetra
.647 .744 .92 r
.46354 .26547 .47011 .27327 .4817 .26929 .47516 .26154 Mtetra
.652 .748 .92 r
.47516 .26154 .4817 .26929 .49334 .26519 .48684 .25745 Mtetra
.655 .751 .92 r
.48684 .25745 .49334 .26519 .50504 .261 .49856 .25326 Mtetra
.657 .752 .92 r
.49856 .25326 .50504 .261 .51678 .25676 .51034 .249 Mtetra
.658 .753 .92 r
.51034 .249 .51678 .25676 .52858 .25247 .52217 .24469 Mtetra
.659 .754 .92 r
.52217 .24469 .52858 .25247 .54042 .24815 .53405 .24034 Mtetra
.53405 .24034 .54042 .24815 .55232 .24382 .54598 .23597 Mtetra
.54598 .23597 .55232 .24382 .56426 .23947 .55796 .23159 Mtetra
.55796 .23159 .56426 .23947 .57626 .23512 .56999 .22719 Mtetra
.658 .753 .92 r
.56999 .22719 .57626 .23512 .58831 .23074 .58207 .22278 Mtetra
.58207 .22278 .58831 .23074 .60041 .22636 .59421 .21836 Mtetra
.59421 .21836 .60041 .22636 .61256 .22196 .6064 .21393 Mtetra
.6064 .21393 .61256 .22196 .62477 .21755 .61864 .20948 Mtetra
.61864 .20948 .62477 .21755 .63703 .21312 .63093 .20501 Mtetra
.63093 .20501 .63703 .21312 .64934 .20868 .64328 .20053 Mtetra
.657 .753 .92 r
.64328 .20053 .64934 .20868 .66171 .20421 .65569 .19603 Mtetra
.65569 .19603 .66171 .20421 .67413 .19973 .66815 .19151 Mtetra
.66815 .19151 .67413 .19973 .6866 .19523 .68066 .18697 Mtetra
.68066 .18697 .6866 .19523 .69913 .19072 .69323 .18242 Mtetra
.657 .752 .92 r
.69323 .18242 .69913 .19072 .71172 .18618 .70585 .17784 Mtetra
.70585 .17784 .71172 .18618 .72436 .18162 .71853 .17325 Mtetra
.71853 .17325 .72436 .18162 .73706 .17705 .73127 .16864 Mtetra
.523 .675 .933 r
.05807 .40202 .06552 .4097 .07392 .41751 .0677 .4011 Mtetra
.731 .606 .718 r
.0677 .4011 .07392 .41751 .08585 .40024 .07877 .39016 Mtetra
.435 .565 .886 r
.07877 .39016 .08585 .40024 .09562 .3988 .08822 .39113 Mtetra
.544 .685 .931 r
.08822 .39113 .09562 .3988 .1048 .40227 .09803 .38985 Mtetra
.777 .666 .741 r
.09803 .38985 .1048 .40227 .1162 .38901 .10933 .37751 Mtetra
.371 .495 .854 r
.10933 .37751 .1162 .38901 .12611 .38755 .11876 .37987 Mtetra
.569 .696 .927 r
.11876 .37987 .12611 .38755 .13592 .3873 .12877 .37811 Mtetra
.914 .712 .615 r
.12877 .37811 .13592 .3873 .14701 .37681 .14477 .32709 Mtetra
0 0 .305 r
.14477 .32709 .14701 .37681 .15698 .37597 .1497 .36817 Mtetra
.58 .698 .923 r
.1497 .36817 .15698 .37597 .16712 .37415 .15987 .36615 Mtetra
.428 .628 .937 r
.15987 .36615 .16712 .37415 .17918 .35513 .16982 .36666 Mtetra
0 0 0 r
.16982 .36666 .17918 .35513 .18825 .36397 .1811 .35547 Mtetra
.553 .669 .914 r
.1811 .35547 .18825 .36397 .19857 .36173 .19134 .35404 Mtetra
.586 .707 .926 r
.19134 .35404 .19857 .36173 .20879 .36096 .20173 .35185 Mtetra
.941 .703 .55 r
.20173 .35185 .20879 .36096 .22003 .35025 .22368 .23281 Mtetra
0 0 .206 r
.22368 .23281 .22003 .35025 .23036 .34934 .22322 .34141 Mtetra
.594 .705 .92 r
.22322 .34141 .23036 .34934 .2409 .34676 .23376 .33904 Mtetra
.589 .71 .927 r
.23376 .33904 .2409 .34676 .2513 .3464 .24434 .33673 Mtetra
.898 .727 .661 r
.24434 .33673 .2513 .3464 .26264 .33536 .25737 .30646 Mtetra
0 .016 .535 r
.25737 .30646 .26264 .33536 .27322 .33391 .26617 .32598 Mtetra
.604 .711 .92 r
.26617 .32598 .27322 .33391 .28397 .33104 .27692 .32333 Mtetra
.611 .722 .924 r
.27692 .32333 .28397 .33104 .29472 .32883 .28774 .3205 Mtetra
.367 .591 .931 r
.28774 .3205 .29472 .32883 .30639 .31425 .2983 .32195 Mtetra
.613 .884 .561 r
.2983 .32195 .30639 .31425 .31684 .31767 .30991 .30916 Mtetra
.583 .689 .914 r
.30991 .30916 .31684 .31767 .32778 .31473 .32082 .30698 Mtetra
.625 .729 .921 r
.32082 .30698 .32778 .31473 .33879 .3115 .33186 .30375 Mtetra
.62 .728 .923 r
.33186 .30375 .33879 .3115 .34981 .30894 .34293 .30063 Mtetra
.466 .645 .935 r
.34293 .30063 .34981 .30894 .36177 .28952 .35389 .3006 Mtetra
0 0 0 r
.35389 .3006 .36177 .28952 .37233 .29751 .36554 .28868 Mtetra
.578 .681 .911 r
.36554 .28868 .37233 .29751 .38352 .29442 .3767 .28657 Mtetra
.632 .732 .92 r
.3767 .28657 .38352 .29442 .39479 .29084 .38799 .2831 Mtetra
.64 .739 .921 r
.38799 .2831 .39479 .29084 .40611 .28718 .39934 .27942 Mtetra
.639 .739 .921 r
.39934 .27942 .40611 .28718 .41748 .28365 .41074 .27575 Mtetra
.623 .73 .924 r
.41074 .27575 .41748 .28365 .42886 .28126 .42217 .27245 Mtetra
.178 .469 .889 r
.42217 .27245 .42886 .28126 .44058 .26848 .43344 .27669 Mtetra
.67 .88 .509 r
.43344 .27669 .44058 .26848 .45198 .26899 .44535 .2604 Mtetra
.606 .705 .914 r
.44535 .2604 .45198 .26899 .46354 .26547 .45692 .25752 Mtetra
.642 .739 .92 r
.45692 .25752 .46354 .26547 .47516 .26154 .46857 .25369 Mtetra
.65 .746 .92 r
.46857 .25369 .47516 .26154 .48684 .25745 .48028 .24962 Mtetra
.654 .75 .92 r
.48028 .24962 .48684 .25745 .49856 .25326 .49204 .24544 Mtetra
.656 .751 .92 r
.49204 .24544 .49856 .25326 .51034 .249 .50385 .24117 Mtetra
.658 .753 .92 r
.50385 .24117 .51034 .249 .52217 .24469 .51571 .23684 Mtetra
.659 .753 .92 r
.51571 .23684 .52217 .24469 .53405 .24034 .52762 .23246 Mtetra
.659 .754 .92 r
.52762 .23246 .53405 .24034 .54598 .23597 .53958 .22806 Mtetra
.53958 .22806 .54598 .23597 .55796 .23159 .5516 .22364 Mtetra
.5516 .22364 .55796 .23159 .56999 .22719 .56367 .2192 Mtetra
.658 .754 .92 r
.56367 .2192 .56999 .22719 .58207 .22278 .57578 .21476 Mtetra
.658 .753 .92 r
.57578 .21476 .58207 .22278 .59421 .21836 .58796 .2103 Mtetra
.58796 .2103 .59421 .21836 .6064 .21393 .60018 .20583 Mtetra
.60018 .20583 .6064 .21393 .61864 .20948 .61246 .20134 Mtetra
.61246 .20134 .61864 .20948 .63093 .20501 .62479 .19683 Mtetra
.62479 .19683 .63093 .20501 .64328 .20053 .63718 .19231 Mtetra
.63718 .19231 .64328 .20053 .65569 .19603 .64962 .18778 Mtetra
.657 .753 .92 r
.64962 .18778 .65569 .19603 .66815 .19151 .66211 .18322 Mtetra
.66211 .18322 .66815 .19151 .68066 .18697 .67467 .17865 Mtetra
.67467 .17865 .68066 .18697 .69323 .18242 .68727 .17405 Mtetra
.68727 .17405 .69323 .18242 .70585 .17784 .69994 .16944 Mtetra
.657 .752 .92 r
.69994 .16944 .70585 .17784 .71853 .17325 .71266 .16481 Mtetra
.71266 .16481 .71853 .17325 .73127 .16864 .72543 .16016 Mtetra
.545 .675 .923 r
.05062 .39403 .05807 .40202 .0677 .4011 .0603 .39276 Mtetra
0 .083 .605 r
.0603 .39276 .0677 .4011 .07877 .39016 .06876 .40055 Mtetra
.822 .959 .627 r
.06876 .40055 .07877 .39016 .08822 .39113 .0808 .38316 Mtetra
.556 .682 .923 r
.0808 .38316 .08822 .39113 .09803 .38985 .09065 .38166 Mtetra
.152 .471 .893 r
.09065 .38166 .09803 .38985 .10933 .37751 .0999 .38509 Mtetra
.765 .968 .68 r
.0999 .38509 .10933 .37751 .11876 .37987 .11141 .37173 Mtetra
.558 .679 .92 r
.11141 .37173 .11876 .37987 .12877 .37811 .1214 .3702 Mtetra
.481 .656 .937 r
.1214 .3702 .12877 .37811 .14477 .32709 .1313 .36989 Mtetra
.332 .041 .312 r
.1313 .36989 .14477 .32709 .1497 .36817 .14249 .35931 Mtetra
.528 .648 .91 r
.14249 .35931 .1497 .36817 .15987 .36615 .15254 .35841 Mtetra
.571 .699 .928 r
.15254 .35841 .15987 .36615 .16982 .36666 .16277 .35652 Mtetra
.85 .717 .715 r
.16277 .35652 .16982 .36666 .1811 .35547 .17496 .33737 Mtetra
.135 .231 .699 r
.17496 .33737 .1811 .35547 .19134 .35404 .18408 .34619 Mtetra
.591 .705 .923 r
.18408 .34619 .19134 .35404 .20173 .35185 .19449 .34388 Mtetra
.512 .671 .935 r
.19449 .34388 .20173 .35185 .22368 .23281 .2048 .34305 Mtetra
.447 .19 .43 r
.2048 .34305 .22368 .23281 .22322 .34141 .21615 .33224 Mtetra
.531 .644 .906 r
.21615 .33224 .22322 .34141 .23376 .33904 .22657 .33127 Mtetra
.604 .716 .923 r
.22657 .33127 .23376 .33904 .24434 .33673 .2372 .32862 Mtetra
.488 .658 .936 r
.2372 .32862 .24434 .33673 .25737 .30646 .24768 .32819 Mtetra
.117 0 .099 r
.24768 .32819 .25737 .30646 .26617 .32598 .25914 .31705 Mtetra
.554 .664 .91 r
.25914 .31705 .26617 .32598 .27692 .32333 .26982 .31554 Mtetra
.615 .722 .922 r
.26982 .31554 .27692 .32333 .28774 .3205 .28066 .31259 Mtetra
.584 .708 .928 r
.28066 .31259 .28774 .3205 .2983 .32195 .29151 .31032 Mtetra
.813 .701 .741 r
.29151 .31032 .2983 .32195 .30991 .30916 .30329 .29562 Mtetra
.358 .453 .821 r
.30329 .29562 .30991 .30916 .32082 .30698 .31383 .29899 Mtetra
.616 .72 .92 r
.31383 .29899 .32082 .30698 .33186 .30375 .32487 .29597 Mtetra
.626 .731 .922 r
.32487 .29597 .33186 .30375 .34293 .30063 .33598 .29267 Mtetra
.598 .716 .927 r
.33598 .29267 .34293 .30063 .35389 .3006 .34711 .29003 Mtetra
.862 .729 .715 r
.34711 .29003 .35389 .3006 .36554 .28868 .3592 .27047 Mtetra
.229 .299 .729 r
.3592 .27047 .36554 .28868 .3767 .28657 .36984 .27843 Mtetra
.619 .721 .919 r
.36984 .27843 .3767 .28657 .38799 .2831 .38114 .27526 Mtetra
.638 .737 .921 r
.38114 .27526 .38799 .2831 .39934 .27942 .39252 .27161 Mtetra
.64 .74 .921 r
.39252 .27161 .39934 .27942 .41074 .27575 .40394 .26786 Mtetra
.634 .737 .922 r
.40394 .26786 .41074 .27575 .42217 .27245 .41542 .26425 Mtetra
.587 .709 .928 r
.41542 .26425 .42217 .27245 .43344 .27669 .42691 .26178 Mtetra
.77 .654 .735 r
.42691 .26178 .43344 .27669 .44535 .2604 .43875 .24889 Mtetra
.477 .57 .87 r
.43875 .24889 .44535 .2604 .45692 .25752 .45026 .24933 Mtetra
.632 .73 .919 r
.45026 .24933 .45692 .25752 .46857 .25369 .46193 .24573 Mtetra
.647 .744 .92 r
.46193 .24573 .46857 .25369 .48028 .24962 .47367 .24172 Mtetra
.652 .748 .92 r
.47367 .24172 .48028 .24962 .49204 .24544 .48546 .23754 Mtetra
.655 .751 .92 r
.48546 .23754 .49204 .24544 .50385 .24117 .4973 .23326 Mtetra
.657 .752 .92 r
.4973 .23326 .50385 .24117 .51571 .23684 .5092 .22892 Mtetra
.658 .753 .92 r
.5092 .22892 .51571 .23684 .52762 .23246 .52114 .22452 Mtetra
.659 .754 .92 r
.52114 .22452 .52762 .23246 .53958 .22806 .53314 .22009 Mtetra
.53314 .22009 .53958 .22806 .5516 .22364 .54519 .21563 Mtetra
.54519 .21563 .5516 .22364 .56367 .2192 .55729 .21116 Mtetra
.55729 .21116 .56367 .2192 .57578 .21476 .56945 .20667 Mtetra
.658 .753 .92 r
.56945 .20667 .57578 .21476 .58796 .2103 .58165 .20217 Mtetra
.58165 .20217 .58796 .2103 .60018 .20583 .59391 .19766 Mtetra
.59391 .19766 .60018 .20583 .61246 .20134 .60623 .19313 Mtetra
.60623 .19313 .61246 .20134 .62479 .19683 .6186 .18859 Mtetra
.6186 .18859 .62479 .19683 .63718 .19231 .63102 .18403 Mtetra
.63102 .18403 .63718 .19231 .64962 .18778 .6435 .17946 Mtetra
.657 .753 .92 r
.6435 .17946 .64962 .18778 .66211 .18322 .65603 .17486 Mtetra
.65603 .17486 .66211 .18322 .67467 .17865 .66862 .17025 Mtetra
.66862 .17025 .67467 .17865 .68727 .17405 .68127 .16562 Mtetra
.68127 .16562 .68727 .17405 .69994 .16944 .69397 .16097 Mtetra
.657 .752 .92 r
.69397 .16097 .69994 .16944 .71266 .16481 .70673 .1563 Mtetra
.70673 .1563 .71266 .16481 .72543 .16016 .71955 .15161 Mtetra
.395 .53 .874 r
.04351 .38332 .05062 .39403 .0603 .39276 .05277 .38495 Mtetra
.524 .675 .933 r
.05277 .38495 .0603 .39276 .06876 .40055 .06247 .38397 Mtetra
.731 .606 .718 r
.06247 .38397 .06876 .40055 .0808 .38316 .07365 .37294 Mtetra
.435 .565 .886 r
.07365 .37294 .0808 .38316 .09065 .38166 .08317 .37386 Mtetra
.544 .685 .931 r
.08317 .37386 .09065 .38166 .0999 .38509 .09306 .37252 Mtetra
.778 .667 .741 r
.09306 .37252 .0999 .38509 .11141 .37173 .10447 .36007 Mtetra
.37 .495 .855 r
.10447 .36007 .11141 .37173 .1214 .3702 .11397 .36238 Mtetra
.569 .696 .927 r
.11397 .36238 .1214 .3702 .1313 .36989 .12406 .36056 Mtetra
.915 .713 .614 r
.12406 .36056 .1313 .36989 .14249 .35931 .14028 .30929 Mtetra
0 0 .299 r
.14028 .30929 .14249 .35931 .15254 .35841 .14517 .35047 Mtetra
.58 .698 .923 r
.14517 .35047 .15254 .35841 .16277 .35652 .15543 .34839 Mtetra
.428 .628 .937 r
.15543 .34839 .16277 .35652 .17496 .33737 .16546 .34884 Mtetra
0 0 0 r
.16546 .34884 .17496 .33737 .18408 .34619 .17685 .33755 Mtetra
.553 .669 .914 r
.17685 .33755 .18408 .34619 .19449 .34388 .18718 .33606 Mtetra
.586 .707 .926 r
.18718 .33606 .19449 .34388 .2048 .34305 .19765 .3338 Mtetra
.942 .704 .548 r
.19765 .3338 .2048 .34305 .21615 .33224 .21995 .21427 Mtetra
0 0 .199 r
.21995 .21427 .21615 .33224 .22657 .33127 .21935 .3232 Mtetra
.594 .705 .92 r
.21935 .3232 .22657 .33127 .2372 .32862 .22998 .32075 Mtetra
.589 .71 .927 r
.22998 .32075 .2372 .32862 .24768 .32819 .24065 .31838 Mtetra
.899 .728 .661 r
.24065 .31838 .24768 .32819 .25914 .31705 .25383 .28793 Mtetra
0 .011 .533 r
.25383 .28793 .25914 .31705 .26982 .31554 .26268 .30746 Mtetra
.604 .711 .92 r
.26268 .30746 .26982 .31554 .28066 .31259 .27353 .30474 Mtetra
.611 .722 .924 r
.27353 .30474 .28066 .31259 .29151 .31032 .28444 .30184 Mtetra
.368 .591 .931 r
.28444 .30184 .29151 .31032 .30329 .29562 .29509 .30323 Mtetra
.624 .892 .572 r
.29509 .30323 .30329 .29562 .31383 .29899 .30683 .29032 Mtetra
.583 .689 .914 r
.30683 .29032 .31383 .29899 .32487 .29597 .31784 .28807 Mtetra
.625 .729 .921 r
.31784 .28807 .32487 .29597 .33598 .29267 .32897 .28477 Mtetra
.62 .728 .923 r
.32897 .28477 .33598 .29267 .34711 .29003 .34015 .28157 Mtetra
.467 .645 .935 r
.34015 .28157 .34711 .29003 .3592 .27047 .35121 .28148 Mtetra
0 0 0 r
.35121 .28148 .3592 .27047 .36984 .27843 .36297 .26945 Mtetra
.578 .681 .911 r
.36297 .26945 .36984 .27843 .38114 .27526 .37425 .26726 Mtetra
.632 .732 .92 r
.37425 .26726 .38114 .27526 .39252 .27161 .38564 .26372 Mtetra
.64 .739 .921 r
.38564 .26372 .39252 .27161 .40394 .26786 .3971 .25995 Mtetra
.639 .739 .921 r
.3971 .25995 .40394 .26786 .41542 .26425 .4086 .2562 Mtetra
.623 .73 .923 r
.4086 .2562 .41542 .26425 .42691 .26178 .42015 .25282 Mtetra
.182 .47 .89 r
.42015 .25282 .42691 .26178 .43875 .24889 .43152 .257 Mtetra
.679 .886 .518 r
.43152 .257 .43875 .24889 .45026 .24933 .44356 .24058 Mtetra
.606 .705 .915 r
.44356 .24058 .45026 .24933 .46193 .24573 .45524 .23763 Mtetra
.642 .739 .92 r
.45524 .23763 .46193 .24573 .47367 .24172 .46701 .23371 Mtetra
.65 .746 .92 r
.46701 .23371 .47367 .24172 .48546 .23754 .47883 .22956 Mtetra
.654 .75 .92 r
.47883 .22956 .48546 .23754 .4973 .23326 .4907 .22528 Mtetra
.656 .751 .92 r
.4907 .22528 .4973 .23326 .5092 .22892 .50263 .22093 Mtetra
.658 .753 .92 r
.50263 .22093 .5092 .22892 .52114 .22452 .51461 .21651 Mtetra
.659 .753 .92 r
.51461 .21651 .52114 .22452 .53314 .22009 .52664 .21205 Mtetra
.659 .754 .92 r
.52664 .21205 .53314 .22009 .54519 .21563 .53873 .20755 Mtetra
.53873 .20755 .54519 .21563 .55729 .21116 .55087 .20304 Mtetra
.55087 .20304 .55729 .21116 .56945 .20667 .56306 .19852 Mtetra
.658 .754 .92 r
.56306 .19852 .56945 .20667 .58165 .20217 .5753 .19398 Mtetra
.658 .753 .92 r
.5753 .19398 .58165 .20217 .59391 .19766 .5876 .18943 Mtetra
.5876 .18943 .59391 .19766 .60623 .19313 .59995 .18486 Mtetra
.59995 .18486 .60623 .19313 .6186 .18859 .61235 .18028 Mtetra
.61235 .18028 .6186 .18859 .63102 .18403 .62482 .17568 Mtetra
.62482 .17568 .63102 .18403 .6435 .17946 .63733 .17107 Mtetra
.63733 .17107 .6435 .17946 .65603 .17486 .6499 .16644 Mtetra
.657 .753 .92 r
.6499 .16644 .65603 .17486 .66862 .17025 .66253 .16178 Mtetra
.66253 .16178 .66862 .17025 .68127 .16562 .67522 .15711 Mtetra
.67522 .15711 .68127 .16562 .69397 .16097 .68796 .15242 Mtetra
.68796 .15242 .69397 .16097 .70673 .1563 .70076 .14771 Mtetra
.657 .752 .92 r
.70076 .14771 .70673 .1563 .71955 .15161 .71361 .14298 Mtetra
.82 .979 .69 r
.03344 .39175 .04351 .38332 .05277 .38495 .04522 .37683 Mtetra
.545 .675 .923 r
.04522 .37683 .05277 .38495 .06247 .38397 .05498 .3755 Mtetra
0 .088 .61 r
.05498 .3755 .06247 .38397 .07365 .37294 .06349 .38327 Mtetra
.827 .962 .633 r
.06349 .38327 .07365 .37294 .08317 .37386 .07566 .36575 Mtetra
.556 .682 .923 r
.07566 .36575 .08317 .37386 .09306 .37252 .08559 .3642 Mtetra
.155 .472 .894 r
.08559 .3642 .09306 .37252 .10447 .36007 .09491 .36758 Mtetra
.771 .971 .687 r
.09491 .36758 .10447 .36007 .11397 .36238 .10653 .35411 Mtetra
.557 .679 .92 r
.10653 .35411 .11397 .36238 .12406 .36056 .11661 .35251 Mtetra
.482 .656 .937 r
.11661 .35251 .12406 .36056 .14028 .30929 .12658 .35215 Mtetra
.323 .03 .303 r
.12658 .35215 .14028 .30929 .14517 .35047 .13788 .34147 Mtetra
.528 .648 .91 r
.13788 .34147 .14517 .35047 .15543 .34839 .14802 .3405 Mtetra
.571 .699 .928 r
.14802 .3405 .15543 .34839 .16546 .34884 .15833 .33855 Mtetra
.851 .718 .715 r
.15833 .33855 .16546 .34884 .17685 .33755 .17065 .31927 Mtetra
.132 .228 .698 r
.17065 .31927 .17685 .33755 .18718 .33606 .17983 .32807 Mtetra
.591 .705 .923 r
.17983 .32807 .18718 .33606 .19765 .3338 .19033 .32568 Mtetra
.513 .671 .935 r
.19033 .32568 .19765 .3338 .21995 .21427 .20073 .32479 Mtetra
.441 .183 .425 r
.20073 .32479 .21995 .21427 .21935 .3232 .21219 .31388 Mtetra
.531 .644 .906 r
.21219 .31388 .21935 .3232 .22998 .32075 .2227 .31284 Mtetra
.604 .716 .923 r
.2227 .31284 .22998 .32075 .24065 .31838 .23342 .31012 Mtetra
.488 .658 .936 r
.23342 .31012 .24065 .31838 .25383 .28793 .244 .30963 Mtetra
.103 0 .085 r
.244 .30963 .25383 .28793 .26268 .30746 .25558 .29839 Mtetra
.554 .664 .91 r
.25558 .29839 .26268 .30746 .27353 .30474 .26634 .2968 Mtetra
.615 .722 .922 r
.26634 .2968 .27353 .30474 .28444 .30184 .27729 .29378 Mtetra
.584 .708 .928 r
.27729 .29378 .28444 .30184 .29509 .30323 .28823 .29144 Mtetra
.814 .702 .742 r
.28823 .29144 .29509 .30323 .30683 .29032 .30014 .27662 Mtetra
.356 .452 .822 r
.30014 .27662 .30683 .29032 .31784 .28807 .31076 .27993 Mtetra
.616 .72 .92 r
.31076 .27993 .31784 .28807 .32897 .28477 .32191 .27684 Mtetra
.626 .731 .922 r
.32191 .27684 .32897 .28477 .34015 .28157 .33312 .27346 Mtetra
.598 .715 .926 r
.33312 .27346 .34015 .28157 .35121 .28148 .34435 .27074 Mtetra
.862 .73 .715 r
.34435 .27074 .35121 .28148 .36297 .26945 .35657 .25105 Mtetra
.226 .297 .728 r
.35657 .25105 .36297 .26945 .37425 .26726 .36731 .25897 Mtetra
.619 .721 .919 r
.36731 .25897 .37425 .26726 .38564 .26372 .37871 .25572 Mtetra
.638 .737 .921 r
.37871 .25572 .38564 .26372 .3971 .25995 .3902 .25198 Mtetra
.64 .74 .921 r
.3902 .25198 .3971 .25995 .4086 .2562 .40173 .24815 Mtetra
.634 .737 .922 r
.40173 .24815 .4086 .2562 .42015 .25282 .41332 .24446 Mtetra
.587 .709 .928 r
.41332 .24446 .42015 .25282 .43152 .257 .42492 .24192 Mtetra
.77 .655 .735 r
.42492 .24192 .43152 .257 .44356 .24058 .43689 .22891 Mtetra
.477 .569 .87 r
.43689 .22891 .44356 .24058 .45524 .23763 .44851 .22928 Mtetra
.632 .73 .919 r
.44851 .22928 .45524 .23763 .46701 .23371 .46029 .22559 Mtetra
.647 .744 .92 r
.46029 .22559 .46701 .23371 .47883 .22956 .47215 .22149 Mtetra
.652 .748 .92 r
.47215 .22149 .47883 .22956 .4907 .22528 .48405 .21722 Mtetra
.655 .751 .92 r
.48405 .21722 .4907 .22528 .50263 .22093 .49601 .21286 Mtetra
.657 .752 .92 r
.49601 .21286 .50263 .22093 .51461 .21651 .50803 .20843 Mtetra
.658 .753 .92 r
.50803 .20843 .51461 .21651 .52664 .21205 .5201 .20394 Mtetra
.659 .754 .92 r
.5201 .20394 .52664 .21205 .53873 .20755 .53222 .19941 Mtetra
.53222 .19941 .53873 .20755 .55087 .20304 .54439 .19486 Mtetra
.54439 .19486 .55087 .20304 .56306 .19852 .55661 .1903 Mtetra
.55661 .1903 .56306 .19852 .5753 .19398 .56889 .18572 Mtetra
.658 .753 .92 r
.56889 .18572 .5753 .19398 .5876 .18943 .58123 .18113 Mtetra
.58123 .18113 .5876 .18943 .59995 .18486 .59362 .17652 Mtetra
.59362 .17652 .59995 .18486 .61235 .18028 .60606 .1719 Mtetra
.60606 .1719 .61235 .18028 .62482 .17568 .61856 .16727 Mtetra
.61856 .16727 .62482 .17568 .63733 .17107 .63111 .16261 Mtetra
.63111 .16261 .63733 .17107 .6499 .16644 .64372 .15794 Mtetra
.657 .753 .92 r
.64372 .15794 .6499 .16644 .66253 .16178 .65639 .15325 Mtetra
.65639 .15325 .66253 .16178 .67522 .15711 .66911 .14854 Mtetra
.66911 .14854 .67522 .15711 .68796 .15242 .68189 .14381 Mtetra
.68189 .14381 .68796 .15242 .70076 .14771 .69473 .13906 Mtetra
.657 .752 .92 r
.69473 .13906 .70076 .14771 .71361 .14298 .70763 .13429 Mtetra
.754 .639 .733 r
.02675 .37749 .03344 .39175 .04522 .37683 .03804 .36598 Mtetra
.394 .529 .874 r
.03804 .36598 .04522 .37683 .05498 .3755 .04736 .36756 Mtetra
.524 .675 .933 r
.04736 .36756 .05498 .3755 .06349 .38327 .05714 .36652 Mtetra
.731 .607 .718 r
.05714 .36652 .06349 .38327 .07566 .36575 .06843 .35539 Mtetra
.434 .564 .886 r
.06843 .35539 .07566 .36575 .08559 .3642 .07802 .35625 Mtetra
.544 .685 .931 r
.07802 .35625 .08559 .3642 .09491 .36758 .08799 .35485 Mtetra
.778 .668 .742 r
.08799 .35485 .09491 .36758 .10653 .35411 .09952 .3423 Mtetra
.369 .494 .855 r
.09952 .3423 .10653 .35411 .11661 .35251 .10908 .34457 Mtetra
.569 .696 .927 r
.10908 .34457 .11661 .35251 .12658 .35215 .11926 .34268 Mtetra
.916 .713 .613 r
.11926 .34268 .12658 .35215 .13788 .34147 .13569 .29116 Mtetra
0 0 .293 r
.13569 .29116 .13788 .34147 .14802 .3405 .14056 .33243 Mtetra
.58 .698 .923 r
.14056 .33243 .14802 .3405 .15833 .33855 .15091 .33028 Mtetra
.429 .628 .937 r
.15091 .33028 .15833 .33855 .17065 .31927 .16102 .33068 Mtetra
0 0 0 r
.16102 .33068 .17065 .31927 .17983 .32807 .17252 .31928 Mtetra
.553 .669 .914 r
.17252 .31928 .17983 .32807 .19033 .32568 .18294 .31772 Mtetra
.586 .707 .926 r
.18294 .31772 .19033 .32568 .20073 .32479 .1935 .31539 Mtetra
.943 .704 .546 r
.1935 .31539 .20073 .32479 .21219 .31388 .21616 .19538 Mtetra
0 0 .192 r
.21616 .19538 .21219 .31388 .2227 .31284 .21539 .30463 Mtetra
.594 .705 .92 r
.21539 .30463 .2227 .31284 .23342 .31012 .22612 .30211 Mtetra
.589 .71 .927 r
.22612 .30211 .23342 .31012 .244 .30963 .23689 .29967 Mtetra
.9 .729 .66 r
.23689 .29967 .244 .30963 .25558 .29839 .25022 .26904 Mtetra
0 .007 .53 r
.25022 .26904 .25558 .29839 .26634 .2968 .25912 .28858 Mtetra
.604 .711 .92 r
.25912 .28858 .26634 .2968 .27729 .29378 .27007 .28579 Mtetra
.611 .722 .924 r
.27007 .28579 .27729 .29378 .28823 .29144 .28108 .28281 Mtetra
.369 .592 .931 r
.28108 .28281 .28823 .29144 .30014 .27662 .29183 .28413 Mtetra
.635 .899 .583 r
.29183 .28413 .30014 .27662 .31076 .27993 .30368 .27112 Mtetra
.583 .689 .914 r
.30368 .27112 .31076 .27993 .32191 .27684 .31479 .26879 Mtetra
.625 .729 .921 r
.31479 .26879 .32191 .27684 .33312 .27346 .32603 .26541 Mtetra
.62 .728 .923 r
.32603 .26541 .33312 .27346 .34435 .27074 .33732 .26213 Mtetra
.467 .645 .935 r
.33732 .26213 .34435 .27074 .35657 .25105 .34848 .26197 Mtetra
0 0 0 r
.34848 .26197 .35657 .25105 .36731 .25897 .36036 .24982 Mtetra
.578 .681 .911 r
.36036 .24982 .36731 .25897 .37871 .25572 .37174 .24757 Mtetra
.632 .732 .92 r
.37174 .24757 .37871 .25572 .3902 .25198 .38324 .24393 Mtetra
.64 .739 .921 r
.38324 .24393 .3902 .25198 .40173 .24815 .39481 .24008 Mtetra
.639 .739 .921 r
.39481 .24008 .40173 .24815 .41332 .24446 .40643 .23625 Mtetra
.623 .73 .923 r
.40643 .23625 .41332 .24446 .42492 .24192 .41809 .23279 Mtetra
.185 .471 .89 r
.41809 .23279 .42492 .24192 .43689 .22891 .42957 .23691 Mtetra
.688 .893 .527 r
.42957 .23691 .43689 .22891 .44851 .22928 .44173 .22036 Mtetra
.606 .705 .915 r
.44173 .22036 .44851 .22928 .46029 .22559 .45353 .21732 Mtetra
.642 .739 .92 r
.45353 .21732 .46029 .22559 .47215 .22149 .46541 .21332 Mtetra
.65 .746 .92 r
.46541 .21332 .47215 .22149 .48405 .21722 .47735 .20908 Mtetra
.654 .75 .92 r
.47735 .20908 .48405 .21722 .49601 .21286 .48934 .20472 Mtetra
.656 .751 .92 r
.48934 .20472 .49601 .21286 .50803 .20843 .50139 .20027 Mtetra
.658 .753 .92 r
.50139 .20027 .50803 .20843 .5201 .20394 .51349 .19576 Mtetra
.659 .753 .92 r
.51349 .19576 .5201 .20394 .53222 .19941 .52565 .1912 Mtetra
.659 .754 .92 r
.52565 .1912 .53222 .19941 .54439 .19486 .53786 .18662 Mtetra
.53786 .18662 .54439 .19486 .55661 .1903 .55012 .18202 Mtetra
.55012 .18202 .55661 .1903 .56889 .18572 .56243 .1774 Mtetra
.658 .754 .92 r
.56243 .1774 .56889 .18572 .58123 .18113 .5748 .17276 Mtetra
.658 .753 .92 r
.5748 .17276 .58123 .18113 .59362 .17652 .58723 .16812 Mtetra
.58723 .16812 .59362 .17652 .60606 .1719 .59971 .16346 Mtetra
.59971 .16346 .60606 .1719 .61856 .16727 .61225 .15878 Mtetra
.61225 .15878 .61856 .16727 .63111 .16261 .62484 .15408 Mtetra
.62484 .15408 .63111 .16261 .64372 .15794 .63749 .14937 Mtetra
.63749 .14937 .64372 .15794 .65639 .15325 .65019 .14464 Mtetra
.657 .753 .92 r
.65019 .14464 .65639 .15325 .66911 .14854 .66296 .13989 Mtetra
.66296 .13989 .66911 .14854 .68189 .14381 .67578 .13512 Mtetra
.67578 .13512 .68189 .14381 .69473 .13906 .68866 .13033 Mtetra
.68866 .13033 .69473 .13906 .70763 .13429 .7016 .12552 Mtetra
0 .302 .79 r
.01911 .36903 .02675 .37749 .03804 .36598 .02782 .37434 Mtetra
.824 .981 .695 r
.02782 .37434 .03804 .36598 .04736 .36756 .03973 .3593 Mtetra
.545 .675 .923 r
.03973 .3593 .04736 .36756 .05714 .36652 .04957 .35792 Mtetra
0 .093 .616 r
.04957 .35792 .05714 .36652 .06843 .35539 .05812 .36565 Mtetra
.832 .965 .639 r
.05812 .36565 .06843 .35539 .07802 .35625 .07043 .34801 Mtetra
.556 .682 .923 r
.07043 .34801 .07802 .35625 .08799 .35485 .08044 .34639 Mtetra
.158 .473 .894 r
.08044 .34639 .08799 .35485 .09952 .3423 .08982 .34974 Mtetra
.777 .974 .694 r
.08982 .34974 .09952 .3423 .10908 .34457 .10156 .33615 Mtetra
.557 .679 .92 r
.10156 .33615 .10908 .34457 .11926 .34268 .11172 .33449 Mtetra
.482 .656 .937 r
.11172 .33449 .11926 .34268 .13569 .29116 .12177 .33407 Mtetra
.314 .019 .294 r
.12177 .33407 .13569 .29116 .14056 .33243 .13318 .32328 Mtetra
.528 .648 .91 r
.13318 .32328 .14056 .33243 .15091 .33028 .1434 .32225 Mtetra
.571 .699 .928 r
.1434 .32225 .15091 .33028 .16102 .33068 .1538 .32024 Mtetra
.852 .718 .715 r
.1538 .32024 .16102 .33068 .17252 .31928 .16625 .30082 Mtetra
.128 .226 .697 r
.16625 .30082 .17252 .31928 .18294 .31772 .1755 .30958 Mtetra
.591 .705 .923 r
.1755 .30958 .18294 .31772 .1935 .31539 .1861 .30713 Mtetra
.513 .671 .935 r
.1861 .30713 .1935 .31539 .21616 .19538 .19658 .30618 Mtetra
.436 .175 .419 r
.19658 .30618 .21616 .19538 .21539 .30463 .20816 .29515 Mtetra
.531 .644 .906 r
.20816 .29515 .21539 .30463 .22612 .30211 .21876 .29405 Mtetra
.604 .716 .923 r
.21876 .29405 .22612 .30211 .23689 .29967 .22958 .29126 Mtetra
.489 .658 .936 r
.22958 .29126 .23689 .29967 .25022 .26904 .24025 .2907 Mtetra
.088 0 .07 r
.24025 .2907 .25022 .26904 .25912 .28858 .25194 .27935 Mtetra
.554 .664 .91 r
.25194 .27935 .25912 .28858 .27007 .28579 .2628 .2777 Mtetra
.615 .722 .922 r
.2628 .2777 .27007 .28579 .28108 .28281 .27384 .2746 Mtetra
.584 .708 .928 r
.27384 .2746 .28108 .28281 .29183 .28413 .28489 .27218 Mtetra
.815 .703 .742 r
.28489 .27218 .29183 .28413 .30368 .27112 .29692 .25724 Mtetra
.355 .452 .822 r
.29692 .25724 .30368 .27112 .31479 .26879 .30764 .2605 Mtetra
.616 .72 .92 r
.30764 .2605 .31479 .26879 .32603 .26541 .31888 .25732 Mtetra
.626 .731 .922 r
.31888 .25732 .32603 .26541 .33732 .26213 .33021 .25386 Mtetra
.598 .715 .926 r
.33021 .25386 .33732 .26213 .34848 .26197 .34154 .25107 Mtetra
.863 .731 .715 r
.34154 .25107 .34848 .26197 .36036 .24982 .35389 .23123 Mtetra
.223 .296 .728 r
.35389 .23123 .36036 .24982 .37174 .24757 .36472 .23911 Mtetra
.619 .721 .919 r
.36472 .23911 .37174 .24757 .38324 .24393 .37623 .23578 Mtetra
.638 .737 .921 r
.37623 .23578 .38324 .24393 .39481 .24008 .38783 .23196 Mtetra
.64 .74 .921 r
.38783 .23196 .39481 .24008 .40643 .23625 .39948 .22804 Mtetra
.634 .737 .922 r
.39948 .22804 .40643 .23625 .41809 .23279 .41118 .22427 Mtetra
.587 .709 .928 r
.41118 .22427 .41809 .23279 .42957 .23691 .42289 .22164 Mtetra
.771 .655 .735 r
.42289 .22164 .42957 .23691 .44173 .22036 .43498 .20851 Mtetra
.476 .569 .87 r
.43498 .20851 .44173 .22036 .45353 .21732 .44671 .20881 Mtetra
.632 .73 .919 r
.44671 .20881 .45353 .21732 .46541 .21332 .45862 .20504 Mtetra
.647 .744 .92 r
.45862 .20504 .46541 .21332 .47735 .20908 .47059 .20084 Mtetra
.652 .748 .92 r
.47059 .20084 .47735 .20908 .48934 .20472 .48262 .19649 Mtetra
.655 .751 .92 r
.48262 .19649 .48934 .20472 .50139 .20027 .4947 .19203 Mtetra
.657 .752 .92 r
.4947 .19203 .50139 .20027 .51349 .19576 .50684 .18751 Mtetra
.658 .753 .92 r
.50684 .18751 .51349 .19576 .52565 .1912 .51903 .18293 Mtetra
.659 .754 .92 r
.51903 .18293 .52565 .1912 .53786 .18662 .53127 .17831 Mtetra
.53127 .17831 .53786 .18662 .55012 .18202 .54357 .17366 Mtetra
.54357 .17366 .55012 .18202 .56243 .1774 .55592 .169 Mtetra
.55592 .169 .56243 .1774 .5748 .17276 .56833 .16433 Mtetra
.658 .753 .92 r
.56833 .16433 .5748 .17276 .58723 .16812 .58079 .15964 Mtetra
.58079 .15964 .58723 .16812 .59971 .16346 .59331 .15494 Mtetra
.59331 .15494 .59971 .16346 .61225 .15878 .60588 .15022 Mtetra
.60588 .15022 .61225 .15878 .62484 .15408 .61851 .14549 Mtetra
.61851 .14549 .62484 .15408 .63749 .14937 .6312 .14073 Mtetra
.6312 .14073 .63749 .14937 .65019 .14464 .64395 .13596 Mtetra
.657 .753 .92 r
.64395 .13596 .65019 .14464 .66296 .13989 .65675 .13117 Mtetra
.65675 .13117 .66296 .13989 .67578 .13512 .66961 .12636 Mtetra
.66961 .12636 .67578 .13512 .68866 .13033 .68253 .12153 Mtetra
.68253 .12153 .68866 .13033 .7016 .12552 .69551 .11668 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`80069oo`=Bo005D_eBo5;lD_aBo@03
D_`015;mD_`005;l5goo00<007ooOol0BGoo002?Ool3001ROol04E;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_d05Woo00<007oo0000BWoo002=Ool3001ROol00e;lD_eBo002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo000009Bo1Moo`03001oogoo04Qoo`00RWoo0`000goo00<007ooOol0
GGoo01MBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m01Moo`03001o
ogoo04Moo`00Qgoo0`00Hgoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;l
D_eBo000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069oo`0PD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoAIoo`03001oogoo04Io
o`00PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eoo`00P7oo0P00Hgoo02EBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00=BoE;l
Ool05Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1MOol0;5;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l
00EBoE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00HGoo03ABo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo049oo`00Lgoo0`00HGoo0U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00ABoE;lD_aBo1Moo`03001oogoo045oo`00LGoo
0P00HWoo03UBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;m
D_`05Goo00<007oo0000@Woo001^Ool3001POol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;m001Bo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001oogoo041oo`00Jgoo0`00HGoo
041Bo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoAMoo`03001oogoo03moo`00JGoo0P000goo00<007ooOol0Fgoo00=Bo5;mD_`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;l
D_aBo@02D_`FOol00`00Oomoo`0oOol006Ioo`<005moo`19DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d05Woo00<007ooOol0?Woo001TOol2001POol00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aB
o@02D_`FOol00`00Oomoo`0mOol0065oo`<0061oo`1?D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d05Goo00<007ooOol09Goo0`005Goo000eOol4000VOol2001OOol00e;lD_eBo002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0EOol00`00Oomoo`0V
Ool00`00Oomoo`0COol003Aoo`03001oogoo009oo`03001oogoo021oo`<0061oo`1EC_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol09Goo00<0
07ooOol04goo000iOol00`00Oomoo`0NOol20002Ool00`00Oomoo`1LOol2D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l5Goo00<007ooOol097oo00<0
07oo000057oo000/Ool60007Ool00`00Oomoo`0KOol3001OOol0G4kLD_e>o5;mC]aBoE;lD_e>o5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`0SOol0
0`00Ool0000DOol003Eoo`@001aoo`80061oo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Ioo`03001oogoo025oo`05001o
ogooOol0000COol003Eoo`03001oogoo01Yoo`<000moo`03@[eoogoo04ioo`1RC]aBoDkLD_e>g5;m
C]aBoDklD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoAAoo`8002=oo`05001oogooOol0000COol003Eoo`03001oogoo01Moo`<0019oo`03=8aoogoo
04Yoo`9>g006C]e>g4kLD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol07goo0`0000Aoo`000000
019oo`00=Goo1@004goo0P005Goo00<d[GooOol0AGoo06aRUeif?U/j>SXk>SYBoDkLC_e>g5;mC]aB
oDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`FOol00`00Oomoo`0gOol004Yoo`<00003Ool007oo01Aoo`03=8aoogoo04Aoo`03
HYMRUV:G00@j>`=>g005D_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eB
o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo1Eoo`03001oogoo00Qoo`@002]oo`00
B7oo0P006Woo00<d[GooOol0@goo06mRUeifHYMNUV:G>SXnFcXj>S]>g5;mC]aBoDkLD_e>g5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d05Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0:7oo0015Ool3000LOol00cB<
Oomoo`12Ool02V:GHYIRUejFHYMRUTkLB[a:g4Zl0TkL00ABo4klD_e>g09Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Io
o`03001oogoo00Eoo`03001oogoo009oo`03001oogoo02Qoo`00@goo0P007Woo00<nWCB]?Y`0?goo
07E6_4[MA[a:gEifHYMNUV:GGWIGT5M_C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0:7oo0010Ool3000POol00cB/=8`d[@0kOol0
1TkmC]a>oDkLC_e:_0=:g@0=GYIRUf:FEi1GL5N@B[a>g4ZlB]a:_5;mC_`00U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoE;lOol05Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0:7oo000nOol2000SOol0
0c2<=:ddS00iOol0ODkLD_e>g5;mC]aBoDkLB]e6_4[MA[aRUeifHYMGKeN@EfmGT4kLC_e>g5;mC]aB
oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
:7oo000kOol4000TOol00cB]=8`d[@0[Ool00fkF6AIoo`09Ool2C_`02U;mC]a>o4kLC_e>g4kmC]a:
gDZl0T[M00=RUejFHYL013Xk00=>g4kMC]`00TkL00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;l
D_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0D
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003Uoo`8000Aoo`03001oogoo025o
o`03=8`d[CB<02]oo`04J]E^mQTF6CL5Ool0Q5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmC]`Eg17K
5M`Eff:GGWIRUcXj?S/j>SiK>SYBoDkLD_e>g5;mC]aBoDkLD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001o
ogoo00=oo`@002]oo`00=Woo0`00:Goo00@nWCB/=8`d[BYoo`03J]I^mV[F008I5P0:6CI>g4kLC]a>
gDkLC_a>g5;mC]`2C_`06E;mC]a>o4kLC]e>g4kMC]`Eg1GKHYMRUV:GGYIRUdZlC]a:_4[LB[aBoDkL
D_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo015oo`800003Ool007oo039oo`00<goo0`00;7oo
00E2_C2<=:ddS4:m02Uoo`2?K_IZeVkf6AHM=aTF6CM:g4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e>g5;m
C]a>oD[LC_e>g6:GGWIRUejFHYMCKeN@B[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@0EOol00`00Oomoo`0aOol0035oo`8002moo`03=8`d[CB<008d[BQoo`05K_IZeVkFJ]I^mP03
6AH01TkMC]a>g4kLC]e>g09>o007D_e>g4klC_aBoDkLC_`00T[M015:_4[MHYIRUejFHYMRUUM`Dfm:
g4ZlC]a:_4[LD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d00000D_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0`Ool0
02ioo`<0035oo`05=:ddS3B]=8`h[@0XOol0LV[FK_IZeFkfJ]HI=aTF7CLI5TkmC]aBoDkLC_e>g5;m
C]aBoDkLD_e>g5;mC]aBoDJlB]e6_4[MGYIRUeifEi1CKeN@DfmBoDkLC_e>g5;mC]aBoDkLD_e>g5;m
C]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@<0000MD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0_Ool002aoo`@0039oo`03=8`d[3B<008d[BMo
o`05J]I^eV[FK_IZeP0200001DZlA[a6_4JlC_d00dkL00]>oDkLC_a>o5;mC]a>oDkLC_e>g4km009:
g@05B[aRUf:FHYMNUP04>S/2C]`01DkMC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m00000000D_d00e;l
00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eo
o`03001oogoo02moo`00:Woo0P00=Woo00Dd[C2<=:ddS3R]02=oo`1aB]e:_4kMB]a:gF[EK_IZeVkf
6AHM=`00B[a6W4ZmAYaBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_dAfd[MA[aRUejFHYLj>SiK
>SXn>dkLD_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@03000095;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02io
o`00:Woo0P00=Goo00@nWCB<=:ddS08d[B1oo`06C_e>g4kMC]a:gD[L0T[M00U^mV[F>YeZeVkF6AHI
=QTFC]d00dkL00IBoDkLC_a>g5;mC]`2C_`01U;mC]a>gDkLC]e>g08Ef`05HYMNUV:GHYIRU`04>S/0
1DkLD_a>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo006D_eBo5;lD_aBoE;l0P0000EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Goo00<007ooOol0;Woo
000@Ool50003Ool40004Ool40006Ool00`00Ool0000dOol023jL=:ddS3B]=8`h[Goo@[dEOol0=VKG
I[H]fRVi;MY:g4kMB]a>gD[LC_e>g4kmC]a:gDZlC]e:g3ZMJ]E^mV[F6CLI5Qdg6AI>gD[LC]e:g5;m
C]aBoDkLD_e>g5;mC]aBoD[LC_e>g4kmB]aRUejFHYMNMV:GGYI>g4ZlC]e:_09>g010D_e>g5;mC]aB
oDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`3
0000:U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo02eoo`004Woo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`800003Ool007oo039oo`04=:ddS3B/
=8`2=:d00goo=:eoo`0DOol016JfI[MV]bWI0RVi00=>g4kMB]`00TkL015>oDkLC]e>g3ZM>WdjWF[F
K]IZeVkF6AHI=QTF6CI>g4kM00=>g006D_e>g4klC_aBoDkL0Tkl00=BoDZlB]d00T[M00ENUV:GHYIR
UejF009CK`06C]a:_4[LB[aBoDkL0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo003D_eBo000008000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0
5Goo00<007ooOol0;7oo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol00Woo0P000goo00<007ooOol0<7oo00PdS3B]<8`d[CB<>:eoocS=57oo07=V]VKGI[IVebVi
;MXY^DkMB]a>gD[LC]e:g4kmB]a>oD[L>YdfO6kfJ]I^mV[EK_HI5QTg6AHM=dkLC_e>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLD_e6_4[MA[a:gEifHYMNUUM`DfmGT4ZlC]a:_4kMB[aBoDkLD_e>g5;mC]aBoDkl
D_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0030000<E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Eoo`03001oogoo02aoo`001goo1P001Goo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
02moo`04=:`dS3B]=8`2=:d00goo=:eoo`0COol2I[L01VKGI[IV]bVi:MTY^@9>g00>C]e>g4kLC]a>
gDkLC]e>g6kFJ]I^eV[FK]IZeP96_005B[a6_4JlC]a>o@02C]`00dklD_e>g002C_`01U;mC]a>oDkL
C_e:_09:g@05HYMNUV:GDfmGK`02Dfl00dkLC]e>g002C]`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eBo7oo01Aoo`03001oogoo02]oo`004Woo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo02ioo`08<8`d[CB<=:dd
S3R]Oolhc@Moo`03205oogoo00Uoo`1^I]MV]VKGI[IVedmaDi96_4ZlA[a>oDkLC_e:g4kmB]a:gDZl
C]e:g6kfJ]E^mV[F7CL004ZmAYa:_4JLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJl
HYMCKf:GGYHn>cXj?U]>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo0<0000iD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l01=oo`03001oo`0002aoo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo009oo`8000Ioo`8002eoo`05?Ydd[CB<=:`dS002=:d00goo=:eoo`05Ool22047Ool2
B]d01TJlB]e:gFKGI[IV]`9?TP0:Ci5:_4ZlB[a6_4ZlC]a>oDkLC]d2B]d024[LB]eZeVkFJ]I^eV[F
6CH3A[`01TZlA[a>o4kLD_e>g09>o00:D_e>g4klC_a>gDkLC]e>g4kM4M/25M/00f:GGYIRU`05>S/0
1E;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_`000020003D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007oo
Ool0:Woo000@Ool30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol0:Woo00Y2_CB<=:d`S3B]=8`h[CjL><dnW@Eoo`0310480P@1009oo`1`C]e:
g4kMB]a>gDJlB]e6_4[MI[IVefJfI]LY^BgJ:KU>gD[LC]e:g4kMC]a>oDkLC_e:g4[MB[a>gF[FK_IZ
eFkf6AHM=d[LC]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oDkL5M`Aff:GGYIRUeifHYM:
_4kLB[a>gDZlD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_`30000@5;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<0
07ooOol0:Goo000BOol00`00Oomoo`03Ool40004Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`0Y
Ool01CB<=:`dS3B]=8`00SB]00<h[CB]><d017oo0PP100Ybe00@AYa6W4:LC]e>g4kMB]a>g@9:g@09
A[a:gFJgI]MV]VJg:KT]fBVi009>g007C]e:g4kMC]a>oDkLC]d00T[M00Q:g3ZMJ]I^eV[F6CHI5QTf
0dkL00I>gDkLC_a>o5;mC]`2C_`03E;mC]a>o4kLC]e>g4kMC]aRUejFHYMNUV:G009CK`0:B[a>g4Zl
B]a>o5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l00000P000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00
D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomo
o`0XOol002Qoo`03001oogoo00Yoo`03001oogoo02Qoo`0:=:d`S3B]=8`d[CB<>:dd[CS==:d4Ool0
L@P2K]Abm00?A[a2W4JL@Ya6_4[LC]e:g4kM:U`^GBXl;UeV]VKGI[H]fRVi;MY:g4kMB]a>gD[LC_e:
g4kmB]a>oCYm>YeZeFkfJ]I^mV[E7CLI5QdgB]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]e6
_4[MGYIRUeifHYMNUU=_Ddi>gDZlC]a:_4kMC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_d00P0004MBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l01Eoo`03001oogoo02Qoo`00:7oo0`002goo00<007ooOol09goo00DdS3B]
=8`d[3B<00@d[@05><eoogooOol80@03L]@20102B]`01d[MB]a:g4[LC]e:g4kM008^G@05I[IV]fJg
I]MV]P02:KT02RgIC]a>g4kLC]e>g4kMC]a>gDkL0SZM00U^eV[FK]IZeVkF6AHI=QTF6CH00dkL00]>
oDkLC_a>o5;mC]a>oDkLC_e>g4km009:g@05B[a:gEjFHYMNUP04Dfl2C]`01TkMC]a>g5;lD_e>o09B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@02D_`30002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo02Moo`00:7oo00<0
07ooOol037oo00<007ooOol09Goo00/nW3B]=8`d[C2<=:ddS3R]=:`hcCB]00=oo`0XK]Abm6kDL_A^
e00@00m>gDZlC]e:_4kMB]a>gD[LC]eV]VKGI[IVefJfI]M6_4ZmA[a:_4[LC_e>g4kmB]a>oD[LC_e:
g6kfJ]I^mV[EK_H20000@TJLB[e6W4ZlC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]e6_6:G
GYIRUeif?U/j>Shk>SYBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7@<0001>D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l5Goo00<007ooOol09Woo000XOol00`00Oomoo`0=Ool00`00Oomoo`0TOol02d:m=8`d
[3B<=:ddS3B]B]a:gD[LB]d00SjM00<jWG;DL]@00g;D0P0@0d[L00=:gD[LB]d00T[M00U6_4[MI[MV
efJfI[M?LDnAA[`00dZl0dkL00=>gD[LB]d00T[M00Q:g6kFJ]I^eV[F6CH004Zl0dJl00I:_4kLC_a>
g5;mC]`2C_`03E;mC]a>o4kLC]e>g4kM4M]:gDZlHYMNUV:G00@j>`=>g005D_e>g5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol002Qoo`8000mo
o`03001oogoo00ioo`0392Uoogoo019oo`0D?Ydd[GJ`N]52O4:L?W]2W4[LC]e:_4kM>Yebm6kDL_A^
e7;dK]@0<080401NB]a>gD[LC]e:g4[MA[a:gDJlI]MV]VKGBg5?TTmaB[a6_4ZmA[a:_4kLC_e>g4km
B[a>gD[LB]eZeFkf>We^mV[E7CLI5TkMB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g1GL
4M]RUeifHYMNUV:G>SXnFcXj?S]>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDad30000EU<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`0UOol002Qoo`03001oogoo00moo`03001oogoo00eo
o`0390Qoogoo019oo`0==:`dS7KAM[1fd49l@Ya2O4[MB]a:gD[LB]d01W;D00T044JLAYa6W4[LC]e>
g4kMA[`00d[M00E6_6JgCg5VefJf008Y^@0:C]e:g4kLC]a>gDkLC]e>g4kmC]`3B]d01CYmK]IZeVkF
6AH00QTf00I>gDkLC]a>g5;mC]`2C_`055;mC]a>o4klD_e>g4kMC]a>gDkLHYINUV:GGYIRUUjFC]a:
_4[LB[`2C]`015;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aB
o0030002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@02D_`EOol00`00Oomoo`0TOol002Qoo`03001oogoo011oo`03001oogoo00aoo`0392Uoogoo00Mo
o`03K]H<eGoo00Qoo`1G<8ajdGJ`M]5f/006@Wa2W3ikB]e6_4[MA[a:gFkDL_A^e7;eK]@0<4:LA[a2
W4JLB]a>gD[LC]e6_4[MA[a:gBXlI]MV]VKG:KT]fRViC]e:g4kMB]a>gD[LC_e:g4kmB]`jWCYmK_IZ
eFkfJ]I^mQTF7CM:g4kMB]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]e6_6:GGYIRUeifDfm?
CTkLB[a>gDZl009>g00ED_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M00<0
001MDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m01=oo`8002Ioo`009goo00<007ooOol04Woo00<007ooOol02Woo00<T:2@8Ool027oo
0V[F00<<eGooOol01Woo00EfdGJ`M]1f/7KA00801@03B[a:gDZl00=:g@03B[abe7;D00=be0804008
@Ya6W4JLAYa:g4kMB]a>g@<^G@05I]MV]VJgI[MVe`03:KT05DkMC]a>g4kLC]e>g4kMC]a>gCYm>YeZ
eVkFJ]I^eV[F7CHI5QTfC]a>o@03C]`02U;mC]a>o4klD_e>g4kmC]a>oDkL0d[M00ENUV:FGYIRUe=>
00=CK`=>g006C]e>o5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00<0009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@02D_`DOol00`00Oomoo`0SOol002Moo`<001=oo`03001oogoo00Uoo`0390PT:Goo00Moo`0A
J]I^eVZe3?H<eD[MA[a:gDZl@[dnW7[AM[1fdGJ`N]5f/00200D0<4[MB[a:gDZlB]e6_4[MA[abmFkD
L_A^e00`0100<4ZlC]e:_4kMB]a>gD[LC]e:g6KGI[IVefJfI]MV]TZlA[a:_DJlC_e:g4kmC]a>oD[L
C_e:g4kmJ]E^mV[FK_IZe@80000_B[a6W4ZmC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6
_4[MGWIRUeifHYLj>SiK>SXn>dkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBo@030000
I5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<007ooOol08Woo000WOol00`00Oomoo`0DOol00`00Oomo
o`08Ool00b@Y90PT:006Ool4J]H33=D02d[MB[a:gDZl@[ef/7K@M[1fdGJ`M]000`0500M:gD[LB]e:
g4[M>YdnW@05L]@30103B]`00d[MA[a:g@02B]d02DJlI[MV]fKGI[I?LD]aB[a6_002B[`01TkMC]a>
g4kLB]e:g0=:g@08J]I^eV[FK]HI5P00A[a:_0=6_006D_e>g4klC]aBoDkL0Tkl00aBoDkLC]e>g4kM
C]`Efd[MHYMNUV:FGYH4>S/01DkMC]a>g4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo080009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol08Woo000EOol40004Ool40006Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool012@Y90PT:B@81Goo075ZeVkFJ[E^eV[FK]H<e@cfB[a:gDJlB]e:_7KA
M[1jdGJ`M]5f/4:L@Wa2W3ikC]e:g4kMB[`nWFkDL_A^e7;eK]Abm00@0300400`B]a>gD[LC]e6_4[M
A[a:gFJfI]MV]TnABg1?TDJlB[a6_4ZmA[a>oDkLC_e>g4[MB[a>gD[LK_IZeCZMJ]I^mQTF7CM:g4kM
B]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mB]a>oDkLC_dA^aGLGWIRUeifHYMNMShk>SXnFcXjD_e>g5;m
C]aBoDkLD_e>g5;mC_aBoE;l00<0001ZD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol0
0`00Oomoo`0QOol001Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomo
o`0FOol20006Ool012@892PT22@Y1Goo1V[F0`cE01=:_D[MB[a:gDZmM]5f/7K@M[1fdGJ`@Ya2O4:L
B]a:gD[LB]e:g006L]@00dJL@Ya6W002AY`01D[LC]e>g4[MA[`00d[M00AV]TmaI[MVe`8Y^@03C]a>
gD[L009>g006C_e>g4kMC]a>oD[L0T[M00TjWF[FK]IZeQdf6AHI=TkLC]d00dkL00IBoDkLC_a>g5;m
C]`2C_`05DkMC]a>gDkLC]eNUV:FGYIRUejFHYI:_4kLB[a:g4ZlD_e>g5;lC_aBo@03D_`300000e;l
D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04goo00<007ooOol087oo
000IOol01000Oomoo`0017oo00<007ooOol00goo0P006Goo00<007ooOol00Woo00HT22@Y90PT:B@8
:2T3Ool0K6kFJ[E^eV[FK]IZ]A3f0016_4:LA[e6_4[MA[a:gGJ`M]5f/7[AM[1fdCik@Ya2O4:LA[a:
gDJlB]e6_7;eK]Abm6kDL_D044JL@Ya6_4:LC]e:g4kMB]a:gDJlB]e6_2iMI[IVefJf;MXY^BgJB]a>
gD[LC]e:g4kmB]a>oD[LC_dfO3ZMJ]I^mV[EK_HI5Qdg6AI>gD[LC]e:g4kMC]aBoDkLD_e>g5;mC]aB
oDkLB]e6_4[MA[aRUeifHYMNMV:GCdiCKdZlC]a:_4kMB[aBoDkLD_e>g0<0001bC_aBoDklD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol087oo000<Ool60007
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol06Woo00P007ooOomoob@X90PT:D9l0d:L
00=6_4JmA[d01V[F01@<eDJLA[a2W4JLB[e:gDZlB]ef/7KAM[1fdGJ`00E:_4[LB[a:gDZl0d[M17;D
00E^e00`0116W4:L0096W00:C]e:g4kMB]`^GBYM;UeV]fKGI[H2I[L01BgI:KTY^DkLC]d00dkL00i>
gDkLC]e>g3ZM>We^eV[FK]IZeVkF6CHM=QTF0TkL00I>oDkLC]a>o5;mC]`2C_`01TkmC]a>oDkLB]e:
_09:g@09HYMNUV:FCdiCKTm>Ddi>g4kM00=>g0<00003D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol07goo000EOol40003Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0KOol04@00Oomoob@892Ub/WKC?Wa2W49l@Ya6
_4[MA[a^eVZeK]H00V[F05l<eA3fB[a:gDJlB]dnWD:mM[1jdGJ`M]5f/7[A00D01TZlB]e:_4[MB[a:
gDJlB]e^e7;eK]Abm00@030044kMB[a>gDZlC]e:g4kMB]a>gFJfI]MV]VKGI[IVedJlB[a6_4ZmC]a>
oD[LC_e:g4kmB]a>oD[LK_IZeFkfJ]I^mV[EB[e6W4ZlAYaBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aB
oDkLB]e6_4[MGWIRUeifHYLj>Shk>SXnFdkL00<0001iC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol07goo000EOol00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2000MOol0200090Qbdg;BL]=bdT:L@W`3@Y`0
14JlA[e6_CIm0f[F0`cE00]:_4[MB[a:gCjMM]5f/7KAM[1fdGJ`00<01@09B]a:gD[LB]e:g3jM>Yeb
e6kD00=be0040100<00@B]d3B]`00d[MA[a:g@02B]d01VJfI[MV]fKGBg1;L@9:_004A[a:_4kLC]d2
C]`2B]d02D[LB]e:gFkFJ]I^eV[F7CH00002A[`01TZlA[a>o4kLD_e>g09>o00@D_e>g4klC]a>oDkL
C_e>g4[MB[a:gEjFHYMNUV:F>S/300001TkLC]e>g4kLD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Aoo`03001oogoo01ioo`005Goo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Goo00efdg:bM]=b/WKC00Q:gDJl
B]e6_4[M<W`fO@02J]H0FfZeK]IZePcf3=E:gDZlB]e6_4[MM[1fdGJ`N]5f/7KA?W]2W49l@Ya:_4kM
B]a>gCZLL_E^e7;dK]AbmFkD0300400`011>gD[LC]e:g4[MA[a:gDJlI]MV]VKGBg1?LD]@B[e6_4Zl
A[a:_DkLC_e>g4kmB]a:gDZlC]eZeVkfJ]E^mQTF7CLI5TkMB]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;m
C]a>oD[LC_e>g1GL4K]RUeif00<00021>SXn>cXjD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDklD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01eoo`00
5Goo1@000goo10001Goo00<007ooOol05Woo0TJl00Y6_DJLA[`jWCjML]9bdg;BL]=bdP802006B[e6
_4ZmA[`fOC9m1F[F0`cE01A:gDZmB]e:_4[MM[1fdGJ`M]5f/7KA@Wa2W49l@Ya:g4[MB]a:gFkD0g;D
00=^e7;DAY`014JL00I>gD[LC]e>g4[MA[`2B]d01VKGBg1V]fJg;MTY^@9>g007C]e:g4kLC]a>oDkL
C]d00T[M00U:g4[M>Ye^eV[F7CHI=Qdf6AH00TkL00I>gDkLC_a>g5;mC]`2C_`025;mC]a>o4kLC]e>
g4kMC]`300002ejFHYMNUT[LB[a>g4ZlD_a>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01=oo`8001moo`009Woo00<007ooOol0
5Goo01MSeEoEA[e2W4Jm@Y`nWG:bM]=b/WKCL[9fd`0800T02009A[a:gDJlJ]IZ]FkF009ZeP1D3=D0
04:LA[a2W4[MA[a:gDJlN]5f/7KAM[1fdGJ`@Y`nNd:L@Wa2W4JlB]e6_4[MK]AbmFkDL_A^e7;e@Ya6
W4:LA[a:g4kMB]a>gD[LB]e6_4[M:UaVef:fI]LY^BgJ:KU>gD[LC]e:g4kMB]a>oD[LC_djOCZM=Wa^
mV[FK]IZeAdg6AHM=d[LC]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[M0P0008QNMV:GGWIRUeif
Dfi?CTkMB[a>g4ZlD_e>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03001oogoo01aoo`009Goo00<007oo00005Goo16?E0TJl
00Y6_DJLL]=bdW;CL]9bdg;B@Ya2O0=2W003A[a6_DJm00EZeP0E3=E6W4JLA[a2W4JLB[e:gDZlM[5f
/7KAM[1f/@05B]e:_4[LB[a:gDZl00=:g@05K]Abe7;DL]A^e0020303AY`01d[LC]e:g4kMB]`^GBYM
009V]`06I]MV]VJg:KT]fBVi0TkL00M>gDkLC]a>g4kMC]a>g@02>Yd3J]H01FkF6AHM=QTf7CH00dkL
00U>oDkLC_a>o5;mC]a>oDkLC_d00`0000I:gDZlB]eNUV:GGYH4Cdh2C]`01TkMC]aBo5;lD_e>o09B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IB
oE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02
D_`DOol00`00Oomoo`07Ool5000?Ool002Eoo`8001Eoo`0GHmDAff:gHYH]nbWJB]e6_4KMA[afdg:b
M]=b/WKCL[92W3il@Ya2O4[MA[a:g@02J]H0@VZeK]IZeQ3f3=E:gDZlB]e6_4[M?YefdGJ`M]5f/7KA
M[001P05B]e:_4[MB[a:gDJlB]e6_4[MK]AbmFkDL]@0400a011>gDZlC]e:g4kMB]a>gD[LI]MR]VKG
I[IVef:fB[e6_4ZlA[a>oDkLC_e:g4kmB]a>oD[LC_eZeVkFJ]E^mP80000<AYa:_DJLB[a>g5;mC]a>
oDkLD_e>g5;m0`0008iBoDkLD_e6_4[MA[aRUeifHYMNMSiK>SXn>cXjD_e>g4kmC]aBoDkLD_e>g5;m
D_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Ao
o`03001oogoo00Moo`05001oogooOol0000?Ool002Eoo`03001oogoo00eoo`0;A[e6_4JmA[`Ag17K
4M`Aff:gHYIRU`03;OX3A[d01DJlL]=bdW;CL]800W;C00Q2W49l@Ya2W4JmA[a6_CIm0f[F01P<e@ce
3=E:gDZlB]e:_3jMM[1fdGJ`M[5f/7KA00D01P0500I:g4[MB]a:gCZM?Yd2L]@026kDL]Abe00`0100
<4[LB]d2B]`2B]d01DJlB]e:gFKGI[H00VJg00=;L4]@B[`00TZl0dkL00=>gDkLB]d00T[M00E:g4[M
J]I^eV[F008M=P090016_4ZlA[a:_4kLC_a>g5;m00<0000=D_e>g4klC]a>gDkLC]dAfd[MB[aRUUjF
HYL013Xk0dkL00E>gE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol01goo00<007ooOol047oo000UOol00`00
Oomoo`0<Ool08F_DIm=6_D:LA[e2W17L4M]R]f:FH[MNUV:g:MX]nbWJB]e6_4KMA[afdg:bM]=b/WKC
00Q:gDJlB]e6_3Im<Wa^eP02J]H0B6ZeK]H<eA3f3=E:gDZlB]e6_7KAM[1fdGJ`M]5f/7KA?W]2W49l
@Ya:_4kMB]`nWCZLL_E^e7;DK]Abm@0@0300400aB]a>gD[LC]e6_4[MA[a:gFJfI]MR]T]aBe1;L4Jl
B[e6_4ZlC]a>oDkLC_e>g4kMB]a:gDZlK_IZeVkFJ]DM=aTF7CM:g4kMB]a>g@<0002FD_e>g5;mC]aB
oDkLD_e>g4kmB]`Eg16kHYMNMV:GGWIRUcXj?U/j>ShkC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007oo
Ool01goo00<007ooOol03goo000UOol2000=Ool02FOCJm=Wdf_DA[a6_DJlH[MRUP02HYL01V:gHYI6
_4JlA[e6W08jW@03?YebdW;C009bd`06L]802@08B[e6_4Zm0SIm1F[F0PcE00X<m@cEB]e:_D[MB[af
/GJ`M]5f/09f/@0:00I2O4:L@Wa:gD[LB]e:g7;DK]@3L]@00fkD0316W003AY`014kLC]e:g4kM0T[M
00U6_4[MI[M;L6JfI[LY^BgIB]`00TkL00I>gDkLC]e>g4kmC]`3B]d01D[LJ]IZeVkF6CH00Qdf00XM
=`00000005;mC]a>o4kLD_e>g09>o00@D_e>g4kMC]a>gDkLHYINUV:GGYIRUUjFC]a:_4[LB[`2C]`0
0e;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mOomoo`0BOol00`00Oomoo`08Ool00`00Oomoo`0>Ool002Eoo`03001oogoo
00]oo`0PFUINMS8k=S`f>cHl@Ya6_D:lH[MNUV:gHYISeEoDA[e2W4Jm@Y`nWG:bM]=b/WKCL[9fd`08
00T024[MA[a:g@9ZeP14J[E^eV[FJ]H<eDJm@Ya6_4:LB]e6_4[MA[afdGJ`M]5f/7KA00D01Sik@Ya2
O4[MA[a:gDJlL]A^e7;eK]Abe6kD0352W4JL@Ya6_4[LC]e:g4kMA[a:gDJl;UeV]VKGH[H]fRVi;MY:
g4kMB]a>gD[LC_e:g4kmB]`jWCImK]IZeFkfJ]I^eP<0000LC]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkL
D_e>g4[MA[a:gEifHYMNMV:GGWI?CTm=C]a:_4kMB[`2C]`0Oe;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Aoo`03001o
ogoo00Qoo`03001oogoo00eoo`009Goo00<007ooOol00Woo0VOE00=2W4Jm@Y`00goo00AWdeYFFUIN
MP<f>`06A[e2_D:mHYMR]f:F0f?E00EOeDJlA[a6_DJL00=bd`05L]9bdg;CL]=2O002@Y`00dJmA[a6
_@06J]H02@cEAYa6W4Jl@Ya:gDZmB]e:_002M[400gKAM[001P0200H01DZlB]a:_4[MB[`00T[M00=b
e6kDL]@00W;D0P0`00=:g4[MB]`00T[L00=>gD[LC]d00RiM00QV]VJgI[MV]fJf;MTY^BgI0dkL00U>
gDkLC]e>g4kM>WdjWF[FK]H00`0000DM=aTf7CHM=Tkm00=>g00:D_e>g4klC_aBoDkLC_e>g4kmC]`3
B]d01EjFHYINUTm>Cdd00Tm>00I>gDkLC]a>g4kMC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l0000
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol00goo
00D007ooOomoo`0000moo`0097oo00<007ooOol00Woo00MWeF_eImE6_D:LA[e2W002Ool08eifFUEN
MUYF=S`b>cHl=S]6_D:LA[eRUV?EGYIR]bWJ;O/YfT[MA[a6gDJlM]=b/WKCL[9fdg:b@Y`nO4:LA[a:
gDJlB]d00V[F03aZ]FkFJ]H@mPcEB]e:_4[MA[a2_CjMM]5f/7KAM[1fd@0500H01D[MB[a:gDZlB]e6
_4[MA[abe6kDL_E^e00a0100<DZlC]e:_4kMB]a>gD[LC]eV]VKGH[IVefJfI]M6_4ZmA[a:_4[LC_e>
g4kmB]a>oD[LC_d30000Y6kFJ]DM=`00B[a6W4ZmAYa>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
B]e6_6:GGWIRUeifHYLj>SiK>SY>oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`04Ool3
000@Ool002Aoo`<0009oo`9We@06IoEWeD:m@Ya6_D:L0UYF00mNMUYFFUIJETJmA[a6_DJl4M`Afa7L
4M]RUf:FHYL00bgj0dJm00YbdW;CL]=bdg;BL]<02D:L@Wa2W096_@03A[a6_F[F00=ZeP0;3=D@mPcE
B]e:_4[MB[`nWGJaM]5f/002M[4400H01d[MB]a:gD[L?YdjWCjM009be003K]Abe00`0080<09:g003
B]e:g4[M009:g@09A[a:gFJgI[MV]VJgAe1;L4Jl009:_006C]e>g4kLC]a>gD[L0P00019:gF[FJ]IZ
eVkFJ]HM=TJlB[a6_4ZlA[aBoDkLC_a>g5;mC]`2C_`01U;mC]a>gDkLC]e>g09:g@04HYMNUV:FGYH3
>S/00dkLC]e>g002C]`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00Ool05goo000TOol0
<`00OomoogooJoENMV:G;Q/b6bgj@[dnW4:mFUENMUYFGWIJEF_DIk=6_D:LA[e2W17L3M]R]f:FH[MN
URgk:MX]nbWJB]e6_4KML[9fdg:bL]=b/P0900Q:gDJlB]dbOCIm<Wa^eP02J]H0=FZeK]H<eA3fA[a:
gDZlB]e6_7KAM[1fdGJ`M]5f/4:L?W]2W49lC]e:_4kMB]`nWFkDL_E^e7;DK]@0<@0@034044kMB]a>
gD[LB]e6_4[MA[aVefJfI]MR]RgJ:KT]fTJlB[e6_4kmC]`00`000:]:_4kMB]a:gF[EK_IZeVkF6AHM
=d[LC]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kmC]a>oA6k5MaNMV:GGWIRUeif?S/j>SiKC]aB
oDkLD_e>g5;mC]aBoDkLD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol05Goo000JOol40006Ool01P000CP1604h
GWINU`9NMP06;Q/b6bhK@[e2WD:m0eYF00Y[dfOCIm=WddJmA[a6_DJlHYMRUP=RU`05HYI6_4JlA[e6
W002>Yd00g;CL]9bd`02L]<300T014ZmA[a:_DJl1V[F0PcE00H@mTZlB]e:_D[MB[`2M[403WKAM[1f
/GJa@Ya2O4:L@Wa:gD[LB]e:g7;DK]@3L]@00fkDAYa6W002AY`01DkMC]a>gD[LC]d00T[M00U6_6Jg
I[MV]fJf;MTY^BgIB]`00`0000E>g4kMC]a>oD[L00=:g@=ZeP057CLI=QdfC]a>g@03C]`01U;mC]a>
o4klD_e>g09>o00EC]e>g4kMC]a>gEjFHYINUV:GGYI?CD]=C]a:_4[LC_aBoDkLD_a>o5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004
D_eBo5;lD_`COol00`00Oomoo`0EOol001Uoo`03001oogoo009oo`03001oogoo00=oo`0j001oogoo
GWIRUeifGYMNMV:G;Q/b6bgj@[dnW5ifFUENMUYFGWHb>cHl=S]6_D:LA[e2_6:gGYIR]f:FHmEO]4Jm
@Ya6_CYlM]=b/W;CL[9fdg:b00T0200900Q:gDJlB]e6_6[FJ[E^eV[F4?H004Jm@Y`2A[`0:4[MA[a:
gGJ`M]5f/7KAM[1fd@06B]e:_4[MB[a:gDJlB]e6_7;DK]AbmFkDL]@044Jl@Ya6W4:LC]e:g4kMB]a>
gBYL;UdZ?6KGI[IVebVi0`000;=:g4kMB]a>gD[LC_e:g4km=W`jWF[FK]IZeFkfJ]HM=aTF7CLI5Tkm
C]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gDJlHYMNMV:GGWIRUd/]Cdi:_4kLB[a>gDkLD_e>g5;m
C]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l01=oo`03001oogoo01Aoo`006Goo00<007ooOol00Woo00<007ooOol0
0goo0P0000=ooejGGWH00Uif00UNUfOEImE2W4Jm@Ya2_D:MGWH00eYF13Hk00=6_D:m@[d00V:G00=R
UV:GHYL00Rgj0TJl00=6_G;BL]<00W;C00EbdW;CL]=2W49l0092W003A[e6_4Jm00EZeP0:4?I2W4JL
AYa6_4ZlB]e:_D[MM[02M[401gKAM[001P06B]e:_4[L009:g@05B[a:gG;DL]A^e002L]@03P0a031:
g4[LB]e:g4kMB]a>gD[L;UdZGFJgI[H3000012Vi;MTY^DkM0dkL00I>gDkLC]e>g3ZM>Wd2J]H02FkF
J]IZeTJlB[a6_4ZlA[a>o@02C]`00dklD_e>g002C_`01TkmC]a>oDkLB]e:_09:g@09HYMNUV:FBde?
CT]=Cde>g4kM009>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol04goo000I
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0;ejGGWIRUfOEIoEWeDJm@Ya6_@0b
05=JEUifFUENMUYF=S`b>cHl=S]6_D:LA[eRUV:gGYIR]bWJ;O/YfT[MA[a6gG:bM]=b/W;CL[9fdg:b
@Y`nO4:L@Wa:gDJlB]d00V[F011Z]FkF3=D@mTJlB]e:_4[M?Ya2_GJ`M]5f/7KAM[1fd@801P0GB[a:
gDZlB]e6_4[MA[a:gFkDL]A^e7;eK]@0<@0@C]e:_4kMB]a>gD[LC]e:g0030000^V:fI]MV]TZlA[a:
_DJlC_e:g4kmC]a>oD[LC_e:g6kFJ]E^mV[FK]HI5P00AYa:_4JLB[a>g4kmC]aBoDkLD_e>g5;mC]aB
oDkLD_e>g4[MA[a:gEifHYMNMV:G>SXn>cXj?U]>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oA=oo`03001oogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00=N
MUjGGWH00Woo00Db6bhK@[e2W4Jm00=JEP0:GWIJEUYFIm=6_DJlA[e6_17L4M/3HYL01F:FHYL]nRgj
A[`00dJm00ebdW;CL]=bdg;BL]<02DZmA[a:_DJl=WdbO@04J]H0213e3=D@mTZlB]e:_4[M?Yd2M[40
17KAM[1f/GJa0`0600M:g4[MB]a:gCZM?Ye^e003L]@016kDL]@0<00a0d[L00=:gDJl00000P0000E6
_6JgI[MV]fJf0097C`0:B[a6_4ZlB[a>oDkLC]e>g4kmB]`2B]d03VkFJ]IZeV[FK]HM=TZlA[a:_4Jl
B[a>g5;mC]`2C_`03U;mC]a>o4klC]e>g4kMC]`AfdZlB]eNUV:GGYH2>S/01Shk>S/j>dklD_e>g09B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0COol00`00Oomoo`0BOol001Uoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00=oo`03GWIoogoo009oo`0R<Q/]nT:m?Ya2_EYEGWIJEUifIk=[dfNc
A[e2W4Jm@YaR]ejFH[MNUV:gGYH]nbWJ;O]6_4[MA[a6gG:bM]=b/W;CL[8200T01d[MA[a:gC9m=WeZ
]FkF009ZeP0QJ[D@mPcE4?I6_4[MB[a:gGJ`M]5f/7KAM[1fdGJ`@Ya2Nd:LB]a>gDZlC]e:g7;DK]Ab
mFkDL]A^e00a0300<D[L00<00031A[a:gDJlB]eR]VKGI[IVebVi;MXY^DkMB]a>gD[LC_e>g4kmC]a:
gDZlC]eZeVkFJ]E^mV[F7CLI5TkMB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_dA^a7LGWIR
UeifHYMNMTkMB[a>g4ZlC]e>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001B
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol0
4Goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool20009Ool2<Q/012hK<Q]2WEif0eYF00EWdfNc
Im=WddJm0092_@9RU`05HYIRUf:GGmEOe002A[`00dJm>YdjW@02L]<017;BL]=bdg;C0P0900A6_4Zm
A[a:_@IZeP09@Ya6W4JLA[a:_4[MB[e:gGJ`009f/@07M]5f/GJa@Wa2W49l@Y`00T[M00E:_4[MB]eb
e6kD00=be00903000000001:g4kMC]a>gD[L00=:g@09I[IV]fJgI[LY^BgI;KU>gD[L009>g009C_e>
g4kMC]a:gD[LB]eZeVkF009ZeP037CHM=adf009>g006C]e>g4kLC_aBoDkL0Tkl01IBoDkLC_a>o4kM
C]a>gEjFHYMNUV:FGYI;CD/]B]a:_4kLB[aBo4klD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_ao
o`0BOol00`00Oomoo`0AOol001Yoo`@000Eoo`03001oogoo00Uoo`0X@Ya6_D:LA[dnW5ifFUE[deYF
GWHb>cHl=S]6_D:LA[eNUV:gGYISeEoDHmE2W4Jm@Ya6_D:LM]=b/W;CL[9fdg:b00T02009A[a:gDJl
B]d2J]H01fZeK]IZ]Q3f@Ya6_D:L0096_00EB]e6_4[MM[1fdGJ`M]5f/007B[a:gDZlB]e6_4[MA[a:
gFkDL]A^e7;e00800038@Ya6_4:LAYa:g4kMB]a>gD[L;UdZG6KGH[IVefJf;MXY^BgJB]a>gD[LC]e:
g4kmB]a>oD[L>YdfO6kfJ]I^eV[EK_HI=Qdg6AIBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6
_4[MGWIRUeifCde;;Dm=B[a>gDZlC]a:_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA9oo`<0
019oo`001Goo0P0000=oo`0000006Goo00<007ooOol02Woo00I2W4Jm@Y`0DUYFGWH3FUH4=S/00dJm
@[eRU`02HYL01F:FHYL]nRgjA[`00dJm00E6_7;CL]=bdg;B009bd`03@Ya2O4:L0096_@03A[a6_F[F
00AZeP054?I2W4JLAYa6_002?Yd00gJaM]5f/@02M[401gKA00H01TZlB]e:_4[L009:g@03B[a:g@00
00800003L]@0<00a00=:g007B]e:g4kMB]a>gBYM;Ud00VJg00QV]VJgI[L]fBVi;MU>g4kM0dkL00E>
gDkLC]e>g6kF00=ZeP06K]IZeTZlA[a:_4Jl0TkL00]>oDkLC]a>o5;mC]a>o4kLC_e>g4km009:g@08
B[aRUUjFHYMNUV:F>S/n>`=>g006C]e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo
015oo`03001oogoo011oo`0017oo00<007ooOol00P006Woo00<007ooOol02goo0412W4Jm@YaNMUYF
GWIJEEifFUI6_D:LA[e2W4Jm@YaR]`gKH[MNUV:g;MX]ndJlB]e6_4KML[9fdg:bL]=b/WKC@Wa2W3il
@Ya6_4[MA[a:gC9mJ]IZ]FkF3=D@mTJlB]e:_4[M?YafdGJ`M]5f/7KAM[001`0600M:_4[MB[a:g@<0
003?L_E^e7;DK]Abm@0`035:_4kMB[a>gD[LC]e:g4kMH[IVefJfI]MR]TM?@bm:_4JlB[e>g4kmB]a>
oDkLB]e:_4kMB]a^eV[EK_IZeQdg001:_4JLB[a6W5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a:
gDJlHYMNMV:GGWHnFcXj?S]>g5;mC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01=o
o`03001oogoo00moo`0017oo00D007ooOomoo`0001Uoo`<000eoo`03@Ye2_EYF009JEP0:GWIJEVOC
Ik=6_DJlA[e6_17L4M/3HYL00f:F;OX]nP02;OX3A[d02W;BL]=bdg;CL]802DJlB[e6_4Zm0SIm00<b
OF[FJ]H00V[F00L@mA3E4?I:_4[MB[a:g@03M[401gKAM[5f/D9l@Ya2O4:L00<00008B]djWG;DK]Ab
e6kDL]A^e080<006035:g4kMC]a>gDJl0d[M00=V]VJgI[L00dM?0TZl0156_4ZlC]a>oDkLC]e>g4[M
B]a:gF[FK]HjOF[F7CHM=adf009>g006C]e>g4klC]aBoDkL0Tkl00MBoDkLC]e>g4kMC]a>g@024M/0
1EjFHYINUV:GGYH00SXk00Hn>dkLD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
01=oo`03001oogoo00ioo`0017oo00D007ooOomoo`0001Uoo`03001oogoo00eoo`0i@[dnW4:mFUEN
MUYFGWIW/V_CIk9Wdd:LA[e2W6:gGYIR]ejFH[MNUTJm@Ya6_D:L?YdjWG;CL[9fdg:bL]<02@0:A[a:
gDJlB]dbOCImJ[E^eVZfJ]H<eA3f3=D@mTJlB]e6_4[MM[1fdGJ`M]5b/7KA00<0001:C]e:g4kMB[a>
gFkDL]A^e7;eK]Abe4:LA[a2W4JLB]a>gD[LC]e6_4[MA[aVef:fI]MV]RgJ:KT]fT[LC]e:g4kMC]a>
oDkLC_e>g4[MB[a>gCImK]IZeFkf7CHM=aTFC]e:g4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmB]a>
oEifHYMNMV:GGWIRUdZlC]e:_09>g02:D_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
4goo00<007ooOol03Woo0004Ool01@00Oomoogoo00006Goo00<007ooOol03Woo00=2_D:MGWH00eYF
00=NMSHk=S/00SHk0d:m00ARUf:FHYMRU`9Oe096_003A[djWG;C009bd`03L]9bdg;C00<02@04A[a:
_DJlB[d5J]H02A3f@Ya6W4JLA[a:_4[MB[efd@02M[4300001006@Wa2W49l0d[M00Q:_4[MK]Abe6kD
L]A^e00a14JL00E:g4kMC]a>gDJl009:g@0:;UeV]VJg;KT]fBVi;MU>g4kMB]`2C]`01TkMC]a>gDkL
>YdjO@AZeP8M=P067CM>g4kLC]a>gDkL0Tkl00IBoDkLC_a>o5;mC]`3B]d01TZlHYINUV:GGYIRUP9;
;@05B[a:g4ZlC]a>o002D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009B
o003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03
001oogoo00eoo`000goo0P000Woo0P006Goo00<007ooOol03goo02i2_EYFGWIW/UifFUINMS8k=S`f
>dJm@Ya6_EjFH[MNUUoEGkAOeEndA[e2W4JmL[9fdg:bL]=b/WKCL[92W3il@Ya6_4[MA[a:gFZfJ]IZ
]F[FJ[H@mT:LA[e2W096_03RB]d00000001fdGJ`M]401P07B[a:gDZlB]e6_4[MA[abmFkDL]A^e7;e
0300<DZlC]e:_4kMB]a>gD[LC]dZ?2iMI[IVef:fI]LY^BgJ:KT]fTkLC_e:g4kmB]a>oD[LC_dfOCZM
J]E^mV[FK]HI5Qdg7CHM=dkLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MA[aRUeifHYM7;4]=
Bba;;DkLD_e>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`COol00`00Oomo
o`0<Ool0029oo`80015oo`03@[eJEUif00=JEP05GWHf>cHk=S]6_@02@[d016:GGmARUV:G0bgj0dJm
00IbdW;CL]=bdg:cL]<2@Y`01D9l@Ya6_DJmA[`01F[F00@@mA3fB[a:g@<0009f/@0;M]5f/GJaM[40
1`06B]a:_4[MB[a:g002B]d024ZlL]A^e7;DK]Abe00`0343B]`01TkMB]a>gD[LC]eV]P=V]`08I[I:
_4ZlB[a6_4ZlC]a>g@=>g003C]e>g4kM00AZeP067CH004JlB[a6_4Zl0dkL00]>oDkLC_a>o5;mC]a>
oDkLC_e>g4km009:g@04GYIRUUjFHYL3>S/01ChkC]a>g4kLC]d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo5;l01=oo`03001oogoo00aoo`008Woo00<007ooOol04Goo02UNMUYFGWIJ
EEifIk9Wdd:LA[e2W17L3K/Ag5jFH[MNURgk;MX]ndJlB]e6_4KML[9fdg:bL]=b/WKC@Wa2W3il@Ya6
_4[MA[aZeVZfJ]IZ]A3f00<0003UB]e:_4:mL[1fdGJ`M]5b/7KA00H01`06C]e:g4kMB[a>gCZM?Ye^
e7;eK]Abe6kD0340<4kMB[a>gDZlB]e6_4[MA[a:gF:fI]MV]TM?@bi:_DJlB[a6_4ZmC]a>oDkLC_e:
g4[MB[a:gF[FK]IZeFkF7CHM=dJLB[a6W4ZlC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmB]a>oDJlB]eN
MV:GGWHn>cXj?U/j>ShkC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
4goo00<007ooOol02goo000QOol00`00Oomoo`0BOol3FUH02UifFUIWdfNcA[e6_4Jm4M/Ag6:F0f:G
00ERURgj;OX]nTJl00=6_@0:L[=bdg;CL]=b/`09A[a:_DJlB[d2=Wd3J]H200024?D01A3fB[a:gDZl
M]400gJa01YfdGJaM[52O4:L@Wa:gD[LB]e:g3jMK]Abe6kDL]A^e7;D0300<@0`C]e:g4kMC]a:gDJl
0T[M00YV]fJfI[MV]bgI:KT]fDkLC]e:g09>g003C_e>g4kM009:g@03B]aZeV[F009ZeP8M=P0:7CM>
g4kLC]a>gDkLC_a>g5;mC]`2C_`02E;mC]a>gDkLC]e>g17K4K]RU`03GYH014kLB[a:g4Zl0TkL00=B
o4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04Woo0P0037oo000QOol00`00
Ool0000COol08eYEGWIJEVOCHk9WdfNbA[e2W4JmGYIR]ejFH[MNUUoDFkA6_D:LA[djO3jML[9bdg:b
M]=b/W;C00T02TJlB]e6_4[MJ[H00`0000EZ]V[F@Ya6_D:L0096_03TB]e6_7KAL[1fdGJaM]5b/4:L
@Wa2W49k@Ya:g4kMB[abmFkDL]A^e7;eK]@0<D:LA[a2W4kMB]a>gD[LC]e6_4[MA[aVef:fI]LY^BgJ
:KT]fT[LC]e:g4kmC]a>oDkLC_e:g4[MB[a^eV[FK]HI5Qdg7CHM=d[LC]e:g4kMC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4kmB]aRUeifHYMNMT/]Aba>g4ZlC]e:_5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l4goo00<007ooOol02Woo000QOol2000DOol00eifFUIWd`02Ool3=S/0
0dJm@[e2_@02HYL01F:FGmAO]5oDGk@00TJl00=6_DJLL]<00W;C00=b/g;CL]<00`0900A6_@000000
00EZeP094?I2W4JLAYa:gDZlB]e:_D[M00=f/@07M]401T[LB[a:gDZlB]`00T[M00M:_7;DK]Abe6kD
L]@0<@04AY`01DkMB]a>gD[LC]d00RYM0VJg00EV]VJg;KT]fBVi009>g007C]e:g4kMC]a>gDkLC]d0
0SZM16[F0adf00HM=dkLC]a>g4kmC]`2C_`01U;mC]a>oDkLC_e>g0=:g@=NUP0:Bbe7;4//B[a>g4Zl
B]a:_5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo015oo`8000]o
o`003goo100017oo10001Woo00<007ooOol057oo01aNMWooOomoocHl<S/f?3Hk=Sa2W6:gGYIR]ejF
H[L]fRgk:MY:gDJlA]e6_7KCL[9bdg:bL]=b/P<0003cA[a:gDJlJ]IZ]V[FJ[EZePcE4?I2W4Jm@Ya2
_CjL@[ef/GKAL[1fdGJa00L01T[MB[a:gDZlB]e6_4[MA[abeFkDL]E^e7;E031>gDZlC]e:_4kMB]a>
gD[L;UdZ?6KGI[IVef:f;MXY^BgJ:KU>oDkLC_e:g4kmB]a>oD[LC_eZeVkFJ]E^eV[FB[a6W4ZlAYa:
_4kLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDJlB]e6_4[MGWIRUeifHYLj>SiKC]a>oDkLD_e>g5;mC]aB
oDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00ioo`<00003Ool007oo00Yoo`00
3Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo01Uoo`0;A[e6_4Jm
A[a6_D:mHYL=ff:GHYIRU`03;OX3A[d00g:cL]=bd`030002@Y`01D9l@Ya6_DJmA[`016[F00P@mQ3e
4?I:_4[MB[`n_CjM0WJa00=fdGJaM[400P0700d01P07B]a:gD[LB]djWCjMK]Abe6kDL]A^e0020340
2T[MB]a:g4[LC]e:g4kMB]aV]fJf0VJg0T<^0dZl00E6_4kLC]a>gDkL00=:g@03B]a:gF[F00=ZeP0;
7CI:_4JlB[a6_4ZlC]a>o4kLD_e>g002C_`01U;mC]a>oDkLC_e:_09:g@05HYMNMUjFGYHn>`02>S/0
0dkLC]e>g002C]`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d02Woo
100017oo00<007ooOol02Goo000COol01000Oomoo`0017oo00<007ooOol00goo0P006goo0116_D:L
A[e2W17L3K]R]ejFH[MNURgk;MX]nbWJB]e6_0<0003jL[9bdg:b00Y6_4[MA[a:gC9m=WeZ]F[FJ[IZ
eVZe4?H<eD[MA[a:gDZlB]eb/7KAM[5fdG:`M]52O4:L@W]2W4[LC]e:_3jMK]AbeFkDL]E^e7;E0300
<@0`C]e:g4kMB]a:gDJlB]e6_6KGH[IVef:f@bm6_4ZmA[a:_4JlC_e>g4kmC]a:gD[LB]e:_6kFJ]I^
eV[E7CLM=TkMB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mB]a>oDkLC_d=^a7LGWIRUeifHYMNMSiK>SXn
FdkLD_e>g5;mC]aBoDkLD_e>g5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d6Ool30008
Ool00`00Oomoo`09Ool001=oo`04001oogoo0004Ool00`00Oomoo`02Ool2000NOol01DJlA[e6_6:G
HYH00f:G00=RUTJlA[`00`0000<jWG;CL[<00g;C0P0900A6_4ZmA[a:_@IZeP084=D@mQ3eB]e:_4[M
B[e:g@=f/@0AM]5f/D:L@Wa2W49lB]e:g4[MB]abe6kDL]A^e7;DK]@0<@03AY`01dkMB]a>gDkLB]e6
_4[M009V]`05I[IV]bfi;MU:g002C]`01TkMB]a>gDkLC_e>g0=:g@04B]aZeV[FJ]H37CH02TkMC]a>
g4kLD_e>g4klC]aBoDkL0Tkl00IBoDkLC]e>g4kMGWH2GYH02V:GGWINUTZlC]a:_4[LC_aBoDkL0U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo0=oo`<000aoo`03001oogoo
00Qoo`003goo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo00M2W4Jm@[aR
]ejFH[MNUP030000JT:LA[djO7;CL[9bdg:bL]=b/P0:00T02TJlB]e6_4[MJ[IZeVZeJ]H@e@00@Ya6
_D:LB]e6_4[MA[afdG:`M]5f/GKA00I2W49l@Ya2Nd[MA[a:gDJlL]E^e7;EK]Abe@0`AYa2W4Jl@Ya>
gD[LC]e:g2iM:S`^GF:fI[MR]VKG:KT]fT[LC]e:g4kMB]a>oD[LC_e:g3ZM=We^eV[EK]IZeVkF7CHM
=adfC]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MA[a:gEifHYMNMV:G0P0009E:_4kLB[a>gDkL
D_e>g5;mC_aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l008000moo`03001o
ogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo
00A6_D:m@[eRU`<00003HYL]nRgj0096_003A[eb/g;C009bd`06L[=bdg;C@Ya2O4:L0TJm00=6_6[F
J]H00f[F00<@mDJl@Y`00TJL00E6_4ZlB]e:_GKA00=f/@801`04B]a:_4[MB[`3B]d01FkDL]A^e7;D
K]@00P0a00Y:gD[LB]a:g4kMB]a>gD[L;UdZG@=V]`05I[H]fBfi;MT]^@02C]`01dkMC]a>gDkLC]dj
OCZM00EZeP05B[a6_4ZlA[a>o@03C]`02U;mC]a>o4klC_e>g4kmC]a>oDZl0T[M00=RUeifGYH01000
00M>g4kMC]a>g5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;l
D_`@Ool00`00Oomoo`08Ool000moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo01moo`18A[d00000GYIRUejFH[L]nRgk:MY:gDJlA]eb/W;CL[9bdg:bL]=2O4:L?Wa2W4Jl
B]e6_6[F<WeZeVZe4?H@eD[MA[a:gDZlB]dnW7KAM[5fdG:`M]401P0700I:gDZlB]e:_4[MA[a:gFkD
L]E^e7;EK]@4<@0`C]e:_4kMB]a>gD[LC]e:g6JgH[IVef:f0P000<9:_DJlB[a6_4kmC]a>oD[LC_e:
g4kmJ]E^eV[FK]IZeB4g001:_4JLB[a>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlHYMN
MV:G>SXnFcXj?U]>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l3goo00<007ooOol027oo000?Ool50003Ool40005Ool2000NOol300000a7L3M]RU`02
HYL00f:FHYL]nP02;OX3A[d03CZML]=bdg;CL[<02TJlB[e6_4Zm<WdfOC9m00AZeP074?H@mD[MB[a:
gDZlB]d00gJa00=fdGJa00L00`0700M:gD[LB]e:g3jMK]Abe003K]@01G;D0300<@0aB]d00T[L0T[M
00I6_4[MB]eV]fJfI[L200002DJlB[a:_4ZlA[a>gDkLC_e>g003B]d5J]H27CH02TZlA[a:_4kLD_e>
g4klC]aBoDkL0Tkl00Y>gDkLC]e>g4kM3K/A^ejFHYMNMP8j>`06?S/j>e;lC_aBoDkL0U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l3goo00<007ooOol027oo000P
Ool00`00Oomoo`0JOol30004Ool0of:GGYIR]ejFHYMNUTJm@Ya6_D:L?YdjWCjML[9bdg:bL]<02@0:
A[a:gDJlB]dbOCImJ[EZeVZfJ]H<eA3f4=E:gDJlB]e6_4[ML[1fdGJaM]5b/D:L@Wa2W49kC]e:g4kM
B[abeFkDL]E^e7;EK]A6W4:LA[a2W4kMB]a>gDJlB]e6_4[MH[IV]f:fI]LY^BgJB]a>gD[LC]e:g4km
C]a>oDkLB]e:g6kFJ]E^eV[FK]HM=R4g7CI>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e>g4km
GWIRUeifHYMNMTkMB[a>g4ZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0035;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@ioo`03001oogoo00Qoo`0087oo00<007ooOol05goo0`0027oo00IR
Uf:FHYMRUe^dFk<2A[`00dJmAY`jW@02L]<02W:cL]=bd`0:00T02TJlB[e6_4Zm1F[F00T@mT:LAYa6
W4[MB[a:gDZmM]400gJa00IfdGJa00M2O4:L@W`3B]d014ZlK]A^e7;D0VkD00P0<DJLAYa6W4kLC]e:
g4kM0T[M00E6_4[M:UeV]fJf00<]f@0;B]a>g4kLC]e:g4kMC]a>gDkL>YdjO@05J]H27CH01dkLC]e>
g4kLC_aBoDkL009>o006D_e>g4klC_a:gDZl0T[M00ARUeifGYINUP800004B]a:_4kLB[`2D_`01E;m
C_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00=Ool00`00
Oomoo`08Ool001moo`03001oogoo01Eoo`<000aoo`0PHYMNUV:gFk=Oe5^cA[e2W4Jm@Yabdg:bL]=b
/W;CL[92W3il@Ya6_4[MA[a:gFZfJ]IZ]F[FJ[I6_4:LA[e2W096_007B]e6_7KAL[5fdG:aM]400P07
04A:_4[MB[a:gDJlB]e^e7;EK]AbeFkD1340<4JL@Ya6_4[LC]e:g4kM:S`^GBXlI]MR]VJgH[H]fRVi
;MY:g4kmC]a>oD[LC_e:g4km=W`jWF[FK]IZeFkFJ]HM=adf8CM>g4kmC]aBoDkLD_e>g5;mC]aBoDkL
D_e>g4[MA[a:gDJlHYMNMV:G0`0009UBoDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d03Goo00<007ooOol01goo000OOol2000COol3000?
Ool2HYL2Ool3;OX3A[d01TJlL]=bdg;CL[=bd`92W005@Wa2W4JmA[e6_005J]H01a3eB]e:_4[MB[a:
gCjM009f/@04M]5f/GJaM[4200L014[LB[a:gDZl0d[M0fkD00Ebe6kD0340<D[M00=:g006C]e:g4kM
B]aV]fJf0fJg00A6_4ZlB[a:_0=>g005C]e>g4kMC]a>g@05J]H200001DZlA[a:_4kLC_d00TkL00=>
o5;mC]`00Tkl00i>oDkLC_e>g4[MB[a:gEjFHYMNMUjF>S/n>cXk0TkL00E>gDkLD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003
001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol037oo00<007oo
Ool01goo000OOol00`00Oomoo`0?Ool3000GOol092gj;O/]fT[MA[a6gG:bL]=b/W;CL[9bdd9l@Y`n
O4:LA[a:gDJlJ]IZ]V[FJ[EZeQ3EB]e6_4[MB[a2_G:aM]5b/GKAL[5fd@<01`0IC]e:g4kMB[`nWFkD
L]E^e7;EK]Abe@0`135:_4kMB[a>gDJlB]e6_4[MA[aV]f:fI]L00P000<E6_4ZmA[a:_4kLC_e>g4km
C]a:gD[LB]eZeFkFJ]I^eQdf8EM6W4ZlAYa:_4kLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oDkL4Ma6_4[M
GWIRUeif?U/j>SiK>SYBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l00aoo`03001oogoo00Moo`007goo00<007ooOol037oo0`006goo0bgj
0dJm00ab/g;CL]=bdg:c00Y6_4ZmA[a:_C9m=Wd5J]H01a3f4?D@mTZlB]e:_7KA00=f/@0:M]5f/GJa
@Wa2W49lB]e:g4[MB]`2K]@017;DK]A^e6kD0`0a00A>g4kMB]a>g@9:g@06A[a:gFJgI[MV]VJg0RgI
00U:g4kLC]a>gDkLC]e>g4kmB]`00T[M16[F00DM=adf7CI>g4kM00=>g006D_e>g4klC_aBoDkL0Tkl
00I>gDkLC]d=^a7KGWH2GYH02V:GGWI:g4ZlC]a:_5;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol02Woo00<007ooOol01goo000OOol0
0`00Oomoo`09Ool3000OOol06D:LA[e2W3jML[9bdg:bL]=b/W;C00T02P09B]e6_4[MJ[IZeVZeJ]IZ
]Q3f0016_D:L0096_01>B]e6_7KAL[5fdG:aM]5b/D:L@Wa2W49kB]e6_4[MA[abeFkDL]E^e7;E0316
W4:LA[a:g4kMB]a>gDJlB]e6_4[MH[IV]f:f;MXY^BgJB]a>gD[LC]e:g4kmC]a>oDZlB]e:g6kFJ]E^
eV[F7CLM=R5GB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_eNMV:GGWIRUeif0P0009a>gDZl
C]a:_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`:Ool00`00Oomoo`07Ool001moo`8000Qoo`80029oo`96_003A[e6W7;C009bd`05L[=b
dg;C@Ya2O002@Y`00dJmA[a6_@05J]H02A3f@Ya6W4JLA[a:_4[MB[efd@03M[401WKA00M:g4ZlB]e:
_0=:g@=^e004L]A^e00a0343AY`014[LC]e:g4kM0RYM00EV]VJgI[MV]fJf00<]f@=>g007C]e>g4kM
C]a>gCIm>Yd016[F00HM=Qdg7CHM=TkLC_d2C]`03dklD_e>g4klC]a>oDkLC_e>g4[MB[a:gEjFHYMN
MP030003C]`01TkMC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eoogoo00Qoo`03001oogoo00Moo`007Woo00<007ooOol01Goo0`009Goo
0?m:gDJlA]e6_7;CL[9bdg:bL]=b/d:L?Wa2W4JlB]e6_6[FJ[IZeVZeJ]H@mA3fA[a:gDZlB]dnW7KA
L[5fdG:aM]5b/@0800M:gDZlB]e:_4[MA[a:gFkDL]E^e7;EK]@4<@0`C]e:_4kMB]a>gD[LC]eR]VJg
H[IVef:fI[M6_4ZmA[a:_4[LC_e>g4kmB]a>oD[LC_eZeFkFJ]I^eQdf0016W4ZlAYa:_4kLC_e>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLB]e6_6:GGWIRUeif?U/j>SiKC]aBoDkLC_e>g5;mC]aBoDkLD_eBo5;m
C]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d000QBo5;mD_aBoE;lD_eBo5;m2Woo00<007oo
Ool01Woo000NOol00`00Oomoo`02Ool3000YOol3A[d02W:cL]=b/g;CL[=bd`0:@Ya2O4:L0TJm00a6
_6[FJ]IZeVZf4?H@mA3fB[a:gDZl?[d3M[400gKAM[5f/@0300L01d[MB]a:gD[L>Ye^e7;D00=^e005
L]@0<@0aB]a:g@02B]`2B]d01TJlB]eV]fJgI[IV]`800004A[a:_4ZlB[`3C]`00dkMB]a:g@02B]d4
J]H02AdfB[a6_4ZlA[a:_4kLD_e>g002C_`02U;mC]a>o4kLC]e>g4kMC]a:gDZl0UjF00YRUcXj>S/j
>chkC]aBo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`015;mD_aBo5;l2Woo00<007ooOol01Woo000NOol00`00Ool00002000]Ool024[MA[a6gFjb
L]=b/g;CK[8200X0H4[MA[a:gC9m=WeZ]F[FJ[IZeVZe5?H@mA3fA[a:gDZlM]5b/GKAL[5fdG:aM]52
O4:L@W]>gD[LC]e:_7;EK]AbeFkDL]E^e0@a0304<D[LC]e:g4kMA[a:gDJlI]MR]VJgH[IVebfi;MY:
g4kMB]a>gDkLC_e>g4kmB[a:gD[LK]IZeFkFJ]HQ=adfC]e:g4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e>
g4kmB]a>o@fk4M]NMV:GGWIRUdZlC]e:_09>g02JD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`9Ool00`00Oomoo`06Ool001ioo`<0
031oo`07>Yeb/g;CL[=bdg:cL]<00`0:00=:_DJlB[d00V[F00EZ]V[FJ]IZeT:L0096W005A[a:_4[M
B[efd@05M[4014:L@Wa2W49l0d[M00A:_6kDK]Abe09^e0081356W4JLAYa>g4kMB]a>g@9:g@05A[aV
]fJgI[MV]P03;MT02D[LC]a>g4kmC]a>gDkLC_e:g002B]d4J]H01Adg7CI>g4kLC]d00TkL00=>o5;m
C]`00Tkl00]BoDkLC_a>g4kMC]a>gEjFHYMNMUjF00800005B[a:g4ZlC]a>o002D_`01E;mC_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l27oo00<0
07ooOol01Woo0004Ool50003Ool40004Ool40007Ool00`00Oomoo`0`Ool05W;CL[=bdfjbL]=b/d:L
?Wa2W49lB]e6_4[MJ[IZeVZeJ]IZ]QCf@Ya6_D:L0TJl035:gDJlM]5b/GKAL[5fd@07B]e:_4[MB[a:
gDJlB]e^e7;EK]AbeFkD1340<DJL@Ya6_4[LC]e:g4kM:S`^GF:fI]MR]VJgH[H]fRfi;MY:g4kMB]a>
oD[LC_e:g4km=W`jW@02J]H06FZeK]HM=R4g7CIBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]e6
_4[MGWIRUeif00<0002OC]aBoDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Moo`03001oogoo00Ioo`001Woo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`80035oo`04L]=b/g;CL[<2
Ool00d:L@Wa2W002A[d03DJlJ]IZeV[FJ[IZeQ3e4?I:_4[MB[a:gCjM00If/@0600P01d[LB[a:gDZl
0d[M0fkD00Ebe6kD1344<D[M00=:g003C]e:g4kM009V]`05I[IV]fJgI[M6_003B[`3C]`01DkMC]a>
gDkLC]d016[F00DM=P00A[a:_4Jl009>g00;C_e>g4kLC_aBoDkLC_a>g4kmC]a>o@02B]d024JlGYIN
UV:G>SXn>cXk?S/3C]`01DkMD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`01goo00<007ooOol01Woo0006Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol01goo00<007ooOol0;Woo00=^/W;COol00goo
03@02T:L?Wa2W4JlB]e6_6[FJ[IZeVJe5?H@mACfA[a:gDZl@[eb/GKAL[5fdG:aM]401`0800M>gD[L
C]e:_3jMK]AbeFkDL]E^e7;E0304<DZlC]e:_4kMA[a:gDJlB]eR]VJgH[IVe`80000>A[a:_DJlB[a:
g4kmC]a:gDZlB]e:g4[MJ[E^eP9ZeP2j7CI:_4JLB[a6W5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4km
3K]:gDJlHYMNMV:G>SXnFcXj?U]>g5;mC]aBoDkLD_e>g5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m1Woo00<007ooOol01Woo0006Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol027oo00<007ooOol0<goo0P0:
00I:_DJlB[dbOCImJ[H3J]H01fZf4?H@mA3fB[a:gDZl00Mf/@07@Wa2W49lB]e:g4[MB]`00VkD00]b
e6kDK]A^e0@a0344<DkLC]e:g4kM009:g@06A[aV]fJgI[MV]VJg0RgI00U:g4kLC]a>gDkLC]e>g4[M
B]`00T[M16[F00XM=adfC]a>g4kMC]a>o4kLD_e>g09>o006D_e>g4klC]a>gDkL0Pfk00QRUeifGYIN
UTkLB[a:g4Zl0TkL00=Bo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol01Woo00<007ooOol01Goo0006Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol02Goo00<007ooOol0<Woo00l02P0;
00Y:gDJlB]eZ]V[FI[EZeVZfJ]I2W4Jm@Y`00TJl04a:gDJlM]5b/GKBL[5fdG:a@Ya2O4:L@W]:gDJl
B]e6_7;EK]AbeFkDL]D0<DJL@Ya6_4[LC]e:g4kMA[a:gDJlI]MR]VJgH[H]fRfi;MY:g4kMB]a>gDkL
C_e>g4[MB[a:gD[LJ]IZ]FkFJ]HQ=adfC]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmB]aRUeif
HYMNMP800004C]a:_4kMB[`2C]`0W5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Ioo`03001oogoo00Eoo`001Woo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Yoo`80039oo`07@Ya2O4:L@Ya6
_DJlA[d00V[F00AZ]V[FJ]HDmP=6W004A[a:_4[MB[d5M[401@07B]a:_4[MB[`00d[M0fkD00A^eFkD
1344<@=6W004B]a>gD[LC]d2:Ud01FJfI[MV]fJgI[H00bgI0dkL00I>gDkLC]e>g3ZM=Wd5J]H00adf
7CLM=P02C]`02dkmC]a>o4klD_e>g4kmC]a>oDkLC_d00T[M00A6_5jFGYIRU`<00006C]e>g4kLC]a>
gDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo00Aoo`03001oogoo00Eoo`0017oo0`0017oo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo00aoo`03001oogoo031oo`13@Y`nO4:LA[a:gDJlJ]IZ]SImI[EZeQ3e
5?I6_4[MB[a:gCjLM]9b/GKAL[5fdW:a00P01d[MB[a:gDZlB]e6_4[MK[AbeFkDL]E^]0@a035>gDZl
C]e:g4kMB]a>gF:fI[MR]VKGH[IV]dJlB[e6_4ZlB]a>oDkLC_e:g4kmB]aZeVZeK]H00V[F0P000;]6
W4ZlAYaBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]eNMV:GGWIRUcXj?U/j>TkmC]aBoDkLC_e>
g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo004Ool00`00Oomoo`05Ool000Ioo`03001oogoo00=oo`@000Aoo`@0011oo`03
001oogoo031oo`03@Ya2O4:L0096_@0<A[`bOF[FJ]IZ]V[F4?HDmTZlB]e:_3jm1WJa0P0800P01d[M
B]a:gD[L>Ye^e6kE0fkD00E^e@@a135:g4[M009:g09:g@06A[a:gFJgI[MV]VJg0P0000A6_4ZlB[a:
_0=>g004B]e:g4[MB]d4J]H02R4g7CI:_4JlB[a6_4klC]aBoDkL0Tkl00MBoDkLC]e>g4kMC]a>g@02
B]d035ifGYINUShk>SXn>cXkD_e>g5;lC_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`02Ool00`00Oomoo`05Ool0
02Uoo`03001oogoo031oo`0oB]e6_4[M<WdfOC9mJ]IZ]V[FI[DDmQ3e5?I6_4[MB[afdG:aM]9b/GKA
L[5fdT9l@Ya2NdkMB]a>gDZlL]E^e7;EK[AbeFkD1340<@@aB]a>gD[LC]e6_4[MA[aVef:fI[MR]RgJ
;KT]fT[LC]e:g4kMC]a>oDkLB]e:_4[M009ZeP30J[E^eQdf8ELM=TkMB]a>gD[LD_e>g5;mC]aBoDkL
D_e>g4kmC]a>oD[L4M`=^f:GGWIRUeifC]a:_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0goo00<0
07ooOol01Goo000ZOol00`00Oomoo`0`Ool01TZmA[a:_DJlJ]IZ]P9ZeP085?H004JLAYa6_4ZlB]e:
_@Ef/@05L[52W49l@Ya2O003B]d014ZlK]A^e6kE0VkD00P4<DJLAYa6W4kLC]e:g4kM0T[M00E6_6Jg
I[MV]bfi00<]f@0:B]a>g4kLC]e>g4kMC]a:gD[LB]d4J]H00adf8CLM=P02C]`01TkMC]a>o4klD_e>
g09>o006D_e>g4kMC]a>gDkL0UjF00YRUeif000004kLB[a:g4ZlD_e>o09Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0=o
o`03001oogoo00Eoo`00:goo0P00<Goo00a:gDJlB]e6_6[FI[EZeVZf5?I2W4Jm@Y`2A[`0<D[MA[af
dG:aM]9b/GKA00M:gDZlB]e:_4[MA[a:gFjdL]E^e7;EK[@4D@@aAYa2W4JlB]a>gD[LC]dZ?2YMH[IV
]f:fI[LY^BgJ;KT]fT[LC_e>g4kmB]a>oD[L>YdfOFkF009ZeP0GJ[DQEadf8ELM=U;mC]a>oDkLD_e>
g5;mC]aBoDkLD_e>g4[MA[a:gEifHYMNMP040000Y4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`3
Ool00`00Oomoo`04Ool002eoo`03001oogoo031oo`0=A[a6_F[FJ]IZ]V[F4?HDmTZlB]e:_4[M?Yd0
0gJa00=b/GJaM[400P0800A:g4ZlB]e:_0=:g@=^e005K]D4<@@a135:g@03B]`00dkMB]a>g@02I[L0
1FJfI[MV]dZlA[`00dZl0dkL00A>gDkLC]e>g0AZeP068CL004ZlA[a:_4Jl0TkL00Y>oDkLC_a>o5;m
C]a>oDkLC_e>g0=:g@08GWINUUjF?S/j>Shk>S]>g@=>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0Woo00<0
07ooOol017oo000^Ool00`00Oomoo`0`Ool0;C9m=WeZ]V[FI[EZeQ3e5?I6_4[MB[a:gG:aM]9b/GKA
L[5fdP0700P01dkMB]a>gDZl?Ye^e7;EK[AbeFkD1340<@AA135>gDZlC]e6_4[MA[a:gF:fI[MR]P02
0000dTZlA[a:_DJlB[a>g4kmC]a>oDZlB]e:g6[FJ[E^eV[F8EM6W4ZlAYa:_4kLD_e>g5;mC]aBoDkL
D_e>g4kmC]a>oD[LB]e6_6:GGWIRUcXj?U/j>SiK>SYBoDkLD_e>g5;mC]aBoDkLD_e>o5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
Ool000Ioo`00;goo00<007ooOol0;goo00<fOC9mJ]H00V[F00UZ]QCf4?HDmTZlB]e:_D[ML[400gJa
00Ub/GJa@Wa2W49lB]e:g4[MB]`00VkD00=^eFkDK]@01DJL00=>gD[LC]d00T[M00E6_6JgI[MV]fJf
008]f@0;C]e:g4kLC]a>gDkLC]e>g4kmB]a:g@04J]H00adf8CM>g002C]`01TkMC]a>o4kLD_e>g09>
o006D_e>g4kMC]a>gDkL0UjF00eRUeifGYI:_4kLB[a:g4ZlD_e>g5;lC_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lOol00006Ool0031oo`80031oo`08J]IV]F[FJ[Iooa3eA[e2W096_00aB]e6_7KAL[5fdW:aM]9b
/@08@Wa2W49kB]e6_4[MA[abeFkDL]E^]7;E@Ya6W4:LA[a2W4kMB]a>gDJlB]e6_2iMH[IV]bVi;MX]
^DkMB]a>gD[LC]e:g4kmB]a>oCIm>Yd00V[F01QZ]FkF7CHQEd[LC]e:g4kMC]aBoDkLD_e>g5;mC]aB
oDkLB]e6_4[MGWIRUeifHYL20000ZDZlC]a:_4kMC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
00Ioo`00<Woo00<007ooOol0;Woo00EZeVZfJ]IooaCf00=6W006A[a:_4[MB[ef/G:a0gJa0P0800=:
_4[MB[`00d[M0fkD00E^eFkD135:g4[M00=:g003C]e:g4kM008ZG@04I[IV]fJgI[L3;MT02TkMC]a>
g4kLC]e>g4kMC]`jWCIm16[F00<Q=adf8CL00dkL00Y>oDkLC_a>o5;mC]a>oDkLC_e>g0=:g@03GWIN
UUjF00<00007C]a>gDkLC]aBo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo007D_eBo5;lD_aBoGoo00001Woo000cOol00`00
Oomoo`0]Ool00fZfJ]Ioo`02Ool031CfA[a:gDZlB]dnW7KBL[5fdW:aM]9b/@<0200HB[a:gDZlB]e6
_4[MK[AbeFkDL]D4<@ABB[a>gDZlC]e:_4kMB]a>gF:fI[MR]VJg0P000<e6_4ZmA[a>oD[LC_e>g4km
B]a>oD[LJ]IZ]FkFJ]HQE`00B[a6W4ZlC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlHYMNMV:G
GWHnFcXj?U]>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo004Ool00`00Oomoo`03Ool003Aoo`03001o
ogoo035oo`074?HDmTZlB]e:_4[ML[400gJa00ab/GJa@Wa2W49l@Ya:g4[MB]`jWFkDK]D3K]@41340
1dkMB]a>gDkLB]e6_4[M009V]`05I[IV]`00B[a6_002B[`01TkmC]a>gDkLB]e:g09:g@AZeP0:8CLM
=TZlA[a:_4kLC_a>g5;mC]`2C_`01U;mC]a>gDkLC]e>g09:g@0:HYMNMUjF>S/n>cXj?S]>o5;mC]`2
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;l
D_d00e;l00=BoGooOol01Woo00<007ooOol00goo000eOol2000aOol0kaDF4?DDmTJlB]e6_4[ML[5f
dW:aM]9b/GKB@Wa2W49kC]e:g4kMB[abeFkDL]E^]7;EK]A6W4:LA[a2W4kMB]a>gDJlB]e6_6JgH[IV
]f:f;MX]^DkMB]a>gD[LC_e>g4kmC]a:gDZlB]e:g6[FJ[E^eQdf8ELM=TkMB]a>gD[LD_e>g5;mC]aB
oDkLD_e:g4kmC]a>oD[LHYMNMV:GGWIRUdZlC]a:_4kMC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_d02goo00<007ooOol00goo000g
Ool00`00Oomoo`0_Ool2AY`01TJlB[a:gDZmB]eb/@=f/@05L[40249l@Ya2O003B]d014ZlK]A^e6kE
0VkD1DJL00=>gD[LC]d00T[M00E6_6JgI[MV]f:f008]f@0:C]e:g4kLC]a>gDkLC]e>g3ZM=Wd5J]H0
0adf8CLM=P02C]`01TkmC]a>o4klD_e>g09>o003D_e6_4[M009:g@04GWINUUjFHYL200001dZlC]a:
_4[LD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=B
o0moo`03001oogoo00=oo`00>7oo00<007ooOol0;goo03E6_D:LA[a6_4[MA[a:gG:aM]9b/GKB00P0
2DZlB]e:_4[MA[a:gFjdL]E^e7;EK[@4DTZlC]e:_4kMB[a>gD[LC]dZ?2YMH[IV]f:fI[L]^BgJ;KU>
oD[LC_e>g4kmB]a>oD[LJ]IZ]FkF009ZeP2_J[E:_4JLB[a6W5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e6
_4[MA[a:gEifHYMNMSiK>SXnFdkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m00004Woo00<007ooOol00goo000iOol00`00Oomoo`0_Ool00d[MB[a:g@02
?Yd2M[400g:aM[5f/@0300P00dZlB]e:_003B]d3K]@01FkE1344<D[LB]d00d[L00=>gD[LC]d00VJg
00ER]VJg000004Jl009:_006C]e>g4kLC]a:gD[L0T[M16[F00XQE`00B[a6_4ZlA[a>o4kLD_e>g09>
o006D_e>g4kmC]a>oDJl0T[M00URUeifGYHj>chk>SXn>dkLC]d00TkL00=Bo5;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`4Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003Yoo`80
031oo`0aB]e:_4[MA[afdW:aM]9b/GKBL[52W49k@Ya:g4kMB[`nWFkDL]E^]7;EK]@4D@@a159:g4kM
B]a>gD[LB]e6_4[MH[IV]f:fI[L]^BgIA[a:_DJlC_e>g4kmC]a:gDZlB]d00V[F0:UZ]F[F7CHQEd[L
C]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLC_e>g4km2K/=^eifHYMNMV:G>SXnFcXjD_e>g5;mC]aBoDkL
D_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo008Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003ao
o`03001oogoo02ioo`04B]e:_D[MB[`3M[402G:aM[52O4:L@Wa2W4[LB]e:g002K]@016kEK]A^e6kD
0dJL00A>g4kMB]a>g@9:g@05A[aV]fJgI[MR]P03;MT02T[LC]a>g4kmC]a>gDkLB]e:g4[M16[F00<Q
=R5GC]`00TkL00I>gDkLC_a>o5;mC]`2C_`02E;mC]a>gDkLC]eNMUjFGWIRU`0200001dZlC]a:_5;l
C_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0;Ool00`00Oomoo`0?Ool00`00Oomoo`02
Ool003eoo`03001oogoo02moo`19A[a:gDJlM]9b/GKBL[402DZlB]e:_4[MA[a:gDJlL]E^e6kEK[Ab
e@@aAYa2W4JlB]a>gD[LC]dZ?2YMH[IV]f:fI[MR]RgJ;KT]fD[LC]e:g4kmB]a>oD[L>YdfOF[FJ[IZ
eVZe8ELM=R5GC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eNMV:GGWH00`0008I:_4kLB[aB
oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m4Goo00<007ooOol03Woo00<007ooOol00Woo000nOol00`00Oomo
o`0_Ool01SjMM[5b/GJaL[5f/@802004B[a:gDZlB]`2B]d024ZlK]A^e6kEK]@4D@@aB]d3B]`00dkM
B]a>g@02I[L01F:fI[MV]fJgA[`00dZl0dkL00A>gDkLC]e>g0AZeP058EL004ZlA[a:_003C]`02Tkm
C]a>o4klD_e>g4kmC]a>oDkL0T[M00URUeifGYINMShk>SXn>dkLC]d00TkL00=Bo5;mD_`00U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oGooOol04goo00<007ooOol03Goo00<007ooOol00Woo000oOol00`00Oomoo`0^Ool08D:mL[5fdW:a
M]9b/@0900P02D[LC]e:_4kM>Ye^eFjdL]E^e6kE1344DP@aC]e:_4kMA[a:gDJlB]eR]VJgH[IV]`02
0000YdJlB[e6_4ZlB]a>oDkLB]e:_4[MB]aZeVZeJ]IZ]R5GAYa:_4JLB[a>g5;mC]aBoDkLD_e>g5;m
B]a>oDkLC_e:g4[MA[aRUeifHYLj>SiK>SXnFdkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`06Goo00<007ooOol03Goo00<007oo
Ool00Woo0010Ool2000_Ool017JaL[5f/G:a0Woo00U2W49l@Ya:g4[MB]a:gFkDK]D00fkD14JL00=>
gD[LC]d00T[M00E6_6JgI[L006:f00<]f@0:B]a>g4kLC]e>g4kMC]a>oD[LB]d4J]H00b4f8EM>g002
C]`01TkMC]a>o4kLD_e>g09>o00BD_e>g4kMC]a>gDkLGYINMUjGGWINUTZlC]a:_4[LC_aBoDkL0U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0NOol00`00
Oomoo`0<Ool00`00Oomoo`02Ool0049oo`03001oogoo02eoo`03M]9b/Goo009oo`1200Q2W49k@Ya6
_4[MA[a:gFkDK]E^]7;E1356W4:LA[a2W4kMB]a>gDJlB]e6_2YMH[IV]f:f<MX]^BgIB]a>gD[LC]e:
g4kmB]a>oCIm>YeZ]V[FJ[EZeQdf8EM:g4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e6_4[MA[a:gEifHYMN
MV:G0P0007E:_4kLB[a>gDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`09Goo00<007ooOol02goo00<007ooOol00Woo0013Ool00`00Oomoo`0aOol01@0900Q:gDZlB]`0
0T[M00A:_6kDK]A^e@9^e003135:gD[L009:g003C]e:g4kM008ZG@04H[IV]fJgI[L3;MT02TkMC]a>
g4kLC]e>g4kMC]`jWCIm16[F00<Q=b4f8EL00dkL00Y>oDkLC_a>o5;mC]a>oDkLC_e6_0=:g@05GWIN
UUif?S/j>P02C]`01TkMC]a>g5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`XOol0
0`00Oomoo`0;Ool00`00Oomoo`02Ool004Aoo`03001oogoo031oo`0J00P02@08B]e:_4[MA[a:gDJl
L]E^]6kEK[@4DP@aC]e:_4kMB[a>gD[LC]eR]VJgH[IV]`80002FA[a:_DJlC_e:g4kmC]a>oD[LC_e:
g6[FJ[EZeVZf8ELM=TZlAYa:_4JLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDJlB]e6_6:GGWIRUcXj?U/j
>U;mC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m;Goo00<007ooOol02goo00<007oo
Ool00Goo0015Ool2000aOol0249l@Ya2O4[MB]a:gCZMK]D3K]@02fkE1344D@@aC]e:g4kMC]a:gDJl
B]d00VJg00ER]VJg;MT]fDJl009:_006C_e>g4kMC]a>oD[L0T[M16[F00XQEb4fC]a>g4kMC]a>o4kL
D_e>g09>o005D_e>g4kMC]a>g@022K/02eifGYMNMUjF>S/n>cXjD_a>o5;mC]`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00=BoE;lD_`0<Goo00<007ooOol02Woo00<007ooOol00Goo0017Ool00`00Oomoo`0^Ool0@D:L
@W]2W49lC]e:_4kMK[A^eFjdL]E^]0AB@Ya6_4:LC]e:g4kMB]a:gDJlI[MR]VJgH[HafRfi;MU:g4kM
B]a>oDkLC_e>g4[MB[a:gD[LJ]IZ]F[F7CHQEadfC]e:g4kMB]aBoDkLD_e>g5;mC]aBoDkLC_e>g4km
GWIRUeifHYL00P0006Q:_4kLB[aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m=Goo00<007ooOol02Goo00<0
07ooOol00Goo0018Ool00`00Oomoo`0^Ool02D[MB[a:g4ZlB]e:_4[MK]A^e@02K]@00`AA1596W002
AY`014kMB]a>gD[L0RYM0fJg00ER]RgI;MT]fD[L009>g006C]e>g4kMC]`jWCIm16[F00<Q=b4f8EL0
0dkL00Y>oDkLC_a>o5;mC]a>oDkLC_e>g0=:g@03GWINUUif00<00003B[a>g4Zl009Bo005D_e>o5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m
D_`iOol00`00Oomoo`09Ool00`00Oomoo`01Ool004Uoo`03001oogoo02ioo`2RB]e:_4[MB[a:gDJl
B]e^]6kEK[Abe@@a159:_4kMB[a>gD[LC]e:g6JgH[IV]f:fI[M6_4ZmA[a:_4[LC_e>g4kmB]a>oD[L
J]IZ]F[FJ[HQE`00B[a6W4ZlC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlHYMNMV:G>SXnFcXj
?U]>g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l?Goo00<007ooOol027oo00<007ooOol00Goo001:Ool2000_Ool01D[MB]a:gD[L
?Yd00fkD00E^eFkD1544D@AB00=:g007B]e6_4[MB]eV]f:fI[L00P0000A6_4ZlB[a:_0=>g004B]e:
g4[MB]d4J]H02R5GA[a:_4JlB[a>g4klC]aBoDkL0Tkl00IBoDkLC]e>g4kMC]`2B]d02UjGGWINUSXk
?S/j>ShkC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBoE;l@Goo00<007ooOol01goo00<007ooOol00Goo001<Ool00`00Oomoo`0]Ool0VDkMB[a>
gD[LK]E^]7;EK[A^eD:LA[a2W4JLB]a>gD[LB]e6_4[MH[IV]f:FI[L]^BgIB]a>gD[LC]e>g4kmC]a>
oDZlB]eZ]V[FJ[EZeQdf8EM:g4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e:g4kmC]a>oEifHYMNMV:GGWI>
gDZlC]a:_4kMC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@16Ool00`00Oomoo`06Ool00`00Oomoo`01Ool004eoo`03001oogoo02eoo`05B]e:_4[MB]e^e@03
K]@00`ABAYa6W002AY`02D[LC]e>g4[MA[a:gBYMI[MR]P03;MT02T[LC]a>g4kMC]a>gDkLC]dfOCZM
16[F00<Q=R5G8CH00TkL00I>gDkLC_a>o5;mC]`2C_`00e;mA[a:g@02B]d00eifGYINMP02000014[L
B[a>g4Zl0U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo04Mo
o`03001oogoo00Moo`40005oo`5oo`00CWoo00<007ooOol0;Goo095:gDJlB]e^]6kEK[AbeFjd159:
_4kMB[a>gD[LC]e:g2YM9SaV]f:fI[MRUS7J;KT]fD[LC_e>g4kmB]a>oD[LC_eZ]F[FJ[IZeVZeB[a6
W4ZlAYaBoDkLC_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlHYMNMV:GGWHnFcXjD_e>g4kmC]aBoDkLD_e>
g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@1=Ool00`00Oomoo`06Ool10001Ool1Ool004mo
o`8002ioo`05B]e:_4[MK]A^e@02K]@00`AA159:g002B]`024[MB]a>gD[LI[MR]VJgI[H20003B[`3
C]`00dkMB]a:g@02B]d4J]H02B4fB[a6_4ZlA[a>o4kLD_e>g002C_`01U;mC]a>oDkLC_e6_09:g@03
GYMNMUjF008n>`05>SY>g4kLC]e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_aBOol00`00Oomo
o`05Ool10001Ool1Ool0055oo`03001oogoo02aoo`28?Ye^]7;EK[A^eFjd1584D@ABB]a>gD[LC]e6
_4[MA[aV]f:FI[MR]RgI;KU:_DJlB[a>g4kmC]a>oDZlB]e:g6[FJ[EZeVZf8ELM=TkMB]a>gD[LD_e>
g5;mC]aBoDkLD_e>g4kmC]a>o@VJ3K]NMV:GGWIRUcXj?U/j>U;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aEOol00`00Oomoo`05Ool10001Ool1Ool0059oo`03001oogoo02aoo`06K]E^e6kDK]Aoo`AA
0dJL00Y:g4kMC]a>gDJlB]eV]VJgH[IV]`<]f@9>g006C]e:g4kMC]a>oD[L0T[M16[F00HQEb4fC]a>
g4kMC]`2C_`03E;mC]a>o4klD_e>g4kMC]a>gEifGYINMUjG00800007B[a>g4ZlB]a>o5;mC]`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_aIOol00`00Oomoo`04Ool10001Ool1Ool005=oo`03001oogoo02aoo`03K]E^]7oo009o
o`0c1556_4:LAYa:g4kMB]a>gBHl:UeR]VJgHYIV]bfi;MT]^DkmC]a>oD[LC_e:g4km=WdjWFZfJ]IZ
]F[F8CHQEadfD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MGWIRUeif00<00015C]a>oDkLD_e>
g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l05eoo`03001oogoo00=oo`40005oo`5oo`00E7oo00<007ooOol0<7oo00h4DPAAB]a:
g4[MB]a>gD[LC]eR]VJgI[IV]`000dZl00Q6_4kLC]a>gDkLC]e>g4kM16[F00DQ=P00A[a:_4Jl009>
g00:C_e>g4klC_aBoDkLC_e>g4kmC]`2B]d00ejGGWINUP02?S/01CXj?S]>g4kMC]`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l069oo`03
001oogoo00=oo`40005oo`00EGoo0P00<7oo00d4D@AB155>gD[LC]e:g4[MA[aV]f:FI[MR]P020000
IDZmA[a:_4kLC_e>g4kmC]a:gD[LB]eZ]F[FJ[HQEb4fB[a6W4ZlC]aBoDkLD_e>g5;mC]aBoD[LC_e>
g4kmB]a:gDJlHYMNMV:G>SXnFcXjD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0IGoo00<007ooOol00goo0@000Goo001GOol00`00Oomoo`0^
Ool3AY`014kMC]a>gDJl0T[M00=V]f:fI[L00RgI00U:g4kLC]a>gDkLC]e>g4kmB]`00T[M00IZeVZf
J]IZeR5G8CH2C]`01TkMC]a>o4kLD_e>g09>o009D_e>g4kMC]a>gEifGYINMUjG00800007B[a>g4Zl
D_a>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0JGoo
00<007ooOol00Woo0@000Goo001HOol00`00Oomoo`0]Ool0<TJl@Ya6W4[LC]e:g4kM9S`ZGF:fI[MR
UVJg;KTafBfiC]e:g4kMB]a>oD[LC_dfOCZMJ[IZeVJeJ]HQ=R5G8CIBoDkLC_e>g5;mC]aBoDkLD_e>
g5;mA[a:gDJlB]eNMV:GGWH30000=4ZlC]a:_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mLGoo00D007ooOomoo`00005oo`00FGoo00<007ooOol0;Goo0T[L00Y:gD[LC]e:g4kMH[IV
]fJfI[MR]P=:_009A[a>g4kLC]e>g4kMC]a>gFZf00=ZeP058CH004JlB[a6_002C]`02TkmC]a>o4kl
D_e>g4kmC]a>oDkL0T[M00UNUeifGYINMShk>SXn>dkLC]d00TkL00=Bo5;mC_`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_aeOol01000Oomoo`000Goo001JOol2000^Ool0HDkMB[a>gDJlB]e6_4[MHYIV]f:f
I[L004ZmA[a:_4JlC_e>g4kmC]a:gD[LB]eV]F[FJ[IZeR4f8EM6W4ZlAYaBoDkLD_e>g5;mC]aBoDkL
C_e>g4kmB]a:gDJlHYMNMV:G>SXnFcXj?U]>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m07Qoo`04
001oogoo0001Ool005aoo`03001oogoo02aoo`04C]e>g4kMA[`2B]d016JgH[IV]f:f0RgI0TkL00I>
gD[LC]e>g4kmC]`2B]d03V[FJ[IZeV[F8ELQ=R5GC]a>gDkLC_a>g5;mC]`2C_`04U;mC]a>gDkLC]e>
g5jFGWINUeifGYI:_4kLB[a:g4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo01lOol00`00Ool00001Ool005eo
o`03001oogoo02aoo`0_C]e:g4kMA[a:gDJlI[MRUVJgH[HafBfiC]e:g4kMB]a>oD[LC_e:g3ZM=WeZ
eVJeJ]IZ]R5G8CHQEd[LC]e:g5;mC]aBoDkLD_e>g5;mC]a:gDJlB]eNMV:GGWIRU`020000:4ZlC]a:
_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mP7oo0@000Goo0@00001NOol00`00Oomoo`0/Ool02DkMB]a>gBXm:UeR]VJg
H[IV]`03;MT2C]`01TkMC]a>gDkLC]e>g0=ZeP08J[IZeTJlB[a6_4ZlC]a>o@9>g007C_aBoDkLC_a>
g4kmC]`00d[M00ENMUjFGWHn>cXj009>g006C]e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0Q7oo0P00001OOol2000]Ool01dkM
B]a>gF:FI[MR]VJg00800017A[a:_4JlB[e>g4kmB]a:gD[LB]e:_6[FJ[IZeR4f1056W4ZlAYaBoDkL
D_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlHYMNMV:G>SXnFcXj?U]>g4kmC]aBoDkLD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo028Ool20000065oo`03001oogoo
02]oo`=:g@04H[IV]f:fI[L2;MT00dkLC]e:g002C]`00dkmC]a>g@02B]d01FZfJ]IZeV[F8CH00TkL
01Y>gDkLC_a>g5;mC]a>oDklD_e>g4kMC]a>g@VK2K]NMUjFGWINUTZlC]a:_4[LC_aBoDkL0U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo8]oo`800000HWoo00<007oo
Ool0:goo02]:gDJlB]dV?6JgH[HafBfi<MY:g4kMB]a>gD[LC_e:g4km=WeZeVJeJ]IZ]R5G8CHUEd[L
C]e:g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_eNMV:GGWIRU`0200006dZlC]a:_4kMC]aBoDkLD_e>o5;m
C]aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo02:Ool40002Ool006=oo`03001oogoo02]o
o`8ZG@04I[MR]VJgH[H3;MT00dkLC]e>g002C]`00dkMC]aZeP02J]H026ZfJ]I6_4ZlA[a:_4kLC_d2
C]`01dklD_e>g4kmC]a>oDkL00=:g@08GWINUUif?S/j>ShkC]a>g@9>g003D_aBoDkl009Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo8Uoo`@000Ioo`00I7oo0P00;7oo00AV]f:fI[MRUP80000g
B[a6_4ZmC]a>oD[LB]e:g4[MB[aZeVZfJ]IV]BEGAYa:_4JLB[a>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
B]e6_6:GGWIRUeif?U/j>SiKC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_d0Rgoo10002Woo
001VOol00`00Oomoo`0ZOol00fJgH[IV]`02;MT00dkLC]e:g002C]`00dkmC]a:g@02B]d026ZfJ]IZ
eV[F8EHQEdkLC]d3C]`02U;mC]a>o4klD_e>g4kmC]a>gDkL0PVk00YNUUifGYI:_4kLB[a:g4klD_e>
g09Bo005D_eBo5;lD_aBo@02D_b:Ool4000>Ool006Moo`03001oogoo02Uoo`0XHYIV]gooOol]^C7J
B]a>gD[LC]e>g4kmC]a:gD[LB]eV]F[FJ[IZeR4f9ELQ=TkMB]a>gDkLD_e>g5;mC]aBoDkLD_e>g4km
B]aRUeifHYL2000034ZlC]a:_4kMC]aBoDkLD_e>o5;mC]aBoHYoo`<0019oo`00J7oo00<007ooOol0
;7oo00DafBgI;MU>g4kM00=>g003C]e>g4kM009ZeP08J[IZeV[FB[a6_4ZlA[a>o@9>g008C_aBoDkL
C_e>g4kmC]a>o@9:g@08GWINUUifGYHj>ShkC]a>g@9>g004D_aBoDklD_b9Ool4000EOol006Uoo`80
02eoo`0[B[a6_4ZmA[a>oD[LC_e:g4[MB[a:gFZfJ]IV]BEG105:_4JLB[a>g5;mC]aBoDkLD_e>g5;m
C]aBoDkLB]e6_4[MGWIRUeif?U/j>SiK>SY>oDkLD_d0R7oo10006Goo001[Ool00`00Oomoo`0[Ool0
1dkMB]a>g4kLC_e>g4kM009:g@08B]aZeV[FJ]IZ]R5GC]a>g@=>g00=D_e>g4klC_aBoDkLC_e>g4kM
C]`9^`FKGYH00eifRWoo10007Goo001/Ool00`00Oomoo`0[Ool08TkMB]a>gD[LC_e>g4kmB]a:gDZl
J]IZ]V[F8CHUEb4fC]e:g4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e:g6:GGWIRUeifQgoo10008Goo001]
Ool00`00Oomoo`0[Ool04DkMC]a>g4kLC]e>g4kMC]aZeVZfJ]IZ]TZlA[a:_4JlC_d00dkL00MBoDkL
C_a>g4kmC]a>o@02B]d014JmGWINMUjFQ7oo0`009Goo001^Ool00`00Oomoo`0/Ool07T[LC_e>g4[M
B[a:gFZfJ]IV]F[F8CI:_4JLB[a6W5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4[MGWIRUh5oo`@002Qo
o`00Kgoo0P00;Goo00U>g4kMC]a:gD[LB]eZ]V[FJ[H00R5G00Q>gDkLC]a>g5;mC]a>o4kLQgoo1000
;7oo001aOol00`00Oomoo`0ZOol044kmC]a>oD[LB]e:_6[FI[IZeVJe9ELQ=REGB]a>gD[LQWoo1000
<7oo001bOol00`00Oomoo`0ZOol02DkMC]a>gDkLJ]IZ]V[FJ[IZeP28Ool4000dOol007=oo`03001o
ogoo02Yoo`07B]e:_4[MB]aZeVJeJ]H0QGoo1000>7oo001dOol2000/Ool014[LB]eZ]V[FPgoo0`00
?7oo001fOol00`00Oomoo`0YOol00`00Oomoo`20Ool4000oOol007Moo`03001oogoo02Qoo`03001o
ogoo07aoo`@004=oo`00N7oo00<007ooOol09goo00<007ooOol0N7oo1000Agoo001iOol2000WOol0
0`00Oomoo`1dOol4001;Ool007]oo`03001oogoo02Aoo`03001oogoo075oo`<004moo`00O7oo00<0
07ooOol08goo00<007ooOol0KGoo1000DWoo001mOol00`00Oomoo`0ROol00`00Oomoo`1YOol4001F
Ool007ioo`80029oo`03001oogoo06Eoo`@005Yoo`00P7oo00<007ooOol07goo00<007ooOol0HGoo
1000GWoo0021Ool00`00Oomoo`0NOol00`00Oomoo`1NOol3001ROol0089oo`03001oogoo01eoo`03
001oogoo05Yoo`@006Eoo`00Pgoo00<007ooOol077oo00<007ooOol0EWoo1000JGoo0024Ool2000L
Ool00`00Oomoo`1BOol4001]Ool008Ioo`03001oogoo01Uoo`03001oogoo04ioo`@0075oo`00Qgoo
00<007ooOol067oo00<007ooOol0Bgoo0`00MGoo0028Ool00`00Oomoo`0GOol00`00Oomoo`17Ool4
001hOol008Uoo`8001Moo`03001oogoo04=oo`@007aoo`00Rgoo00<007ooOol057oo00<007ooOol0
?goo1000P7oo002<Ool00`00Oomoo`0BOol00`00Oomoo`0lOol40024Ool008eoo`03001oogoo015o
o`03001oogoo03Uoo`<008Qoo`00SWoo0P004Goo00<007ooOol0=Goo1000Rgoo002@Ool00`00Oomo
o`0>Ool00`00Oomoo`0aOol4002?Ool0095oo`03001oogoo00eoo`03001oogoo02eoo`@009=oo`00
TWoo00<007ooOol037oo00<007ooOol0:Goo1000Ugoo002COol2000<Ool00`00Oomoo`0UOol4002K
Ool009Eoo`03001oogoo00Uoo`03001oogoo029oo`<009moo`00UWoo00<007ooOol027oo00<007oo
Ool07Woo1000XWoo002GOol00`00Oomoo`07Ool00`00Oomoo`0JOol4002VOol009Qoo`03001oogoo
00Ioo`03001oogoo01Ioo`@00:Yoo`00VGoo0P001Woo00<007ooOol04Woo1000[Woo002KOol00`00
Oomoo`03Ool00`00Oomoo`0?Ool3002bOol009aoo`03001oogoo009oo`03001oogoo00]oo`@00;Eo
o`00WGoo00D007ooOomoo`0000Uoo`@00;Uoo`00WWoo0P0000=oo`00Ool017oo1000_Goo002POol2
00000goo000000020031Ool00:5oo`800<Eoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo
003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.627 .73 .922 r
.39636 .69727 .40168 .70225 .41058 .70046 .40528 .6954 Mtetra
.608 .722 .926 r
.40528 .6954 .41058 .70046 .41947 .70017 .41422 .6939 Mtetra
.951 .622 .367 r
.41422 .6939 .41947 .70017 .42863 .69113 .42192 .73643 Mtetra
0 0 .199 r
.42192 .73643 .42863 .69113 .43757 .69119 .43234 .68581 Mtetra
.612 .712 .916 r
.43234 .68581 .43757 .69119 .4466 .68926 .44137 .68428 Mtetra
.636 .736 .92 r
.44137 .68428 .4466 .68926 .45566 .68709 .45045 .68216 Mtetra
.64 .74 .921 r
.45045 .68216 .45566 .68709 .46476 .6849 .45957 .67994 Mtetra
.636 .738 .922 r
.45957 .67994 .46476 .6849 .47389 .68296 .46871 .67781 Mtetra
.604 .721 .927 r
.46871 .67781 .47389 .68296 .48301 .68384 .47789 .67635 Mtetra
.846 .712 .716 r
.47789 .67635 .48301 .68384 .49229 .67407 .48726 .65957 Mtetra
.314 .352 .741 r
.48726 .65957 .49229 .67407 .5015 .67312 .49638 .66782 Mtetra
.626 .724 .917 r
.49638 .66782 .5015 .67312 .51075 .67091 .50566 .66591 Mtetra
.646 .742 .92 r
.50566 .66591 .51075 .67091 .52004 .66845 .51496 .66353 Mtetra
.652 .748 .92 r
.51496 .66353 .52004 .66845 .52936 .66588 .5243 .66099 Mtetra
.655 .75 .92 r
.5243 .66099 .52936 .66588 .53871 .66325 .53367 .65836 Mtetra
.657 .752 .92 r
.53367 .65836 .53871 .66325 .54809 .66056 .54308 .65568 Mtetra
.658 .753 .92 r
.54308 .65568 .54809 .66056 .55751 .65784 .55251 .65295 Mtetra
.659 .754 .92 r
.55251 .65295 .55751 .65784 .56695 .6551 .56198 .6502 Mtetra
.56198 .6502 .56695 .6551 .57643 .65235 .57148 .64743 Mtetra
.57148 .64743 .57643 .65235 .58594 .6496 .58101 .64466 Mtetra
.58101 .64466 .58594 .6496 .59548 .64684 .59058 .64188 Mtetra
.658 .753 .92 r
.59058 .64188 .59548 .64684 .60506 .64408 .60018 .6391 Mtetra
.60018 .6391 .60506 .64408 .61467 .64131 .60981 .63631 Mtetra
.60981 .63631 .61467 .64131 .62431 .63854 .61947 .63352 Mtetra
.61947 .63352 .62431 .63854 .63398 .63576 .62917 .63072 Mtetra
.62917 .63072 .63398 .63576 .64369 .63298 .6389 .62792 Mtetra
.6389 .62792 .64369 .63298 .65343 .63019 .64866 .62511 Mtetra
.657 .753 .92 r
.64866 .62511 .65343 .63019 .6632 .62739 .65846 .6223 Mtetra
.65846 .6223 .6632 .62739 .67301 .62459 .66829 .61947 Mtetra
.66829 .61947 .67301 .62459 .68285 .62177 .67815 .61664 Mtetra
.67815 .61664 .68285 .62177 .69273 .61895 .68806 .6138 Mtetra
.68806 .6138 .69273 .61895 .70264 .61612 .69799 .61095 Mtetra
.657 .752 .92 r
.69799 .61095 .70264 .61612 .71259 .61328 .70796 .60809 Mtetra
.70796 .60809 .71259 .61328 .72257 .61043 .71796 .60522 Mtetra
.71796 .60522 .72257 .61043 .73258 .60757 .728 .60234 Mtetra
.728 .60234 .73258 .60757 .74263 .6047 .73808 .59945 Mtetra
.73808 .59945 .74263 .6047 .75272 .60182 .74819 .59656 Mtetra
.74819 .59656 .75272 .60182 .76284 .59894 .75834 .59365 Mtetra
.75834 .59365 .76284 .59894 .773 .59604 .76852 .59074 Mtetra
.76852 .59074 .773 .59604 .78319 .59313 .77874 .58781 Mtetra
.77874 .58781 .78319 .59313 .79342 .59022 .78899 .58488 Mtetra
.78899 .58488 .79342 .59022 .80368 .58729 .79928 .58193 Mtetra
.79928 .58193 .80368 .58729 .81399 .58436 .80961 .57898 Mtetra
.80961 .57898 .81399 .58436 .82432 .58141 .81998 .57601 Mtetra
.81998 .57601 .82432 .58141 .8347 .57846 .83038 .57304 Mtetra
.83038 .57304 .8347 .57846 .84511 .57549 .84082 .57005 Mtetra
.84082 .57005 .84511 .57549 .85556 .57252 .85129 .56706 Mtetra
.85129 .56706 .85556 .57252 .86605 .56953 .86181 .56405 Mtetra
.86181 .56405 .86605 .56953 .87657 .56654 .87236 .56104 Mtetra
.87236 .56104 .87657 .56654 .88714 .56353 .88295 .55801 Mtetra
.88295 .55801 .88714 .56353 .89774 .56051 .89358 .55497 Mtetra
.89358 .55497 .89774 .56051 .90838 .55749 .90425 .55193 Mtetra
.90425 .55193 .90838 .55749 .91905 .55445 .91495 .54887 Mtetra
.91495 .54887 .91905 .55445 .92977 .5514 .9257 .5458 Mtetra
.9257 .5458 .92977 .5514 .94052 .54834 .93648 .54272 Mtetra
.93648 .54272 .94052 .54834 .95132 .54527 .94731 .53963 Mtetra
.94731 .53963 .95132 .54527 .96215 .54219 .95817 .53653 Mtetra
.95817 .53653 .96215 .54219 .97303 .5391 .96907 .53341 Mtetra
.96907 .53341 .97303 .5391 .98394 .536 .98002 .53029 Mtetra
.623 .726 .92 r
.39101 .69218 .39636 .69727 .40528 .6954 .39995 .69038 Mtetra
.623 .73 .923 r
.39995 .69038 .40528 .6954 .41422 .6939 .40891 .68855 Mtetra
.543 .69 .935 r
.40891 .68855 .41422 .6939 .42192 .73643 .41787 .68823 Mtetra
.632 .453 .622 r
.41787 .68823 .42192 .73643 .43234 .68581 .42711 .67912 Mtetra
.545 .641 .896 r
.42711 .67912 .43234 .68581 .44137 .68428 .43611 .67915 Mtetra
.629 .729 .919 r
.43611 .67915 .44137 .68428 .45045 .68216 .44521 .67719 Mtetra
.639 .739 .921 r
.44521 .67719 .45045 .68216 .45957 .67994 .45434 .67497 Mtetra
.64 .74 .921 r
.45434 .67497 .45957 .67994 .46871 .67781 .46351 .67275 Mtetra
.628 .733 .923 r
.46351 .67275 .46871 .67781 .47789 .67635 .47271 .67077 Mtetra
.467 .651 .939 r
.47271 .67077 .47789 .67635 .48726 .65957 .4819 .67162 Mtetra
.111 0 .118 r
.4819 .67162 .48726 .65957 .49638 .66782 .49125 .66178 Mtetra
.588 .684 .907 r
.49125 .66178 .49638 .66782 .50566 .66591 .50053 .66079 Mtetra
.639 .737 .919 r
.50053 .66079 .50566 .66591 .51496 .66353 .50986 .65854 Mtetra
.649 .746 .92 r
.50986 .65854 .51496 .66353 .5243 .66099 .51922 .65604 Mtetra
.653 .749 .92 r
.51922 .65604 .5243 .66099 .53367 .65836 .52861 .65343 Mtetra
.656 .751 .92 r
.52861 .65343 .53367 .65836 .54308 .65568 .53803 .65076 Mtetra
.657 .753 .92 r
.53803 .65076 .54308 .65568 .55251 .65295 .54749 .64803 Mtetra
.658 .753 .92 r
.54749 .64803 .55251 .65295 .56198 .6502 .55698 .64526 Mtetra
.659 .754 .92 r
.55698 .64526 .56198 .6502 .57148 .64743 .5665 .64248 Mtetra
.5665 .64248 .57148 .64743 .58101 .64466 .57606 .63969 Mtetra
.57606 .63969 .58101 .64466 .59058 .64188 .58564 .63689 Mtetra
.58564 .63689 .59058 .64188 .60018 .6391 .59526 .63409 Mtetra
.658 .753 .92 r
.59526 .63409 .60018 .6391 .60981 .63631 .60491 .63128 Mtetra
.60491 .63128 .60981 .63631 .61947 .63352 .6146 .62847 Mtetra
.6146 .62847 .61947 .63352 .62917 .63072 .62432 .62565 Mtetra
.62432 .62565 .62917 .63072 .6389 .62792 .63407 .62283 Mtetra
.63407 .62283 .6389 .62792 .64866 .62511 .64386 .62 Mtetra
.64386 .62 .64866 .62511 .65846 .6223 .65368 .61717 Mtetra
.657 .753 .92 r
.65368 .61717 .65846 .6223 .66829 .61947 .66354 .61432 Mtetra
.66354 .61432 .66829 .61947 .67815 .61664 .67343 .61147 Mtetra
.67343 .61147 .67815 .61664 .68806 .6138 .68335 .60861 Mtetra
.68335 .60861 .68806 .6138 .69799 .61095 .69331 .60574 Mtetra
.657 .752 .92 r
.69331 .60574 .69799 .61095 .70796 .60809 .7033 .60286 Mtetra
.7033 .60286 .70796 .60809 .71796 .60522 .71333 .59998 Mtetra
.71333 .59998 .71796 .60522 .728 .60234 .7234 .59708 Mtetra
.7234 .59708 .728 .60234 .73808 .59945 .7335 .59417 Mtetra
.7335 .59417 .73808 .59945 .74819 .59656 .74363 .59126 Mtetra
.74363 .59126 .74819 .59656 .75834 .59365 .7538 .58833 Mtetra
.7538 .58833 .75834 .59365 .76852 .59074 .76401 .5854 Mtetra
.76401 .5854 .76852 .59074 .77874 .58781 .77426 .58245 Mtetra
.77426 .58245 .77874 .58781 .78899 .58488 .78454 .5795 Mtetra
.78454 .5795 .78899 .58488 .79928 .58193 .79485 .57654 Mtetra
.79485 .57654 .79928 .58193 .80961 .57898 .80521 .57356 Mtetra
.80521 .57356 .80961 .57898 .81998 .57601 .8156 .57058 Mtetra
.8156 .57058 .81998 .57601 .83038 .57304 .82603 .56758 Mtetra
.82603 .56758 .83038 .57304 .84082 .57005 .8365 .56458 Mtetra
.8365 .56458 .84082 .57005 .85129 .56706 .847 .56156 Mtetra
.847 .56156 .85129 .56706 .86181 .56405 .85754 .55854 Mtetra
.85754 .55854 .86181 .56405 .87236 .56104 .86812 .5555 Mtetra
.86812 .5555 .87236 .56104 .88295 .55801 .87874 .55245 Mtetra
.87874 .55245 .88295 .55801 .89358 .55497 .8894 .5494 Mtetra
.8894 .5494 .89358 .55497 .90425 .55193 .90009 .54633 Mtetra
.90009 .54633 .90425 .55193 .91495 .54887 .91083 .54325 Mtetra
.91083 .54325 .91495 .54887 .9257 .5458 .9216 .54016 Mtetra
.9216 .54016 .9257 .5458 .93648 .54272 .93241 .53706 Mtetra
.93241 .53706 .93648 .54272 .94731 .53963 .94327 .53395 Mtetra
.94327 .53395 .94731 .53963 .95817 .53653 .95416 .53082 Mtetra
.95416 .53082 .95817 .53653 .96907 .53341 .96509 .52769 Mtetra
.96509 .52769 .96907 .53341 .98002 .53029 .97606 .52454 Mtetra
.61 .713 .918 r
.38565 .68683 .39101 .69218 .39995 .69038 .39458 .68532 Mtetra
.627 .73 .922 r
.39458 .68532 .39995 .69038 .40891 .68855 .40357 .68341 Mtetra
.608 .722 .926 r
.40357 .68341 .40891 .68855 .41787 .68823 .41258 .68188 Mtetra
.951 .622 .363 r
.41258 .68188 .41787 .68823 .42711 .67912 .42031 .72457 Mtetra
0 0 .192 r
.42031 .72457 .42711 .67912 .43611 .67915 .43083 .67369 Mtetra
.612 .712 .916 r
.43083 .67369 .43611 .67915 .44521 .67719 .43993 .67213 Mtetra
.636 .736 .92 r
.43993 .67213 .44521 .67719 .45434 .67497 .44909 .66997 Mtetra
.64 .74 .921 r
.44909 .66997 .45434 .67497 .46351 .67275 .45827 .66771 Mtetra
.636 .738 .922 r
.45827 .66771 .46351 .67275 .47271 .67077 .46749 .66554 Mtetra
.604 .721 .927 r
.46749 .66554 .47271 .67077 .4819 .67162 .47673 .66404 Mtetra
.846 .713 .716 r
.47673 .66404 .4819 .67162 .49125 .66178 .48618 .64716 Mtetra
.312 .35 .741 r
.48618 .64716 .49125 .66178 .50053 .66079 .49537 .65542 Mtetra
.626 .724 .917 r
.49537 .65542 .50053 .66079 .50986 .65854 .50472 .65347 Mtetra
.646 .742 .92 r
.50472 .65347 .50986 .65854 .51922 .65604 .5141 .65104 Mtetra
.652 .748 .92 r
.5141 .65104 .51922 .65604 .52861 .65343 .52351 .64846 Mtetra
.655 .75 .92 r
.52351 .64846 .52861 .65343 .53803 .65076 .53296 .64579 Mtetra
.657 .752 .92 r
.53296 .64579 .53803 .65076 .54749 .64803 .54244 .64306 Mtetra
.658 .753 .92 r
.54244 .64306 .54749 .64803 .55698 .64526 .55195 .6403 Mtetra
.659 .754 .92 r
.55195 .6403 .55698 .64526 .5665 .64248 .56149 .6375 Mtetra
.56149 .6375 .5665 .64248 .57606 .63969 .57107 .63469 Mtetra
.57107 .63469 .57606 .63969 .58564 .63689 .58068 .63187 Mtetra
.58068 .63187 .58564 .63689 .59526 .63409 .59032 .62904 Mtetra
.658 .753 .92 r
.59032 .62904 .59526 .63409 .60491 .63128 .59999 .62622 Mtetra
.59999 .62622 .60491 .63128 .6146 .62847 .6097 .62339 Mtetra
.6097 .62339 .6146 .62847 .62432 .62565 .61944 .62055 Mtetra
.61944 .62055 .62432 .62565 .63407 .62283 .62922 .61771 Mtetra
.62922 .61771 .63407 .62283 .64386 .62 .63903 .61486 Mtetra
.63903 .61486 .64386 .62 .65368 .61717 .64887 .61201 Mtetra
.657 .753 .92 r
.64887 .61201 .65368 .61717 .66354 .61432 .65875 .60914 Mtetra
.65875 .60914 .66354 .61432 .67343 .61147 .66867 .60627 Mtetra
.66867 .60627 .67343 .61147 .68335 .60861 .67861 .60339 Mtetra
.67861 .60339 .68335 .60861 .69331 .60574 .6886 .6005 Mtetra
.6886 .6005 .69331 .60574 .7033 .60286 .69862 .59761 Mtetra
.657 .752 .92 r
.69862 .59761 .7033 .60286 .71333 .59998 .70867 .5947 Mtetra
.70867 .5947 .71333 .59998 .7234 .59708 .71876 .59178 Mtetra
.71876 .59178 .7234 .59708 .7335 .59417 .72888 .58886 Mtetra
.72888 .58886 .7335 .59417 .74363 .59126 .73905 .58592 Mtetra
.73905 .58592 .74363 .59126 .7538 .58833 .74924 .58298 Mtetra
.74924 .58298 .7538 .58833 .76401 .5854 .75948 .58003 Mtetra
.75948 .58003 .76401 .5854 .77426 .58245 .76975 .57706 Mtetra
.76975 .57706 .77426 .58245 .78454 .5795 .78005 .57409 Mtetra
.78005 .57409 .78454 .5795 .79485 .57654 .7904 .5711 Mtetra
.7904 .5711 .79485 .57654 .80521 .57356 .80078 .56811 Mtetra
.80078 .56811 .80521 .57356 .8156 .57058 .8112 .56511 Mtetra
.8112 .56511 .8156 .57058 .82603 .56758 .82165 .56209 Mtetra
.82165 .56209 .82603 .56758 .8365 .56458 .83214 .55907 Mtetra
.83214 .55907 .8365 .56458 .847 .56156 .84268 .55603 Mtetra
.84268 .55603 .847 .56156 .85754 .55854 .85324 .55298 Mtetra
.85324 .55298 .85754 .55854 .86812 .5555 .86385 .54993 Mtetra
.86385 .54993 .86812 .5555 .87874 .55245 .8745 .54686 Mtetra
.8745 .54686 .87874 .55245 .8894 .5494 .88518 .54378 Mtetra
.88518 .54378 .8894 .5494 .90009 .54633 .89591 .54069 Mtetra
.89591 .54069 .90009 .54633 .91083 .54325 .90667 .53759 Mtetra
.90667 .53759 .91083 .54325 .9216 .54016 .91747 .53448 Mtetra
.91747 .53448 .9216 .54016 .93241 .53706 .92832 .53136 Mtetra
.92832 .53136 .93241 .53706 .94327 .53395 .9392 .52823 Mtetra
.9392 .52823 .94327 .53395 .95416 .53082 .95012 .52508 Mtetra
.95012 .52508 .95416 .53082 .96509 .52769 .96108 .52193 Mtetra
.96108 .52193 .96509 .52769 .97606 .52454 .97209 .51876 Mtetra
.558 .659 .904 r
.38029 .68048 .38565 .68683 .39458 .68532 .38919 .68016 Mtetra
.623 .726 .92 r
.38919 .68016 .39458 .68532 .40357 .68341 .39819 .67832 Mtetra
.623 .729 .923 r
.39819 .67832 .40357 .68341 .41258 .68188 .40722 .67645 Mtetra
.543 .689 .935 r
.40722 .67645 .41258 .68188 .42031 .72457 .41624 .6761 Mtetra
.631 .452 .621 r
.41624 .6761 .42031 .72457 .43083 .67369 .42556 .66692 Mtetra
.545 .641 .896 r
.42556 .66692 .43083 .67369 .43993 .67213 .43463 .66692 Mtetra
.629 .729 .919 r
.43463 .66692 .43993 .67213 .44909 .66997 .4438 .66492 Mtetra
.639 .739 .921 r
.4438 .66492 .44909 .66997 .45827 .66771 .453 .66267 Mtetra
.64 .74 .921 r
.453 .66267 .45827 .66771 .46749 .66554 .46224 .6604 Mtetra
.628 .733 .923 r
.46224 .6604 .46749 .66554 .47673 .66404 .47151 .65839 Mtetra
.468 .651 .939 r
.47151 .65839 .47673 .66404 .48618 .64716 .48077 .65921 Mtetra
.1 0 .108 r
.48077 .65921 .48618 .64716 .49537 .65542 .4902 .64929 Mtetra
.588 .684 .907 r
.4902 .64929 .49537 .65542 .50472 .65347 .49955 .64827 Mtetra
.639 .737 .919 r
.49955 .64827 .50472 .65347 .5141 .65104 .50895 .64598 Mtetra
.649 .746 .92 r
.50895 .64598 .5141 .65104 .52351 .64846 .51838 .64344 Mtetra
.653 .749 .92 r
.51838 .64344 .52351 .64846 .53296 .64579 .52785 .64078 Mtetra
.656 .751 .92 r
.52785 .64078 .53296 .64579 .54244 .64306 .53735 .63806 Mtetra
.657 .753 .92 r
.53735 .63806 .54244 .64306 .55195 .6403 .54688 .63529 Mtetra
.658 .753 .92 r
.54688 .63529 .55195 .6403 .56149 .6375 .55645 .63248 Mtetra
.659 .754 .92 r
.55645 .63248 .56149 .6375 .57107 .63469 .56605 .62965 Mtetra
.56605 .62965 .57107 .63469 .58068 .63187 .57568 .62682 Mtetra
.57568 .62682 .58068 .63187 .59032 .62904 .58534 .62397 Mtetra
.58534 .62397 .59032 .62904 .59999 .62622 .59504 .62112 Mtetra
.658 .753 .92 r
.59504 .62112 .59999 .62622 .6097 .62339 .60477 .61827 Mtetra
.60477 .61827 .6097 .62339 .61944 .62055 .61454 .61542 Mtetra
.61454 .61542 .61944 .62055 .62922 .61771 .62433 .61256 Mtetra
.62433 .61256 .62922 .61771 .63903 .61486 .63417 .60969 Mtetra
.63417 .60969 .63903 .61486 .64887 .61201 .64404 .60681 Mtetra
.64404 .60681 .64887 .61201 .65875 .60914 .65394 .60393 Mtetra
.657 .753 .92 r
.65394 .60393 .65875 .60914 .66867 .60627 .66388 .60104 Mtetra
.66388 .60104 .66867 .60627 .67861 .60339 .67385 .59814 Mtetra
.67385 .59814 .67861 .60339 .6886 .6005 .68386 .59523 Mtetra
.68386 .59523 .6886 .6005 .69862 .59761 .6939 .59232 Mtetra
.657 .752 .92 r
.6939 .59232 .69862 .59761 .70867 .5947 .70398 .58939 Mtetra
.70398 .58939 .70867 .5947 .71876 .59178 .71409 .58645 Mtetra
.71409 .58645 .71876 .59178 .72888 .58886 .72424 .58351 Mtetra
.72424 .58351 .72888 .58886 .73905 .58592 .73443 .58055 Mtetra
.73443 .58055 .73905 .58592 .74924 .58298 .74465 .57759 Mtetra
.74465 .57759 .74924 .58298 .75948 .58003 .75491 .57462 Mtetra
.75491 .57462 .75948 .58003 .76975 .57706 .76521 .57163 Mtetra
.76521 .57163 .76975 .57706 .78005 .57409 .77554 .56864 Mtetra
.77554 .56864 .78005 .57409 .7904 .5711 .78591 .56564 Mtetra
.78591 .56564 .7904 .5711 .80078 .56811 .79632 .56262 Mtetra
.79632 .56262 .80078 .56811 .8112 .56511 .80676 .5596 Mtetra
.80676 .5596 .8112 .56511 .82165 .56209 .81724 .55656 Mtetra
.81724 .55656 .82165 .56209 .83214 .55907 .82776 .55352 Mtetra
.82776 .55352 .83214 .55907 .84268 .55603 .83832 .55046 Mtetra
.83832 .55046 .84268 .55603 .85324 .55298 .84892 .54739 Mtetra
.84892 .54739 .85324 .55298 .86385 .54993 .85956 .54432 Mtetra
.85956 .54432 .86385 .54993 .8745 .54686 .87023 .54123 Mtetra
.87023 .54123 .8745 .54686 .88518 .54378 .88094 .53813 Mtetra
.88094 .53813 .88518 .54378 .89591 .54069 .8917 .53502 Mtetra
.8917 .53502 .89591 .54069 .90667 .53759 .90249 .5319 Mtetra
.90249 .5319 .90667 .53759 .91747 .53448 .91332 .52877 Mtetra
.91332 .52877 .91747 .53448 .92832 .53136 .92419 .52562 Mtetra
.92419 .52562 .92832 .53136 .9392 .52823 .9351 .52247 Mtetra
.9351 .52247 .9392 .52823 .95012 .52508 .94606 .5193 Mtetra
.94606 .5193 .95012 .52508 .96108 .52193 .95705 .51612 Mtetra
.95705 .51612 .96108 .52193 .97209 .51876 .96808 .51294 Mtetra
.015 .002 .495 r
.37644 .63824 .38029 .68048 .38919 .68016 .38377 .67472 Mtetra
.61 .713 .918 r
.38377 .67472 .38919 .68016 .39819 .67832 .39278 .67318 Mtetra
.627 .73 .922 r
.39278 .67318 .39819 .67832 .40722 .67645 .40183 .67124 Mtetra
.609 .722 .926 r
.40183 .67124 .40722 .67645 .41624 .6761 .41091 .66966 Mtetra
.951 .621 .358 r
.41091 .66966 .41624 .6761 .42556 .66692 .41868 .71252 Mtetra
0 0 .186 r
.41868 .71252 .42556 .66692 .43463 .66692 .4293 .66138 Mtetra
.612 .712 .916 r
.4293 .66138 .43463 .66692 .4438 .66492 .43848 .65978 Mtetra
.636 .736 .92 r
.43848 .65978 .4438 .66492 .453 .66267 .4477 .65759 Mtetra
.64 .74 .921 r
.4477 .65759 .453 .66267 .46224 .6604 .45695 .65529 Mtetra
.636 .738 .922 r
.45695 .65529 .46224 .6604 .47151 .65839 .46624 .65307 Mtetra
.604 .721 .927 r
.46624 .65307 .47151 .65839 .48077 .65921 .47556 .65154 Mtetra
.847 .714 .716 r
.47556 .65154 .48077 .65921 .4902 .64929 .48509 .63455 Mtetra
.31 .349 .741 r
.48509 .63455 .4902 .64929 .49955 .64827 .49435 .64281 Mtetra
.626 .724 .917 r
.49435 .64281 .49955 .64827 .50895 .64598 .50376 .64082 Mtetra
.646 .742 .92 r
.50376 .64082 .50895 .64598 .51838 .64344 .51322 .63835 Mtetra
.652 .748 .92 r
.51322 .63835 .51838 .64344 .52785 .64078 .52271 .63573 Mtetra
.655 .75 .92 r
.52271 .63573 .52785 .64078 .53735 .63806 .53223 .63302 Mtetra
.657 .752 .92 r
.53223 .63302 .53735 .63806 .54688 .63529 .54178 .63024 Mtetra
.658 .753 .92 r
.54178 .63024 .54688 .63529 .55645 .63248 .55137 .62743 Mtetra
.659 .754 .92 r
.55137 .62743 .55645 .63248 .56605 .62965 .56099 .62459 Mtetra
.56099 .62459 .56605 .62965 .57568 .62682 .57065 .62173 Mtetra
.57065 .62173 .57568 .62682 .58534 .62397 .58033 .61887 Mtetra
.58033 .61887 .58534 .62397 .59504 .62112 .59005 .616 Mtetra
.658 .753 .92 r
.59005 .616 .59504 .62112 .60477 .61827 .59981 .61313 Mtetra
.59981 .61313 .60477 .61827 .61454 .61542 .6096 .61025 Mtetra
.6096 .61025 .61454 .61542 .62433 .61256 .61942 .60737 Mtetra
.61942 .60737 .62433 .61256 .63417 .60969 .62927 .60448 Mtetra
.62927 .60448 .63417 .60969 .64404 .60681 .63917 .60159 Mtetra
.63917 .60159 .64404 .60681 .65394 .60393 .64909 .59868 Mtetra
.657 .753 .92 r
.64909 .59868 .65394 .60393 .66388 .60104 .65905 .59577 Mtetra
.65905 .59577 .66388 .60104 .67385 .59814 .66905 .59285 Mtetra
.66905 .59285 .67385 .59814 .68386 .59523 .67908 .58993 Mtetra
.67908 .58993 .68386 .59523 .6939 .59232 .68915 .58699 Mtetra
.68915 .58699 .6939 .59232 .70398 .58939 .69925 .58404 Mtetra
.657 .752 .92 r
.69925 .58404 .70398 .58939 .71409 .58645 .70939 .58109 Mtetra
.70939 .58109 .71409 .58645 .72424 .58351 .71957 .57812 Mtetra
.71957 .57812 .72424 .58351 .73443 .58055 .72978 .57515 Mtetra
.72978 .57515 .73443 .58055 .74465 .57759 .74003 .57217 Mtetra
.74003 .57217 .74465 .57759 .75491 .57462 .75031 .56917 Mtetra
.75031 .56917 .75491 .57462 .76521 .57163 .76063 .56617 Mtetra
.76063 .56617 .76521 .57163 .77554 .56864 .77099 .56315 Mtetra
.77099 .56315 .77554 .56864 .78591 .56564 .78139 .56013 Mtetra
.78139 .56013 .78591 .56564 .79632 .56262 .79182 .5571 Mtetra
.79182 .5571 .79632 .56262 .80676 .5596 .8023 .55405 Mtetra
.8023 .55405 .80676 .5596 .81724 .55656 .81281 .551 Mtetra
.81281 .551 .81724 .55656 .82776 .55352 .82335 .54793 Mtetra
.82335 .54793 .82776 .55352 .83832 .55046 .83394 .54485 Mtetra
.83394 .54485 .83832 .55046 .84892 .54739 .84456 .54177 Mtetra
.84456 .54177 .84892 .54739 .85956 .54432 .85523 .53867 Mtetra
.85523 .53867 .85956 .54432 .87023 .54123 .86593 .53556 Mtetra
.86593 .53556 .87023 .54123 .88094 .53813 .87667 .53244 Mtetra
.87667 .53244 .88094 .53813 .8917 .53502 .88745 .52931 Mtetra
.88745 .52931 .8917 .53502 .90249 .5319 .89828 .52616 Mtetra
.89828 .52616 .90249 .5319 .91332 .52877 .90914 .52301 Mtetra
.90914 .52301 .91332 .52877 .92419 .52562 .92004 .51985 Mtetra
.92004 .51985 .92419 .52562 .9351 .52247 .93098 .51667 Mtetra
.93098 .51667 .9351 .52247 .94606 .5193 .94196 .51348 Mtetra
.94196 .51348 .94606 .5193 .95705 .51612 .95299 .51028 Mtetra
.95299 .51028 .95705 .51612 .96808 .51294 .96405 .50707 Mtetra
.468 .221 .456 r
.36905 .67741 .37644 .63824 .38377 .67472 .37837 .6683 Mtetra
.558 .659 .904 r
.37837 .6683 .38377 .67472 .39278 .67318 .38734 .66794 Mtetra
.623 .726 .92 r
.38734 .66794 .39278 .67318 .40183 .67124 .3964 .66606 Mtetra
.623 .729 .923 r
.3964 .66606 .40183 .67124 .41091 .66966 .40551 .66416 Mtetra
.543 .689 .935 r
.40551 .66416 .41091 .66966 .41868 .71252 .41459 .66378 Mtetra
.63 .45 .62 r
.41459 .66378 .41868 .71252 .4293 .66138 .42398 .65452 Mtetra
.545 .641 .896 r
.42398 .65452 .4293 .66138 .43848 .65978 .43313 .6545 Mtetra
.629 .729 .919 r
.43313 .6545 .43848 .65978 .4477 .65759 .44236 .65245 Mtetra
.639 .739 .921 r
.44236 .65245 .4477 .65759 .45695 .65529 .45164 .65016 Mtetra
.64 .74 .921 r
.45164 .65016 .45695 .65529 .46624 .65307 .46095 .64785 Mtetra
.628 .733 .923 r
.46095 .64785 .46624 .65307 .47556 .65154 .47029 .6458 Mtetra
.468 .651 .939 r
.47029 .6458 .47556 .65154 .48509 .63455 .47962 .64659 Mtetra
.09 0 .097 r
.47962 .64659 .48509 .63455 .49435 .64281 .48912 .6366 Mtetra
.588 .684 .908 r
.48912 .6366 .49435 .64281 .50376 .64082 .49855 .63554 Mtetra
.639 .737 .919 r
.49855 .63554 .50376 .64082 .51322 .63835 .50802 .63321 Mtetra
.649 .746 .92 r
.50802 .63321 .51322 .63835 .52271 .63573 .51753 .63062 Mtetra
.653 .749 .92 r
.51753 .63062 .52271 .63573 .53223 .63302 .52708 .62793 Mtetra
.656 .751 .92 r
.52708 .62793 .53223 .63302 .54178 .63024 .53665 .62516 Mtetra
.657 .753 .92 r
.53665 .62516 .54178 .63024 .55137 .62743 .54626 .62234 Mtetra
.658 .753 .92 r
.54626 .62234 .55137 .62743 .56099 .62459 .55591 .61949 Mtetra
.659 .754 .92 r
.55591 .61949 .56099 .62459 .57065 .62173 .56558 .61662 Mtetra
.56558 .61662 .57065 .62173 .58033 .61887 .57529 .61373 Mtetra
.57529 .61373 .58033 .61887 .59005 .616 .58503 .61084 Mtetra
.58503 .61084 .59005 .616 .59981 .61313 .59481 .60795 Mtetra
.658 .753 .92 r
.59481 .60795 .59981 .61313 .6096 .61025 .60462 .60505 Mtetra
.60462 .60505 .6096 .61025 .61942 .60737 .61447 .60215 Mtetra
.61447 .60215 .61942 .60737 .62927 .60448 .62435 .59924 Mtetra
.62435 .59924 .62927 .60448 .63917 .60159 .63426 .59632 Mtetra
.63426 .59632 .63917 .60159 .64909 .59868 .64421 .5934 Mtetra
.64421 .5934 .64909 .59868 .65905 .59577 .6542 .59047 Mtetra
.657 .753 .92 r
.6542 .59047 .65905 .59577 .66905 .59285 .66422 .58753 Mtetra
.66422 .58753 .66905 .59285 .67908 .58993 .67428 .58459 Mtetra
.67428 .58459 .67908 .58993 .68915 .58699 .68437 .58163 Mtetra
.68437 .58163 .68915 .58699 .69925 .58404 .6945 .57866 Mtetra
.657 .752 .92 r
.6945 .57866 .69925 .58404 .70939 .58109 .70466 .57569 Mtetra
.70466 .57569 .70939 .58109 .71957 .57812 .71486 .5727 Mtetra
.71486 .5727 .71957 .57812 .72978 .57515 .7251 .56971 Mtetra
.7251 .56971 .72978 .57515 .74003 .57217 .73537 .56671 Mtetra
.73537 .56671 .74003 .57217 .75031 .56917 .74568 .56369 Mtetra
.74568 .56369 .75031 .56917 .76063 .56617 .75603 .56067 Mtetra
.75603 .56067 .76063 .56617 .77099 .56315 .76642 .55763 Mtetra
.76642 .55763 .77099 .56315 .78139 .56013 .77684 .55459 Mtetra
.77684 .55459 .78139 .56013 .79182 .5571 .7873 .55153 Mtetra
.7873 .55153 .79182 .5571 .8023 .55405 .7978 .54847 Mtetra
.7978 .54847 .8023 .55405 .81281 .551 .80834 .54539 Mtetra
.80834 .54539 .81281 .551 .82335 .54793 .81891 .5423 Mtetra
.81891 .5423 .82335 .54793 .83394 .54485 .82953 .53921 Mtetra
.82953 .53921 .83394 .54485 .84456 .54177 .84018 .5361 Mtetra
.84018 .5361 .84456 .54177 .85523 .53867 .85087 .53298 Mtetra
.85087 .53298 .85523 .53867 .86593 .53556 .8616 .52985 Mtetra
.8616 .52985 .86593 .53556 .87667 .53244 .87237 .52671 Mtetra
.87237 .52671 .87667 .53244 .88745 .52931 .88319 .52355 Mtetra
.88319 .52355 .88745 .52931 .89828 .52616 .89404 .52039 Mtetra
.89404 .52039 .89828 .52616 .90914 .52301 .90493 .51722 Mtetra
.90493 .51722 .90914 .52301 .92004 .51985 .91586 .51403 Mtetra
.91586 .51403 .92004 .51985 .93098 .51667 .92683 .51083 Mtetra
.92683 .51083 .93098 .51667 .94196 .51348 .93784 .50762 Mtetra
.93784 .50762 .94196 .51348 .95299 .51028 .94889 .5044 Mtetra
.94889 .5044 .95299 .51028 .96405 .50707 .95999 .50117 Mtetra
.905 .708 .626 r
.36361 .67053 .36905 .67741 .37837 .6683 .3745 .62582 Mtetra
.009 0 .493 r
.3745 .62582 .37837 .6683 .38734 .66794 .38187 .66243 Mtetra
.61 .713 .918 r
.38187 .66243 .38734 .66794 .3964 .66606 .39094 .66085 Mtetra
.627 .73 .922 r
.39094 .66085 .3964 .66606 .40551 .66416 .40006 .65887 Mtetra
.609 .722 .926 r
.40006 .65887 .40551 .66416 .41459 .66378 .40921 .65725 Mtetra
.952 .62 .354 r
.40921 .65725 .41459 .66378 .42398 .65452 .41702 .70028 Mtetra
0 0 .179 r
.41702 .70028 .42398 .65452 .43313 .6545 .42775 .64888 Mtetra
.611 .712 .916 r
.42775 .64888 .43313 .6545 .44236 .65245 .43699 .64724 Mtetra
.636 .736 .92 r
.43699 .64724 .44236 .65245 .45164 .65016 .44629 .645 Mtetra
.64 .74 .921 r
.44629 .645 .45164 .65016 .46095 .64785 .45562 .64266 Mtetra
.636 .738 .922 r
.45562 .64266 .46095 .64785 .47029 .6458 .46498 .6404 Mtetra
.604 .72 .927 r
.46498 .6404 .47029 .6458 .47962 .64659 .47436 .63883 Mtetra
.848 .715 .716 r
.47436 .63883 .47962 .64659 .48912 .6366 .48397 .62173 Mtetra
.308 .348 .74 r
.48397 .62173 .48912 .6366 .49855 .63554 .49331 .63 Mtetra
.626 .724 .917 r
.49331 .63 .49855 .63554 .50802 .63321 .5028 .62797 Mtetra
.645 .742 .92 r
.5028 .62797 .50802 .63321 .51753 .63062 .51233 .62546 Mtetra
.652 .748 .92 r
.51233 .62546 .51753 .63062 .52708 .62793 .52189 .62279 Mtetra
.655 .75 .92 r
.52189 .62279 .52708 .62793 .53665 .62516 .53149 .62003 Mtetra
.657 .752 .92 r
.53149 .62003 .53665 .62516 .54626 .62234 .54112 .61722 Mtetra
.658 .753 .92 r
.54112 .61722 .54626 .62234 .55591 .61949 .55079 .61436 Mtetra
.659 .754 .92 r
.55079 .61436 .55591 .61949 .56558 .61662 .56049 .61147 Mtetra
.56049 .61147 .56558 .61662 .57529 .61373 .57022 .60856 Mtetra
.57022 .60856 .57529 .61373 .58503 .61084 .57998 .60565 Mtetra
.57998 .60565 .58503 .61084 .59481 .60795 .58978 .60274 Mtetra
.658 .753 .92 r
.58978 .60274 .59481 .60795 .60462 .60505 .59962 .59982 Mtetra
.59962 .59982 .60462 .60505 .61447 .60215 .60949 .59689 Mtetra
.60949 .59689 .61447 .60215 .62435 .59924 .61939 .59396 Mtetra
.61939 .59396 .62435 .59924 .63426 .59632 .62933 .59103 Mtetra
.62933 .59103 .63426 .59632 .64421 .5934 .63931 .58809 Mtetra
.63931 .58809 .64421 .5934 .6542 .59047 .64931 .58514 Mtetra
.657 .753 .92 r
.64931 .58514 .6542 .59047 .66422 .58753 .65936 .58218 Mtetra
.65936 .58218 .66422 .58753 .67428 .58459 .66944 .57921 Mtetra
.66944 .57921 .67428 .58459 .68437 .58163 .67956 .57623 Mtetra
.67956 .57623 .68437 .58163 .6945 .57866 .68971 .57325 Mtetra
.68971 .57325 .6945 .57866 .70466 .57569 .6999 .57025 Mtetra
.657 .752 .92 r
.6999 .57025 .70466 .57569 .71486 .5727 .71013 .56725 Mtetra
.71013 .56725 .71486 .5727 .7251 .56971 .72039 .56423 Mtetra
.72039 .56423 .7251 .56971 .73537 .56671 .73069 .56121 Mtetra
.73069 .56121 .73537 .56671 .74568 .56369 .74103 .55817 Mtetra
.74103 .55817 .74568 .56369 .75603 .56067 .7514 .55513 Mtetra
.7514 .55513 .75603 .56067 .76642 .55763 .76181 .55207 Mtetra
.76181 .55207 .76642 .55763 .77684 .55459 .77226 .54901 Mtetra
.77226 .54901 .77684 .55459 .7873 .55153 .78275 .54593 Mtetra
.78275 .54593 .7873 .55153 .7978 .54847 .79328 .54285 Mtetra
.79328 .54285 .7978 .54847 .80834 .54539 .80384 .53975 Mtetra
.80384 .53975 .80834 .54539 .81891 .5423 .81444 .53664 Mtetra
.81444 .53664 .81891 .5423 .82953 .53921 .82509 .53352 Mtetra
.82509 .53352 .82953 .53921 .84018 .5361 .83577 .53039 Mtetra
.83577 .53039 .84018 .5361 .85087 .53298 .84649 .52725 Mtetra
.84649 .52725 .85087 .53298 .8616 .52985 .85725 .5241 Mtetra
.85725 .5241 .8616 .52985 .87237 .52671 .86805 .52094 Mtetra
.86805 .52094 .87237 .52671 .88319 .52355 .87889 .51776 Mtetra
.87889 .51776 .88319 .52355 .89404 .52039 .88977 .51458 Mtetra
.88977 .51458 .89404 .52039 .90493 .51722 .90069 .51138 Mtetra
.90069 .51138 .90493 .51722 .91586 .51403 .91165 .50817 Mtetra
.91165 .50817 .91586 .51403 .92683 .51083 .92265 .50495 Mtetra
.92265 .50495 .92683 .51083 .93784 .50762 .93369 .50172 Mtetra
.93369 .50172 .93784 .50762 .94889 .5044 .94477 .49848 Mtetra
.94477 .49848 .94889 .5044 .95999 .50117 .9559 .49522 Mtetra
.506 .671 .938 r
.35808 .66491 .36361 .67053 .3745 .62582 .36702 .6651 Mtetra
.464 .216 .452 r
.36702 .6651 .3745 .62582 .38187 .66243 .37642 .65592 Mtetra
.557 .659 .904 r
.37642 .65592 .38187 .66243 .39094 .66085 .38545 .65553 Mtetra
.623 .726 .921 r
.38545 .65553 .39094 .66085 .40006 .65887 .39459 .65361 Mtetra
.623 .729 .923 r
.39459 .65361 .40006 .65887 .40921 .65725 .40376 .65167 Mtetra
.543 .689 .934 r
.40376 .65167 .40921 .65725 .41702 .70028 .41292 .65126 Mtetra
.63 .449 .619 r
.41292 .65126 .41702 .70028 .42775 .64888 .42238 .64193 Mtetra
.545 .641 .896 r
.42238 .64193 .42775 .64888 .43699 .64724 .4316 .64187 Mtetra
.629 .729 .919 r
.4316 .64187 .43699 .64724 .44629 .645 .4409 .63979 Mtetra
.639 .739 .921 r
.4409 .63979 .44629 .645 .45562 .64266 .45025 .63745 Mtetra
.64 .74 .921 r
.45025 .63745 .45562 .64266 .46498 .6404 .45963 .6351 Mtetra
.628 .733 .923 r
.45963 .6351 .46498 .6404 .47436 .63883 .46905 .63301 Mtetra
.469 .651 .938 r
.46905 .63301 .47436 .63883 .48397 .62173 .47846 .63377 Mtetra
.079 0 .086 r
.47846 .63377 .48397 .62173 .49331 .63 .48804 .62371 Mtetra
.588 .684 .908 r
.48804 .62371 .49331 .63 .5028 .62797 .49754 .6226 Mtetra
.639 .737 .919 r
.49754 .6226 .5028 .62797 .51233 .62546 .50709 .62023 Mtetra
.649 .746 .92 r
.50709 .62023 .51233 .62546 .52189 .62279 .51667 .6176 Mtetra
.653 .749 .92 r
.51667 .6176 .52189 .62279 .53149 .62003 .52629 .61486 Mtetra
.656 .751 .92 r
.52629 .61486 .53149 .62003 .54112 .61722 .53595 .61205 Mtetra
.657 .753 .92 r
.53595 .61205 .54112 .61722 .55079 .61436 .54563 .60918 Mtetra
.658 .753 .92 r
.54563 .60918 .55079 .61436 .56049 .61147 .55536 .60628 Mtetra
.659 .754 .92 r
.55536 .60628 .56049 .61147 .57022 .60856 .56511 .60336 Mtetra
.56511 .60336 .57022 .60856 .57998 .60565 .5749 .60043 Mtetra
.5749 .60043 .57998 .60565 .58978 .60274 .58472 .59749 Mtetra
.58472 .59749 .58978 .60274 .59962 .59982 .59458 .59455 Mtetra
.658 .753 .92 r
.59458 .59455 .59962 .59982 .60949 .59689 .60447 .59161 Mtetra
.60447 .59161 .60949 .59689 .61939 .59396 .6144 .58866 Mtetra
.6144 .58866 .61939 .59396 .62933 .59103 .62436 .5857 Mtetra
.62436 .5857 .62933 .59103 .63931 .58809 .63436 .58274 Mtetra
.63436 .58274 .63931 .58809 .64931 .58514 .6444 .57977 Mtetra
.6444 .57977 .64931 .58514 .65936 .58218 .65447 .57679 Mtetra
.657 .753 .92 r
.65447 .57679 .65936 .58218 .66944 .57921 .66457 .5738 Mtetra
.66457 .5738 .66944 .57921 .67956 .57623 .67471 .5708 Mtetra
.67471 .5708 .67956 .57623 .68971 .57325 .68489 .5678 Mtetra
.68489 .5678 .68971 .57325 .6999 .57025 .69511 .56478 Mtetra
.657 .752 .92 r
.69511 .56478 .6999 .57025 .71013 .56725 .70536 .56176 Mtetra
.70536 .56176 .71013 .56725 .72039 .56423 .71565 .55872 Mtetra
.71565 .55872 .72039 .56423 .73069 .56121 .72597 .55568 Mtetra
.72597 .55568 .73069 .56121 .74103 .55817 .73634 .55262 Mtetra
.73634 .55262 .74103 .55817 .7514 .55513 .74674 .54955 Mtetra
.74674 .54955 .7514 .55513 .76181 .55207 .75718 .54648 Mtetra
.75718 .54648 .76181 .55207 .77226 .54901 .76765 .54339 Mtetra
.76765 .54339 .77226 .54901 .78275 .54593 .77817 .5403 Mtetra
.77817 .5403 .78275 .54593 .79328 .54285 .78872 .53719 Mtetra
.78872 .53719 .79328 .54285 .80384 .53975 .79931 .53407 Mtetra
.79931 .53407 .80384 .53975 .81444 .53664 .80994 .53094 Mtetra
.80994 .53094 .81444 .53664 .82509 .53352 .82061 .5278 Mtetra
.82061 .5278 .82509 .53352 .83577 .53039 .83132 .52465 Mtetra
.83132 .52465 .83577 .53039 .84649 .52725 .84207 .52149 Mtetra
.84207 .52149 .84649 .52725 .85725 .5241 .85286 .51831 Mtetra
.85286 .51831 .85725 .5241 .86805 .52094 .86369 .51513 Mtetra
.86369 .51513 .86805 .52094 .87889 .51776 .87456 .51193 Mtetra
.87456 .51193 .87889 .51776 .88977 .51458 .88547 .50873 Mtetra
.88547 .50873 .88977 .51458 .90069 .51138 .89642 .50551 Mtetra
.89642 .50551 .90069 .51138 .91165 .50817 .90741 .50228 Mtetra
.90741 .50228 .91165 .50817 .92265 .50495 .91844 .49903 Mtetra
.91844 .49903 .92265 .50495 .93369 .50172 .92951 .49578 Mtetra
.92951 .49578 .93369 .50172 .94477 .49848 .94063 .49251 Mtetra
.94063 .49251 .94477 .49848 .9559 .49522 .95178 .48923 Mtetra
.597 .715 .927 r
.3525 .65953 .35808 .66491 .36702 .6651 .36153 .65814 Mtetra
.906 .708 .625 r
.36153 .65814 .36702 .6651 .37642 .65592 .37253 .6132 Mtetra
.003 0 .49 r
.37253 .6132 .37642 .65592 .38545 .65553 .37994 .64994 Mtetra
.61 .713 .918 r
.37994 .64994 .38545 .65553 .39459 .65361 .38908 .64832 Mtetra
.627 .73 .922 r
.38908 .64832 .39459 .65361 .40376 .65167 .39827 .64629 Mtetra
.609 .722 .926 r
.39827 .64629 .40376 .65167 .41292 .65126 .40748 .64464 Mtetra
.952 .619 .35 r
.40748 .64464 .41292 .65126 .42238 .64193 .41534 .68783 Mtetra
0 0 .172 r
.41534 .68783 .42238 .64193 .4316 .64187 .42617 .63617 Mtetra
.611 .712 .916 r
.42617 .63617 .4316 .64187 .4409 .63979 .43549 .63449 Mtetra
.636 .736 .92 r
.43549 .63449 .4409 .63979 .45025 .63745 .44485 .63221 Mtetra
.64 .74 .921 r
.44485 .63221 .45025 .63745 .45963 .6351 .45426 .62982 Mtetra
.636 .738 .922 r
.45426 .62982 .45963 .6351 .46905 .63301 .46369 .62752 Mtetra
.604 .72 .927 r
.46369 .62752 .46905 .63301 .47846 .63377 .47315 .62592 Mtetra
.849 .715 .716 r
.47315 .62592 .47846 .63377 .48804 .62371 .48284 .60871 Mtetra
.306 .347 .74 r
.48284 .60871 .48804 .62371 .49754 .6226 .49225 .61698 Mtetra
.626 .724 .917 r
.49225 .61698 .49754 .6226 .50709 .62023 .50181 .61491 Mtetra
.645 .742 .92 r
.50181 .61491 .50709 .62023 .51667 .6176 .51142 .61235 Mtetra
.652 .748 .92 r
.51142 .61235 .51667 .6176 .52629 .61486 .52106 .60964 Mtetra
.655 .75 .92 r
.52106 .60964 .52629 .61486 .53595 .61205 .53074 .60683 Mtetra
.657 .752 .92 r
.53074 .60683 .53595 .61205 .54563 .60918 .54045 .60397 Mtetra
.658 .753 .92 r
.54045 .60397 .54563 .60918 .55536 .60628 .55019 .60106 Mtetra
.659 .754 .92 r
.55019 .60106 .55536 .60628 .56511 .60336 .55997 .59813 Mtetra
.55997 .59813 .56511 .60336 .5749 .60043 .56978 .59518 Mtetra
.56978 .59518 .5749 .60043 .58472 .59749 .57963 .59222 Mtetra
.57963 .59222 .58472 .59749 .59458 .59455 .58951 .58925 Mtetra
.658 .753 .92 r
.58951 .58925 .59458 .59455 .60447 .59161 .59943 .58629 Mtetra
.59943 .58629 .60447 .59161 .6144 .58866 .60938 .58331 Mtetra
.60938 .58331 .6144 .58866 .62436 .5857 .61937 .58034 Mtetra
.61937 .58034 .62436 .5857 .63436 .58274 .62939 .57735 Mtetra
.62939 .57735 .63436 .58274 .6444 .57977 .63945 .57436 Mtetra
.63945 .57436 .6444 .57977 .65447 .57679 .64954 .57136 Mtetra
.657 .753 .92 r
.64954 .57136 .65447 .57679 .66457 .5738 .65967 .56835 Mtetra
.65967 .56835 .66457 .5738 .67471 .5708 .66984 .56533 Mtetra
.66984 .56533 .67471 .5708 .68489 .5678 .68004 .56231 Mtetra
.68004 .56231 .68489 .5678 .69511 .56478 .69028 .55927 Mtetra
.69028 .55927 .69511 .56478 .70536 .56176 .70056 .55623 Mtetra
.657 .752 .92 r
.70056 .55623 .70536 .56176 .71565 .55872 .71087 .55317 Mtetra
.71087 .55317 .71565 .55872 .72597 .55568 .72123 .5501 Mtetra
.72123 .5501 .72597 .55568 .73634 .55262 .73161 .54703 Mtetra
.73161 .54703 .73634 .55262 .74674 .54955 .74204 .54394 Mtetra
.74204 .54394 .74674 .54955 .75718 .54648 .75251 .54085 Mtetra
.75251 .54085 .75718 .54648 .76765 .54339 .76301 .53774 Mtetra
.76301 .53774 .76765 .54339 .77817 .5403 .77355 .53462 Mtetra
.77355 .53462 .77817 .5403 .78872 .53719 .78413 .53149 Mtetra
.78413 .53149 .78872 .53719 .79931 .53407 .79475 .52835 Mtetra
.79475 .52835 .79931 .53407 .80994 .53094 .80541 .5252 Mtetra
.80541 .5252 .80994 .53094 .82061 .5278 .81611 .52204 Mtetra
.81611 .52204 .82061 .5278 .83132 .52465 .82685 .51887 Mtetra
.82685 .51887 .83132 .52465 .84207 .52149 .83763 .51568 Mtetra
.83763 .51568 .84207 .52149 .85286 .51831 .84844 .51249 Mtetra
.84844 .51249 .85286 .51831 .86369 .51513 .8593 .50928 Mtetra
.8593 .50928 .86369 .51513 .87456 .51193 .8702 .50606 Mtetra
.8702 .50606 .87456 .51193 .88547 .50873 .88114 .50283 Mtetra
.88114 .50283 .88547 .50873 .89642 .50551 .89212 .49959 Mtetra
.89212 .49959 .89642 .50551 .90741 .50228 .90314 .49634 Mtetra
.90314 .49634 .90741 .50228 .91844 .49903 .9142 .49307 Mtetra
.9142 .49307 .91844 .49903 .92951 .49578 .9253 .48979 Mtetra
.9253 .48979 .92951 .49578 .94063 .49251 .93645 .48651 Mtetra
.93645 .48651 .94063 .49251 .95178 .48923 .94764 .4832 Mtetra
.614 .723 .923 r
.34689 .65417 .3525 .65953 .36153 .65814 .35595 .65244 Mtetra
.506 .671 .938 r
.35595 .65244 .36153 .65814 .37253 .6132 .36496 .65259 Mtetra
.46 .21 .448 r
.36496 .65259 .37253 .6132 .37994 .64994 .37443 .64334 Mtetra
.557 .659 .904 r
.37443 .64334 .37994 .64994 .38908 .64832 .38354 .64292 Mtetra
.623 .726 .921 r
.38354 .64292 .38908 .64832 .39827 .64629 .39274 .64096 Mtetra
.623 .729 .923 r
.39274 .64096 .39827 .64629 .40748 .64464 .40199 .63898 Mtetra
.544 .689 .934 r
.40199 .63898 .40748 .64464 .41534 .68783 .41122 .63853 Mtetra
.629 .448 .618 r
.41122 .63853 .41534 .68783 .42617 .63617 .42076 .62913 Mtetra
.545 .641 .896 r
.42076 .62913 .42617 .63617 .43549 .63449 .43004 .62904 Mtetra
.629 .729 .919 r
.43004 .62904 .43549 .63449 .44485 .63221 .43942 .62691 Mtetra
.639 .739 .921 r
.43942 .62691 .44485 .63221 .45426 .62982 .44884 .62453 Mtetra
.64 .74 .921 r
.44884 .62453 .45426 .62982 .46369 .62752 .4583 .62214 Mtetra
.628 .733 .923 r
.4583 .62214 .46369 .62752 .47315 .62592 .46779 .62 Mtetra
.47 .651 .938 r
.46779 .62 .47315 .62592 .48284 .60871 .47727 .62074 Mtetra
.067 0 .075 r
.47727 .62074 .48284 .60871 .49225 .61698 .48693 .6106 Mtetra
.588 .684 .908 r
.48693 .6106 .49225 .61698 .50181 .61491 .49651 .60946 Mtetra
.639 .737 .919 r
.49651 .60946 .50181 .61491 .51142 .61235 .50613 .60704 Mtetra
.649 .746 .92 r
.50613 .60704 .51142 .61235 .52106 .60964 .5158 .60436 Mtetra
.653 .749 .92 r
.5158 .60436 .52106 .60964 .53074 .60683 .52549 .60157 Mtetra
.656 .751 .92 r
.52549 .60157 .53074 .60683 .54045 .60397 .53523 .59871 Mtetra
.657 .753 .92 r
.53523 .59871 .54045 .60397 .55019 .60106 .54499 .5958 Mtetra
.658 .753 .92 r
.54499 .5958 .55019 .60106 .55997 .59813 .5548 .59286 Mtetra
.659 .754 .92 r
.5548 .59286 .55997 .59813 .56978 .59518 .56463 .58989 Mtetra
.56463 .58989 .56978 .59518 .57963 .59222 .5745 .58691 Mtetra
.5745 .58691 .57963 .59222 .58951 .58925 .58441 .58392 Mtetra
.58441 .58392 .58951 .58925 .59943 .58629 .59435 .58093 Mtetra
.658 .753 .92 r
.59435 .58093 .59943 .58629 .60938 .58331 .60432 .57794 Mtetra
.60432 .57794 .60938 .58331 .61937 .58034 .61433 .57494 Mtetra
.61433 .57494 .61937 .58034 .62939 .57735 .62438 .57193 Mtetra
.62438 .57193 .62939 .57735 .63945 .57436 .63446 .56892 Mtetra
.63446 .56892 .63945 .57436 .64954 .57136 .64458 .5659 Mtetra
.64458 .5659 .64954 .57136 .65967 .56835 .65474 .56287 Mtetra
.657 .753 .92 r
.65474 .56287 .65967 .56835 .66984 .56533 .66493 .55983 Mtetra
.66493 .55983 .66984 .56533 .68004 .56231 .67516 .55678 Mtetra
.67516 .55678 .68004 .56231 .69028 .55927 .68542 .55373 Mtetra
.68542 .55373 .69028 .55927 .70056 .55623 .69573 .55066 Mtetra
.657 .752 .92 r
.69573 .55066 .70056 .55623 .71087 .55317 .70607 .54758 Mtetra
.70607 .54758 .71087 .55317 .72123 .5501 .71645 .5445 Mtetra
.71645 .5445 .72123 .5501 .73161 .54703 .72686 .5414 Mtetra
.72686 .5414 .73161 .54703 .74204 .54394 .73732 .53829 Mtetra
.73732 .53829 .74204 .54394 .75251 .54085 .74781 .53517 Mtetra
.74781 .53517 .75251 .54085 .76301 .53774 .75834 .53205 Mtetra
.75834 .53205 .76301 .53774 .77355 .53462 .76891 .52891 Mtetra
.76891 .52891 .77355 .53462 .78413 .53149 .77952 .52576 Mtetra
.77952 .52576 .78413 .53149 .79475 .52835 .79016 .52259 Mtetra
.79016 .52259 .79475 .52835 .80541 .5252 .80085 .51942 Mtetra
.80085 .51942 .80541 .5252 .81611 .52204 .81158 .51624 Mtetra
.81158 .51624 .81611 .52204 .82685 .51887 .82234 .51304 Mtetra
.82234 .51304 .82685 .51887 .83763 .51568 .83315 .50984 Mtetra
.83315 .50984 .83763 .51568 .84844 .51249 .844 .50662 Mtetra
.844 .50662 .84844 .51249 .8593 .50928 .85488 .50339 Mtetra
.85488 .50339 .8593 .50928 .8702 .50606 .86581 .50015 Mtetra
.86581 .50015 .8702 .50606 .88114 .50283 .87678 .4969 Mtetra
.87678 .4969 .88114 .50283 .89212 .49959 .88779 .49363 Mtetra
.88779 .49363 .89212 .49959 .90314 .49634 .89884 .49036 Mtetra
.89884 .49036 .90314 .49634 .9142 .49307 .90993 .48707 Mtetra
.90993 .48707 .9142 .49307 .9253 .48979 .92107 .48377 Mtetra
.92107 .48377 .9253 .48979 .93645 .48651 .93224 .48046 Mtetra
.93224 .48046 .93645 .48651 .94764 .4832 .94346 .47713 Mtetra
.613 .72 .921 r
.34124 .6487 .34689 .65417 .35595 .65244 .35032 .64697 Mtetra
.598 .715 .927 r
.35032 .64697 .35595 .65244 .36496 .65259 .35942 .64554 Mtetra
.907 .709 .624 r
.35942 .64554 .36496 .65259 .37443 .64334 .37054 .60037 Mtetra
0 0 .487 r
.37054 .60037 .37443 .64334 .38354 .64292 .37797 .63724 Mtetra
.61 .713 .918 r
.37797 .63724 .38354 .64292 .39274 .64096 .38718 .63559 Mtetra
.627 .73 .922 r
.38718 .63559 .39274 .64096 .40199 .63898 .39645 .63352 Mtetra
.609 .722 .925 r
.39645 .63352 .40199 .63898 .41122 .63853 .40573 .63183 Mtetra
.952 .618 .345 r
.40573 .63183 .41122 .63853 .42076 .62913 .41362 .67518 Mtetra
0 0 .165 r
.41362 .67518 .42076 .62913 .43004 .62904 .42457 .62325 Mtetra
.611 .712 .916 r
.42457 .62325 .43004 .62904 .43942 .62691 .43396 .62153 Mtetra
.636 .736 .92 r
.43396 .62153 .43942 .62691 .44884 .62453 .4434 .61921 Mtetra
.64 .74 .921 r
.4434 .61921 .44884 .62453 .4583 .62214 .45287 .61678 Mtetra
.636 .738 .922 r
.45287 .61678 .4583 .62214 .46779 .62 .46238 .61444 Mtetra
.604 .72 .927 r
.46238 .61444 .46779 .62 .47727 .62074 .47192 .61279 Mtetra
.85 .716 .716 r
.47192 .61279 .47727 .62074 .48693 .6106 .48169 .59547 Mtetra
.304 .346 .74 r
.48169 .59547 .48693 .6106 .49651 .60946 .49117 .60375 Mtetra
.626 .724 .917 r
.49117 .60375 .49651 .60946 .50613 .60704 .50081 .60163 Mtetra
.645 .742 .92 r
.50081 .60163 .50613 .60704 .5158 .60436 .5105 .59903 Mtetra
.652 .748 .92 r
.5105 .59903 .5158 .60436 .52549 .60157 .52022 .59627 Mtetra
.655 .75 .92 r
.52022 .59627 .52549 .60157 .53523 .59871 .52997 .59341 Mtetra
.657 .752 .92 r
.52997 .59341 .53523 .59871 .54499 .5958 .53976 .5905 Mtetra
.658 .753 .92 r
.53976 .5905 .54499 .5958 .5548 .59286 .54959 .58755 Mtetra
.659 .754 .92 r
.54959 .58755 .5548 .59286 .56463 .58989 .55945 .58457 Mtetra
.55945 .58457 .56463 .58989 .5745 .58691 .56934 .58157 Mtetra
.56934 .58157 .5745 .58691 .58441 .58392 .57927 .57856 Mtetra
.57927 .57856 .58441 .58392 .59435 .58093 .58923 .57554 Mtetra
.658 .753 .92 r
.58923 .57554 .59435 .58093 .60432 .57794 .59923 .57253 Mtetra
.59923 .57253 .60432 .57794 .61433 .57494 .60927 .56951 Mtetra
.60927 .56951 .61433 .57494 .62438 .57193 .61934 .56648 Mtetra
.61934 .56648 .62438 .57193 .63446 .56892 .62945 .56344 Mtetra
.62945 .56344 .63446 .56892 .64458 .5659 .63959 .5604 Mtetra
.63959 .5604 .64458 .5659 .65474 .56287 .64977 .55735 Mtetra
.657 .753 .92 r
.64977 .55735 .65474 .56287 .66493 .55983 .65999 .55429 Mtetra
.65999 .55429 .66493 .55983 .67516 .55678 .67024 .55122 Mtetra
.67024 .55122 .67516 .55678 .68542 .55373 .68053 .54814 Mtetra
.68053 .54814 .68542 .55373 .69573 .55066 .69086 .54506 Mtetra
.69086 .54506 .69573 .55066 .70607 .54758 .70123 .54196 Mtetra
.657 .752 .92 r
.70123 .54196 .70607 .54758 .71645 .5445 .71163 .53885 Mtetra
.71163 .53885 .71645 .5445 .72686 .5414 .72208 .53573 Mtetra
.72208 .53573 .72686 .5414 .73732 .53829 .73256 .5326 Mtetra
.73256 .5326 .73732 .53829 .74781 .53517 .74308 .52946 Mtetra
.74308 .52946 .74781 .53517 .75834 .53205 .75363 .52631 Mtetra
.75363 .52631 .75834 .53205 .76891 .52891 .76423 .52315 Mtetra
.76423 .52315 .76891 .52891 .77952 .52576 .77487 .51998 Mtetra
.77487 .51998 .77952 .52576 .79016 .52259 .78554 .5168 Mtetra
.78554 .5168 .79016 .52259 .80085 .51942 .79626 .5136 Mtetra
.79626 .5136 .80085 .51942 .81158 .51624 .80701 .5104 Mtetra
.80701 .5104 .81158 .51624 .82234 .51304 .81781 .50718 Mtetra
.81781 .50718 .82234 .51304 .83315 .50984 .82864 .50395 Mtetra
.82864 .50395 .83315 .50984 .844 .50662 .83952 .50071 Mtetra
.83952 .50071 .844 .50662 .85488 .50339 .85043 .49746 Mtetra
.85043 .49746 .85488 .50339 .86581 .50015 .86139 .4942 Mtetra
.86139 .4942 .86581 .50015 .87678 .4969 .87239 .49092 Mtetra
.87239 .49092 .87678 .4969 .88779 .49363 .88343 .48764 Mtetra
.88343 .48764 .88779 .49363 .89884 .49036 .89451 .48434 Mtetra
.89451 .48434 .89884 .49036 .90993 .48707 .90563 .48103 Mtetra
.90563 .48103 .90993 .48707 .92107 .48377 .9168 .4777 Mtetra
.9168 .4777 .92107 .48377 .93224 .48046 .92801 .47437 Mtetra
.92801 .47437 .93224 .48046 .94346 .47713 .93926 .47102 Mtetra
.596 .702 .917 r
.33558 .64287 .34124 .6487 .35032 .64697 .34466 .64153 Mtetra
.614 .723 .923 r
.34466 .64153 .35032 .64697 .35942 .64554 .35379 .63976 Mtetra
.507 .671 .938 r
.35379 .63976 .35942 .64554 .37054 .60037 .36287 .63988 Mtetra
.456 .205 .444 r
.36287 .63988 .37054 .60037 .37797 .63724 .37242 .63055 Mtetra
.557 .659 .904 r
.37242 .63055 .37797 .63724 .38718 .63559 .38159 .6301 Mtetra
.623 .726 .921 r
.38159 .6301 .38718 .63559 .39645 .63352 .39087 .6281 Mtetra
.623 .729 .923 r
.39087 .6281 .39645 .63352 .40573 .63183 .40018 .62608 Mtetra
.544 .689 .934 r
.40018 .62608 .40573 .63183 .41362 .67518 .40948 .62559 Mtetra
.628 .446 .617 r
.40948 .62559 .41362 .67518 .42457 .62325 .41911 .61612 Mtetra
.544 .641 .897 r
.41911 .61612 .42457 .62325 .43396 .62153 .42846 .616 Mtetra
.629 .729 .919 r
.42846 .616 .43396 .62153 .4434 .61921 .43791 .61383 Mtetra
.639 .739 .921 r
.43791 .61383 .4434 .61921 .45287 .61678 .44741 .6114 Mtetra
.64 .74 .921 r
.44741 .6114 .45287 .61678 .46238 .61444 .45694 .60897 Mtetra
.628 .733 .923 r
.45694 .60897 .46238 .61444 .47192 .61279 .46651 .60679 Mtetra
.47 .651 .938 r
.46651 .60679 .47192 .61279 .48169 .59547 .47607 .60749 Mtetra
.056 0 .063 r
.47607 .60749 .48169 .59547 .49117 .60375 .48581 .59727 Mtetra
.588 .684 .908 r
.48581 .59727 .49117 .60375 .50081 .60163 .49546 .59609 Mtetra
.639 .737 .919 r
.49546 .59609 .50081 .60163 .5105 .59903 .50516 .59362 Mtetra
.649 .746 .92 r
.50516 .59362 .5105 .59903 .52022 .59627 .51491 .5909 Mtetra
.653 .749 .92 r
.51491 .5909 .52022 .59627 .52997 .59341 .52468 .58807 Mtetra
.656 .751 .92 r
.52468 .58807 .52997 .59341 .53976 .5905 .5345 .58516 Mtetra
.657 .753 .92 r
.5345 .58516 .53976 .5905 .54959 .58755 .54434 .5822 Mtetra
.658 .753 .92 r
.54434 .5822 .54959 .58755 .55945 .58457 .55423 .57921 Mtetra
.659 .754 .92 r
.55423 .57921 .55945 .58457 .56934 .58157 .56414 .57619 Mtetra
.56414 .57619 .56934 .58157 .57927 .57856 .5741 .57316 Mtetra
.5741 .57316 .57927 .57856 .58923 .57554 .58408 .57012 Mtetra
.58408 .57012 .58923 .57554 .59923 .57253 .59411 .56708 Mtetra
.658 .753 .92 r
.59411 .56708 .59923 .57253 .60927 .56951 .60417 .56404 Mtetra
.60417 .56404 .60927 .56951 .61934 .56648 .61426 .56099 Mtetra
.61426 .56099 .61934 .56648 .62945 .56344 .6244 .55793 Mtetra
.6244 .55793 .62945 .56344 .63959 .5604 .63456 .55487 Mtetra
.63456 .55487 .63959 .5604 .64977 .55735 .64477 .5518 Mtetra
.64477 .5518 .64977 .55735 .65999 .55429 .65501 .54871 Mtetra
.657 .753 .92 r
.65501 .54871 .65999 .55429 .67024 .55122 .66529 .54562 Mtetra
.66529 .54562 .67024 .55122 .68053 .54814 .67561 .54253 Mtetra
.67561 .54253 .68053 .54814 .69086 .54506 .68596 .53942 Mtetra
.68596 .53942 .69086 .54506 .70123 .54196 .69636 .5363 Mtetra
.657 .752 .92 r
.69636 .5363 .70123 .54196 .71163 .53885 .70679 .53317 Mtetra
.70679 .53317 .71163 .53885 .72208 .53573 .71726 .53003 Mtetra
.71726 .53003 .72208 .53573 .73256 .5326 .72777 .52688 Mtetra
.72777 .52688 .73256 .5326 .74308 .52946 .73831 .52372 Mtetra
.73831 .52372 .74308 .52946 .75363 .52631 .7489 .52054 Mtetra
.7489 .52054 .75363 .52631 .76423 .52315 .75952 .51736 Mtetra
.75952 .51736 .76423 .52315 .77487 .51998 .77019 .51417 Mtetra
.77019 .51417 .77487 .51998 .78554 .5168 .78089 .51096 Mtetra
.78089 .51096 .78554 .5168 .79626 .5136 .79163 .50775 Mtetra
.79163 .50775 .79626 .5136 .80701 .5104 .80242 .50452 Mtetra
.80242 .50452 .80701 .5104 .81781 .50718 .81324 .50128 Mtetra
.81324 .50128 .81781 .50718 .82864 .50395 .8241 .49803 Mtetra
.8241 .49803 .82864 .50395 .83952 .50071 .83501 .49476 Mtetra
.83501 .49476 .83952 .50071 .85043 .49746 .84595 .49149 Mtetra
.84595 .49149 .85043 .49746 .86139 .4942 .85694 .4882 Mtetra
.85694 .4882 .86139 .4942 .87239 .49092 .86797 .48491 Mtetra
.86797 .48491 .87239 .49092 .88343 .48764 .87904 .4816 Mtetra
.87904 .4816 .88343 .48764 .89451 .48434 .89015 .47827 Mtetra
.89015 .47827 .89451 .48434 .90563 .48103 .9013 .47494 Mtetra
.9013 .47494 .90563 .48103 .9168 .4777 .9125 .47159 Mtetra
.9125 .47159 .9168 .4777 .92801 .47437 .92374 .46823 Mtetra
.92374 .46823 .92801 .47437 .93926 .47102 .93502 .46486 Mtetra
.509 .611 .89 r
.32998 .63534 .33558 .64287 .34466 .64153 .33896 .63598 Mtetra
.613 .72 .921 r
.33896 .63598 .34466 .64153 .35379 .63976 .34811 .63421 Mtetra
.598 .715 .927 r
.34811 .63421 .35379 .63976 .36287 .63988 .35728 .63274 Mtetra
.908 .71 .623 r
.35728 .63274 .36287 .63988 .37242 .63055 .36851 .58734 Mtetra
0 0 .484 r
.36851 .58734 .37242 .63055 .38159 .6301 .37598 .62434 Mtetra
.61 .713 .918 r
.37598 .62434 .38159 .6301 .39087 .6281 .38526 .62264 Mtetra
.627 .73 .922 r
.38526 .62264 .39087 .6281 .40018 .62608 .39459 .62054 Mtetra
.609 .722 .925 r
.39459 .62054 .40018 .62608 .40948 .62559 .40395 .6188 Mtetra
.952 .617 .341 r
.40395 .6188 .40948 .62559 .41911 .61612 .41188 .66232 Mtetra
0 0 .158 r
.41188 .66232 .41911 .61612 .42846 .616 .42294 .61012 Mtetra
.611 .712 .917 r
.42294 .61012 .42846 .616 .43791 .61383 .4324 .60836 Mtetra
.636 .736 .92 r
.4324 .60836 .43791 .61383 .44741 .6114 .44191 .60599 Mtetra
.64 .74 .921 r
.44191 .60599 .44741 .6114 .45694 .60897 .45147 .60352 Mtetra
.636 .738 .922 r
.45147 .60352 .45694 .60897 .46651 .60679 .46105 .60113 Mtetra
.604 .72 .927 r
.46105 .60113 .46651 .60679 .47607 .60749 .47067 .59944 Mtetra
.85 .717 .715 r
.47067 .59944 .47607 .60749 .48581 .59727 .48052 .58202 Mtetra
.302 .344 .74 r
.48052 .58202 .48581 .59727 .49546 .59609 .49007 .59029 Mtetra
.626 .724 .917 r
.49007 .59029 .49546 .59609 .50516 .59362 .4998 .58813 Mtetra
.645 .742 .92 r
.4998 .58813 .50516 .59362 .51491 .5909 .50956 .58548 Mtetra
.652 .748 .92 r
.50956 .58548 .51491 .5909 .52468 .58807 .51936 .58267 Mtetra
.655 .75 .92 r
.51936 .58267 .52468 .58807 .5345 .58516 .52919 .57977 Mtetra
.657 .752 .92 r
.52919 .57977 .5345 .58516 .54434 .5822 .53907 .57681 Mtetra
.658 .753 .92 r
.53907 .57681 .54434 .5822 .55423 .57921 .54897 .57381 Mtetra
.659 .754 .92 r
.54897 .57381 .55423 .57921 .56414 .57619 .55891 .57077 Mtetra
.55891 .57077 .56414 .57619 .5741 .57316 .56889 .56772 Mtetra
.56889 .56772 .5741 .57316 .58408 .57012 .5789 .56467 Mtetra
.5789 .56467 .58408 .57012 .59411 .56708 .58895 .5616 Mtetra
.658 .753 .92 r
.58895 .5616 .59411 .56708 .60417 .56404 .59903 .55853 Mtetra
.59903 .55853 .60417 .56404 .61426 .56099 .60915 .55546 Mtetra
.60915 .55546 .61426 .56099 .6244 .55793 .61931 .55238 Mtetra
.61931 .55238 .6244 .55793 .63456 .55487 .6295 .5493 Mtetra
.6295 .5493 .63456 .55487 .64477 .5518 .63974 .5462 Mtetra
.63974 .5462 .64477 .5518 .65501 .54871 .65 .5431 Mtetra
.657 .753 .92 r
.65 .5431 .65501 .54871 .66529 .54562 .66031 .53999 Mtetra
.66031 .53999 .66529 .54562 .67561 .54253 .67065 .53687 Mtetra
.67065 .53687 .67561 .54253 .68596 .53942 .68103 .53374 Mtetra
.68103 .53374 .68596 .53942 .69636 .5363 .69145 .5306 Mtetra
.69145 .5306 .69636 .5363 .70679 .53317 .70191 .52744 Mtetra
.657 .752 .92 r
.70191 .52744 .70679 .53317 .71726 .53003 .71241 .52428 Mtetra
.71241 .52428 .71726 .53003 .72777 .52688 .72294 .52111 Mtetra
.72294 .52111 .72777 .52688 .73831 .52372 .73351 .51793 Mtetra
.73351 .51793 .73831 .52372 .7489 .52054 .74413 .51473 Mtetra
.74413 .51473 .7489 .52054 .75952 .51736 .75478 .51153 Mtetra
.75478 .51153 .75952 .51736 .77019 .51417 .76547 .50831 Mtetra
.76547 .50831 .77019 .51417 .78089 .51096 .7762 .50509 Mtetra
.7762 .50509 .78089 .51096 .79163 .50775 .78697 .50185 Mtetra
.78697 .50185 .79163 .50775 .80242 .50452 .79779 .4986 Mtetra
.79779 .4986 .80242 .50452 .81324 .50128 .80864 .49533 Mtetra
.80864 .49533 .81324 .50128 .8241 .49803 .81953 .49206 Mtetra
.81953 .49206 .8241 .49803 .83501 .49476 .83047 .48878 Mtetra
.83047 .48878 .83501 .49476 .84595 .49149 .84144 .48548 Mtetra
.84144 .48548 .84595 .49149 .85694 .4882 .85246 .48217 Mtetra
.85246 .48217 .85694 .4882 .86797 .48491 .86352 .47885 Mtetra
.86352 .47885 .86797 .48491 .87904 .4816 .87462 .47551 Mtetra
.87462 .47551 .87904 .4816 .89015 .47827 .88576 .47217 Mtetra
.88576 .47217 .89015 .47827 .9013 .47494 .89695 .46881 Mtetra
.89695 .46881 .9013 .47494 .9125 .47159 .90817 .46544 Mtetra
.90817 .46544 .9125 .47159 .92374 .46823 .91944 .46206 Mtetra
.91944 .46206 .92374 .46823 .93502 .46486 .93076 .45866 Mtetra
0 0 0 r
.32298 .65149 .32998 .63534 .33896 .63598 .33325 .63006 Mtetra
.596 .702 .917 r
.33325 .63006 .33896 .63598 .34811 .63421 .34239 .62869 Mtetra
.614 .723 .923 r
.34239 .62869 .34811 .63421 .35728 .63274 .3516 .62687 Mtetra
.507 .671 .937 r
.3516 .62687 .35728 .63274 .36851 .58734 .36075 .62696 Mtetra
.452 .199 .439 r
.36075 .62696 .36851 .58734 .37598 .62434 .37037 .61756 Mtetra
.557 .659 .904 r
.37037 .61756 .37598 .62434 .38526 .62264 .37961 .61707 Mtetra
.623 .726 .921 r
.37961 .61707 .38526 .62264 .39459 .62054 .38896 .61503 Mtetra
.623 .729 .923 r
.38896 .61503 .39459 .62054 .40395 .6188 .39835 .61297 Mtetra
.544 .689 .934 r
.39835 .61297 .40395 .6188 .41188 .66232 .40772 .61245 Mtetra
.627 .445 .616 r
.40772 .61245 .41188 .66232 .42294 .61012 .41743 .60289 Mtetra
.544 .641 .897 r
.41743 .60289 .42294 .61012 .4324 .60836 .42685 .60274 Mtetra
.629 .729 .919 r
.42685 .60274 .4324 .60836 .44191 .60599 .43638 .60053 Mtetra
.639 .739 .921 r
.43638 .60053 .44191 .60599 .45147 .60352 .44596 .59806 Mtetra
.64 .74 .921 r
.44596 .59806 .45147 .60352 .46105 .60113 .45556 .59557 Mtetra
.628 .733 .923 r
.45556 .59557 .46105 .60113 .47067 .59944 .46521 .59335 Mtetra
.471 .651 .938 r
.46521 .59335 .47067 .59944 .48052 .58202 .47484 .59402 Mtetra
.044 0 .052 r
.47484 .59402 .48052 .58202 .49007 .59029 .48466 .58372 Mtetra
.587 .684 .908 r
.48466 .58372 .49007 .59029 .4998 .58813 .49439 .5825 Mtetra
.639 .737 .919 r
.49439 .5825 .4998 .58813 .50956 .58548 .50418 .57999 Mtetra
.649 .746 .92 r
.50418 .57999 .50956 .58548 .51936 .58267 .514 .57722 Mtetra
.653 .749 .92 r
.514 .57722 .51936 .58267 .52919 .57977 .52386 .57433 Mtetra
.656 .751 .92 r
.52386 .57433 .52919 .57977 .53907 .57681 .53375 .57138 Mtetra
.657 .753 .92 r
.53375 .57138 .53907 .57681 .54897 .57381 .54368 .56837 Mtetra
.658 .753 .92 r
.54368 .56837 .54897 .57381 .55891 .57077 .55365 .56532 Mtetra
.659 .754 .92 r
.55365 .56532 .55891 .57077 .56889 .56772 .56365 .56225 Mtetra
.56365 .56225 .56889 .56772 .5789 .56467 .57368 .55917 Mtetra
.57368 .55917 .5789 .56467 .58895 .5616 .58376 .55609 Mtetra
.58376 .55609 .58895 .5616 .59903 .55853 .59386 .553 Mtetra
.658 .753 .92 r
.59386 .553 .59903 .55853 .60915 .55546 .60401 .5499 Mtetra
.60401 .5499 .60915 .55546 .61931 .55238 .61419 .5468 Mtetra
.61419 .5468 .61931 .55238 .6295 .5493 .62441 .54369 Mtetra
.62441 .54369 .6295 .5493 .63974 .5462 .63467 .54057 Mtetra
.63467 .54057 .63974 .5462 .65 .5431 .64496 .53745 Mtetra
.64496 .53745 .65 .5431 .66031 .53999 .65529 .53432 Mtetra
.657 .753 .92 r
.65529 .53432 .66031 .53999 .67065 .53687 .66566 .53117 Mtetra
.66566 .53117 .67065 .53687 .68103 .53374 .67607 .52802 Mtetra
.67607 .52802 .68103 .53374 .69145 .5306 .68651 .52486 Mtetra
.68651 .52486 .69145 .5306 .70191 .52744 .697 .52168 Mtetra
.657 .752 .92 r
.697 .52168 .70191 .52744 .71241 .52428 .70752 .5185 Mtetra
.70752 .5185 .71241 .52428 .72294 .52111 .71808 .51531 Mtetra
.71808 .51531 .72294 .52111 .73351 .51793 .72868 .5121 Mtetra
.72868 .5121 .73351 .51793 .74413 .51473 .73932 .50888 Mtetra
.73932 .50888 .74413 .51473 .75478 .51153 .75 .50566 Mtetra
.75 .50566 .75478 .51153 .76547 .50831 .76072 .50242 Mtetra
.76072 .50242 .76547 .50831 .7762 .50509 .77148 .49917 Mtetra
.77148 .49917 .7762 .50509 .78697 .50185 .78229 .49591 Mtetra
.78229 .49591 .78697 .50185 .79779 .4986 .79313 .49263 Mtetra
.79313 .49263 .79779 .4986 .80864 .49533 .80401 .48935 Mtetra
.80401 .48935 .80864 .49533 .81953 .49206 .81493 .48605 Mtetra
.81493 .48605 .81953 .49206 .83047 .48878 .82589 .48274 Mtetra
.82589 .48274 .83047 .48878 .84144 .48548 .8369 .47942 Mtetra
.8369 .47942 .84144 .48548 .85246 .48217 .84795 .47609 Mtetra
.84795 .47609 .85246 .48217 .86352 .47885 .85904 .47275 Mtetra
.85904 .47275 .86352 .47885 .87462 .47551 .87017 .46939 Mtetra
.87017 .46939 .87462 .47551 .88576 .47217 .88134 .46602 Mtetra
.88134 .46602 .88576 .47217 .89695 .46881 .89256 .46264 Mtetra
.89256 .46264 .89695 .46881 .90817 .46544 .90382 .45924 Mtetra
.90382 .45924 .90817 .46544 .91944 .46206 .91512 .45584 Mtetra
.91512 .45584 .91944 .46206 .93076 .45866 .92646 .45242 Mtetra
.697 .553 .687 r
.318 .63196 .32298 .65149 .33325 .63006 .3276 .62244 Mtetra
.508 .611 .89 r
.3276 .62244 .33325 .63006 .34239 .62869 .33664 .62305 Mtetra
.613 .72 .921 r
.33664 .62305 .34239 .62869 .3516 .62687 .34586 .62124 Mtetra
.598 .715 .927 r
.34586 .62124 .3516 .62687 .36075 .62696 .3551 .61973 Mtetra
.909 .71 .622 r
.3551 .61973 .36075 .62696 .37037 .61756 .36644 .5741 Mtetra
0 0 .48 r
.36644 .5741 .37037 .61756 .37961 .61707 .37395 .61122 Mtetra
.609 .713 .918 r
.37395 .61122 .37961 .61707 .38896 .61503 .3833 .60949 Mtetra
.627 .73 .922 r
.3833 .60949 .38896 .61503 .39835 .61297 .39271 .60734 Mtetra
.609 .722 .925 r
.39271 .60734 .39835 .61297 .40772 .61245 .40214 .60556 Mtetra
.953 .615 .336 r
.40214 .60556 .40772 .61245 .41743 .60289 .41011 .64924 Mtetra
0 0 .151 r
.41011 .64924 .41743 .60289 .42685 .60274 .42128 .59677 Mtetra
.611 .712 .917 r
.42128 .59677 .42685 .60274 .43638 .60053 .43082 .59497 Mtetra
.636 .736 .92 r
.43082 .59497 .43638 .60053 .44596 .59806 .44041 .59256 Mtetra
.64 .74 .921 r
.44041 .59256 .44596 .59806 .45556 .59557 .45004 .59004 Mtetra
.636 .738 .922 r
.45004 .59004 .45556 .59557 .46521 .59335 .4597 .5876 Mtetra
.605 .72 .927 r
.4597 .5876 .46521 .59335 .47484 .59402 .46939 .58587 Mtetra
.851 .718 .715 r
.46939 .58587 .47484 .59402 .48466 .58372 .47934 .56833 Mtetra
.3 .343 .739 r
.47934 .56833 .48466 .58372 .49439 .5825 .48896 .57661 Mtetra
.626 .724 .917 r
.48896 .57661 .49439 .5825 .50418 .57999 .49876 .5744 Mtetra
.645 .742 .92 r
.49876 .5744 .50418 .57999 .514 .57722 .5086 .5717 Mtetra
.652 .748 .92 r
.5086 .5717 .514 .57722 .52386 .57433 .51849 .56884 Mtetra
.655 .75 .92 r
.51849 .56884 .52386 .57433 .53375 .57138 .5284 .5659 Mtetra
.657 .752 .92 r
.5284 .5659 .53375 .57138 .54368 .56837 .53836 .56288 Mtetra
.658 .753 .92 r
.53836 .56288 .54368 .56837 .55365 .56532 .54835 .55983 Mtetra
.659 .754 .92 r
.54835 .55983 .55365 .56532 .56365 .56225 .55837 .55675 Mtetra
.55837 .55675 .56365 .56225 .57368 .55917 .56843 .55365 Mtetra
.56843 .55365 .57368 .55917 .58376 .55609 .57853 .55054 Mtetra
.57853 .55054 .58376 .55609 .59386 .553 .58866 .54742 Mtetra
.658 .753 .92 r
.58866 .54742 .59386 .553 .60401 .5499 .59883 .5443 Mtetra
.59883 .5443 .60401 .5499 .61419 .5468 .60904 .54118 Mtetra
.60904 .54118 .61419 .5468 .62441 .54369 .61928 .53804 Mtetra
.61928 .53804 .62441 .54369 .63467 .54057 .62956 .53491 Mtetra
.62956 .53491 .63467 .54057 .64496 .53745 .63988 .53176 Mtetra
.63988 .53176 .64496 .53745 .65529 .53432 .65024 .5286 Mtetra
.657 .753 .92 r
.65024 .5286 .65529 .53432 .66566 .53117 .66064 .52544 Mtetra
.66064 .52544 .66566 .53117 .67607 .52802 .67107 .52226 Mtetra
.67107 .52226 .67607 .52802 .68651 .52486 .68154 .51908 Mtetra
.68154 .51908 .68651 .52486 .697 .52168 .69205 .51588 Mtetra
.69205 .51588 .697 .52168 .70752 .5185 .7026 .51268 Mtetra
.657 .752 .92 r
.7026 .51268 .70752 .5185 .71808 .51531 .71319 .50946 Mtetra
.71319 .50946 .71808 .51531 .72868 .5121 .72382 .50623 Mtetra
.72382 .50623 .72868 .5121 .73932 .50888 .73449 .50299 Mtetra
.73449 .50299 .73932 .50888 .75 .50566 .7452 .49974 Mtetra
.7452 .49974 .75 .50566 .76072 .50242 .75595 .49648 Mtetra
.75595 .49648 .76072 .50242 .77148 .49917 .76673 .49321 Mtetra
.76673 .49321 .77148 .49917 .78229 .49591 .77756 .48993 Mtetra
.77756 .48993 .78229 .49591 .79313 .49263 .78843 .48663 Mtetra
.78843 .48663 .79313 .49263 .80401 .48935 .79934 .48332 Mtetra
.79934 .48332 .80401 .48935 .81493 .48605 .8103 .48 Mtetra
.8103 .48 .81493 .48605 .82589 .48274 .82129 .47667 Mtetra
.82129 .47667 .82589 .48274 .8369 .47942 .83232 .47333 Mtetra
.83232 .47333 .8369 .47942 .84795 .47609 .8434 .46997 Mtetra
.8434 .46997 .84795 .47609 .85904 .47275 .85452 .4666 Mtetra
.85452 .4666 .85904 .47275 .87017 .46939 .86568 .46322 Mtetra
.86568 .46322 .87017 .46939 .88134 .46602 .87689 .45983 Mtetra
.87689 .45983 .88134 .46602 .89256 .46264 .88814 .45642 Mtetra
.88814 .45642 .89256 .46264 .90382 .45924 .89943 .453 Mtetra
.89943 .453 .90382 .45924 .91512 .45584 .91076 .44957 Mtetra
.91076 .44957 .91512 .45584 .92646 .45242 .92214 .44613 Mtetra
.761 .291 0 r
.31223 .62537 .318 .63196 .3276 .62244 .32051 .63861 Mtetra
0 0 0 r
.32051 .63861 .3276 .62244 .33664 .62305 .33088 .61705 Mtetra
.596 .702 .917 r
.33088 .61705 .33664 .62305 .34586 .62124 .34009 .61563 Mtetra
.614 .723 .923 r
.34009 .61563 .34586 .62124 .3551 .61973 .34937 .61377 Mtetra
.507 .671 .937 r
.34937 .61377 .3551 .61973 .36644 .5741 .35859 .61383 Mtetra
.447 .194 .435 r
.35859 .61383 .36644 .5741 .37395 .61122 .36829 .60435 Mtetra
.557 .659 .905 r
.36829 .60435 .37395 .61122 .3833 .60949 .3776 .60383 Mtetra
.623 .726 .921 r
.3776 .60383 .3833 .60949 .39271 .60734 .38703 .60174 Mtetra
.623 .729 .923 r
.38703 .60174 .39271 .60734 .40214 .60556 .39649 .59964 Mtetra
.544 .689 .934 r
.39649 .59964 .40214 .60556 .41011 .64924 .40594 .59908 Mtetra
.626 .443 .615 r
.40594 .59908 .41011 .64924 .42128 .59677 .41572 .58945 Mtetra
.544 .641 .897 r
.41572 .58945 .42128 .59677 .43082 .59497 .42522 .58926 Mtetra
.629 .729 .919 r
.42522 .58926 .43082 .59497 .44041 .59256 .43483 .587 Mtetra
.639 .739 .921 r
.43483 .587 .44041 .59256 .45004 .59004 .44448 .58449 Mtetra
.64 .74 .921 r
.44448 .58449 .45004 .59004 .4597 .5876 .45416 .58196 Mtetra
.628 .733 .923 r
.45416 .58196 .4597 .5876 .46939 .58587 .46388 .57968 Mtetra
.471 .651 .938 r
.46388 .57968 .46939 .58587 .47934 .56833 .4736 .58033 Mtetra
.032 0 .04 r
.4736 .58033 .47934 .56833 .48896 .57661 .4835 .56994 Mtetra
.587 .684 .908 r
.4835 .56994 .48896 .57661 .49876 .5744 .49331 .56868 Mtetra
.639 .737 .919 r
.49331 .56868 .49876 .5744 .5086 .5717 .50317 .56612 Mtetra
.649 .746 .92 r
.50317 .56612 .5086 .5717 .51849 .56884 .51308 .5633 Mtetra
.653 .749 .92 r
.51308 .5633 .51849 .56884 .5284 .5659 .52302 .56036 Mtetra
.656 .751 .92 r
.52302 .56036 .5284 .5659 .53836 .56288 .533 .55736 Mtetra
.657 .753 .92 r
.533 .55736 .53836 .56288 .54835 .55983 .54301 .5543 Mtetra
.658 .753 .92 r
.54301 .5543 .54835 .55983 .55837 .55675 .55306 .5512 Mtetra
.659 .754 .92 r
.55306 .5512 .55837 .55675 .56843 .55365 .56314 .54808 Mtetra
.56314 .54808 .56843 .55365 .57853 .55054 .57326 .54495 Mtetra
.57326 .54495 .57853 .55054 .58866 .54742 .58342 .54181 Mtetra
.58342 .54181 .58866 .54742 .59883 .5443 .59362 .53867 Mtetra
.658 .753 .92 r
.59362 .53867 .59883 .5443 .60904 .54118 .60385 .53552 Mtetra
.60385 .53552 .60904 .54118 .61928 .53804 .61412 .53236 Mtetra
.61412 .53236 .61928 .53804 .62956 .53491 .62443 .5292 Mtetra
.62443 .5292 .62956 .53491 .63988 .53176 .63477 .52603 Mtetra
.63477 .52603 .63988 .53176 .65024 .5286 .64516 .52285 Mtetra
.64516 .52285 .65024 .5286 .66064 .52544 .65558 .51967 Mtetra
.657 .753 .92 r
.65558 .51967 .66064 .52544 .67107 .52226 .66604 .51647 Mtetra
.66604 .51647 .67107 .52226 .68154 .51908 .67654 .51326 Mtetra
.67654 .51326 .68154 .51908 .69205 .51588 .68707 .51004 Mtetra
.68707 .51004 .69205 .51588 .7026 .51268 .69765 .50681 Mtetra
.657 .752 .92 r
.69765 .50681 .7026 .51268 .71319 .50946 .70827 .50357 Mtetra
.70827 .50357 .71319 .50946 .72382 .50623 .71892 .50032 Mtetra
.71892 .50032 .72382 .50623 .73449 .50299 .72962 .49706 Mtetra
.72962 .49706 .73449 .50299 .7452 .49974 .74036 .49379 Mtetra
.74036 .49379 .7452 .49974 .75595 .49648 .75113 .49051 Mtetra
.75113 .49051 .75595 .49648 .76673 .49321 .76195 .48721 Mtetra
.76195 .48721 .76673 .49321 .77756 .48993 .77281 .4839 Mtetra
.77281 .4839 .77756 .48993 .78843 .48663 .78371 .48058 Mtetra
.78371 .48058 .78843 .48663 .79934 .48332 .79465 .47725 Mtetra
.79465 .47725 .79934 .48332 .8103 .48 .80563 .47391 Mtetra
.80563 .47391 .8103 .48 .82129 .47667 .81665 .47055 Mtetra
.81665 .47055 .82129 .47667 .83232 .47333 .82772 .46719 Mtetra
.82772 .46719 .83232 .47333 .8434 .46997 .83882 .46381 Mtetra
.83882 .46381 .8434 .46997 .85452 .4666 .84998 .46041 Mtetra
.84998 .46041 .85452 .4666 .86568 .46322 .86117 .45701 Mtetra
.86117 .45701 .86568 .46322 .87689 .45983 .8724 .45359 Mtetra
.8724 .45359 .87689 .45983 .88814 .45642 .88368 .45016 Mtetra
.88368 .45016 .88814 .45642 .89943 .453 .89501 .44672 Mtetra
.89501 .44672 .89943 .453 .91076 .44957 .90637 .44326 Mtetra
.90637 .44326 .91076 .44957 .92214 .44613 .91778 .43979 Mtetra
.547 .69 .933 r
.30638 .61951 .31223 .62537 .32051 .63861 .31549 .61892 Mtetra
.697 .553 .687 r
.31549 .61892 .32051 .63861 .33088 .61705 .32517 .60933 Mtetra
.508 .611 .89 r
.32517 .60933 .33088 .61705 .34009 .61563 .33429 .6099 Mtetra
.613 .72 .921 r
.33429 .6099 .34009 .61563 .34937 .61377 .34358 .60805 Mtetra
.598 .715 .927 r
.34358 .60805 .34937 .61377 .35859 .61383 .35289 .6065 Mtetra
.91 .711 .621 r
.35289 .6065 .35859 .61383 .36829 .60435 .36435 .56065 Mtetra
0 0 .477 r
.36435 .56065 .36829 .60435 .3776 .60383 .37188 .59789 Mtetra
.609 .713 .918 r
.37188 .59789 .3776 .60383 .38703 .60174 .38131 .59611 Mtetra
.627 .73 .922 r
.38131 .59611 .38703 .60174 .39649 .59964 .39079 .59392 Mtetra
.609 .722 .925 r
.39079 .59392 .39649 .59964 .40594 .59908 .4003 .5921 Mtetra
.953 .614 .331 r
.4003 .5921 .40594 .59908 .41572 .58945 .40831 .63594 Mtetra
0 0 .144 r
.40831 .63594 .41572 .58945 .42522 .58926 .4196 .5832 Mtetra
.611 .712 .917 r
.4196 .5832 .42522 .58926 .43483 .587 .42921 .58135 Mtetra
.636 .736 .92 r
.42921 .58135 .43483 .587 .44448 .58449 .43888 .5789 Mtetra
.64 .74 .921 r
.43888 .5789 .44448 .58449 .45416 .58196 .44859 .57633 Mtetra
.636 .738 .922 r
.44859 .57633 .45416 .58196 .46388 .57968 .45833 .57385 Mtetra
.605 .72 .926 r
.45833 .57385 .46388 .57968 .4736 .58033 .4681 .57207 Mtetra
.852 .719 .715 r
.4681 .57207 .4736 .58033 .4835 .56994 .47813 .55442 Mtetra
.298 .342 .739 r
.47813 .55442 .4835 .56994 .49331 .56868 .48783 .56269 Mtetra
.626 .724 .917 r
.48783 .56269 .49331 .56868 .50317 .56612 .49771 .56044 Mtetra
.645 .742 .92 r
.49771 .56044 .50317 .56612 .51308 .5633 .50763 .55769 Mtetra
.652 .748 .92 r
.50763 .55769 .51308 .5633 .52302 .56036 .5176 .55478 Mtetra
.655 .75 .92 r
.5176 .55478 .52302 .56036 .533 .55736 .5276 .55178 Mtetra
.657 .752 .92 r
.5276 .55178 .533 .55736 .54301 .5543 .53764 .54872 Mtetra
.658 .753 .92 r
.53764 .54872 .54301 .5543 .55306 .5512 .54771 .54561 Mtetra
.659 .754 .92 r
.54771 .54561 .55306 .5512 .56314 .54808 .55782 .54248 Mtetra
.55782 .54248 .56314 .54808 .57326 .54495 .56797 .53933 Mtetra
.56797 .53933 .57326 .54495 .58342 .54181 .57815 .53616 Mtetra
.57815 .53616 .58342 .54181 .59362 .53867 .58837 .53299 Mtetra
.658 .753 .92 r
.58837 .53299 .59362 .53867 .60385 .53552 .59863 .52982 Mtetra
.59863 .52982 .60385 .53552 .61412 .53236 .60892 .52664 Mtetra
.60892 .52664 .61412 .53236 .62443 .5292 .61925 .52346 Mtetra
.61925 .52346 .62443 .5292 .63477 .52603 .62963 .52027 Mtetra
.62963 .52027 .63477 .52603 .64516 .52285 .64003 .51706 Mtetra
.64003 .51706 .64516 .52285 .65558 .51967 .65048 .51385 Mtetra
.657 .753 .92 r
.65048 .51385 .65558 .51967 .66604 .51647 .66097 .51063 Mtetra
.66097 .51063 .66604 .51647 .67654 .51326 .6715 .5074 Mtetra
.6715 .5074 .67654 .51326 .68707 .51004 .68206 .50416 Mtetra
.68206 .50416 .68707 .51004 .69765 .50681 .69266 .50091 Mtetra
.69266 .50091 .69765 .50681 .70827 .50357 .70331 .49765 Mtetra
.657 .752 .92 r
.70331 .49765 .70827 .50357 .71892 .50032 .71399 .49438 Mtetra
.71399 .49438 .71892 .50032 .72962 .49706 .72472 .49109 Mtetra
.72472 .49109 .72962 .49706 .74036 .49379 .73548 .48779 Mtetra
.73548 .48779 .74036 .49379 .75113 .49051 .74629 .48449 Mtetra
.74629 .48449 .75113 .49051 .76195 .48721 .75713 .48117 Mtetra
.75713 .48117 .76195 .48721 .77281 .4839 .76802 .47784 Mtetra
.76802 .47784 .77281 .4839 .78371 .48058 .77895 .47449 Mtetra
.77895 .47449 .78371 .48058 .79465 .47725 .78992 .47114 Mtetra
.78992 .47114 .79465 .47725 .80563 .47391 .80093 .46777 Mtetra
.80093 .46777 .80563 .47391 .81665 .47055 .81198 .46439 Mtetra
.81198 .46439 .81665 .47055 .82772 .46719 .82308 .461 Mtetra
.82308 .461 .82772 .46719 .83882 .46381 .83422 .4576 Mtetra
.83422 .4576 .83882 .46381 .84998 .46041 .8454 .45418 Mtetra
.8454 .45418 .84998 .46041 .86117 .45701 .85662 .45075 Mtetra
.85662 .45075 .86117 .45701 .8724 .45359 .86789 .44731 Mtetra
.86789 .44731 .8724 .45359 .88368 .45016 .8792 .44386 Mtetra
.8792 .44386 .88368 .45016 .89501 .44672 .89055 .44039 Mtetra
.89055 .44039 .89501 .44672 .90637 .44326 .90195 .43691 Mtetra
.90195 .43691 .90637 .44326 .91778 .43979 .91339 .43341 Mtetra
.598 .714 .925 r
.30049 .61378 .30638 .61951 .31549 .61892 .30967 .61224 Mtetra
.756 .286 0 r
.30967 .61224 .31549 .61892 .32517 .60933 .31801 .6255 Mtetra
0 0 0 r
.31801 .6255 .32517 .60933 .33429 .6099 .32847 .60381 Mtetra
.595 .702 .917 r
.32847 .60381 .33429 .6099 .34358 .60805 .33775 .60235 Mtetra
.614 .723 .923 r
.33775 .60235 .34358 .60805 .35289 .6065 .3471 .60046 Mtetra
.507 .671 .937 r
.3471 .60046 .35289 .6065 .36435 .56065 .35639 .60048 Mtetra
.443 .188 .43 r
.35639 .60048 .36435 .56065 .37188 .59789 .36617 .59093 Mtetra
.557 .659 .905 r
.36617 .59093 .37188 .59789 .38131 .59611 .37556 .59037 Mtetra
.623 .726 .921 r
.37556 .59037 .38131 .59611 .39079 .59392 .38506 .58824 Mtetra
.623 .729 .923 r
.38506 .58824 .39079 .59392 .4003 .5921 .3946 .58608 Mtetra
.544 .689 .934 r
.3946 .58608 .4003 .5921 .40831 .63594 .40412 .58549 Mtetra
.625 .442 .614 r
.40412 .58549 .40831 .63594 .4196 .5832 .41398 .57578 Mtetra
.544 .641 .897 r
.41398 .57578 .4196 .5832 .42921 .58135 .42356 .57555 Mtetra
.629 .729 .919 r
.42356 .57555 .42921 .58135 .43888 .5789 .43324 .57325 Mtetra
.639 .739 .921 r
.43324 .57325 .43888 .5789 .44859 .57633 .44297 .57068 Mtetra
.64 .74 .921 r
.44297 .57068 .44859 .57633 .45833 .57385 .45274 .56811 Mtetra
.628 .733 .923 r
.45274 .56811 .45833 .57385 .4681 .57207 .46254 .56579 Mtetra
.472 .651 .937 r
.46254 .56579 .4681 .57207 .47813 .55442 .47233 .5664 Mtetra
.02 0 .027 r
.47233 .5664 .47813 .55442 .48783 .56269 .48232 .55593 Mtetra
.587 .684 .908 r
.48232 .55593 .48783 .56269 .49771 .56044 .49221 .55462 Mtetra
.639 .737 .919 r
.49221 .55462 .49771 .56044 .50763 .55769 .50216 .55201 Mtetra
.649 .746 .92 r
.50216 .55201 .50763 .55769 .5176 .55478 .51214 .54914 Mtetra
.653 .749 .92 r
.51214 .54914 .5176 .55478 .5276 .55178 .52217 .54616 Mtetra
.656 .751 .92 r
.52217 .54616 .5276 .55178 .53764 .54872 .53223 .5431 Mtetra
.657 .753 .92 r
.53223 .5431 .53764 .54872 .54771 .54561 .54232 .53999 Mtetra
.658 .753 .92 r
.54232 .53999 .54771 .54561 .55782 .54248 .55246 .53684 Mtetra
.659 .754 .92 r
.55246 .53684 .55782 .54248 .56797 .53933 .56263 .53366 Mtetra
.56263 .53366 .56797 .53933 .57815 .53616 .57284 .53048 Mtetra
.57284 .53048 .57815 .53616 .58837 .53299 .58308 .52729 Mtetra
.58308 .52729 .58837 .53299 .59863 .52982 .59337 .52409 Mtetra
.658 .753 .92 r
.59337 .52409 .59863 .52982 .60892 .52664 .60369 .52089 Mtetra
.60369 .52089 .60892 .52664 .61925 .52346 .61405 .51768 Mtetra
.61405 .51768 .61925 .52346 .62963 .52027 .62444 .51446 Mtetra
.62444 .51446 .62963 .52027 .64003 .51706 .63488 .51124 Mtetra
.63488 .51124 .64003 .51706 .65048 .51385 .64535 .508 Mtetra
.64535 .508 .65048 .51385 .66097 .51063 .65587 .50476 Mtetra
.657 .753 .92 r
.65587 .50476 .66097 .51063 .6715 .5074 .66642 .50151 Mtetra
.66642 .50151 .6715 .5074 .68206 .50416 .67701 .49824 Mtetra
.67701 .49824 .68206 .50416 .69266 .50091 .68764 .49497 Mtetra
.68764 .49497 .69266 .50091 .70331 .49765 .69832 .49168 Mtetra
.657 .752 .92 r
.69832 .49168 .70331 .49765 .71399 .49438 .70903 .48838 Mtetra
.70903 .48838 .71399 .49438 .72472 .49109 .71978 .48508 Mtetra
.71978 .48508 .72472 .49109 .73548 .48779 .73057 .48176 Mtetra
.73057 .48176 .73548 .48779 .74629 .48449 .74141 .47843 Mtetra
.74141 .47843 .74629 .48449 .75713 .48117 .75228 .47508 Mtetra
.75228 .47508 .75713 .48117 .76802 .47784 .7632 .47173 Mtetra
.7632 .47173 .76802 .47784 .77895 .47449 .77415 .46836 Mtetra
.77415 .46836 .77895 .47449 .78992 .47114 .78515 .46498 Mtetra
.78515 .46498 .78992 .47114 .80093 .46777 .79619 .46159 Mtetra
.79619 .46159 .80093 .46777 .81198 .46439 .80728 .45819 Mtetra
.80728 .45819 .81198 .46439 .82308 .461 .8184 .45477 Mtetra
.8184 .45477 .82308 .461 .83422 .4576 .82957 .45135 Mtetra
.82957 .45135 .83422 .4576 .8454 .45418 .84079 .44791 Mtetra
.84079 .44791 .8454 .45418 .85662 .45075 .85204 .44445 Mtetra
.85204 .44445 .85662 .45075 .86789 .44731 .86334 .44098 Mtetra
.86334 .44098 .86789 .44731 .8792 .44386 .87468 .43751 Mtetra
.87468 .43751 .8792 .44386 .89055 .44039 .88607 .43401 Mtetra
.88607 .43401 .89055 .44039 .90195 .43691 .8975 .43051 Mtetra
.8975 .43051 .90195 .43691 .91339 .43341 .90897 .42699 Mtetra
.604 .714 .922 r
.29456 .60795 .30049 .61378 .30967 .61224 .30377 .6063 Mtetra
.547 .69 .933 r
.30377 .6063 .30967 .61224 .31801 .6255 .31295 .60567 Mtetra
.697 .553 .686 r
.31295 .60567 .31801 .6255 .32847 .60381 .32271 .596 Mtetra
.508 .611 .89 r
.32271 .596 .32847 .60381 .33775 .60235 .33189 .59654 Mtetra
.613 .72 .921 r
.33189 .59654 .33775 .60235 .3471 .60046 .34125 .59465 Mtetra
.598 .715 .927 r
.34125 .59465 .3471 .60046 .35639 .60048 .35064 .59306 Mtetra
.911 .712 .62 r
.35064 .59306 .35639 .60048 .36617 .59093 .36221 .54697 Mtetra
0 0 .474 r
.36221 .54697 .36617 .59093 .37556 .59037 .36979 .58433 Mtetra
.609 .713 .918 r
.36979 .58433 .37556 .59037 .38506 .58824 .37929 .58251 Mtetra
.627 .73 .922 r
.37929 .58251 .38506 .58824 .3946 .58608 .38885 .58027 Mtetra
.609 .722 .925 r
.38885 .58027 .3946 .58608 .40412 .58549 .39843 .57841 Mtetra
.953 .613 .326 r
.39843 .57841 .40412 .58549 .41398 .57578 .40648 .62241 Mtetra
0 0 .136 r
.40648 .62241 .41398 .57578 .42356 .57555 .41788 .5694 Mtetra
.611 .712 .917 r
.41788 .5694 .42356 .57555 .43324 .57325 .42757 .56751 Mtetra
.636 .736 .92 r
.42757 .56751 .43324 .57325 .44297 .57068 .43732 .565 Mtetra
.64 .74 .921 r
.43732 .565 .44297 .57068 .45274 .56811 .44711 .56239 Mtetra
.636 .738 .922 r
.44711 .56239 .45274 .56811 .46254 .56579 .45693 .55986 Mtetra
.605 .72 .926 r
.45693 .55986 .46254 .56579 .47233 .5664 .46678 .55803 Mtetra
.853 .72 .715 r
.46678 .55803 .47233 .5664 .48232 .55593 .4769 .54027 Mtetra
.296 .34 .739 r
.4769 .54027 .48232 .55593 .49221 .55462 .48667 .54854 Mtetra
.626 .724 .917 r
.48667 .54854 .49221 .55462 .50216 .55201 .49664 .54624 Mtetra
.645 .742 .92 r
.49664 .54624 .50216 .55201 .51214 .54914 .50665 .54344 Mtetra
.652 .748 .92 r
.50665 .54344 .51214 .54914 .52217 .54616 .5167 .54048 Mtetra
.655 .75 .92 r
.5167 .54048 .52217 .54616 .53223 .5431 .52678 .53743 Mtetra
.657 .752 .92 r
.52678 .53743 .53223 .5431 .54232 .53999 .5369 .53431 Mtetra
.658 .753 .92 r
.5369 .53431 .54232 .53999 .55246 .53684 .54706 .53115 Mtetra
.659 .754 .92 r
.54706 .53115 .55246 .53684 .56263 .53366 .55726 .52796 Mtetra
.55726 .52796 .56263 .53366 .57284 .53048 .56749 .52476 Mtetra
.56749 .52476 .57284 .53048 .58308 .52729 .57776 .52154 Mtetra
.57776 .52154 .58308 .52729 .59337 .52409 .58807 .51832 Mtetra
.658 .753 .92 r
.58807 .51832 .59337 .52409 .60369 .52089 .59842 .51509 Mtetra
.59842 .51509 .60369 .52089 .61405 .51768 .6088 .51186 Mtetra
.6088 .51186 .61405 .51768 .62444 .51446 .61923 .50862 Mtetra
.61923 .50862 .62444 .51446 .63488 .51124 .62969 .50537 Mtetra
.62969 .50537 .63488 .51124 .64535 .508 .64019 .50211 Mtetra
.64019 .50211 .64535 .508 .65587 .50476 .65073 .49884 Mtetra
.657 .753 .92 r
.65073 .49884 .65587 .50476 .66642 .50151 .66131 .49557 Mtetra
.66131 .49557 .66642 .50151 .67701 .49824 .67193 .49228 Mtetra
.67193 .49228 .67701 .49824 .68764 .49497 .68259 .48898 Mtetra
.68259 .48898 .68764 .49497 .69832 .49168 .69329 .48567 Mtetra
.69329 .48567 .69832 .49168 .70903 .48838 .70403 .48235 Mtetra
.657 .752 .92 r
.70403 .48235 .70903 .48838 .71978 .48508 .71481 .47902 Mtetra
.71481 .47902 .71978 .48508 .73057 .48176 .72563 .47568 Mtetra
.72563 .47568 .73057 .48176 .74141 .47843 .73649 .47232 Mtetra
.73649 .47232 .74141 .47843 .75228 .47508 .74739 .46896 Mtetra
.74739 .46896 .75228 .47508 .7632 .47173 .75834 .46558 Mtetra
.75834 .46558 .7632 .47173 .77415 .46836 .76933 .46219 Mtetra
.76933 .46219 .77415 .46836 .78515 .46498 .78036 .45879 Mtetra
.78036 .45879 .78515 .46498 .79619 .46159 .79143 .45537 Mtetra
.79143 .45537 .79619 .46159 .80728 .45819 .80254 .45194 Mtetra
.80254 .45194 .80728 .45819 .8184 .45477 .8137 .4485 Mtetra
.8137 .4485 .8184 .45477 .82957 .45135 .8249 .44505 Mtetra
.8249 .44505 .82957 .45135 .84079 .44791 .83614 .44158 Mtetra
.83614 .44158 .84079 .44791 .85204 .44445 .84743 .43811 Mtetra
.84743 .43811 .85204 .44445 .86334 .44098 .85876 .43461 Mtetra
.85876 .43461 .86334 .44098 .87468 .43751 .87013 .43111 Mtetra
.87013 .43111 .87468 .43751 .88607 .43401 .88155 .42759 Mtetra
.88155 .42759 .88607 .43401 .8975 .43051 .89301 .42406 Mtetra
.89301 .42406 .8975 .43051 .90897 .42699 .90452 .42052 Mtetra
.584 .694 .917 r
.28862 .60171 .29456 .60795 .30377 .6063 .29781 .60048 Mtetra
.598 .714 .925 r
.29781 .60048 .30377 .6063 .31295 .60567 .30707 .59889 Mtetra
.751 .28 0 r
.30707 .59889 .31295 .60567 .32271 .596 .31546 .61218 Mtetra
0 0 0 r
.31546 .61218 .32271 .596 .33189 .59654 .32601 .59036 Mtetra
.595 .702 .918 r
.32601 .59036 .33189 .59654 .34125 .59465 .33537 .58886 Mtetra
.614 .723 .923 r
.33537 .58886 .34125 .59465 .35064 .59306 .34479 .58692 Mtetra
.508 .671 .937 r
.34479 .58692 .35064 .59306 .36221 .54697 .35415 .5869 Mtetra
.439 .182 .426 r
.35415 .5869 .36221 .54697 .36979 .58433 .36402 .57728 Mtetra
.557 .659 .905 r
.36402 .57728 .36979 .58433 .37929 .58251 .37348 .57668 Mtetra
.623 .726 .921 r
.37348 .57668 .37929 .58251 .38885 .58027 .38306 .5745 Mtetra
.624 .729 .923 r
.38306 .5745 .38885 .58027 .39843 .57841 .39267 .5723 Mtetra
.545 .689 .934 r
.39267 .5723 .39843 .57841 .40648 .62241 .40227 .57167 Mtetra
.624 .44 .613 r
.40227 .57167 .40648 .62241 .41788 .5694 .41222 .56188 Mtetra
.544 .641 .897 r
.41222 .56188 .41788 .5694 .42757 .56751 .42187 .56161 Mtetra
.629 .729 .919 r
.42187 .56161 .42757 .56751 .43732 .565 .43163 .55926 Mtetra
.639 .739 .921 r
.43163 .55926 .43732 .565 .44711 .56239 .44144 .55665 Mtetra
.64 .74 .921 r
.44144 .55665 .44711 .56239 .45693 .55986 .45129 .55402 Mtetra
.628 .733 .923 r
.45129 .55402 .45693 .55986 .46678 .55803 .46117 .55165 Mtetra
.472 .651 .937 r
.46117 .55165 .46678 .55803 .4769 .54027 .47104 .55223 Mtetra
.007 0 .015 r
.47104 .55223 .4769 .54027 .48667 .54854 .48111 .54167 Mtetra
.587 .684 .908 r
.48111 .54167 .48667 .54854 .49664 .54624 .49109 .54032 Mtetra
.639 .737 .919 r
.49109 .54032 .49664 .54624 .50665 .54344 .50112 .53766 Mtetra
.649 .746 .92 r
.50112 .53766 .50665 .54344 .5167 .54048 .51119 .53474 Mtetra
.653 .749 .92 r
.51119 .53474 .5167 .54048 .52678 .53743 .5213 .5317 Mtetra
.656 .751 .92 r
.5213 .5317 .52678 .53743 .5369 .53431 .53144 .52859 Mtetra
.657 .753 .92 r
.53144 .52859 .5369 .53431 .54706 .53115 .54163 .52543 Mtetra
.658 .753 .92 r
.54163 .52543 .54706 .53115 .55726 .52796 .55185 .52222 Mtetra
.659 .754 .92 r
.55185 .52222 .55726 .52796 .56749 .52476 .56211 .519 Mtetra
.56211 .519 .56749 .52476 .57776 .52154 .5724 .51576 Mtetra
.5724 .51576 .57776 .52154 .58807 .51832 .58274 .51251 Mtetra
.58274 .51251 .58807 .51832 .59842 .51509 .59311 .50925 Mtetra
.658 .753 .92 r
.59311 .50925 .59842 .51509 .6088 .51186 .60352 .506 Mtetra
.60352 .506 .6088 .51186 .61923 .50862 .61397 .50273 Mtetra
.61397 .50273 .61923 .50862 .62969 .50537 .62446 .49946 Mtetra
.62446 .49946 .62969 .50537 .64019 .50211 .63499 .49618 Mtetra
.63499 .49618 .64019 .50211 .65073 .49884 .64555 .49289 Mtetra
.64555 .49289 .65073 .49884 .66131 .49557 .65616 .48959 Mtetra
.657 .753 .92 r
.65616 .48959 .66131 .49557 .67193 .49228 .66681 .48628 Mtetra
.66681 .48628 .67193 .49228 .68259 .48898 .6775 .48296 Mtetra
.6775 .48296 .68259 .48898 .69329 .48567 .68822 .47962 Mtetra
.68822 .47962 .69329 .48567 .70403 .48235 .69899 .47628 Mtetra
.657 .752 .92 r
.69899 .47628 .70403 .48235 .71481 .47902 .7098 .47292 Mtetra
.7098 .47292 .71481 .47902 .72563 .47568 .72065 .46956 Mtetra
.72065 .46956 .72563 .47568 .73649 .47232 .73154 .46618 Mtetra
.73154 .46618 .73649 .47232 .74739 .46896 .74247 .46279 Mtetra
.74247 .46279 .74739 .46896 .75834 .46558 .75345 .45939 Mtetra
.75345 .45939 .75834 .46558 .76933 .46219 .76447 .45597 Mtetra
.76447 .45597 .76933 .46219 .78036 .45879 .77553 .45254 Mtetra
.77553 .45254 .78036 .45879 .79143 .45537 .78663 .4491 Mtetra
.78663 .4491 .79143 .45537 .80254 .45194 .79777 .44565 Mtetra
.79777 .44565 .80254 .45194 .8137 .4485 .80896 .44219 Mtetra
.80896 .44219 .8137 .4485 .8249 .44505 .82019 .43871 Mtetra
.82019 .43871 .8249 .44505 .83614 .44158 .83146 .43522 Mtetra
.83146 .43522 .83614 .44158 .84743 .43811 .84278 .43171 Mtetra
.84278 .43171 .84743 .43811 .85876 .43461 .85414 .4282 Mtetra
.85414 .4282 .85876 .43461 .87013 .43111 .86555 .42467 Mtetra
.86555 .42467 .87013 .43111 .88155 .42759 .877 .42112 Mtetra
.877 .42112 .88155 .42759 .89301 .42406 .8885 .41757 Mtetra
.8885 .41757 .89301 .42406 .90452 .42052 .90004 .414 Mtetra
.463 .568 .875 r
.28281 .59308 .28862 .60171 .29781 .60048 .29183 .59456 Mtetra
.604 .714 .922 r
.29183 .59456 .29781 .60048 .30707 .59889 .30111 .59286 Mtetra
.547 .69 .933 r
.30111 .59286 .30707 .59889 .31546 .61218 .31036 .5922 Mtetra
.697 .552 .686 r
.31036 .5922 .31546 .61218 .32601 .59036 .3202 .58244 Mtetra
.507 .611 .89 r
.3202 .58244 .32601 .59036 .33537 .58886 .32945 .58295 Mtetra
.613 .72 .921 r
.32945 .58295 .33537 .58886 .34479 .58692 .33889 .58102 Mtetra
.598 .715 .926 r
.33889 .58102 .34479 .58692 .35415 .5869 .34835 .57938 Mtetra
.912 .712 .62 r
.34835 .57938 .35415 .5869 .36402 .57728 .36005 .53306 Mtetra
0 0 .471 r
.36005 .53306 .36402 .57728 .37348 .57668 .36765 .57055 Mtetra
.609 .713 .918 r
.36765 .57055 .37348 .57668 .38306 .5745 .37723 .56869 Mtetra
.627 .73 .922 r
.37723 .56869 .38306 .5745 .39267 .5723 .38687 .5664 Mtetra
.609 .722 .925 r
.38687 .5664 .39267 .5723 .40227 .57167 .39653 .56449 Mtetra
.953 .612 .321 r
.39653 .56449 .40227 .57167 .41222 .56188 .40461 .60865 Mtetra
0 0 .129 r
.40461 .60865 .41222 .56188 .42187 .56161 .41614 .55536 Mtetra
.611 .712 .917 r
.41614 .55536 .42187 .56161 .43163 .55926 .42591 .55343 Mtetra
.636 .736 .92 r
.42591 .55343 .43163 .55926 .44144 .55665 .43574 .55087 Mtetra
.64 .74 .921 r
.43574 .55087 .44144 .55665 .45129 .55402 .4456 .54821 Mtetra
.636 .738 .922 r
.4456 .54821 .45129 .55402 .46117 .55165 .45551 .54563 Mtetra
.605 .72 .926 r
.45551 .54563 .46117 .55165 .47104 .55223 .46544 .54375 Mtetra
.854 .72 .715 r
.46544 .54375 .47104 .55223 .48111 .54167 .47565 .52588 Mtetra
.294 .339 .738 r
.47565 .52588 .48111 .54167 .49109 .54032 .4855 .53414 Mtetra
.626 .724 .917 r
.4855 .53414 .49109 .54032 .50112 .53766 .49555 .53179 Mtetra
.645 .742 .92 r
.49555 .53179 .50112 .53766 .51119 .53474 .50564 .52894 Mtetra
.652 .748 .92 r
.50564 .52894 .51119 .53474 .5213 .5317 .51578 .52593 Mtetra
.655 .75 .92 r
.51578 .52593 .5213 .5317 .53144 .52859 .52595 .52282 Mtetra
.657 .752 .92 r
.52595 .52282 .53144 .52859 .54163 .52543 .53616 .51965 Mtetra
.658 .753 .92 r
.53616 .51965 .54163 .52543 .55185 .52222 .5464 .51644 Mtetra
.659 .754 .92 r
.5464 .51644 .55185 .52222 .56211 .519 .55669 .5132 Mtetra
.55669 .5132 .56211 .519 .5724 .51576 .56701 .50993 Mtetra
.56701 .50993 .5724 .51576 .58274 .51251 .57737 .50666 Mtetra
.57737 .50666 .58274 .51251 .59311 .50925 .58777 .50338 Mtetra
.658 .753 .92 r
.58777 .50338 .59311 .50925 .60352 .506 .5982 .5001 Mtetra
.5982 .5001 .60352 .506 .61397 .50273 .60868 .49681 Mtetra
.60868 .49681 .61397 .50273 .62446 .49946 .6192 .49351 Mtetra
.6192 .49351 .62446 .49946 .63499 .49618 .62975 .49021 Mtetra
.62975 .49021 .63499 .49618 .64555 .49289 .64034 .48689 Mtetra
.64034 .48689 .64555 .49289 .65616 .48959 .65098 .48357 Mtetra
.657 .753 .92 r
.65098 .48357 .65616 .48959 .66681 .48628 .66165 .48023 Mtetra
.66165 .48023 .66681 .48628 .6775 .48296 .67237 .47689 Mtetra
.67237 .47689 .6775 .48296 .68822 .47962 .68312 .47353 Mtetra
.68312 .47353 .68822 .47962 .69899 .47628 .69392 .47016 Mtetra
.69392 .47016 .69899 .47628 .7098 .47292 .70476 .46678 Mtetra
.657 .752 .92 r
.70476 .46678 .7098 .47292 .72065 .46956 .71564 .46339 Mtetra
.71564 .46339 .72065 .46956 .73154 .46618 .72656 .45999 Mtetra
.72656 .45999 .73154 .46618 .74247 .46279 .73752 .45657 Mtetra
.73752 .45657 .74247 .46279 .75345 .45939 .74852 .45315 Mtetra
.74852 .45315 .75345 .45939 .76447 .45597 .75957 .44971 Mtetra
.75957 .44971 .76447 .45597 .77553 .45254 .77066 .44626 Mtetra
.77066 .44626 .77553 .45254 .78663 .4491 .78179 .44279 Mtetra
.78179 .44279 .78663 .4491 .79777 .44565 .79297 .43931 Mtetra
.79297 .43931 .79777 .44565 .80896 .44219 .80418 .43582 Mtetra
.80418 .43582 .80896 .44219 .82019 .43871 .81545 .43232 Mtetra
.81545 .43232 .82019 .43871 .83146 .43522 .82675 .42881 Mtetra
.82675 .42881 .83146 .43522 .84278 .43171 .8381 .42528 Mtetra
.8381 .42528 .84278 .43171 .85414 .4282 .8495 .42173 Mtetra
.8495 .42173 .85414 .4282 .86555 .42467 .86094 .41818 Mtetra
.86094 .41818 .86555 .42467 .877 .42112 .87242 .41461 Mtetra
.87242 .41461 .877 .42112 .8885 .41757 .88395 .41103 Mtetra
.88395 .41103 .8885 .41757 .90004 .414 .89552 .40743 Mtetra
.629 .84 .448 r
.27563 .60291 .28281 .59308 .29183 .59456 .28583 .58822 Mtetra
.584 .694 .917 r
.28583 .58822 .29183 .59456 .30111 .59286 .2951 .58695 Mtetra
.598 .714 .925 r
.2951 .58695 .30111 .59286 .31036 .5922 .30443 .58532 Mtetra
.745 .274 0 r
.30443 .58532 .31036 .5922 .3202 .58244 .31287 .59863 Mtetra
0 0 0 r
.31287 .59863 .3202 .58244 .32945 .58295 .32352 .57668 Mtetra
.595 .702 .918 r
.32352 .57668 .32945 .58295 .33889 .58102 .33295 .57514 Mtetra
.614 .723 .923 r
.33295 .57514 .33889 .58102 .34835 .57938 .34245 .57315 Mtetra
.508 .671 .937 r
.34245 .57315 .34835 .57938 .36005 .53306 .35188 .5731 Mtetra
.434 .175 .421 r
.35188 .5731 .36005 .53306 .36765 .57055 .36183 .56339 Mtetra
.556 .659 .905 r
.36183 .56339 .36765 .57055 .37723 .56869 .37137 .56275 Mtetra
.623 .726 .921 r
.37137 .56275 .37723 .56869 .38687 .5664 .38102 .56053 Mtetra
.624 .729 .923 r
.38102 .56053 .38687 .5664 .39653 .56449 .39071 .55828 Mtetra
.545 .689 .934 r
.39071 .55828 .39653 .56449 .40461 .60865 .40039 .55761 Mtetra
.623 .438 .612 r
.40039 .55761 .40461 .60865 .41614 .55536 .41042 .54774 Mtetra
.543 .641 .897 r
.41042 .54774 .41614 .55536 .42591 .55343 .42015 .54743 Mtetra
.629 .729 .919 r
.42015 .54743 .42591 .55343 .43574 .55087 .42999 .54503 Mtetra
.639 .739 .921 r
.42999 .54503 .43574 .55087 .4456 .54821 .43988 .54237 Mtetra
.64 .74 .921 r
.43988 .54237 .4456 .54821 .45551 .54563 .44981 .53969 Mtetra
.628 .733 .923 r
.44981 .53969 .45551 .54563 .46544 .54375 .45977 .53728 Mtetra
.473 .651 .937 r
.45977 .53728 .46544 .54375 .47565 .52588 .46973 .53781 Mtetra
0 0 .002 r
.46973 .53781 .47565 .52588 .4855 .53414 .47989 .52717 Mtetra
.587 .684 .908 r
.47989 .52717 .4855 .53414 .49555 .53179 .48995 .52578 Mtetra
.639 .737 .919 r
.48995 .52578 .49555 .53179 .50564 .52894 .50006 .52306 Mtetra
.649 .746 .92 r
.50006 .52306 .50564 .52894 .51578 .52593 .51022 .52009 Mtetra
.653 .749 .92 r
.51022 .52009 .51578 .52593 .52595 .52282 .52041 .517 Mtetra
.656 .751 .92 r
.52041 .517 .52595 .52282 .53616 .51965 .53065 .51383 Mtetra
.657 .753 .92 r
.53065 .51383 .53616 .51965 .5464 .51644 .54092 .51061 Mtetra
.658 .753 .92 r
.54092 .51061 .5464 .51644 .55669 .5132 .55123 .50735 Mtetra
.659 .754 .92 r
.55123 .50735 .55669 .5132 .56701 .50993 .56158 .50407 Mtetra
.56158 .50407 .56701 .50993 .57737 .50666 .57196 .50077 Mtetra
.57196 .50077 .57737 .50666 .58777 .50338 .58239 .49747 Mtetra
.58239 .49747 .58777 .50338 .5982 .5001 .59285 .49416 Mtetra
.658 .753 .92 r
.59285 .49416 .5982 .5001 .60868 .49681 .60335 .49084 Mtetra
.60335 .49084 .60868 .49681 .6192 .49351 .61389 .48752 Mtetra
.61389 .48752 .6192 .49351 .62975 .49021 .62448 .48419 Mtetra
.62448 .48419 .62975 .49021 .64034 .48689 .6351 .48085 Mtetra
.6351 .48085 .64034 .48689 .65098 .48357 .64576 .4775 Mtetra
.64576 .4775 .65098 .48357 .66165 .48023 .65646 .47414 Mtetra
.657 .753 .92 r
.65646 .47414 .66165 .48023 .67237 .47689 .6672 .47078 Mtetra
.6672 .47078 .67237 .47689 .68312 .47353 .67799 .46739 Mtetra
.67799 .46739 .68312 .47353 .69392 .47016 .68881 .464 Mtetra
.68881 .464 .69392 .47016 .70476 .46678 .69968 .4606 Mtetra
.657 .752 .92 r
.69968 .4606 .70476 .46678 .71564 .46339 .71059 .45718 Mtetra
.71059 .45718 .71564 .46339 .72656 .45999 .72154 .45376 Mtetra
.72154 .45376 .72656 .45999 .73752 .45657 .73253 .45032 Mtetra
.73253 .45032 .73752 .45657 .74852 .45315 .74356 .44687 Mtetra
.74356 .44687 .74852 .45315 .75957 .44971 .75464 .4434 Mtetra
.75464 .4434 .75957 .44971 .77066 .44626 .76576 .43992 Mtetra
.76576 .43992 .77066 .44626 .78179 .44279 .77692 .43643 Mtetra
.77692 .43643 .78179 .44279 .79297 .43931 .78813 .43293 Mtetra
.78813 .43293 .79297 .43931 .80418 .43582 .79938 .42942 Mtetra
.79938 .42942 .80418 .43582 .81545 .43232 .81067 .42589 Mtetra
.81067 .42589 .81545 .43232 .82675 .42881 .82201 .42235 Mtetra
.82201 .42235 .82675 .42881 .8381 .42528 .83339 .41879 Mtetra
.83339 .41879 .8381 .42528 .8495 .42173 .84482 .41522 Mtetra
.84482 .41522 .8495 .42173 .86094 .41818 .85629 .41164 Mtetra
.85629 .41164 .86094 .41818 .87242 .41461 .8678 .40805 Mtetra
.8678 .40805 .87242 .41461 .88395 .41103 .87937 .40444 Mtetra
.87937 .40444 .88395 .41103 .89552 .40743 .89097 .40081 Mtetra
.745 .624 .725 r
.27007 .58981 .27563 .60291 .28583 .58822 .27997 .57949 Mtetra
.463 .568 .875 r
.27997 .57949 .28583 .58822 .2951 .58695 .28905 .58094 Mtetra
.603 .714 .922 r
.28905 .58094 .2951 .58695 .30443 .58532 .2984 .5792 Mtetra
.547 .69 .933 r
.2984 .5792 .30443 .58532 .31287 .59863 .30773 .57849 Mtetra
.697 .552 .686 r
.30773 .57849 .31287 .59863 .32352 .57668 .31766 .56866 Mtetra
.507 .611 .89 r
.31766 .56866 .32352 .57668 .33295 .57514 .32698 .56914 Mtetra
.613 .72 .921 r
.32698 .56914 .33295 .57514 .34245 .57315 .33649 .56716 Mtetra
.598 .715 .926 r
.33649 .56716 .34245 .57315 .35188 .5731 .34602 .56548 Mtetra
.913 .713 .618 r
.34602 .56548 .35188 .5731 .36183 .56339 .35784 .51892 Mtetra
0 0 .468 r
.35784 .51892 .36183 .56339 .37137 .56275 .36548 .55653 Mtetra
.609 .713 .918 r
.36548 .55653 .37137 .56275 .38102 .56053 .37514 .55462 Mtetra
.627 .73 .922 r
.37514 .55462 .38102 .56053 .39071 .55828 .38485 .55228 Mtetra
.609 .722 .925 r
.38485 .55228 .39071 .55828 .40039 .55761 .39459 .55033 Mtetra
.953 .61 .316 r
.39459 .55033 .40039 .55761 .41042 .54774 .40272 .59465 Mtetra
0 0 .122 r
.40272 .59465 .41042 .54774 .42015 .54743 .41437 .54109 Mtetra
.611 .712 .917 r
.41437 .54109 .42015 .54743 .42999 .54503 .42422 .5391 Mtetra
.636 .736 .92 r
.42422 .5391 .42999 .54503 .43988 .54237 .43413 .5365 Mtetra
.64 .74 .921 r
.43413 .5365 .43988 .54237 .44981 .53969 .44408 .53378 Mtetra
.636 .738 .922 r
.44408 .53378 .44981 .53969 .45977 .53728 .45406 .53115 Mtetra
.605 .72 .926 r
.45406 .53115 .45977 .53728 .46973 .53781 .46408 .52923 Mtetra
.855 .721 .715 r
.46408 .52923 .46973 .53781 .47989 .52717 .47438 .51123 Mtetra
.292 .338 .738 r
.47438 .51123 .47989 .52717 .48995 .52578 .48431 .51949 Mtetra
.626 .724 .917 r
.48431 .51949 .48995 .52578 .50006 .52306 .49444 .51709 Mtetra
.645 .742 .92 r
.49444 .51709 .50006 .52306 .51022 .52009 .50462 .51419 Mtetra
.652 .748 .92 r
.50462 .51419 .51022 .52009 .52041 .517 .51484 .51112 Mtetra
.655 .75 .92 r
.51484 .51112 .52041 .517 .53065 .51383 .5251 .50796 Mtetra
.657 .752 .92 r
.5251 .50796 .53065 .51383 .54092 .51061 .5354 .50474 Mtetra
.658 .753 .92 r
.5354 .50474 .54092 .51061 .55123 .50735 .54573 .50147 Mtetra
.659 .754 .92 r
.54573 .50147 .55123 .50735 .56158 .50407 .55611 .49817 Mtetra
.55611 .49817 .56158 .50407 .57196 .50077 .56652 .49485 Mtetra
.56652 .49485 .57196 .50077 .58239 .49747 .57697 .49152 Mtetra
.57697 .49152 .58239 .49747 .59285 .49416 .58746 .48818 Mtetra
.658 .753 .92 r
.58746 .48818 .59285 .49416 .60335 .49084 .59799 .48484 Mtetra
.59799 .48484 .60335 .49084 .61389 .48752 .60856 .48149 Mtetra
.60856 .48149 .61389 .48752 .62448 .48419 .61917 .47814 Mtetra
.61917 .47814 .62448 .48419 .6351 .48085 .62981 .47477 Mtetra
.62981 .47477 .6351 .48085 .64576 .4775 .6405 .4714 Mtetra
.6405 .4714 .64576 .4775 .65646 .47414 .65123 .46802 Mtetra
.657 .753 .92 r
.65123 .46802 .65646 .47414 .6672 .47078 .662 .46462 Mtetra
.662 .46462 .6672 .47078 .67799 .46739 .67282 .46122 Mtetra
.67282 .46122 .67799 .46739 .68881 .464 .68367 .4578 Mtetra
.68367 .4578 .68881 .464 .69968 .4606 .69457 .45437 Mtetra
.69457 .45437 .69968 .4606 .71059 .45718 .7055 .45093 Mtetra
.657 .752 .92 r
.7055 .45093 .71059 .45718 .72154 .45376 .71648 .44748 Mtetra
.71648 .44748 .72154 .45376 .73253 .45032 .7275 .44401 Mtetra
.7275 .44401 .73253 .45032 .74356 .44687 .73857 .44054 Mtetra
.73857 .44054 .74356 .44687 .75464 .4434 .74967 .43705 Mtetra
.74967 .43705 .75464 .4434 .76576 .43992 .76082 .43355 Mtetra
.76082 .43355 .76576 .43992 .77692 .43643 .77202 .43003 Mtetra
.77202 .43003 .77692 .43643 .78813 .43293 .78325 .4265 Mtetra
.78325 .4265 .78813 .43293 .79938 .42942 .79453 .42296 Mtetra
.79453 .42296 .79938 .42942 .81067 .42589 .80586 .41941 Mtetra
.80586 .41941 .81067 .42589 .82201 .42235 .81723 .41584 Mtetra
.81723 .41584 .82201 .42235 .83339 .41879 .82864 .41226 Mtetra
.82864 .41226 .83339 .41879 .84482 .41522 .8401 .40867 Mtetra
.8401 .40867 .84482 .41522 .85629 .41164 .8516 .40506 Mtetra
.8516 .40506 .85629 .41164 .8678 .40805 .86315 .40144 Mtetra
.86315 .40144 .8678 .40805 .87937 .40444 .87475 .3978 Mtetra
.87475 .3978 .87937 .40444 .89097 .40081 .88639 .39415 Mtetra
0 .266 .763 r
.264 .58309 .27007 .58981 .27997 .57949 .27271 .5893 Mtetra
.639 .848 .458 r
.27271 .5893 .27997 .57949 .28905 .58094 .283 .57451 Mtetra
.584 .694 .917 r
.283 .57451 .28905 .58094 .2984 .5792 .29233 .57319 Mtetra
.598 .714 .925 r
.29233 .57319 .2984 .5792 .30773 .57849 .30174 .57152 Mtetra
.739 .269 0 r
.30174 .57152 .30773 .57849 .31766 .56866 .31023 .58485 Mtetra
0 0 0 r
.31023 .58485 .31766 .56866 .32698 .56914 .32099 .56277 Mtetra
.595 .702 .918 r
.32099 .56277 .32698 .56914 .33649 .56716 .33049 .56118 Mtetra
.614 .723 .923 r
.33049 .56118 .33649 .56716 .34602 .56548 .34006 .55915 Mtetra
.508 .671 .937 r
.34006 .55915 .34602 .56548 .35784 .51892 .34957 .55906 Mtetra
.429 .169 .416 r
.34957 .55906 .35784 .51892 .36548 .55653 .35961 .54927 Mtetra
.556 .659 .905 r
.35961 .54927 .36548 .55653 .37514 .55462 .36922 .54859 Mtetra
.623 .726 .921 r
.36922 .54859 .37514 .55462 .38485 .55228 .37895 .54632 Mtetra
.624 .729 .923 r
.37895 .54632 .38485 .55228 .39459 .55033 .38872 .54402 Mtetra
.545 .689 .933 r
.38872 .54402 .39459 .55033 .40272 .59465 .39847 .54331 Mtetra
.622 .437 .611 r
.39847 .54331 .40272 .59465 .41437 .54109 .40859 .53336 Mtetra
.543 .641 .897 r
.40859 .53336 .41437 .54109 .42422 .5391 .4184 .53301 Mtetra
.629 .729 .92 r
.4184 .53301 .42422 .5391 .43413 .5365 .42833 .53056 Mtetra
.639 .739 .921 r
.42833 .53056 .43413 .5365 .44408 .53378 .4383 .52785 Mtetra
.64 .74 .921 r
.4383 .52785 .44408 .53378 .45406 .53115 .44831 .52512 Mtetra
.628 .733 .923 r
.44831 .52512 .45406 .53115 .46408 .52923 .45836 .52265 Mtetra
.474 .651 .937 r
.45836 .52265 .46408 .52923 .47438 .51123 .46839 .52315 Mtetra
0 0 0 r
.46839 .52315 .47438 .51123 .48431 .51949 .47864 .51242 Mtetra
.587 .684 .908 r
.47864 .51242 .48431 .51949 .49444 .51709 .48879 .51098 Mtetra
.639 .737 .919 r
.48879 .51098 .49444 .51709 .50462 .51419 .49899 .50821 Mtetra
.649 .746 .92 r
.49899 .50821 .50462 .51419 .51484 .51112 .50923 .50518 Mtetra
.653 .749 .92 r
.50923 .50518 .51484 .51112 .5251 .50796 .51952 .50204 Mtetra
.656 .751 .92 r
.51952 .50204 .5251 .50796 .5354 .50474 .52984 .49881 Mtetra
.657 .753 .92 r
.52984 .49881 .5354 .50474 .54573 .50147 .5402 .49553 Mtetra
.658 .753 .92 r
.5402 .49553 .54573 .50147 .55611 .49817 .5506 .49222 Mtetra
.659 .754 .92 r
.5506 .49222 .55611 .49817 .56652 .49485 .56104 .48888 Mtetra
.56104 .48888 .56652 .49485 .57697 .49152 .57151 .48552 Mtetra
.57151 .48552 .57697 .49152 .58746 .48818 .58203 .48216 Mtetra
.58203 .48216 .58746 .48818 .59799 .48484 .59259 .47879 Mtetra
.658 .753 .92 r
.59259 .47879 .59799 .48484 .60856 .48149 .60318 .47542 Mtetra
.60318 .47542 .60856 .48149 .61917 .47814 .61382 .47204 Mtetra
.61382 .47204 .61917 .47814 .62981 .47477 .62449 .46865 Mtetra
.62449 .46865 .62981 .47477 .6405 .4714 .63521 .46525 Mtetra
.63521 .46525 .6405 .4714 .65123 .46802 .64597 .46184 Mtetra
.64597 .46184 .65123 .46802 .662 .46462 .65677 .45842 Mtetra
.657 .753 .92 r
.65677 .45842 .662 .46462 .67282 .46122 .66761 .45499 Mtetra
.66761 .45499 .67282 .46122 .68367 .4578 .67849 .45155 Mtetra
.67849 .45155 .68367 .4578 .69457 .45437 .68941 .4481 Mtetra
.68941 .4481 .69457 .45437 .7055 .45093 .70038 .44463 Mtetra
.657 .752 .92 r
.70038 .44463 .7055 .45093 .71648 .44748 .71139 .44116 Mtetra
.71139 .44116 .71648 .44748 .7275 .44401 .72244 .43767 Mtetra
.72244 .43767 .7275 .44401 .73857 .44054 .73353 .43417 Mtetra
.73353 .43417 .73857 .44054 .74967 .43705 .74467 .43065 Mtetra
.74467 .43065 .74967 .43705 .76082 .43355 .75585 .42712 Mtetra
.75585 .42712 .76082 .43355 .77202 .43003 .76707 .42358 Mtetra
.76707 .42358 .77202 .43003 .78325 .4265 .77834 .42003 Mtetra
.77834 .42003 .78325 .4265 .79453 .42296 .78965 .41646 Mtetra
.78965 .41646 .79453 .42296 .80586 .41941 .80101 .41288 Mtetra
.80101 .41288 .80586 .41941 .81723 .41584 .81241 .40929 Mtetra
.81241 .40929 .81723 .41584 .82864 .41226 .82386 .40568 Mtetra
.82386 .40568 .82864 .41226 .8401 .40867 .83535 .40206 Mtetra
.83535 .40206 .8401 .40867 .8516 .40506 .84689 .39843 Mtetra
.84689 .39843 .8516 .40506 .86315 .40144 .85847 .39478 Mtetra
.85847 .39478 .86315 .40144 .87475 .3978 .8701 .39111 Mtetra
.8701 .39111 .87475 .3978 .88639 .39415 .88177 .38744 Mtetra
.555 .693 .932 r
.25785 .57693 .264 .58309 .27271 .5893 .26709 .57607 Mtetra
.745 .624 .726 r
.26709 .57607 .27271 .5893 .283 .57451 .27708 .56567 Mtetra
.462 .568 .876 r
.27708 .56567 .283 .57451 .29233 .57319 .28623 .56709 Mtetra
.603 .714 .922 r
.28623 .56709 .29233 .57319 .30174 .57152 .29566 .5653 Mtetra
.547 .69 .933 r
.29566 .5653 .30174 .57152 .31023 .58485 .30505 .56456 Mtetra
.697 .552 .686 r
.30505 .56456 .31023 .58485 .32099 .56277 .31506 .55465 Mtetra
.507 .611 .891 r
.31506 .55465 .32099 .56277 .33049 .56118 .32446 .55509 Mtetra
.613 .72 .921 r
.32446 .55509 .33049 .56118 .34006 .55915 .33405 .55306 Mtetra
.598 .715 .926 r
.33405 .55306 .34006 .55915 .34957 .55906 .34366 .55133 Mtetra
.914 .714 .617 r
.34366 .55133 .34957 .55906 .35961 .54927 .3556 .50454 Mtetra
0 0 .464 r
.3556 .50454 .35961 .54927 .36922 .54859 .36328 .54227 Mtetra
.609 .713 .918 r
.36328 .54227 .36922 .54859 .37895 .54632 .37301 .54031 Mtetra
.627 .73 .922 r
.37301 .54031 .37895 .54632 .38872 .54402 .3828 .53793 Mtetra
.609 .722 .925 r
.3828 .53793 .38872 .54402 .39847 .54331 .39262 .53593 Mtetra
.953 .609 .311 r
.39262 .53593 .39847 .54331 .40859 .53336 .40079 .5804 Mtetra
0 0 .114 r
.40079 .5804 .40859 .53336 .4184 .53301 .41256 .52656 Mtetra
.611 .712 .917 r
.41256 .52656 .4184 .53301 .42833 .53056 .42249 .52453 Mtetra
.636 .736 .92 r
.42249 .52453 .42833 .53056 .4383 .52785 .43249 .52187 Mtetra
.64 .74 .921 r
.43249 .52187 .4383 .52785 .44831 .52512 .44252 .5191 Mtetra
.636 .738 .922 r
.44252 .5191 .44831 .52512 .45836 .52265 .45259 .51642 Mtetra
.605 .72 .926 r
.45259 .51642 .45836 .52265 .46839 .52315 .46269 .51445 Mtetra
.855 .722 .715 r
.46269 .51445 .46839 .52315 .47864 .51242 .47308 .49634 Mtetra
.29 .336 .738 r
.47308 .49634 .47864 .51242 .48879 .51098 .4831 .50459 Mtetra
.626 .724 .917 r
.4831 .50459 .48879 .51098 .49899 .50821 .49332 .50213 Mtetra
.645 .742 .92 r
.49332 .50213 .49899 .50821 .50923 .50518 .50358 .49918 Mtetra
.652 .748 .92 r
.50358 .49918 .50923 .50518 .51952 .50204 .51389 .49605 Mtetra
.655 .75 .92 r
.51389 .49605 .51952 .50204 .52984 .49881 .52424 .49284 Mtetra
.657 .752 .92 r
.52424 .49284 .52984 .49881 .5402 .49553 .53463 .48956 Mtetra
.658 .753 .92 r
.53463 .48956 .5402 .49553 .5506 .49222 .54505 .48623 Mtetra
.659 .754 .92 r
.54505 .48623 .5506 .49222 .56104 .48888 .55552 .48287 Mtetra
.55552 .48287 .56104 .48888 .57151 .48552 .56602 .47949 Mtetra
.56602 .47949 .57151 .48552 .58203 .48216 .57656 .4761 Mtetra
.57656 .4761 .58203 .48216 .59259 .47879 .58714 .47271 Mtetra
.658 .753 .92 r
.58714 .47271 .59259 .47879 .60318 .47542 .59777 .46931 Mtetra
.59777 .46931 .60318 .47542 .61382 .47204 .60843 .4659 Mtetra
.60843 .4659 .61382 .47204 .62449 .46865 .61913 .46249 Mtetra
.61913 .46249 .62449 .46865 .63521 .46525 .62988 .45906 Mtetra
.62988 .45906 .63521 .46525 .64597 .46184 .64067 .45563 Mtetra
.64067 .45563 .64597 .46184 .65677 .45842 .65149 .45218 Mtetra
.657 .753 .92 r
.65149 .45218 .65677 .45842 .66761 .45499 .66236 .44873 Mtetra
.66236 .44873 .66761 .45499 .67849 .45155 .67327 .44526 Mtetra
.67327 .44526 .67849 .45155 .68941 .4481 .68423 .44178 Mtetra
.68423 .44178 .68941 .4481 .70038 .44463 .69522 .43829 Mtetra
.69522 .43829 .70038 .44463 .71139 .44116 .70626 .43479 Mtetra
.657 .752 .92 r
.70626 .43479 .71139 .44116 .72244 .43767 .71734 .43127 Mtetra
.71734 .43127 .72244 .43767 .73353 .43417 .72846 .42775 Mtetra
.72846 .42775 .73353 .43417 .74467 .43065 .73963 .42421 Mtetra
.73963 .42421 .74467 .43065 .75585 .42712 .75084 .42065 Mtetra
.75084 .42065 .75585 .42712 .76707 .42358 .7621 .41709 Mtetra
.7621 .41709 .76707 .42358 .77834 .42003 .7734 .41351 Mtetra
.7734 .41351 .77834 .42003 .78965 .41646 .78474 .40991 Mtetra
.78474 .40991 .78965 .41646 .80101 .41288 .79613 .40631 Mtetra
.79613 .40631 .80101 .41288 .81241 .40929 .80756 .40269 Mtetra
.80756 .40269 .81241 .40929 .82386 .40568 .81904 .39905 Mtetra
.81904 .39905 .82386 .40568 .83535 .40206 .83056 .39541 Mtetra
.83056 .39541 .83535 .40206 .84689 .39843 .84213 .39174 Mtetra
.84213 .39174 .84689 .39843 .85847 .39478 .85375 .38807 Mtetra
.85375 .38807 .85847 .39478 .8701 .39111 .86541 .38438 Mtetra
.86541 .38438 .8701 .39111 .88177 .38744 .87712 .38068 Mtetra
.592 .709 .925 r
.25165 .57081 .25785 .57693 .26709 .57607 .26096 .56925 Mtetra
0 .27 .766 r
.26096 .56925 .26709 .57607 .27708 .56567 .26973 .57546 Mtetra
.648 .855 .467 r
.26973 .57546 .27708 .56567 .28623 .56709 .28012 .56056 Mtetra
.584 .694 .917 r
.28012 .56056 .28623 .56709 .29566 .5653 .28953 .5592 Mtetra
.598 .714 .925 r
.28953 .5592 .29566 .5653 .30505 .56456 .299 .55749 Mtetra
.734 .263 0 r
.299 .55749 .30505 .56456 .31506 .55465 .30755 .57084 Mtetra
0 0 0 r
.30755 .57084 .31506 .55465 .32446 .55509 .31841 .54862 Mtetra
.595 .702 .918 r
.31841 .54862 .32446 .55509 .33405 .55306 .32799 .54699 Mtetra
.614 .723 .923 r
.32799 .54699 .33405 .55306 .34366 .55133 .33764 .54491 Mtetra
.509 .671 .936 r
.33764 .54491 .34366 .55133 .3556 .50454 .34722 .54478 Mtetra
.424 .162 .411 r
.34722 .54478 .3556 .50454 .36328 .54227 .35734 .53491 Mtetra
.556 .659 .905 r
.35734 .53491 .36328 .54227 .37301 .54031 .36703 .53419 Mtetra
.623 .726 .921 r
.36703 .53419 .37301 .54031 .3828 .53793 .37684 .53186 Mtetra
.624 .729 .923 r
.37684 .53186 .3828 .53793 .39262 .53593 .38669 .52952 Mtetra
.545 .689 .933 r
.38669 .52952 .39262 .53593 .40079 .5804 .39652 .52876 Mtetra
.621 .435 .609 r
.39652 .52876 .40079 .5804 .41256 .52656 .40673 .51873 Mtetra
.543 .642 .897 r
.40673 .51873 .41256 .52656 .42249 .52453 .41663 .51834 Mtetra
.629 .729 .92 r
.41663 .51834 .42249 .52453 .43249 .52187 .42663 .51583 Mtetra
.639 .739 .921 r
.42663 .51583 .43249 .52187 .44252 .5191 .43669 .51307 Mtetra
.64 .74 .921 r
.43669 .51307 .44252 .5191 .45259 .51642 .44678 .51029 Mtetra
.628 .733 .923 r
.44678 .51029 .45259 .51642 .46269 .51445 .45691 .50776 Mtetra
.474 .651 .937 r
.45691 .50776 .46269 .51445 .47308 .49634 .46704 .50822 Mtetra
0 0 0 r
.46704 .50822 .47308 .49634 .4831 .50459 .47738 .49741 Mtetra
.587 .684 .908 r
.47738 .49741 .4831 .50459 .49332 .50213 .48761 .49591 Mtetra
.639 .737 .919 r
.48761 .49591 .49332 .50213 .50358 .49918 .4979 .49309 Mtetra
.649 .746 .92 r
.4979 .49309 .50358 .49918 .51389 .49605 .50823 .49001 Mtetra
.653 .749 .92 r
.50823 .49001 .51389 .49605 .52424 .49284 .5186 .48681 Mtetra
.656 .751 .92 r
.5186 .48681 .52424 .49284 .53463 .48956 .52901 .48352 Mtetra
.657 .753 .92 r
.52901 .48352 .53463 .48956 .54505 .48623 .53946 .48019 Mtetra
.658 .753 .92 r
.53946 .48019 .54505 .48623 .55552 .48287 .54996 .47682 Mtetra
.659 .754 .92 r
.54996 .47682 .55552 .48287 .56602 .47949 .56049 .47342 Mtetra
.56049 .47342 .56602 .47949 .57656 .4761 .57106 .47 Mtetra
.57106 .47 .57656 .4761 .58714 .47271 .58167 .46658 Mtetra
.58167 .46658 .58714 .47271 .59777 .46931 .59232 .46315 Mtetra
.658 .753 .92 r
.59232 .46315 .59777 .46931 .60843 .4659 .60301 .45972 Mtetra
.60301 .45972 .60843 .4659 .61913 .46249 .61374 .45628 Mtetra
.61374 .45628 .61913 .46249 .62988 .45906 .62451 .45283 Mtetra
.62451 .45283 .62988 .45906 .64067 .45563 .63533 .44937 Mtetra
.63533 .44937 .64067 .45563 .65149 .45218 .64618 .4459 Mtetra
.64618 .4459 .65149 .45218 .66236 .44873 .65708 .44242 Mtetra
.657 .753 .92 r
.65708 .44242 .66236 .44873 .67327 .44526 .66802 .43892 Mtetra
.66802 .43892 .67327 .44526 .68423 .44178 .679 .43542 Mtetra
.679 .43542 .68423 .44178 .69522 .43829 .69003 .4319 Mtetra
.69003 .4319 .69522 .43829 .70626 .43479 .70109 .42838 Mtetra
.657 .752 .92 r
.70109 .42838 .70626 .43479 .71734 .43127 .7122 .42484 Mtetra
.7122 .42484 .71734 .43127 .72846 .42775 .72336 .42128 Mtetra
.72336 .42128 .72846 .42775 .73963 .42421 .73456 .41772 Mtetra
.73456 .41772 .73963 .42421 .75084 .42065 .7458 .41414 Mtetra
.7458 .41414 .75084 .42065 .7621 .41709 .75708 .41054 Mtetra
.75708 .41054 .7621 .41709 .7734 .41351 .76842 .40694 Mtetra
.76842 .40694 .7734 .41351 .78474 .40991 .77979 .40332 Mtetra
.77979 .40332 .78474 .40991 .79613 .40631 .79121 .39969 Mtetra
.79121 .39969 .79613 .40631 .80756 .40269 .80268 .39604 Mtetra
.80268 .39604 .80756 .40269 .81904 .39905 .81419 .39238 Mtetra
.81419 .39238 .81904 .39905 .83056 .39541 .82574 .3887 Mtetra
.82574 .3887 .83056 .39541 .84213 .39174 .83735 .38501 Mtetra
.83735 .38501 .84213 .39174 .85375 .38807 .849 .38131 Mtetra
.849 .38131 .85375 .38807 .86541 .38438 .86069 .37759 Mtetra
.86069 .37759 .86541 .38438 .87712 .38068 .87244 .37386 Mtetra
.586 .699 .92 r
.24543 .56442 .25165 .57081 .26096 .56925 .25475 .563 Mtetra
.555 .693 .932 r
.25475 .563 .26096 .56925 .26973 .57546 .26407 .5621 Mtetra
.745 .625 .726 r
.26407 .5621 .26973 .57546 .28012 .56056 .27414 .55162 Mtetra
.462 .567 .876 r
.27414 .55162 .28012 .56056 .28953 .5592 .28336 .553 Mtetra
.603 .714 .922 r
.28336 .553 .28953 .5592 .299 .55749 .29286 .55117 Mtetra
.547 .69 .933 r
.29286 .55117 .299 .55749 .30755 .57084 .30233 .55038 Mtetra
.697 .552 .686 r
.30233 .55038 .30755 .57084 .31841 .54862 .31243 .54039 Mtetra
.506 .611 .891 r
.31243 .54039 .31841 .54862 .32799 .54699 .3219 .54079 Mtetra
.613 .72 .921 r
.3219 .54079 .32799 .54699 .33764 .54491 .33156 .53872 Mtetra
.598 .715 .926 r
.33156 .53872 .33764 .54491 .34722 .54478 .34125 .53695 Mtetra
.915 .714 .616 r
.34125 .53695 .34722 .54478 .35734 .53491 .35332 .48992 Mtetra
0 0 .461 r
.35332 .48992 .35734 .53491 .36703 .53419 .36103 .52776 Mtetra
.609 .713 .918 r
.36103 .52776 .36703 .53419 .37684 .53186 .37084 .52576 Mtetra
.627 .73 .922 r
.37084 .52576 .37684 .53186 .38669 .52952 .38072 .52332 Mtetra
.609 .722 .925 r
.38072 .52332 .38669 .52952 .39652 .52876 .39062 .52127 Mtetra
.953 .608 .306 r
.39062 .52127 .39652 .52876 .40673 .51873 .39882 .5659 Mtetra
0 0 .106 r
.39882 .5659 .40673 .51873 .41663 .51834 .41073 .51178 Mtetra
.611 .712 .917 r
.41073 .51178 .41663 .51834 .42663 .51583 .42074 .5097 Mtetra
.636 .736 .92 r
.42074 .5097 .42663 .51583 .43669 .51307 .43082 .50699 Mtetra
.64 .74 .921 r
.43082 .50699 .43669 .51307 .44678 .51029 .44094 .50417 Mtetra
.636 .738 .922 r
.44094 .50417 .44678 .51029 .45691 .50776 .45109 .50143 Mtetra
.605 .72 .926 r
.45109 .50143 .45691 .50776 .46704 .50822 .46128 .49941 Mtetra
.856 .723 .715 r
.46128 .49941 .46704 .50822 .47738 .49741 .47177 .48118 Mtetra
.288 .335 .738 r
.47177 .48118 .47738 .49741 .48761 .49591 .48186 .48942 Mtetra
.626 .724 .917 r
.48186 .48942 .48761 .49591 .4979 .49309 .49217 .48691 Mtetra
.645 .742 .92 r
.49217 .48691 .4979 .49309 .50823 .49001 .50253 .4839 Mtetra
.652 .748 .92 r
.50253 .4839 .50823 .49001 .5186 .48681 .51292 .48072 Mtetra
.655 .75 .92 r
.51292 .48072 .5186 .48681 .52901 .48352 .52336 .47744 Mtetra
.657 .752 .92 r
.52336 .47744 .52901 .48352 .53946 .48019 .53384 .4741 Mtetra
.658 .753 .92 r
.53384 .4741 .53946 .48019 .54996 .47682 .54436 .47072 Mtetra
.659 .754 .92 r
.54436 .47072 .54996 .47682 .56049 .47342 .55491 .4673 Mtetra
.55491 .4673 .56049 .47342 .57106 .47 .56551 .46386 Mtetra
.56551 .46386 .57106 .47 .58167 .46658 .57615 .46041 Mtetra
.57615 .46041 .58167 .46658 .59232 .46315 .58682 .45696 Mtetra
.658 .753 .92 r
.58682 .45696 .59232 .46315 .60301 .45972 .59754 .4535 Mtetra
.59754 .4535 .60301 .45972 .61374 .45628 .6083 .45003 Mtetra
.6083 .45003 .61374 .45628 .62451 .45283 .6191 .44655 Mtetra
.6191 .44655 .62451 .45283 .63533 .44937 .62995 .44306 Mtetra
.62995 .44306 .63533 .44937 .64618 .4459 .64083 .43957 Mtetra
.64083 .43957 .64618 .4459 .65708 .44242 .65176 .43606 Mtetra
.657 .753 .92 r
.65176 .43606 .65708 .44242 .66802 .43892 .66273 .43254 Mtetra
.66273 .43254 .66802 .43892 .679 .43542 .67374 .42901 Mtetra
.67374 .42901 .679 .43542 .69003 .4319 .68479 .42547 Mtetra
.68479 .42547 .69003 .4319 .70109 .42838 .69589 .42192 Mtetra
.69589 .42192 .70109 .42838 .7122 .42484 .70703 .41835 Mtetra
.657 .752 .92 r
.70703 .41835 .7122 .42484 .72336 .42128 .71822 .41477 Mtetra
.71822 .41477 .72336 .42128 .73456 .41772 .72944 .41118 Mtetra
.72944 .41118 .73456 .41772 .7458 .41414 .74072 .40757 Mtetra
.74072 .40757 .7458 .41414 .75708 .41054 .75204 .40395 Mtetra
.75204 .40395 .75708 .41054 .76842 .40694 .7634 .40032 Mtetra
.7634 .40032 .76842 .40694 .77979 .40332 .7748 .39667 Mtetra
.7748 .39667 .77979 .40332 .79121 .39969 .78626 .39301 Mtetra
.78626 .39301 .79121 .39969 .80268 .39604 .79775 .38934 Mtetra
.79775 .38934 .80268 .39604 .81419 .39238 .8093 .38565 Mtetra
.8093 .38565 .81419 .39238 .82574 .3887 .82089 .38195 Mtetra
.82089 .38195 .82574 .3887 .83735 .38501 .83252 .37823 Mtetra
.83252 .37823 .83735 .38501 .849 .38131 .84421 .3745 Mtetra
.84421 .3745 .849 .38131 .86069 .37759 .85594 .37076 Mtetra
.85594 .37076 .86069 .37759 .87244 .37386 .86771 .367 Mtetra
.515 .628 .901 r
.23929 .55668 .24543 .56442 .25475 .563 .24849 .55678 Mtetra
.592 .709 .925 r
.24849 .55678 .25475 .563 .26407 .5621 .25788 .55518 Mtetra
0 .273 .769 r
.25788 .55518 .26407 .5621 .27414 .55162 .26671 .56137 Mtetra
.658 .862 .477 r
.26671 .56137 .27414 .55162 .28336 .553 .27719 .54638 Mtetra
.584 .694 .917 r
.27719 .54638 .28336 .553 .29286 .55117 .28667 .54497 Mtetra
.598 .714 .925 r
.28667 .54497 .29286 .55117 .30233 .55038 .29622 .54321 Mtetra
.728 .257 0 r
.29622 .54321 .30233 .55038 .31243 .54039 .30482 .55658 Mtetra
0 0 0 r
.30482 .55658 .31243 .54039 .3219 .54079 .31579 .53422 Mtetra
.595 .702 .918 r
.31579 .53422 .3219 .54079 .33156 .53872 .32544 .53255 Mtetra
.614 .723 .923 r
.32544 .53255 .33156 .53872 .34125 .53695 .33517 .53042 Mtetra
.509 .671 .936 r
.33517 .53042 .34125 .53695 .35332 .48992 .34483 .53025 Mtetra
.419 .155 .405 r
.34483 .53025 .35332 .48992 .36103 .52776 .35504 .5203 Mtetra
.556 .659 .905 r
.35504 .5203 .36103 .52776 .37084 .52576 .36481 .51953 Mtetra
.623 .726 .921 r
.36481 .51953 .37084 .52576 .38072 .52332 .3747 .51716 Mtetra
.624 .729 .923 r
.3747 .51716 .38072 .52332 .39062 .52127 .38463 .51476 Mtetra
.545 .689 .933 r
.38463 .51476 .39062 .52127 .39882 .5659 .39454 .51395 Mtetra
.62 .433 .608 r
.39454 .51395 .39882 .5659 .41073 .51178 .40484 .50384 Mtetra
.543 .642 .898 r
.40484 .50384 .41073 .51178 .42074 .5097 .41482 .5034 Mtetra
.629 .729 .92 r
.41482 .5034 .42074 .5097 .43082 .50699 .42491 .50085 Mtetra
.639 .739 .921 r
.42491 .50085 .43082 .50699 .44094 .50417 .43505 .49803 Mtetra
.64 .74 .921 r
.43505 .49803 .44094 .50417 .45109 .50143 .44523 .49519 Mtetra
.628 .733 .923 r
.44523 .49519 .45109 .50143 .46128 .49941 .45545 .49262 Mtetra
.475 .651 .936 r
.45545 .49262 .46128 .49941 .47177 .48118 .46565 .49303 Mtetra
0 0 0 r
.46565 .49303 .47177 .48118 .48186 .48942 .47609 .48213 Mtetra
.587 .684 .908 r
.47609 .48213 .48186 .48942 .49217 .48691 .48641 .48058 Mtetra
.639 .737 .919 r
.48641 .48058 .49217 .48691 .50253 .4839 .49678 .47771 Mtetra
.649 .746 .92 r
.49678 .47771 .50253 .4839 .51292 .48072 .50721 .47457 Mtetra
.653 .749 .92 r
.50721 .47457 .51292 .48072 .52336 .47744 .51767 .4713 Mtetra
.656 .751 .92 r
.51767 .4713 .52336 .47744 .53384 .4741 .52817 .46796 Mtetra
.657 .753 .92 r
.52817 .46796 .53384 .4741 .54436 .47072 .53872 .46457 Mtetra
.658 .753 .92 r
.53872 .46457 .54436 .47072 .55491 .4673 .5493 .46113 Mtetra
.659 .754 .92 r
.5493 .46113 .55491 .4673 .56551 .46386 .55993 .45767 Mtetra
.55993 .45767 .56551 .46386 .57615 .46041 .57059 .4542 Mtetra
.57059 .4542 .57615 .46041 .58682 .45696 .58129 .45072 Mtetra
.58129 .45072 .58682 .45696 .59754 .4535 .59204 .44723 Mtetra
.658 .753 .92 r
.59204 .44723 .59754 .4535 .6083 .45003 .60283 .44373 Mtetra
.60283 .44373 .6083 .45003 .6191 .44655 .61366 .44023 Mtetra
.61366 .44023 .6191 .44655 .62995 .44306 .62453 .43672 Mtetra
.62453 .43672 .62995 .44306 .64083 .43957 .63544 .43319 Mtetra
.63544 .43319 .64083 .43957 .65176 .43606 .6464 .42966 Mtetra
.6464 .42966 .65176 .43606 .66273 .43254 .6574 .42612 Mtetra
.657 .753 .92 r
.6574 .42612 .66273 .43254 .67374 .42901 .66844 .42256 Mtetra
.66844 .42256 .67374 .42901 .68479 .42547 .67952 .41899 Mtetra
.67952 .41899 .68479 .42547 .69589 .42192 .69065 .41541 Mtetra
.69065 .41541 .69589 .42192 .70703 .41835 .70182 .41182 Mtetra
.657 .752 .92 r
.70182 .41182 .70703 .41835 .71822 .41477 .71304 .40821 Mtetra
.71304 .40821 .71822 .41477 .72944 .41118 .7243 .40459 Mtetra
.7243 .40459 .72944 .41118 .74072 .40757 .7356 .40096 Mtetra
.7356 .40096 .74072 .40757 .75204 .40395 .74695 .39731 Mtetra
.74695 .39731 .75204 .40395 .7634 .40032 .75834 .39365 Mtetra
.75834 .39365 .7634 .40032 .7748 .39667 .76978 .38998 Mtetra
.76978 .38998 .7748 .39667 .78626 .39301 .78127 .38629 Mtetra
.78127 .38629 .78626 .39301 .79775 .38934 .7928 .38259 Mtetra
.7928 .38259 .79775 .38934 .8093 .38565 .80437 .37888 Mtetra
.80437 .37888 .8093 .38565 .82089 .38195 .816 .37515 Mtetra
.816 .37515 .82089 .38195 .83252 .37823 .82767 .3714 Mtetra
.82767 .3714 .83252 .37823 .84421 .3745 .83938 .36765 Mtetra
.83938 .36765 .84421 .3745 .85594 .37076 .85115 .36387 Mtetra
.85115 .36387 .85594 .37076 .86771 .367 .86296 .36009 Mtetra
0 0 0 r
.22883 .59835 .23929 .55668 .24849 .55678 .24221 .55029 Mtetra
.586 .699 .92 r
.24221 .55029 .24849 .55678 .25788 .55518 .2516 .54883 Mtetra
.555 .693 .932 r
.2516 .54883 .25788 .55518 .26671 .56137 .26099 .54789 Mtetra
.745 .625 .726 r
.26099 .54789 .26671 .56137 .27719 .54638 .27115 .53732 Mtetra
.461 .567 .876 r
.27115 .53732 .27719 .54638 .28667 .54497 .28044 .53867 Mtetra
.603 .714 .922 r
.28044 .53867 .28667 .54497 .29622 .54321 .29002 .53679 Mtetra
.547 .69 .933 r
.29002 .53679 .29622 .54321 .30482 .55658 .29956 .53596 Mtetra
.697 .551 .685 r
.29956 .53596 .30482 .55658 .31579 .53422 .30975 .52589 Mtetra
.506 .611 .891 r
.30975 .52589 .31579 .53422 .32544 .53255 .31929 .52625 Mtetra
.613 .72 .921 r
.31929 .52625 .32544 .53255 .33517 .53042 .32903 .52413 Mtetra
.598 .715 .926 r
.32903 .52413 .33517 .53042 .34483 .53025 .3388 .52231 Mtetra
.917 .715 .615 r
.3388 .52231 .34483 .53025 .35504 .5203 .35101 .47504 Mtetra
0 0 .457 r
.35101 .47504 .35504 .5203 .36481 .51953 .35875 .513 Mtetra
.609 .713 .918 r
.35875 .513 .36481 .51953 .3747 .51716 .36864 .51095 Mtetra
.627 .73 .922 r
.36864 .51095 .3747 .51716 .38463 .51476 .3786 .50846 Mtetra
.609 .722 .925 r
.3786 .50846 .38463 .51476 .39454 .51395 .38858 .50636 Mtetra
.952 .606 .301 r
.38858 .50636 .39454 .51395 .40484 .50384 .39682 .55114 Mtetra
0 0 .099 r
.39682 .55114 .40484 .50384 .41482 .5034 .40886 .49674 Mtetra
.611 .712 .917 r
.40886 .49674 .41482 .5034 .42491 .50085 .41896 .49461 Mtetra
.636 .736 .92 r
.41896 .49461 .42491 .50085 .43505 .49803 .42912 .49185 Mtetra
.64 .74 .921 r
.42912 .49185 .43505 .49803 .44523 .49519 .43933 .48897 Mtetra
.636 .738 .922 r
.43933 .48897 .44523 .49519 .45545 .49262 .44957 .48617 Mtetra
.605 .72 .926 r
.44957 .48617 .45545 .49262 .46565 .49303 .45984 .4841 Mtetra
.857 .724 .715 r
.45984 .4841 .46565 .49303 .47609 .48213 .47043 .46575 Mtetra
.286 .334 .737 r
.47043 .46575 .47609 .48213 .48641 .48058 .4806 .47398 Mtetra
.626 .724 .917 r
.4806 .47398 .48641 .48058 .49678 .47771 .491 .47142 Mtetra
.645 .742 .92 r
.491 .47142 .49678 .47771 .50721 .47457 .50145 .46835 Mtetra
.652 .748 .92 r
.50145 .46835 .50721 .47457 .51767 .4713 .51194 .4651 Mtetra
.655 .75 .92 r
.51194 .4651 .51767 .4713 .52817 .46796 .52247 .46177 Mtetra
.657 .752 .92 r
.52247 .46177 .52817 .46796 .53872 .46457 .53304 .45837 Mtetra
.658 .753 .92 r
.53304 .45837 .53872 .46457 .5493 .46113 .54365 .45492 Mtetra
.659 .754 .92 r
.54365 .45492 .5493 .46113 .55993 .45767 .5543 .45144 Mtetra
.5543 .45144 .55993 .45767 .57059 .4542 .56499 .44795 Mtetra
.56499 .44795 .57059 .4542 .58129 .45072 .57573 .44444 Mtetra
.57573 .44444 .58129 .45072 .59204 .44723 .5865 .44092 Mtetra
.658 .753 .92 r
.5865 .44092 .59204 .44723 .60283 .44373 .59732 .43739 Mtetra
.59732 .43739 .60283 .44373 .61366 .44023 .60817 .43386 Mtetra
.60817 .43386 .61366 .44023 .62453 .43672 .61907 .43032 Mtetra
.61907 .43032 .62453 .43672 .63544 .43319 .63001 .42677 Mtetra
.63001 .42677 .63544 .43319 .6464 .42966 .641 .42321 Mtetra
.641 .42321 .6464 .42966 .6574 .42612 .65203 .41964 Mtetra
.657 .753 .92 r
.65203 .41964 .6574 .42612 .66844 .42256 .6631 .41606 Mtetra
.6631 .41606 .66844 .42256 .67952 .41899 .67421 .41247 Mtetra
.67421 .41247 .67952 .41899 .69065 .41541 .68537 .40886 Mtetra
.68537 .40886 .69065 .41541 .70182 .41182 .69657 .40524 Mtetra
.69657 .40524 .70182 .41182 .71304 .40821 .70782 .40161 Mtetra
.657 .752 .92 r
.70782 .40161 .71304 .40821 .7243 .40459 .71911 .39796 Mtetra
.71911 .39796 .7243 .40459 .7356 .40096 .73044 .3943 Mtetra
.73044 .3943 .7356 .40096 .74695 .39731 .74182 .39063 Mtetra
.74182 .39063 .74695 .39731 .75834 .39365 .75325 .38694 Mtetra
.75325 .38694 .75834 .39365 .76978 .38998 .76472 .38324 Mtetra
.76472 .38324 .76978 .38998 .78127 .38629 .77624 .37952 Mtetra
.77624 .37952 .78127 .38629 .7928 .38259 .7878 .3758 Mtetra
.7878 .3758 .7928 .38259 .80437 .37888 .79941 .37205 Mtetra
.79941 .37205 .80437 .37888 .816 .37515 .81107 .3683 Mtetra
.81107 .3683 .816 .37515 .82767 .3714 .82277 .36452 Mtetra
.82277 .36452 .82767 .3714 .83938 .36765 .83452 .36074 Mtetra
.83452 .36074 .83938 .36765 .85115 .36387 .84632 .35694 Mtetra
.84632 .35694 .85115 .36387 .86296 .36009 .85817 .35312 Mtetra
.625 .442 .615 r
.22593 .55206 .22883 .59835 .24221 .55029 .23601 .54245 Mtetra
.515 .628 .901 r
.23601 .54245 .24221 .55029 .2516 .54883 .24528 .54252 Mtetra
.592 .709 .925 r
.24528 .54252 .2516 .54883 .26099 .54789 .25474 .54087 Mtetra
0 .277 .772 r
.25474 .54087 .26099 .54789 .27115 .53732 .26363 .54705 Mtetra
.667 .869 .486 r
.26363 .54705 .27115 .53732 .28044 .53867 .2742 .53195 Mtetra
.584 .694 .917 r
.2742 .53195 .28044 .53867 .29002 .53679 .28376 .53049 Mtetra
.598 .714 .925 r
.28376 .53049 .29002 .53679 .29956 .53596 .29339 .52869 Mtetra
.722 .251 0 r
.29339 .52869 .29956 .53596 .30975 .52589 .30205 .54208 Mtetra
0 0 0 r
.30205 .54208 .30975 .52589 .31929 .52625 .31312 .51958 Mtetra
.595 .702 .918 r
.31312 .51958 .31929 .52625 .32903 .52413 .32285 .51785 Mtetra
.614 .723 .923 r
.32285 .51785 .32903 .52413 .3388 .52231 .33266 .51567 Mtetra
.509 .671 .936 r
.33266 .51567 .3388 .52231 .35101 .47504 .3424 .51546 Mtetra
.414 .148 .4 r
.3424 .51546 .35101 .47504 .35875 .513 .3527 .50543 Mtetra
.556 .659 .905 r
.3527 .50543 .35875 .513 .36864 .51095 .36255 .50461 Mtetra
.623 .726 .921 r
.36255 .50461 .36864 .51095 .3786 .50846 .37252 .50219 Mtetra
.624 .729 .923 r
.37252 .50219 .3786 .50846 .38858 .50636 .38253 .49974 Mtetra
.546 .689 .933 r
.38253 .49974 .38858 .50636 .39682 .55114 .39253 .49889 Mtetra
.619 .432 .607 r
.39253 .49889 .39682 .55114 .40886 .49674 .40292 .48869 Mtetra
.542 .642 .898 r
.40292 .48869 .40886 .49674 .41896 .49461 .41297 .48821 Mtetra
.629 .729 .92 r
.41297 .48821 .41896 .49461 .42912 .49185 .42315 .4856 Mtetra
.639 .739 .921 r
.42315 .4856 .42912 .49185 .43933 .48897 .43338 .48272 Mtetra
.64 .74 .921 r
.43338 .48272 .43933 .48897 .44957 .48617 .44365 .47983 Mtetra
.628 .733 .923 r
.44365 .47983 .44957 .48617 .45984 .4841 .45395 .4772 Mtetra
.475 .651 .936 r
.45395 .4772 .45984 .4841 .47043 .46575 .46425 .47757 Mtetra
0 0 0 r
.46425 .47757 .47043 .46575 .4806 .47398 .47478 .46657 Mtetra
.587 .684 .909 r
.47478 .46657 .4806 .47398 .491 .47142 .48518 .46498 Mtetra
.639 .737 .919 r
.48518 .46498 .491 .47142 .50145 .46835 .49565 .46204 Mtetra
.649 .746 .92 r
.49565 .46204 .50145 .46835 .51194 .4651 .50617 .45884 Mtetra
.653 .749 .92 r
.50617 .45884 .51194 .4651 .52247 .46177 .51672 .45552 Mtetra
.656 .751 .92 r
.51672 .45552 .52247 .46177 .53304 .45837 .52732 .45212 Mtetra
.657 .753 .92 r
.52732 .45212 .53304 .45837 .54365 .45492 .53796 .44866 Mtetra
.658 .753 .92 r
.53796 .44866 .54365 .45492 .5543 .45144 .54864 .44517 Mtetra
.659 .754 .92 r
.54864 .44517 .5543 .45144 .56499 .44795 .55936 .44165 Mtetra
.55936 .44165 .56499 .44795 .57573 .44444 .57012 .43811 Mtetra
.57012 .43811 .57573 .44444 .5865 .44092 .58092 .43456 Mtetra
.58092 .43456 .5865 .44092 .59732 .43739 .59176 .43101 Mtetra
.658 .753 .92 r
.59176 .43101 .59732 .43739 .60817 .43386 .60265 .42745 Mtetra
.60265 .42745 .60817 .43386 .61907 .43032 .61358 .42388 Mtetra
.61358 .42388 .61907 .43032 .63001 .42677 .62455 .42031 Mtetra
.62455 .42031 .63001 .42677 .641 .42321 .63556 .41672 Mtetra
.63556 .41672 .641 .42321 .65203 .41964 .64662 .41312 Mtetra
.64662 .41312 .65203 .41964 .6631 .41606 .65772 .40951 Mtetra
.657 .753 .92 r
.65772 .40951 .6631 .41606 .67421 .41247 .66886 .40589 Mtetra
.66886 .40589 .67421 .41247 .68537 .40886 .68005 .40226 Mtetra
.68005 .40226 .68537 .40886 .69657 .40524 .69128 .39861 Mtetra
.69128 .39861 .69657 .40524 .70782 .40161 .70256 .39495 Mtetra
.657 .752 .92 r
.70256 .39495 .70782 .40161 .71911 .39796 .71388 .39128 Mtetra
.71388 .39128 .71911 .39796 .73044 .3943 .72525 .38759 Mtetra
.72525 .38759 .73044 .3943 .74182 .39063 .73666 .38389 Mtetra
.73666 .38389 .74182 .39063 .75325 .38694 .74812 .38018 Mtetra
.74812 .38018 .75325 .38694 .76472 .38324 .75962 .37645 Mtetra
.75962 .37645 .76472 .38324 .77624 .37952 .77117 .3727 Mtetra
.77117 .3727 .77624 .37952 .7878 .3758 .78277 .36895 Mtetra
.78277 .36895 .7878 .3758 .79941 .37205 .79441 .36518 Mtetra
.79441 .36518 .79941 .37205 .81107 .3683 .8061 .36139 Mtetra
.8061 .36139 .81107 .3683 .82277 .36452 .81784 .35759 Mtetra
.81784 .35759 .82277 .36452 .83452 .36074 .82962 .35378 Mtetra
.82962 .35378 .83452 .36074 .84632 .35694 .84146 .34994 Mtetra
.84146 .34994 .84632 .35694 .85817 .35312 .85334 .3461 Mtetra
.949 .616 .357 r
.21963 .5446 .22593 .55206 .23601 .54245 .2254 .58423 Mtetra
0 0 0 r
.2254 .58423 .23601 .54245 .24528 .54252 .23893 .53593 Mtetra
.586 .699 .92 r
.23893 .53593 .24528 .54252 .25474 .54087 .2484 .53442 Mtetra
.555 .693 .932 r
.2484 .53442 .25474 .54087 .26363 .54705 .25786 .53343 Mtetra
.746 .625 .726 r
.25786 .53343 .26363 .54705 .2742 .53195 .26811 .52278 Mtetra
.461 .567 .876 r
.26811 .52278 .2742 .53195 .28376 .53049 .27747 .5241 Mtetra
.603 .714 .922 r
.27747 .5241 .28376 .53049 .29339 .52869 .28712 .52217 Mtetra
.548 .69 .933 r
.28712 .52217 .29339 .52869 .30205 .54208 .29674 .52129 Mtetra
.697 .551 .685 r
.29674 .52129 .30205 .54208 .31312 .51958 .30702 .51113 Mtetra
.506 .611 .891 r
.30702 .51113 .31312 .51958 .32285 .51785 .31664 .51146 Mtetra
.613 .72 .921 r
.31664 .51146 .32285 .51785 .33266 .51567 .32646 .50928 Mtetra
.598 .715 .926 r
.32646 .50928 .33266 .51567 .3424 .51546 .33631 .50741 Mtetra
.918 .716 .614 r
.33631 .50741 .3424 .51546 .3527 .50543 .34865 .4599 Mtetra
0 0 .454 r
.34865 .4599 .3527 .50543 .36255 .50461 .35642 .49798 Mtetra
.609 .713 .918 r
.35642 .49798 .36255 .50461 .37252 .50219 .3664 .49588 Mtetra
.627 .73 .922 r
.3664 .49588 .37252 .50219 .38253 .49974 .37644 .49333 Mtetra
.609 .722 .925 r
.37644 .49333 .38253 .49974 .39253 .49889 .3865 .49118 Mtetra
.952 .604 .295 r
.3865 .49118 .39253 .49889 .40292 .48869 .39479 .53612 Mtetra
0 0 .091 r
.39479 .53612 .40292 .48869 .41297 .48821 .40696 .48144 Mtetra
.611 .712 .917 r
.40696 .48144 .41297 .48821 .42315 .4856 .41714 .47925 Mtetra
.636 .736 .92 r
.41714 .47925 .42315 .4856 .43338 .48272 .42739 .47643 Mtetra
.64 .74 .921 r
.42739 .47643 .43338 .48272 .44365 .47983 .43769 .47349 Mtetra
.636 .738 .922 r
.43769 .47349 .44365 .47983 .45395 .4772 .44802 .47065 Mtetra
.605 .72 .926 r
.44802 .47065 .45395 .4772 .46425 .47757 .45838 .46852 Mtetra
.858 .725 .715 r
.45838 .46852 .46425 .47757 .47478 .46657 .46906 .45004 Mtetra
.283 .332 .737 r
.46906 .45004 .47478 .46657 .48518 .46498 .47932 .45826 Mtetra
.626 .724 .918 r
.47932 .45826 .48518 .46498 .49565 .46204 .48981 .45564 Mtetra
.645 .742 .92 r
.48981 .45564 .49565 .46204 .50617 .45884 .50035 .45251 Mtetra
.652 .748 .92 r
.50035 .45251 .50617 .45884 .51672 .45552 .51093 .44921 Mtetra
.655 .75 .92 r
.51093 .44921 .51672 .45552 .52732 .45212 .52156 .44581 Mtetra
.657 .752 .92 r
.52156 .44581 .52732 .45212 .53796 .44866 .53222 .44235 Mtetra
.658 .753 .92 r
.53222 .44235 .53796 .44866 .54864 .44517 .54293 .43884 Mtetra
.659 .754 .92 r
.54293 .43884 .54864 .44517 .55936 .44165 .55368 .4353 Mtetra
.55368 .4353 .55936 .44165 .57012 .43811 .56447 .43174 Mtetra
.56447 .43174 .57012 .43811 .58092 .43456 .5753 .42817 Mtetra
.5753 .42817 .58092 .43456 .59176 .43101 .58617 .42458 Mtetra
.658 .753 .92 r
.58617 .42458 .59176 .43101 .60265 .42745 .59708 .421 Mtetra
.59708 .421 .60265 .42745 .61358 .42388 .60804 .4174 Mtetra
.60804 .4174 .61358 .42388 .62455 .42031 .61904 .4138 Mtetra
.61904 .4138 .62455 .42031 .63556 .41672 .63008 .41018 Mtetra
.63008 .41018 .63556 .41672 .64662 .41312 .64117 .40656 Mtetra
.64117 .40656 .64662 .41312 .65772 .40951 .6523 .40292 Mtetra
.657 .753 .92 r
.6523 .40292 .65772 .40951 .66886 .40589 .66348 .39927 Mtetra
.66348 .39927 .66886 .40589 .68005 .40226 .67469 .39561 Mtetra
.67469 .39561 .68005 .40226 .69128 .39861 .68596 .39193 Mtetra
.68596 .39193 .69128 .39861 .70256 .39495 .69727 .38825 Mtetra
.69727 .38825 .70256 .39495 .71388 .39128 .70862 .38455 Mtetra
.657 .752 .92 r
.70862 .38455 .71388 .39128 .72525 .38759 .72002 .38083 Mtetra
.72002 .38083 .72525 .38759 .73666 .38389 .73146 .3771 Mtetra
.73146 .3771 .73666 .38389 .74812 .38018 .74295 .37336 Mtetra
.74295 .37336 .74812 .38018 .75962 .37645 .75449 .3696 Mtetra
.75449 .3696 .75962 .37645 .77117 .3727 .76607 .36583 Mtetra
.76607 .36583 .77117 .3727 .78277 .36895 .7777 .36205 Mtetra
.7777 .36205 .78277 .36895 .79441 .36518 .78938 .35825 Mtetra
.78938 .35825 .79441 .36518 .8061 .36139 .8011 .35443 Mtetra
.8011 .35443 .8061 .36139 .81784 .35759 .81287 .35061 Mtetra
.81287 .35061 .81784 .35759 .82962 .35378 .82469 .34676 Mtetra
.82469 .34676 .82962 .35378 .84146 .34994 .83656 .3429 Mtetra
.83656 .3429 .84146 .34994 .85334 .3461 .84847 .33903 Mtetra
.518 .675 .935 r
.2132 .53803 .21963 .5446 .2254 .58423 .2225 .53767 Mtetra
.624 .44 .614 r
.2225 .53767 .2254 .58423 .23893 .53593 .23267 .52797 Mtetra
.515 .628 .901 r
.23267 .52797 .23893 .53593 .2484 .53442 .24201 .528 Mtetra
.592 .709 .925 r
.24201 .528 .2484 .53442 .25786 .53343 .25154 .52631 Mtetra
0 .281 .775 r
.25154 .52631 .25786 .53343 .26811 .52278 .2605 .53247 Mtetra
.676 .876 .496 r
.2605 .53247 .26811 .52278 .27747 .5241 .27117 .51726 Mtetra
.584 .694 .918 r
.27117 .51726 .27747 .5241 .28712 .52217 .2808 .51576 Mtetra
.598 .714 .925 r
.2808 .51576 .28712 .52217 .29674 .52129 .29051 .51391 Mtetra
.716 .245 0 r
.29051 .51391 .29674 .52129 .30702 .51113 .29923 .52731 Mtetra
0 0 0 r
.29923 .52731 .30702 .51113 .31664 .51146 .3104 .50468 Mtetra
.595 .702 .918 r
.3104 .50468 .31664 .51146 .32646 .50928 .32022 .5029 Mtetra
.614 .723 .923 r
.32022 .5029 .32646 .50928 .33631 .50741 .3301 .50067 Mtetra
.51 .671 .936 r
.3301 .50067 .33631 .50741 .34865 .4599 .33992 .50042 Mtetra
.408 .141 .394 r
.33992 .50042 .34865 .4599 .35642 .49798 .35031 .49029 Mtetra
.556 .659 .905 r
.35031 .49029 .35642 .49798 .3664 .49588 .36024 .48944 Mtetra
.623 .726 .921 r
.36024 .48944 .3664 .49588 .37644 .49333 .3703 .48696 Mtetra
.624 .729 .923 r
.3703 .48696 .37644 .49333 .3865 .49118 .3804 .48445 Mtetra
.546 .689 .933 r
.3804 .48445 .3865 .49118 .39479 .53612 .39047 .48355 Mtetra
.617 .43 .606 r
.39047 .48355 .39479 .53612 .40696 .48144 .40096 .47326 Mtetra
.542 .642 .898 r
.40096 .47326 .40696 .48144 .41714 .47925 .4111 .47274 Mtetra
.629 .729 .92 r
.4111 .47274 .41714 .47925 .42739 .47643 .42136 .47007 Mtetra
.639 .739 .921 r
.42136 .47007 .42739 .47643 .43769 .47349 .43168 .46714 Mtetra
.64 .74 .921 r
.43168 .46714 .43769 .47349 .44802 .47065 .44204 .46419 Mtetra
.628 .733 .923 r
.44204 .46419 .44802 .47065 .45838 .46852 .45243 .4615 Mtetra
.476 .651 .936 r
.45243 .4615 .45838 .46852 .46906 .45004 .46281 .46183 Mtetra
0 0 0 r
.46281 .46183 .46906 .45004 .47932 .45826 .47344 .45074 Mtetra
.587 .684 .909 r
.47344 .45074 .47932 .45826 .48981 .45564 .48394 .44909 Mtetra
.639 .737 .919 r
.48394 .44909 .48981 .45564 .50035 .45251 .4945 .4461 Mtetra
.649 .746 .92 r
.4945 .4461 .50035 .45251 .51093 .44921 .50511 .44283 Mtetra
.653 .749 .92 r
.50511 .44283 .51093 .44921 .52156 .44581 .51576 .43945 Mtetra
.656 .751 .92 r
.51576 .43945 .52156 .44581 .53222 .44235 .52645 .43599 Mtetra
.657 .753 .92 r
.52645 .43599 .53222 .44235 .54293 .43884 .53718 .43247 Mtetra
.658 .753 .92 r
.53718 .43247 .54293 .43884 .55368 .4353 .54796 .42891 Mtetra
.659 .754 .92 r
.54796 .42891 .55368 .4353 .56447 .43174 .55877 .42532 Mtetra
.55877 .42532 .56447 .43174 .5753 .42817 .56963 .42172 Mtetra
.56963 .42172 .5753 .42817 .58617 .42458 .58053 .41811 Mtetra
.58053 .41811 .58617 .42458 .59708 .421 .59148 .41449 Mtetra
.658 .753 .92 r
.59148 .41449 .59708 .421 .60804 .4174 .60246 .41087 Mtetra
.60246 .41087 .60804 .4174 .61904 .4138 .61349 .40724 Mtetra
.61349 .40724 .61904 .4138 .63008 .41018 .62457 .40359 Mtetra
.62457 .40359 .63008 .41018 .64117 .40656 .63568 .39994 Mtetra
.63568 .39994 .64117 .40656 .6523 .40292 .64684 .39628 Mtetra
.64684 .39628 .6523 .40292 .66348 .39927 .65805 .3926 Mtetra
.657 .753 .92 r
.65805 .3926 .66348 .39927 .67469 .39561 .6693 .38891 Mtetra
.6693 .38891 .67469 .39561 .68596 .39193 .68059 .38521 Mtetra
.68059 .38521 .68596 .39193 .69727 .38825 .69193 .38149 Mtetra
.69193 .38149 .69727 .38825 .70862 .38455 .70331 .37776 Mtetra
.657 .752 .92 r
.70331 .37776 .70862 .38455 .72002 .38083 .71475 .37402 Mtetra
.71475 .37402 .72002 .38083 .73146 .3771 .72622 .37027 Mtetra
.72622 .37027 .73146 .3771 .74295 .37336 .73774 .36649 Mtetra
.73774 .36649 .74295 .37336 .75449 .3696 .74931 .36271 Mtetra
.74931 .36271 .75449 .3696 .76607 .36583 .76093 .35891 Mtetra
.76093 .35891 .76607 .36583 .7777 .36205 .77259 .3551 Mtetra
.77259 .3551 .7777 .36205 .78938 .35825 .7843 .35127 Mtetra
.7843 .35127 .78938 .35825 .8011 .35443 .79606 .34743 Mtetra
.79606 .34743 .8011 .35443 .81287 .35061 .80786 .34357 Mtetra
.80786 .34357 .81287 .35061 .82469 .34676 .81972 .33969 Mtetra
.81972 .33969 .82469 .34676 .83656 .3429 .83162 .33581 Mtetra
.83162 .33581 .83656 .3429 .84847 .33903 .84357 .3319 Mtetra
.58 .702 .926 r
.20672 .53155 .2132 .53803 .2225 .53767 .21613 .5301 Mtetra
.949 .615 .352 r
.21613 .5301 .2225 .53767 .23267 .52797 .22191 .56987 Mtetra
0 0 0 r
.22191 .56987 .23267 .52797 .24201 .528 .2356 .52131 Mtetra
.586 .699 .92 r
.2356 .52131 .24201 .528 .25154 .52631 .24514 .51975 Mtetra
.555 .693 .932 r
.24514 .51975 .25154 .52631 .2605 .53247 .25467 .51872 Mtetra
.746 .626 .726 r
.25467 .51872 .2605 .53247 .27117 .51726 .26502 .50798 Mtetra
.46 .567 .876 r
.26502 .50798 .27117 .51726 .2808 .51576 .27445 .50926 Mtetra
.603 .714 .922 r
.27445 .50926 .2808 .51576 .29051 .51391 .28418 .50728 Mtetra
.548 .69 .933 r
.28418 .50728 .29051 .51391 .29923 .52731 .29387 .50636 Mtetra
.696 .551 .685 r
.29387 .50636 .29923 .52731 .3104 .50468 .30424 .49612 Mtetra
.505 .611 .891 r
.30424 .49612 .3104 .50468 .32022 .5029 .31394 .4964 Mtetra
.613 .72 .921 r
.31394 .4964 .32022 .5029 .3301 .50067 .32384 .49417 Mtetra
.598 .715 .926 r
.32384 .49417 .3301 .50067 .33992 .50042 .33377 .49225 Mtetra
.919 .716 .613 r
.33377 .49225 .33992 .50042 .35031 .49029 .34625 .4445 Mtetra
0 0 .45 r
.34625 .4445 .35031 .49029 .36024 .48944 .35406 .4827 Mtetra
.609 .713 .918 r
.35406 .4827 .36024 .48944 .3703 .48696 .36412 .48054 Mtetra
.627 .73 .922 r
.36412 .48054 .3703 .48696 .3804 .48445 .37424 .47794 Mtetra
.609 .722 .925 r
.37424 .47794 .3804 .48445 .39047 .48355 .38439 .47573 Mtetra
.952 .603 .29 r
.38439 .47573 .39047 .48355 .40096 .47326 .39272 .52082 Mtetra
0 0 .083 r
.39272 .52082 .40096 .47326 .4111 .47274 .40503 .46586 Mtetra
.611 .712 .917 r
.40503 .46586 .4111 .47274 .42136 .47007 .4153 .46361 Mtetra
.636 .736 .92 r
.4153 .46361 .42136 .47007 .43168 .46714 .42563 .46074 Mtetra
.64 .74 .921 r
.42563 .46074 .43168 .46714 .44204 .46419 .43602 .45774 Mtetra
.636 .738 .922 r
.43602 .45774 .44204 .46419 .45243 .4615 .44644 .45483 Mtetra
.605 .72 .926 r
.44644 .45483 .45243 .4615 .46281 .46183 .45689 .45265 Mtetra
.859 .726 .714 r
.45689 .45265 .46281 .46183 .47344 .45074 .46768 .43405 Mtetra
.281 .331 .737 r
.46768 .43405 .47344 .45074 .48394 .44909 .47802 .44226 Mtetra
.626 .724 .918 r
.47802 .44226 .48394 .44909 .4945 .4461 .4886 .43958 Mtetra
.645 .742 .92 r
.4886 .43958 .4945 .4461 .50511 .44283 .49924 .43639 Mtetra
.652 .748 .92 r
.49924 .43639 .50511 .44283 .51576 .43945 .50991 .43302 Mtetra
.655 .75 .92 r
.50991 .43302 .51576 .43945 .52645 .43599 .52063 .42957 Mtetra
.657 .752 .92 r
.52063 .42957 .52645 .43599 .53718 .43247 .53139 .42604 Mtetra
.658 .753 .92 r
.53139 .42604 .53718 .43247 .54796 .42891 .5422 .42247 Mtetra
.659 .754 .92 r
.5422 .42247 .54796 .42891 .55877 .42532 .55304 .41886 Mtetra
.55304 .41886 .55877 .42532 .56963 .42172 .56393 .41523 Mtetra
.56393 .41523 .56963 .42172 .58053 .41811 .57486 .41159 Mtetra
.57486 .41159 .58053 .41811 .59148 .41449 .58583 .40795 Mtetra
.658 .753 .92 r
.58583 .40795 .59148 .41449 .60246 .41087 .59685 .40429 Mtetra
.59685 .40429 .60246 .41087 .61349 .40724 .6079 .40063 Mtetra
.6079 .40063 .61349 .40724 .62457 .40359 .61901 .39696 Mtetra
.61901 .39696 .62457 .40359 .63568 .39994 .63015 .39328 Mtetra
.63015 .39328 .63568 .39994 .64684 .39628 .64134 .38959 Mtetra
.64134 .38959 .64684 .39628 .65805 .3926 .65258 .38588 Mtetra
.657 .753 .92 r
.65258 .38588 .65805 .3926 .6693 .38891 .66386 .38216 Mtetra
.66386 .38216 .6693 .38891 .68059 .38521 .67519 .37843 Mtetra
.67519 .37843 .68059 .38521 .69193 .38149 .68656 .37469 Mtetra
.68656 .37469 .69193 .38149 .70331 .37776 .69797 .37093 Mtetra
.69797 .37093 .70331 .37776 .71475 .37402 .70943 .36716 Mtetra
.657 .752 .92 r
.70943 .36716 .71475 .37402 .72622 .37027 .72094 .36338 Mtetra
.72094 .36338 .72622 .37027 .73774 .36649 .7325 .35958 Mtetra
.7325 .35958 .73774 .36649 .74931 .36271 .7441 .35576 Mtetra
.7441 .35576 .74931 .36271 .76093 .35891 .75575 .35194 Mtetra
.75575 .35194 .76093 .35891 .77259 .3551 .76744 .34809 Mtetra
.76744 .34809 .77259 .3551 .7843 .35127 .77919 .34424 Mtetra
.77919 .34424 .7843 .35127 .79606 .34743 .79098 .34036 Mtetra
.79098 .34036 .79606 .34743 .80786 .34357 .80282 .33648 Mtetra
.80282 .33648 .80786 .34357 .81972 .33969 .81471 .33257 Mtetra
.81471 .33257 .81972 .33969 .83162 .33581 .82665 .32866 Mtetra
.82665 .32866 .83162 .33581 .84357 .3319 .83863 .32472 Mtetra
.573 .69 .92 r
.20023 .52473 .20672 .53155 .21613 .5301 .20964 .52343 Mtetra
.518 .675 .935 r
.20964 .52343 .21613 .5301 .22191 .56987 .21901 .52302 Mtetra
.623 .439 .613 r
.21901 .52302 .22191 .56987 .2356 .52131 .22927 .51324 Mtetra
.514 .628 .901 r
.22927 .51324 .2356 .52131 .24514 .51975 .23868 .51323 Mtetra
.592 .709 .925 r
.23868 .51323 .24514 .51975 .25467 .51872 .24829 .51149 Mtetra
0 .284 .778 r
.24829 .51149 .25467 .51872 .26502 .50798 .25731 .51764 Mtetra
.685 .882 .505 r
.25731 .51764 .26502 .50798 .27445 .50926 .26808 .50232 Mtetra
.584 .694 .918 r
.26808 .50232 .27445 .50926 .28418 .50728 .27779 .50078 Mtetra
.598 .714 .925 r
.27779 .50078 .28418 .50728 .29387 .50636 .28758 .49887 Mtetra
.709 .239 0 r
.28758 .49887 .29387 .50636 .30424 .49612 .29635 .51229 Mtetra
0 0 0 r
.29635 .51229 .30424 .49612 .31394 .4964 .30764 .48951 Mtetra
.595 .702 .918 r
.30764 .48951 .31394 .4964 .32384 .49417 .31753 .48769 Mtetra
.614 .723 .923 r
.31753 .48769 .32384 .49417 .33377 .49225 .3275 .4854 Mtetra
.51 .671 .936 r
.3275 .4854 .33377 .49225 .34625 .4445 .3374 .4851 Mtetra
.402 .134 .388 r
.3374 .4851 .34625 .4445 .35406 .4827 .34789 .47489 Mtetra
.555 .659 .906 r
.34789 .47489 .35406 .4827 .36412 .48054 .3579 .47399 Mtetra
.623 .726 .921 r
.3579 .47399 .36412 .48054 .37424 .47794 .36804 .47145 Mtetra
.624 .729 .923 r
.36804 .47145 .37424 .47794 .38439 .47573 .37822 .46889 Mtetra
.546 .689 .933 r
.37822 .46889 .38439 .47573 .39272 .52082 .38839 .46794 Mtetra
.616 .428 .604 r
.38839 .46794 .39272 .52082 .40503 .46586 .39896 .45756 Mtetra
.542 .642 .898 r
.39896 .45756 .40503 .46586 .4153 .46361 .40919 .45699 Mtetra
.629 .729 .92 r
.40919 .45699 .4153 .46361 .42563 .46074 .41955 .45427 Mtetra
.639 .739 .921 r
.41955 .45427 .42563 .46074 .43602 .45774 .42995 .45127 Mtetra
.64 .74 .921 r
.42995 .45127 .43602 .45774 .44644 .45483 .4404 .44826 Mtetra
.628 .733 .923 r
.4404 .44826 .44644 .45483 .45689 .45265 .45088 .44552 Mtetra
.476 .651 .936 r
.45088 .44552 .45689 .45265 .46768 .43405 .46136 .4458 Mtetra
0 0 0 r
.46136 .4458 .46768 .43405 .47802 .44226 .47208 .43462 Mtetra
.587 .684 .909 r
.47208 .43462 .47802 .44226 .4886 .43958 .48267 .43291 Mtetra
.639 .737 .919 r
.48267 .43291 .4886 .43958 .49924 .43639 .49333 .42986 Mtetra
.649 .746 .92 r
.49333 .42986 .49924 .43639 .50991 .43302 .50403 .42653 Mtetra
.653 .749 .92 r
.50403 .42653 .50991 .43302 .52063 .42957 .51477 .42308 Mtetra
.656 .751 .92 r
.51477 .42308 .52063 .42957 .53139 .42604 .52556 .41956 Mtetra
.657 .753 .92 r
.52556 .41956 .53139 .42604 .5422 .42247 .53639 .41597 Mtetra
.658 .753 .92 r
.53639 .41597 .5422 .42247 .55304 .41886 .54727 .41235 Mtetra
.659 .754 .92 r
.54727 .41235 .55304 .41886 .56393 .41523 .55818 .4087 Mtetra
.55818 .4087 .56393 .41523 .57486 .41159 .56914 .40503 Mtetra
.56914 .40503 .57486 .41159 .58583 .40795 .58014 .40135 Mtetra
.58014 .40135 .58583 .40795 .59685 .40429 .59119 .39767 Mtetra
.658 .753 .92 r
.59119 .39767 .59685 .40429 .6079 .40063 .60228 .39398 Mtetra
.60228 .39398 .6079 .40063 .61901 .39696 .61341 .39028 Mtetra
.61341 .39028 .61901 .39696 .63015 .39328 .62458 .38657 Mtetra
.62458 .38657 .63015 .39328 .64134 .38959 .63581 .38285 Mtetra
.63581 .38285 .64134 .38959 .65258 .38588 .64707 .37911 Mtetra
.64707 .37911 .65258 .38588 .66386 .38216 .65838 .37537 Mtetra
.657 .753 .92 r
.65838 .37537 .66386 .38216 .67519 .37843 .66974 .37161 Mtetra
.66974 .37161 .67519 .37843 .68656 .37469 .68114 .36784 Mtetra
.68114 .36784 .68656 .37469 .69797 .37093 .69259 .36405 Mtetra
.69259 .36405 .69797 .37093 .70943 .36716 .70408 .36025 Mtetra
.657 .752 .92 r
.70408 .36025 .70943 .36716 .72094 .36338 .71562 .35644 Mtetra
.71562 .35644 .72094 .36338 .7325 .35958 .72721 .35261 Mtetra
.72721 .35261 .7325 .35958 .7441 .35576 .73885 .34877 Mtetra
.73885 .34877 .7441 .35576 .75575 .35194 .75053 .34491 Mtetra
.75053 .34491 .75575 .35194 .76744 .34809 .76226 .34104 Mtetra
.76226 .34104 .76744 .34809 .77919 .34424 .77404 .33715 Mtetra
.77404 .33715 .77919 .34424 .79098 .34036 .78586 .33325 Mtetra
.78586 .33325 .79098 .34036 .80282 .33648 .79774 .32933 Mtetra
.79774 .32933 .80282 .33648 .81471 .33257 .80966 .3254 Mtetra
.80966 .3254 .81471 .33257 .82665 .32866 .82163 .32145 Mtetra
.82163 .32145 .82665 .32866 .83863 .32472 .83366 .31749 Mtetra
.466 .583 .887 r
.1939 .51588 .20023 .52473 .20964 .52343 .20309 .51685 Mtetra
.58 .702 .926 r
.20309 .51685 .20964 .52343 .21901 .52302 .21258 .51534 Mtetra
.95 .614 .348 r
.21258 .51534 .21901 .52302 .22927 .51324 .21835 .55525 Mtetra
0 0 0 r
.21835 .55525 .22927 .51324 .23868 .51323 .23221 .50643 Mtetra
.586 .699 .92 r
.23221 .50643 .23868 .51323 .24829 .51149 .24182 .50483 Mtetra
.555 .693 .931 r
.24182 .50483 .24829 .51149 .25731 .51764 .25143 .50375 Mtetra
.746 .626 .726 r
.25143 .50375 .25731 .51764 .26808 .50232 .26187 .49292 Mtetra
.46 .567 .876 r
.26187 .49292 .26808 .50232 .27779 .50078 .27137 .49417 Mtetra
.603 .714 .922 r
.27137 .49417 .27779 .50078 .28758 .49887 .28118 .49213 Mtetra
.548 .69 .933 r
.28118 .49213 .28758 .49887 .29635 .51229 .29096 .49117 Mtetra
.696 .551 .685 r
.29096 .49117 .29635 .51229 .30764 .48951 .30142 .48084 Mtetra
.505 .611 .891 r
.30142 .48084 .30764 .48951 .31753 .48769 .31119 .48108 Mtetra
.613 .72 .921 r
.31119 .48108 .31753 .48769 .3275 .4854 .32117 .47879 Mtetra
.598 .715 .926 r
.32117 .47879 .3275 .4854 .3374 .4851 .33119 .47682 Mtetra
.92 .717 .612 r
.33119 .47682 .3374 .4851 .34789 .47489 .34381 .42883 Mtetra
0 0 .447 r
.34381 .42883 .34789 .47489 .3579 .47399 .35165 .46714 Mtetra
.609 .713 .918 r
.35165 .46714 .3579 .47399 .36804 .47145 .36179 .46492 Mtetra
.627 .73 .922 r
.36179 .46492 .36804 .47145 .37822 .46889 .372 .46226 Mtetra
.609 .722 .925 r
.372 .46226 .37822 .46889 .38839 .46794 .38224 .46 Mtetra
.951 .601 .284 r
.38224 .46 .38839 .46794 .39896 .45756 .39061 .50524 Mtetra
0 0 .075 r
.39061 .50524 .39896 .45756 .40919 .45699 .40306 .45 Mtetra
.611 .712 .917 r
.40306 .45 .40919 .45699 .41955 .45427 .41342 .4477 Mtetra
.636 .736 .92 r
.41342 .4477 .41955 .45427 .42995 .45127 .42384 .44476 Mtetra
.64 .74 .921 r
.42384 .44476 .42995 .45127 .4404 .44826 .43432 .4417 Mtetra
.636 .738 .922 r
.43432 .4417 .4404 .44826 .45088 .44552 .44483 .43874 Mtetra
.605 .72 .926 r
.44483 .43874 .45088 .44552 .46136 .4458 .45537 .4365 Mtetra
.86 .727 .714 r
.45537 .4365 .46136 .4458 .47208 .43462 .46626 .41777 Mtetra
.279 .33 .736 r
.46626 .41777 .47208 .43462 .48267 .43291 .47669 .42596 Mtetra
.626 .724 .918 r
.47669 .42596 .48267 .43291 .49333 .42986 .48737 .42322 Mtetra
.645 .742 .92 r
.48737 .42322 .49333 .42986 .50403 .42653 .4981 .41997 Mtetra
.652 .748 .92 r
.4981 .41997 .50403 .42653 .51477 .42308 .50887 .41654 Mtetra
.655 .75 .92 r
.50887 .41654 .51477 .42308 .52556 .41956 .51969 .41302 Mtetra
.657 .752 .92 r
.51969 .41302 .52556 .41956 .53639 .41597 .53055 .40943 Mtetra
.658 .753 .92 r
.53055 .40943 .53639 .41597 .54727 .41235 .54145 .40579 Mtetra
.659 .754 .92 r
.54145 .40579 .54727 .41235 .55818 .4087 .55239 .40211 Mtetra
.55239 .40211 .55818 .4087 .56914 .40503 .56338 .39842 Mtetra
.56338 .39842 .56914 .40503 .58014 .40135 .57441 .39471 Mtetra
.57441 .39471 .58014 .40135 .59119 .39767 .58549 .391 Mtetra
.658 .753 .92 r
.58549 .391 .59119 .39767 .60228 .39398 .5966 .38728 Mtetra
.5966 .38728 .60228 .39398 .61341 .39028 .60777 .38355 Mtetra
.60777 .38355 .61341 .39028 .62458 .38657 .61897 .37981 Mtetra
.61897 .37981 .62458 .38657 .63581 .38285 .63023 .37606 Mtetra
.63023 .37606 .63581 .38285 .64707 .37911 .64152 .37229 Mtetra
.64152 .37229 .64707 .37911 .65838 .37537 .65286 .36852 Mtetra
.657 .753 .92 r
.65286 .36852 .65838 .37537 .66974 .37161 .66425 .36473 Mtetra
.66425 .36473 .66974 .37161 .68114 .36784 .67569 .36093 Mtetra
.67569 .36093 .68114 .36784 .69259 .36405 .68717 .35712 Mtetra
.68717 .35712 .69259 .36405 .70408 .36025 .69869 .35329 Mtetra
.69869 .35329 .70408 .36025 .71562 .35644 .71027 .34945 Mtetra
.657 .752 .92 r
.71027 .34945 .71562 .35644 .72721 .35261 .72189 .34559 Mtetra
.72189 .34559 .72721 .35261 .73885 .34877 .73355 .34172 Mtetra
.73355 .34172 .73885 .34877 .75053 .34491 .74527 .33783 Mtetra
.74527 .33783 .75053 .34491 .76226 .34104 .75703 .33393 Mtetra
.75703 .33393 .76226 .34104 .77404 .33715 .76885 .33001 Mtetra
.76885 .33001 .77404 .33715 .78586 .33325 .78071 .32608 Mtetra
.78071 .32608 .78586 .33325 .79774 .32933 .79262 .32213 Mtetra
.79262 .32213 .79774 .32933 .80966 .3254 .80457 .31817 Mtetra
.80457 .31817 .80966 .3254 .82163 .32145 .81658 .31419 Mtetra
.81658 .31419 .82163 .32145 .83366 .31749 .82864 .3102 Mtetra
.727 .886 .49 r
.18542 .52777 .1939 .51588 .20309 .51685 .19654 .50992 Mtetra
.573 .69 .92 r
.19654 .50992 .20309 .51685 .21258 .51534 .20602 .50857 Mtetra
.518 .675 .935 r
.20602 .50857 .21258 .51534 .21835 .55525 .21547 .50812 Mtetra
.621 .437 .612 r
.21547 .50812 .21835 .55525 .23221 .50643 .22581 .49826 Mtetra
.514 .628 .901 r
.22581 .49826 .23221 .50643 .24182 .50483 .2353 .4982 Mtetra
.592 .709 .925 r
.2353 .4982 .24182 .50483 .25143 .50375 .24498 .49641 Mtetra
0 .288 .781 r
.24498 .49641 .25143 .50375 .26187 .49292 .25407 .50254 Mtetra
.693 .889 .514 r
.25407 .50254 .26187 .49292 .27137 .49417 .26494 .48712 Mtetra
.584 .694 .918 r
.26494 .48712 .27137 .49417 .28118 .49213 .27473 .48552 Mtetra
.598 .714 .925 r
.27473 .48552 .28118 .49213 .29096 .49117 .28459 .48356 Mtetra
.703 .233 0 r
.28459 .48356 .29096 .49117 .30142 .48084 .29343 .497 Mtetra
0 0 0 r
.29343 .497 .30142 .48084 .31119 .48108 .30483 .47408 Mtetra
.595 .702 .918 r
.30483 .47408 .31119 .48108 .32117 .47879 .3148 .4722 Mtetra
.614 .723 .923 r
.3148 .4722 .32117 .47879 .33119 .47682 .32485 .46986 Mtetra
.51 .671 .936 r
.32485 .46986 .33119 .47682 .34381 .42883 .33483 .46951 Mtetra
.396 .126 .382 r
.33483 .46951 .34381 .42883 .35165 .46714 .34541 .45921 Mtetra
.555 .66 .906 r
.34541 .45921 .35165 .46714 .36179 .46492 .35551 .45826 Mtetra
.623 .726 .921 r
.35551 .45826 .36179 .46492 .372 .46226 .36574 .45567 Mtetra
.624 .729 .923 r
.36574 .45567 .372 .46226 .38224 .46 .37601 .45305 Mtetra
.546 .689 .933 r
.37601 .45305 .38224 .46 .39061 .50524 .38626 .45205 Mtetra
.615 .426 .603 r
.38626 .45205 .39061 .50524 .40306 .45 .39693 .44158 Mtetra
.542 .642 .898 r
.39693 .44158 .40306 .45 .41342 .4477 .40725 .44095 Mtetra
.629 .729 .92 r
.40725 .44095 .41342 .4477 .42384 .44476 .41769 .43817 Mtetra
.639 .739 .921 r
.41769 .43817 .42384 .44476 .43432 .4417 .42819 .43512 Mtetra
.64 .74 .921 r
.42819 .43512 .43432 .4417 .44483 .43874 .43873 .43205 Mtetra
.628 .733 .923 r
.43873 .43205 .44483 .43874 .45537 .4365 .44931 .42924 Mtetra
.477 .651 .936 r
.44931 .42924 .45537 .4365 .46626 .41777 .45987 .42947 Mtetra
0 0 0 r
.45987 .42947 .46626 .41777 .47669 .42596 .47069 .41819 Mtetra
.586 .684 .909 r
.47069 .41819 .47669 .42596 .48737 .42322 .48138 .41643 Mtetra
.639 .737 .919 r
.48138 .41643 .48737 .42322 .4981 .41997 .49213 .41332 Mtetra
.649 .746 .92 r
.49213 .41332 .4981 .41997 .50887 .41654 .50293 .40993 Mtetra
.653 .749 .92 r
.50293 .40993 .50887 .41654 .51969 .41302 .51377 .40641 Mtetra
.656 .751 .92 r
.51377 .40641 .51969 .41302 .53055 .40943 .52466 .40282 Mtetra
.657 .753 .92 r
.52466 .40282 .53055 .40943 .54145 .40579 .53559 .39917 Mtetra
.658 .753 .92 r
.53559 .39917 .54145 .40579 .55239 .40211 .54656 .39548 Mtetra
.659 .754 .92 r
.54656 .39548 .55239 .40211 .56338 .39842 .55758 .39176 Mtetra
.55758 .39176 .56338 .39842 .57441 .39471 .56864 .38803 Mtetra
.56864 .38803 .57441 .39471 .58549 .391 .57974 .38428 Mtetra
.57974 .38428 .58549 .391 .5966 .38728 .59089 .38053 Mtetra
.658 .753 .92 r
.59089 .38053 .5966 .38728 .60777 .38355 .60208 .37677 Mtetra
.60208 .37677 .60777 .38355 .61897 .37981 .61332 .373 Mtetra
.61332 .373 .61897 .37981 .63023 .37606 .6246 .36922 Mtetra
.6246 .36922 .63023 .37606 .64152 .37229 .63593 .36543 Mtetra
.63593 .36543 .64152 .37229 .65286 .36852 .6473 .36162 Mtetra
.6473 .36162 .65286 .36852 .66425 .36473 .65872 .35781 Mtetra
.657 .753 .92 r
.65872 .35781 .66425 .36473 .67569 .36093 .67019 .35398 Mtetra
.67019 .35398 .67569 .36093 .68717 .35712 .6817 .35013 Mtetra
.6817 .35013 .68717 .35712 .69869 .35329 .69326 .34627 Mtetra
.69326 .34627 .69869 .35329 .71027 .34945 .70487 .3424 Mtetra
.657 .752 .92 r
.70487 .3424 .71027 .34945 .72189 .34559 .71652 .33851 Mtetra
.71652 .33851 .72189 .34559 .73355 .34172 .72822 .33461 Mtetra
.72822 .33461 .73355 .34172 .74527 .33783 .73997 .3307 Mtetra
.73997 .3307 .74527 .33783 .75703 .33393 .75177 .32677 Mtetra
.75177 .32677 .75703 .33393 .76885 .33001 .76362 .32282 Mtetra
.76362 .32282 .76885 .33001 .78071 .32608 .77551 .31886 Mtetra
.77551 .31886 .78071 .32608 .79262 .32213 .78745 .31488 Mtetra
.78745 .31488 .79262 .32213 .80457 .31817 .79945 .31088 Mtetra
.79945 .31088 .80457 .31817 .81658 .31419 .81149 .30688 Mtetra
.81149 .30688 .81658 .31419 .82864 .3102 .82359 .30285 Mtetra
.722 .591 .71 r
.17977 .51123 .18542 .52777 .19654 .50992 .19014 .50095 Mtetra
.466 .583 .887 r
.19014 .50095 .19654 .50992 .20602 .50857 .1994 .50188 Mtetra
.58 .702 .926 r
.1994 .50188 .20602 .50857 .21547 .50812 .20897 .50033 Mtetra
.95 .613 .344 r
.20897 .50033 .21547 .50812 .22581 .49826 .21474 .54037 Mtetra
0 0 0 r
.21474 .54037 .22581 .49826 .2353 .4982 .22875 .4913 Mtetra
.586 .699 .921 r
.22875 .4913 .2353 .4982 .24498 .49641 .23844 .48964 Mtetra
.555 .693 .931 r
.23844 .48964 .24498 .49641 .25407 .50254 .24813 .48852 Mtetra
.747 .626 .726 r
.24813 .48852 .25407 .50254 .26494 .48712 .25866 .4776 Mtetra
.459 .567 .877 r
.25866 .4776 .26494 .48712 .27473 .48552 .26824 .4788 Mtetra
.603 .714 .922 r
.26824 .4788 .27473 .48552 .28459 .48356 .27813 .47672 Mtetra
.548 .69 .933 r
.27813 .47672 .28459 .48356 .29343 .497 .28799 .4757 Mtetra
.696 .55 .684 r
.28799 .4757 .29343 .497 .30483 .47408 .29854 .46528 Mtetra
.505 .611 .891 r
.29854 .46528 .30483 .47408 .3148 .4722 .30839 .46548 Mtetra
.613 .72 .921 r
.30839 .46548 .3148 .4722 .32485 .46986 .31846 .46314 Mtetra
.598 .715 .926 r
.31846 .46314 .32485 .46986 .33483 .46951 .32856 .46111 Mtetra
.921 .718 .611 r
.32856 .46111 .33483 .46951 .34541 .45921 .34132 .41288 Mtetra
0 0 .443 r
.34132 .41288 .34541 .45921 .35551 .45826 .3492 .45129 Mtetra
.609 .713 .918 r
.3492 .45129 .35551 .45826 .36574 .45567 .35943 .44902 Mtetra
.627 .73 .922 r
.35943 .44902 .36574 .45567 .37601 .45305 .36973 .44631 Mtetra
.609 .722 .925 r
.36973 .44631 .37601 .45305 .38626 .45205 .38005 .44399 Mtetra
.951 .599 .278 r
.38005 .44399 .38626 .45205 .39693 .44158 .38846 .48938 Mtetra
0 0 .067 r
.38846 .48938 .39693 .44158 .40725 .44095 .40105 .43384 Mtetra
.611 .712 .917 r
.40105 .43384 .40725 .44095 .41769 .43817 .4115 .43148 Mtetra
.636 .736 .92 r
.4115 .43148 .41769 .43817 .42819 .43512 .42202 .42849 Mtetra
.64 .74 .921 r
.42202 .42849 .42819 .43512 .43873 .43205 .43258 .42537 Mtetra
.636 .738 .922 r
.43258 .42537 .43873 .43205 .44931 .42924 .44319 .42234 Mtetra
.605 .72 .926 r
.44319 .42234 .44931 .42924 .45987 .42947 .45383 .42004 Mtetra
.861 .728 .714 r
.45383 .42004 .45987 .42947 .47069 .41819 .46482 .40119 Mtetra
.277 .328 .736 r
.46482 .40119 .47069 .41819 .48138 .41643 .47534 .40936 Mtetra
.626 .724 .918 r
.47534 .40936 .48138 .41643 .49213 .41332 .48612 .40656 Mtetra
.645 .742 .92 r
.48612 .40656 .49213 .41332 .50293 .40993 .49694 .40324 Mtetra
.652 .748 .92 r
.49694 .40324 .50293 .40993 .51377 .40641 .50781 .39975 Mtetra
.655 .75 .92 r
.50781 .39975 .51377 .40641 .52466 .40282 .51873 .39616 Mtetra
.657 .752 .92 r
.51873 .39616 .52466 .40282 .53559 .39917 .52969 .3925 Mtetra
.658 .753 .92 r
.52969 .3925 .53559 .39917 .54656 .39548 .54069 .38879 Mtetra
.659 .754 .92 r
.54069 .38879 .54656 .39548 .55758 .39176 .55173 .38505 Mtetra
.55173 .38505 .55758 .39176 .56864 .38803 .56282 .38129 Mtetra
.56282 .38129 .56864 .38803 .57974 .38428 .57396 .37751 Mtetra
.57396 .37751 .57974 .38428 .59089 .38053 .58514 .37373 Mtetra
.658 .753 .92 r
.58514 .37373 .59089 .38053 .60208 .37677 .59636 .36994 Mtetra
.59636 .36994 .60208 .37677 .61332 .373 .60763 .36614 Mtetra
.60763 .36614 .61332 .373 .6246 .36922 .61894 .36233 Mtetra
.61894 .36233 .6246 .36922 .63593 .36543 .6303 .35851 Mtetra
.6303 .35851 .63593 .36543 .6473 .36162 .6417 .35467 Mtetra
.6417 .35467 .6473 .36162 .65872 .35781 .65315 .35083 Mtetra
.657 .753 .92 r
.65315 .35083 .65872 .35781 .67019 .35398 .66465 .34697 Mtetra
.66465 .34697 .67019 .35398 .6817 .35013 .6762 .34309 Mtetra
.6762 .34309 .6817 .35013 .69326 .34627 .68779 .33921 Mtetra
.68779 .33921 .69326 .34627 .70487 .3424 .69943 .3353 Mtetra
.69943 .3353 .70487 .3424 .71652 .33851 .71111 .33139 Mtetra
.657 .752 .92 r
.71111 .33139 .71652 .33851 .72822 .33461 .72285 .32746 Mtetra
.72285 .32746 .72822 .33461 .73997 .3307 .73463 .32351 Mtetra
.73463 .32351 .73997 .3307 .75177 .32677 .74646 .31955 Mtetra
.74646 .31955 .75177 .32677 .76362 .32282 .75834 .31557 Mtetra
.75834 .31557 .76362 .32282 .77551 .31886 .77027 .31158 Mtetra
.77027 .31158 .77551 .31886 .78745 .31488 .78225 .30757 Mtetra
.78225 .30757 .78745 .31488 .79945 .31088 .79428 .30354 Mtetra
.79428 .30354 .79945 .31088 .81149 .30688 .80636 .2995 Mtetra
.80636 .2995 .81149 .30688 .82359 .30285 .81849 .29545 Mtetra
0 0 .505 r
.17315 .50377 .17977 .51123 .19014 .50095 .18156 .51282 Mtetra
.735 .892 .498 r
.18156 .51282 .19014 .50095 .1994 .50188 .19278 .49485 Mtetra
.573 .69 .92 r
.19278 .49485 .1994 .50188 .20897 .50033 .20233 .49345 Mtetra
.519 .675 .935 r
.20233 .49345 .20897 .50033 .21474 .54037 .21185 .49295 Mtetra
.62 .435 .61 r
.21185 .49295 .21474 .54037 .22875 .4913 .22229 .483 Mtetra
.514 .628 .901 r
.22229 .483 .22875 .4913 .23844 .48964 .23185 .48291 Mtetra
.592 .709 .925 r
.23185 .48291 .23844 .48964 .24813 .48852 .24162 .48106 Mtetra
0 .291 .783 r
.24162 .48106 .24813 .48852 .25866 .4776 .25077 .48718 Mtetra
.702 .895 .523 r
.25077 .48718 .25866 .4776 .26824 .4788 .26174 .47164 Mtetra
.584 .694 .918 r
.26174 .47164 .26824 .4788 .27813 .47672 .27161 .46999 Mtetra
.598 .714 .925 r
.27161 .46999 .27813 .47672 .28799 .4757 .28156 .46798 Mtetra
.697 .227 0 r
.28156 .46798 .28799 .4757 .29854 .46528 .29045 .48142 Mtetra
.637 .777 .319 r
.29045 .48142 .29854 .46528 .30839 .46548 .30196 .45836 Mtetra
.595 .702 .918 r
.30196 .45836 .30839 .46548 .31846 .46314 .31202 .45643 Mtetra
.614 .723 .923 r
.31202 .45643 .31846 .46314 .32856 .46111 .32216 .45403 Mtetra
.511 .671 .936 r
.32216 .45403 .32856 .46111 .34132 .41288 .33222 .45364 Mtetra
.39 .118 .376 r
.33222 .45364 .34132 .41288 .3492 .45129 .3429 .44325 Mtetra
.555 .66 .906 r
.3429 .44325 .3492 .45129 .35943 .44902 .35308 .44224 Mtetra
.623 .726 .921 r
.35308 .44224 .35943 .44902 .36973 .44631 .36339 .43959 Mtetra
.624 .729 .923 r
.36339 .43959 .36973 .44631 .38005 .44399 .37376 .43692 Mtetra
.546 .689 .933 r
.37376 .43692 .38005 .44399 .38846 .48938 .38409 .43586 Mtetra
.614 .424 .602 r
.38409 .43586 .38846 .48938 .40105 .43384 .39487 .4253 Mtetra
.542 .642 .898 r
.39487 .4253 .40105 .43384 .4115 .43148 .40527 .42462 Mtetra
.629 .729 .92 r
.40527 .42462 .4115 .43148 .42202 .42849 .41581 .42178 Mtetra
.639 .739 .921 r
.41581 .42178 .42202 .42849 .43258 .42537 .4264 .41866 Mtetra
.64 .74 .921 r
.4264 .41866 .43258 .42537 .44319 .42234 .43703 .41553 Mtetra
.628 .733 .923 r
.43703 .41553 .44319 .42234 .45383 .42004 .4477 .41266 Mtetra
.477 .651 .935 r
.4477 .41266 .45383 .42004 .46482 .40119 .45836 .41284 Mtetra
0 0 0 r
.45836 .41284 .46482 .40119 .47534 .40936 .46928 .40147 Mtetra
.586 .684 .909 r
.46928 .40147 .47534 .40936 .48612 .40656 .48006 .39965 Mtetra
.639 .737 .919 r
.48006 .39965 .48612 .40656 .49694 .40324 .49091 .39647 Mtetra
.649 .746 .92 r
.49091 .39647 .49694 .40324 .50781 .39975 .50181 .39301 Mtetra
.653 .749 .92 r
.50181 .39301 .50781 .39975 .51873 .39616 .51275 .38943 Mtetra
.656 .751 .92 r
.51275 .38943 .51873 .39616 .52969 .3925 .52374 .38577 Mtetra
.657 .753 .92 r
.52374 .38577 .52969 .3925 .54069 .38879 .53477 .38205 Mtetra
.658 .753 .92 r
.53477 .38205 .54069 .38879 .55173 .38505 .54585 .37829 Mtetra
.659 .754 .92 r
.54585 .37829 .55173 .38505 .56282 .38129 .55697 .3745 Mtetra
.55697 .3745 .56282 .38129 .57396 .37751 .56813 .3707 Mtetra
.56813 .3707 .57396 .37751 .58514 .37373 .57934 .36688 Mtetra
.57934 .36688 .58514 .37373 .59636 .36994 .59059 .36306 Mtetra
.658 .753 .92 r
.59059 .36306 .59636 .36994 .60763 .36614 .60189 .35923 Mtetra
.60189 .35923 .60763 .36614 .61894 .36233 .61323 .35539 Mtetra
.61323 .35539 .61894 .36233 .6303 .35851 .62462 .35154 Mtetra
.62462 .35154 .6303 .35851 .6417 .35467 .63606 .34767 Mtetra
.63606 .34767 .6417 .35467 .65315 .35083 .64754 .3438 Mtetra
.64754 .3438 .65315 .35083 .66465 .34697 .65907 .33991 Mtetra
.657 .753 .92 r
.65907 .33991 .66465 .34697 .6762 .34309 .67065 .336 Mtetra
.67065 .336 .6762 .34309 .68779 .33921 .68227 .33208 Mtetra
.68227 .33208 .68779 .33921 .69943 .3353 .69395 .32815 Mtetra
.69395 .32815 .69943 .3353 .71111 .33139 .70567 .32421 Mtetra
.657 .752 .92 r
.70567 .32421 .71111 .33139 .72285 .32746 .71743 .32024 Mtetra
.71743 .32024 .72285 .32746 .73463 .32351 .72925 .31627 Mtetra
.72925 .31627 .73463 .32351 .74646 .31955 .74112 .31227 Mtetra
.74112 .31227 .74646 .31955 .75834 .31557 .75303 .30827 Mtetra
.75303 .30827 .75834 .31557 .77027 .31158 .765 .30424 Mtetra
.765 .30424 .77027 .31158 .78225 .30757 .77701 .3002 Mtetra
.77701 .3002 .78225 .30757 .79428 .30354 .78908 .29615 Mtetra
.78908 .29615 .79428 .30354 .80636 .2995 .80119 .29207 Mtetra
.80119 .29207 .80636 .2995 .81849 .29545 .81336 .28798 Mtetra
.535 .682 .933 r
.16642 .49691 .17315 .50377 .18156 .51282 .17585 .49613 Mtetra
.722 .591 .71 r
.17585 .49613 .18156 .51282 .19278 .49485 .18631 .48576 Mtetra
.465 .583 .887 r
.18631 .48576 .19278 .49485 .20233 .49345 .19565 .48665 Mtetra
.58 .702 .926 r
.19565 .48665 .20233 .49345 .21185 .49295 .20529 .48505 Mtetra
.95 .612 .339 r
.20529 .48505 .21185 .49295 .22229 .483 .21105 .52522 Mtetra
0 0 0 r
.21105 .52522 .22229 .483 .23185 .48291 .22524 .47589 Mtetra
.586 .699 .921 r
.22524 .47589 .23185 .48291 .24162 .48106 .23501 .47418 Mtetra
.555 .693 .931 r
.23501 .47418 .24162 .48106 .25077 .48718 .24478 .47301 Mtetra
.747 .627 .726 r
.24478 .47301 .25077 .48718 .26174 .47164 .2554 .462 Mtetra
.458 .567 .877 r
.2554 .462 .26174 .47164 .27161 .46999 .26505 .46316 Mtetra
.603 .714 .922 r
.26505 .46316 .27161 .46999 .28156 .46798 .27502 .46102 Mtetra
.548 .69 .932 r
.27502 .46102 .28156 .46798 .29045 .48142 .28496 .45996 Mtetra
.696 .55 .684 r
.28496 .45996 .29045 .48142 .30196 .45836 .29561 .44944 Mtetra
.504 .611 .892 r
.29561 .44944 .30196 .45836 .31202 .45643 .30554 .44959 Mtetra
.613 .72 .921 r
.30554 .44959 .31202 .45643 .32216 .45403 .3157 .4472 Mtetra
.598 .715 .926 r
.3157 .4472 .32216 .45403 .33222 .45364 .32588 .44512 Mtetra
.922 .719 .61 r
.32588 .44512 .33222 .45364 .3429 .44325 .33879 .39664 Mtetra
0 0 .439 r
.33879 .39664 .3429 .44325 .35308 .44224 .3467 .43516 Mtetra
.609 .713 .918 r
.3467 .43516 .35308 .44224 .36339 .43959 .35702 .43283 Mtetra
.627 .73 .922 r
.35702 .43283 .36339 .43959 .37376 .43692 .36741 .43005 Mtetra
.609 .722 .925 r
.36741 .43005 .37376 .43692 .38409 .43586 .37782 .42768 Mtetra
.95 .598 .273 r
.37782 .42768 .38409 .43586 .39487 .4253 .38627 .47321 Mtetra
0 0 .058 r
.38627 .47321 .39487 .4253 .40527 .42462 .39901 .41739 Mtetra
.611 .712 .917 r
.39901 .41739 .40527 .42462 .41581 .42178 .40955 .41497 Mtetra
.636 .736 .92 r
.40955 .41497 .41581 .42178 .4264 .41866 .42016 .41191 Mtetra
.64 .74 .921 r
.42016 .41191 .4264 .41866 .43703 .41553 .43082 .40873 Mtetra
.636 .738 .922 r
.43082 .40873 .43703 .41553 .4477 .41266 .44152 .40564 Mtetra
.605 .72 .926 r
.44152 .40564 .4477 .41266 .45836 .41284 .45225 .40328 Mtetra
.862 .729 .714 r
.45225 .40328 .45836 .41284 .46928 .40147 .46336 .38429 Mtetra
.274 .327 .736 r
.46336 .38429 .46928 .40147 .48006 .39965 .47397 .39245 Mtetra
.626 .724 .918 r
.47397 .39245 .48006 .39965 .49091 .39647 .48484 .38959 Mtetra
.645 .742 .92 r
.48484 .38959 .49091 .39647 .50181 .39301 .49576 .3862 Mtetra
.652 .748 .92 r
.49576 .3862 .50181 .39301 .51275 .38943 .50673 .38264 Mtetra
.655 .75 .92 r
.50673 .38264 .51275 .38943 .52374 .38577 .51775 .37898 Mtetra
.657 .752 .92 r
.51775 .37898 .52374 .38577 .53477 .38205 .52881 .37525 Mtetra
.658 .753 .92 r
.52881 .37525 .53477 .38205 .54585 .37829 .53991 .37148 Mtetra
.659 .754 .92 r
.53991 .37148 .54585 .37829 .55697 .3745 .55106 .36767 Mtetra
.55106 .36767 .55697 .3745 .56813 .3707 .56226 .36383 Mtetra
.56226 .36383 .56813 .3707 .57934 .36688 .57349 .35999 Mtetra
.57349 .35999 .57934 .36688 .59059 .36306 .58478 .35613 Mtetra
.658 .753 .92 r
.58478 .35613 .59059 .36306 .60189 .35923 .59611 .35227 Mtetra
.59611 .35227 .60189 .35923 .61323 .35539 .60748 .3484 Mtetra
.60748 .3484 .61323 .35539 .62462 .35154 .6189 .34451 Mtetra
.6189 .34451 .62462 .35154 .63606 .34767 .63037 .34062 Mtetra
.63037 .34062 .63606 .34767 .64754 .3438 .64189 .33671 Mtetra
.64189 .33671 .64754 .3438 .65907 .33991 .65345 .33279 Mtetra
.657 .753 .92 r
.65345 .33279 .65907 .33991 .67065 .336 .66506 .32886 Mtetra
.66506 .32886 .67065 .336 .68227 .33208 .67672 .32491 Mtetra
.67672 .32491 .68227 .33208 .69395 .32815 .68842 .32095 Mtetra
.68842 .32095 .69395 .32815 .70567 .32421 .70018 .31697 Mtetra
.70018 .31697 .70567 .32421 .71743 .32024 .71198 .31298 Mtetra
.657 .752 .92 r
.71198 .31298 .71743 .32024 .72925 .31627 .72383 .30897 Mtetra
.72383 .30897 .72925 .31627 .74112 .31227 .73573 .30494 Mtetra
.73573 .30494 .74112 .31227 .75303 .30827 .74768 .3009 Mtetra
.74768 .3009 .75303 .30827 .765 .30424 .75968 .29685 Mtetra
.75968 .29685 .765 .30424 .77701 .3002 .77173 .29278 Mtetra
.77173 .29278 .77701 .3002 .78908 .29615 .78383 .28869 Mtetra
.78383 .28869 .78908 .29615 .80119 .29207 .79598 .28459 Mtetra
.79598 .28459 .80119 .29207 .81336 .28798 .80819 .28047 Mtetra
.572 .695 .925 r
.15965 .48999 .16642 .49691 .17585 .49613 .16916 .48855 Mtetra
0 0 .512 r
.16916 .48855 .17585 .49613 .18631 .48576 .17762 .4976 Mtetra
.743 .897 .506 r
.17762 .4976 .18631 .48576 .19565 .48665 .18895 .47951 Mtetra
.573 .69 .92 r
.18895 .47951 .19565 .48665 .20529 .48505 .19858 .47806 Mtetra
.519 .675 .935 r
.19858 .47806 .20529 .48505 .21105 .52522 .20818 .47751 Mtetra
.619 .434 .609 r
.20818 .47751 .21105 .52522 .22524 .47589 .21871 .46748 Mtetra
.514 .628 .901 r
.21871 .46748 .22524 .47589 .23501 .47418 .22834 .46733 Mtetra
.592 .709 .925 r
.22834 .46733 .23501 .47418 .24478 .47301 .23819 .46544 Mtetra
0 .294 .786 r
.23819 .46544 .24478 .47301 .2554 .462 .24741 .47153 Mtetra
.71 .901 .532 r
.24741 .47153 .2554 .462 .26505 .46316 .25849 .45589 Mtetra
.584 .694 .918 r
.25849 .45589 .26505 .46316 .27502 .46102 .26844 .45418 Mtetra
.598 .714 .925 r
.26844 .45418 .27502 .46102 .28496 .45996 .27846 .45212 Mtetra
.69 .221 0 r
.27846 .45212 .28496 .45996 .29561 .44944 .28742 .46557 Mtetra
.646 .785 .329 r
.28742 .46557 .29561 .44944 .30554 .44959 .29905 .44236 Mtetra
.595 .702 .918 r
.29905 .44236 .30554 .44959 .3157 .4472 .30919 .44037 Mtetra
.614 .723 .923 r
.30919 .44037 .3157 .4472 .32588 .44512 .31941 .43792 Mtetra
.511 .671 .935 r
.31941 .43792 .32588 .44512 .33879 .39664 .32956 .43748 Mtetra
.384 .11 .369 r
.32956 .43748 .33879 .39664 .3467 .43516 .34034 .427 Mtetra
.555 .66 .906 r
.34034 .427 .3467 .43516 .35702 .43283 .3506 .42593 Mtetra
.623 .726 .921 r
.3506 .42593 .35702 .43283 .36741 .43005 .36101 .42322 Mtetra
.624 .729 .923 r
.36101 .42322 .36741 .43005 .37782 .42768 .37146 .42049 Mtetra
.547 .689 .933 r
.37146 .42049 .37782 .42768 .38627 .47321 .38189 .41938 Mtetra
.612 .422 .6 r
.38189 .41938 .38627 .47321 .39901 .41739 .39276 .40872 Mtetra
.541 .642 .898 r
.39276 .40872 .39901 .41739 .40955 .41497 .40325 .40799 Mtetra
.629 .729 .92 r
.40325 .40799 .40955 .41497 .42016 .41191 .41388 .40509 Mtetra
.639 .739 .921 r
.41388 .40509 .42016 .41191 .43082 .40873 .42457 .40191 Mtetra
.64 .74 .921 r
.42457 .40191 .43082 .40873 .44152 .40564 .4353 .39871 Mtetra
.628 .733 .923 r
.4353 .39871 .44152 .40564 .45225 .40328 .44607 .39577 Mtetra
.478 .651 .935 r
.44607 .39577 .45225 .40328 .46336 .38429 .45682 .3959 Mtetra
0 0 0 r
.45682 .3959 .46336 .38429 .47397 .39245 .46784 .38443 Mtetra
.586 .684 .909 r
.46784 .38443 .47397 .39245 .48484 .38959 .47872 .38255 Mtetra
.639 .737 .919 r
.47872 .38255 .48484 .38959 .49576 .3862 .48967 .3793 Mtetra
.649 .746 .92 r
.48967 .3793 .49576 .3862 .50673 .38264 .50067 .37577 Mtetra
.653 .749 .92 r
.50067 .37577 .50673 .38264 .51775 .37898 .51171 .37213 Mtetra
.656 .751 .92 r
.51171 .37213 .51775 .37898 .52881 .37525 .5228 .3684 Mtetra
.657 .753 .92 r
.5228 .3684 .52881 .37525 .53991 .37148 .53394 .36461 Mtetra
.658 .753 .92 r
.53394 .36461 .53991 .37148 .55106 .36767 .54512 .36078 Mtetra
.659 .754 .92 r
.54512 .36078 .55106 .36767 .56226 .36383 .55634 .35692 Mtetra
.55634 .35692 .56226 .36383 .57349 .35999 .56761 .35304 Mtetra
.56761 .35304 .57349 .35999 .58478 .35613 .57892 .34915 Mtetra
.57892 .34915 .58478 .35613 .59611 .35227 .59028 .34526 Mtetra
.658 .753 .92 r
.59028 .34526 .59611 .35227 .60748 .3484 .60169 .34135 Mtetra
.60169 .34135 .60748 .3484 .6189 .34451 .61314 .33744 Mtetra
.61314 .33744 .6189 .34451 .63037 .34062 .62464 .33351 Mtetra
.62464 .33351 .63037 .34062 .64189 .33671 .63619 .32957 Mtetra
.63619 .32957 .64189 .33671 .65345 .33279 .64778 .32562 Mtetra
.64778 .32562 .65345 .33279 .66506 .32886 .65943 .32166 Mtetra
.657 .753 .92 r
.65943 .32166 .66506 .32886 .67672 .32491 .67112 .31768 Mtetra
.67112 .31768 .67672 .32491 .68842 .32095 .68286 .31369 Mtetra
.68286 .31369 .68842 .32095 .70018 .31697 .69464 .30968 Mtetra
.69464 .30968 .70018 .31697 .71198 .31298 .70648 .30565 Mtetra
.657 .752 .92 r
.70648 .30565 .71198 .31298 .72383 .30897 .71837 .30161 Mtetra
.71837 .30161 .72383 .30897 .73573 .30494 .7303 .29756 Mtetra
.7303 .29756 .73573 .30494 .74768 .3009 .74229 .29349 Mtetra
.74229 .29349 .74768 .3009 .75968 .29685 .75432 .2894 Mtetra
.75432 .2894 .75968 .29685 .77173 .29278 .76641 .2853 Mtetra
.76641 .2853 .77173 .29278 .78383 .28869 .77855 .28118 Mtetra
.77855 .28118 .78383 .28869 .79598 .28459 .79073 .27704 Mtetra
.79073 .27704 .79598 .28459 .80819 .28047 .80297 .27289 Mtetra
.535 .656 .913 r
.15292 .48225 .15965 .48999 .16916 .48855 .16235 .48158 Mtetra
.535 .682 .933 r
.16235 .48158 .16916 .48855 .17762 .4976 .17186 .48076 Mtetra
.722 .592 .71 r
.17186 .48076 .17762 .4976 .18895 .47951 .18242 .4703 Mtetra
.465 .582 .887 r
.18242 .4703 .18895 .47951 .19858 .47806 .19182 .47115 Mtetra
.58 .702 .926 r
.19182 .47115 .19858 .47806 .20818 .47751 .20154 .46949 Mtetra
.95 .611 .335 r
.20154 .46949 .20818 .47751 .21871 .46748 .2073 .50979 Mtetra
0 0 0 r
.2073 .50979 .21871 .46748 .22834 .46733 .22166 .4602 Mtetra
.586 .699 .921 r
.22166 .4602 .22834 .46733 .23819 .46544 .23151 .45844 Mtetra
.556 .693 .931 r
.23151 .45844 .23819 .46544 .24741 .47153 .24136 .45722 Mtetra
.747 .627 .727 r
.24136 .45722 .24741 .47153 .25849 .45589 .25208 .44612 Mtetra
.458 .567 .877 r
.25208 .44612 .25849 .45589 .26844 .45418 .26181 .44724 Mtetra
.603 .714 .922 r
.26181 .44724 .26844 .45418 .27846 .45212 .27186 .44504 Mtetra
.548 .69 .932 r
.27186 .44504 .27846 .45212 .28742 .46557 .28188 .44392 Mtetra
.696 .55 .684 r
.28188 .44392 .28742 .46557 .29905 .44236 .29263 .43332 Mtetra
.504 .611 .892 r
.29263 .43332 .29905 .44236 .30919 .44037 .30264 .43342 Mtetra
.613 .72 .921 r
.30264 .43342 .30919 .44037 .31941 .43792 .31289 .43097 Mtetra
.598 .715 .926 r
.31289 .43097 .31941 .43792 .32956 .43748 .32315 .42883 Mtetra
.924 .719 .608 r
.32315 .42883 .32956 .43748 .34034 .427 .33621 .3801 Mtetra
0 0 .435 r
.33621 .3801 .34034 .427 .3506 .42593 .34416 .41873 Mtetra
.609 .713 .919 r
.34416 .41873 .3506 .42593 .36101 .42322 .35457 .41634 Mtetra
.627 .73 .922 r
.35457 .41634 .36101 .42322 .37146 .42049 .36504 .4135 Mtetra
.609 .722 .925 r
.36504 .4135 .37146 .42049 .38189 .41938 .37555 .41107 Mtetra
.95 .596 .267 r
.37555 .41107 .38189 .41938 .39276 .40872 .38404 .45674 Mtetra
0 0 .05 r
.38404 .45674 .39276 .40872 .40325 .40799 .39693 .40063 Mtetra
.611 .712 .917 r
.39693 .40063 .40325 .40799 .41388 .40509 .40756 .39815 Mtetra
.636 .736 .92 r
.40756 .39815 .41388 .40509 .42457 .40191 .41827 .39503 Mtetra
.64 .74 .921 r
.41827 .39503 .42457 .40191 .4353 .39871 .42902 .39178 Mtetra
.636 .738 .922 r
.42902 .39178 .4353 .39871 .44607 .39577 .43982 .38862 Mtetra
.605 .72 .926 r
.43982 .38862 .44607 .39577 .45682 .3959 .45065 .3862 Mtetra
.863 .729 .714 r
.45065 .3862 .45682 .3959 .46784 .38443 .46186 .36709 Mtetra
.272 .325 .735 r
.46186 .36709 .46784 .38443 .47872 .38255 .47256 .37522 Mtetra
.626 .724 .918 r
.47256 .37522 .47872 .38255 .48967 .3793 .48353 .37229 Mtetra
.645 .742 .92 r
.48353 .37229 .48967 .3793 .50067 .37577 .49456 .36883 Mtetra
.652 .748 .92 r
.49456 .36883 .50067 .37577 .51171 .37213 .50563 .3652 Mtetra
.655 .75 .92 r
.50563 .3652 .51171 .37213 .5228 .3684 .51675 .36148 Mtetra
.657 .752 .92 r
.51675 .36148 .5228 .3684 .53394 .36461 .52791 .35768 Mtetra
.658 .753 .92 r
.52791 .35768 .53394 .36461 .54512 .36078 .53912 .35383 Mtetra
.659 .754 .92 r
.53912 .35383 .54512 .36078 .55634 .35692 .55038 .34995 Mtetra
.55038 .34995 .55634 .35692 .56761 .35304 .56168 .34604 Mtetra
.56168 .34604 .56761 .35304 .57892 .34915 .57302 .34212 Mtetra
.57302 .34212 .57892 .34915 .59028 .34526 .58441 .33819 Mtetra
.658 .753 .92 r
.58441 .33819 .59028 .34526 .60169 .34135 .59585 .33426 Mtetra
.59585 .33426 .60169 .34135 .61314 .33744 .60734 .33031 Mtetra
.60734 .33031 .61314 .33744 .62464 .33351 .61887 .32635 Mtetra
.61887 .32635 .62464 .33351 .63619 .32957 .63045 .32238 Mtetra
.63045 .32238 .63619 .32957 .64778 .32562 .64208 .3184 Mtetra
.64208 .3184 .64778 .32562 .65943 .32166 .65375 .3144 Mtetra
.657 .753 .92 r
.65375 .3144 .65943 .32166 .67112 .31768 .66547 .31039 Mtetra
.66547 .31039 .67112 .31768 .68286 .31369 .67725 .30637 Mtetra
.67725 .30637 .68286 .31369 .69464 .30968 .68907 .30233 Mtetra
.68907 .30233 .69464 .30968 .70648 .30565 .70094 .29827 Mtetra
.70094 .29827 .70648 .30565 .71837 .30161 .71286 .2942 Mtetra
.657 .752 .92 r
.71286 .2942 .71837 .30161 .7303 .29756 .72483 .29012 Mtetra
.72483 .29012 .7303 .29756 .74229 .29349 .73685 .28601 Mtetra
.73685 .28601 .74229 .29349 .75432 .2894 .74892 .28189 Mtetra
.74892 .28189 .75432 .2894 .76641 .2853 .76104 .27776 Mtetra
.76104 .27776 .76641 .2853 .77855 .28118 .77322 .2736 Mtetra
.77322 .2736 .77855 .28118 .79073 .27704 .78544 .26944 Mtetra
.78544 .26944 .79073 .27704 .80297 .27289 .79772 .26525 Mtetra
0 .064 .582 r
.14781 .45998 .15292 .48225 .16235 .48158 .15551 .47455 Mtetra
.572 .695 .925 r
.15551 .47455 .16235 .48158 .17186 .48076 .1651 .47306 Mtetra
0 0 .519 r
.1651 .47306 .17186 .48076 .18242 .4703 .17361 .4821 Mtetra
.75 .902 .515 r
.17361 .4821 .18242 .4703 .19182 .47115 .18505 .46389 Mtetra
.573 .69 .92 r
.18505 .46389 .19182 .47115 .20154 .46949 .19476 .46239 Mtetra
.519 .675 .935 r
.19476 .46239 .20154 .46949 .2073 .50979 .20444 .4618 Mtetra
.618 .432 .608 r
.20444 .4618 .2073 .50979 .22166 .4602 .21506 .45167 Mtetra
.513 .628 .901 r
.21506 .45167 .22166 .4602 .23151 .45844 .22477 .45148 Mtetra
.592 .709 .925 r
.22477 .45148 .23151 .45844 .24136 .45722 .2347 .44953 Mtetra
0 .298 .789 r
.2347 .44953 .24136 .45722 .25208 .44612 .24399 .4556 Mtetra
.718 .906 .54 r
.24399 .4556 .25208 .44612 .26181 .44724 .25517 .43984 Mtetra
.584 .694 .918 r
.25517 .43984 .26181 .44724 .27186 .44504 .2652 .43808 Mtetra
.598 .714 .925 r
.2652 .43808 .27186 .44504 .28188 .44392 .27532 .43596 Mtetra
.683 .215 0 r
.27532 .43596 .28188 .44392 .29263 .43332 .28433 .44942 Mtetra
.655 .793 .338 r
.28433 .44942 .29263 .43332 .30264 .43342 .29608 .42607 Mtetra
.595 .702 .918 r
.29608 .42607 .30264 .43342 .31289 .43097 .30631 .42402 Mtetra
.614 .723 .923 r
.30631 .42402 .31289 .43097 .32315 .42883 .31662 .42151 Mtetra
.511 .671 .935 r
.31662 .42151 .32315 .42883 .33621 .3801 .32685 .42101 Mtetra
.378 .101 .362 r
.32685 .42101 .33621 .3801 .34416 .41873 .33773 .41044 Mtetra
.555 .66 .906 r
.33773 .41044 .34416 .41873 .35457 .41634 .34808 .40932 Mtetra
.623 .726 .921 r
.34808 .40932 .35457 .41634 .36504 .4135 .35858 .40655 Mtetra
.624 .729 .923 r
.35858 .40655 .36504 .4135 .37555 .41107 .36912 .40375 Mtetra
.547 .689 .932 r
.36912 .40375 .37555 .41107 .38404 .45674 .37964 .40259 Mtetra
.611 .42 .599 r
.37964 .40259 .38404 .45674 .39693 .40063 .39061 .39183 Mtetra
.541 .642 .898 r
.39061 .39183 .39693 .40063 .40756 .39815 .4012 .39105 Mtetra
.629 .729 .92 r
.4012 .39105 .40756 .39815 .41827 .39503 .41193 .38808 Mtetra
.639 .739 .921 r
.41193 .38808 .41827 .39503 .42902 .39178 .42271 .38483 Mtetra
.64 .74 .921 r
.42271 .38483 .42902 .39178 .43982 .38862 .43353 .38156 Mtetra
.628 .733 .923 r
.43353 .38156 .43982 .38862 .45065 .3862 .4444 .37857 Mtetra
.479 .651 .935 r
.4444 .37857 .45065 .3862 .46186 .36709 .45525 .37864 Mtetra
0 0 0 r
.45525 .37864 .46186 .36709 .47256 .37522 .46638 .36707 Mtetra
.586 .684 .909 r
.46638 .36707 .47256 .37522 .48353 .37229 .47736 .36512 Mtetra
.639 .737 .919 r
.47736 .36512 .48353 .37229 .49456 .36883 .48841 .3618 Mtetra
.649 .746 .92 r
.48841 .3618 .49456 .36883 .50563 .3652 .49951 .35821 Mtetra
.653 .749 .92 r
.49951 .35821 .50563 .3652 .51675 .36148 .51065 .35449 Mtetra
.656 .751 .92 r
.51065 .35449 .51675 .36148 .52791 .35768 .52185 .35069 Mtetra
.657 .753 .92 r
.52185 .35069 .52791 .35768 .53912 .35383 .53309 .34683 Mtetra
.658 .753 .92 r
.53309 .34683 .53912 .35383 .55038 .34995 .54437 .34292 Mtetra
.659 .754 .92 r
.54437 .34292 .55038 .34995 .56168 .34604 .5557 .33899 Mtetra
.5557 .33899 .56168 .34604 .57302 .34212 .56708 .33504 Mtetra
.56708 .33504 .57302 .34212 .58441 .33819 .5785 .33108 Mtetra
.5785 .33108 .58441 .33819 .59585 .33426 .58997 .32711 Mtetra
.658 .753 .92 r
.58997 .32711 .59585 .33426 .60734 .33031 .60149 .32313 Mtetra
.60149 .32313 .60734 .33031 .61887 .32635 .61305 .31914 Mtetra
.61305 .31914 .61887 .32635 .63045 .32238 .62466 .31514 Mtetra
.62466 .31514 .63045 .32238 .64208 .3184 .63632 .31112 Mtetra
.63632 .31112 .64208 .3184 .65375 .3144 .64803 .3071 Mtetra
.64803 .3071 .65375 .3144 .66547 .31039 .65979 .30305 Mtetra
.657 .753 .92 r
.65979 .30305 .66547 .31039 .67725 .30637 .67159 .299 Mtetra
.67159 .299 .67725 .30637 .68907 .30233 .68345 .29492 Mtetra
.68345 .29492 .68907 .30233 .70094 .29827 .69536 .29084 Mtetra
.69536 .29084 .70094 .29827 .71286 .2942 .70731 .28673 Mtetra
.657 .752 .92 r
.70731 .28673 .71286 .2942 .72483 .29012 .71932 .28261 Mtetra
.71932 .28261 .72483 .29012 .73685 .28601 .73137 .27848 Mtetra
.73137 .27848 .73685 .28601 .74892 .28189 .74348 .27433 Mtetra
.74348 .27433 .74892 .28189 .76104 .27776 .75564 .27016 Mtetra
.75564 .27016 .76104 .27776 .77322 .2736 .76785 .26597 Mtetra
.76785 .26597 .77322 .2736 .78544 .26944 .78011 .26177 Mtetra
.78011 .26177 .78544 .26944 .79772 .26525 .79242 .25755 Mtetra
.038 0 .018 r
.13814 .47684 .14781 .45998 .15551 .47455 .14871 .46669 Mtetra
.535 .656 .913 r
.14871 .46669 .15551 .47455 .1651 .47306 .15822 .46598 Mtetra
.535 .682 .933 r
.15822 .46598 .1651 .47306 .17361 .4821 .1678 .46511 Mtetra
.722 .592 .71 r
.1678 .46511 .17361 .4821 .18505 .46389 .17845 .45456 Mtetra
.464 .582 .887 r
.17845 .45456 .18505 .46389 .19476 .46239 .18793 .45536 Mtetra
.58 .702 .926 r
.18793 .45536 .19476 .46239 .20444 .4618 .19773 .45366 Mtetra
.95 .61 .33 r
.19773 .45366 .20444 .4618 .21506 .45167 .20348 .49408 Mtetra
0 0 0 r
.20348 .49408 .21506 .45167 .22477 .45148 .21802 .44423 Mtetra
.585 .699 .921 r
.21802 .44423 .22477 .45148 .2347 .44953 .22795 .44242 Mtetra
.556 .693 .931 r
.22795 .44242 .2347 .44953 .24399 .4556 .23787 .44114 Mtetra
.747 .628 .727 r
.23787 .44114 .24399 .4556 .25517 .43984 .2487 .42994 Mtetra
.457 .566 .877 r
.2487 .42994 .25517 .43984 .2652 .43808 .25851 .43102 Mtetra
.603 .714 .922 r
.25851 .43102 .2652 .43808 .27532 .43596 .26864 .42876 Mtetra
.549 .69 .932 r
.26864 .42876 .27532 .43596 .28433 .44942 .27875 .42759 Mtetra
.696 .55 .684 r
.27875 .42759 .28433 .44942 .29608 .42607 .28959 .4169 Mtetra
.504 .611 .892 r
.28959 .4169 .29608 .42607 .30631 .42402 .29969 .41695 Mtetra
.613 .72 .921 r
.29969 .41695 .30631 .42402 .31662 .42151 .31002 .41444 Mtetra
.598 .715 .926 r
.31002 .41444 .31662 .42151 .32685 .42101 .32038 .41223 Mtetra
.925 .72 .607 r
.32038 .41223 .32685 .42101 .33773 .41044 .33359 .36327 Mtetra
0 0 .431 r
.33359 .36327 .33773 .41044 .34808 .40932 .34157 .40199 Mtetra
.609 .713 .919 r
.34157 .40199 .34808 .40932 .35858 .40655 .35207 .39954 Mtetra
.627 .73 .922 r
.35207 .39954 .35858 .40655 .36912 .40375 .36264 .39664 Mtetra
.609 .722 .925 r
.36264 .39664 .36912 .40375 .37964 .40259 .37324 .39414 Mtetra
.949 .594 .26 r
.37324 .39414 .37964 .40259 .39061 .39183 .38176 .43996 Mtetra
0 0 .042 r
.38176 .43996 .39061 .39183 .4012 .39105 .39481 .38356 Mtetra
.611 .712 .917 r
.39481 .38356 .4012 .39105 .41193 .38808 .40554 .38102 Mtetra
.636 .736 .92 r
.40554 .38102 .41193 .38808 .42271 .38483 .41634 .37783 Mtetra
.64 .74 .921 r
.41634 .37783 .42271 .38483 .43353 .38156 .42719 .37451 Mtetra
.636 .738 .922 r
.42719 .37451 .43353 .38156 .4444 .37857 .43809 .37129 Mtetra
.605 .72 .926 r
.43809 .37129 .4444 .37857 .45525 .37864 .44902 .3688 Mtetra
.864 .73 .714 r
.44902 .3688 .45525 .37864 .46638 .36707 .46034 .34955 Mtetra
.27 .324 .735 r
.46034 .34955 .46638 .36707 .47736 .36512 .47113 .35767 Mtetra
.626 .724 .918 r
.47113 .35767 .47736 .36512 .48841 .3618 .48221 .35466 Mtetra
.645 .742 .92 r
.48221 .35466 .48841 .3618 .49951 .35821 .49333 .35114 Mtetra
.652 .748 .92 r
.49333 .35114 .49951 .35821 .51065 .35449 .50451 .34744 Mtetra
.655 .75 .92 r
.50451 .34744 .51065 .35449 .52185 .35069 .51573 .34364 Mtetra
.657 .752 .92 r
.51573 .34364 .52185 .35069 .53309 .34683 .527 .33976 Mtetra
.658 .753 .92 r
.527 .33976 .53309 .34683 .54437 .34292 .53832 .33584 Mtetra
.659 .754 .92 r
.53832 .33584 .54437 .34292 .5557 .33899 .54968 .33189 Mtetra
.54968 .33189 .5557 .33899 .56708 .33504 .56109 .32791 Mtetra
.56109 .32791 .56708 .33504 .5785 .33108 .57254 .32391 Mtetra
.57254 .32391 .5785 .33108 .58997 .32711 .58404 .31991 Mtetra
.658 .753 .92 r
.58404 .31991 .58997 .32711 .60149 .32313 .59559 .3159 Mtetra
.59559 .3159 .60149 .32313 .61305 .31914 .60719 .31187 Mtetra
.60719 .31187 .61305 .31914 .62466 .31514 .61883 .30784 Mtetra
.61883 .30784 .62466 .31514 .63632 .31112 .63053 .30379 Mtetra
.63053 .30379 .63632 .31112 .64803 .3071 .64227 .29973 Mtetra
.64227 .29973 .64803 .3071 .65979 .30305 .65406 .29566 Mtetra
.657 .753 .92 r
.65406 .29566 .65979 .30305 .67159 .299 .6659 .29157 Mtetra
.6659 .29157 .67159 .299 .68345 .29492 .67779 .28746 Mtetra
.67779 .28746 .68345 .29492 .69536 .29084 .68973 .28334 Mtetra
.68973 .28334 .69536 .29084 .70731 .28673 .70172 .27921 Mtetra
.70172 .27921 .70731 .28673 .71932 .28261 .71376 .27505 Mtetra
.657 .752 .92 r
.71376 .27505 .71932 .28261 .73137 .27848 .72585 .27089 Mtetra
.72585 .27089 .73137 .27848 .74348 .27433 .73799 .2667 Mtetra
.73799 .2667 .74348 .27433 .75564 .27016 .75019 .2625 Mtetra
.75019 .2625 .75564 .27016 .76785 .26597 .76243 .25828 Mtetra
.76243 .25828 .76785 .26597 .78011 .26177 .77473 .25405 Mtetra
.77473 .25405 .78011 .26177 .79242 .25755 .78708 .24979 Mtetra
.866 .713 .69 r
.1314 .46791 .13814 .47684 .14871 .46669 .14357 .44425 Mtetra
0 .06 .579 r
.14357 .44425 .14871 .46669 .15822 .46598 .1513 .45883 Mtetra
.572 .695 .925 r
.1513 .45883 .15822 .46598 .1678 .46511 .16096 .4573 Mtetra
0 .002 .525 r
.16096 .4573 .1678 .46511 .17845 .45456 .16953 .46633 Mtetra
.758 .907 .523 r
.16953 .46633 .17845 .45456 .18793 .45536 .18109 .44799 Mtetra
.573 .69 .92 r
.18109 .44799 .18793 .45536 .19773 .45366 .19088 .44644 Mtetra
.519 .675 .935 r
.19088 .44644 .19773 .45366 .20348 .49408 .20062 .44579 Mtetra
.617 .43 .606 r
.20062 .44579 .20348 .49408 .21802 .44423 .21135 .43558 Mtetra
.513 .628 .902 r
.21135 .43558 .21802 .44423 .22795 .44242 .22114 .43534 Mtetra
.592 .709 .925 r
.22114 .43534 .22795 .44242 .23787 .44114 .23115 .43333 Mtetra
0 .301 .791 r
.23115 .43333 .23787 .44114 .2487 .42994 .2405 .43938 Mtetra
.726 .912 .549 r
.2405 .43938 .2487 .42994 .25851 .43102 .25179 .42351 Mtetra
.583 .694 .918 r
.25179 .42351 .25851 .43102 .26864 .42876 .26191 .42169 Mtetra
.598 .714 .925 r
.26191 .42169 .26864 .42876 .27875 .42759 .27211 .41951 Mtetra
.676 .208 0 r
.27211 .41951 .27875 .42759 .28959 .4169 .28118 .43298 Mtetra
.665 .8 .348 r
.28118 .43298 .28959 .4169 .29969 .41695 .29305 .40948 Mtetra
.595 .702 .918 r
.29305 .40948 .29969 .41695 .31002 .41444 .30337 .40737 Mtetra
.614 .723 .923 r
.30337 .40737 .31002 .41444 .32038 .41223 .31377 .40479 Mtetra
.512 .671 .935 r
.31377 .40479 .32038 .41223 .33359 .36327 .32409 .40424 Mtetra
.371 .093 .355 r
.32409 .40424 .33359 .36327 .34157 .40199 .33507 .39357 Mtetra
.555 .66 .906 r
.33507 .39357 .34157 .40199 .35207 .39954 .34551 .3924 Mtetra
.623 .726 .921 r
.34551 .3924 .35207 .39954 .36264 .39664 .3561 .38956 Mtetra
.624 .729 .923 r
.3561 .38956 .36264 .39664 .37324 .39414 .36674 .3867 Mtetra
.547 .689 .932 r
.36674 .3867 .37324 .39414 .38176 .43996 .37735 .38548 Mtetra
.61 .418 .597 r
.37735 .38548 .38176 .43996 .39481 .38356 .38843 .37463 Mtetra
.541 .642 .899 r
.38843 .37463 .39481 .38356 .40554 .38102 .39911 .37378 Mtetra
.629 .729 .92 r
.39911 .37378 .40554 .38102 .41634 .37783 .40993 .37075 Mtetra
.639 .739 .921 r
.40993 .37075 .41634 .37783 .42719 .37451 .42081 .36743 Mtetra
.64 .74 .921 r
.42081 .36743 .42719 .37451 .43809 .37129 .43173 .3641 Mtetra
.628 .733 .923 r
.43173 .3641 .43809 .37129 .44902 .3688 .4427 .36103 Mtetra
.479 .651 .935 r
.4427 .36103 .44902 .3688 .46034 .34955 .45365 .36105 Mtetra
0 0 0 r
.45365 .36105 .46034 .34955 .47113 .35767 .46488 .34937 Mtetra
.586 .685 .909 r
.46488 .34937 .47113 .35767 .48221 .35466 .47596 .34736 Mtetra
.639 .737 .919 r
.47596 .34736 .48221 .35466 .49333 .35114 .48712 .34397 Mtetra
.649 .746 .92 r
.48712 .34397 .49333 .35114 .50451 .34744 .49832 .34031 Mtetra
.653 .749 .92 r
.49832 .34031 .50451 .34744 .51573 .34364 .50957 .33651 Mtetra
.656 .751 .92 r
.50957 .33651 .51573 .34364 .527 .33976 .52087 .33264 Mtetra
.657 .753 .92 r
.52087 .33264 .527 .33976 .53832 .33584 .53222 .3287 Mtetra
.658 .753 .92 r
.53222 .3287 .53832 .33584 .54968 .33189 .54361 .32472 Mtetra
.659 .754 .92 r
.54361 .32472 .54968 .33189 .56109 .32791 .55505 .32072 Mtetra
.55505 .32072 .56109 .32791 .57254 .32391 .56654 .31669 Mtetra
.56654 .31669 .57254 .32391 .58404 .31991 .57807 .31265 Mtetra
.57807 .31265 .58404 .31991 .59559 .3159 .58965 .30861 Mtetra
.658 .753 .92 r
.58965 .30861 .59559 .3159 .60719 .31187 .60128 .30455 Mtetra
.60128 .30455 .60719 .31187 .61883 .30784 .61296 .30048 Mtetra
.61296 .30048 .61883 .30784 .63053 .30379 .62468 .2964 Mtetra
.62468 .2964 .63053 .30379 .64227 .29973 .63646 .29231 Mtetra
.63646 .29231 .64227 .29973 .65406 .29566 .64828 .2882 Mtetra
.64828 .2882 .65406 .29566 .6659 .29157 .66016 .28408 Mtetra
.657 .753 .92 r
.66016 .28408 .6659 .29157 .67779 .28746 .67208 .27994 Mtetra
.67208 .27994 .67779 .28746 .68973 .28334 .68406 .27579 Mtetra
.68406 .27579 .68973 .28334 .70172 .27921 .69608 .27162 Mtetra
.69608 .27162 .70172 .27921 .71376 .27505 .70816 .26744 Mtetra
.657 .752 .92 r
.70816 .26744 .71376 .27505 .72585 .27089 .72028 .26323 Mtetra
.72028 .26323 .72585 .27089 .73799 .2667 .73246 .25902 Mtetra
.73246 .25902 .73799 .2667 .75019 .2625 .74469 .25478 Mtetra
.74469 .25478 .75019 .2625 .76243 .25828 .75698 .25053 Mtetra
.75698 .25053 .76243 .25828 .77473 .25405 .76931 .24626 Mtetra
.76931 .24626 .77473 .25405 .78708 .24979 .7817 .24197 Mtetra
.439 .635 .938 r
.12441 .46057 .1314 .46791 .14357 .44425 .13376 .46109 Mtetra
.024 0 .003 r
.13376 .46109 .14357 .44425 .1513 .45883 .14442 .45086 Mtetra
.535 .656 .913 r
.14442 .45086 .1513 .45883 .16096 .4573 .15401 .4501 Mtetra
.536 .682 .933 r
.15401 .4501 .16096 .4573 .16953 .46633 .16366 .44917 Mtetra
.722 .592 .71 r
.16366 .44917 .16953 .46633 .18109 .44799 .17441 .43853 Mtetra
.464 .582 .888 r
.17441 .43853 .18109 .44799 .19088 .44644 .18397 .43929 Mtetra
.58 .702 .926 r
.18397 .43929 .19088 .44644 .20062 .44579 .19384 .43753 Mtetra
.95 .608 .326 r
.19384 .43753 .20062 .44579 .21135 .43558 .19959 .47808 Mtetra
0 0 0 r
.19959 .47808 .21135 .43558 .22114 .43534 .21431 .42797 Mtetra
.585 .699 .921 r
.21431 .42797 .22114 .43534 .23115 .43333 .22432 .4261 Mtetra
.556 .693 .931 r
.22432 .4261 .23115 .43333 .2405 .43938 .23433 .42476 Mtetra
.748 .628 .727 r
.23433 .42476 .2405 .43938 .25179 .42351 .24525 .41347 Mtetra
.457 .566 .877 r
.24525 .41347 .25179 .42351 .26191 .42169 .25514 .4145 Mtetra
.603 .714 .922 r
.25514 .4145 .26191 .42169 .27211 .41951 .26536 .41219 Mtetra
.549 .69 .932 r
.26536 .41219 .27211 .41951 .28118 .43298 .27555 .41096 Mtetra
.696 .549 .684 r
.27555 .41096 .28118 .43298 .29305 .40948 .2865 .40017 Mtetra
.503 .611 .892 r
.2865 .40017 .29305 .40948 .30337 .40737 .29668 .40017 Mtetra
.613 .72 .921 r
.29668 .40017 .30337 .40737 .31377 .40479 .3071 .39759 Mtetra
.598 .715 .926 r
.3071 .39759 .31377 .40479 .32409 .40424 .31755 .39533 Mtetra
.926 .721 .606 r
.31755 .39533 .32409 .40424 .33507 .39357 .33092 .34612 Mtetra
0 0 .427 r
.33092 .34612 .33507 .39357 .34551 .3924 .33893 .38494 Mtetra
.609 .713 .919 r
.33893 .38494 .34551 .3924 .3561 .38956 .34952 .38243 Mtetra
.627 .73 .922 r
.34952 .38243 .3561 .38956 .36674 .3867 .36019 .37946 Mtetra
.609 .722 .925 r
.36019 .37946 .36674 .3867 .37735 .38548 .37088 .3769 Mtetra
.949 .592 .254 r
.37088 .3769 .37735 .38548 .38843 .37463 .37945 .42285 Mtetra
0 0 .034 r
.37945 .42285 .38843 .37463 .39911 .37378 .39265 .36617 Mtetra
.611 .712 .917 r
.39265 .36617 .39911 .37378 .40993 .37075 .40347 .36356 Mtetra
.636 .736 .92 r
.40347 .36356 .40993 .37075 .42081 .36743 .41438 .3603 Mtetra
.64 .74 .921 r
.41438 .3603 .42081 .36743 .43173 .3641 .42533 .35691 Mtetra
.636 .738 .922 r
.42533 .35691 .43173 .3641 .4427 .36103 .43633 .35362 Mtetra
.605 .72 .926 r
.43633 .35362 .4427 .36103 .45365 .36105 .44735 .35106 Mtetra
.865 .731 .714 r
.44735 .35106 .45365 .36105 .46488 .34937 .45879 .33168 Mtetra
.268 .322 .734 r
.45879 .33168 .46488 .34937 .47596 .34736 .46968 .33977 Mtetra
.626 .724 .918 r
.46968 .33977 .47596 .34736 .48712 .34397 .48085 .3367 Mtetra
.645 .742 .92 r
.48085 .3367 .48712 .34397 .49832 .34031 .49209 .3331 Mtetra
.652 .748 .92 r
.49209 .3331 .49832 .34031 .50957 .33651 .50337 .32932 Mtetra
.655 .75 .92 r
.50337 .32932 .50957 .33651 .52087 .33264 .5147 .32545 Mtetra
.657 .752 .92 r
.5147 .32545 .52087 .33264 .53222 .3287 .52607 .3215 Mtetra
.658 .753 .92 r
.52607 .3215 .53222 .3287 .54361 .32472 .5375 .31751 Mtetra
.659 .754 .92 r
.5375 .31751 .54361 .32472 .55505 .32072 .54897 .31347 Mtetra
.54897 .31347 .55505 .32072 .56654 .31669 .56049 .30942 Mtetra
.56049 .30942 .56654 .31669 .57807 .31265 .57205 .30534 Mtetra
.57205 .30534 .57807 .31265 .58965 .30861 .58366 .30126 Mtetra
.658 .753 .92 r
.58366 .30126 .58965 .30861 .60128 .30455 .59533 .29717 Mtetra
.59533 .29717 .60128 .30455 .61296 .30048 .60704 .29307 Mtetra
.60704 .29307 .61296 .30048 .62468 .2964 .6188 .28896 Mtetra
.6188 .28896 .62468 .2964 .63646 .29231 .6306 .28483 Mtetra
.6306 .28483 .63646 .29231 .64828 .2882 .64246 .28069 Mtetra
.64246 .28069 .64828 .2882 .66016 .28408 .65437 .27653 Mtetra
.657 .753 .92 r
.65437 .27653 .66016 .28408 .67208 .27994 .66633 .27236 Mtetra
.66633 .27236 .67208 .27994 .68406 .27579 .67834 .26818 Mtetra
.67834 .26818 .68406 .27579 .69608 .27162 .6904 .26397 Mtetra
.6904 .26397 .69608 .27162 .70816 .26744 .70251 .25976 Mtetra
.70251 .25976 .70816 .26744 .72028 .26323 .71468 .25552 Mtetra
.657 .752 .92 r
.71468 .25552 .72028 .26323 .73246 .25902 .72689 .25127 Mtetra
.72689 .25127 .73246 .25902 .74469 .25478 .73916 .247 Mtetra
.73916 .247 .74469 .25478 .75698 .25053 .75148 .24271 Mtetra
.75148 .24271 .75698 .25053 .76931 .24626 .76385 .23841 Mtetra
.76385 .23841 .76931 .24626 .7817 .24197 .77628 .23409 Mtetra
.558 .689 .928 r
.11736 .45335 .12441 .46057 .13376 .46109 .12694 .45204 Mtetra
.867 .714 .69 r
.12694 .45204 .13376 .46109 .14442 .45086 .13924 .42823 Mtetra
0 .056 .577 r
.13924 .42823 .14442 .45086 .15401 .4501 .14701 .44283 Mtetra
.572 .695 .925 r
.14701 .44283 .15401 .4501 .16366 .44917 .15675 .44124 Mtetra
0 .007 .532 r
.15675 .44124 .16366 .44917 .17441 .43853 .16538 .45026 Mtetra
.765 .912 .531 r
.16538 .45026 .17441 .43853 .18397 .43929 .17705 .4318 Mtetra
.573 .69 .92 r
.17705 .4318 .18397 .43929 .19384 .43753 .18692 .43019 Mtetra
.519 .675 .935 r
.18692 .43019 .19384 .43753 .19959 .47808 .19674 .42949 Mtetra
.615 .428 .605 r
.19674 .42949 .19959 .47808 .21431 .42797 .20757 .41919 Mtetra
.513 .628 .902 r
.20757 .41919 .21431 .42797 .22432 .4261 .21744 .4189 Mtetra
.592 .709 .925 r
.21744 .4189 .22432 .4261 .23433 .42476 .22753 .41683 Mtetra
0 .304 .794 r
.22753 .41683 .23433 .42476 .24525 .41347 .23695 .42285 Mtetra
.734 .917 .557 r
.23695 .42285 .24525 .41347 .25514 .4145 .24836 .40686 Mtetra
.583 .694 .918 r
.24836 .40686 .25514 .4145 .26536 .41219 .25856 .40499 Mtetra
.598 .714 .925 r
.25856 .40499 .26536 .41219 .27555 .41096 .26884 .40275 Mtetra
.669 .202 0 r
.26884 .40275 .27555 .41096 .2865 .40017 .27798 .41622 Mtetra
.674 .807 .357 r
.27798 .41622 .2865 .40017 .29668 .40017 .28997 .39257 Mtetra
.595 .702 .918 r
.28997 .39257 .29668 .40017 .3071 .39759 .30038 .3904 Mtetra
.614 .723 .923 r
.30038 .3904 .3071 .39759 .31755 .39533 .31087 .38776 Mtetra
.512 .671 .935 r
.31087 .38776 .31755 .39533 .33092 .34612 .32128 .38716 Mtetra
.364 .084 .348 r
.32128 .38716 .33092 .34612 .33893 .38494 .33236 .37639 Mtetra
.555 .66 .906 r
.33236 .37639 .33893 .38494 .34952 .38243 .3429 .37516 Mtetra
.623 .726 .921 r
.3429 .37516 .34952 .38243 .36019 .37946 .35358 .37225 Mtetra
.624 .729 .923 r
.35358 .37225 .36019 .37946 .37088 .3769 .36431 .36932 Mtetra
.547 .689 .932 r
.36431 .36932 .37088 .3769 .37945 .42285 .37502 .36804 Mtetra
.608 .416 .596 r
.37502 .36804 .37945 .42285 .39265 .36617 .3862 .35709 Mtetra
.541 .642 .899 r
.3862 .35709 .39265 .36617 .40347 .36356 .39698 .35619 Mtetra
.629 .729 .92 r
.39698 .35619 .40347 .36356 .41438 .3603 .4079 .35308 Mtetra
.639 .739 .921 r
.4079 .35308 .41438 .3603 .42533 .35691 .41888 .3497 Mtetra
.64 .74 .921 r
.41888 .3497 .42533 .35691 .43633 .35362 .4299 .34629 Mtetra
.628 .733 .923 r
.4299 .34629 .43633 .35362 .44735 .35106 .44097 .34316 Mtetra
.48 .651 .935 r
.44097 .34316 .44735 .35106 .45879 .33168 .45201 .34312 Mtetra
0 0 0 r
.45201 .34312 .45879 .33168 .46968 .33977 .46336 .33134 Mtetra
.586 .685 .909 r
.46336 .33134 .46968 .33977 .48085 .3367 .47454 .32926 Mtetra
.639 .737 .919 r
.47454 .32926 .48085 .3367 .49209 .3331 .4858 .3258 Mtetra
.649 .746 .92 r
.4858 .3258 .49209 .3331 .50337 .32932 .49711 .32206 Mtetra
.653 .749 .92 r
.49711 .32206 .50337 .32932 .5147 .32545 .50847 .31819 Mtetra
.656 .751 .92 r
.50847 .31819 .5147 .32545 .52607 .3215 .51988 .31424 Mtetra
.657 .753 .92 r
.51988 .31424 .52607 .3215 .5375 .31751 .53134 .31023 Mtetra
.658 .753 .92 r
.53134 .31023 .5375 .31751 .54897 .31347 .54284 .30617 Mtetra
.659 .754 .92 r
.54284 .30617 .54897 .31347 .56049 .30942 .55439 .30208 Mtetra
.55439 .30208 .56049 .30942 .57205 .30534 .56599 .29798 Mtetra
.56599 .29798 .57205 .30534 .58366 .30126 .57763 .29386 Mtetra
.57763 .29386 .58366 .30126 .59533 .29717 .58933 .28974 Mtetra
.658 .753 .92 r
.58933 .28974 .59533 .29717 .60704 .29307 .60107 .2856 Mtetra
.60107 .2856 .60704 .29307 .6188 .28896 .61286 .28145 Mtetra
.61286 .28145 .6188 .28896 .6306 .28483 .6247 .27729 Mtetra
.6247 .27729 .6306 .28483 .64246 .28069 .6366 .27312 Mtetra
.6366 .27312 .64246 .28069 .65437 .27653 .64854 .26893 Mtetra
.64854 .26893 .65437 .27653 .66633 .27236 .66053 .26472 Mtetra
.657 .753 .92 r
.66053 .26472 .66633 .27236 .67834 .26818 .67258 .26051 Mtetra
.67258 .26051 .67834 .26818 .6904 .26397 .68467 .25627 Mtetra
.68467 .25627 .6904 .26397 .70251 .25976 .69682 .25202 Mtetra
.69682 .25202 .70251 .25976 .71468 .25552 .70902 .24775 Mtetra
.657 .752 .92 r
.70902 .24775 .71468 .25552 .72689 .25127 .72127 .24346 Mtetra
.72127 .24346 .72689 .25127 .73916 .247 .73358 .23916 Mtetra
.73358 .23916 .73916 .247 .75148 .24271 .74594 .23484 Mtetra
.74594 .23484 .75148 .24271 .76385 .23841 .75835 .2305 Mtetra
.75835 .2305 .76385 .23841 .77628 .23409 .77081 .22614 Mtetra
.541 .666 .918 r
.11033 .44554 .11736 .45335 .12694 .45204 .11988 .44459 Mtetra
.44 .635 .938 r
.11988 .44459 .12694 .45204 .13924 .42823 .1293 .44506 Mtetra
.008 0 0 r
.1293 .44506 .13924 .42823 .14701 .44283 .14006 .43474 Mtetra
.535 .656 .914 r
.14006 .43474 .14701 .44283 .15675 .44124 .14972 .43392 Mtetra
.536 .682 .933 r
.14972 .43392 .15675 .44124 .16538 .45026 .15945 .43294 Mtetra
.722 .592 .71 r
.15945 .43294 .16538 .45026 .17705 .4318 .1703 .42221 Mtetra
.464 .582 .888 r
.1703 .42221 .17705 .4318 .18692 .43019 .17993 .42293 Mtetra
.58 .702 .926 r
.17993 .42293 .18692 .43019 .19674 .42949 .18989 .4211 Mtetra
.95 .607 .321 r
.18989 .4211 .19674 .42949 .20757 .41919 .19563 .46178 Mtetra
0 0 0 r
.19563 .46178 .20757 .41919 .21744 .4189 .21053 .41141 Mtetra
.585 .699 .921 r
.21053 .41141 .21744 .4189 .22753 .41683 .22062 .40947 Mtetra
.556 .693 .931 r
.22062 .40947 .22753 .41683 .23695 .42285 .23072 .40808 Mtetra
.748 .628 .727 r
.23072 .40808 .23695 .42285 .24836 .40686 .24174 .39669 Mtetra
.456 .566 .877 r
.24174 .39669 .24836 .40686 .25856 .40499 .25171 .39768 Mtetra
.603 .714 .922 r
.25171 .39768 .25856 .40499 .26884 .40275 .26202 .3953 Mtetra
.549 .69 .932 r
.26202 .3953 .26884 .40275 .27798 .41622 .2723 .39402 Mtetra
.696 .549 .683 r
.2723 .39402 .27798 .41622 .28997 .39257 .28335 .38313 Mtetra
.503 .61 .892 r
.28335 .38313 .28997 .39257 .30038 .3904 .29362 .38308 Mtetra
.613 .72 .921 r
.29362 .38308 .30038 .3904 .31087 .38776 .30413 .38044 Mtetra
.598 .715 .926 r
.30413 .38044 .31087 .38776 .32128 .38716 .31466 .37811 Mtetra
.927 .721 .605 r
.31466 .37811 .32128 .38716 .33236 .37639 .32819 .32865 Mtetra
0 0 .423 r
.32819 .32865 .33236 .37639 .3429 .37516 .33624 .36757 Mtetra
.609 .713 .919 r
.33624 .36757 .3429 .37516 .35358 .37225 .34693 .36499 Mtetra
.627 .73 .922 r
.34693 .36499 .35358 .37225 .36431 .36932 .35769 .36196 Mtetra
.609 .722 .925 r
.35769 .36196 .36431 .36932 .37502 .36804 .36848 .35933 Mtetra
.948 .59 .248 r
.36848 .35933 .37502 .36804 .3862 .35709 .37708 .40542 Mtetra
0 0 .025 r
.37708 .40542 .3862 .35709 .39698 .35619 .39045 .34844 Mtetra
.611 .712 .917 r
.39045 .34844 .39698 .35619 .4079 .35308 .40137 .34576 Mtetra
.636 .736 .92 r
.40137 .34576 .4079 .35308 .41888 .3497 .41237 .34243 Mtetra
.64 .74 .921 r
.41237 .34243 .41888 .3497 .4299 .34629 .42343 .33897 Mtetra
.636 .738 .922 r
.42343 .33897 .4299 .34629 .44097 .34316 .43453 .33561 Mtetra
.605 .72 .926 r
.43453 .33561 .44097 .34316 .45201 .34312 .44566 .33298 Mtetra
.866 .732 .714 r
.44566 .33298 .45201 .34312 .46336 .33134 .45721 .31347 Mtetra
.265 .321 .734 r
.45721 .31347 .46336 .33134 .47454 .32926 .46819 .32153 Mtetra
.626 .724 .918 r
.46819 .32153 .47454 .32926 .4858 .3258 .47947 .31838 Mtetra
.645 .742 .92 r
.47947 .31838 .4858 .3258 .49711 .32206 .49081 .31471 Mtetra
.652 .748 .92 r
.49081 .31471 .49711 .32206 .50847 .31819 .5022 .31086 Mtetra
.655 .75 .92 r
.5022 .31086 .50847 .31819 .51988 .31424 .51364 .30691 Mtetra
.657 .752 .92 r
.51364 .30691 .51988 .31424 .53134 .31023 .52513 .30288 Mtetra
.658 .753 .92 r
.52513 .30288 .53134 .31023 .54284 .30617 .53666 .29881 Mtetra
.659 .754 .92 r
.53666 .29881 .54284 .30617 .55439 .30208 .54824 .2947 Mtetra
.54824 .2947 .55439 .30208 .56599 .29798 .55987 .29056 Mtetra
.55987 .29056 .56599 .29798 .57763 .29386 .57155 .28641 Mtetra
.57155 .28641 .57763 .29386 .58933 .28974 .58328 .28225 Mtetra
.658 .753 .92 r
.58328 .28225 .58933 .28974 .60107 .2856 .59506 .27807 Mtetra
.59506 .27807 .60107 .2856 .61286 .28145 .60688 .27389 Mtetra
.60688 .27389 .61286 .28145 .6247 .27729 .61876 .2697 Mtetra
.61876 .2697 .6247 .27729 .6366 .27312 .63069 .26549 Mtetra
.63069 .26549 .6366 .27312 .64854 .26893 .64266 .26127 Mtetra
.64266 .26127 .64854 .26893 .66053 .26472 .65469 .25703 Mtetra
.657 .753 .92 r
.65469 .25703 .66053 .26472 .67258 .26051 .66677 .25277 Mtetra
.66677 .25277 .67258 .26051 .68467 .25627 .6789 .2485 Mtetra
.6789 .2485 .68467 .25627 .69682 .25202 .69109 .24422 Mtetra
.69109 .24422 .69682 .25202 .70902 .24775 .70332 .23991 Mtetra
.70332 .23991 .70902 .24775 .72127 .24346 .71561 .23559 Mtetra
.657 .752 .92 r
.71561 .23559 .72127 .24346 .73358 .23916 .72795 .23125 Mtetra
.72795 .23125 .73358 .23916 .74594 .23484 .74035 .2269 Mtetra
.74035 .2269 .74594 .23484 .75835 .2305 .7528 .22252 Mtetra
.7528 .22252 .75835 .2305 .77081 .22614 .7653 .21813 Mtetra
.217 .335 .77 r
.10408 .43136 .11033 .44554 .11988 .44459 .11275 .43725 Mtetra
.558 .689 .928 r
.11275 .43725 .11988 .44459 .1293 .44506 .12241 .43588 Mtetra
.868 .714 .689 r
.12241 .43588 .1293 .44506 .14006 .43474 .13484 .41193 Mtetra
0 .052 .575 r
.13484 .41193 .14006 .43474 .14972 .43392 .14265 .42654 Mtetra
.572 .695 .925 r
.14265 .42654 .14972 .43392 .15945 .43294 .15247 .42489 Mtetra
0 .013 .539 r
.15247 .42489 .15945 .43294 .1703 .42221 .16114 .4339 Mtetra
.772 .917 .538 r
.16114 .4339 .1703 .42221 .17993 .42293 .17293 .41531 Mtetra
.573 .69 .92 r
.17293 .41531 .17993 .42293 .18989 .4211 .18288 .41364 Mtetra
.52 .675 .935 r
.18288 .41364 .18989 .4211 .19563 .46178 .19279 .41289 Mtetra
.614 .426 .604 r
.19279 .41289 .19563 .46178 .21053 .41141 .20371 .40249 Mtetra
.512 .628 .902 r
.20371 .40249 .21053 .41141 .22062 .40947 .21366 .40215 Mtetra
.592 .709 .925 r
.21366 .40215 .22062 .40947 .23072 .40808 .22384 .40002 Mtetra
0 .307 .796 r
.22384 .40002 .23072 .40808 .24174 .39669 .23333 .40602 Mtetra
.741 .922 .565 r
.23333 .40602 .24174 .39669 .25171 .39768 .24485 .38991 Mtetra
.583 .694 .918 r
.24485 .38991 .25171 .39768 .26202 .3953 .25514 .38798 Mtetra
.598 .714 .925 r
.25514 .38798 .26202 .3953 .2723 .39402 .26551 .38567 Mtetra
.662 .196 0 r
.26551 .38567 .2723 .39402 .28335 .38313 .27471 .39915 Mtetra
.683 .814 .366 r
.27471 .39915 .28335 .38313 .29362 .38308 .28683 .37535 Mtetra
.595 .702 .918 r
.28683 .37535 .29362 .38308 .30413 .38044 .29733 .37311 Mtetra
.614 .723 .923 r
.29733 .37311 .30413 .38044 .31466 .37811 .30791 .37041 Mtetra
.512 .671 .935 r
.30791 .37041 .31466 .37811 .32819 .32865 .31841 .36975 Mtetra
.357 .075 .341 r
.31841 .36975 .32819 .32865 .33624 .36757 .3296 .35888 Mtetra
.554 .66 .906 r
.3296 .35888 .33624 .36757 .34693 .36499 .34023 .35759 Mtetra
.623 .726 .921 r
.34023 .35759 .34693 .36499 .35769 .36196 .35101 .35462 Mtetra
.624 .729 .923 r
.35101 .35462 .35769 .36196 .36848 .35933 .36184 .35162 Mtetra
.547 .689 .932 r
.36184 .35162 .36848 .35933 .37708 .40542 .37264 .35027 Mtetra
.607 .413 .594 r
.37264 .35027 .37708 .40542 .39045 .34844 .38393 .33922 Mtetra
.541 .642 .899 r
.38393 .33922 .39045 .34844 .40137 .34576 .3948 .33826 Mtetra
.629 .729 .92 r
.3948 .33826 .40137 .34576 .41237 .34243 .40582 .33508 Mtetra
.639 .739 .921 r
.40582 .33508 .41237 .34243 .42343 .33897 .4169 .33162 Mtetra
.64 .74 .921 r
.4169 .33162 .42343 .33897 .43453 .33561 .42803 .32814 Mtetra
.628 .733 .923 r
.42803 .32814 .43453 .33561 .44566 .33298 .4392 .32494 Mtetra
.48 .651 .934 r
.4392 .32494 .44566 .33298 .45721 .31347 .45035 .32484 Mtetra
0 0 0 r
.45035 .32484 .45721 .31347 .46819 .32153 .46181 .31295 Mtetra
.586 .685 .909 r
.46181 .31295 .46819 .32153 .47947 .31838 .4731 .3108 Mtetra
.639 .737 .919 r
.4731 .3108 .47947 .31838 .49081 .31471 .48446 .30727 Mtetra
.649 .746 .92 r
.48446 .30727 .49081 .31471 .5022 .31086 .49588 .30345 Mtetra
.653 .749 .92 r
.49588 .30345 .5022 .31086 .51364 .30691 .50735 .2995 Mtetra
.656 .751 .92 r
.50735 .2995 .51364 .30691 .52513 .30288 .51887 .29547 Mtetra
.657 .753 .92 r
.51887 .29547 .52513 .30288 .53666 .29881 .53043 .29138 Mtetra
.658 .753 .92 r
.53043 .29138 .53666 .29881 .54824 .2947 .54205 .28725 Mtetra
.659 .754 .92 r
.54205 .28725 .54824 .2947 .55987 .29056 .55371 .28308 Mtetra
.55371 .28308 .55987 .29056 .57155 .28641 .56542 .2789 Mtetra
.56542 .2789 .57155 .28641 .58328 .28225 .57718 .2747 Mtetra
.57718 .2747 .58328 .28225 .59506 .27807 .58899 .27049 Mtetra
.658 .753 .92 r
.58899 .27049 .59506 .27807 .60688 .27389 .60085 .26627 Mtetra
.60085 .26627 .60688 .27389 .61876 .2697 .61277 .26204 Mtetra
.61277 .26204 .61876 .2697 .63069 .26549 .62473 .2578 Mtetra
.62473 .2578 .63069 .26549 .64266 .26127 .63674 .25354 Mtetra
.63674 .25354 .64266 .26127 .65469 .25703 .6488 .24927 Mtetra
.6488 .24927 .65469 .25703 .66677 .25277 .66092 .24498 Mtetra
.657 .753 .92 r
.66092 .24498 .66677 .25277 .6789 .2485 .67309 .24067 Mtetra
.67309 .24067 .6789 .2485 .69109 .24422 .6853 .23635 Mtetra
.6853 .23635 .69109 .24422 .70332 .23991 .69758 .23201 Mtetra
.69758 .23201 .70332 .23991 .71561 .23559 .7099 .22766 Mtetra
.657 .752 .92 r
.7099 .22766 .71561 .23559 .72795 .23125 .72228 .22329 Mtetra
.72228 .22329 .72795 .23125 .74035 .2269 .73471 .21889 Mtetra
.73471 .21889 .74035 .2269 .7528 .22252 .7472 .21448 Mtetra
.7472 .21448 .7528 .22252 .7653 .21813 .75974 .21006 Mtetra
.544 .848 .535 r
.09475 .44039 .10408 .43136 .11275 .43725 .10564 .42931 Mtetra
.541 .666 .918 r
.10564 .42931 .11275 .43725 .12241 .43588 .11526 .42831 Mtetra
.44 .635 .938 r
.11526 .42831 .12241 .43588 .13484 .41193 .12476 .42873 Mtetra
0 0 0 r
.12476 .42873 .13484 .41193 .14265 .42654 .13562 .41832 Mtetra
.535 .656 .914 r
.13562 .41832 .14265 .42654 .15247 .42489 .14535 .41745 Mtetra
.536 .682 .933 r
.14535 .41745 .15247 .42489 .16114 .4339 .15516 .41642 Mtetra
.722 .592 .71 r
.15516 .41642 .16114 .4339 .17293 .41531 .16612 .40559 Mtetra
.463 .582 .888 r
.16612 .40559 .17293 .41531 .18288 .41364 .17582 .40626 Mtetra
.58 .702 .926 r
.17582 .40626 .18288 .41364 .19279 .41289 .18586 .40438 Mtetra
.95 .606 .316 r
.18586 .40438 .19279 .41289 .20371 .40249 .19159 .44517 Mtetra
0 0 0 r
.19159 .44517 .20371 .40249 .21366 .40215 .20668 .39453 Mtetra
.585 .699 .921 r
.20668 .39453 .21366 .40215 .22384 .40002 .21686 .39254 Mtetra
.556 .693 .931 r
.21686 .39254 .22384 .40002 .23333 .40602 .22704 .39109 Mtetra
.748 .629 .727 r
.22704 .39109 .23333 .40602 .24485 .38991 .23817 .3796 Mtetra
.456 .566 .878 r
.23817 .3796 .24485 .38991 .25514 .38798 .24822 .38054 Mtetra
.603 .714 .922 r
.24822 .38054 .25514 .38798 .26551 .38567 .25862 .3781 Mtetra
.549 .69 .932 r
.25862 .3781 .26551 .38567 .27471 .39915 .26898 .37675 Mtetra
.696 .549 .683 r
.26898 .37675 .27471 .39915 .28683 .37535 .28014 .36576 Mtetra
.503 .61 .892 r
.28014 .36576 .28683 .37535 .29733 .37311 .29049 .36566 Mtetra
.613 .72 .921 r
.29049 .36566 .29733 .37311 .30791 .37041 .3011 .36295 Mtetra
.598 .715 .926 r
.3011 .36295 .30791 .37041 .31841 .36975 .31173 .36056 Mtetra
.929 .722 .603 r
.31173 .36056 .31841 .36975 .3296 .35888 .32542 .31085 Mtetra
0 0 .419 r
.32542 .31085 .3296 .35888 .34023 .35759 .3335 .34986 Mtetra
.609 .713 .919 r
.3335 .34986 .34023 .35759 .35101 .35462 .34428 .34722 Mtetra
.627 .73 .922 r
.34428 .34722 .35101 .35462 .36184 .35162 .35514 .34411 Mtetra
.609 .722 .925 r
.35514 .34411 .36184 .35162 .37264 .35027 .36603 .34142 Mtetra
.947 .587 .242 r
.36603 .34142 .37264 .35027 .38393 .33922 .37468 .38764 Mtetra
0 0 .017 r
.37468 .38764 .38393 .33922 .3948 .33826 .3882 .33037 Mtetra
.611 .712 .917 r
.3882 .33037 .3948 .33826 .40582 .33508 .39923 .32762 Mtetra
.636 .736 .92 r
.39923 .32762 .40582 .33508 .4169 .33162 .41033 .32421 Mtetra
.64 .74 .921 r
.41033 .32421 .4169 .33162 .42803 .32814 .42149 .32069 Mtetra
.636 .738 .922 r
.42149 .32069 .42803 .32814 .4392 .32494 .43269 .31725 Mtetra
.605 .72 .926 r
.43269 .31725 .4392 .32494 .45035 .32484 .44393 .31455 Mtetra
.867 .733 .713 r
.44393 .31455 .45035 .32484 .46181 .31295 .45559 .2949 Mtetra
.263 .32 .734 r
.45559 .2949 .46181 .31295 .4731 .3108 .46668 .30293 Mtetra
.626 .724 .918 r
.46668 .30293 .4731 .3108 .48446 .30727 .47807 .29971 Mtetra
.645 .742 .92 r
.47807 .29971 .48446 .30727 .49588 .30345 .48951 .29596 Mtetra
.652 .748 .92 r
.48951 .29596 .49588 .30345 .50735 .2995 .50101 .29203 Mtetra
.655 .75 .92 r
.50101 .29203 .50735 .2995 .51887 .29547 .51256 .288 Mtetra
.657 .752 .92 r
.51256 .288 .51887 .29547 .53043 .29138 .52416 .28389 Mtetra
.658 .753 .92 r
.52416 .28389 .53043 .29138 .54205 .28725 .53581 .27974 Mtetra
.659 .754 .92 r
.53581 .27974 .54205 .28725 .55371 .28308 .5475 .27554 Mtetra
.5475 .27554 .55371 .28308 .56542 .2789 .55925 .27133 Mtetra
.55925 .27133 .56542 .2789 .57718 .2747 .57104 .26709 Mtetra
.57104 .26709 .57718 .2747 .58899 .27049 .58289 .26285 Mtetra
.658 .753 .92 r
.58289 .26285 .58899 .27049 .60085 .26627 .59478 .25859 Mtetra
.59478 .25859 .60085 .26627 .61277 .26204 .60672 .25433 Mtetra
.60672 .25433 .61277 .26204 .62473 .2578 .61872 .25005 Mtetra
.61872 .25005 .62473 .2578 .63674 .25354 .63077 .24576 Mtetra
.63077 .24576 .63674 .25354 .6488 .24927 .64287 .24145 Mtetra
.64287 .24145 .6488 .24927 .66092 .24498 .65502 .23712 Mtetra
.657 .753 .92 r
.65502 .23712 .66092 .24498 .67309 .24067 .66722 .23278 Mtetra
.66722 .23278 .67309 .24067 .6853 .23635 .67948 .22843 Mtetra
.67948 .22843 .6853 .23635 .69758 .23201 .69179 .22405 Mtetra
.69179 .22405 .69758 .23201 .7099 .22766 .70415 .21966 Mtetra
.70415 .21966 .7099 .22766 .72228 .22329 .71657 .21525 Mtetra
.657 .752 .92 r
.71657 .21525 .72228 .22329 .73471 .21889 .72904 .21083 Mtetra
.72904 .21083 .73471 .21889 .7472 .21448 .74156 .20638 Mtetra
.74156 .20638 .7472 .21448 .75974 .21006 .75414 .20192 Mtetra
.818 .699 .733 r
.08786 .43019 .09475 .44039 .10564 .42931 .09933 .41499 Mtetra
.214 .333 .77 r
.09933 .41499 .10564 .42931 .11526 .42831 .10805 .42084 Mtetra
.558 .689 .928 r
.10805 .42084 .11526 .42831 .12476 .42873 .11779 .41942 Mtetra
.869 .715 .689 r
.11779 .41942 .12476 .42873 .13562 .41832 .13035 .39532 Mtetra
0 .048 .572 r
.13035 .39532 .13562 .41832 .14535 .41745 .1382 .40994 Mtetra
.572 .695 .925 r
.1382 .40994 .14535 .41745 .15516 .41642 .1481 .40823 Mtetra
0 .019 .545 r
.1481 .40823 .15516 .41642 .16612 .40559 .15683 .41723 Mtetra
.778 .921 .546 r
.15683 .41723 .16612 .40559 .17582 .40626 .16874 .39851 Mtetra
.573 .69 .92 r
.16874 .39851 .17582 .40626 .18586 .40438 .17878 .39679 Mtetra
.52 .675 .934 r
.17878 .39679 .18586 .40438 .19159 .44517 .18876 .39598 Mtetra
.613 .424 .602 r
.18876 .39598 .19159 .44517 .20668 .39453 .19979 .38549 Mtetra
.512 .628 .902 r
.19979 .38549 .20668 .39453 .21686 .39254 .20982 .38509 Mtetra
.592 .709 .925 r
.20982 .38509 .21686 .39254 .22704 .39109 .22008 .3829 Mtetra
0 .311 .799 r
.22008 .3829 .22704 .39109 .23817 .3796 .22965 .38887 Mtetra
.748 .927 .573 r
.22965 .38887 .23817 .3796 .24822 .38054 .24128 .37264 Mtetra
.583 .694 .918 r
.24128 .37264 .24822 .38054 .25862 .3781 .25166 .37064 Mtetra
.598 .714 .925 r
.25166 .37064 .25862 .3781 .26898 .37675 .26212 .36827 Mtetra
.655 .189 0 r
.26212 .36827 .26898 .37675 .28014 .36576 .27138 .38174 Mtetra
.692 .821 .375 r
.27138 .38174 .28014 .36576 .29049 .36566 .28363 .35779 Mtetra
.595 .702 .918 r
.28363 .35779 .29049 .36566 .3011 .36295 .29423 .3555 Mtetra
.614 .723 .923 r
.29423 .3555 .3011 .36295 .31173 .36056 .3049 .35272 Mtetra
.513 .671 .935 r
.3049 .35272 .31173 .36056 .32542 .31085 .31549 .352 Mtetra
.349 .065 .333 r
.31549 .352 .32542 .31085 .3335 .34986 .32679 .34103 Mtetra
.554 .66 .906 r
.32679 .34103 .3335 .34986 .34428 .34722 .33751 .33968 Mtetra
.623 .726 .921 r
.33751 .33968 .34428 .34722 .35514 .34411 .34839 .33664 Mtetra
.624 .729 .923 r
.34839 .33664 .35514 .34411 .36603 .34142 .35932 .33357 Mtetra
.548 .689 .932 r
.35932 .33357 .36603 .34142 .37468 .38764 .37021 .33216 Mtetra
.605 .411 .592 r
.37021 .33216 .37468 .38764 .3882 .33037 .38162 .321 Mtetra
.54 .642 .899 r
.38162 .321 .3882 .33037 .39923 .32762 .39259 .31998 Mtetra
.629 .729 .92 r
.39259 .31998 .39923 .32762 .41033 .32421 .40371 .31673 Mtetra
.639 .739 .921 r
.40371 .31673 .41033 .32421 .42149 .32069 .41489 .31319 Mtetra
.64 .74 .921 r
.41489 .31319 .42149 .32069 .43269 .31725 .42613 .30964 Mtetra
.628 .733 .923 r
.42613 .30964 .43269 .31725 .44393 .31455 .4374 .30636 Mtetra
.481 .651 .934 r
.4374 .30636 .44393 .31455 .45559 .2949 .44866 .3062 Mtetra
0 0 0 r
.44866 .3062 .45559 .2949 .46668 .30293 .46023 .2942 Mtetra
.586 .685 .909 r
.46023 .2942 .46668 .30293 .47807 .29971 .47162 .29198 Mtetra
.639 .737 .919 r
.47162 .29198 .47807 .29971 .48951 .29596 .4831 .28837 Mtetra
.649 .746 .92 r
.4831 .28837 .48951 .29596 .50101 .29203 .49463 .28447 Mtetra
.653 .749 .92 r
.49463 .28447 .50101 .29203 .51256 .288 .50621 .28045 Mtetra
.656 .751 .92 r
.50621 .28045 .51256 .288 .52416 .28389 .51784 .27634 Mtetra
.657 .753 .92 r
.51784 .27634 .52416 .28389 .53581 .27974 .52952 .27216 Mtetra
.658 .753 .92 r
.52952 .27216 .53581 .27974 .5475 .27554 .54124 .26795 Mtetra
.659 .754 .92 r
.54124 .26795 .5475 .27554 .55925 .27133 .55302 .2637 Mtetra
.55302 .2637 .55925 .27133 .57104 .26709 .56485 .25943 Mtetra
.56485 .25943 .57104 .26709 .58289 .26285 .57673 .25515 Mtetra
.57673 .25515 .58289 .26285 .59478 .25859 .58866 .25086 Mtetra
.658 .753 .92 r
.58866 .25086 .59478 .25859 .60672 .25433 .60064 .24655 Mtetra
.60064 .24655 .60672 .25433 .61872 .25005 .61267 .24224 Mtetra
.61267 .24224 .61872 .25005 .63077 .24576 .62475 .23791 Mtetra
.62475 .23791 .63077 .24576 .64287 .24145 .63688 .23357 Mtetra
.63688 .23357 .64287 .24145 .65502 .23712 .64907 .22921 Mtetra
.64907 .22921 .65502 .23712 .66722 .23278 .66131 .22483 Mtetra
.657 .753 .92 r
.66131 .22483 .66722 .23278 .67948 .22843 .6736 .22044 Mtetra
.6736 .22044 .67948 .22843 .69179 .22405 .68595 .21603 Mtetra
.68595 .21603 .69179 .22405 .70415 .21966 .69835 .2116 Mtetra
.69835 .2116 .70415 .21966 .71657 .21525 .7108 .20716 Mtetra
.657 .752 .92 r
.7108 .20716 .71657 .21525 .72904 .21083 .72331 .20269 Mtetra
.72331 .20269 .72904 .21083 .74156 .20638 .73588 .19821 Mtetra
.73588 .19821 .74156 .20638 .75414 .20192 .74849 .19371 Mtetra
.346 .585 .933 r
.0806 .42243 .08786 .43019 .09933 .41499 .08987 .42395 Mtetra
.557 .858 .548 r
.08987 .42395 .09933 .41499 .10805 .42084 .10087 .41278 Mtetra
.541 .666 .918 r
.10087 .41278 .10805 .42084 .11779 .41942 .11056 .41172 Mtetra
.441 .635 .938 r
.11056 .41172 .11779 .41942 .13035 .39532 .12013 .4121 Mtetra
0 0 0 r
.12013 .4121 .13035 .39532 .1382 .40994 .13109 .40159 Mtetra
.534 .656 .914 r
.13109 .40159 .1382 .40994 .1481 .40823 .14091 .40067 Mtetra
.536 .682 .932 r
.14091 .40067 .1481 .40823 .15683 .41723 .1508 .39958 Mtetra
.723 .592 .71 r
.1508 .39958 .15683 .41723 .16874 .39851 .16185 .38866 Mtetra
.463 .582 .888 r
.16185 .38866 .16874 .39851 .17878 .39679 .17163 .38927 Mtetra
.58 .702 .926 r
.17163 .38927 .17878 .39679 .18876 .39598 .18175 .38733 Mtetra
.95 .604 .311 r
.18175 .38733 .18876 .39598 .19979 .38549 .18748 .42824 Mtetra
0 0 0 r
.18748 .42824 .19979 .38549 .20982 .38509 .20276 .37734 Mtetra
.585 .699 .921 r
.20276 .37734 .20982 .38509 .22008 .3829 .21302 .37529 Mtetra
.556 .693 .931 r
.21302 .37529 .22008 .3829 .22965 .38887 .22329 .37378 Mtetra
.749 .629 .727 r
.22329 .37378 .22965 .38887 .24128 .37264 .23453 .36219 Mtetra
.455 .566 .878 r
.23453 .36219 .24128 .37264 .25166 .37064 .24466 .36307 Mtetra
.603 .714 .922 r
.24466 .36307 .25166 .37064 .26212 .36827 .25515 .36056 Mtetra
.549 .69 .932 r
.25515 .36056 .26212 .36827 .27138 .38174 .2656 .35916 Mtetra
.695 .548 .683 r
.2656 .35916 .27138 .38174 .28363 .35779 .27687 .34807 Mtetra
.502 .61 .893 r
.27687 .34807 .28363 .35779 .29423 .3555 .28731 .3479 Mtetra
.613 .72 .921 r
.28731 .3479 .29423 .3555 .3049 .35272 .29801 .34513 Mtetra
.598 .715 .926 r
.29801 .34513 .3049 .35272 .31549 .352 .30873 .34267 Mtetra
.93 .723 .602 r
.30873 .34267 .31549 .352 .32679 .34103 .32259 .29271 Mtetra
0 0 .415 r
.32259 .29271 .32679 .34103 .33751 .33968 .33071 .33182 Mtetra
.609 .713 .919 r
.33071 .33182 .33751 .33968 .34839 .33664 .34159 .3291 Mtetra
.627 .73 .922 r
.34159 .3291 .34839 .33664 .35932 .33357 .35254 .32592 Mtetra
.609 .722 .925 r
.35254 .32592 .35932 .33357 .37021 .33216 .36353 .32316 Mtetra
.946 .585 .235 r
.36353 .32316 .37021 .33216 .38162 .321 .37222 .3695 Mtetra
0 0 .008 r
.37222 .3695 .38162 .321 .39259 .31998 .38591 .31194 Mtetra
.611 .712 .917 r
.38591 .31194 .39259 .31998 .40371 .31673 .39704 .30912 Mtetra
.636 .736 .92 r
.39704 .30912 .40371 .31673 .41489 .31319 .40825 .30564 Mtetra
.64 .74 .921 r
.40825 .30564 .41489 .31319 .42613 .30964 .41951 .30204 Mtetra
.636 .738 .922 r
.41951 .30204 .42613 .30964 .4374 .30636 .43082 .29852 Mtetra
.605 .72 .926 r
.43082 .29852 .4374 .30636 .44866 .3062 .44216 .29575 Mtetra
.868 .734 .713 r
.44216 .29575 .44866 .3062 .46023 .2942 .45395 .27596 Mtetra
.26 .318 .733 r
.45395 .27596 .46023 .2942 .47162 .29198 .46513 .28396 Mtetra
.626 .724 .918 r
.46513 .28396 .47162 .29198 .4831 .28837 .47663 .28066 Mtetra
.645 .742 .92 r
.47663 .28066 .4831 .28837 .49463 .28447 .48819 .27683 Mtetra
.652 .748 .92 r
.48819 .27683 .49463 .28447 .50621 .28045 .4998 .27282 Mtetra
.655 .75 .92 r
.4998 .27282 .50621 .28045 .51784 .27634 .51146 .26871 Mtetra
.657 .752 .92 r
.51146 .26871 .51784 .27634 .52952 .27216 .52317 .26452 Mtetra
.658 .753 .92 r
.52317 .26452 .52952 .27216 .54124 .26795 .53494 .26028 Mtetra
.659 .754 .92 r
.53494 .26028 .54124 .26795 .55302 .2637 .54675 .25601 Mtetra
.54675 .25601 .55302 .2637 .56485 .25943 .55861 .25171 Mtetra
.55861 .25171 .56485 .25943 .57673 .25515 .57052 .24739 Mtetra
.57052 .24739 .57673 .25515 .58866 .25086 .58248 .24306 Mtetra
.658 .753 .92 r
.58248 .24306 .58866 .25086 .60064 .24655 .5945 .23872 Mtetra
.5945 .23872 .60064 .24655 .61267 .24224 .60656 .23437 Mtetra
.60656 .23437 .61267 .24224 .62475 .23791 .61868 .23 Mtetra
.61868 .23 .62475 .23791 .63688 .23357 .63085 .22562 Mtetra
.63085 .22562 .63688 .23357 .64907 .22921 .64307 .22123 Mtetra
.64307 .22123 .64907 .22921 .66131 .22483 .65535 .21681 Mtetra
.657 .753 .92 r
.65535 .21681 .66131 .22483 .6736 .22044 .66768 .21238 Mtetra
.66768 .21238 .6736 .22044 .68595 .21603 .68006 .20794 Mtetra
.68006 .20794 .68595 .21603 .69835 .2116 .6925 .20347 Mtetra
.6925 .20347 .69835 .2116 .7108 .20716 .70499 .19899 Mtetra
.70499 .19899 .7108 .20716 .72331 .20269 .71754 .19449 Mtetra
.657 .752 .92 r
.71754 .19449 .72331 .20269 .73588 .19821 .73014 .18997 Mtetra
.73014 .18997 .73588 .19821 .74849 .19371 .7428 .18544 Mtetra
.544 .683 .929 r
.07326 .41484 .0806 .42243 .08987 .42395 .08291 .41363 Mtetra
.819 .7 .733 r
.08291 .41363 .08987 .42395 .10087 .41278 .09448 .39831 Mtetra
.212 .332 .769 r
.09448 .39831 .10087 .41278 .11056 .41172 .10327 .40414 Mtetra
.558 .689 .928 r
.10327 .40414 .11056 .41172 .12013 .4121 .11308 .40266 Mtetra
.87 .716 .689 r
.11308 .40266 .12013 .4121 .13109 .40159 .12578 .37841 Mtetra
0 .044 .57 r
.12578 .37841 .13109 .40159 .14091 .40067 .13367 .39303 Mtetra
.572 .695 .925 r
.13367 .39303 .14091 .40067 .1508 .39958 .14365 .39127 Mtetra
0 .025 .551 r
.14365 .39127 .1508 .39958 .16185 .38866 .15244 .40025 Mtetra
.785 .926 .554 r
.15244 .40025 .16185 .38866 .17163 .38927 .16447 .3814 Mtetra
.573 .69 .921 r
.16447 .3814 .17163 .38927 .18175 .38733 .17459 .37961 Mtetra
.52 .675 .934 r
.17459 .37961 .18175 .38733 .18748 .42824 .18466 .37875 Mtetra
.611 .422 .601 r
.18466 .37875 .18748 .42824 .20276 .37734 .19579 .36816 Mtetra
.512 .628 .902 r
.19579 .36816 .20276 .37734 .21302 .37529 .20591 .3677 Mtetra
.592 .709 .925 r
.20591 .3677 .21302 .37529 .22329 .37378 .21626 .36545 Mtetra
0 .314 .801 r
.21626 .36545 .22329 .37378 .23453 .36219 .22589 .37139 Mtetra
.756 .931 .581 r
.22589 .37139 .23453 .36219 .24466 .36307 .23765 .35504 Mtetra
.583 .694 .918 r
.23765 .35504 .24466 .36307 .25515 .36056 .24811 .35297 Mtetra
.598 .714 .925 r
.24811 .35297 .25515 .36056 .2656 .35916 .25867 .35054 Mtetra
.648 .183 0 r
.25867 .35054 .2656 .35916 .27687 .34807 .26799 .36401 Mtetra
.7 .828 .385 r
.26799 .36401 .27687 .34807 .28731 .3479 .28037 .3399 Mtetra
.595 .702 .918 r
.28037 .3399 .28731 .3479 .29801 .34513 .29106 .33754 Mtetra
.614 .723 .923 r
.29106 .33754 .29801 .34513 .30873 .34267 .30183 .3347 Mtetra
.513 .671 .935 r
.30183 .3347 .30873 .34267 .32259 .29271 .31252 .33391 Mtetra
.341 .055 .325 r
.31252 .33391 .32259 .29271 .33071 .33182 .32392 .32284 Mtetra
.554 .66 .907 r
.32392 .32284 .33071 .33182 .34159 .3291 .33474 .32142 Mtetra
.623 .726 .921 r
.33474 .32142 .34159 .3291 .35254 .32592 .34572 .31831 Mtetra
.624 .729 .923 r
.34572 .31831 .35254 .32592 .36353 .32316 .35675 .31516 Mtetra
.548 .689 .932 r
.35675 .31516 .36353 .32316 .37222 .3695 .36774 .31369 Mtetra
.604 .409 .591 r
.36774 .31369 .37222 .3695 .38591 .31194 .37926 .30243 Mtetra
.54 .642 .899 r
.37926 .30243 .38591 .31194 .39704 .30912 .39033 .30134 Mtetra
.629 .729 .92 r
.39033 .30134 .39704 .30912 .40825 .30564 .40156 .29801 Mtetra
.639 .739 .921 r
.40156 .29801 .40825 .30564 .41951 .30204 .41285 .2944 Mtetra
.64 .74 .921 r
.41285 .2944 .41951 .30204 .43082 .29852 .42419 .29077 Mtetra
.628 .733 .923 r
.42419 .29077 .43082 .29852 .44216 .29575 .43557 .28741 Mtetra
.481 .651 .934 r
.43557 .28741 .44216 .29575 .45395 .27596 .44693 .28718 Mtetra
0 0 0 r
.44693 .28718 .45395 .27596 .46513 .28396 .45861 .27508 Mtetra
.586 .685 .909 r
.45861 .27508 .46513 .28396 .47663 .28066 .47012 .27278 Mtetra
.639 .737 .919 r
.47012 .27278 .47663 .28066 .48819 .27683 .4817 .26909 Mtetra
.649 .746 .92 r
.4817 .26909 .48819 .27683 .4998 .27282 .49335 .26511 Mtetra
.653 .749 .92 r
.49335 .26511 .4998 .27282 .51146 .26871 .50504 .26101 Mtetra
.656 .751 .92 r
.50504 .26101 .51146 .26871 .52317 .26452 .51678 .25681 Mtetra
.657 .753 .92 r
.51678 .25681 .52317 .26452 .53494 .26028 .52858 .25256 Mtetra
.658 .753 .92 r
.52858 .25256 .53494 .26028 .54675 .25601 .54042 .24825 Mtetra
.659 .754 .92 r
.54042 .24825 .54675 .25601 .55861 .25171 .55232 .24392 Mtetra
.55232 .24392 .55861 .25171 .57052 .24739 .56426 .23957 Mtetra
.56426 .23957 .57052 .24739 .58248 .24306 .57626 .2352 Mtetra
.57626 .2352 .58248 .24306 .5945 .23872 .58831 .23082 Mtetra
.658 .753 .92 r
.58831 .23082 .5945 .23872 .60656 .23437 .60041 .22643 Mtetra
.60041 .22643 .60656 .23437 .61868 .23 .61256 .22203 Mtetra
.61256 .22203 .61868 .23 .63085 .22562 .62477 .21761 Mtetra
.62477 .21761 .63085 .22562 .64307 .22123 .63703 .21318 Mtetra
.63703 .21318 .64307 .22123 .65535 .21681 .64934 .20873 Mtetra
.64934 .20873 .65535 .21681 .66768 .21238 .66171 .20427 Mtetra
.657 .753 .92 r
.66171 .20427 .66768 .21238 .68006 .20794 .67413 .19978 Mtetra
.67413 .19978 .68006 .20794 .6925 .20347 .68661 .19528 Mtetra
.68661 .19528 .6925 .20347 .70499 .19899 .69914 .19076 Mtetra
.69914 .19076 .70499 .19899 .71754 .19449 .71172 .18623 Mtetra
.657 .752 .92 r
.71172 .18623 .71754 .19449 .73014 .18997 .72436 .18167 Mtetra
.72436 .18167 .73014 .18997 .7428 .18544 .73706 .17709 Mtetra
.528 .657 .918 r
.06596 .40659 .07326 .41484 .08291 .41363 .07556 .40573 Mtetra
.347 .585 .933 r
.07556 .40573 .08291 .41363 .09448 .39831 .0849 .40722 Mtetra
.57 .868 .561 r
.0849 .40722 .09448 .39831 .10327 .40414 .096 .39595 Mtetra
.541 .666 .918 r
.096 .39595 .10327 .40414 .11308 .40266 .10577 .39483 Mtetra
.441 .635 .937 r
.10577 .39483 .11308 .40266 .12578 .37841 .11542 .39516 Mtetra
0 0 0 r
.11542 .39516 .12578 .37841 .13367 .39303 .12648 .38455 Mtetra
.534 .656 .914 r
.12648 .38455 .13367 .39303 .14365 .39127 .13637 .38357 Mtetra
.536 .682 .932 r
.13637 .38357 .14365 .39127 .15244 .40025 .14634 .38242 Mtetra
.723 .592 .71 r
.14634 .38242 .15244 .40025 .16447 .3814 .15751 .3714 Mtetra
.462 .582 .888 r
.15751 .3714 .16447 .3814 .17459 .37961 .16736 .37197 Mtetra
.58 .702 .926 r
.16736 .37197 .17459 .37961 .18466 .37875 .17757 .36996 Mtetra
.95 .603 .306 r
.17757 .36996 .18466 .37875 .19579 .36816 .18328 .41099 Mtetra
0 0 0 r
.18328 .41099 .19579 .36816 .20591 .3677 .19876 .35982 Mtetra
.585 .699 .921 r
.19876 .35982 .20591 .3677 .21626 .36545 .20912 .3577 Mtetra
.556 .693 .931 r
.20912 .3577 .21626 .36545 .22589 .37139 .21947 .35613 Mtetra
.749 .63 .728 r
.21947 .35613 .22589 .37139 .23765 .35504 .23082 .34444 Mtetra
.455 .566 .878 r
.23082 .34444 .23765 .35504 .24811 .35297 .24103 .34527 Mtetra
.603 .714 .922 r
.24103 .34527 .24811 .35297 .25867 .35054 .25162 .34269 Mtetra
.549 .69 .932 r
.25162 .34269 .25867 .35054 .26799 .36401 .26216 .34122 Mtetra
.695 .548 .683 r
.26216 .34122 .26799 .36401 .28037 .3399 .27353 .33003 Mtetra
.502 .61 .893 r
.27353 .33003 .28037 .3399 .29106 .33754 .28407 .32981 Mtetra
.613 .72 .921 r
.28407 .32981 .29106 .33754 .30183 .3347 .29486 .32696 Mtetra
.598 .715 .926 r
.29486 .32696 .30183 .3347 .31252 .33391 .30568 .32443 Mtetra
.931 .724 .601 r
.30568 .32443 .31252 .33391 .32392 .32284 .31971 .27423 Mtetra
0 0 .411 r
.31971 .27423 .32392 .32284 .33474 .32142 .32786 .31342 Mtetra
.609 .713 .919 r
.32786 .31342 .33474 .32142 .34572 .31831 .33884 .31063 Mtetra
.627 .73 .922 r
.33884 .31063 .34572 .31831 .35675 .31516 .3499 .30738 Mtetra
.609 .722 .925 r
.3499 .30738 .35675 .31516 .36774 .31369 .36098 .30454 Mtetra
.945 .583 .228 r
.36098 .30454 .36774 .31369 .37926 .30243 .36971 .35101 Mtetra
0 0 0 r
.36971 .35101 .37926 .30243 .39033 .30134 .38358 .29315 Mtetra
.611 .712 .917 r
.38358 .29315 .39033 .30134 .40156 .29801 .39481 .29026 Mtetra
.636 .736 .92 r
.39481 .29026 .40156 .29801 .41285 .2944 .40613 .2867 Mtetra
.64 .74 .921 r
.40613 .2867 .41285 .2944 .42419 .29077 .4175 .28302 Mtetra
.636 .738 .922 r
.4175 .28302 .42419 .29077 .43557 .28741 .42891 .27943 Mtetra
.605 .72 .926 r
.42891 .27943 .43557 .28741 .44693 .28718 .44036 .27658 Mtetra
.869 .735 .713 r
.44036 .27658 .44693 .28718 .45861 .27508 .45227 .25665 Mtetra
.258 .316 .733 r
.45227 .25665 .45861 .27508 .47012 .27278 .46356 .26461 Mtetra
.626 .724 .918 r
.46356 .26461 .47012 .27278 .4817 .26909 .47517 .26123 Mtetra
.645 .742 .92 r
.47517 .26123 .4817 .26909 .49335 .26511 .48684 .25732 Mtetra
.652 .748 .92 r
.48684 .25732 .49335 .26511 .50504 .26101 .49856 .25323 Mtetra
.655 .75 .92 r
.49856 .25323 .50504 .26101 .51678 .25681 .51034 .24903 Mtetra
.657 .752 .92 r
.51034 .24903 .51678 .25681 .52858 .25256 .52217 .24476 Mtetra
.658 .753 .92 r
.52217 .24476 .52858 .25256 .54042 .24825 .53405 .24044 Mtetra
.659 .754 .92 r
.53405 .24044 .54042 .24825 .55232 .24392 .54598 .23607 Mtetra
.54598 .23607 .55232 .24392 .56426 .23957 .55796 .23169 Mtetra
.55796 .23169 .56426 .23957 .57626 .2352 .56999 .22728 Mtetra
.56999 .22728 .57626 .2352 .58831 .23082 .58207 .22287 Mtetra
.658 .753 .92 r
.58207 .22287 .58831 .23082 .60041 .22643 .59421 .21844 Mtetra
.59421 .21844 .60041 .22643 .61256 .22203 .6064 .214 Mtetra
.6064 .214 .61256 .22203 .62477 .21761 .61864 .20954 Mtetra
.61864 .20954 .62477 .21761 .63703 .21318 .63094 .20507 Mtetra
.63094 .20507 .63703 .21318 .64934 .20873 .64329 .20059 Mtetra
.64329 .20059 .64934 .20873 .66171 .20427 .65569 .19608 Mtetra
.657 .753 .92 r
.65569 .19608 .66171 .20427 .67413 .19978 .66815 .19156 Mtetra
.66815 .19156 .67413 .19978 .68661 .19528 .68066 .18702 Mtetra
.68066 .18702 .68661 .19528 .69914 .19076 .69323 .18247 Mtetra
.69323 .18247 .69914 .19076 .71172 .18623 .70585 .17789 Mtetra
.70585 .17789 .71172 .18623 .72436 .18167 .71854 .1733 Mtetra
.657 .752 .92 r
.71854 .1733 .72436 .18167 .73706 .17709 .73127 .16868 Mtetra
.079 .198 .687 r
.05992 .38928 .06596 .40659 .07556 .40573 .06814 .39802 Mtetra
.544 .683 .929 r
.06814 .39802 .07556 .40573 .0849 .40722 .07786 .39675 Mtetra
.819 .7 .734 r
.07786 .39675 .0849 .40722 .096 .39595 .08955 .38132 Mtetra
.209 .33 .769 r
.08955 .38132 .096 .39595 .10577 .39483 .0984 .38712 Mtetra
.558 .689 .928 r
.0984 .38712 .10577 .39483 .11542 .39516 .10829 .38558 Mtetra
.871 .717 .689 r
.10829 .38558 .11542 .39516 .12648 .38455 .12113 .36118 Mtetra
0 .04 .567 r
.12113 .36118 .12648 .38455 .13637 .38357 .12905 .3758 Mtetra
.572 .695 .925 r
.12905 .3758 .13637 .38357 .14634 .38242 .13912 .37398 Mtetra
0 .03 .558 r
.13912 .37398 .14634 .38242 .15751 .3714 .14796 .38294 Mtetra
.791 .93 .561 r
.14796 .38294 .15751 .3714 .16736 .37197 .16012 .36396 Mtetra
.573 .69 .921 r
.16012 .36396 .16736 .37197 .17757 .36996 .17033 .36211 Mtetra
.52 .675 .934 r
.17033 .36211 .17757 .36996 .18328 .41099 .18048 .36119 Mtetra
.61 .42 .599 r
.18048 .36119 .18328 .41099 .19876 .35982 .19172 .3505 Mtetra
.512 .628 .902 r
.19172 .3505 .19876 .35982 .20912 .3577 .20192 .34999 Mtetra
.592 .709 .925 r
.20192 .34999 .20912 .3577 .21947 .35613 .21236 .34766 Mtetra
0 .317 .803 r
.21236 .34766 .21947 .35613 .23082 .34444 .22206 .35357 Mtetra
.763 .936 .589 r
.22206 .35357 .23082 .34444 .24103 .34527 .23394 .33709 Mtetra
.583 .694 .918 r
.23394 .33709 .24103 .34527 .25162 .34269 .2445 .33496 Mtetra
.598 .714 .925 r
.2445 .33496 .25162 .34269 .26216 .34122 .25514 .33246 Mtetra
.64 .176 0 r
.25514 .33246 .26216 .34122 .27353 .33003 .26453 .34592 Mtetra
.709 .835 .394 r
.26453 .34592 .27353 .33003 .28407 .32981 .27705 .32166 Mtetra
.595 .702 .918 r
.27705 .32166 .28407 .32981 .29486 .32696 .28783 .31923 Mtetra
.614 .723 .923 r
.28783 .31923 .29486 .32696 .30568 .32443 .2987 .31632 Mtetra
.513 .671 .934 r
.2987 .31632 .30568 .32443 .31971 .27423 .30948 .31547 Mtetra
.333 .045 .317 r
.30948 .31547 .31971 .27423 .32786 .31342 .321 .30429 Mtetra
.554 .66 .907 r
.321 .30429 .32786 .31342 .33884 .31063 .33191 .3028 Mtetra
.623 .726 .921 r
.33191 .3028 .33884 .31063 .3499 .30738 .34299 .29962 Mtetra
.624 .729 .923 r
.34299 .29962 .3499 .30738 .36098 .30454 .35412 .2964 Mtetra
.548 .689 .932 r
.35412 .2964 .36098 .30454 .36971 .35101 .36522 .29485 Mtetra
.602 .406 .589 r
.36522 .29485 .36971 .35101 .38358 .29315 .37685 .28349 Mtetra
.54 .642 .899 r
.37685 .28349 .38358 .29315 .39481 .29026 .38803 .28232 Mtetra
.629 .729 .92 r
.38803 .28232 .39481 .29026 .40613 .2867 .39936 .27892 Mtetra
.639 .739 .921 r
.39936 .27892 .40613 .2867 .4175 .28302 .41076 .27523 Mtetra
.64 .74 .921 r
.41076 .27523 .4175 .28302 .42891 .27943 .4222 .27152 Mtetra
.628 .733 .923 r
.4222 .27152 .42891 .27943 .44036 .27658 .4337 .26808 Mtetra
.482 .651 .934 r
.4337 .26808 .44036 .27658 .45227 .25665 .44516 .26779 Mtetra
0 0 0 r
.44516 .26779 .45227 .25665 .46356 .26461 .45697 .25557 Mtetra
.586 .685 .91 r
.45697 .25557 .46356 .26461 .47517 .26123 .46858 .2532 Mtetra
.639 .737 .919 r
.46858 .2532 .47517 .26123 .48684 .25732 .48028 .24943 Mtetra
.649 .746 .92 r
.48028 .24943 .48684 .25732 .49856 .25323 .49204 .24536 Mtetra
.653 .749 .92 r
.49204 .24536 .49856 .25323 .51034 .24903 .50385 .24117 Mtetra
.656 .751 .92 r
.50385 .24117 .51034 .24903 .52217 .24476 .51571 .23689 Mtetra
.657 .753 .92 r
.51571 .23689 .52217 .24476 .53405 .24044 .52762 .23255 Mtetra
.658 .753 .92 r
.52762 .23255 .53405 .24044 .54598 .23607 .53959 .22816 Mtetra
.659 .754 .92 r
.53959 .22816 .54598 .23607 .55796 .23169 .5516 .22374 Mtetra
.5516 .22374 .55796 .23169 .56999 .22728 .56367 .2193 Mtetra
.56367 .2193 .56999 .22728 .58207 .22287 .57579 .21485 Mtetra
.57579 .21485 .58207 .22287 .59421 .21844 .58796 .21038 Mtetra
.658 .753 .92 r
.58796 .21038 .59421 .21844 .6064 .214 .60018 .2059 Mtetra
.60018 .2059 .6064 .214 .61864 .20954 .61246 .2014 Mtetra
.61246 .2014 .61864 .20954 .63094 .20507 .62479 .1969 Mtetra
.62479 .1969 .63094 .20507 .64329 .20059 .63718 .19237 Mtetra
.63718 .19237 .64329 .20059 .65569 .19608 .64962 .18783 Mtetra
.64962 .18783 .65569 .19608 .66815 .19156 .66212 .18327 Mtetra
.657 .753 .92 r
.66212 .18327 .66815 .19156 .68066 .18702 .67467 .1787 Mtetra
.67467 .1787 .68066 .18702 .69323 .18247 .68728 .1741 Mtetra
.68728 .1741 .69323 .18247 .70585 .17789 .69994 .16949 Mtetra
.69994 .16949 .70585 .17789 .71854 .1733 .71266 .16486 Mtetra
.657 .752 .92 r
.71266 .16486 .71854 .1733 .73127 .16868 .72544 .1602 Mtetra
0 0 0 r
.04967 .40044 .05992 .38928 .06814 .39802 .06075 .38964 Mtetra
.528 .657 .918 r
.06075 .38964 .06814 .39802 .07786 .39675 .07043 .38873 Mtetra
.348 .586 .933 r
.07043 .38873 .07786 .39675 .08955 .38132 .07983 .39016 Mtetra
.583 .878 .574 r
.07983 .39016 .08955 .38132 .0984 .38712 .09104 .3788 Mtetra
.541 .666 .918 r
.09104 .3788 .0984 .38712 .10829 .38558 .10089 .37762 Mtetra
.442 .635 .937 r
.10089 .37762 .10829 .38558 .12113 .36118 .11061 .3779 Mtetra
0 0 0 r
.11061 .3779 .12113 .36118 .12905 .3758 .12178 .36719 Mtetra
.534 .656 .914 r
.12178 .36719 .12905 .3758 .13912 .37398 .13176 .36615 Mtetra
.536 .682 .932 r
.13176 .36615 .13912 .37398 .14796 .38294 .14181 .36494 Mtetra
.723 .592 .71 r
.14181 .36494 .14796 .38294 .16012 .36396 .15308 .35382 Mtetra
.462 .582 .888 r
.15308 .35382 .16012 .36396 .17033 .36211 .16302 .35433 Mtetra
.58 .702 .926 r
.16302 .35433 .17033 .36211 .18048 .36119 .17331 .35226 Mtetra
.95 .602 .301 r
.17331 .35226 .18048 .36119 .19172 .3505 .179 .3934 Mtetra
0 0 0 r
.179 .3934 .19172 .3505 .20192 .34999 .19469 .34197 Mtetra
.585 .699 .921 r
.19469 .34197 .20192 .34999 .21236 .34766 .20513 .33978 Mtetra
.556 .693 .931 r
.20513 .33978 .21236 .34766 .22206 .35357 .21557 .33814 Mtetra
.749 .63 .728 r
.21557 .33814 .22206 .35357 .23394 .33709 .22703 .32635 Mtetra
.454 .566 .878 r
.22703 .32635 .23394 .33709 .2445 .33496 .23733 .32712 Mtetra
.603 .714 .922 r
.23733 .32712 .2445 .33496 .25514 .33246 .24801 .32447 Mtetra
.549 .69 .932 r
.24801 .32447 .25514 .33246 .26453 .34592 .25865 .32294 Mtetra
.695 .548 .682 r
.25865 .32294 .26453 .34592 .27705 .32166 .27013 .31164 Mtetra
.501 .61 .893 r
.27013 .31164 .27705 .32166 .28783 .31923 .28076 .31136 Mtetra
.613 .72 .921 r
.28076 .31136 .28783 .31923 .2987 .31632 .29165 .30844 Mtetra
.598 .715 .926 r
.29165 .30844 .2987 .31632 .30948 .31547 .30257 .30584 Mtetra
.932 .724 .599 r
.30257 .30584 .30948 .31547 .321 .30429 .31678 .25538 Mtetra
0 0 .406 r
.31678 .25538 .321 .30429 .33191 .3028 .32496 .29465 Mtetra
.609 .713 .919 r
.32496 .29465 .33191 .3028 .34299 .29962 .33604 .29179 Mtetra
.627 .73 .922 r
.33604 .29179 .34299 .29962 .35412 .2964 .3472 .28847 Mtetra
.609 .722 .925 r
.3472 .28847 .35412 .2964 .36522 .29485 .35839 .28555 Mtetra
.944 .58 .222 r
.35839 .28555 .36522 .29485 .37685 .28349 .36716 .33214 Mtetra
0 0 0 r
.36716 .33214 .37685 .28349 .38803 .28232 .3812 .27399 Mtetra
.611 .713 .917 r
.3812 .27399 .38803 .28232 .39936 .27892 .39254 .27102 Mtetra
.636 .736 .92 r
.39254 .27102 .39936 .27892 .41076 .27523 .40396 .26738 Mtetra
.64 .74 .921 r
.40396 .26738 .41076 .27523 .4222 .27152 .41544 .26362 Mtetra
.636 .738 .922 r
.41544 .26362 .4222 .27152 .4337 .26808 .42697 .25994 Mtetra
.606 .72 .926 r
.42697 .25994 .4337 .26808 .44516 .26779 .43853 .25702 Mtetra
.87 .736 .713 r
.43853 .25702 .44516 .26779 .45697 .25557 .45056 .23695 Mtetra
.256 .315 .733 r
.45056 .23695 .45697 .25557 .46858 .2532 .46195 .24487 Mtetra
.626 .724 .918 r
.46195 .24487 .46858 .2532 .48028 .24943 .47367 .24141 Mtetra
.645 .742 .92 r
.47367 .24141 .48028 .24943 .49204 .24536 .48546 .23741 Mtetra
.651 .748 .92 r
.48546 .23741 .49204 .24536 .50385 .24117 .4973 .23323 Mtetra
.655 .75 .92 r
.4973 .23323 .50385 .24117 .51571 .23689 .5092 .22895 Mtetra
.657 .752 .92 r
.5092 .22895 .51571 .23689 .52762 .23255 .52114 .22459 Mtetra
.658 .753 .92 r
.52114 .22459 .52762 .23255 .53959 .22816 .53314 .22018 Mtetra
.659 .754 .92 r
.53314 .22018 .53959 .22816 .5516 .22374 .54519 .21573 Mtetra
.54519 .21573 .5516 .22374 .56367 .2193 .55729 .21125 Mtetra
.55729 .21125 .56367 .2193 .57579 .21485 .56945 .20676 Mtetra
.56945 .20676 .57579 .21485 .58796 .21038 .58166 .20225 Mtetra
.658 .753 .92 r
.58166 .20225 .58796 .21038 .60018 .2059 .59392 .19773 Mtetra
.59392 .19773 .60018 .2059 .61246 .2014 .60623 .1932 Mtetra
.60623 .1932 .61246 .2014 .62479 .1969 .6186 .18866 Mtetra
.6186 .18866 .62479 .1969 .63718 .19237 .63102 .18409 Mtetra
.63102 .18409 .63718 .19237 .64962 .18783 .6435 .17951 Mtetra
.6435 .17951 .64962 .18783 .66212 .18327 .65604 .17492 Mtetra
.657 .753 .92 r
.65604 .17492 .66212 .18327 .67467 .1787 .66863 .1703 Mtetra
.66863 .1703 .67467 .1787 .68728 .1741 .68127 .16567 Mtetra
.68127 .16567 .68728 .1741 .69994 .16949 .69398 .16102 Mtetra
.69398 .16102 .69994 .16949 .71266 .16486 .70673 .15634 Mtetra
.70673 .15634 .71266 .16486 .72544 .1602 .71955 .15165 Mtetra
.839 .708 .719 r
.04245 .3904 .04967 .40044 .06075 .38964 .05465 .37216 Mtetra
.076 .195 .686 r
.05465 .37216 .06075 .38964 .07043 .38873 .06292 .38088 Mtetra
.545 .683 .929 r
.06292 .38088 .07043 .38873 .07983 .39016 .07271 .37955 Mtetra
.82 .701 .734 r
.07271 .37955 .07983 .39016 .09104 .3788 .08453 .364 Mtetra
.207 .329 .769 r
.08453 .364 .09104 .3788 .10089 .37762 .09343 .36977 Mtetra
.558 .689 .928 r
.09343 .36977 .10089 .37762 .11061 .3779 .1034 .36817 Mtetra
.871 .717 .688 r
.1034 .36817 .11061 .3779 .12178 .36719 .11639 .34362 Mtetra
0 .035 .565 r
.11639 .34362 .12178 .36719 .13176 .36615 .12435 .35825 Mtetra
.572 .695 .925 r
.12435 .35825 .13176 .36615 .14181 .36494 .1345 .35636 Mtetra
0 .036 .564 r
.1345 .35636 .14181 .36494 .15308 .35382 .1434 .3653 Mtetra
.798 .934 .568 r
.1434 .3653 .15308 .35382 .16302 .35433 .15569 .34619 Mtetra
.573 .69 .921 r
.15569 .34619 .16302 .35433 .17331 .35226 .16598 .34427 Mtetra
.52 .675 .934 r
.16598 .34427 .17331 .35226 .179 .3934 .17622 .34329 Mtetra
.609 .417 .597 r
.17622 .34329 .179 .3934 .19469 .34197 .18756 .3325 Mtetra
.511 .628 .902 r
.18756 .3325 .19469 .34197 .20513 .33978 .19785 .33192 Mtetra
.592 .709 .925 r
.19785 .33192 .20513 .33978 .21557 .33814 .20838 .32953 Mtetra
0 .32 .805 r
.20838 .32953 .21557 .33814 .22703 .32635 .21816 .3354 Mtetra
.769 .94 .596 r
.21816 .3354 .22703 .32635 .23733 .32712 .23016 .3188 Mtetra
.583 .694 .918 r
.23016 .3188 .23733 .32712 .24801 .32447 .24081 .3166 Mtetra
.598 .714 .925 r
.24081 .3166 .24801 .32447 .25865 .32294 .25155 .31403 Mtetra
.633 .169 0 r
.25155 .31403 .25865 .32294 .27013 .31164 .261 .32749 Mtetra
.717 .841 .402 r
.261 .32749 .27013 .31164 .28076 .31136 .27366 .30307 Mtetra
.595 .702 .918 r
.27366 .30307 .28076 .31136 .29165 .30844 .28454 .30056 Mtetra
.614 .723 .923 r
.28454 .30056 .29165 .30844 .30257 .30584 .29551 .29757 Mtetra
.514 .671 .934 r
.29551 .29757 .30257 .30584 .31678 .25538 .30638 .29666 Mtetra
.325 .034 .308 r
.30638 .29666 .31678 .25538 .32496 .29465 .31802 .28538 Mtetra
.554 .66 .907 r
.31802 .28538 .32496 .29465 .33604 .29179 .32903 .28382 Mtetra
.623 .726 .921 r
.32903 .28382 .33604 .29179 .3472 .28847 .34021 .28055 Mtetra
.624 .729 .923 r
.34021 .28055 .3472 .28847 .35839 .28555 .35145 .27726 Mtetra
.548 .689 .932 r
.35145 .27726 .35839 .28555 .36716 .33214 .36265 .27564 Mtetra
.601 .404 .587 r
.36265 .27564 .36716 .33214 .3812 .27399 .3744 .26417 Mtetra
.54 .642 .899 r
.3744 .26417 .3812 .27399 .39254 .27102 .38568 .26293 Mtetra
.629 .729 .92 r
.38568 .26293 .39254 .27102 .40396 .26738 .39712 .25945 Mtetra
.639 .739 .921 r
.39712 .25945 .40396 .26738 .41544 .26362 .40862 .25568 Mtetra
.64 .74 .921 r
.40862 .25568 .41544 .26362 .42697 .25994 .42018 .25189 Mtetra
.628 .733 .923 r
.42018 .25189 .42697 .25994 .43853 .25702 .43179 .24837 Mtetra
.482 .651 .934 r
.43179 .24837 .43853 .25702 .45056 .23695 .44336 .248 Mtetra
0 0 0 r
.44336 .248 .45056 .23695 .46195 .24487 .45529 .23567 Mtetra
.585 .685 .91 r
.45529 .23567 .46195 .24487 .47367 .24141 .46702 .23322 Mtetra
.639 .737 .919 r
.46702 .23322 .47367 .24141 .48546 .23741 .47883 .22936 Mtetra
.649 .746 .92 r
.47883 .22936 .48546 .23741 .4973 .23323 .49071 .22521 Mtetra
.653 .749 .92 r
.49071 .22521 .4973 .23323 .5092 .22895 .50263 .22093 Mtetra
.656 .751 .92 r
.50263 .22093 .5092 .22895 .52114 .22459 .51461 .21656 Mtetra
.657 .753 .92 r
.51461 .21656 .52114 .22459 .53314 .22018 .52664 .21213 Mtetra
.658 .753 .92 r
.52664 .21213 .53314 .22018 .54519 .21573 .53873 .20766 Mtetra
.659 .754 .92 r
.53873 .20766 .54519 .21573 .55729 .21125 .55087 .20314 Mtetra
.55087 .20314 .55729 .21125 .56945 .20676 .56306 .19861 Mtetra
.56306 .19861 .56945 .20676 .58166 .20225 .5753 .19407 Mtetra
.5753 .19407 .58166 .20225 .59392 .19773 .5876 .18951 Mtetra
.658 .753 .92 r
.5876 .18951 .59392 .19773 .60623 .1932 .59995 .18493 Mtetra
.59995 .18493 .60623 .1932 .6186 .18866 .61236 .18035 Mtetra
.61236 .18035 .6186 .18866 .63102 .18409 .62482 .17575 Mtetra
.62482 .17575 .63102 .18409 .6435 .17951 .63733 .17113 Mtetra
.63733 .17113 .6435 .17951 .65604 .17492 .64991 .16649 Mtetra
.64991 .16649 .65604 .17492 .66863 .1703 .66253 .16184 Mtetra
.657 .753 .92 r
.66253 .16184 .66863 .1703 .68127 .16567 .67522 .15716 Mtetra
.67522 .15716 .68127 .16567 .69398 .16102 .68796 .15247 Mtetra
.68796 .15247 .69398 .16102 .70673 .15634 .70076 .14776 Mtetra
.70076 .14776 .70673 .15634 .71955 .15165 .71362 .14303 Mtetra
.385 .606 .936 r
.03488 .38233 .04245 .3904 .05465 .37216 .04426 .38327 Mtetra
0 0 0 r
.04426 .38327 .05465 .37216 .06292 .38088 .05544 .37237 Mtetra
.528 .657 .918 r
.05544 .37237 .06292 .38088 .07271 .37955 .0652 .3714 Mtetra
.349 .586 .932 r
.0652 .3714 .07271 .37955 .08453 .364 .07467 .37279 Mtetra
.596 .887 .587 r
.07467 .37279 .08453 .364 .09343 .36977 .08599 .36132 Mtetra
.541 .666 .918 r
.08599 .36132 .09343 .36977 .1034 .36817 .09592 .36008 Mtetra
.442 .635 .937 r
.09592 .36008 .1034 .36817 .11639 .34362 .10572 .3603 Mtetra
0 0 0 r
.10572 .3603 .11639 .34362 .12435 .35825 .11699 .34949 Mtetra
.534 .656 .914 r
.11699 .34949 .12435 .35825 .1345 .35636 .12705 .3484 Mtetra
.536 .682 .932 r
.12705 .3484 .1345 .35636 .1434 .3653 .13719 .34712 Mtetra
.723 .593 .71 r
.13719 .34712 .1434 .3653 .15569 .34619 .14856 .3359 Mtetra
.461 .582 .888 r
.14856 .3359 .15569 .34619 .16598 .34427 .15858 .33635 Mtetra
.58 .702 .926 r
.15858 .33635 .16598 .34427 .17622 .34329 .16896 .33422 Mtetra
.95 .6 .296 r
.16896 .33422 .17622 .34329 .18756 .3325 .17464 .37547 Mtetra
0 0 0 r
.17464 .37547 .18756 .3325 .19785 .33192 .19054 .32376 Mtetra
.585 .699 .921 r
.19054 .32376 .19785 .33192 .20838 .32953 .20107 .32151 Mtetra
.556 .693 .931 r
.20107 .32151 .20838 .32953 .21816 .3354 .2116 .31981 Mtetra
.75 .631 .728 r
.2116 .31981 .21816 .3354 .23016 .3188 .22318 .3079 Mtetra
.453 .566 .878 r
.22318 .3079 .23016 .3188 .24081 .3166 .23356 .30861 Mtetra
.603 .714 .922 r
.23356 .30861 .24081 .3166 .25155 .31403 .24434 .3059 Mtetra
.55 .689 .932 r
.24434 .3059 .25155 .31403 .261 .32749 .25507 .3043 Mtetra
.695 .547 .682 r
.25507 .3043 .261 .32749 .27366 .30307 .26667 .29289 Mtetra
.501 .61 .893 r
.26667 .29289 .27366 .30307 .28454 .30056 .27739 .29254 Mtetra
.613 .72 .921 r
.27739 .29254 .28454 .30056 .29551 .29757 .28838 .28955 Mtetra
.598 .715 .926 r
.28838 .28955 .29551 .29757 .30638 .29666 .29939 .28688 Mtetra
.934 .725 .598 r
.29939 .28688 .30638 .29666 .31802 .28538 .31378 .23617 Mtetra
0 0 .402 r
.31378 .23617 .31802 .28538 .32903 .28382 .32199 .27552 Mtetra
.609 .713 .919 r
.32199 .27552 .32903 .28382 .34021 .28055 .33318 .27258 Mtetra
.627 .73 .922 r
.33318 .27258 .34021 .28055 .35145 .27726 .34444 .26917 Mtetra
.609 .722 .925 r
.34444 .26917 .35145 .27726 .36265 .27564 .35574 .26618 Mtetra
.942 .578 .215 r
.35574 .26618 .36265 .27564 .3744 .26417 .36455 .31288 Mtetra
0 0 0 r
.36455 .31288 .3744 .26417 .38568 .26293 .37877 .25444 Mtetra
.611 .713 .917 r
.37877 .25444 .38568 .26293 .39712 .25945 .39022 .2514 Mtetra
.636 .736 .92 r
.39022 .2514 .39712 .25945 .40862 .25568 .40175 .24768 Mtetra
.64 .74 .921 r
.40175 .24768 .40862 .25568 .42018 .25189 .41334 .24383 Mtetra
.636 .738 .922 r
.41334 .24383 .42018 .25189 .43179 .24837 .42498 .24007 Mtetra
.606 .72 .926 r
.42498 .24007 .43179 .24837 .44336 .248 .43665 .23706 Mtetra
.871 .738 .713 r
.43665 .23706 .44336 .248 .45529 .23567 .44882 .21685 Mtetra
.253 .313 .732 r
.44882 .21685 .45529 .23567 .46702 .23322 .46031 .22472 Mtetra
.626 .724 .918 r
.46031 .22472 .46702 .23322 .47883 .22936 .47215 .22118 Mtetra
.645 .742 .92 r
.47215 .22118 .47883 .22936 .49071 .22521 .48405 .2171 Mtetra
.651 .748 .92 r
.48405 .2171 .49071 .22521 .50263 .22093 .49601 .21283 Mtetra
.655 .75 .92 r
.49601 .21283 .50263 .22093 .51461 .21656 .50803 .20846 Mtetra
.657 .752 .92 r
.50803 .20846 .51461 .21656 .52664 .21213 .5201 .20401 Mtetra
.658 .753 .92 r
.5201 .20401 .52664 .21213 .53873 .20766 .53222 .19951 Mtetra
.659 .754 .92 r
.53222 .19951 .53873 .20766 .55087 .20314 .54439 .19497 Mtetra
.54439 .19497 .55087 .20314 .56306 .19861 .55661 .1904 Mtetra
.55661 .1904 .56306 .19861 .5753 .19407 .56889 .18581 Mtetra
.56889 .18581 .5753 .19407 .5876 .18951 .58123 .18121 Mtetra
.658 .753 .92 r
.58123 .18121 .5876 .18951 .59995 .18493 .59362 .1766 Mtetra
.59362 .1766 .59995 .18493 .61236 .18035 .60606 .17197 Mtetra
.60606 .17197 .61236 .18035 .62482 .17575 .61856 .16733 Mtetra
.61856 .16733 .62482 .17575 .63733 .17113 .63111 .16267 Mtetra
.63111 .16267 .63733 .17113 .64991 .16649 .64372 .158 Mtetra
.64372 .158 .64991 .16649 .66253 .16184 .65639 .1533 Mtetra
.657 .753 .92 r
.65639 .1533 .66253 .16184 .67522 .15716 .66912 .14859 Mtetra
.66912 .14859 .67522 .15716 .68796 .15247 .6819 .14386 Mtetra
.6819 .14386 .68796 .15247 .70076 .14776 .69474 .13911 Mtetra
.69474 .13911 .70076 .14776 .71362 .14303 .70763 .13434 Mtetra
.537 .677 .928 r
.02724 .37432 .03488 .38233 .04426 .38327 .03695 .37309 Mtetra
.84 .709 .719 r
.03695 .37309 .04426 .38327 .05544 .37237 .04928 .35472 Mtetra
.072 .192 .685 r
.04928 .35472 .05544 .37237 .0652 .3714 .0576 .36342 Mtetra
.545 .683 .929 r
.0576 .36342 .0652 .3714 .07467 .37279 .06747 .36203 Mtetra
.821 .702 .734 r
.06747 .36203 .07467 .37279 .08599 .36132 .07941 .34636 Mtetra
.204 .328 .768 r
.07941 .34636 .08599 .36132 .09592 .36008 .08837 .3521 Mtetra
.558 .689 .928 r
.08837 .3521 .09592 .36008 .10572 .3603 .09842 .35043 Mtetra
.872 .718 .688 r
.09842 .35043 .10572 .3603 .11699 .34949 .11155 .32573 Mtetra
0 .031 .562 r
.11155 .32573 .11699 .34949 .12705 .3484 .11956 .34036 Mtetra
.572 .695 .925 r
.11956 .34036 .12705 .3484 .13719 .34712 .12979 .3384 Mtetra
0 .042 .57 r
.12979 .3384 .13719 .34712 .14856 .3359 .13875 .34732 Mtetra
.804 .937 .575 r
.13875 .34732 .14856 .3359 .15858 .33635 .15117 .32807 Mtetra
.573 .69 .921 r
.15117 .32807 .15858 .33635 .16896 .33422 .16155 .32609 Mtetra
.521 .675 .934 r
.16155 .32609 .16896 .33422 .17464 .37547 .17187 .32504 Mtetra
.607 .415 .596 r
.17187 .32504 .17464 .37547 .19054 .32376 .18333 .31415 Mtetra
.511 .628 .902 r
.18333 .31415 .19054 .32376 .20107 .32151 .1937 .31351 Mtetra
.592 .709 .925 r
.1937 .31351 .20107 .32151 .2116 .31981 .20432 .31105 Mtetra
0 .323 .808 r
.20432 .31105 .2116 .31981 .22318 .3079 .21418 .31688 Mtetra
.776 .944 .603 r
.21418 .31688 .22318 .3079 .23356 .30861 .2263 .30015 Mtetra
.583 .694 .918 r
.2263 .30015 .23356 .30861 .24434 .3059 .23705 .29788 Mtetra
.598 .714 .925 r
.23705 .29788 .24434 .3059 .25507 .3043 .24789 .29523 Mtetra
.625 .163 0 r
.24789 .29523 .25507 .3043 .26667 .29289 .25741 .30868 Mtetra
.725 .847 .411 r
.25741 .30868 .26667 .29289 .27739 .29254 .27021 .2841 Mtetra
.595 .702 .918 r
.27021 .2841 .27739 .29254 .28838 .28955 .28118 .28152 Mtetra
.614 .723 .923 r
.28118 .28152 .28838 .28955 .29939 .28688 .29225 .27846 Mtetra
.514 .671 .934 r
.29225 .27846 .29939 .28688 .31378 .23617 .30323 .27748 Mtetra
.316 .023 .299 r
.30323 .27748 .31378 .23617 .32199 .27552 .31498 .26609 Mtetra
.554 .66 .907 r
.31498 .26609 .32199 .27552 .33318 .27258 .32609 .26445 Mtetra
.623 .726 .921 r
.32609 .26445 .33318 .27258 .34444 .26917 .33738 .26111 Mtetra
.624 .729 .923 r
.33738 .26111 .34444 .26917 .35574 .26618 .34872 .25773 Mtetra
.548 .688 .931 r
.34872 .25773 .35574 .26618 .36455 .31288 .36003 .25604 Mtetra
.599 .401 .585 r
.36003 .25604 .36455 .31288 .37877 .25444 .37189 .24446 Mtetra
.539 .642 .9 r
.37189 .24446 .37877 .25444 .39022 .2514 .38328 .24315 Mtetra
.629 .729 .92 r
.38328 .24315 .39022 .2514 .40175 .24768 .39483 .23958 Mtetra
.639 .739 .921 r
.39483 .23958 .40175 .24768 .41334 .24383 .40645 .23573 Mtetra
.64 .74 .921 r
.40645 .23573 .41334 .24383 .42498 .24007 .41812 .23185 Mtetra
.628 .733 .923 r
.41812 .23185 .42498 .24007 .43665 .23706 .42984 .22825 Mtetra
.483 .651 .933 r
.42984 .22825 .43665 .23706 .44882 .21685 .44152 .22781 Mtetra
0 0 0 r
.44152 .22781 .44882 .21685 .46031 .22472 .45357 .21536 Mtetra
.585 .685 .91 r
.45357 .21536 .46031 .22472 .47215 .22118 .46542 .21283 Mtetra
.639 .737 .919 r
.46542 .21283 .47215 .22118 .48405 .2171 .47735 .20888 Mtetra
.649 .746 .92 r
.47735 .20888 .48405 .2171 .49601 .21283 .48934 .20464 Mtetra
.653 .749 .92 r
.48934 .20464 .49601 .21283 .50803 .20846 .50139 .20027 Mtetra
.656 .751 .92 r
.50139 .20027 .50803 .20846 .5201 .20401 .51349 .19581 Mtetra
.657 .753 .92 r
.51349 .19581 .5201 .20401 .53222 .19951 .52565 .19129 Mtetra
.658 .753 .92 r
.52565 .19129 .53222 .19951 .54439 .19497 .53786 .18672 Mtetra
.659 .754 .92 r
.53786 .18672 .54439 .19497 .55661 .1904 .55012 .18212 Mtetra
.55012 .18212 .55661 .1904 .56889 .18581 .56244 .17749 Mtetra
.56244 .17749 .56889 .18581 .58123 .18121 .57481 .17285 Mtetra
.57481 .17285 .58123 .18121 .59362 .1766 .58723 .1682 Mtetra
.658 .753 .92 r
.58723 .1682 .59362 .1766 .60606 .17197 .59971 .16353 Mtetra
.59971 .16353 .60606 .17197 .61856 .16733 .61225 .15885 Mtetra
.61225 .15885 .61856 .16733 .63111 .16267 .62484 .15415 Mtetra
.62484 .15415 .63111 .16267 .64372 .158 .63749 .14943 Mtetra
.63749 .14943 .64372 .158 .65639 .1533 .6502 .1447 Mtetra
.6502 .1447 .65639 .1533 .66912 .14859 .66296 .13994 Mtetra
.657 .753 .92 r
.66296 .13994 .66912 .14859 .6819 .14386 .67578 .13517 Mtetra
.67578 .13517 .6819 .14386 .69474 .13911 .68866 .13038 Mtetra
.68866 .13038 .69474 .13911 .70763 .13434 .7016 .12557 Mtetra
.487 .622 .91 r
.01973 .36514 .02724 .37432 .03695 .37309 .02929 .36489 Mtetra
.386 .606 .936 r
.02929 .36489 .03695 .37309 .04928 .35472 .03874 .36577 Mtetra
0 0 0 r
.03874 .36577 .04928 .35472 .0576 .36342 .05004 .35477 Mtetra
.528 .657 .918 r
.05004 .35477 .0576 .36342 .06747 .36203 .05987 .35374 Mtetra
.35 .586 .932 r
.05987 .35374 .06747 .36203 .07941 .34636 .06941 .35507 Mtetra
.608 .896 .599 r
.06941 .35507 .07941 .34636 .08837 .3521 .08084 .3435 Mtetra
.541 .666 .918 r
.08084 .3435 .08837 .3521 .09842 .35043 .09085 .3422 Mtetra
.443 .635 .937 r
.09085 .3422 .09842 .35043 .11155 .32573 .10073 .34237 Mtetra
0 0 0 r
.10073 .34237 .11155 .32573 .11956 .34036 .11211 .33146 Mtetra
.534 .656 .914 r
.11211 .33146 .11956 .34036 .12979 .3384 .12225 .3303 Mtetra
.536 .682 .932 r
.12225 .3303 .12979 .3384 .13875 .34732 .13247 .32896 Mtetra
.723 .593 .71 r
.13247 .32896 .13875 .34732 .15117 .32807 .14396 .31764 Mtetra
.461 .582 .889 r
.14396 .31764 .15117 .32807 .16155 .32609 .15406 .31803 Mtetra
.58 .702 .926 r
.15406 .31803 .16155 .32609 .17187 .32504 .16453 .31582 Mtetra
.95 .598 .29 r
.16453 .31582 .17187 .32504 .18333 .31415 .1702 .35718 Mtetra
0 0 0 r
.1702 .35718 .18333 .31415 .1937 .31351 .1863 .30521 Mtetra
.585 .699 .921 r
.1863 .30521 .1937 .31351 .20432 .31105 .19693 .30288 Mtetra
.557 .693 .931 r
.19693 .30288 .20432 .31105 .21418 .31688 .20755 .30111 Mtetra
.75 .631 .728 r
.20755 .30111 .21418 .31688 .2263 .30015 .21924 .28909 Mtetra
.453 .565 .878 r
.21924 .28909 .2263 .30015 .23705 .29788 .22972 .28975 Mtetra
.603 .714 .922 r
.22972 .28975 .23705 .29788 .24789 .29523 .24059 .28696 Mtetra
.55 .689 .932 r
.24059 .28696 .24789 .29523 .25741 .30868 .25141 .28528 Mtetra
.695 .547 .682 r
.25141 .28528 .25741 .30868 .27021 .2841 .26313 .27377 Mtetra
.501 .61 .893 r
.26313 .27377 .27021 .2841 .28118 .28152 .27394 .27335 Mtetra
.613 .72 .921 r
.27394 .27335 .28118 .28152 .29225 .27846 .28504 .27028 Mtetra
.598 .715 .926 r
.28504 .27028 .29225 .27846 .30323 .27748 .29616 .26753 Mtetra
.935 .726 .596 r
.29616 .26753 .30323 .27748 .31498 .26609 .31073 .21658 Mtetra
0 0 .397 r
.31073 .21658 .31498 .26609 .32609 .26445 .31897 .256 Mtetra
.609 .713 .919 r
.31897 .256 .32609 .26445 .33738 .26111 .33026 .25298 Mtetra
.627 .73 .922 r
.33026 .25298 .33738 .26111 .34872 .25773 .34163 .24949 Mtetra
.609 .722 .925 r
.34163 .24949 .34872 .25773 .36003 .25604 .35304 .24642 Mtetra
.941 .575 .208 r
.35304 .24642 .36003 .25604 .37189 .24446 .36189 .29323 Mtetra
0 0 0 r
.36189 .29323 .37189 .24446 .38328 .24315 .3763 .2345 Mtetra
.611 .713 .917 r
.3763 .2345 .38328 .24315 .39483 .23958 .38785 .23137 Mtetra
.636 .736 .92 r
.38785 .23137 .39483 .23958 .40645 .23573 .3995 .22756 Mtetra
.64 .74 .921 r
.3995 .22756 .40645 .23573 .41812 .23185 .4112 .22363 Mtetra
.636 .738 .922 r
.4112 .22363 .41812 .23185 .42984 .22825 .42296 .21979 Mtetra
.606 .72 .925 r
.42296 .21979 .42984 .22825 .44152 .22781 .43474 .2167 Mtetra
.872 .739 .713 r
.43474 .2167 .44152 .22781 .45357 .21536 .44703 .19634 Mtetra
.251 .312 .732 r
.44703 .19634 .45357 .21536 .46542 .21283 .45864 .20416 Mtetra
.626 .725 .918 r
.45864 .20416 .46542 .21283 .47735 .20888 .4706 .20053 Mtetra
.645 .742 .92 r
.4706 .20053 .47735 .20888 .48934 .20464 .48262 .19636 Mtetra
.651 .748 .92 r
.48262 .19636 .48934 .20464 .50139 .20027 .4947 .192 Mtetra
.655 .75 .92 r
.4947 .192 .50139 .20027 .51349 .19581 .50684 .18754 Mtetra
.657 .752 .92 r
.50684 .18754 .51349 .19581 .52565 .19129 .51903 .183 Mtetra
.658 .753 .92 r
.51903 .183 .52565 .19129 .53786 .18672 .53127 .1784 Mtetra
.659 .754 .92 r
.53127 .1784 .53786 .18672 .55012 .18212 .54357 .17377 Mtetra
.54357 .17377 .55012 .18212 .56244 .17749 .55592 .1691 Mtetra
.55592 .1691 .56244 .17749 .57481 .17285 .56833 .16442 Mtetra
.56833 .16442 .57481 .17285 .58723 .1682 .58079 .15973 Mtetra
.658 .753 .92 r
.58079 .15973 .58723 .1682 .59971 .16353 .59331 .15502 Mtetra
.59331 .15502 .59971 .16353 .61225 .15885 .60589 .15029 Mtetra
.60589 .15029 .61225 .15885 .62484 .15415 .61852 .14555 Mtetra
.61852 .14555 .62484 .15415 .63749 .14943 .6312 .1408 Mtetra
.6312 .1408 .63749 .14943 .6502 .1447 .64395 .13602 Mtetra
.64395 .13602 .6502 .1447 .66296 .13994 .65675 .13123 Mtetra
.657 .753 .92 r
.65675 .13123 .66296 .13994 .67578 .13517 .66961 .12641 Mtetra
.66961 .12641 .67578 .13517 .68866 .13038 .68253 .12158 Mtetra
.68253 .12158 .68866 .13038 .7016 .12557 .69551 .11673 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`8006Aoo`03D_aBoE;l009Bo008D_eB
o5;lD_aBoE;l001Bo1Moo`03001oogoo04Uoo`00Sgoo0`00I7oo00mBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_d05Woo00<007oo0000BWoo002=Ool3001ROol00e;lD_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo000009Bo1Moo`03001oogoo04Qoo`00RWoo0`000goo00<007ooOol0GGoo
01MBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m01Moo`03001oogoo
04Moo`00Qgoo0`00Hgoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eB
o000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069oo`0PD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoAIoo`03001oogoo04Ioo`00
PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eoo`00P7oo0P00Hgoo02EBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00=BoE;lOol0
5Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1MOol0;5;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EB
oE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00HGoo03ABo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo049oo`00Lgoo0`00HGoo0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00ABoE;lD_aBo1Moo`03001oogoo045oo`00LGoo0P00
HWoo03UBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_`0
5Goo00<007oo0000@Woo001^Ool3001POol2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;m001Bo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001oogoo041oo`00Jgoo0`00HGoo041B
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoAMoo`03001oogoo03moo`00JGoo0P000goo00<007ooOol0Fgoo00=Bo5;mD_`00U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aB
o@02D_`FOol00`00Oomoo`0oOol006Ioo`<0065oo`17D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0FOol0
0`00Oomoo`0nOol006Aoo`80069oo`=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Ioo`03001oogoo
03eoo`00HGoo0`00H7oo04mBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol0
0`00Oomoo`0UOol3000EOol003Eoo`@002Ioo`8005moo`03D_aBoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;m
D_`00U;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Eoo`03001oogoo02Ioo`03001oogoo01=oo`00
=7oo00<007ooOol00Woo00<007ooOol087oo0`00H7oo05E>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0UOol00`00Oomoo`0COol003Uoo`03
001oogoo01ioo`80009oo`03001oogoo05aoo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;m
D_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`EOol00`00Oomoo`0TOol00`00Ool0000DOol002aoo`H0
00Moo`03001oogoo01]oo`<005Ioo`03K_HM5Qdg00Ioo`1LC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo02=oo`03001o
o`0001Aoo`00=Goo100077oo0P00FGoo0Vkf0adf00I>gDkLC]a>g4kMC]`2D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m01Ioo`03001o
ogoo025oo`05001oogooOol0000COol003Eoo`03001oogoo01Yoo`<005Yoo`1XJ]E^mVkE7CLM5Qdg
7CI>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoAAoo`8002=oo`05001oogooOol0000COol003Eoo`03001oogoo01Moo`<0
05eoo`05K_I^eVkf7CHM=`027CH00dkLC]e>g002C]`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0OOol30000
17oo000000004Woo000eOol5000COol2001OOol0JVkfK]E^mV[EK_HM=Qdg7AHM=dkLD_e>g5;mC]aB
oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l5Woo00<007ooOol0=goo001:Ool300000goo001oo`1NOol01FkFK_I^mVkfK]H00dZl00Q6_4Zl
C]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`EOol00`00Oomoo`08Ool4000[Ool004Qoo`8006=oo`05K]E^mV[EK_I^e@020000
IDZlA[a:_4JLD_e>g5;mC]aBoDklD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d05Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0
:7oo0015Ool3001QOol01D[MB]a>gD[LB]d00Vkf00E^eVkf7CH004Jl00=:_005A[aBo5;lD_e>g002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l5Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0:7oo0013Ool2000nOol00gKB
Oomoo`0OOol0MDkLD_e>g5;mC]a>gD[LC]e:g6kfK]E^mV[E7CLM=QdgC]a>oDkLC]e>g5;mC]aBoDkL
D_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo00FOol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol0041oo`<0041oo`03M]80
37oo01]oo`0BD_e>g4klC_aBoDkLC_e>g4kmC]a:gD[LC]e:g6kfK]I^mVkF0Qdf00HM=dkLC]a>g4kM
C]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o006D_eBo5;lD_aBoE;l5Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0:7oo000nOol2
0013Ool00g;B00aoo`0GOol0OdkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g3jM>Wa^mV[EK_IZ
eFkf7CHM=adfC]e>g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo02Qoo`00>goo1000@goo0WKB00<02gooOol04goo00=:g4kLB]`00TkL00I>oDkLC_a>
o5;mC]`2C_`01DkmC]a>gDkLC_d00SZM00I^eVkfK]I^mVkFK_H37CH01E;mC]a>o4kLD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo7oo01Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00>Goo0P0017oo
00<007ooOol0@7oo00=flWKB00`05Goo08@004ZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4km
C]a>oF[EK_IZeFkfJ]E^mV[EB[a6W4ZlA[aBoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomo
o`03Ool4000[Ool003Ioo`<004Uoo`9fdP8031Aoo`09001>g4[LC]a:g4kLC_aBoDkL009>o006D_e>
g4klC_aBoD[L0T[M00I>gFkFK_I^eVkfK]H200002DZlA[a:_4ZlD_e>g4klD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@0COol200000goo001oo`0bOol003=oo`<004aoo`04M]9bdWKb00/COol30000Pe;mC]a>oDkLD_e>
g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4kMJ]E^mV[EK_HM=R4gA[a:_4JLB[a6_5;mC]aBoDkLD_e>
g5;mC_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d05Goo00<007ooOol0<Goo000aOol2001>Ool4M]800`0<Oomoo`0@Ool01@00@Ya2
O4:L@W`00TkL00i>gDkLC_a>o5;mC]a>o4kLC_e>g4kmC]a>gD[L0T[M00E^mVkFK_I^eQdg008M=P03
C]a>gDkL009>g005D_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d00000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0`Ool002ioo`<0051o
o`05L]9flWKBM]802`08Ool01DkMB]a>gD[LMTH017oo06Yf9@00@W]6W49k@Ya>g5;mC]a>oDkLD_e>
g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e:g6kfJ]E^mQdf7CLM=R4gC]a>gDkLC_e>g5;mC]aBoDkLD_e>
g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@<0000MD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@0EOol00`00Oomoo`0_Ool002aoo`@0055oo`AfdP0300`02goo00Aoo`07C]a>gDkL
B]e:g4kMMRD00goo00ef9GHV0012W49l@Ya2O4:LC]a>o4kLC_e>g002C_`04U;mC]a>o4kLC_e>g4kM
C]`nWCZMK_I^eVkfK]I^mQdf7CLM=P9>g005C]e>g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00<00006D_eBo5;lD_aB
o@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<0
07ooOol0;goo000ZOol2001DOol01gKbM]9fdW;BM_802`0<00=oo`1aC_e>g4kmC]a>oDkLC]e:g4kM
MREoogHUMTH004fBBG5>gDZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oCYm?YeZeFkf
J]E^mV[E8CLM=Qdg7CIBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@03000095;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo02io
o`00:Woo0P00E7oo1GKB0P0<00i>gD[LB]a:g4kMC]a>gDkLC]e>g4[MB]afAWHU0WHV00X004VABI80
04kLB]a>g4[LC_e>g09>o00@D_e>g4klC_aBoDkLC]e>g4kmC]a>gFkFK_I^eVkfK]H20004B[`01dkl
C]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;l
D_aBoE;l0P0000EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Goo00<007ooOol0;Woo000@Ool50003Ool40004
Ool40006Ool00`00Ool0001COol00gKBL]9flP02M]805@0;00`02dkMB[a>gDZlC]e:g4kmC]a>oD[L
A[ef9GI6MREfAP00BI99L@020000FTkMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e:g4kM
J]E^mV[EK_HM=P00AYa:_4JlB[a6W5;mC]aBoDkLD_e>o5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo0<0000ZD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<007oo
Ool0;Goo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo
0P0000=oo`00Ool0D7oo1WKB00D0300;00`034kM00=>g006C]e>g4kMC]a>gD:m0WHV00AfAWHU0019
TP@00006C]e>g4kLC]aBoDkL0Tkl00IBoDkLC_e>g4kmC]`2B]d02DkMB]a^mVkF?Ye^eVkf7CHM=`03
C]`01TkMC]aBo5;lD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eB
o000008000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol0;7oo000BOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo0P000goo00<007oo
Ool0CWoo075bdWKbM]9fdW;BM_92W4JL@Ya6W4:LC]e:g4kmC]a>oD[LC_e>g4kmMREfAWHUMTI9LDfB
BI56W49kAYa2NdkmC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e:g3jMJ]E^mV[E8CLM=R4g
C]a>oDkLC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00<0000a
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol0;7oo0007Ool6
0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0BWoo00A:g4[MB]e:g@IfdP96W004@Ya6W4kLC]d3C]`01TkMB]a:gD[LA[ef
9@9f9P0>BI99TDVB@Wa2W49l@Ya2O4kmC]a>o4kLC_e>g09>o006D_e>g4kmC]a>oDkL0SZM00DnWFkF
K_I^eVkf00<M=P05C]e>g4kLC]a>g@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l
0`000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol057oo00<007oo
Ool0:goo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol0AGoo00]>gD[LC]e:g4kMB[a>gD[LB]ebdWKb009fdP1UL]8034:L
AYa2W4JLC]a>oDkLC_e>g4kMB]a>gD:lMTIf9@00BG59TTUaCI9:_4kMB[a>gDZlD_e>g5;mC]aBoDkL
D_e>g5;mC]a>oDkLC_e>g3jM>We^mV[EK_IZeFkf7CHQ=adfD_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo0030000>E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo00COol00`00Ool0000/Ool0019oo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`02Ool20006Ool20010Ool035HeEQDnO3iK?W`nFdkMB]a>g4[L
B]e:g09:g@EfdP80300?B]a>gD[LB]a>g4kMC]a>gDkLC]e:g4[MMRIfAP0000A9TP04001:g4kLB]`2
C]`01TkmC]a>o4kLD_e>g09>o00<D_e>g4kMC]a>oDkLK_I^eVkfK]I^mVkF14Zl00EBoDkLC_a>g5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01U;mD_aBo5;lD_eBo0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0ZOol0011oo`<000Aoo`03001o
ogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0mOol0@EHD
FSEF53il?U/nO4[LC]e:g4kMB]a:gDZlC]e:g7KBL]9flgKB00`02`0<B[a>gDZlC]e>g4kmC]a>oDkL
A[e2_7I6MRE9TTUaCI99TDVB001>gDZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gD[L
K_IZeFkfJ]D00P0002i:_4JLB[a6_5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo0<00010D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dE
Ool00`00Oomoo`0YOol0019oo`03001oogoo00=oo`@000Aoo`@000Eoo`03001oogoo00Qoo`03001o
ogoo03]oo`0?EQEF=EHEESDnFcil?U/nO4kLC]e:g4kMC]a2_CjM00EfdP<0309:g00;C]e:g4[LC]a>
gDkLC]e>g4JmMREf9P04BI830002C]`01TkMC]a>g4klD_e>g09>o006C_e>g4kmC]a>oD[L0d[M00A^
eVkfK]I^mP8M=PE:_005D_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<0
05;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Woo00<007oo
Ool0:7oo000XOol00`00Oomoo`0:Ool00`00Oomoo`0iOol04UHDFSEF55HeEQAJ=DZlB]e:_4[MB]a>
gD[LC_dnWGKBL]9fl`9fdP1JL]80300;00`02dkmC]a>gD[LC_e>g4kmB]a>oDkLMTIf9DfBBG59TTUa
AYa2NdJL@W]BoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMB]a>gF[EK_IZeB4g7CHQEdkL
C]e>g4kmC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<M0P0004MBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Eoo`03001oogoo02Qo
o`00:7oo0`002goo00<007ooOol0=7oo00e6_D:mA[e2_EHeEQEF=EHEESEF5E]<B[a:g@02B[`014kL
C]e:g4kM1gKB0dJL00A2W4kLC]a>g@9>g007B]a>gD[LB]e2_@00BI4014VB00A2W49l@Ya2O09>g00>
C]e>g4klC_aBoDkLC_a>g4kmC]a>oDkLB]e:g09:g@05K_I^eVkF7CHM=`027CH00dkLC]e>g002C]`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0U;l0`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`EOol00`00Oomoo`0WOol002Qoo`03001o
ogoo00aoo`03001oogoo02]oo`0AGWINMcHk>S]:_4kMB[a>gDZlA[e2_4Jm@[aF=EHDFSEF5002Fd`0
2D[MB[a:gDZlB]e:g4[MB[a>g@02M]80EW;BM_=bdWKB00]6W4:LAYa2W4kmC]a>oDkLC_e:g4kMB]a6
_DUaBI99LDfBBI5=TT9kAYa2NdJL@W]BoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL?YdjO6kfJ]E^
mV[EK_HM=R4g7CHQEdkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDad30000CU<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eo
o`03001oogoo02Ioo`00:7oo00<007ooOol03Goo00<007ooOol0:Goo0eif00lj>cHk=S]:g4[MB]a:
gD[LA[e2_DJmEQEF=EHEESD00e]<00E>g4[LC]e:g4kL009:g@03B]a:gGKB00AfdP80309:g00:C]e:
g4kMC]a>gDkLB]e:g4kMB]`7BI802D[LC]a:g4kLB]a>o4kLC_e>g002C_`02E;mC]a>o4kLC_e>g4kM
>YdnW@03K]H00fkfK]I:_004B[`01TkLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoE;lD_`00`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;m
D_aBo5;l57oo00<007ooOol09Woo000XOol2000?Ool00`00Oomoo`0WOol095ifGWMJMUjGGWHj>cHk
>S/f>d[MB[a>gDZlA[e2_5XeEQAF=EHDFSDnFcil?U]>gD[LC]e:g4kMB]a:gDZlC]ebdWKBL]9fl`80
301:00]>gDZlC]e:_4kmC]a>oDkLA[e2_4JmBG5=TTVABI99LDfBBI4004ZlC]e:_4kMB[aBoDkLD_e>
g5;mC]aBoDkLD_e>g4kmC]a>oF[EK_IZeFkfJ]DQ=`00B[a6_4ZlAYaBoDkLD_e>g5;mC_aBoDkLD_e>
o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7@<0001FDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo02Eoo`00:7oo00<007ooOol03goo
00<007ooOol09Goo1Uif00=:_4ZmA[`00TZl01E:gD[LB]e:g4JmEQEF=EHEESEF5Cil?U/nO3iKC]e>
g4kMB]a>gCjM@[d01GKB0`0<0d[L00Y>gD[LC]e>g4kMC]a6_D:mA[e9T@A9TP<000=>g006C]e>g4kl
C_aBoDkL0Tkl00=BoDkLC_d00T[M00A:g4[MK]I^mP=^eP038CM:_4Zl00=:_09Bo005D_e>g5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`00`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Goo00<007ooOol097oo000XOol00`00Oomo
o`0@Ool00`00Oomoo`0QOol0:D:lA]e2_5igFWINUeifGWMO/V?CA[a:_DJlB]e:_4[MB[a>gD:lA[eF
55XeEQAF=EHDB]e:_4[MB[a>oD[LC]e:g4:mL]9fdW;BM_=bdWKB00/00`0<049:g4kmC]a>gD[LC_e>
g4kmB]a>oD:lBI99LDfBBI5=TT9kAYa2NdJLC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:
g6kfJ]E^mV[EK_HM=R4gC]a>oDkLC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_d3
0000GE<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@0COol2000VOol002Moo`03001oogoo019oo`03001oogoo01aoo`05B[e6_4ZlB[a:
_@03A[d4GWH3Hk803dZlB[e6_4Zl@[e6_D:mA[e2_EHeEQEF=EHEESEKC002B[`01T[MB[a>gDkLC]e:
g0MfdP04@Ya6W4JLAY`3C]`01dkMC]a:gD[LC]e:g4Jm00I9TP04@Wa2W49lC]d3C]`02dkMC]a>o4kl
D_e>g4kmC]a>oDkLC_d00T[M00E:g3ZMK]I^mV[F008M=P068CM>g4kLC]a>gDkL0U;l00EBoE;lD_aB
o5;m00=Bo003D_eBo5;l00<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`DOol00`00Oomoo`0SOol002Moo`<001=o
o`03001oogoo01]oo`1/001:gDJlB]e6_4Jm@[a6gEifGWMJMV?CGk9S/enbHm=:_4kMB[a>gD:lA[e2
_4JmEQAF=EHDFSEKBe]<B[a:gDZlB]e:_4kMB]a:gDZlM_=bdWKBL]9flg;B00a2W4JL@Ya6W4kLC_e>
g4kmC]a>gD[LC]e2_4fBBI59TTUaCI99TTJL@W]6W49kD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>
g4km>WdnWF[EK_IZeFkfJ]DQEadfC]e>g4kmC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;m0`0006ABoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo029oo`009goo00<007ooOol057oo00<007ooOol06Goo
100000=6_4ZlB[`00TJm0Uif00ES/UifGWHf>cXk008f>`0;B]a:gD[LB]e2_DJm@[eF=EHEESEF5@03
Fd`01D[LC]a:g4kMB]`00d[M00=:g7KBM]800gKB0P0<0d[L00U>gDkLC]e>g4kMB]a:gD[LA[d01dVB
00Y>g4[LC]a:g4kmC]a>o4kLC_e>g09>o006D_e>g4kMC]a>oDkL0SZM00E^mV[FK]I^eVkf00<M=P05
D_e>g4klC]aBo@03D_`015;mD_aBo5;l0P000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`DOol0
0`00Oomoo`0ROol001Eoo`@000Aoo`@000Ioo`03001oogoo01Eoo`03001oogoo01Qoo`0_@W`nNd9l
?W]2O4JlB]e:_4Jm@[aNUeifGWMJMUjG=S/j>cHk>S]:_4kMB[a>gD:lA[eF55XeEQAF=EHD?W`nFcil
B]a>gD[LC]e:g4kMB]a:gDZlM_=bdWKBL]803@0200`0:TZlC]e:_4kMC]a>oDkLC_e2_4Jm@[a9TTUa
CI99TDfBBI5=TP00C]e:_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLK_IZeFkfJ]E^mP80
000;AYa:_4JlD_e>g5;mC]aBoDkLD_e>o0030000JU;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m5Goo00<007ooOol08Goo000DOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo
00<007ooOol05Woo0P003goo00A:_DJmB]efB0Aoo`03MTQ9TSil00<nO004B]e:_4[MB]`7GWH05dZl
B[e6_4ZlB]a:gD[LB]e2_EHeEQEF=EHEESDnFcil?U/nO3iKC]e>g4kMB]`00SjM1GKB0`0<00]>gD[L
B]a:g4kMC]a>gDkLC]e2_DJm00I9TP800003B]a>g4[L009>g006C]e>g4klC_aBoDkL0Tkl00=BoD[L
B]d00T[M00E:g6kFK]I^mV[F008M=PA:_004D_e>g5;lD_`300000e;lD_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04goo00<007ooOol087oo000IOol01000Oomoo`0017oo
00<007ooOol00goo0P006Goo00<007ooOol01goo00UJEUXe>U`f>cYL=S]:gDJlNTT00Woo035fB7Y9
001=/TVB@W`nNd9l?W]6_D:lA]e2_5igFWINUeifGWMO/V>bA[a:_DJlC]e:_4[MB[a@X4:lESEF55Xe
EQAF=DZlB]e:_4[MB[a>oD[LC]dnW7KcL]9fdW;BM_=bdP0200`04P0=00a>gD[LC_e>g4kMB]a>oDkL
A[e2_4JmBI5=TTUaCI99TP<0000MC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4kMJ]E^
mV[EK_HM=R5G7CI>gDkLC_e>g0030000LTkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoAAoo`03001oogoo021oo`0037oo1P001goo00@007ooOol000Aoo`03001oogoo
009oo`03001oogoo01Yoo`03001oogoo00Aoo`0<FUEJEUYFFUIJECYK>S/jG4JlB[efB7Y80gI800I=
TTVBBI99TTZmA[`2B[`3A[d5GWH04F>bGk9:_4ZlB[e6_4[MB]a:gD[LA[eF5EHeEQEF=EHEFd`00dZl
00E:gD[LC]e>g4kM00MfdP05AYa2W4JLAYa>g@03C]`01TkMC]a>gDkLA[e2_@E9TP06@Wa2W49l@Ya>
g4kM0dkL00YBoDkLC_a>o4kmC]a>oDkLC_e:g0=:g@04J]I^eVkF8CL37CH300000dkLC]eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001B
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001oogoo
01moo`005Goo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol06Goo00<007oo0000
17oo06eJEEYFFSENEUYEFUIJ=CYL=S/jG3jL@[efB7Y9MTQjJDVBCK99TTfb001:gDJlB]e2_4Jm@[a6
gEifGWMJMV>bGk9S/UnbC]e:_4kMB[a6_D:lA[eF55XeEQAF=EHDFdaG:d[MB[a:gDZlB]e:_4kMB]a:
gG;BM_=bdWKBL]9fl`0<AYa2W4JLC]a>gD[LC_e>g4kmB]a>gD:lA[e9LDfBBI9=TTVAAYa2NdJL@W]6
W4kLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_djO3jMJ]E^mV[EK_IZe@030000NDkLC]e>g5;mC]aB
oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001o
ogoo01moo`005Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo0P006Woo0P0000=o
o`00@[d00T:m0eYF00EJEEYFFUIW/V>a0096_006A[dnWGI8MTQjB7I80TVB00M=TP00000004ZmA[a:
_003A[d2GWH06V>bGWINMSHk>S/f>d[MB]a:gD[LA[e2_DJmEQEF=EHEESEG:e]<Fd]>gD[LC]a:g4kM
B]`3B]d5M]8200`034JL@Ya6W4kLC]e>g4kMC]a>gD[LA[e2_@I9TP04C]a:g4kLB]`2C]`01TkmC]a>
o4kLD_e>g09>o004D_e>g4kMC]`2>Yd2K]H300002Qdf8CLM=QdfC]aBoDkLC_a>g5;m0e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Aoo`03001oogoo01ioo`005Goo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol067oo06l006kE0352W49l
@Ye2W4:m@YaNEUYEFUIJ=EiFHk5W/TJlB[e6_4ZmMTQjJGI8CK99TTfbBI92O3ik@W`nNd[MA[a:g@4h
A[e2_5jGGWINMeYf>S/f>cXk=S]>gDZlC]e:_4Jm@[aF=EHDFSEF55He?U/nO3iKC]e:g4kMB]a>gDZl
C]e:g4[ML]9flg;BM]<0300=00a>gDZlC]e>g4kmC]a>oDkLC]e:g4JmBI5=TTVACI99TTfB001>gDZl
C]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]`00`00085ZeFkf7CH004JlB[a6W4ZlC]aBoDkL
D_e>g5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo
00<007ooOol07Goo000EOol50003Ool40005Ool00`00Oomoo`0GOol01000K]E^eFkE14:L0T:m00EJ
EEYFFUIJEV>a009W/@05Ik96_4ZmA[ejB002MTP00dVBCI99TP02BI83?W`01D[LB]e:_4[MB]`01Uif
0TZl01E:_DJlB]e:g4[MB]a6_EHEESEF5EHeEQDnO3iK?W`nFcilB]a>gDkLC]d00SjM1GKB0`0<00]:
g4kMB]a:g4kLC]e>g4kMC]a6_D:m00I9TP800003C]a:g4kL009>g003C_aBoDkL009>o004D_e>g4kl
C_`300000d[MK_IZeP02K]H00fkf7CI:_004B[`00e;lD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01=oo`8001moo`009Woo00<007ooOol05goo
0fkE05UZ]@0a@Ya2W49l@Ye2W4:mFSENEUYEFUIJ=CYL=S/jG4JlB]efB7Y9MTQ=/TVBCK99TTfb?W]2
O3ik@Wa2_4Jm@[a6gEifGWMJMUjGGWIS/UnAB]e6_4ZmA[a>gDZlB]e<P5XeEQAF=EHDFSEF54[MB[a:
gDZlB]e:g4kmB]a2_G;BM_=bdWKCL]9fl`0<00d0300=C]a>gD[LC_e>g4kmB]a>oD:lA[e9LDfBBI9=
TTVA00@0000;D_e>g4kmC]aBoDkLD_e>g5;mC]aBo@020000R4kLC]e:g4kMJ]E^mV[EK_IZeB5G7CI>
oDkLC]e>g4kmC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m57oo00<007ooOol077oo000UOol00`00Ool0000GOol00cImK]E^e@02K]D2034024Jl
A[e6_4Jm@[eJEUYEIk42FUH01CXk>U/j>d[MA[`00WI800E=TTVBBI99TTfB0099TP04B[a:_DJlB[`4
A[d4GWH00enbHk96_002B[`03DZmA[a:gD[LB]e2_EHeEQEF=EHEESEG:d[M00=:_004C]e:g4kMC]`5
M]8027;BM]96W4JL@Ya6W4kLC]d3C]`014kMC]a>gD:m1TVB00A2W49l@Ya2O09>g005C]e>g4klC_aB
o@0300003TkmC]a>oDkLB]e:g4[M>Ye^mV[FK]HM=R4g7CH2C]`01DkMC]a>g5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00DOol00`00Oomoo`07
Ool5000?Ool002Eoo`80011oo`08Bg9?TT:LA[e2W4Jm=W`jW@9^e@1TJ[E^eFkE0340400aA[a:_DJl
B]e2W5YFFSENEUYEFUHf>cYL=S]2_GI8NVU9TTfbBI9=/TVBCK99TP00A[a:gDJlB]e2_4Jm@[aNUeif
GWMOTF>bGk5S/TZlC]e:_4kMB[a6_D:lESEF55XeEQAF=EL[Fda:_4[MB[a:gDZlB]e:_4kMB]afdg;B
M_=bdWKCL]803D:LAYa2VdJLC]a>oDkLC_e>g4kMB]a6_DVACI99TDfbBI9=TT9kAYa2NdJL@W]BoDkL
D_d30000SU;mC]aBoDkLC_e>g4kmC]`nWCYlK_IZeFkfJ]E^mQdf8EM>g4kmC]aBoDkLD_e>g5;mC]aB
oE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007oo
Ool01goo00D007ooOomoo`0000moo`009Goo00<007ooOol03goo00=V]QDgCi800d:L0SIm1FkE100a
0d:m0eYF00AJEEYFHk5W/@=6_005@[efB4VBBI9=TP03BI83000014ZlB[e6_4Zl0TJm0Uif019O/Uif
GWHj>cHk>S]:g4[MB]a:gD:mA[e2_EHeEQEF=EHEFd/2Eb/01d[LC]e:g4kLB]a:gD[L009:g@EfdP80
300<B]a>gD[LB]a>g4kMC]a>gD[LC]e2_DJm1DVB00E=TT[LC]a:g4kL00<0000;C_e>g4klC_aBoDkL
C_a>g4kmC]a>g@02>Yd03F[FK]I^eVkfJ]HQ=Qdf8CM>g4klC]aBoDkL009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol01goo
00<007ooOol047oo000UOol00`00Oomoo`0>Ool02V[GI[IZeaDg6EQ2W4Jm@Ya^eFZe0fkE05]Z]FkE
@Ya2W49l@Ye2W4:m@YaNEUYEFUIJ=FNbHk5:_DJlB[e6_7Y9BI9=/TVBCK99TTfb?W]2O3ik@Wa:_4[M
A[a:gD:lA[eJMUjGGWINMcHk>S/f>cXkB[a>gDZlC]e2_4JmEQAF=EHDFSEF53il?U/nO4[LC]e:g4kM
B]a:gDZlC]e:g7KCL]9fdg;B00d0300=B[a>gDZlC_e>g4kmC]a>oD:lA[e2_4fBBI9=TTVACK99TP04
000054kMB[aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmC]a>oF[EK_IZeFkfJ]D20000P4ZlA[a:_4kLD_e>
g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`DOol00`00Oomoo`07Ool00`00Oomoo`0?Ool002Eoo`8000ioo`08:UeV]VKGI[HI>1Dg6EQ6
_096_@I^e@030352W4:L0092W092_@0DFUEJEUYFIk5S/FNaHk5:gDJlB[e2WDfBBI8004VBCI99TTfB
?Wa2O08nO004B]a:gDZlB]d6GWH06DJlB[a:_4ZmB]a:gD[LB]e2_EHeEQEF=EHEESDnFcil?U/nO3iK
C]e:g4kMC]a2_CjM00=fdP05L]9fdP0<00d03002B]`02DkMB]a>gDkLC]e>g4kM@[e6_@03BI800dfB
000000020003C]`01TkMC]a>o4klD_e>g09>o003D_e>g4[M009:g@08B]a:gFkFK_IZeVkF8CHQ=`A:
_005C]aBo5;lD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@0DOol00`00Oomoo`08Ool00`00Oomoo`0>Ool002Eoo`03001oogoo00Eoo`0H
I[H8eD:L@YdnW4:M:S`ZGFJfJ]MV]V[GI[HIF1DgA[e2_4Jm@[a^eFZeK]EZeFkE0P0a0596_4ZmA[a:
gD:LFUIJ=FNbFUEJESHk>U`f>d[MA[a2_DVBCK99TTfbBI9=/TVB@W`nNd9l?W]2O4:lA[e2_5jGGWIN
MeYfGYMOTEnbA[a:gDJlB[e:_4kMB[a:gEHDFSEF55HeEQAJ=DZlB]e:_4[MB[a>gD[LC_dnWGKCL]9f
dg;BM]=bdP0=00`03@0<C_e>g4kMB]a>oDkLC_e:g4km@[a=TP<0002MCI92NdJL@W]6W4kLD_e>g4km
C]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMB]a^mV[EK_IZeB5G7CHQEdkLC_e>g4kMC]aBoDkLD_e>g5;m
D_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d057oo
00<007ooOol027oo00<007ooOol03Goo000UOol00`00Oomoo`05Ool01F[FJ[H4]D:L@Yd00T:L00=V
]VKGI[H00VJf00IVeaDg6CPE=dJmA[`2A[d5K]D203401dJlA[e6_4Jm@[eJEUYE00=JEP05>S/jFcXk
>U`nW@02BI801TfBBI99TTVBCK99TP9:_003B[e6_4Zl00=6_@=NMP05Gk5O/UnaB[e6_002B[`03DZm
@[e6_D:mA[eF5EHeEQEF=EHEEb]:_4[M009:_004C]a>gD[LC]d2M]801G;BM]9fdWKBL]800dJL00Q2
W4kLC]a>gDkLB]e:g4kM0`0014VB00E=TT9l@Ya2O4:L00=>g00:C]e>g4klC_aBoDkLC_e>g4kmC]`3
B]d024[LK]I^eVkF7CHQ=b4f8CL3C]`01DkMD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol00goo00D007ooOomoo`00
00moo`0097oo00<007ooOol01Goo01YZeVZfJ]H4]0SE@Ya6_D:LA[eV]V[GI[IZed]aBi92W4Jm@Y`f
WCIl>YeZeFkEJ[E^eF[E0P0a04]:gDJlB[e6_4[MFUEJEUXeGUIJEEYFA[a:_DJl@[e9TTfbBI9=/TVB
CK=9TTfb001:gDJlB]e6_4[M@[a6_EYfGYMNMUigFWHj>cHkC]e:_4kMB[a>gD:lA[e2_5HeEQAJ=EHD
Ed]G:T[MB[a:gDZlB]e:g4[MB[a>gG;BM]=bdWKCL]9fdd:KAYa2W4JL@Y]>oDkLC_d00`000:A>gD:l
CI99TTfBBI9=/TVBAYa2NdJL@W]6W4kLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL?YdjOFkfJ]E^mV[E
K_HM=R5G7CHQEdkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007ooOol017oo0`0047oo000TOol01@00?W`jO3il
>W`00RiM00AZeVZfJ]IZeP<4]@03@[e6_D:l009V]P05I]M;LVJf5CM;TP03@Y`00d:MK]E^e@04K]D3
0344@[d3FUH015YEFUIS/F>a0dJl00M=TTVBBI99TTfBBI9=TP04000014[LB]e:_4[M0TJm15if00hf
>cXk=S]:gD[LB]e:g4[M@[e6_EHEESEF5EHe0eL[00E>g4[LC]e:g4kL009:g@05B]a:gGKBM]9bdP02
M]801P0=B]a:g4[LC]e:g0800006C]e>g4[MB]a>gD:m0TVB00Q=TTVBBI99TTkLB]a>g4[L0TkL00A>
o4kLC_e>g09>o005D_e>g4kMC]a>o@02>Yd2K]H00f[FK]I^eP05B[`014kLC_a>g5;m0e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l
4Goo0P0000=oo`00Ool05goo000TOol08`00OolnO3Yl?W`^G39mJ[IZeVJfJ]IZ]PRe1;@8eD:LA[e2
W6[G:SaVefJfJ]LE=aUH@[a6_D:lA[eZ]FkEJ]E^eFZe03800T:L04E2O4Jm@Ya2_D:LGUIJEEYFFSEW
/F>AB[e6_4ZmBI92_DVBCK99TTfbBI9=/cik@W`nNd9lB[a:gDJl0CT1>5igFWINUeifGWLf>cXk=S/j
>dZlC]e:_4[M@[aJ=EHDESEF55Xe?U/nO3iKC]e:g4kMB]a>gD[LB]e:_4kML]9fdg;BM]<0300=B[`0
0`000:]>g4kmC]a>oDkLA[e2_4JmBI5=/TVBCI99TTfb001>gDZlC]e:_4kMC]aBoDkLD_e>g5;mC]aB
oDkLC_e>g4kmJ]E^mV[EK_IZeB5G001:_4JLB[a6_5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001B
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol0
5Goo000JOol40006Ool01`00Oomoocil>W`nO6Zf00=ZeP04J[IZeT:L@Yd2@Y`4:Ud01fJfI]MV]QUH
5CLIF4Jl0096_@I^e@E2W092_@0IFUEJEUYFFUIJECYK>S]:gDJlB[e2WDfBBI9=TTVBCK99TTfb?Wa2
O3ilB]e:g4[MB[`01Uif01Y:_DJlB[a:_4ZmB]a:gD[LA[eF5EHeEQEF=EHE?W`nFcil?U/nO4kLC]e:
g4kM?Ye2_G;B0gKB00AbdP00000000=:g008C]e>g4kMC]a>gDkLA[e2_@A9TP05CI99TP00001>g@03
C]`02TkMC]a>o4klD_e>g4kmC]a>oDkL0d[M00IZeVkFK]I^eV[F8CL5B[`01E;mC]aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;m
D_aBo5;l4goo00<007ooOol05Goo000IOol00`00Oomoo`02Ool00`00Oomoo`03Ool0I000Oomoogoo
A[e2W4:mI[IZeVZfJ]IV]PSE@Ya2WCjL@YdZ?2YMI[IZefJfI]MV]QUH5CLIF4:lA[e2_6kE=Wa^eF[E
K]D0<D[MA[a:_DJlB]e2W5YFFSEW/EYEFUHf>cYL=S]:gDJl@[e9TTfbBI9=/dVBCK99TTfc?W]2O3ik
A]e2_4JmFWINUeifGWMJMUnbGi5:_DJlB]e6_4[MB[a>gDZlA[eF55XeEQAJ=EHDB]e:_4[MB[a:gD[L
C]e:g4:mL]9fdg;B0`000;<0300=00`03D[LC_e>g4kMB]a>oDkLC_e:g4JmBI9=TTVBCK99TTfb@W]6
W49kC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gF[EK_IZeFkf7CHQEdkLC]e>g4kmC]aB
oDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l01=oo`03001oogoo01Aoo`006Goo00<007ooOol00Woo00<007ooOol00goo
0P000Woo00E2W4:m@[eZeVZf008^G@05J]IZ]PBe@Ya2W@02@Y`00fJfI]MV]P02I[H01FKG@Ya2W4:L
@Yd00cIm16kE0P0a00Q6_DJlA[e6_00a@[eJEUYE0eYF00Dj>cYK>S]:gCjM0099TP0:CK99TTfbBI9=
/TVB001:_4ZmA[`3A[d3GWH01UnaGi5O/EnaB[e6_09:_00:A[e2_DJm@[eF=EHEESEF5EHeEbX2B[`0
1T[MB[a:_4kLC]e:g0<00004L]9fdWKBM]<4AY`3C]`01TkMB]a:gD[LC]e2_@99TP09CI99TTVBBI92
W49l@Ya>g4kM00=>g00:D_e>g4klC_a>oDkLC_e>g4kmB]`3B]d026[FK]IZeR5G7CHQ=dkLC]d3C]`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eBo5;l01Aoo`03001oogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00goo01i2W4Jm@Y`bOBiLJ]IV]V[F1;@8eD:LA[e2W4JmI[IVefJfJ]M7LD]b@Ya6_D:L
A[dfO3ZMJ]E^eFZeK]D303405P0bA[a:_DJlGUIJEEYFFSENEUYEB[e6_4ZmA[a2_DVBCK=9TTfbBI9=
/dVB0P00021:gDJlB]e6_4KM@[aNMeYfGYMNMUig=S/j>cHkC]e:_4kMB[a6_D:lA[eF55XeEQAJ=E<Z
Eb]C:TkMB]a>gD[L0`000;Y:_7KCL]9fdg;BM]=bdTJL@Y]6W4:LAYa>g4kmC]a>oD[LC]e:g4JmBI9=
/TVBCK99TTfbBI96W49kAYa>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g4km>W`nWF[EK_IZeFkfJ]DQ
Eadf8EM>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dCOol00`00Oomoo`0COol001Uoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Aoo`<^G@03J]IZ]V[F009ZeP84]@03@[e6_D:l009V]P05I]MV
]VJfBg52W@03@Y`00d:MK]E^e@03K]D5@Y`2@[d01EYEFUIJEUYFFUD00V>a00]6_DJlA[a6_4fBBI9=
TTVBCK99TTfb00<00004B]e:g4[MB[`2A[d05Uif0CQNMUif>S/f>cXk=S]:gD[LB]e:g4Jm@[eF=EHE
ESEF5EHe?U/nO3iK0`0000E:g4[MB]e:gG;B009fdP05M]=bdWKB00e>g@03B]`02DkMC]a>gDkLC]e:
g4[MB]a=TP03BI801TfBBI9=TP00C]a:g09>g006C_e>g4klC]aBoDkL0Tkl00]>oDkLC]e>g4kmJ]I^
eV[FK]IZeVkF00A:_006C]aBoDkLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04goo00<007ooOol04Woo000IOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool07RiL<WeV]V[FI[IZeVJf2;D4]0SE@Ya6
_D:LJ]LZ?6KGI[HIF1DgA[e2_4Jm@[a6_FZeK]EZeFkEJ[E2W@92W00a@Wa6_D:L@[eJ=EiFFUEJEV>@
Hk5ST4ZmA[a:_DVBCK99TTfcBI9=/TVBCK<nNd9l?W]:gDZlB]e6_04i0CQNMeYfGYMNMSXk=S/j>cHk
B]e:_4kMB[a6_EHDFSEF55XeEQ@00`00020nFdkMB]a>gD[LC]e:g4[ML]9fdg;BM]=bdP0=00a>gDZl
C]e:_4kMB]a>oDkLC_e2_4JmBI9=TTVBCK99TTfb0P0009m:_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>
g4kMB]a>gD[LC]eZeFkfJ]E^mQdf0016_4ZlAYa:_4kLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<0
07ooOol04Goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool20007Ool026ZfJ]IZeV[FJ[Ioo`Be
@Yd2@Y`3:Ud2I[H01VKGI[HIF1TgA[e6_096_@E^e@030352W4:L0092W092_@03FUIJEEYF009JEP0=
>S/jFcXkB]e6_4:mBI9=/TVBCK99TTfbBI800Sil00I2O3ilB]e:g4[MB[`5GWH00dZlB[e6_002B[`0
1T[MB]a:gD:mESEF5@<0000=EQDnO3iK?W`nFdkMC]a>gD[L?YefdWKCL]800WKB00Efd`0<00d03DkM
00=>g006C]e>g4kMC]a>gD:m0TVB00A=TTVBCI99TP<00007C]a>gDkLC]a>o5;mC]`00Tkl00I>oDkL
C_e>g4[MB]`2B]d02FkFJ]I^eV[F8ELQ=R4gC]a>g@02C]`00e;lD_e>g002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m
D_`COol00`00Oomoo`0AOol001Yoo`@000Eoo`03001oogoo00Moo`03I[IZeVJf00=oo`0E@Ya2WCjL
@YdZ?2YMI[IZefJfI]LE=aUH5CLIF4:lA[e2_3JMJ[E^eF[E0080<@0]B]e6_4ZmA[a6_EYEFUIST5iF
FUDjG3Hk>U`f>d[M?Ya=/dVBCK99TTfcBI9=/dVBB]e6_4[MA[a6gD:lA[eJMUjGGWINMe^AGk56_4Zm
A[a:gDJlB]e:_4kM00800038EQAJ=EHDFSEC2T[MB[a:gDZlC_e:g4kMB]afdg;BM]=bdWKCL]96W4:K
AYa2W4kMB]a>oDkLC_e:g4kmC]a>oD:lCK99TTfbBI9=/T9kAYa2NdJLC]a>oDkLD_e>g5;mC]aBoDkL
D_e>g5;mC]a>gD[LC]e:g3jMJ]E^mQdf8ELM=R5GC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA9o
o`<0019oo`001Goo0P0000=oo`0000006Goo00<007ooOol01goo00=ZeVZfOol00goo00<8]D:L@Yd0
0T:L00AV]VKGI[IV]P97L@=2W003@YdfOCIm00E^e@80<@05A[e6_4Jm0312_@02FUH04EYEFUIJESYL
>S/jFcXk@[e9TTfbBI9=/TVBCK99TTfb00000TZl00=:_DJmA[d00TJm0eif00MO/E^AGk5OTD[MB]a:
g@0300001dJmEQEF=EHEESEC:UL[00=:_003B]e:_4[M009:g@07B]afdWKBM]=bdWKBL]8014JL00U>
gDkLC]a>g4kMB]a:gD[LA[d00dVB00Y=/TVB@Ya2O4:L@W]2W4kLC_e>g09>o008D_e>g4klC_a>oDkL
C]e>g0<jW@07J]I^eV[FK]HQ=R5G8CH00TkL00E>gDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eB
o5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d04goo
00<007ooOol047oo0004Ool00`00Oomoo`02000JOol00`00Oomoo`0=Ool05PBd2=E2W4Jm@Ya6_FJf
I]MV]V[G5CM7LD:LA[e2W3JM=Wa^eF[EK]EZ]FkE0`0a01E:gDJlB[eJ=EiFFUEJEUXeHk5ST4ZmA[a:
_DJlCK99TTfcBI9=/TVBCK<00P0000i6_4[MA[a:gD:lA]e2_5igFWINMeif>S/f>cXk0`000<m>gD:l
A[e2_5XeEQAJ=EHDEb]C2UL[B]a>gD[LC]e:g4kMB]a:gG;BM]=bdWKCL]9fd`0<AYa2VdJL@Ya>oDkL
C_e>g4kMB]a>gD:lCK99TTfbBI9=/TVBC]e:_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL
?YdjO6kfJ]E^mV[E8ELM=R5G7CIBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04goo00<007oo
Ool03goo0004Ool01@00Oomoogoo00006Goo0`003goo00D4]@Re@[e6_D:l009V]P05I]MV]VJf6CLI
F003@Y`6K]D0100a@Ya2W4:L0T:m00=JEUYEFUH00UYF0f>@00Y6_DJlA[a9TT:mBI9=/TVBCK99TP<0
0005B[a:gD[LB]d1>002A[d3GWH3000053Xk=S]:gD[LB]e2_DJmEQEF=EHEESEF5Cil?U/nO4[LC]a:
g4kMB]`3B]d01G;BM]9bdWKCL]800P0=01Y>gD[LB]a:g4kMC]a>gDkLC]e:g4JmBI9=TTVBCI99TTfb
005>g4[LC]a:g4kLC_aBoDkL0Tkl00iBoDkLC_a>g4kmC]a>gDkLK]IZeVkFJ]HQE`0014Zl00A>o4kL
D_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0AOol00`00Oomoo`0>Ool000Aoo`05001oogoo
Ool0000IOol00`00Oomoo`0?Ool05`SE1;@8eD:LA[e2W2YMI[IVefJf6EPE=aUH@[a6_D:lK]EZ]FkE
J]E^eFZe@Yd00T:L01i2O4Jm@YaJEUXeGUIST6>aGi1S/F>@B]e6_4[M?Ye=/TVBCK=9TTfcBI92O3ik
@Wa6_4[MB[a:gDJlGWL30000<UigGWI:_DJlB]e6_4[MB[a>gD:lFSEF55XeEQEJ=CiK?W`nFcil?U]>
oD[LC]e:g4:m?Yefdg;BM]=bdWKC00`03DZlC]e:_4kMB[a>oD[LC_e>g4Jm@[a=/TVBCK99TTfcBI82
0040XU;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC]e:g6kfJ]E^mV[E8EM6W4ZlA[a:_4JL
D_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1=oo`03001oogoo00ioo`0017oo00D007ooOomoo`00
01Uoo`03001oogoo011oo`03@Ye2W4:L008ZG@=V]P07I]MV]QUH6CM6_DJlA[d00VkE00DfOFkEK]E^
e@0a00A2W003@[eJEUYF009ST09JEP0<>S/jFcXkB]e6_4:mBI9=/TVBCK99TTfb0cil00=2O4JmA[d0
0`0015if0U^A00e:_DJlB[a:g4[MB]a:gEHEESEF5EHeEQEF=@03B[`034[MB[a>gDkLC]dnWGKBL]9f
dg;BM]9bdP<03@03C]a>gDkL009>g006C]e>g4kMC]a6_D:m0TVB00I=/TVB@Ya2O4:L@W/2C]`02dkM
C]a>o4klD_e>g4kmC]a>oDkLC_d00T[M00Q:g4[MJ]I^eV[FK]HQ=R5G0dkL00I>gDkLD_aBo5;mC]`2
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4goo00<007ooOol03Goo0003Ool20002Ool2000IOol00`00
Oomoo`0@Ool0<4:L@YdnW4:MI[IVefJfJ]MV]VKG5CLIF1DgA[e2_4Jm=We^eFZeK]EZe@0b035:gDJl
B[e6_4JmFUEJEUXeFUIJECYL=S/jG3HkB]dnW4fcBI9=/dVBCK=9TTfcA[a:g@<0003NA]e2_4JmFWIN
MeifGk5KT5naA[a:_DJlB]e2_4Jm@[a6_EHDFSEF55XeEQEG:TZlB]e:_4[MB]a>oD[LC]ebdWKCL]9f
dg;BM]<03DJL@Y]6W4kLC]e:g4kmC]a>gD[LC]e2_4JmBI9=/TVBCK99TTJL@W]6W4kLD_e>g4kmC]aB
oDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gF[EK_IZeB5G7CHQEdkLC_e>g4kMC]aBoDkLD_e>g5;mD_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l4goo00<007ooOol037oo000ROol2000BOol01T:mA[e2_4:mI[IVe`9V]P03
Ae17LD:L0092W0<fO@A^e@<0<@04A[e6_4JmA[`3FUH015YEFUIJETJm0dJl00M2_DVBCK99TTfbBI9=
/P030002B[`014ZmA[a6_DJm1Eif010f>cXkB]a:gD[LB]e2_DJm@[eF=EHEESEF5E<ZD`YC:P=:_003
B]e:g4[M009:g@06L]9fdW;BM]=bdWKB14JL01M>g4kMC]a>gDkLC]e:g4Jm@[e=/TVBCI99TTfb@W]2
W49l@Ya>g4klC]a>oDkL009>o007D_e>g4klC]a>oDkLC]d00SZM00eZeVkFJ]I^eV[F8CLQ=R5GC]a>
o4kLD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`04goo00<007ooOol037oo000ROol00`00
Oomoo`0BOol0:4:LA[e2W6[GI[IVed=@J]MV]TJm@Ya6_D:LA[eZ]FkEJ]E^eFZe0380<@0b0356_D:L
@[eJ=EYFFUEJEUXeHk5OT4ZmA[a:_CjMCK99TTfc1P000>96_4[MB[a:gDJlA]e2_5igFWINMeif>S/f
>cXkB[a>gDZlC]e2_4JmEQAJ=EHEFSEF549l?U/nO4[LC]e:g4kMB[a>gD[LM]=bdWKCL]9fdg;B00e:
_4kMB[a>gDkLC_e>g4kmB]a>gD[LA[e9TTfbBI9=/dVBCK9:_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>
g5;mC]a>oDkLC_eZeFkfJ]E^mV[EK_I6W4ZlA[a:_4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoA=oo`03001oogoo00]oo`008Goo00<007ooOol057oo00I2_DJm@[aV]RYMI[L2I[H00aUH
A[e6_003A[d5K]D4@Y`3@[d01EYEFUIJEUYFGi000V>@00A6_DJlA[a9TP8000==/P0:BI8nO3il@Wa:
_4[MB]a:g@4H0CP5GWH05SXk=S/j>d[LB]e:g4[M@[eF=EHEESEF5EHe?U/nO3iK?Wa:g4kLB]a>gD[L
0T[M00Efdg;BM]9bdWKC00803@03B]a>gD[L009:g00BC]e>g4kM@[e6_D:mCI99TTfbBI9=/TVB005:
g4kLB]a>g4[L0Tkl00MBoDkLC_a>o5;mC]a>o002B]d024[LB]eZeVkFJ]I^eR4f0004B[`01DkLD_aB
o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo019oo`8000aoo`008Goo00<007oo00005Goo
01@Z?2YM:S`ZGFJfI]MV]V[G5CM6_D:lA[e2_6kEJ[E^eFZeK]D0<D:M0T:L00]2O4Jm@YaJEUXeFUIJ
EEYF=S/jG3Hk00<00014BI9=/dVBCK=9TTfc?W]2O3ik@W`nNd[MB[a:gEYfGWMNMUigFWINMdJlB[e6
_4[MB[a:gDZlA[eF5EXeEQAJ=EHEFSDnFd9l?U/nO4[LC_e:g4kM?Yafdg;BM]=bdWKCL]803@0<00e>
g4kMB]a>oDkLC_e:g4km@[a6_DVBCK=9TTfbBI9=/`800@2UC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;m
C]aBoD[LC]e:g6kfJ]E^mV[E8ELQ=R5GC]a>oDkLC]e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l01=oo`03001oogoo00Yoo`008Goo0P005goo0RYM0fJf00=V]fJf6EP00QUH00A6_4JmA[df
O@=^e@070380<DJmA[a6_DJl@[d00UYF00=OT5YFFUH00`0000M6_D[M?Ye=/TVBCK99TP03CK801DJl
B[a:_4ZmA[`00TJm1Eif011KT5^AB[a:_DJlB[a:g4[MB]a6_EHEESEF5EHeEQEC:P=:_00;B]e:g4kM
C]a>gG;BM]9bdWKCL]9fdP04AY`00dkLC]e>g002C]`03DkMC]a>gD:mCK99TTfBBI9=/TVB@Ya2O4:L
00=>g00;C]e>g4klC_aBoDkLC_e>g4kmC]a>o@02B]d024[LK]IZeVkF8CHQEb4f8EL3C]`01E;mC]aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo015oo`8000]oo`003goo100017oo10001Woo
00<007ooOol05goo01UV]VKGI[IZefJfAe13D4Jm@Ya6_CIm=YeZ]FkEJ[E^eFZe0380<D[MA[a:_@0@
A[eJE@030000leYE>U`f>cYLA[a2_DVBCK=9TTfcBI9=/dVB0016_4[MA[a:gD:lA]e2_5igFWINMe^@
Fi5KT5naB[a>gDZlC]e2_4Jm@[aJ=EHEFSEF55<ZD`U:gDZlB]e:_4[MB[a>gD[LB]ebdWKCL]9fdg;B
00e2W4JL@Y]>oDkLC]e:g4kmB]a>gD[LA[e9TTfbBI9=/dVBCK=2NdJL@W]6W4kLD_e>g5;mC]aBoDkL
D_e>g4kmC]a>oDkLC_djOCjMJ]E^mV[EK_HM=R5G8CI>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo00>Ool300000goo001oo`0:Ool000ioo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`03Ool00`00Oomoo`0HOol01VJfI[MV]Woo6EQ7D0=2W08fO@E^e@050340<P0a
A[e6_0030002FUH015YEGi1OT4Jm0TJl00=2WDfbBI800dfb00=9TTfb00000P000TZl00=:_DJmA[d0
1Eif00dj>cHk>S]:g4[MB]a6_D:mA[eF5EHeEQEF=@03D`X01TkMB]a>g4[LC]e:g09:g@07M]=bdWKC
L]9fdg;B00d00dJL019>gDkLC]e>g4kMB]a>gD:mCI99TTfbBI9=/TfBCK9:g4kLB]`2C]`014klC]a>
oDkL0Tkl00IBoDkLC]e>g4kmC]`2>Yd03FkFJ]I^eV[F8ELQ=R5G8CIBoDkLC_a>g5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00Yoo`@000Aoo`03001oogoo00Uoo`004goo00@007ooOol0
00Aoo`03001oogoo00=oo`8001Uoo`03J]MV]Woo009oo`0=6CLIF4:LA[e2W6kEJ[E^eFZeK]EZ]@0b
@Y`00`0003i2W5YFFSEJEUYEFUIOSf>`A[a:_DJlB[e9TTfcBI9=/dVBCK<nNd9l?W]2O3ikB]e:_4[M
@[a6gEifGWMJMUig=S/j>cHk>S]:_4kMB[a6_D:lFSEF55XeEQEJ=CiK@W`nFdkMB]a>gD[LC]e:_4kM
B]afdg;BM]=bdWKC0P0=0;Y:_4kMB[a>oDkLC_e>g4kmB]a>gD:lCK=9TTfbBI9=/dVB005:_4kMB[a>
gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLK_IZeFkfJ]DQE`00B[a6W4ZlA[aBoDkLD_e>g5;mC]aB
oDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d6Ool30008Ool00`00Oomoo`09Ool001=oo`04001o
ogoo0004Ool00`00Oomoo`02Ool2000OOol36EP00dJlA[e6_@04K]D30003@Y`2@[d00eYFFUEJEP02
FUH01CXk>U]6_D[MA[`00dfb00A9TTfbCK9=/`<nO005@Wa:_4[MB]a:g@06GWH05TZlB[e6_4ZlB]a:
gD[LA[e2_EHeEQEF=EHE?W`nFcil?U/nO4[LC]e>g4kM0SjM00EbdWKCL]9fdg;B00803@9:g00?C]e:
g4kMC]a>gDkLC]e2_DJmBI9=/TVBCK99TTfb00800@=>g006C]e>g4klC_aBoDkL0Tkl00=BoD[LB]d0
0T[M00I:g6kFJ]I^eR4f8EL4B[`00e;lD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo0=oo`<000aoo`03001oogoo00Qoo`003goo10000goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol07goo00HIF1Tg6EQ2_4JmJ[D30000A6ZeK]D0<D[MA[a:_DJlA[eJEEYFGhmJEUYE>U`f
>cYLA[a:gCjLCK=9TTfcBI9=/dVBCK=9TT9l?W]2O4:lA]e2_5igFWINMeifGWMGL5^AA[a:_DJlC]e:
_4[MB[a6_EHEFSEF55XeEQE:gDZlB]e:_4[MB]a>oD[L@[ebdWKCL]9fdg;BM]<300d0^TkmC]a>gD[L
C_e>g4kmB]a>oD:lCK99TTfcBI9=/d9kAYa2NdJLC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[L
C]eZeFkfJ]E^eQdf8EM>g4kMC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo08000moo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol07goo0d:L0`0000<fOFkEJ]D00VkE00L0<P0aA[e6_4JmA[a2_@02FUH02EYEFUIJ
ESYL>S/jFcXk@[e9TP03CK801DVBCK9=/Tfc00000TZl00A:_DJmA[e6_@=NMPAKT00>B[a:_DJlA[e2
_DJm@[eF=EHEESEF5E<:D`U:g@=:_00;B]e:g4kMC]afdg;BM]=bdWKCL]803@03AY`2C]`04DkMC]a:
gD[LC]e:g4JmBI9=/TVBCK9=TT:L@W]2W49l@Y`00dkL00YBoDkLC_a>o5;mC]a>oDkLC_e:g0=:g@=Z
eP058ELQ=R5GC]a>g@02C]`00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o11oo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol087oo0P000212W4Jm=WdfWFZeK]EZ]FkE0340<P0a0396_4ZmA[aJEUYEFUIJ=EYFA[a:_DJl
B[dnWDfcBI9=/dVBCK=9TTfc0P000>M6_4[MA[a:gD:lA]eNMUigFWINMeif>S/f>cYKB[a>gDZlA[e2
_4JmEQAJ=EHEFSE?2E<:C`U>gD[LC]e:g4kMB[a>gD[LM]=bdWKCL]9fd`0=AYa2W4JL@Y]>oDkLC_e>
g4kMB]a>gD:lCK=9TTfbBI9=/dVBC]e:_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oCYl?YeZ
eFkFJ]E^mR4f8ELM=R5GC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`03goo00<007ooOol027oo000?Ool50003Ool40005Ool2000NOol300001Woo@Ya2W4:L@YeZ
e@=^e@03J]E2W4:L00=2W092_@08FUEJEUYFFUIJEEn@A[a6_@96_09=/P05BI9=/TfbCK=9/P030000
14ZlB]e:g4[M0TJm15if0SXk01Df>d[MB]a:gD[LA[e2_EHeEQEF=EHEESDnFcil?U]>gD[LC]a:g4[M
B]`00T[M00Afdg;BL]=bdP803@9:g00JC]e:g4kMC]a>gDkLB]e:g4kMBI9=/TVBCK99TTfb005>g4[L
C]a:g4kmC]a>o4kLD_e>g09>o005D_e>g4kMC]a>o@03J]H00fkF8CH00004B[`01TkLD_e>g4klD_aB
o@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l3goo00<007ooOol027oo000POol00`00
Oomoo`0JOol30005Ool02T:lA[e2_4JmJ[E^eFZeK]EZ]D:M0T:L03i2O4Jm@Ya2_EXeFUIJEF>@GhmS
T5n?B]e6_4fc?Ye=/dVBCK=9TTfcBI92O3ik@Wa6_4[MB[`1>04HGWMNMUigFWINMcHk>S/f>dkMB[a:
gDZlA[e2_5XeEQAJ=EHE?W`nFd9l?U]>gD[LC]e:g4:m?Ya2_G;BM]=b/WKC0`0=0;e>gDZlC]e:_4km
C]a>oD[LA[e2_4fbBI9=/dVBCK=9TP02B[a>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4kM
J]E^mV[EK]HQ=TZlA[a:_4JLB[a>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d03Woo00<007ooOol027oo000POol00`00Oomoo`0GOol30009Ool01DJlA[e6_FkEJ]D0
0fkE00<0<@0b@Y`00T:L0T:m00=JEUYEFUH00UYF00Hj>cYK>S]:gDJl@[d2CK8014VbCK9=/Tfc0cil
00A2O4ZlB]e:g0ENMP0@Ei1KT4ZlB[e6_4[MB]a:gD[LA[eF5EHeEQEF=EHEB]d3B[`02TkMB]a>gDkL
?[ebdW;CL]9fdg;B100=0TkL00Y>gDkLC]e>g4kMC]a2_DVBCK99TP9=/P0500800@01C]a>g@03C]`0
2U;mC]a>o4klC_e>g4kmC]a>oD[L0T[M00I^eV[FJ]IZeR5G8CH2C]`01TkMC]a>g5;lD_e>g09Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`03Goo00<007ooOol027oo000OOol0
0`00Oomoo`0EOol3000=Ool0od:lA[e2_6kEJ[E^eFZeK]D0<@0bA[a:_DJlA[eJEEYFGhmJEUYE>U`f
>cYL=S]:gCjLCK=9TTfcBI9=/dVBCK=6_4[MA[a:gD:lA]e2_5igFWINMeM`Fi1GL4[MA[a:_DJlC]e:
_4[M@[aJ=EHEFSEF55XeC^U:gDZlB]e:_4kMB]a>oD[LM]=b/WKCL]9fdg:bAYa2W4JL@Y]>oDkLC]e:
g4kmC]a>oD[LA[e9TTfcBI9=/dVBAYa2NdJLC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:
g6kFJ]E^mR4f8ELQ=TkmC]a>gDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0002e;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d03Goo00<007ooOol01goo000OOol2000COol3000AOol2=Wd2K]D02V[EK]E^
e@0b0340<TJlA[e6_4:m0UYF00AJEEYFFUI6_@=6_005@[e9TTfbCK9=/`03CK801@00B[a:_4ZlB[d0
0TJm1Eif00dj>cHkB]e:g4[MB]a6_D:mA[eF5EHeEQEF=@03C`T01T[MB[a:_4ZlB]e:g09:g@05M]=b
dW;CL]9fd`05AY`034kMC]a>gDkLB]e:g4kM@[e=/TfBCK99TP9=/P0:@Ya2Nd:LC]a>oDkLC_a>g5;m
C]`2C_`01DkmC]a>gDkLC_d00SZM00iZeVkFJ]IZeR4f8ELQ=TklC]aBoDkLC_aBo5;m0e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0<Ool00`00Oomoo`07Ool001moo`03001o
ogoo00moo`<001Eoo`06J[E^eFZeK]EZ]FkE0T:L01E2O4:M@Ya2_EXeFUIJEEYFFSEOT5m_B[e6_4Zm
?Ye=/dVBCK=9TTfcBI800`0000I6_4[MB[a:gD:lA]d2GWH0hEYfGWLf>cXk=S]>gDZlC]e:_4Jm@[aJ
=EHDFSEF5EXe?U]2O3iKC]e:g4kMB]a:gDZlC]ebdWKCL[9fdg;B00i:_4kMB[a>gDZlC_e>g4kmC]a>
gD[LA[e9TTfcBI9=/dVBCK<00DkMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkLC_eZeFkfJ]I^
eV[EB[a6_4ZlAYaBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo00<Ool00`00Oomoo`07Ool001moo`03001oogoo00aoo`<001Uoo`06J]E^eFkEK]Eoo`0b
0d:L0d:m00AJEEYFFUIJEP=OS`06A[e6_4JlCK9=/dVb0Tfb00Y=/dfb?W`nO49lB[a:gD[L0CP160EN
MP8j>`0J=S]:gD[LB]e:g4JmEQEF=EHEESEF5Cil?U/nO4[LC]e:g4kLB]a:gD[LB]ebdWKCL]9bd`80
3@=:g006C]e:g4kMC]a>gDkL0T:m00==/TVBCK800Tfb00U9TP02B]a>g4[LC]a>o5;mC]`00Tkl00IB
oDkLC_a>o4[MB]`2B]d01VkFJ]IZeV[F8ELQ=PA:_09Bo005D_e>g5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Yoo`03001oogoo00Moo`007goo00<007ooOol0
2Goo0`0077oo00=^eFZeOol00Woo0280<@0b@Ya2W49l@[e2W5YFFSEJEUYEFUHf>cYL>S]:gDJl@[e9
TTfcBI9=/dVBCK<nNd9l?W]2O4JlB]e:_5ifFWINM`9NMP3QEfmKT4JlB[e6_4kMB[a:gD:lA[eF5EXe
EQAJ=EHE?W`nFd9lB]a>gD[LC_e:g4:mL[9fdg;BM]=b/P0>00d03P0=C_e>g4kMB]a>oDkLC_e2_4Jm
BI9=/dVBCK=9TP0200400TkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMB]a^eV[EK_IZeR5G
8CI>oDkLC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l00Yoo`03001oogoo00Moo`007goo0P0027oo0P0097oo00L0<P0a0396_4JmA[a2_@02FUH0
2En?FUIJESYL>S/jFcXkB]dnW@02CK801DfcCK9=/TfbCK<00dZl00A:_DJmA[e6_@=NMP03Ei1KT5M_
009:_00=B[e6_4[MB]a:gD:mESEF5EHeEQEF=@00B]d00TZl00]>g4kMB]a>gDkLM]=bdW;CL]9fdg;B
00A6W09>g005C]e>g4kMC]a>g@02@[d00dfBCK99TP02CK801D:L@W]2W4kLC]d00TkL00=>o5;mC]`0
0Tkl00U>oDkLC_e>g4[MB]a:gF[FK]H00V[F00<QER5G8CH014kL0U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol027oo00<007ooOol01goo000NOol0
0`00Oomoo`05Ool3000WOol07`0b035:gDJlB[e6_4:mFUEJEUXeFUIJEDZmA[a:_DJl@[e9TTfcBI9=
/dVBCK=9/P00A[a:gDJlB]e2_4KM009NMP0@FWINMeif>S/f>dkMB[a>gDZlA[e2_4JmEQAJ=EHEFSD3
0000dD[MB[a:gD[LB]e:_4kMB]afdg:bM]=bdWKC@Y]6W4:LAYa2VdkmC]a>oDkLC]e:g4Jm@[a=/dVB
CK=9TTfc@W]6W49kAYa>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g3ZM>Wa^mV[FK]IZeBEG8CHQEb4f
D_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d02Woo00<007ooOol01Woo000NOol00`00Oomoo`02Ool3000ZOol00`0a0380<@03@[d01EYEFUIJ
EUYFFUD00Un?00E6_DJlA[`nWDfc00==/P03CK==/P0000800004B[a:gD[LB]d2A[d4GWH2>S/04SHk
B]e:g4[MB]a6_D:mESEF5EHeEQEF=CiK?W`nFdkMB]a>g09:g@08B]a:gG;BM]=bdW;CL]803P=:g00:
C]e:g4kMC]a>gD[LB]e2_DJmBI83CK801DVbCK9:g4kLB]`00TkL00I>oDkLC_a>o5;mC]`2C_`01Dkm
C]a>gDkLK]H00f[F00=^eTZlB[`00dZl00A>o4kLD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0Yoo`03001oogoo00Ioo`007Woo00<007oo00000P00;Woo
0T:L01i2O4:m@Ya2_EXeFUIJEEYFFfmOT5]_B[e6_4ZmBI9=/dVBCK=9/TfcBI92O3ik@Wa6_4[MB[`1
>04HGWL2GWH0heYfGWLf>cXk=S]>gDZlB]e:_4JmEQEJ=EHDFSEF5Cil?U]2O4[LC]e:g4kMB]a:gDZl
C]ebdWKCL[9fd`0=00i:_4kMB[a>gDZlC_e>g4km@[a6_D:lCK=9TTfcBI9=/dVB009:_4kMB[a>gDkL
D_e>g5;mC]aBoDkLD_e>g4kMB]a>gD[LK]IZeFkfJ]HQEdJLB[a6_4ZlAYaBoDkLD_e>g5;mC_aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`02Goo00<007ooOol01Woo
000NOol3000aOol4@Y`00d:mFUIJE@03FUH01CXk>U/jFd[MA[`00Tfb00E=/dfbCK9=/Tfc00<nO004
@Wa:_4[MB]`5GWH2Efl02dZlB[e6_4[MB]a:gD:mA[eF5EHeEQD00UHe00hnO3iK?Wa>g4kMB]a>gDkL
?[ebdW;CL]9fdg;B0P0=00T03TkLC]a>g4kMC]a>gDkLC]d00T:m0Tfb00A9TTfbCK9=/`800P0BC]a>
gDkLC]a>o5;mC]a>o4kLC_e>g4kmC]a:gD[LB]eZeVkF0V[F00<QER5GC]`014kL0U;l00EBoDkLD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aB
o5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`8Ool00`00Oomo
o`06Ool000Aoo`D000=oo`@000Aoo`@000Moo`03001oogoo035oo`0LA[a:_DJlB]eJEEYFFfmJEUYE
>U`f>cYLA[a:gCjLCK=9TTfcBI9=/dVbCK=6_4[MA[a:gD:lA]d2GWH0ieYfGWMNMUN@Efm:gDJlB[e6
_4kMB[a:gD:lFSEF5EXeEQAJ=@00B]e:_4[MB]a>gD[LC_e:g7KCL[9fdg;BM]<03DJL@Ya6W4[LC_e>
g4kMB]a>oDkLC_e2_4fcBI9=/dVBCK=2NdJL@W]6W4kLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:
g4kMJ]I^eV[E9ELQ=R5GC]a>oDkLC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo007Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`05Ool2000bOol014JlA[e6_4:m0UYF00QJEEYF
FUHjG3Xk>U/nWD:m0dfb00E=/dfbCK==/P0000=:_003B[e6_DJm00ENMP0:>S/f>d[MB]a:gD[LA[e2
_DJmEQD3ESD300000d[MB[a:_002B]d01D[LB]e:gGKCL]800W;C00=fddJLAY`00TJL00U>g4kMC]a>
gDkLB]e:g4JmBI800Tfb00Y=/dVb@Ya2O4:L@W]2W4kLC_e>g09>o009D_e>g4klC]a>oDkLC]e>g3ZM
00=ZeP0:K]IZeR5G8EHQEdkLC_a>g5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aBo007Ool00`00Oomoo`06Ool000Ioo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool04d:L@[e2W5YFFUEJ
EUXeFUIKKdZmA[a:_CjMCK=9TTfcBK9=/dVB00<0003^A[a:gDZlB]e2_5igGWIGT5YfGWLf>cXk=S]>
gDZlC]e:_4Jm@[aJ=EHDFSEF5EXe?U]2O3iKC]e:g4kMB]a:gDZlC]ebdWKCL[9fdg;B00i:_4kMB[a>
gDkLC_e>g4kmB]a>gD:lA[e9TTfcBI9=/dVBC]e:_4kMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>
oF[FK]IZeFkfJ]I^eTJLB[a6_4ZlC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d6Ool00`00Oomoo`06Ool000Ioo`03001oogoo009o
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool3@[d3FUH015]_
GhmKKdJm0TJl00==/TfcCK800Tfb00Y=/dfb?W`nO49lB[a:gD[LB]e6_@ENMP8j>`06=S]:gD[LB]e:
g4Jm0UHe00YF5EHeESDnO3iK?Wa:g4kMB]a>g09:g@08B]a:gG;CM]=bdW;C00d03P=:g005C]e>g4kM
C]a>g@03@[d03TfbBK9=/TfbCK<00TkLB]a>g4[LC]a>o5;mC]`2C_`00e;mC]a>o002B]d014[LB]eZ
eVkF0V[F00<QER5GB[`00dZl00A>g5;lD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Ioo`03001oogoo00Eoo`001Woo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Uoo`03001oogoo031oo`1=@Ya2_EXeFUIJ
EEYF=S/jG3XkB]e6_4fcBK9=/dVBCK=9/Tfc?W]2O3ik@Wa6_4[MB[a:gEYfGWMJMUifDfmGT4JlB[e6
_4kMB[a:gD:lA[eF5EXeEQAJ=EHE?W`nFd9lB]a>gD[LC_dnWGKCL[9fdg;BM]=b/P0>00d03T[LC_e>
g4kMB]a>oDkLC_e2_4JmBI9=/dVBCK=9TP020080]5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>
gD[LK_IZeVkFJ]DUEb4f9EM>g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Ioo`03001oogoo00Eoo`001Woo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Yoo`80035oo`03@[eJEUYE00=JEP05
>S/jFcYK>U`nW@02CK801DfcCK9=/dfbCK<00dZl00A:_DJmA[e6_@=NMP=GK`9:_006B[e6_4[MB]a:
gD:m0eHe00AF5EHe001:g@9:_007C]a>gD[LC]ebdgKCL]800g;C00@03DJLAYa6W0=>g006C]e>g4kM
C]a>gD:m0Tfb00I=/dfbCK92O4JL@W/2C]`02dkMC]a>o4klD_e>g4klC]a>oDkLC_d00T[M00Q:g6[F
J]IZeR5F8ELQER5G14kL0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol017oo00<007ooOol01Goo0004Ool30004Ool00`00Oomo
o`02Ool01000Oomoo`0017oo00<007ooOol037oo00<007ooOol0;goo02Y2W5YFFSEJEUYEFUI6_4Zm
A[a2_DVBCK=9/TfcBI9=/dVb0016_4[MA[a:gDJlA]e2_5ifFWINMeYf>S/f>dkMB[a>gDZlA[e2_4Jm
EQAJ=EHEFSD30000eT[MB[a:gD[LB]e:_4kML]9fdg:bM]=bdWKC@Y]6W4:LAYa>g4kmC]a>oD[LC]e:
g4JmBI9=/dVBCK=9TTJL@W]6W49kD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_djOCZMJ]E^eV[FK]HQ
=REG8CHUEdkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l17oo00<007ooOol01Goo0006Ool00`00Oomoo`03Ool40004Ool4
000@Ool00`00Oomoo`0^Ool3FUH015YEFUIKKe]_0TJl00PnWDfcCK9=/dfbCK==/Tfc0P0000Q:_4[M
B]a:gDZlA[eNMP4H0Uif0SXk00Tf>d[MB]a:gD[LA[e2_EHeEQD00eHe00HnFcil?U]>gD[LC]`2B]d0
1D[LL]=bdg;CL]800W;C00h03T[LB]a:g4kMC]a>gDkLC]e:g4[M@[e=/TVb0Tfb00Y=/dfbC]a:g4kL
B]a>o4kLC_e>g09>o007D_e>g4klC]a>oDkLC]d01F[F1DZl00A>g4klC]aBo@=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aB
oE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol00Woo00<0
07ooOol01Goo000YOol00`00Oomoo`0^Ool0oeYFFUEJEUXeGhmKKUn?A[a:_DVbCK=9TTfcBK9=/dVb
@W`nNd9lA[a:gDZlB]d15`4HFWINMUYfGWLf>cXk=S]>gDZlB]e:_4JmEQEJ=EHDFSEF5Cil?U]2O4[L
C]e:g4kMB]a:gDZlM]=bdWKCL[9fd`0=00i:_4kMB[a>gDkLC_e>g4Jm@[a6_DVBCK=9TTfcBI9=/`02
C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gF[FK]IZeFkF8CI:_4JLB[a6_5;mC]aBoDkL
D_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
15;lD_eBo5;m0goo00<007ooOol01Goo000ZOol00`00Oomoo`0]Ool00eYEFUIJEP02Ool2>U/02CYL
A[a=/TfbCK==/TfcCK9=/`03?W`01D9lB[a:gD[LB]d015if00UCKeM_B[a:_DJlB]e:g4[M@[d00eHe
00eF5EHeESDnO3iK?Wa>g4kMB]a>gCjML]=bdP03L]<017;B00h03@0>0dkL00I>gDkLC]e>g4Jm@[d2
CK801TfcCK9=/Tfb00<00P9>g00;C]e>g4klC_aBoDkLC_e>g4kmC]a>o@02B]d00d[LJ]IZeP02J]H0
0b5G8EI>g003C]`01E;mC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`3Ool00`00Oomoo`05Ool002]oo`8002eoo`03FUIJ=En?009o
o`3o=S/jG3Xk>Ua6_4fcBK9=/dVBCK==/TfcA[a:gDJlB]e2_4KM@[a6_EYfGWMJMUM_Dfi:gDJlB[e6
_4kMB[a:gEHDFSEF5EXeEQAJ=@00B]e:_4[MB]a>gD[LC_ebdWKCL[9fdg;BM]<03DJL@Ya6W4[LC_e>
g4kMB]a>oDkLA[e9TTfcBI9=/dVBCK=2NdJL@W]BoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:
g6kFJ]I^eR4f9ELQ=TkMC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00=oo`03001oogoo00Aoo`00;Goo00<007oo
Ool0:goo00=JEWooOol00Woo0dJl00U6_DfbCK==/TfcCK9=/dfb00000dZl00A:_DZlA[e6_@ANMP8j
>`08B]e:g4[MB]a6_D:mA[eF5@=F=@<00003B]e:_4Zl009:g@05B]a:gG;CL]=bdP02L]<00`0>AYa6
W002AY`02DkLC]e>g4kMB]a:gD:mA[e9/P02CK802TfcCK92W49lAYa2NdklC]a>oDkL0Tkl00QBoDkL
C]e>g4kmC]a>gCZM1F[F00PQER5G8EIBoDkLC_a>g5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo09oo`03001oogoo00Aoo`00;Woo
00<007ooOol0<7oo00Y6_4ZmA[a=/dVBCK=9/TfcBK9=/`80003eA[a:gDZlB]e6_4KM@[aNMUYFGWLf
>cXk=S]>gDZlC]e:_4Jm@[aJ=EHDFSEF5EXe?U]2O3iKC]e:g4kMB]a:gDZlM]=bdWKCL[9fd`0=00i:
_4kMB[a>gDkLC_e>g4kmB]a6_D:lCK=9TTfcBI9=/`02C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC_e>
g4kmC]a^eV[FK]IZeFkFJ]I:_4JLB[a6_5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lOol00006Ool002moo`03
001oogoo031oo`96_007CK92_DfbCK==/TfcCK800Sil00E2O4ZlB]e:g4[M008160ANMP<j>`05B]e:
g4[MB]a6_@02ESD02UHEESEF=Cil?U/nO3iKC]e:g4kL0T[M00E:g7;CL]=bdg;B00<03P=:g005C]e>
g4kMC]a>g@02@[d00dfbCK==/P02CK801P03B]a>g4[LC]a:g09>o006D_e>g4klC_aBoDkL0d[M00=:
g6[FJ]H00V[F00<QE`00B[`00dZl00EBoDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001B
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00goo001oo`05Ool0031oo`80
035oo`3oA[a=/cjMCK=9TTfcCK9=/dVb@W`nNd9l?W]:gDZlB]eJEUigFWINMU=>Efm6_4ZmA[a>gDZl
B]e2_5XeEQEJ=EHDFSEF5D[MB[a:gDZlC]e:g4km?Yefdg:bM]=b/WKC00d03P0=00i:g4kmC]a>gD[L
C_e>g4km@[a=/dVBCK=9TTfc00800dkLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMJ]E^eV[F
K]HQ=REGC]a>gDkLC_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0000Ioo`00<Woo00<007ooOol0;goo00E6
_4:mCK9=/dfb00==/`05001:_4ZlB[e:_003A[d3GWH00e=_DfiCK`02B[`01DJlA[e2_DJmEQD00eHe
00AF5@00001:g@=:_003C]e:g4kM009bd`04L]9bdg;CL]<4AY`3C]`01DkMB]a:gD[LA[d00dfb00E=
/dfb@Ya2O4JL00=>g00:C]e>g4klC_aBoDkLC_e>g4kmC]`3B]d4J]H00b5F8EM>g004C]`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00MB
oE;lD_aBo5;mD_`00006Ool003=oo`03001oogoo02moo`07?Ya=/dfbCK=9/TfcCK800P0001M:gDJl
B]e6_4KM@[aNMUYFGWMJMSXk=S/jFdZlC]e:_4Jm@[a6_EHDFSEF5EXe00<0003FC]e:g4kMB]a:gDZl
C]eb/WKCL[9fdg:bAYa2VdJL@Ya>oDkLC_e>g4kmB]a>gD:lCK=9TTfcBK9=/dVBAYa2NdJLC]aBoDkL
D_e>g5;mC]aBoDkLC_e>g4kmC]`nWCYmK]IZeFkFJ]HUEb4f9EM>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`4Ool0
0`00Oomoo`03Ool003Aoo`03001oogoo02ioo`06@[e=/TfcCK9=/dfb100000A:gD[LB]e:_096_@=N
MP@j>`07B]a:gD[LA[e2_EHeEQD00eHe00XnFcil?U]>gD[LC]a:g4[MB]a:g@9bd`04L]9bd`0>C]d3
B]`02DkMC]a>gDkLC]e:g4[M@[e=/`03CK802Tfc00=>g4[LC]a:g4klC]a>oDkL0Tkl00IBoDkLC]e>
g4kmC]`4J]H00b5G001:_002B[`01TkLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;l00000e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo00Ioo`03001oogoo00=oo`00=Goo0P00;goo
0?5=/dVbCK==/TfcBK92O3ik@W`nNd[MB[a:gDJlGWMJMUifFUINMdJlB[e6_4[MB[a:gDZlA[eF5EXe
EQAJ=EHE?W`nFd9l?U]>gD[LC_e:g4:m?Yafdg:bL]=b/P0>00e>gDZlC]e:_4kmB]a>oDkLC_e2_4Jm
BI9=/dVBCK==/P03009BoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e:g6kFJ]I^eR4f9EM6_4Zl
AYa:_4kLD_e>g5;mC_aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;m
D_aBo@0;Ool00`00Oomoo`03Ool003Moo`03001oogoo02aoo`03CK9=/dfb00==/`05CK9=/cil@W`n
O003A[d4GWH02E=>Dfi:_4ZlA[a:_4[LB]e:g003ESD015HEESEF=D[M0dZl00I>gD[LC]dnWG;CL]83
L]<300h02TkMC]a>g4kLC]e>g4kMC]a>gD:m0Tfb00I=/dfbCK=2O4JL@W/2C]`02TkMC]a>o4klD_e>
g4kmC]a>oDkL0d[M16[F00<QER5GC]`00dkL00=Bo5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`?Ool00`00Oomoo`03Ool003Qoo`03001oogoo02]oo`0P@[e=
/TfcBK9=/dfbCK=9/P00A[a:gDJlA]e2_4JmFUINMeYfDfmCCU=_B[a>gDZlC]e2_4Jm@[aJ=EHEFSEF
50800038B]e:_4[MB[a>gD[LC_eb/W;CL[9fdg:bL]=2VdJL@Ya>gD[LC_e>g4kMB]a>gD[LA[e9TTfc
BK9=/dVbAYa2NdJL@W]BoDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC]eZeFkFJ]HUEb4f9EM>g4kM
C]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0019oo`03001oogoo00=o
o`00>Goo00<007ooOol0:Woo00DnWDfcCK==/dfb009=/`<00003B[a:_DZl0096_@ANMP<j>`07B]a:
gD[LA[e2_DJmEQD00eHe0`0000M>gD[LC]a:g4[MB]a:g@05L]<06P0>AYa6W4JLC]e>g4kMC]a>gD[L
B]e2_DfcCK9=/dfbCK==/TkLB]a>g4[LC_a>g4kmC]`2C_`01E;mC]a>gDkLC_d00SZM16[F00XQEbEG
8EHQEdkLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo004Ool00`00Oomoo`0?Ool0
0`00Oomoo`03Ool003Yoo`8002Yoo`0_@[e9/TfcCK9=/dVbCM=ood9l?W]2O4ZlB]e6_4KM@[aNMUYF
GWLf>cXk=S/jFdZlC]e:_4Jm@[aJ=EHDFSEF5Cil?U]2O3iKC]e:g4kMB]a:gDZlC]eb/W;CL[9fd`02
00h0/DZlC]e:_4kmC]a>oDkLC]e:g4JmBK9=/dVBCK==/Tfc00=>gDZlC]e:_5;mC]aBoDkLD_e>g5;m
C]a>oDkLC_eZeFkFJ]I^eR4f0016_4ZlAYa:_4kLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo008
Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003aoo`03001oogoo02Qoo`03CK==/Tfc009=/`04CK9o
ocil@W`2?W`00d[LB]e:_005GWH2B[`01TJlB[a:g4[MB]a6_@9F=@0<EQEF=EHe?W`nFcil?U]>gD[L
C]e>g3jm1G;C0`0>0d[L00I>gDkLC]e>g4Jm@[d2CK8014fcCK9=/dfb0P030TkL00Y>gDkLC_a>o5;m
C]a>oDkLC_e>g0=:g@AZeP038EHUEdZl009:_09Bo005D_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0;Ool0
0`00Oomoo`0?Ool00`00Oomoo`02Ool003eoo`03001oogoo02Moo`05CK9=/dVbCM==/P03Ool0dTJl
B]e6_4[M@[a6_D:lGWMJMUifCdeCKTJlB[e6_4[MB[a:gDZlFSEF5EXeEQAJ=@00B]e:_4[MB[a>gD[L
C_e:g7;CL[9fdg:bL]=2VdJL@Ya6W4[LC_e>g4kMB]a>oDkLA[e9TTfcCK9=/dVbAYa2NdJL@W]BoDkL
C_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]eZeFkFJ]HUEb4f9EM>g4kMC]a>oDkLD_e>g5;mC]aBoDkL
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoA5o
o`03001oogoo00ioo`03001oogoo009oo`00?Woo00<007ooOol09Woo00E2_DfcCK==/Tfc00Aoo`04
B[a:_DZlB[`2A[d4GWH2>S/01d[LB]e:g4[M@[e6_D:m00=F=@<00003B]e:_4Zl009:g@03B]a:gD[M
00Ebd`A6W00EC]a>gDkLC]e:g4[M@[e6_DfbCK==/TfcCK92W49lAYa>g4klC]a>oDkL009>o006D_e>
g4kMC]a>oDkL0SZM16[F00TUEb5F9EM>g5;mC]a>o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol03Goo00<007ooOol0
0Woo000oOol00`00Oomoo`0UOol01CjLCK==/TfcBK801Goo0<U:_4[MA[a:gD:lA[eJEUigFWHj>cHk
>U]:_4kMB[a>gD:lA[eF55XeEQEJ=CiK@W`nFdkMB]a>gD[LB]e:_4kML[9bdg:bM]=b/P0>B[a>gDZl
C]e>g4kmC]a>oD[LA[e2_4fcBI9=/dfbCK<00dkMB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a>oDkL
K]IZeVkFJ]E^eTJlB[a6W4ZlC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`06Goo00<007ooOol03Goo00<007ooOol00Woo0010Ool2000VOol0
14fbCK==/dfc1Woo00E:g4[MB[`1604G00ANMP<j>`07B]a:gD[LB]e2_EHeEQD00UHe00LnO3iK?W/n
FdkMB]a>g002B]d00d[LB]ebd`03L]<200h3B]`01DkMC]a>gDkLC]d00T:m00E=/TfcCK9=/dfb0080
0`04C]a:g4kLC]`2C_`01U;mC]a>o4klD_e>g0=:g@06B]aZeV[FJ]HQEREG14Zl00=Bo5;mC]`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`MOol00`00Oomoo`0<Ool0
0`00Oomoo`02Ool0049oo`03001oogoo02=oo`03CK=9/TgC00Qoo`0SB[a:gDJlGWMJMUifFUICKTm=
B[e6_4[MB[a:gDZlA[eF5EXeEQAJ=EHEB]e:_4[MB[a>gD[LC_dnWG;CL[9fdg:bL]=b/P0300h0Ud[L
C_e>g4kMB]a>oDkLC_e2_4fcCK9=/dVbAYa2NdJL@W]BoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[L
C]eZeFkFJ]HUEb4f9EM>g4kMC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
02Eoo`03001oogoo00]oo`03001oogoo009oo`00@goo00<007ooOol08goo00==/dfbOol027oo0dJm
0eif00U?CDm>Cdi:_4JlB[a2_DJm@[d00eHe00AF5EHe001:g@=:_003C]e:g4kM00Ibd`0400i6W4JL
AY`3C]`03TkMB]a:gD[LA[e=/TfcCK9=/dfb@Ya2O4JL@W/2C]`02TkMC]a>o4klD_e>g4kmC]a>oD[L
0d[M0f[F00<UEb5F9EL014kL00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo2Qoo`03001o
ogoo00]oo`03001oogoo009oo`00A7oo00<007ooOol08Woo00==/TfcOol02Goo0192_4JmFUINMeYf
GWHf>SYK=S]>gDZlC]e2_4Jm@[aJ=EHEFSD30000;dkMB]a>gD[LB]e:_4kML[9bdg:bM]=b/P0>@Y]6
W4:LAYa>g4kmC]a>oD[LC]e2_4fcBK9=/dfbCK=9/TkMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g4kmC]a>
oCYm>Yd00V[F06iZ]FkF8EHUEb4fD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m;Goo00<007oo
Ool02goo00<007ooOol00Goo0015Ool2000ROol00dfcOomoo`0:Ool2A[d3GWH4>S/01T[MB]a:gD:m
A[eF5@=F=@0:?U/nNciKC]e:g4kLB]a:gD[LB]d4L]<200h3B]`02TkMC]a>gDkLC]e:g4:mCK9=/dfb
0dfc00D00dkLB]a>g4[L009>o009D_e>g4klC_aBoDkLC]e>g4km00AZeP038EH40DZl009:_004C_a>
g5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@02D_`aOol00`00Oomoo`0:Ool00`00Oomoo`01Ool004Moo`03001oogoo
01moo`03BK9oogoo00]oo`0PFWINMUYFGWMJMTZmA[a:gDJlB]e:_4kM@[aJ=EHDFSEF5EXe?U]2O3iK
C]e:g4kmB]a2_G:bM]=b/W;CL[803`803P0RB[a>gDZlC_e:g4kmC]a>oD:lCK==/TfcBK9=ddfb00@0
0e;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gFZeK]H2J]H0IR5F9EM6_4ZlAYaBoDkLD_e>g5;m
C_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoCEoo`03001oogoo00Uoo`03001oogoo005oo`00B7oo00<007ooOol07Woo00==/gooOol02goo
15if0Tm=00M:_4JlB[a:_4[MB]a:g@02ESD015HEESEF=@000dZl00A>gD[LC]e>g0Ebd`A6W0=>g00>
C]e>g4kMC]a6_DfbCK==/TfcCK9=/d9lAYa2N`9>g00:C]e>g4klC_aBoDkLC_e>g4kmC]`2B]d4J]H0
0bEG8EHUE`04C]`00e;lD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00IBoE;lD_aBo5;mD_`iOol00`00Oomoo`09Ool00`00Oomoo`01Ool004Uoo`03001oogoo02ao
o`0@GWMJMWooOoljFcHkC]e:_4kMB[a6_D:lA[eF5EXeEQ@30000TDZlB]e:_4[MB[a>gD[LL]=b/WKC
L[9bdd:KAYa2W4JLB]a>oDkLC]e:g4kM@[e6_DVbCK==/TfcCK96W49kAYa>g5;mC]aBoDkLD_e>g5;m
C]a>oDkLC_e>g3ZM>WeZeVZeK]IZeREG8EHUEdkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l03eoo`03001oogoo00Qoo`03001oogoo005oo`00
BWoo0P00;7oo00ANMWooOomoo`<j>`06B]e:g4[MB]a6_D:m0eHe00YF5Cik?U/nO4[LC]a:g4[MB]a:
g@Ebd`0:00i:g4[LB]a>gDkLC]e>g4kMB]`2@[d00dfcCK9=/`02CK<00`04C]a:g002C]`014klC]a>
oDkL0Tkl00IBoDkLC]e>g4kmC]`5J]H4B[`01TkLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo006D_eBo5;lD_aBoE;l@Goo00<007ooOol01goo00<007ooOol00Goo001<Ool00`00Oomo
o`0^Ool0?SHj>U/f>d[MB[a>gDZlA[eF55XeEQEJ=CiK@W`nFd9lB]a>gD[LB]e:_4kML[9bdg:bL]<0
3P0?B[a>gDZlC]e:g4kmC]a>oD:lA[e=/TfcBK9=ddfb00@00dkMB[a>gDkLD_e>g5;mC]aBoDkLD_e:
g4kMB]a>gFZeK]H2J]H0F25F1056_4ZlAYaBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mAWoo00<007ooOol01Woo00<007ooOol00Goo001=Ool00`00Oomoo`0^Ool02DJl
B[a:_4[MB]a:gD:mESEF5@03ESD3B[`2B]`00dkMC]`n_@05L]<300h3C]`01TkMC]a>gDkLC]e2_@==
/`05CK9=/d9lAYa2N`02C]`02TkMC]a>o4klD_e>g4kmC]a>oD[L0d[M0f[F00<UEb5FC]`00dkL0U;l
00EBoDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m04Uoo`03001oogoo00Moo`40005oo`5o
o`00CWoo00<007ooOol0;Woo00Y6_4[MA[a6_D:lA[eF5EXeEQAJ=@800024B[a:gDZlB]e:g4kmB]ab
dg:bL]=b/W;CL[96W4:LAYa:g4kmC]a>gD[LC]e:g4JmBK9=ddfbCK==/TJL@W]6W49kD_e>g4kmC]aB
oDkLD_e>g5;mC]aBoD[LC]e:g6[FJ[E^eV[F9ELQETkmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mCGoo00<007ooOol01Woo0@000Goo0Goo001?Ool2000_Ool01T[LB]e:g4Jm@[e6_@9F
=@09EQD00000001:g4kLB]a>gD[L009:g@Ebd`0=00i6W4JLAYa>g4kMC]a>gD[LB]e2_DfcCK800dfc
00U=/TkLB]a>g4[LC_a>g4kmC]`00Tkl00EBoDkLC]e>g4km008jW@AZeP8UE`058EI>o4kLD_e>g002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo004D_eBo5;lD_aBOol00`00Oomoo`05Ool10001Ool1Ool0055oo`03001oogoo02eo
o`0jB[a>gDZlA[eF55XeEQEJ=EHD@W`nFd9lB]a>gD[LC]e:_4kMB]abdg:bL]=b/`0?00i>gDZlC]e:
_4kmC]a>oD[LC]e=/TfcBK9=ddfbCK<014kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g4kmC]a>oFZeK]H2
J]H0Bb5F9EM6_4ZlAYa:_4kLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo01EOol00`00Oomoo`05Ool10001Ool1Ool0
059oo`03001oogoo02eoo`05B]a:gD[LA[eF5@03ESD02EHE?W/nFcilB]a>gDkLC]dnW@03L]<00g:c
L]<03P0200h2C]`01DkMC]a>gDkLC]d00T:m0Tfc00==/TfcCK<00P040TkL00Y>gDkLC_a>o5;mC]a>
oDkLC_e>g0=:g@AZeP039EHUEdkL00=>g003D_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;lFGoo00<007ooOol017oo0@000Goo
0Goo001COol00`00Oomoo`0]Ool01dZlC]e2_5XeEQAJ=EHE0080001fB]e:_4[MB]a>oD[LC]eb/W;C
L[=bdg:bAYa2W4JL@Y]>oDkLC]e:g4kmC]a>oD:lCM==/TfcCK9=dd9kAYa2Ne;mC]a>oDkLD_e>g5;m
C]aBoDkLD_e>g4kMB]a>gFZeK]IZeREG8EHUEdkLC]e>g4kmC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aMOol00`00Oomoo`03Ool10001Ool1
Ool005Aoo`03001oogoo02eoo`06@[e6_EHeESEF5EHe0`000TZl0T[L0d[M00Eb/g;CL]=bd`0>00A6
W008C]e>g4kMC]a:gD[LA[e=/P==/`09CK92W49lAYa2NdklC]a>oDkL009>o007D_e>g4kMC]a>oDkL
>Yd016[F0REG00PUETklC]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lD_`0HWoo00<007ooOol00goo0@000Goo001EOol2000^Ool0=T:lFSEF5EXeEQAJ
=CiK@W`nFdkMB]a>gDZlC]e:g7;CL[9bdg:c00m:_4kMB[a>gDZlC_e>g4kmB]a>gD:mCK==/TgCCK9=
d`04C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmJ[E^eP9ZeP0n8EH80TJlB[a6W5;mC]aBoDkL
D_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoFEoo`03001oogoo00=o
o`40005oo`00Egoo00<007ooOol0;7oo00e2_EHeESEF=EHE?W/nFcilB]a>gDkLC]dnW@03L]<037:c
L]<03P0?00i>g4[LC]e>g4kMC]a>g@92_@9=/`03CK9=/dfc0080109>g006C]e>g4klC_aBoDkL0Tkl
00=BoD[LB]d00T[M16[F00<UEREGB[`00TZl0U;l00EBoDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lD_`0JGoo00<007ooOol00Woo0@000Goo001HOol00`00Oomoo`0[Ool0JdJmEQAJ
=EHEFSD004[MB[a:gD[LC_e:g4kML[9bdg:cL]=b/TJL@Ya6W4:KC_e>g4kMB]a>oDkLC_e2_4gCCK9=
/dfbDM=2NdJL@W]BoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LJ]IZ]FkFJ]HUEb5F9GM>g4kMC]a>
oDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0LGoo00D007ooOomoo`00005oo`00FGoo00<007oo
Ool0:Woo0UHe00=F5EHe00000P000TZl0T[L0d[M00Eb/g;CL]=bdg:c00A6W09>g006C]e:g4[MB]a6
_Dfb1Dfc00M2O4JL@W]>o4kLC_e>g002C_`01U;mC]a>gDkLC_e>g08jW@AZeP099ELUEREGC]aBoDkL
C_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`00e;mD_aBo01eOol01000Oomoo`000Goo001JOol2000[Ool0=5HEFSEF57oo
?U]2O3iKC]e:g4kMB[a>gD[LL]=b/W;CL[=bd`0>C]e:_4kMB[a>oDkLC_e>g4kM@[e6_DfbCM==/TgC
CK801DZlC]e:_5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e>g6kF0V[F02iZ]FkFA[a:_4JLB[a>g5;mC]aB
oDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoGQoo`04001oogoo0001Ool005aoo`03001oogoo02Qoo`9F=@9oo`08?W/nFcil
?U]>g4[LC]e:g09:g@0>L]=b/g;CL]<03`0>C]a:g4kMB]a>gDkLC]e>g092_@03CK==/Tfc009=/`05
00@01D[LC]a:g002C_`01U;mC]a>o4klD_e>g0=:g@06B]aZeV[FJ]HUEPP20dZl0U;l00EBoDkLD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eB
o5;l07aoo`03001oo`00005oo`00GGoo00<007ooOol09goo00=F55XeOol00Woo05U:gDZlB]e:_4km
B]a>gD[LL]=b/g;CL[9bd`0>00l03TkmC]a>gD[LC_e>g4kmB]a6_DfbCM==/U7C@W]6W49kAYa>g4km
C]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMJ[E^eVZf9ELQETkmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m081oo`40005oo`40
0000GWoo00<007ooOol0;7oo0TZl00=:g4ZlB]d00T[M00I:g7;CL]=bdg:cL]<4AY`00dkLC]e>g002
B]d00dkM@[e=/`04CK<01d9lAYa2Nd:LC]a>oDkL009>o006D_e>g4kmC]a>oD[L0d[M0f[F00<UEbEF
9EL00dkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oE;lD_`0Q7oo0P00001OOol2000]Ool0D4kMB]a>gD[LC]e:g4[ML[9bdg:cL]=^/P0?B[a>gDZlC]e>
g4kmC]a>gD[LA[e=/TgCCK9=ddfbC]e:_4kMB[a>gDkLD_e>g5;mC]aBoDkLC_e>g4kmC]aZeVZfJ]IZ
]F[FA[a:_4JLB[a>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_b8Ool20000065oo`03001oogoo02aoo`03B]a>gD[L00=:g@09L[=bdg;CL]<03P0?B]a>gD[L
009>g006C]e>g4:m@[e=/dfb0dfc00D01005B]a>g4[L009>o006D_e>g4klC_aBoDkL0d[M00I:g6[F
J]IZeREF9EL4B[`00e;lD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eB
o7oo08Yoo`800000HWoo00<007ooOol0;7oo04M:g4kMB]a2_G:cL]=^/W;CL[<03`0>00m>g4kMB]a>
oDkLC_e:g4JmCK9=ddfbDM==/TJL@W]6W4kLC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]eZ]F[FJ[IZ
eR5F9GM>g4kMC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;l08Yoo`@0009o
o`00Hgoo00<007ooOol0;7oo00=>g4kMB]`00g;C00=b/g;C00l00dJL00=>g4kMC]`00T[M00=>gD:m
CK<014fc00M2O4JL@W]2W4kLC_e>g002C_`01U;mC]a>o4kLC_e>g0=:g@=ZeP039ELUEREG00=>g09B
o005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo8Uoo`@000Ioo`00I7oo0P00;Goo03a:g4[MB[ab
dg:cL]=^/`@?@Ya6W4:KC_e>g4kmC]a>gD[LA[e2_4gCCK9=ddfbDM=:_4kMB[a>gDkLD_e>g5;mC]aB
oDkLD_e>g4kmC]`jWCYmJ]IZ]F[F9EHUEb5FD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_f;Ool4000:
Ool006Ioo`03001oogoo02]oo`9:g@04B]abdg;CL]<200l00d[LC]e:g002C]`01TkMC]a2_D:mA[e=
/P9=/`0:CM==/`05B]a>g4[LC]a>o5;mC]`2C_`01U;mC]a>o4kLC_e>g0AZeP039EM:_4Zl009:_003
D_aBoDkL009Bo003D_eBo5;l08Yoo`@000ioo`00Igoo00<007ooOol0:goo03Ab/g;CK[=bdg:c10l0
3P@?C]a>gD[LC_e>g4kmB]a>oD:mCM==/U7CCK9=d`0400E>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:
g4kMB]aZeVZfJ]HUEREgC]a>gDkLC_e>g5;mC]aBoHYoo`<0019oo`00J7oo00<007ooOol0:Woo0g;C
00=b/gooOol00dJL00Q>g4kMC]a>g4[MC]e:g4:m1Dfc00I6W49k@Ya>g4kMC]`2C_`01U;mC]a>o4kL
C_e>g0=:g@AZeP039EHUEdkL00=>g8Uoo`@001Eoo`00JGoo0P00:goo00=bdg:cOol00Woo02P03TJL
@Y]6W4kLC_e>g4kmB]a>gD:lDM==/TgCCK9AddZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g3ZM
>WeZeVZeJ]IZ]REg9EHUMhQoo`@001Uoo`00Jgoo00<007ooOol0;Goo0P0?00U>gD[LC]a:g4kMC]a>
gD[MA[d00dfc00Y=ddfc00E:g4kLB]a>g4klD_e>g09>o006D_e>g4klC]a>oDkL16[FR7oo10007Goo
001/Ool00`00Oomoo`0/Ool08`0>10l03TkMB]a>oDkLC_e:g4km@[e6_DfbDM==/TgC00D01TkLC_e>
g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e:g6[FJ[H0QGoo10008Goo001]Ool00`00Oomoo`0/Ool3AY`0
1TkMC]a>g4kLC]e:g092_@A=/`05AYa2Nd:L@Wa>g@02C]`00dklD_e>g002C_`00dkmC]a>o@02B]d0
0d[LOomoo`21Ool3000UOol006ioo`03001oogoo02aoo`0G@Y]6W4:LC_e>g4kmC]a>gD:lA[e=/TgC
CK9AddfcC]e:_4kMB[aBoDkLD_e>g028Ool4000XOol006moo`8002eoo`09B]a>g4[LC]e>g4kMB]e>
gD:m009=/`03CM==/dfc00801@03B]a>g4[L08Moo`@002aoo`00LGoo00<007ooOol0:Woo00i>gD[L
C_e>g4kmB]a>oDkLA[e=/U7CCK9=ddfbR7oo1000<7oo001bOol00`00Oomoo`0[Ool3C]`01DkMB]a:
gD:mCM<00dfcQGoo1000=7oo001cOol00`00Oomoo`0[Ool02TkLC_e>g4kMB]a6_DfbCM==/U7CPGoo
1000>7oo001dOol2000/Ool01DkLC]e>g7oo@[d00Tfc00==ddfcOol0OGoo0`00?7oo001fOol00`00
Oomoo`0YOol00`00Oomoo`02Ool014fbDM==/dgCNWoo1000?goo001gOol00`00Oomoo`0XOol00`00
Oomoo`02Ool014JmCK==/dfcMWoo1000@goo001hOol00`00Oomoo`0WOol00`00Oomoo`02Ool014:m
CM==/U7CLWoo1000Agoo001iOol2000WOol00`00Oomoo`02Ool00d:mCK==d`1_Ool4001;Ool007]o
o`03001oogoo02Aoo`03001oogoo00=oo`03DM==/goo06]oo`<004moo`00O7oo00<007ooOol08goo
00<007ooOol00goo0TfcJ7oo1000DWoo001mOol00`00Oomoo`0ROol00`00Oomoo`03Ool00dgCCK9o
o`1SOol4001FOol007ioo`80029oo`03001oogoo00=oo`03@[e=dgoo05moo`@005Yoo`00P7oo00<0
07ooOol07goo00<007ooOol0HGoo1000GWoo0021Ool00`00Oomoo`0NOol00`00Oomoo`1NOol3001R
Ool0089oo`03001oogoo01eoo`03001oogoo05Yoo`@006Eoo`00Pgoo00<007ooOol077oo00<007oo
Ool0EWoo1000JGoo0024Ool2000LOol00`00Oomoo`1BOol4001]Ool008Ioo`03001oogoo01Uoo`03
001oogoo04ioo`@0075oo`00Qgoo00<007ooOol067oo00<007ooOol0Bgoo0`00MGoo0028Ool00`00
Oomoo`0GOol00`00Oomoo`17Ool4001hOol008Uoo`8001Moo`03001oogoo04=oo`@007aoo`00Rgoo
00<007ooOol057oo00<007ooOol0?goo1000P7oo002<Ool00`00Oomoo`0BOol00`00Oomoo`0lOol4
0024Ool008eoo`03001oogoo015oo`03001oogoo03Uoo`<008Qoo`00SWoo0P004Goo00<007ooOol0
=Goo1000Rgoo002@Ool00`00Oomoo`0>Ool00`00Oomoo`0aOol4002?Ool0095oo`03001oogoo00eo
o`03001oogoo02eoo`@009=oo`00TWoo00<007ooOol037oo00<007ooOol0:Goo1000Ugoo002COol2
000<Ool00`00Oomoo`0UOol4002KOol009Eoo`03001oogoo00Uoo`03001oogoo029oo`<009moo`00
UWoo00<007ooOol027oo00<007ooOol07Woo1000XWoo002GOol00`00Oomoo`07Ool00`00Oomoo`0J
Ool4002VOol009Qoo`03001oogoo00Ioo`03001oogoo01Ioo`@00:Yoo`00VGoo0P001Woo00<007oo
Ool04Woo1000[Woo002KOol00`00Oomoo`03Ool00`00Oomoo`0?Ool3002bOol009aoo`03001oogoo
009oo`03001oogoo00]oo`@00;Eoo`00WGoo00D007ooOomoo`0000Uoo`@00;Uoo`00WWoo0P0000=o
o`00Ool017oo1000_Goo002POol200000goo000000020031Ool00:5oo`800<Eoo`00ogooJGoo003o
OomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.6 .702 .916 r
.39641 .69585 .40171 .70133 .4106 .69963 .40531 .69461 Mtetra
.627 .73 .921 r
.40531 .69461 .4106 .69963 .41954 .69779 .41426 .69274 Mtetra
.616 .726 .924 r
.41426 .69274 .41954 .69779 .42848 .69685 .42323 .69108 Mtetra
.142 .466 .891 r
.42323 .69108 .42848 .69685 .43769 .68641 .43209 .6953 Mtetra
0 0 0 r
.43209 .6953 .43769 .68641 .44662 .68846 .44141 .68283 Mtetra
.599 .699 .913 r
.44141 .68283 .44662 .68846 .45567 .68663 .45046 .6816 Mtetra
.635 .734 .92 r
.45046 .6816 .45567 .68663 .46477 .68446 .45958 .67952 Mtetra
.64 .74 .921 r
.45958 .67952 .46477 .68446 .4739 .68225 .46872 .67729 Mtetra
.638 .739 .922 r
.46872 .67729 .4739 .68225 .48306 .68023 .4779 .67511 Mtetra
.616 .727 .925 r
.4779 .67511 .48306 .68023 .49223 .67975 .48711 .6734 Mtetra
.951 .608 .318 r
.48711 .6734 .49223 .67975 .50151 .67047 .49601 .71417 Mtetra
0 0 .238 r
.49601 .71417 .50151 .67047 .51075 .67038 .50566 .66492 Mtetra
.618 .716 .915 r
.50566 .66492 .51075 .67038 .52004 .66824 .51496 .66321 Mtetra
.644 .741 .919 r
.51496 .66321 .52004 .66824 .52936 .6658 .5243 .66085 Mtetra
.651 .747 .92 r
.5243 .66085 .52936 .6658 .53871 .66324 .53367 .65832 Mtetra
.654 .75 .92 r
.53367 .65832 .53871 .66324 .54809 .66061 .54308 .6557 Mtetra
.656 .752 .92 r
.54308 .6557 .54809 .66061 .55751 .65792 .55251 .65301 Mtetra
.658 .753 .92 r
.55251 .65301 .55751 .65792 .56695 .65519 .56198 .65028 Mtetra
.659 .754 .92 r
.56198 .65028 .56695 .65519 .57643 .65244 .57148 .64752 Mtetra
.57148 .64752 .57643 .65244 .58594 .64968 .58102 .64475 Mtetra
.58102 .64475 .58594 .64968 .59548 .64692 .59058 .64196 Mtetra
.59058 .64196 .59548 .64692 .60506 .64415 .60018 .63917 Mtetra
.658 .753 .92 r
.60018 .63917 .60506 .64415 .61467 .64138 .60981 .63638 Mtetra
.60981 .63638 .61467 .64138 .62431 .6386 .61947 .63358 Mtetra
.61947 .63358 .62431 .6386 .63398 .63582 .62917 .63078 Mtetra
.62917 .63078 .63398 .63582 .64369 .63303 .6389 .62798 Mtetra
.6389 .62798 .64369 .63303 .65343 .63024 .64866 .62516 Mtetra
.64866 .62516 .65343 .63024 .6632 .62744 .65846 .62235 Mtetra
.657 .753 .92 r
.65846 .62235 .6632 .62744 .67301 .62463 .66829 .61952 Mtetra
.66829 .61952 .67301 .62463 .68286 .62182 .67816 .61668 Mtetra
.67816 .61668 .68286 .62182 .69273 .61899 .68806 .61384 Mtetra
.68806 .61384 .69273 .61899 .70264 .61616 .69799 .61099 Mtetra
.69799 .61099 .70264 .61616 .71259 .61332 .70796 .60813 Mtetra
.657 .752 .92 r
.70796 .60813 .71259 .61332 .72257 .61047 .71797 .60526 Mtetra
.71797 .60526 .72257 .61047 .73258 .60761 .72801 .60238 Mtetra
.72801 .60238 .73258 .60761 .74263 .60474 .73808 .59949 Mtetra
.73808 .59949 .74263 .60474 .75272 .60186 .74819 .59659 Mtetra
.74819 .59659 .75272 .60186 .76284 .59897 .75834 .59369 Mtetra
.75834 .59369 .76284 .59897 .773 .59608 .76852 .59077 Mtetra
.76852 .59077 .773 .59608 .78319 .59317 .77874 .58785 Mtetra
.77874 .58785 .78319 .59317 .79342 .59025 .789 .58491 Mtetra
.789 .58491 .79342 .59025 .80369 .58733 .79929 .58197 Mtetra
.79929 .58197 .80369 .58733 .81399 .58439 .80961 .57901 Mtetra
.80961 .57901 .81399 .58439 .82433 .58145 .81998 .57605 Mtetra
.81998 .57605 .82433 .58145 .8347 .57849 .83038 .57307 Mtetra
.83038 .57307 .8347 .57849 .84511 .57553 .84082 .57009 Mtetra
.84082 .57009 .84511 .57553 .85556 .57255 .8513 .56709 Mtetra
.8513 .56709 .85556 .57255 .86605 .56956 .86181 .56408 Mtetra
.86181 .56408 .86605 .56956 .87658 .56657 .87236 .56107 Mtetra
.87236 .56107 .87658 .56657 .88714 .56356 .88295 .55804 Mtetra
.88295 .55804 .88714 .56356 .89774 .56054 .89358 .555 Mtetra
.89358 .555 .89774 .56054 .90838 .55752 .90425 .55196 Mtetra
.90425 .55196 .90838 .55752 .91906 .55448 .91496 .5489 Mtetra
.91496 .5489 .91906 .55448 .92977 .55143 .9257 .54583 Mtetra
.9257 .54583 .92977 .55143 .94053 .54837 .93649 .54275 Mtetra
.93649 .54275 .94053 .54837 .95132 .5453 .94731 .53966 Mtetra
.94731 .53966 .95132 .5453 .96216 .54222 .95817 .53655 Mtetra
.95817 .53655 .96216 .54222 .97303 .53913 .96908 .53344 Mtetra
.96908 .53344 .97303 .53913 .98394 .53602 .98002 .53032 Mtetra
.504 .598 .881 r
.39116 .68844 .39641 .69585 .40531 .69461 .39998 .68945 Mtetra
.62 .723 .92 r
.39998 .68945 .40531 .69461 .41426 .69274 .40894 .68771 Mtetra
.626 .73 .922 r
.40894 .68771 .41426 .69274 .42323 .69108 .41794 .68584 Mtetra
.58 .707 .93 r
.41794 .68584 .42323 .69108 .43209 .6953 .42695 .68487 Mtetra
.766 .651 .734 r
.42695 .68487 .43209 .6953 .44141 .68283 .43624 .67435 Mtetra
.469 .552 .858 r
.43624 .67435 .44141 .68283 .45046 .6816 .44523 .67638 Mtetra
.625 .725 .919 r
.44523 .67638 .45046 .6816 .45958 .67952 .45435 .67451 Mtetra
.639 .738 .92 r
.45435 .67451 .45958 .67952 .46872 .67729 .46352 .67231 Mtetra
.64 .74 .921 r
.46352 .67231 .46872 .67729 .4779 .67511 .47272 .67006 Mtetra
.632 .735 .923 r
.47272 .67006 .4779 .67511 .48711 .6734 .48195 .66799 Mtetra
.553 .694 .933 r
.48195 .66799 .48711 .6734 .49601 .71417 .49119 .66749 Mtetra
.634 .456 .624 r
.49119 .66749 .49601 .71417 .50566 .66492 .50055 .65814 Mtetra
.554 .645 .894 r
.50055 .65814 .50566 .66492 .51496 .66321 .50986 .65801 Mtetra
.636 .733 .919 r
.50986 .65801 .51496 .66321 .5243 .66085 .51922 .65583 Mtetra
.648 .745 .92 r
.51922 .65583 .5243 .66085 .53367 .65832 .52861 .65335 Mtetra
.653 .749 .92 r
.52861 .65335 .53367 .65832 .54308 .6557 .53803 .65075 Mtetra
.655 .751 .92 r
.53803 .65075 .54308 .6557 .55251 .65301 .54749 .64807 Mtetra
.657 .752 .92 r
.54749 .64807 .55251 .65301 .56198 .65028 .55698 .64534 Mtetra
.658 .753 .92 r
.55698 .64534 .56198 .65028 .57148 .64752 .5665 .64257 Mtetra
.659 .754 .92 r
.5665 .64257 .57148 .64752 .58102 .64475 .57606 .63978 Mtetra
.57606 .63978 .58102 .64475 .59058 .64196 .58564 .63697 Mtetra
.58564 .63697 .59058 .64196 .60018 .63917 .59526 .63416 Mtetra
.59526 .63416 .60018 .63917 .60981 .63638 .60492 .63135 Mtetra
.658 .753 .92 r
.60492 .63135 .60981 .63638 .61947 .63358 .6146 .62854 Mtetra
.6146 .62854 .61947 .63358 .62917 .63078 .62432 .62571 Mtetra
.62432 .62571 .62917 .63078 .6389 .62798 .63408 .62289 Mtetra
.63408 .62289 .6389 .62798 .64866 .62516 .64386 .62006 Mtetra
.64386 .62006 .64866 .62516 .65846 .62235 .65368 .61722 Mtetra
.65368 .61722 .65846 .62235 .66829 .61952 .66354 .61437 Mtetra
.657 .753 .92 r
.66354 .61437 .66829 .61952 .67816 .61668 .67343 .61152 Mtetra
.67343 .61152 .67816 .61668 .68806 .61384 .68335 .60866 Mtetra
.68335 .60866 .68806 .61384 .69799 .61099 .69331 .60578 Mtetra
.69331 .60578 .69799 .61099 .70796 .60813 .70331 .60291 Mtetra
.657 .752 .92 r
.70331 .60291 .70796 .60813 .71797 .60526 .71333 .60002 Mtetra
.71333 .60002 .71797 .60526 .72801 .60238 .7234 .59712 Mtetra
.7234 .59712 .72801 .60238 .73808 .59949 .7335 .59421 Mtetra
.7335 .59421 .73808 .59949 .74819 .59659 .74364 .5913 Mtetra
.74364 .5913 .74819 .59659 .75834 .59369 .75381 .58837 Mtetra
.75381 .58837 .75834 .59369 .76852 .59077 .76402 .58543 Mtetra
.76402 .58543 .76852 .59077 .77874 .58785 .77426 .58249 Mtetra
.77426 .58249 .77874 .58785 .789 .58491 .78454 .57953 Mtetra
.78454 .57953 .789 .58491 .79929 .58197 .79486 .57657 Mtetra
.79486 .57657 .79929 .58197 .80961 .57901 .80521 .5736 Mtetra
.80521 .5736 .80961 .57901 .81998 .57605 .8156 .57061 Mtetra
.8156 .57061 .81998 .57605 .83038 .57307 .82603 .56762 Mtetra
.82603 .56762 .83038 .57307 .84082 .57009 .8365 .56461 Mtetra
.8365 .56461 .84082 .57009 .8513 .56709 .847 .56159 Mtetra
.847 .56159 .8513 .56709 .86181 .56408 .85754 .55857 Mtetra
.85754 .55857 .86181 .56408 .87236 .56107 .86812 .55553 Mtetra
.86812 .55553 .87236 .56107 .88295 .55804 .87874 .55248 Mtetra
.87874 .55248 .88295 .55804 .89358 .555 .8894 .54943 Mtetra
.8894 .54943 .89358 .555 .90425 .55196 .9001 .54636 Mtetra
.9001 .54636 .90425 .55196 .91496 .5489 .91083 .54328 Mtetra
.91083 .54328 .91496 .5489 .9257 .54583 .9216 .54019 Mtetra
.9216 .54019 .9257 .54583 .93649 .54275 .93242 .53709 Mtetra
.93242 .53709 .93649 .54275 .94731 .53966 .94327 .53397 Mtetra
.94327 .53397 .94731 .53966 .95817 .53655 .95416 .53085 Mtetra
.95416 .53085 .95817 .53655 .96908 .53344 .9651 .52772 Mtetra
.9651 .52772 .96908 .53344 .98002 .53032 .97607 .52457 Mtetra
0 0 0 r
.38509 .70073 .39116 .68844 .39998 .68945 .39464 .6839 Mtetra
.6 .702 .916 r
.39464 .6839 .39998 .68945 .40894 .68771 .4036 .68262 Mtetra
.627 .73 .921 r
.4036 .68262 .40894 .68771 .41794 .68584 .41261 .68072 Mtetra
.616 .726 .924 r
.41261 .68072 .41794 .68584 .42695 .68487 .42166 .67902 Mtetra
.145 .467 .892 r
.42166 .67902 .42695 .68487 .43624 .67435 .43058 .68323 Mtetra
0 0 0 r
.43058 .68323 .43624 .67435 .44523 .67638 .43997 .67068 Mtetra
.599 .699 .913 r
.43997 .67068 .44523 .67638 .45435 .67451 .4491 .6694 Mtetra
.635 .734 .92 r
.4491 .6694 .45435 .67451 .46352 .67231 .45828 .66728 Mtetra
.64 .74 .921 r
.45828 .66728 .46352 .67231 .47272 .67006 .4675 .66502 Mtetra
.638 .739 .922 r
.4675 .66502 .47272 .67006 .48195 .66799 .47675 .6628 Mtetra
.616 .727 .925 r
.47675 .6628 .48195 .66799 .49119 .66749 .48603 .66105 Mtetra
.951 .607 .313 r
.48603 .66105 .49119 .66749 .50055 .65814 .49498 .70198 Mtetra
0 0 .232 r
.49498 .70198 .50055 .65814 .50986 .65801 .50472 .65247 Mtetra
.618 .716 .915 r
.50472 .65247 .50986 .65801 .51922 .65583 .5141 .65072 Mtetra
.644 .741 .919 r
.5141 .65072 .51922 .65583 .52861 .65335 .52351 .64833 Mtetra
.651 .747 .92 r
.52351 .64833 .52861 .65335 .53803 .65075 .53296 .64575 Mtetra
.654 .75 .92 r
.53296 .64575 .53803 .65075 .54749 .64807 .54244 .64309 Mtetra
.656 .752 .92 r
.54244 .64309 .54749 .64807 .55698 .64534 .55195 .64036 Mtetra
.658 .753 .92 r
.55195 .64036 .55698 .64534 .5665 .64257 .56149 .63758 Mtetra
.659 .754 .92 r
.56149 .63758 .5665 .64257 .57606 .63978 .57107 .63478 Mtetra
.57107 .63478 .57606 .63978 .58564 .63697 .58068 .63196 Mtetra
.58068 .63196 .58564 .63697 .59526 .63416 .59032 .62913 Mtetra
.59032 .62913 .59526 .63416 .60492 .63135 .59999 .62629 Mtetra
.658 .753 .92 r
.59999 .62629 .60492 .63135 .6146 .62854 .6097 .62346 Mtetra
.6097 .62346 .6146 .62854 .62432 .62571 .61945 .62061 Mtetra
.61945 .62061 .62432 .62571 .63408 .62289 .62922 .61777 Mtetra
.62922 .61777 .63408 .62289 .64386 .62006 .63903 .61492 Mtetra
.63903 .61492 .64386 .62006 .65368 .61722 .64888 .61206 Mtetra
.64888 .61206 .65368 .61722 .66354 .61437 .65876 .60919 Mtetra
.657 .753 .92 r
.65876 .60919 .66354 .61437 .67343 .61152 .66867 .60632 Mtetra
.66867 .60632 .67343 .61152 .68335 .60866 .67862 .60344 Mtetra
.67862 .60344 .68335 .60866 .69331 .60578 .6886 .60055 Mtetra
.6886 .60055 .69331 .60578 .70331 .60291 .69862 .59765 Mtetra
.69862 .59765 .70331 .60291 .71333 .60002 .70867 .59474 Mtetra
.657 .752 .92 r
.70867 .59474 .71333 .60002 .7234 .59712 .71876 .59182 Mtetra
.71876 .59182 .7234 .59712 .7335 .59421 .72889 .5889 Mtetra
.72889 .5889 .7335 .59421 .74364 .5913 .73905 .58596 Mtetra
.73905 .58596 .74364 .5913 .75381 .58837 .74925 .58302 Mtetra
.74925 .58302 .75381 .58837 .76402 .58543 .75948 .58006 Mtetra
.75948 .58006 .76402 .58543 .77426 .58249 .76975 .5771 Mtetra
.76975 .5771 .77426 .58249 .78454 .57953 .78006 .57412 Mtetra
.78006 .57412 .78454 .57953 .79486 .57657 .7904 .57114 Mtetra
.7904 .57114 .79486 .57657 .80521 .5736 .80078 .56814 Mtetra
.80078 .56814 .80521 .5736 .8156 .57061 .8112 .56514 Mtetra
.8112 .56514 .8156 .57061 .82603 .56762 .82165 .56212 Mtetra
.82165 .56212 .82603 .56762 .8365 .56461 .83215 .5591 Mtetra
.83215 .5591 .8365 .56461 .847 .56159 .84268 .55606 Mtetra
.84268 .55606 .847 .56159 .85754 .55857 .85325 .55302 Mtetra
.85325 .55302 .85754 .55857 .86812 .55553 .86386 .54996 Mtetra
.86386 .54996 .86812 .55553 .87874 .55248 .8745 .54689 Mtetra
.8745 .54689 .87874 .55248 .8894 .54943 .88519 .54381 Mtetra
.88519 .54381 .8894 .54943 .9001 .54636 .89591 .54072 Mtetra
.89591 .54072 .9001 .54636 .91083 .54328 .90667 .53762 Mtetra
.90667 .53762 .91083 .54328 .9216 .54019 .91748 .53451 Mtetra
.91748 .53451 .9216 .54019 .93242 .53709 .92832 .53139 Mtetra
.92832 .53139 .93242 .53709 .94327 .53397 .9392 .52825 Mtetra
.9392 .52825 .94327 .53397 .95416 .53085 .95012 .52511 Mtetra
.95012 .52511 .95416 .53085 .9651 .52772 .96109 .52195 Mtetra
.96109 .52195 .9651 .52772 .97607 .52457 .97209 .51879 Mtetra
.722 .591 .708 r
.38006 .68591 .38509 .70073 .39464 .6839 .38934 .6764 Mtetra
.504 .598 .881 r
.38934 .6764 .39464 .6839 .4036 .68262 .39822 .67739 Mtetra
.62 .723 .92 r
.39822 .67739 .4036 .68262 .41261 .68072 .40725 .67561 Mtetra
.626 .73 .922 r
.40725 .67561 .41261 .68072 .42166 .67902 .41632 .6737 Mtetra
.58 .707 .93 r
.41632 .6737 .42166 .67902 .43058 .68323 .42539 .67269 Mtetra
.766 .651 .735 r
.42539 .67269 .43058 .68323 .43997 .67068 .43476 .6621 Mtetra
.469 .552 .859 r
.43476 .6621 .43997 .67068 .4491 .6694 .44382 .66411 Mtetra
.625 .725 .919 r
.44382 .66411 .4491 .6694 .45828 .66728 .45301 .6622 Mtetra
.639 .738 .92 r
.45301 .6622 .45828 .66728 .4675 .66502 .46225 .65996 Mtetra
.64 .74 .921 r
.46225 .65996 .4675 .66502 .47675 .6628 .47152 .65767 Mtetra
.632 .735 .923 r
.47152 .65767 .47675 .6628 .48603 .66105 .48082 .65556 Mtetra
.553 .694 .933 r
.48082 .65556 .48603 .66105 .49498 .70198 .49014 .65502 Mtetra
.634 .455 .623 r
.49014 .65502 .49498 .70198 .50472 .65247 .49957 .6456 Mtetra
.553 .645 .894 r
.49957 .6456 .50472 .65247 .5141 .65072 .50895 .64544 Mtetra
.636 .733 .919 r
.50895 .64544 .5141 .65072 .52351 .64833 .51838 .64323 Mtetra
.648 .745 .92 r
.51838 .64323 .52351 .64833 .53296 .64575 .52785 .6407 Mtetra
.653 .749 .92 r
.52785 .6407 .53296 .64575 .54244 .64309 .53735 .63806 Mtetra
.655 .751 .92 r
.53735 .63806 .54244 .64309 .55195 .64036 .54688 .63533 Mtetra
.657 .752 .92 r
.54688 .63533 .55195 .64036 .56149 .63758 .55645 .63256 Mtetra
.658 .753 .92 r
.55645 .63256 .56149 .63758 .57107 .63478 .56605 .62974 Mtetra
.659 .754 .92 r
.56605 .62974 .57107 .63478 .58068 .63196 .57568 .62691 Mtetra
.57568 .62691 .58068 .63196 .59032 .62913 .58534 .62406 Mtetra
.58534 .62406 .59032 .62913 .59999 .62629 .59504 .6212 Mtetra
.59504 .6212 .59999 .62629 .6097 .62346 .60477 .61834 Mtetra
.658 .753 .92 r
.60477 .61834 .6097 .62346 .61945 .62061 .61454 .61548 Mtetra
.61454 .61548 .61945 .62061 .62922 .61777 .62434 .61262 Mtetra
.62434 .61262 .62922 .61777 .63903 .61492 .63417 .60974 Mtetra
.63417 .60974 .63903 .61492 .64888 .61206 .64404 .60687 Mtetra
.64404 .60687 .64888 .61206 .65876 .60919 .65394 .60398 Mtetra
.65394 .60398 .65876 .60919 .66867 .60632 .66388 .60109 Mtetra
.657 .753 .92 r
.66388 .60109 .66867 .60632 .67862 .60344 .67385 .59819 Mtetra
.67385 .59819 .67862 .60344 .6886 .60055 .68386 .59528 Mtetra
.68386 .59528 .6886 .60055 .69862 .59765 .6939 .59236 Mtetra
.6939 .59236 .69862 .59765 .70867 .59474 .70398 .58943 Mtetra
.657 .752 .92 r
.70398 .58943 .70867 .59474 .71876 .59182 .71409 .58649 Mtetra
.71409 .58649 .71876 .59182 .72889 .5889 .72424 .58355 Mtetra
.72424 .58355 .72889 .5889 .73905 .58596 .73443 .58059 Mtetra
.73443 .58059 .73905 .58596 .74925 .58302 .74465 .57763 Mtetra
.74465 .57763 .74925 .58302 .75948 .58006 .75491 .57465 Mtetra
.75491 .57465 .75948 .58006 .76975 .5771 .76521 .57167 Mtetra
.76521 .57167 .76975 .5771 .78006 .57412 .77554 .56867 Mtetra
.77554 .56867 .78006 .57412 .7904 .57114 .78591 .56567 Mtetra
.78591 .56567 .7904 .57114 .80078 .56814 .79632 .56265 Mtetra
.79632 .56265 .80078 .56814 .8112 .56514 .80676 .55963 Mtetra
.80676 .55963 .8112 .56514 .82165 .56212 .81725 .55659 Mtetra
.81725 .55659 .82165 .56212 .83215 .5591 .82777 .55355 Mtetra
.82777 .55355 .83215 .5591 .84268 .55606 .83833 .55049 Mtetra
.83833 .55049 .84268 .55606 .85325 .55302 .84892 .54742 Mtetra
.84892 .54742 .85325 .55302 .86386 .54996 .85956 .54435 Mtetra
.85956 .54435 .86386 .54996 .8745 .54689 .87023 .54126 Mtetra
.87023 .54126 .8745 .54689 .88519 .54381 .88095 .53816 Mtetra
.88095 .53816 .88519 .54381 .89591 .54072 .8917 .53505 Mtetra
.8917 .53505 .89591 .54072 .90667 .53762 .90249 .53193 Mtetra
.90249 .53193 .90667 .53762 .91748 .53451 .91332 .52879 Mtetra
.91332 .52879 .91748 .53451 .92832 .53139 .9242 .52565 Mtetra
.9242 .52565 .92832 .53139 .9392 .52825 .93511 .5225 Mtetra
.93511 .5225 .9392 .52825 .95012 .52511 .94606 .51933 Mtetra
.94606 .51933 .95012 .52511 .96109 .52195 .95705 .51615 Mtetra
.95705 .51615 .96109 .52195 .97209 .51879 .96809 .51296 Mtetra
0 .018 .54 r
.37465 .67983 .38006 .68591 .38934 .6764 .38321 .68869 Mtetra
0 0 0 r
.38321 .68869 .38934 .6764 .39822 .67739 .39283 .67175 Mtetra
.6 .702 .916 r
.39283 .67175 .39822 .67739 .40725 .67561 .40186 .67044 Mtetra
.627 .73 .921 r
.40186 .67044 .40725 .67561 .41632 .6737 .41094 .6685 Mtetra
.616 .726 .924 r
.41094 .6685 .41632 .6737 .42539 .67269 .42006 .66676 Mtetra
.149 .469 .892 r
.42006 .66676 .42539 .67269 .43476 .6621 .42904 .67096 Mtetra
0 0 0 r
.42904 .67096 .43476 .6621 .44382 .66411 .43851 .65832 Mtetra
.599 .699 .913 r
.43851 .65832 .44382 .66411 .45301 .6622 .44771 .65701 Mtetra
.635 .734 .92 r
.44771 .65701 .45301 .6622 .46225 .65996 .45696 .65485 Mtetra
.64 .74 .921 r
.45696 .65485 .46225 .65996 .47152 .65767 .46625 .65255 Mtetra
.638 .739 .922 r
.46625 .65255 .47152 .65767 .48082 .65556 .47557 .65029 Mtetra
.616 .727 .925 r
.47557 .65029 .48082 .65556 .49014 .65502 .48493 .6485 Mtetra
.951 .605 .308 r
.48493 .6485 .49014 .65502 .49957 .6456 .49394 .68958 Mtetra
0 0 .226 r
.49394 .68958 .49957 .6456 .50895 .64544 .50377 .63982 Mtetra
.618 .716 .915 r
.50377 .63982 .50895 .64544 .51838 .64323 .51322 .63803 Mtetra
.644 .741 .919 r
.51322 .63803 .51838 .64323 .52785 .6407 .52271 .63559 Mtetra
.651 .747 .92 r
.52271 .63559 .52785 .6407 .53735 .63806 .53223 .63298 Mtetra
.654 .75 .92 r
.53223 .63298 .53735 .63806 .54688 .63533 .54178 .63027 Mtetra
.656 .752 .92 r
.54178 .63027 .54688 .63533 .55645 .63256 .55137 .62749 Mtetra
.658 .753 .92 r
.55137 .62749 .55645 .63256 .56605 .62974 .56099 .62467 Mtetra
.659 .754 .92 r
.56099 .62467 .56605 .62974 .57568 .62691 .57065 .62182 Mtetra
.57065 .62182 .57568 .62691 .58534 .62406 .58033 .61896 Mtetra
.58033 .61896 .58534 .62406 .59504 .6212 .59005 .61608 Mtetra
.59005 .61608 .59504 .6212 .60477 .61834 .59981 .6132 Mtetra
.658 .753 .92 r
.59981 .6132 .60477 .61834 .61454 .61548 .6096 .61032 Mtetra
.6096 .61032 .61454 .61548 .62434 .61262 .61942 .60743 Mtetra
.61942 .60743 .62434 .61262 .63417 .60974 .62928 .60454 Mtetra
.62928 .60454 .63417 .60974 .64404 .60687 .63917 .60164 Mtetra
.63917 .60164 .64404 .60687 .65394 .60398 .64909 .59874 Mtetra
.64909 .59874 .65394 .60398 .66388 .60109 .65906 .59582 Mtetra
.657 .753 .92 r
.65906 .59582 .66388 .60109 .67385 .59819 .66905 .5929 Mtetra
.66905 .5929 .67385 .59819 .68386 .59528 .67908 .58997 Mtetra
.67908 .58997 .68386 .59528 .6939 .59236 .68915 .58703 Mtetra
.68915 .58703 .6939 .59236 .70398 .58943 .69926 .58409 Mtetra
.69926 .58409 .70398 .58943 .71409 .58649 .70939 .58113 Mtetra
.657 .752 .92 r
.70939 .58113 .71409 .58649 .72424 .58355 .71957 .57816 Mtetra
.71957 .57816 .72424 .58355 .73443 .58059 .72978 .57519 Mtetra
.72978 .57519 .73443 .58059 .74465 .57763 .74003 .5722 Mtetra
.74003 .5722 .74465 .57763 .75491 .57465 .75032 .56921 Mtetra
.75032 .56921 .75491 .57465 .76521 .57167 .76064 .5662 Mtetra
.76064 .5662 .76521 .57167 .77554 .56867 .771 .56319 Mtetra
.771 .56319 .77554 .56867 .78591 .56567 .78139 .56017 Mtetra
.78139 .56017 .78591 .56567 .79632 .56265 .79183 .55713 Mtetra
.79183 .55713 .79632 .56265 .80676 .55963 .8023 .55408 Mtetra
.8023 .55408 .80676 .55963 .81725 .55659 .81281 .55103 Mtetra
.81281 .55103 .81725 .55659 .82777 .55355 .82336 .54796 Mtetra
.82336 .54796 .82777 .55355 .83833 .55049 .83394 .54488 Mtetra
.83394 .54488 .83833 .55049 .84892 .54742 .84457 .5418 Mtetra
.84457 .5418 .84892 .54742 .85956 .54435 .85523 .5387 Mtetra
.85523 .5387 .85956 .54435 .87023 .54126 .86593 .53559 Mtetra
.86593 .53559 .87023 .54126 .88095 .53816 .87668 .53247 Mtetra
.87668 .53247 .88095 .53816 .8917 .53505 .88746 .52934 Mtetra
.88746 .52934 .8917 .53505 .90249 .53193 .89828 .52619 Mtetra
.89828 .52619 .90249 .53193 .91332 .52879 .90914 .52304 Mtetra
.90914 .52304 .91332 .52879 .9242 .52565 .92004 .51987 Mtetra
.92004 .51987 .9242 .52565 .93511 .5225 .93098 .5167 Mtetra
.93098 .5167 .93511 .5225 .94606 .51933 .94197 .51351 Mtetra
.94197 .51351 .94606 .51933 .95705 .51615 .95299 .51031 Mtetra
.95299 .51031 .95705 .51615 .96809 .51296 .96405 .5071 Mtetra
.56 .697 .932 r
.36918 .67441 .37465 .67983 .38321 .68869 .37814 .67375 Mtetra
.723 .591 .708 r
.37814 .67375 .38321 .68869 .39283 .67175 .38748 .66416 Mtetra
.503 .598 .882 r
.38748 .66416 .39283 .67175 .40186 .67044 .39644 .66513 Mtetra
.62 .723 .92 r
.39644 .66513 .40186 .67044 .41094 .6685 .40553 .66331 Mtetra
.626 .73 .922 r
.40553 .66331 .41094 .6685 .42006 .66676 .41467 .66136 Mtetra
.58 .707 .93 r
.41467 .66136 .42006 .66676 .42904 .67096 .42382 .66032 Mtetra
.767 .652 .735 r
.42382 .66032 .42904 .67096 .43851 .65832 .43325 .64965 Mtetra
.468 .552 .859 r
.43325 .64965 .43851 .65832 .44771 .65701 .44238 .65164 Mtetra
.625 .725 .919 r
.44238 .65164 .44771 .65701 .45696 .65485 .45165 .64969 Mtetra
.639 .738 .92 r
.45165 .64969 .45696 .65485 .46625 .65255 .46095 .64741 Mtetra
.64 .74 .921 r
.46095 .64741 .46625 .65255 .47557 .65029 .4703 .64508 Mtetra
.632 .735 .922 r
.4703 .64508 .47557 .65029 .48493 .6485 .47967 .64293 Mtetra
.554 .694 .933 r
.47967 .64293 .48493 .6485 .49394 .68958 .48907 .64236 Mtetra
.633 .453 .622 r
.48907 .64236 .49394 .68958 .50377 .63982 .49857 .63286 Mtetra
.553 .645 .894 r
.49857 .63286 .50377 .63982 .51322 .63803 .50803 .63267 Mtetra
.636 .733 .919 r
.50803 .63267 .51322 .63803 .52271 .63559 .51753 .63041 Mtetra
.648 .745 .92 r
.51753 .63041 .52271 .63559 .53223 .63298 .52708 .62785 Mtetra
.653 .749 .92 r
.52708 .62785 .53223 .63298 .54178 .63027 .53665 .62515 Mtetra
.655 .751 .92 r
.53665 .62515 .54178 .63027 .55137 .62749 .54626 .62239 Mtetra
.657 .752 .92 r
.54626 .62239 .55137 .62749 .56099 .62467 .55591 .61957 Mtetra
.658 .753 .92 r
.55591 .61957 .56099 .62467 .57065 .62182 .56558 .61671 Mtetra
.659 .754 .92 r
.56558 .61671 .57065 .62182 .58033 .61896 .57529 .61382 Mtetra
.57529 .61382 .58033 .61896 .59005 .61608 .58504 .61093 Mtetra
.58504 .61093 .59005 .61608 .59981 .6132 .59481 .60803 Mtetra
.59481 .60803 .59981 .6132 .6096 .61032 .60462 .60512 Mtetra
.658 .753 .92 r
.60462 .60512 .6096 .61032 .61942 .60743 .61447 .60221 Mtetra
.61447 .60221 .61942 .60743 .62928 .60454 .62435 .5993 Mtetra
.62435 .5993 .62928 .60454 .63917 .60164 .63427 .59638 Mtetra
.63427 .59638 .63917 .60164 .64909 .59874 .64422 .59346 Mtetra
.64422 .59346 .64909 .59874 .65906 .59582 .6542 .59052 Mtetra
.6542 .59052 .65906 .59582 .66905 .5929 .66422 .58758 Mtetra
.657 .753 .92 r
.66422 .58758 .66905 .5929 .67908 .58997 .67428 .58463 Mtetra
.67428 .58463 .67908 .58997 .68915 .58703 .68437 .58167 Mtetra
.68437 .58167 .68915 .58703 .69926 .58409 .6945 .57871 Mtetra
.6945 .57871 .69926 .58409 .70939 .58113 .70466 .57573 Mtetra
.657 .752 .92 r
.70466 .57573 .70939 .58113 .71957 .57816 .71487 .57274 Mtetra
.71487 .57274 .71957 .57816 .72978 .57519 .7251 .56975 Mtetra
.7251 .56975 .72978 .57519 .74003 .5722 .73538 .56674 Mtetra
.73538 .56674 .74003 .5722 .75032 .56921 .74569 .56373 Mtetra
.74569 .56373 .75032 .56921 .76064 .5662 .75604 .5607 Mtetra
.75604 .5607 .76064 .5662 .771 .56319 .76642 .55767 Mtetra
.76642 .55767 .771 .56319 .78139 .56017 .77684 .55462 Mtetra
.77684 .55462 .78139 .56017 .79183 .55713 .78731 .55157 Mtetra
.78731 .55157 .79183 .55713 .8023 .55408 .7978 .5485 Mtetra
.7978 .5485 .8023 .55408 .81281 .55103 .80834 .54543 Mtetra
.80834 .54543 .81281 .55103 .82336 .54796 .81892 .54234 Mtetra
.81892 .54234 .82336 .54796 .83394 .54488 .82953 .53924 Mtetra
.82953 .53924 .83394 .54488 .84457 .5418 .84018 .53613 Mtetra
.84018 .53613 .84457 .5418 .85523 .5387 .85088 .53301 Mtetra
.85088 .53301 .85523 .5387 .86593 .53559 .86161 .52988 Mtetra
.86161 .52988 .86593 .53559 .87668 .53247 .87238 .52674 Mtetra
.87238 .52674 .87668 .53247 .88746 .52934 .88319 .52358 Mtetra
.88319 .52358 .88746 .52934 .89828 .52619 .89404 .52042 Mtetra
.89404 .52042 .89828 .52619 .90914 .52304 .90493 .51724 Mtetra
.90493 .51724 .90914 .52304 .92004 .51987 .91586 .51406 Mtetra
.91586 .51406 .92004 .51987 .93098 .5167 .92683 .51086 Mtetra
.92683 .51086 .93098 .5167 .94197 .51351 .93784 .50765 Mtetra
.93784 .50765 .94197 .51351 .95299 .51031 .9489 .50443 Mtetra
.9489 .50443 .95299 .51031 .96405 .5071 .95999 .50119 Mtetra
.606 .72 .925 r
.36367 .66912 .36918 .67441 .37814 .67375 .37268 .66759 Mtetra
0 .024 .547 r
.37268 .66759 .37814 .67375 .38748 .66416 .38129 .67646 Mtetra
0 0 0 r
.38129 .67646 .38748 .66416 .39644 .66513 .391 .65941 Mtetra
.599 .702 .916 r
.391 .65941 .39644 .66513 .40553 .66331 .40009 .65807 Mtetra
.627 .73 .921 r
.40009 .65807 .40553 .66331 .41467 .66136 .40925 .65608 Mtetra
.616 .726 .924 r
.40925 .65608 .41467 .66136 .42382 .66032 .41843 .65431 Mtetra
.152 .47 .893 r
.41843 .65431 .42382 .66032 .43325 .64965 .42748 .6585 Mtetra
0 0 0 r
.42748 .6585 .43325 .64965 .44238 .65164 .43703 .64577 Mtetra
.599 .699 .913 r
.43703 .64577 .44238 .65164 .45165 .64969 .4463 .64443 Mtetra
.635 .734 .92 r
.4463 .64443 .45165 .64969 .46095 .64741 .45562 .64222 Mtetra
.64 .74 .921 r
.45562 .64222 .46095 .64741 .4703 .64508 .46499 .63988 Mtetra
.638 .739 .922 r
.46499 .63988 .4703 .64508 .47967 .64293 .47438 .63758 Mtetra
.616 .727 .925 r
.47438 .63758 .47967 .64293 .48907 .64236 .48381 .63575 Mtetra
.951 .604 .303 r
.48381 .63575 .48907 .64236 .49857 .63286 .49288 .67698 Mtetra
0 0 .22 r
.49288 .67698 .49857 .63286 .50803 .63267 .5028 .62697 Mtetra
.618 .716 .915 r
.5028 .62697 .50803 .63267 .51753 .63041 .51233 .62513 Mtetra
.644 .741 .92 r
.51233 .62513 .51753 .63041 .52708 .62785 .52189 .62265 Mtetra
.651 .747 .92 r
.52189 .62265 .52708 .62785 .53665 .62515 .53149 .61999 Mtetra
.654 .75 .92 r
.53149 .61999 .53665 .62515 .54626 .62239 .54112 .61724 Mtetra
.656 .752 .92 r
.54112 .61724 .54626 .62239 .55591 .61957 .55079 .61442 Mtetra
.658 .753 .92 r
.55079 .61442 .55591 .61957 .56558 .61671 .56049 .61155 Mtetra
.659 .754 .92 r
.56049 .61155 .56558 .61671 .57529 .61382 .57022 .60866 Mtetra
.57022 .60866 .57529 .61382 .58504 .61093 .57998 .60574 Mtetra
.57998 .60574 .58504 .61093 .59481 .60803 .58979 .60282 Mtetra
.58979 .60282 .59481 .60803 .60462 .60512 .59962 .59989 Mtetra
.658 .753 .92 r
.59962 .59989 .60462 .60512 .61447 .60221 .60949 .59696 Mtetra
.60949 .59696 .61447 .60221 .62435 .5993 .61939 .59403 Mtetra
.61939 .59403 .62435 .5993 .63427 .59638 .62933 .59109 Mtetra
.62933 .59109 .63427 .59638 .64422 .59346 .63931 .58814 Mtetra
.63931 .58814 .64422 .59346 .6542 .59052 .64932 .58519 Mtetra
.64932 .58519 .6542 .59052 .66422 .58758 .65936 .58223 Mtetra
.657 .753 .92 r
.65936 .58223 .66422 .58758 .67428 .58463 .66944 .57926 Mtetra
.66944 .57926 .67428 .58463 .68437 .58167 .67956 .57628 Mtetra
.67956 .57628 .68437 .58167 .6945 .57871 .68971 .57329 Mtetra
.68971 .57329 .6945 .57871 .70466 .57573 .6999 .5703 Mtetra
.6999 .5703 .70466 .57573 .71487 .57274 .71013 .56729 Mtetra
.657 .752 .92 r
.71013 .56729 .71487 .57274 .7251 .56975 .72039 .56427 Mtetra
.72039 .56427 .7251 .56975 .73538 .56674 .73069 .56125 Mtetra
.73069 .56125 .73538 .56674 .74569 .56373 .74103 .55821 Mtetra
.74103 .55821 .74569 .56373 .75604 .5607 .7514 .55517 Mtetra
.7514 .55517 .75604 .5607 .76642 .55767 .76182 .55211 Mtetra
.76182 .55211 .76642 .55767 .77684 .55462 .77227 .54905 Mtetra
.77227 .54905 .77684 .55462 .78731 .55157 .78275 .54597 Mtetra
.78275 .54597 .78731 .55157 .7978 .5485 .79328 .54288 Mtetra
.79328 .54288 .7978 .5485 .80834 .54543 .80384 .53978 Mtetra
.80384 .53978 .80834 .54543 .81892 .54234 .81445 .53668 Mtetra
.81445 .53668 .81892 .54234 .82953 .53924 .82509 .53356 Mtetra
.82509 .53356 .82953 .53924 .84018 .53613 .83577 .53043 Mtetra
.83577 .53043 .84018 .53613 .85088 .53301 .84649 .52728 Mtetra
.84649 .52728 .85088 .53301 .86161 .52988 .85725 .52413 Mtetra
.85725 .52413 .86161 .52988 .87238 .52674 .86805 .52097 Mtetra
.86805 .52097 .87238 .52674 .88319 .52358 .87889 .51779 Mtetra
.87889 .51779 .88319 .52358 .89404 .52042 .88977 .51461 Mtetra
.88977 .51461 .89404 .52042 .90493 .51724 .90069 .51141 Mtetra
.90069 .51141 .90493 .51724 .91586 .51406 .91165 .5082 Mtetra
.91165 .5082 .91586 .51406 .92683 .51086 .92265 .50498 Mtetra
.92265 .50498 .92683 .51086 .93784 .50765 .93369 .50175 Mtetra
.93369 .50175 .93784 .50765 .9489 .50443 .94478 .4985 Mtetra
.94478 .4985 .9489 .50443 .95999 .50119 .9559 .49525 Mtetra
.615 .723 .922 r
.35813 .66381 .36367 .66912 .37268 .66759 .36716 .66208 Mtetra
.56 .697 .932 r
.36716 .66208 .37268 .66759 .38129 .67646 .37618 .66139 Mtetra
.723 .591 .708 r
.37618 .66139 .38129 .67646 .391 .65941 .3856 .65174 Mtetra
.503 .598 .882 r
.3856 .65174 .391 .65941 .40009 .65807 .39462 .65268 Mtetra
.62 .723 .92 r
.39462 .65268 .40009 .65807 .40925 .65608 .40379 .65082 Mtetra
.626 .73 .922 r
.40379 .65082 .40925 .65608 .41843 .65431 .413 .64883 Mtetra
.58 .707 .93 r
.413 .64883 .41843 .65431 .42748 .6585 .42221 .64775 Mtetra
.767 .652 .735 r
.42221 .64775 .42748 .6585 .43703 .64577 .43173 .637 Mtetra
.468 .552 .859 r
.43173 .637 .43703 .64577 .4463 .64443 .44092 .63897 Mtetra
.625 .725 .919 r
.44092 .63897 .4463 .64443 .45562 .64222 .45026 .63698 Mtetra
.639 .738 .92 r
.45026 .63698 .45562 .64222 .46499 .63988 .45964 .63465 Mtetra
.64 .74 .921 r
.45964 .63465 .46499 .63988 .47438 .63758 .46906 .63228 Mtetra
.632 .735 .922 r
.46906 .63228 .47438 .63758 .48381 .63575 .47851 .63009 Mtetra
.554 .694 .933 r
.47851 .63009 .48381 .63575 .49288 .67698 .48797 .62948 Mtetra
.632 .452 .621 r
.48797 .62948 .49288 .67698 .5028 .62697 .49756 .61991 Mtetra
.553 .645 .895 r
.49756 .61991 .5028 .62697 .51233 .62513 .50709 .61969 Mtetra
.636 .733 .919 r
.50709 .61969 .51233 .62513 .52189 .62265 .51667 .61739 Mtetra
.648 .745 .92 r
.51667 .61739 .52189 .62265 .53149 .61999 .52629 .61478 Mtetra
.653 .749 .92 r
.52629 .61478 .53149 .61999 .54112 .61724 .53595 .61204 Mtetra
.655 .751 .92 r
.53595 .61204 .54112 .61724 .55079 .61442 .54563 .60923 Mtetra
.657 .752 .92 r
.54563 .60923 .55079 .61442 .56049 .61155 .55536 .60636 Mtetra
.658 .753 .92 r
.55536 .60636 .56049 .61155 .57022 .60866 .56511 .60345 Mtetra
.659 .754 .92 r
.56511 .60345 .57022 .60866 .57998 .60574 .5749 .60052 Mtetra
.5749 .60052 .57998 .60574 .58979 .60282 .58472 .59758 Mtetra
.58472 .59758 .58979 .60282 .59962 .59989 .59458 .59463 Mtetra
.59458 .59463 .59962 .59989 .60949 .59696 .60448 .59168 Mtetra
.658 .753 .92 r
.60448 .59168 .60949 .59696 .61939 .59403 .6144 .58872 Mtetra
.6144 .58872 .61939 .59403 .62933 .59109 .62437 .58576 Mtetra
.62437 .58576 .62933 .59109 .63931 .58814 .63436 .58279 Mtetra
.63436 .58279 .63931 .58814 .64932 .58519 .6444 .57982 Mtetra
.6444 .57982 .64932 .58519 .65936 .58223 .65447 .57684 Mtetra
.65447 .57684 .65936 .58223 .66944 .57926 .66457 .57385 Mtetra
.657 .753 .92 r
.66457 .57385 .66944 .57926 .67956 .57628 .67472 .57085 Mtetra
.67472 .57085 .67956 .57628 .68971 .57329 .68489 .56784 Mtetra
.68489 .56784 .68971 .57329 .6999 .5703 .69511 .56482 Mtetra
.69511 .56482 .6999 .5703 .71013 .56729 .70536 .5618 Mtetra
.657 .752 .92 r
.70536 .5618 .71013 .56729 .72039 .56427 .71565 .55876 Mtetra
.71565 .55876 .72039 .56427 .73069 .56125 .72598 .55572 Mtetra
.72598 .55572 .73069 .56125 .74103 .55821 .73634 .55266 Mtetra
.73634 .55266 .74103 .55821 .7514 .55517 .74674 .54959 Mtetra
.74674 .54959 .7514 .55517 .76182 .55211 .75718 .54652 Mtetra
.75718 .54652 .76182 .55211 .77227 .54905 .76766 .54343 Mtetra
.76766 .54343 .77227 .54905 .78275 .54597 .77817 .54033 Mtetra
.77817 .54033 .78275 .54597 .79328 .54288 .78872 .53722 Mtetra
.78872 .53722 .79328 .54288 .80384 .53978 .79932 .5341 Mtetra
.79932 .5341 .80384 .53978 .81445 .53668 .80995 .53097 Mtetra
.80995 .53097 .81445 .53668 .82509 .53356 .82062 .52783 Mtetra
.82062 .52783 .82509 .53356 .83577 .53043 .83133 .52468 Mtetra
.83133 .52468 .83577 .53043 .84649 .52728 .84207 .52152 Mtetra
.84207 .52152 .84649 .52728 .85725 .52413 .85286 .51835 Mtetra
.85286 .51835 .85725 .52413 .86805 .52097 .86369 .51516 Mtetra
.86369 .51516 .86805 .52097 .87889 .51779 .87456 .51196 Mtetra
.87456 .51196 .87889 .51779 .88977 .51461 .88547 .50876 Mtetra
.88547 .50876 .88977 .51461 .90069 .51141 .89642 .50554 Mtetra
.89642 .50554 .90069 .51141 .91165 .5082 .90741 .5023 Mtetra
.90741 .5023 .91165 .5082 .92265 .50498 .91844 .49906 Mtetra
.91844 .49906 .92265 .50498 .93369 .50175 .92952 .49581 Mtetra
.92952 .49581 .93369 .50175 .94478 .4985 .94063 .49254 Mtetra
.94063 .49254 .94478 .4985 .9559 .49525 .95179 .48926 Mtetra
.61 .716 .92 r
.35256 .65834 .35813 .66381 .36716 .66208 .3616 .65672 Mtetra
.606 .719 .925 r
.3616 .65672 .36716 .66208 .37618 .66139 .37067 .65515 Mtetra
0 .03 .553 r
.37067 .65515 .37618 .66139 .3856 .65174 .37935 .66403 Mtetra
0 0 0 r
.37935 .66403 .3856 .65174 .39462 .65268 .38913 .64688 Mtetra
.599 .702 .916 r
.38913 .64688 .39462 .65268 .40379 .65082 .3983 .64549 Mtetra
.627 .73 .921 r
.3983 .64549 .40379 .65082 .413 .64883 .40752 .64347 Mtetra
.616 .726 .924 r
.40752 .64347 .413 .64883 .42221 .64775 .41678 .64166 Mtetra
.155 .472 .893 r
.41678 .64166 .42221 .64775 .43173 .637 .4259 .64583 Mtetra
0 0 0 r
.4259 .64583 .43173 .637 .44092 .63897 .43553 .63302 Mtetra
.599 .699 .913 r
.43553 .63302 .44092 .63897 .45026 .63698 .44487 .63163 Mtetra
.635 .734 .92 r
.44487 .63163 .45026 .63698 .45964 .63465 .45426 .62939 Mtetra
.64 .74 .921 r
.45426 .62939 .45964 .63465 .46906 .63228 .4637 .627 Mtetra
.638 .739 .922 r
.4637 .627 .46906 .63228 .47851 .63009 .47317 .62465 Mtetra
.616 .727 .925 r
.47317 .62465 .47851 .63009 .48797 .62948 .48267 .62279 Mtetra
.951 .602 .297 r
.48267 .62279 .48797 .62948 .49756 .61991 .4918 .66418 Mtetra
0 0 .213 r
.4918 .66418 .49756 .61991 .50709 .61969 .50182 .6139 Mtetra
.618 .716 .915 r
.50182 .6139 .50709 .61969 .51667 .61739 .51142 .61202 Mtetra
.644 .741 .92 r
.51142 .61202 .51667 .61739 .52629 .61478 .52106 .6095 Mtetra
.651 .747 .92 r
.52106 .6095 .52629 .61478 .53595 .61204 .53074 .60679 Mtetra
.654 .75 .92 r
.53074 .60679 .53595 .61204 .54563 .60923 .54045 .60399 Mtetra
.656 .752 .92 r
.54045 .60399 .54563 .60923 .55536 .60636 .55019 .60113 Mtetra
.658 .753 .92 r
.55019 .60113 .55536 .60636 .56511 .60345 .55997 .59821 Mtetra
.659 .754 .92 r
.55997 .59821 .56511 .60345 .5749 .60052 .56978 .59527 Mtetra
.56978 .59527 .5749 .60052 .58472 .59758 .57963 .59231 Mtetra
.57963 .59231 .58472 .59758 .59458 .59463 .58951 .58934 Mtetra
.58951 .58934 .59458 .59463 .60448 .59168 .59943 .58636 Mtetra
.658 .753 .92 r
.59943 .58636 .60448 .59168 .6144 .58872 .60938 .58338 Mtetra
.60938 .58338 .6144 .58872 .62437 .58576 .61937 .5804 Mtetra
.61937 .5804 .62437 .58576 .63436 .58279 .62939 .57741 Mtetra
.62939 .57741 .63436 .58279 .6444 .57982 .63945 .57442 Mtetra
.63945 .57442 .6444 .57982 .65447 .57684 .64954 .57141 Mtetra
.64954 .57141 .65447 .57684 .66457 .57385 .65967 .5684 Mtetra
.657 .753 .92 r
.65967 .5684 .66457 .57385 .67472 .57085 .66984 .56538 Mtetra
.66984 .56538 .67472 .57085 .68489 .56784 .68004 .56235 Mtetra
.68004 .56235 .68489 .56784 .69511 .56482 .69028 .55932 Mtetra
.69028 .55932 .69511 .56482 .70536 .5618 .70056 .55627 Mtetra
.70056 .55627 .70536 .5618 .71565 .55876 .71088 .55321 Mtetra
.657 .752 .92 r
.71088 .55321 .71565 .55876 .72598 .55572 .72123 .55015 Mtetra
.72123 .55015 .72598 .55572 .73634 .55266 .73162 .54707 Mtetra
.73162 .54707 .73634 .55266 .74674 .54959 .74204 .54398 Mtetra
.74204 .54398 .74674 .54959 .75718 .54652 .75251 .54088 Mtetra
.75251 .54088 .75718 .54652 .76766 .54343 .76301 .53778 Mtetra
.76301 .53778 .76766 .54343 .77817 .54033 .77356 .53466 Mtetra
.77356 .53466 .77817 .54033 .78872 .53722 .78414 .53153 Mtetra
.78414 .53153 .78872 .53722 .79932 .5341 .79476 .52839 Mtetra
.79476 .52839 .79932 .5341 .80995 .53097 .80542 .52524 Mtetra
.80542 .52524 .80995 .53097 .82062 .52783 .81611 .52207 Mtetra
.81611 .52207 .82062 .52783 .83133 .52468 .82685 .5189 Mtetra
.82685 .5189 .83133 .52468 .84207 .52152 .83763 .51572 Mtetra
.83763 .51572 .84207 .52152 .85286 .51835 .84845 .51252 Mtetra
.84845 .51252 .85286 .51835 .86369 .51516 .8593 .50931 Mtetra
.8593 .50931 .86369 .51516 .87456 .51196 .8702 .50609 Mtetra
.8702 .50609 .87456 .51196 .88547 .50876 .88114 .50286 Mtetra
.88114 .50286 .88547 .50876 .89642 .50554 .89212 .49962 Mtetra
.89212 .49962 .89642 .50554 .90741 .5023 .90314 .49637 Mtetra
.90314 .49637 .90741 .5023 .91844 .49906 .9142 .4931 Mtetra
.9142 .4931 .91844 .49906 .92952 .49581 .92531 .48982 Mtetra
.92531 .48982 .92952 .49581 .94063 .49254 .93645 .48653 Mtetra
.93645 .48653 .94063 .49254 .95179 .48926 .94764 .48323 Mtetra
.581 .686 .913 r
.34698 .6523 .35256 .65834 .3616 .65672 .356 .65133 Mtetra
.615 .723 .922 r
.356 .65133 .3616 .65672 .37067 .65515 .3651 .64956 Mtetra
.56 .697 .932 r
.3651 .64956 .37067 .65515 .37935 .66403 .37419 .64884 Mtetra
.723 .591 .708 r
.37419 .64884 .37935 .66403 .38913 .64688 .38369 .63911 Mtetra
.502 .598 .882 r
.38369 .63911 .38913 .64688 .3983 .64549 .39278 .64002 Mtetra
.62 .723 .92 r
.39278 .64002 .3983 .64549 .40752 .64347 .40202 .63812 Mtetra
.626 .73 .922 r
.40202 .63812 .40752 .64347 .41678 .64166 .4113 .63609 Mtetra
.58 .707 .93 r
.4113 .63609 .41678 .64166 .4259 .64583 .42058 .63498 Mtetra
.768 .653 .735 r
.42058 .63498 .4259 .64583 .43553 .63302 .43018 .62415 Mtetra
.467 .552 .859 r
.43018 .62415 .43553 .63302 .44487 .63163 .43944 .62609 Mtetra
.625 .725 .919 r
.43944 .62609 .44487 .63163 .45426 .62939 .44885 .62406 Mtetra
.639 .738 .92 r
.44885 .62406 .45426 .62939 .4637 .627 .45831 .62169 Mtetra
.64 .74 .921 r
.45831 .62169 .4637 .627 .47317 .62465 .4678 .61928 Mtetra
.632 .735 .922 r
.4678 .61928 .47317 .62465 .48267 .62279 .47732 .61704 Mtetra
.554 .694 .933 r
.47732 .61704 .48267 .62279 .4918 .66418 .48687 .6164 Mtetra
.631 .451 .62 r
.48687 .6164 .4918 .66418 .50182 .6139 .49653 .60675 Mtetra
.553 .645 .895 r
.49653 .60675 .50182 .6139 .51142 .61202 .50614 .6065 Mtetra
.636 .733 .919 r
.50614 .6065 .51142 .61202 .52106 .6095 .5158 .60415 Mtetra
.648 .745 .92 r
.5158 .60415 .52106 .6095 .53074 .60679 .52549 .60149 Mtetra
.653 .749 .92 r
.52549 .60149 .53074 .60679 .54045 .60399 .53523 .59871 Mtetra
.655 .751 .92 r
.53523 .59871 .54045 .60399 .55019 .60113 .54499 .59585 Mtetra
.657 .752 .92 r
.54499 .59585 .55019 .60113 .55997 .59821 .5548 .59293 Mtetra
.658 .753 .92 r
.5548 .59293 .55997 .59821 .56978 .59527 .56463 .58998 Mtetra
.659 .754 .92 r
.56463 .58998 .56978 .59527 .57963 .59231 .5745 .587 Mtetra
.5745 .587 .57963 .59231 .58951 .58934 .58441 .58401 Mtetra
.58441 .58401 .58951 .58934 .59943 .58636 .59435 .58101 Mtetra
.59435 .58101 .59943 .58636 .60938 .58338 .60432 .57801 Mtetra
.658 .753 .92 r
.60432 .57801 .60938 .58338 .61937 .5804 .61433 .57501 Mtetra
.61433 .57501 .61937 .5804 .62939 .57741 .62438 .57199 Mtetra
.62438 .57199 .62939 .57741 .63945 .57442 .63446 .56898 Mtetra
.63446 .56898 .63945 .57442 .64954 .57141 .64458 .56595 Mtetra
.64458 .56595 .64954 .57141 .65967 .5684 .65474 .56292 Mtetra
.65474 .56292 .65967 .5684 .66984 .56538 .66493 .55988 Mtetra
.657 .753 .92 r
.66493 .55988 .66984 .56538 .68004 .56235 .67516 .55683 Mtetra
.67516 .55683 .68004 .56235 .69028 .55932 .68543 .55377 Mtetra
.68543 .55377 .69028 .55932 .70056 .55627 .69573 .5507 Mtetra
.69573 .5507 .70056 .55627 .71088 .55321 .70607 .54763 Mtetra
.657 .752 .92 r
.70607 .54763 .71088 .55321 .72123 .55015 .71645 .54454 Mtetra
.71645 .54454 .72123 .55015 .73162 .54707 .72686 .54144 Mtetra
.72686 .54144 .73162 .54707 .74204 .54398 .73732 .53833 Mtetra
.73732 .53833 .74204 .54398 .75251 .54088 .74781 .53521 Mtetra
.74781 .53521 .75251 .54088 .76301 .53778 .75834 .53208 Mtetra
.75834 .53208 .76301 .53778 .77356 .53466 .76891 .52894 Mtetra
.76891 .52894 .77356 .53466 .78414 .53153 .77952 .52579 Mtetra
.77952 .52579 .78414 .53153 .79476 .52839 .79017 .52263 Mtetra
.79017 .52263 .79476 .52839 .80542 .52524 .80085 .51946 Mtetra
.80085 .51946 .80542 .52524 .81611 .52207 .81158 .51627 Mtetra
.81158 .51627 .81611 .52207 .82685 .5189 .82235 .51308 Mtetra
.82235 .51308 .82685 .5189 .83763 .51572 .83315 .50987 Mtetra
.83315 .50987 .83763 .51572 .84845 .51252 .844 .50665 Mtetra
.844 .50665 .84845 .51252 .8593 .50931 .85489 .50342 Mtetra
.85489 .50342 .8593 .50931 .8702 .50609 .86581 .50018 Mtetra
.86581 .50018 .8702 .50609 .88114 .50286 .87678 .49693 Mtetra
.87678 .49693 .88114 .50286 .89212 .49962 .88779 .49366 Mtetra
.88779 .49366 .89212 .49962 .90314 .49637 .89884 .49039 Mtetra
.89884 .49039 .90314 .49637 .9142 .4931 .90993 .4871 Mtetra
.90993 .4871 .9142 .4931 .92531 .48982 .92107 .4838 Mtetra
.92107 .4838 .92531 .48982 .93645 .48653 .93225 .48049 Mtetra
.93225 .48049 .93645 .48653 .94764 .48323 .94347 .47716 Mtetra
.391 .476 .827 r
.34159 .64206 .34698 .6523 .356 .65133 .35038 .64577 Mtetra
.61 .716 .92 r
.35038 .64577 .356 .65133 .3651 .64956 .35949 .64412 Mtetra
.606 .719 .925 r
.35949 .64412 .3651 .64956 .37419 .64884 .36864 .64251 Mtetra
0 .036 .56 r
.36864 .64251 .37419 .64884 .38369 .63911 .37737 .6514 Mtetra
0 0 0 r
.37737 .6514 .38369 .63911 .39278 .64002 .38724 .63414 Mtetra
.599 .702 .916 r
.38724 .63414 .39278 .64002 .40202 .63812 .39648 .63272 Mtetra
.627 .73 .921 r
.39648 .63272 .40202 .63812 .4113 .63609 .40577 .63065 Mtetra
.616 .726 .924 r
.40577 .63065 .4113 .63609 .42058 .63498 .4151 .6288 Mtetra
.159 .473 .894 r
.4151 .6288 .42058 .63498 .43018 .62415 .42429 .63296 Mtetra
0 0 0 r
.42429 .63296 .43018 .62415 .43944 .62609 .434 .62005 Mtetra
.599 .699 .913 r
.434 .62005 .43944 .62609 .44885 .62406 .44341 .61863 Mtetra
.635 .734 .92 r
.44341 .61863 .44885 .62406 .45831 .62169 .45288 .61634 Mtetra
.64 .74 .921 r
.45288 .61634 .45831 .62169 .4678 .61928 .46239 .61391 Mtetra
.638 .739 .922 r
.46239 .61391 .4678 .61928 .47732 .61704 .47194 .61152 Mtetra
.616 .727 .925 r
.47194 .61152 .47732 .61704 .48687 .6164 .48151 .60961 Mtetra
.951 .601 .292 r
.48151 .60961 .48687 .6164 .49653 .60675 .4907 .65115 Mtetra
0 0 .207 r
.4907 .65115 .49653 .60675 .50614 .6065 .50082 .60062 Mtetra
.618 .716 .916 r
.50082 .60062 .50614 .6065 .5158 .60415 .5105 .5987 Mtetra
.644 .741 .92 r
.5105 .5987 .5158 .60415 .52549 .60149 .52022 .59613 Mtetra
.651 .747 .92 r
.52022 .59613 .52549 .60149 .53523 .59871 .52997 .59337 Mtetra
.654 .75 .92 r
.52997 .59337 .53523 .59871 .54499 .59585 .53976 .59053 Mtetra
.656 .752 .92 r
.53976 .59053 .54499 .59585 .5548 .59293 .54959 .58761 Mtetra
.658 .753 .92 r
.54959 .58761 .5548 .59293 .56463 .58998 .55945 .58465 Mtetra
.659 .754 .92 r
.55945 .58465 .56463 .58998 .5745 .587 .56934 .58166 Mtetra
.56934 .58166 .5745 .587 .58441 .58401 .57927 .57865 Mtetra
.57927 .57865 .58441 .58401 .59435 .58101 .58923 .57563 Mtetra
.58923 .57563 .59435 .58101 .60432 .57801 .59923 .5726 Mtetra
.658 .753 .92 r
.59923 .5726 .60432 .57801 .61433 .57501 .60927 .56958 Mtetra
.60927 .56958 .61433 .57501 .62438 .57199 .61934 .56654 Mtetra
.61934 .56654 .62438 .57199 .63446 .56898 .62945 .5635 Mtetra
.62945 .5635 .63446 .56898 .64458 .56595 .63959 .56046 Mtetra
.63959 .56046 .64458 .56595 .65474 .56292 .64977 .5574 Mtetra
.64977 .5574 .65474 .56292 .66493 .55988 .65999 .55434 Mtetra
.657 .753 .92 r
.65999 .55434 .66493 .55988 .67516 .55683 .67024 .55127 Mtetra
.67024 .55127 .67516 .55683 .68543 .55377 .68054 .54819 Mtetra
.68054 .54819 .68543 .55377 .69573 .5507 .69086 .5451 Mtetra
.69086 .5451 .69573 .5507 .70607 .54763 .70123 .542 Mtetra
.70123 .542 .70607 .54763 .71645 .54454 .71164 .53889 Mtetra
.657 .752 .92 r
.71164 .53889 .71645 .54454 .72686 .54144 .72208 .53577 Mtetra
.72208 .53577 .72686 .54144 .73732 .53833 .73256 .53264 Mtetra
.73256 .53264 .73732 .53833 .74781 .53521 .74308 .5295 Mtetra
.74308 .5295 .74781 .53521 .75834 .53208 .75364 .52635 Mtetra
.75364 .52635 .75834 .53208 .76891 .52894 .76423 .52319 Mtetra
.76423 .52319 .76891 .52894 .77952 .52579 .77487 .52002 Mtetra
.77487 .52002 .77952 .52579 .79017 .52263 .78554 .51683 Mtetra
.78554 .51683 .79017 .52263 .80085 .51946 .79626 .51364 Mtetra
.79626 .51364 .80085 .51946 .81158 .51627 .80701 .51043 Mtetra
.80701 .51043 .81158 .51627 .82235 .51308 .81781 .50722 Mtetra
.81781 .50722 .82235 .51308 .83315 .50987 .82864 .50399 Mtetra
.82864 .50399 .83315 .50987 .844 .50665 .83952 .50075 Mtetra
.83952 .50075 .844 .50665 .85489 .50342 .85044 .49749 Mtetra
.85044 .49749 .85489 .50342 .86581 .50018 .86139 .49423 Mtetra
.86139 .49423 .86581 .50018 .87678 .49693 .87239 .49095 Mtetra
.87239 .49095 .87678 .49693 .88779 .49366 .88343 .48767 Mtetra
.88343 .48767 .88779 .49366 .89884 .49039 .89451 .48437 Mtetra
.89451 .48437 .89884 .49039 .90993 .4871 .90564 .48106 Mtetra
.90564 .48106 .90993 .4871 .92107 .4838 .9168 .47773 Mtetra
.9168 .47773 .92107 .4838 .93225 .48049 .92801 .4744 Mtetra
.92801 .4744 .93225 .48049 .94347 .47716 .93926 .47105 Mtetra
0 0 0 r
.33516 .65057 .34159 .64206 .35038 .64577 .34476 .63965 Mtetra
.581 .687 .914 r
.34476 .63965 .35038 .64577 .35949 .64412 .35385 .63865 Mtetra
.615 .723 .922 r
.35385 .63865 .35949 .64412 .36864 .64251 .36302 .63684 Mtetra
.561 .697 .932 r
.36302 .63684 .36864 .64251 .37737 .6514 .37217 .63608 Mtetra
.723 .591 .708 r
.37217 .63608 .37737 .6514 .38724 .63414 .38175 .62627 Mtetra
.502 .598 .882 r
.38175 .62627 .38724 .63414 .39648 .63272 .39091 .62716 Mtetra
.62 .723 .92 r
.39091 .62716 .39648 .63272 .40577 .63065 .40022 .62522 Mtetra
.626 .73 .922 r
.40022 .62522 .40577 .63065 .4151 .6288 .40957 .62314 Mtetra
.58 .707 .93 r
.40957 .62314 .4151 .6288 .42429 .63296 .41892 .622 Mtetra
.768 .653 .735 r
.41892 .622 .42429 .63296 .434 .62005 .4286 .61108 Mtetra
.466 .552 .859 r
.4286 .61108 .434 .62005 .44341 .61863 .43794 .613 Mtetra
.625 .725 .919 r
.43794 .613 .44341 .61863 .45288 .61634 .44742 .61093 Mtetra
.639 .738 .92 r
.44742 .61093 .45288 .61634 .46239 .61391 .45695 .60852 Mtetra
.64 .74 .921 r
.45695 .60852 .46239 .61391 .47194 .61152 .46652 .60606 Mtetra
.632 .735 .922 r
.46652 .60606 .47194 .61152 .48151 .60961 .47612 .60378 Mtetra
.554 .694 .933 r
.47612 .60378 .48151 .60961 .4907 .65115 .48574 .6031 Mtetra
.63 .449 .619 r
.48574 .6031 .4907 .65115 .50082 .60062 .49548 .59338 Mtetra
.553 .645 .895 r
.49548 .59338 .50082 .60062 .5105 .5987 .50517 .59308 Mtetra
.636 .733 .919 r
.50517 .59308 .5105 .5987 .52022 .59613 .51491 .59069 Mtetra
.648 .745 .92 r
.51491 .59069 .52022 .59613 .52997 .59337 .52468 .58799 Mtetra
.653 .749 .92 r
.52468 .58799 .52997 .59337 .53976 .59053 .5345 .58515 Mtetra
.655 .751 .92 r
.5345 .58515 .53976 .59053 .54959 .58761 .54434 .58224 Mtetra
.657 .752 .92 r
.54434 .58224 .54959 .58761 .55945 .58465 .55423 .57928 Mtetra
.658 .753 .92 r
.55423 .57928 .55945 .58465 .56934 .58166 .56414 .57628 Mtetra
.659 .754 .92 r
.56414 .57628 .56934 .58166 .57927 .57865 .5741 .57325 Mtetra
.5741 .57325 .57927 .57865 .58923 .57563 .58409 .57021 Mtetra
.58409 .57021 .58923 .57563 .59923 .5726 .59411 .56716 Mtetra
.59411 .56716 .59923 .5726 .60927 .56958 .60417 .56411 Mtetra
.658 .753 .92 r
.60417 .56411 .60927 .56958 .61934 .56654 .61426 .56106 Mtetra
.61426 .56106 .61934 .56654 .62945 .5635 .6244 .55799 Mtetra
.6244 .55799 .62945 .5635 .63959 .56046 .63457 .55493 Mtetra
.63457 .55493 .63959 .56046 .64977 .5574 .64477 .55185 Mtetra
.64477 .55185 .64977 .5574 .65999 .55434 .65501 .54877 Mtetra
.65501 .54877 .65999 .55434 .67024 .55127 .66529 .54567 Mtetra
.657 .753 .92 r
.66529 .54567 .67024 .55127 .68054 .54819 .67561 .54257 Mtetra
.67561 .54257 .68054 .54819 .69086 .5451 .68597 .53946 Mtetra
.68597 .53946 .69086 .5451 .70123 .542 .69636 .53634 Mtetra
.69636 .53634 .70123 .542 .71164 .53889 .70679 .53321 Mtetra
.657 .752 .92 r
.70679 .53321 .71164 .53889 .72208 .53577 .71726 .53007 Mtetra
.71726 .53007 .72208 .53577 .73256 .53264 .72777 .52692 Mtetra
.72777 .52692 .73256 .53264 .74308 .5295 .73831 .52375 Mtetra
.73831 .52375 .74308 .5295 .75364 .52635 .7489 .52058 Mtetra
.7489 .52058 .75364 .52635 .76423 .52319 .75952 .5174 Mtetra
.75952 .5174 .76423 .52319 .77487 .52002 .77019 .5142 Mtetra
.77019 .5142 .77487 .52002 .78554 .51683 .78089 .511 Mtetra
.78089 .511 .78554 .51683 .79626 .51364 .79163 .50778 Mtetra
.79163 .50778 .79626 .51364 .80701 .51043 .80242 .50455 Mtetra
.80242 .50455 .80701 .51043 .81781 .50722 .81324 .50131 Mtetra
.81324 .50131 .81781 .50722 .82864 .50399 .82411 .49806 Mtetra
.82411 .49806 .82864 .50399 .83952 .50075 .83501 .4948 Mtetra
.83501 .4948 .83952 .50075 .85044 .49749 .84596 .49152 Mtetra
.84596 .49152 .85044 .49749 .86139 .49423 .85694 .48824 Mtetra
.85694 .48824 .86139 .49423 .87239 .49095 .86797 .48494 Mtetra
.86797 .48494 .87239 .49095 .88343 .48767 .87904 .48163 Mtetra
.87904 .48163 .88343 .48767 .89451 .48437 .89015 .4783 Mtetra
.89015 .4783 .89451 .48437 .90564 .48106 .90131 .47497 Mtetra
.90131 .47497 .90564 .48106 .9168 .47773 .9125 .47162 Mtetra
.9125 .47162 .9168 .47773 .92801 .4744 .92374 .46826 Mtetra
.92374 .46826 .92801 .4744 .93926 .47105 .93503 .46489 Mtetra
.794 .68 .739 r
.32964 .64137 .33516 .65057 .34476 .63965 .33932 .62931 Mtetra
.39 .476 .828 r
.33932 .62931 .34476 .63965 .35385 .63865 .34817 .633 Mtetra
.61 .716 .92 r
.34817 .633 .35385 .63865 .36302 .63684 .35735 .63131 Mtetra
.606 .719 .925 r
.35735 .63131 .36302 .63684 .37217 .63608 .36657 .62966 Mtetra
0 .042 .566 r
.36657 .62966 .37217 .63608 .38175 .62627 .37536 .63856 Mtetra
0 0 0 r
.37536 .63856 .38175 .62627 .39091 .62716 .38532 .62119 Mtetra
.599 .702 .916 r
.38532 .62119 .39091 .62716 .40022 .62522 .39462 .61973 Mtetra
.627 .73 .921 r
.39462 .61973 .40022 .62522 .40957 .62314 .40399 .61762 Mtetra
.616 .726 .924 r
.40399 .61762 .40957 .62314 .41892 .622 .41339 .61573 Mtetra
.162 .474 .895 r
.41339 .61573 .41892 .622 .4286 .61108 .42265 .61987 Mtetra
0 0 0 r
.42265 .61987 .4286 .61108 .43794 .613 .43244 .60687 Mtetra
.599 .699 .914 r
.43244 .60687 .43794 .613 .44742 .61093 .44193 .60541 Mtetra
.635 .734 .92 r
.44193 .60541 .44742 .61093 .45695 .60852 .45148 .60308 Mtetra
.64 .74 .921 r
.45148 .60308 .45695 .60852 .46652 .60606 .46106 .6006 Mtetra
.638 .739 .922 r
.46106 .6006 .46652 .60606 .47612 .60378 .47069 .59817 Mtetra
.616 .727 .925 r
.47069 .59817 .47612 .60378 .48574 .6031 .48034 .59622 Mtetra
.95 .599 .286 r
.48034 .59622 .48574 .6031 .49548 .59338 .48959 .63791 Mtetra
0 0 .201 r
.48959 .63791 .49548 .59338 .50517 .59308 .4998 .58711 Mtetra
.618 .716 .916 r
.4998 .58711 .50517 .59308 .51491 .59069 .50956 .58515 Mtetra
.644 .741 .92 r
.50956 .58515 .51491 .59069 .52468 .58799 .51936 .58253 Mtetra
.651 .747 .92 r
.51936 .58253 .52468 .58799 .5345 .58515 .52919 .57973 Mtetra
.654 .75 .92 r
.52919 .57973 .5345 .58515 .54434 .58224 .53907 .57683 Mtetra
.656 .752 .92 r
.53907 .57683 .54434 .58224 .55423 .57928 .54897 .57387 Mtetra
.658 .753 .92 r
.54897 .57387 .55423 .57928 .56414 .57628 .55891 .57086 Mtetra
.659 .754 .92 r
.55891 .57086 .56414 .57628 .5741 .57325 .56889 .56782 Mtetra
.56889 .56782 .5741 .57325 .58409 .57021 .5789 .56476 Mtetra
.5789 .56476 .58409 .57021 .59411 .56716 .58895 .56169 Mtetra
.58895 .56169 .59411 .56716 .60417 .56411 .59903 .55861 Mtetra
.658 .753 .92 r
.59903 .55861 .60417 .56411 .61426 .56106 .60916 .55553 Mtetra
.60916 .55553 .61426 .56106 .6244 .55799 .61931 .55245 Mtetra
.61931 .55245 .6244 .55799 .63457 .55493 .62951 .54936 Mtetra
.62951 .54936 .63457 .55493 .64477 .55185 .63974 .54626 Mtetra
.63974 .54626 .64477 .55185 .65501 .54877 .65001 .54315 Mtetra
.65001 .54315 .65501 .54877 .66529 .54567 .66031 .54004 Mtetra
.657 .753 .92 r
.66031 .54004 .66529 .54567 .67561 .54257 .67065 .53692 Mtetra
.67065 .53692 .67561 .54257 .68597 .53946 .68104 .53378 Mtetra
.68104 .53378 .68597 .53946 .69636 .53634 .69145 .53064 Mtetra
.69145 .53064 .69636 .53634 .70679 .53321 .70191 .52749 Mtetra
.70191 .52749 .70679 .53321 .71726 .53007 .71241 .52433 Mtetra
.657 .752 .92 r
.71241 .52433 .71726 .53007 .72777 .52692 .72294 .52115 Mtetra
.72294 .52115 .72777 .52692 .73831 .52375 .73352 .51797 Mtetra
.73352 .51797 .73831 .52375 .7489 .52058 .74413 .51477 Mtetra
.74413 .51477 .7489 .52058 .75952 .5174 .75478 .51157 Mtetra
.75478 .51157 .75952 .5174 .77019 .5142 .76547 .50835 Mtetra
.76547 .50835 .77019 .5142 .78089 .511 .77621 .50512 Mtetra
.77621 .50512 .78089 .511 .79163 .50778 .78698 .50188 Mtetra
.78698 .50188 .79163 .50778 .80242 .50455 .79779 .49863 Mtetra
.79779 .49863 .80242 .50455 .81324 .50131 .80864 .49537 Mtetra
.80864 .49537 .81324 .50131 .82411 .49806 .81954 .49209 Mtetra
.81954 .49209 .82411 .49806 .83501 .4948 .83047 .48881 Mtetra
.83047 .48881 .83501 .4948 .84596 .49152 .84145 .48551 Mtetra
.84145 .48551 .84596 .49152 .85694 .48824 .85246 .4822 Mtetra
.85246 .4822 .85694 .48824 .86797 .48494 .86352 .47888 Mtetra
.86352 .47888 .86797 .48494 .87904 .48163 .87462 .47555 Mtetra
.87462 .47555 .87904 .48163 .89015 .4783 .88576 .4722 Mtetra
.88576 .4722 .89015 .4783 .90131 .47497 .89695 .46884 Mtetra
.89695 .46884 .90131 .47497 .9125 .47162 .90818 .46547 Mtetra
.90818 .46547 .9125 .47162 .92374 .46826 .91945 .46209 Mtetra
.91945 .46209 .92374 .46826 .93503 .46489 .93076 .45869 Mtetra
.306 .565 .929 r
.32392 .63527 .32964 .64137 .33932 .62931 .33282 .6378 Mtetra
0 0 0 r
.33282 .6378 .33932 .62931 .34817 .633 .34249 .6268 Mtetra
.581 .687 .914 r
.34249 .6268 .34817 .633 .35735 .63131 .35165 .62575 Mtetra
.615 .723 .922 r
.35165 .62575 .35735 .63131 .36657 .62966 .36089 .62391 Mtetra
.561 .697 .932 r
.36089 .62391 .36657 .62966 .37536 .63856 .37012 .62311 Mtetra
.723 .592 .708 r
.37012 .62311 .37536 .63856 .38532 .62119 .37978 .61323 Mtetra
.502 .598 .882 r
.37978 .61323 .38532 .62119 .39462 .61973 .389 .61408 Mtetra
.62 .723 .92 r
.389 .61408 .39462 .61973 .40399 .61762 .39838 .6121 Mtetra
.626 .73 .922 r
.39838 .6121 .40399 .61762 .41339 .61573 .40781 .60999 Mtetra
.58 .707 .929 r
.40781 .60999 .41339 .61573 .42265 .61987 .41724 .6088 Mtetra
.768 .654 .735 r
.41724 .6088 .42265 .61987 .43244 .60687 .42699 .5978 Mtetra
.466 .552 .859 r
.42699 .5978 .43244 .60687 .44193 .60541 .4364 .5997 Mtetra
.625 .725 .919 r
.4364 .5997 .44193 .60541 .45148 .60308 .44597 .59758 Mtetra
.639 .738 .92 r
.44597 .59758 .45148 .60308 .46106 .6006 .45557 .59512 Mtetra
.64 .74 .921 r
.45557 .59512 .46106 .6006 .47069 .59817 .46522 .59262 Mtetra
.632 .735 .922 r
.46522 .59262 .47069 .59817 .48034 .59622 .4749 .59029 Mtetra
.554 .694 .933 r
.4749 .59029 .48034 .59622 .48959 .63791 .48459 .58957 Mtetra
.629 .448 .618 r
.48459 .58957 .48959 .63791 .4998 .58711 .49442 .57977 Mtetra
.552 .645 .895 r
.49442 .57977 .4998 .58711 .50956 .58515 .50418 .57944 Mtetra
.636 .733 .919 r
.50418 .57944 .50956 .58515 .51936 .58253 .514 .577 Mtetra
.648 .745 .92 r
.514 .577 .51936 .58253 .52919 .57973 .52386 .57425 Mtetra
.653 .749 .92 r
.52386 .57425 .52919 .57973 .53907 .57683 .53375 .57137 Mtetra
.655 .751 .92 r
.53375 .57137 .53907 .57683 .54897 .57387 .54368 .56841 Mtetra
.657 .752 .92 r
.54368 .56841 .54897 .57387 .55891 .57086 .55365 .5654 Mtetra
.658 .753 .92 r
.55365 .5654 .55891 .57086 .56889 .56782 .56365 .56235 Mtetra
.659 .754 .92 r
.56365 .56235 .56889 .56782 .5789 .56476 .57368 .55927 Mtetra
.57368 .55927 .5789 .56476 .58895 .56169 .58376 .55618 Mtetra
.58376 .55618 .58895 .56169 .59903 .55861 .59387 .55308 Mtetra
.59387 .55308 .59903 .55861 .60916 .55553 .60401 .54997 Mtetra
.658 .753 .92 r
.60401 .54997 .60916 .55553 .61931 .55245 .61419 .54687 Mtetra
.61419 .54687 .61931 .55245 .62951 .54936 .62441 .54375 Mtetra
.62441 .54375 .62951 .54936 .63974 .54626 .63467 .54063 Mtetra
.63467 .54063 .63974 .54626 .65001 .54315 .64496 .5375 Mtetra
.64496 .5375 .65001 .54315 .66031 .54004 .65529 .53437 Mtetra
.65529 .53437 .66031 .54004 .67065 .53692 .66566 .53122 Mtetra
.657 .753 .92 r
.66566 .53122 .67065 .53692 .68104 .53378 .67607 .52807 Mtetra
.67607 .52807 .68104 .53378 .69145 .53064 .68652 .5249 Mtetra
.68652 .5249 .69145 .53064 .70191 .52749 .697 .52173 Mtetra
.697 .52173 .70191 .52749 .71241 .52433 .70752 .51854 Mtetra
.657 .752 .92 r
.70752 .51854 .71241 .52433 .72294 .52115 .71809 .51535 Mtetra
.71809 .51535 .72294 .52115 .73352 .51797 .72869 .51214 Mtetra
.72869 .51214 .73352 .51797 .74413 .51477 .73933 .50892 Mtetra
.73933 .50892 .74413 .51477 .75478 .51157 .75001 .5057 Mtetra
.75001 .5057 .75478 .51157 .76547 .50835 .76073 .50246 Mtetra
.76073 .50246 .76547 .50835 .77621 .50512 .77149 .4992 Mtetra
.77149 .4992 .77621 .50512 .78698 .50188 .78229 .49594 Mtetra
.78229 .49594 .78698 .50188 .79779 .49863 .79313 .49267 Mtetra
.79313 .49267 .79779 .49863 .80864 .49537 .80401 .48938 Mtetra
.80401 .48938 .80864 .49537 .81954 .49209 .81493 .48609 Mtetra
.81493 .48609 .81954 .49209 .83047 .48881 .8259 .48278 Mtetra
.8259 .48278 .83047 .48881 .84145 .48551 .8369 .47946 Mtetra
.8369 .47946 .84145 .48551 .85246 .4822 .84795 .47612 Mtetra
.84795 .47612 .85246 .4822 .86352 .47888 .85904 .47278 Mtetra
.85904 .47278 .86352 .47888 .87462 .47555 .87017 .46942 Mtetra
.87017 .46942 .87462 .47555 .88576 .4722 .88134 .46605 Mtetra
.88134 .46605 .88576 .4722 .89695 .46884 .89256 .46267 Mtetra
.89256 .46267 .89695 .46884 .90818 .46547 .90382 .45927 Mtetra
.90382 .45927 .90818 .46547 .91945 .46209 .91512 .45587 Mtetra
.91512 .45587 .91945 .46209 .93076 .45869 .92647 .45245 Mtetra
.576 .704 .929 r
.31814 .62956 .32392 .63527 .33282 .6378 .32725 .6285 Mtetra
.794 .681 .739 r
.32725 .6285 .33282 .6378 .34249 .6268 .33701 .61635 Mtetra
.389 .475 .828 r
.33701 .61635 .34249 .6268 .35165 .62575 .34593 .62003 Mtetra
.61 .716 .92 r
.34593 .62003 .35165 .62575 .36089 .62391 .35518 .61829 Mtetra
.606 .719 .925 r
.35518 .61829 .36089 .62391 .37012 .62311 .36446 .6166 Mtetra
0 .048 .573 r
.36446 .6166 .37012 .62311 .37978 .61323 .37332 .62551 Mtetra
0 0 0 r
.37332 .62551 .37978 .61323 .389 .61408 .38336 .60803 Mtetra
.599 .702 .916 r
.38336 .60803 .389 .61408 .39838 .6121 .39274 .60652 Mtetra
.627 .73 .921 r
.39274 .60652 .39838 .6121 .40781 .60999 .40218 .60437 Mtetra
.616 .726 .924 r
.40218 .60437 .40781 .60999 .41724 .6088 .41166 .60244 Mtetra
.165 .476 .895 r
.41166 .60244 .41724 .6088 .42699 .5978 .42098 .60657 Mtetra
0 0 0 r
.42098 .60657 .42699 .5978 .4364 .5997 .43086 .59348 Mtetra
.599 .699 .914 r
.43086 .59348 .4364 .5997 .44597 .59758 .44042 .59197 Mtetra
.635 .734 .92 r
.44042 .59197 .44597 .59758 .45557 .59512 .45005 .5896 Mtetra
.64 .74 .921 r
.45005 .5896 .45557 .59512 .46522 .59262 .45971 .58707 Mtetra
.638 .739 .922 r
.45971 .58707 .46522 .59262 .4749 .59029 .46941 .58459 Mtetra
.616 .727 .925 r
.46941 .58459 .4749 .59029 .48459 .58957 .47915 .5826 Mtetra
.95 .597 .281 r
.47915 .5826 .48459 .58957 .49442 .57977 .48845 .62444 Mtetra
0 0 .194 r
.48845 .62444 .49442 .57977 .50418 .57944 .49877 .57338 Mtetra
.618 .716 .916 r
.49877 .57338 .50418 .57944 .514 .577 .50861 .57137 Mtetra
.644 .741 .92 r
.50861 .57137 .514 .577 .52386 .57425 .51849 .56871 Mtetra
.651 .747 .92 r
.51849 .56871 .52386 .57425 .53375 .57137 .5284 .56586 Mtetra
.654 .75 .92 r
.5284 .56586 .53375 .57137 .54368 .56841 .53836 .56291 Mtetra
.656 .752 .92 r
.53836 .56291 .54368 .56841 .55365 .5654 .54835 .55989 Mtetra
.658 .753 .92 r
.54835 .55989 .55365 .5654 .56365 .56235 .55837 .55683 Mtetra
.659 .754 .92 r
.55837 .55683 .56365 .56235 .57368 .55927 .56843 .55374 Mtetra
.56843 .55374 .57368 .55927 .58376 .55618 .57853 .55063 Mtetra
.57853 .55063 .58376 .55618 .59387 .55308 .58866 .54751 Mtetra
.58866 .54751 .59387 .55308 .60401 .54997 .59883 .54438 Mtetra
.658 .753 .92 r
.59883 .54438 .60401 .54997 .61419 .54687 .60904 .54125 Mtetra
.60904 .54125 .61419 .54687 .62441 .54375 .61928 .53811 Mtetra
.61928 .53811 .62441 .54375 .63467 .54063 .62957 .53497 Mtetra
.62957 .53497 .63467 .54063 .64496 .5375 .63989 .53182 Mtetra
.63989 .53182 .64496 .5375 .65529 .53437 .65024 .52866 Mtetra
.65024 .52866 .65529 .53437 .66566 .53122 .66064 .52549 Mtetra
.657 .753 .92 r
.66064 .52549 .66566 .53122 .67607 .52807 .67107 .52231 Mtetra
.67107 .52231 .67607 .52807 .68652 .5249 .68154 .51913 Mtetra
.68154 .51913 .68652 .5249 .697 .52173 .69206 .51593 Mtetra
.69206 .51593 .697 .52173 .70752 .51854 .70261 .51272 Mtetra
.70261 .51272 .70752 .51854 .71809 .51535 .71319 .5095 Mtetra
.657 .752 .92 r
.71319 .5095 .71809 .51535 .72869 .51214 .72382 .50627 Mtetra
.72382 .50627 .72869 .51214 .73933 .50892 .73449 .50303 Mtetra
.73449 .50303 .73933 .50892 .75001 .5057 .7452 .49978 Mtetra
.7452 .49978 .75001 .5057 .76073 .50246 .75595 .49652 Mtetra
.75595 .49652 .76073 .50246 .77149 .4992 .76674 .49325 Mtetra
.76674 .49325 .77149 .4992 .78229 .49594 .77757 .48996 Mtetra
.77757 .48996 .78229 .49594 .79313 .49267 .78844 .48667 Mtetra
.78844 .48667 .79313 .49267 .80401 .48938 .79935 .48336 Mtetra
.79935 .48336 .80401 .48938 .81493 .48609 .8103 .48004 Mtetra
.8103 .48004 .81493 .48609 .8259 .48278 .82129 .4767 Mtetra
.82129 .4767 .8259 .48278 .8369 .47946 .83233 .47336 Mtetra
.83233 .47336 .8369 .47946 .84795 .47612 .8434 .47 Mtetra
.8434 .47 .84795 .47612 .85904 .47278 .85452 .46663 Mtetra
.85452 .46663 .85904 .47278 .87017 .46942 .86569 .46325 Mtetra
.86569 .46325 .87017 .46942 .88134 .46605 .87689 .45986 Mtetra
.87689 .45986 .88134 .46605 .89256 .46267 .88814 .45645 Mtetra
.88814 .45645 .89256 .46267 .90382 .45927 .89943 .45303 Mtetra
.89943 .45303 .90382 .45927 .91512 .45587 .91076 .4496 Mtetra
.91076 .4496 .91512 .45587 .92647 .45245 .92214 .44616 Mtetra
.603 .716 .924 r
.31232 .6239 .31814 .62956 .32725 .6285 .32148 .6223 Mtetra
.308 .565 .929 r
.32148 .6223 .32725 .6285 .33701 .61635 .33044 .62481 Mtetra
0 0 0 r
.33044 .62481 .33701 .61635 .34593 .62003 .34019 .61373 Mtetra
.581 .687 .914 r
.34019 .61373 .34593 .62003 .35518 .61829 .34942 .61265 Mtetra
.615 .723 .922 r
.34942 .61265 .35518 .61829 .36446 .6166 .35873 .61076 Mtetra
.561 .697 .932 r
.35873 .61076 .36446 .6166 .37332 .62551 .36803 .60993 Mtetra
.723 .592 .708 r
.36803 .60993 .37332 .62551 .38336 .60803 .37777 .59997 Mtetra
.501 .598 .882 r
.37777 .59997 .38336 .60803 .39274 .60652 .38707 .60079 Mtetra
.62 .723 .92 r
.38707 .60079 .39274 .60652 .40218 .60437 .39652 .59877 Mtetra
.626 .73 .922 r
.39652 .59877 .40218 .60437 .41166 .60244 .40602 .59661 Mtetra
.58 .707 .929 r
.40602 .59661 .41166 .60244 .42098 .60657 .41553 .59538 Mtetra
.769 .654 .736 r
.41553 .59538 .42098 .60657 .43086 .59348 .42536 .5843 Mtetra
.465 .551 .86 r
.42536 .5843 .43086 .59348 .44042 .59197 .43485 .58617 Mtetra
.625 .725 .919 r
.43485 .58617 .44042 .59197 .45005 .5896 .44449 .58401 Mtetra
.639 .738 .92 r
.44449 .58401 .45005 .5896 .45971 .58707 .45417 .5815 Mtetra
.64 .74 .921 r
.45417 .5815 .45971 .58707 .46941 .58459 .46389 .57895 Mtetra
.632 .735 .922 r
.46389 .57895 .46941 .58459 .47915 .5826 .47365 .57658 Mtetra
.554 .694 .932 r
.47365 .57658 .47915 .5826 .48845 .62444 .48343 .57582 Mtetra
.628 .446 .617 r
.48343 .57582 .48845 .62444 .49877 .57338 .49334 .56594 Mtetra
.552 .645 .895 r
.49334 .56594 .49877 .57338 .50861 .57137 .50318 .56557 Mtetra
.636 .733 .919 r
.50318 .56557 .50861 .57137 .51849 .56871 .51308 .56308 Mtetra
.648 .745 .92 r
.51308 .56308 .51849 .56871 .5284 .56586 .52302 .56028 Mtetra
.653 .749 .92 r
.52302 .56028 .5284 .56586 .53836 .56291 .533 .55735 Mtetra
.655 .751 .92 r
.533 .55735 .53836 .56291 .54835 .55989 .54301 .55434 Mtetra
.657 .752 .92 r
.54301 .55434 .54835 .55989 .55837 .55683 .55306 .55128 Mtetra
.658 .753 .92 r
.55306 .55128 .55837 .55683 .56843 .55374 .56314 .54817 Mtetra
.659 .754 .92 r
.56314 .54817 .56843 .55374 .57853 .55063 .57327 .54504 Mtetra
.57327 .54504 .57853 .55063 .58866 .54751 .58342 .5419 Mtetra
.58342 .5419 .58866 .54751 .59883 .54438 .59362 .53875 Mtetra
.59362 .53875 .59883 .54438 .60904 .54125 .60385 .53559 Mtetra
.658 .753 .92 r
.60385 .53559 .60904 .54125 .61928 .53811 .61412 .53243 Mtetra
.61412 .53243 .61928 .53811 .62957 .53497 .62443 .52926 Mtetra
.62443 .52926 .62957 .53497 .63989 .53182 .63477 .52609 Mtetra
.63477 .52609 .63989 .53182 .65024 .52866 .64516 .52291 Mtetra
.64516 .52291 .65024 .52866 .66064 .52549 .65558 .51972 Mtetra
.65558 .51972 .66064 .52549 .67107 .52231 .66604 .51652 Mtetra
.657 .753 .92 r
.66604 .51652 .67107 .52231 .68154 .51913 .67654 .51331 Mtetra
.67654 .51331 .68154 .51913 .69206 .51593 .68708 .51009 Mtetra
.68708 .51009 .69206 .51593 .70261 .51272 .69765 .50686 Mtetra
.69765 .50686 .70261 .51272 .71319 .5095 .70827 .50362 Mtetra
.657 .752 .92 r
.70827 .50362 .71319 .5095 .72382 .50627 .71893 .50037 Mtetra
.71893 .50037 .72382 .50627 .73449 .50303 .72962 .4971 Mtetra
.72962 .4971 .73449 .50303 .7452 .49978 .74036 .49383 Mtetra
.74036 .49383 .7452 .49978 .75595 .49652 .75114 .49054 Mtetra
.75114 .49054 .75595 .49652 .76674 .49325 .76195 .48725 Mtetra
.76195 .48725 .76674 .49325 .77757 .48996 .77281 .48394 Mtetra
.77281 .48394 .77757 .48996 .78844 .48667 .78371 .48062 Mtetra
.78371 .48062 .78844 .48667 .79935 .48336 .79465 .47729 Mtetra
.79465 .47729 .79935 .48336 .8103 .48004 .80563 .47394 Mtetra
.80563 .47394 .8103 .48004 .82129 .4767 .81665 .47059 Mtetra
.81665 .47059 .82129 .4767 .83233 .47336 .82772 .46722 Mtetra
.82772 .46722 .83233 .47336 .8434 .47 .83883 .46384 Mtetra
.83883 .46384 .8434 .47 .85452 .46663 .84998 .46045 Mtetra
.84998 .46045 .85452 .46663 .86569 .46325 .86117 .45704 Mtetra
.86117 .45704 .86569 .46325 .87689 .45986 .87241 .45362 Mtetra
.87241 .45362 .87689 .45986 .88814 .45645 .88369 .45019 Mtetra
.88369 .45019 .88814 .45645 .89943 .45303 .89501 .44675 Mtetra
.89501 .44675 .89943 .45303 .91076 .4496 .90638 .44329 Mtetra
.90638 .44329 .91076 .4496 .92214 .44616 .91779 .43982 Mtetra
.601 .71 .921 r
.30647 .61807 .31232 .6239 .32148 .6223 .31564 .61652 Mtetra
.576 .704 .929 r
.31564 .61652 .32148 .6223 .33044 .62481 .32482 .61541 Mtetra
.795 .681 .739 r
.32482 .61541 .33044 .62481 .34019 .61373 .33466 .60317 Mtetra
.388 .475 .828 r
.33466 .60317 .34019 .61373 .34942 .61265 .34364 .60684 Mtetra
.61 .716 .92 r
.34364 .60684 .34942 .61265 .35873 .61076 .35296 .60506 Mtetra
.606 .719 .925 r
.35296 .60506 .35873 .61076 .36803 .60993 .36232 .60333 Mtetra
0 .053 .579 r
.36232 .60333 .36803 .60993 .37777 .59997 .37124 .61224 Mtetra
0 0 0 r
.37124 .61224 .37777 .59997 .38707 .60079 .38137 .59464 Mtetra
.599 .702 .916 r
.38137 .59464 .38707 .60079 .39652 .59877 .39083 .5931 Mtetra
.627 .73 .921 r
.39083 .5931 .39652 .59877 .40602 .59661 .40034 .59091 Mtetra
.616 .726 .924 r
.40034 .59091 .40602 .59661 .41553 .59538 .40989 .58893 Mtetra
.168 .477 .896 r
.40989 .58893 .41553 .59538 .42536 .5843 .41929 .59304 Mtetra
0 0 0 r
.41929 .59304 .42536 .5843 .43485 .58617 .42925 .57985 Mtetra
.599 .699 .914 r
.42925 .57985 .43485 .58617 .44449 .58401 .43889 .57831 Mtetra
.635 .734 .92 r
.43889 .57831 .44449 .58401 .45417 .5815 .4486 .57589 Mtetra
.64 .74 .921 r
.4486 .57589 .45417 .5815 .46389 .57895 .45834 .57331 Mtetra
.638 .739 .922 r
.45834 .57331 .46389 .57895 .47365 .57658 .46812 .57078 Mtetra
.616 .727 .925 r
.46812 .57078 .47365 .57658 .48343 .57582 .47793 .56874 Mtetra
.949 .596 .275 r
.47793 .56874 .48343 .57582 .49334 .56594 .4873 .61074 Mtetra
0 0 .187 r
.4873 .61074 .49334 .56594 .50318 .56557 .49772 .55941 Mtetra
.618 .716 .916 r
.49772 .55941 .50318 .56557 .51308 .56308 .50764 .55736 Mtetra
.644 .741 .92 r
.50764 .55736 .51308 .56308 .52302 .56028 .5176 .55464 Mtetra
.651 .747 .92 r
.5176 .55464 .52302 .56028 .533 .55735 .5276 .55174 Mtetra
.654 .75 .92 r
.5276 .55174 .533 .55735 .54301 .55434 .53764 .54874 Mtetra
.656 .752 .92 r
.53764 .54874 .54301 .55434 .55306 .55128 .54771 .54568 Mtetra
.658 .753 .92 r
.54771 .54568 .55306 .55128 .56314 .54817 .55782 .54257 Mtetra
.659 .754 .92 r
.55782 .54257 .56314 .54817 .57327 .54504 .56797 .53942 Mtetra
.56797 .53942 .57327 .54504 .58342 .5419 .57815 .53626 Mtetra
.57815 .53626 .58342 .5419 .59362 .53875 .58837 .53308 Mtetra
.58837 .53308 .59362 .53875 .60385 .53559 .59863 .5299 Mtetra
.658 .753 .92 r
.59863 .5299 .60385 .53559 .61412 .53243 .60892 .52671 Mtetra
.60892 .52671 .61412 .53243 .62443 .52926 .61926 .52352 Mtetra
.61926 .52352 .62443 .52926 .63477 .52609 .62963 .52033 Mtetra
.62963 .52033 .63477 .52609 .64516 .52291 .64004 .51712 Mtetra
.64004 .51712 .64516 .52291 .65558 .51972 .65048 .51391 Mtetra
.65048 .51391 .65558 .51972 .66604 .51652 .66097 .51068 Mtetra
.657 .753 .92 r
.66097 .51068 .66604 .51652 .67654 .51331 .6715 .50745 Mtetra
.6715 .50745 .67654 .51331 .68708 .51009 .68206 .50421 Mtetra
.68206 .50421 .68708 .51009 .69765 .50686 .69267 .50096 Mtetra
.69267 .50096 .69765 .50686 .70827 .50362 .70331 .49769 Mtetra
.70331 .49769 .70827 .50362 .71893 .50037 .714 .49442 Mtetra
.657 .752 .92 r
.714 .49442 .71893 .50037 .72962 .4971 .72472 .49113 Mtetra
.72472 .49113 .72962 .4971 .74036 .49383 .73548 .48784 Mtetra
.73548 .48784 .74036 .49383 .75114 .49054 .74629 .48453 Mtetra
.74629 .48453 .75114 .49054 .76195 .48725 .75713 .48121 Mtetra
.75713 .48121 .76195 .48725 .77281 .48394 .76802 .47788 Mtetra
.76802 .47788 .77281 .48394 .78371 .48062 .77895 .47453 Mtetra
.77895 .47453 .78371 .48062 .79465 .47729 .78992 .47118 Mtetra
.78992 .47118 .79465 .47729 .80563 .47394 .80093 .46781 Mtetra
.80093 .46781 .80563 .47394 .81665 .47059 .81198 .46443 Mtetra
.81198 .46443 .81665 .47059 .82772 .46722 .82308 .46104 Mtetra
.82308 .46104 .82772 .46722 .83883 .46384 .83422 .45763 Mtetra
.83422 .45763 .83883 .46384 .84998 .46045 .8454 .45421 Mtetra
.8454 .45421 .84998 .46045 .86117 .45704 .85662 .45078 Mtetra
.85662 .45078 .86117 .45704 .87241 .45362 .86789 .44734 Mtetra
.86789 .44734 .87241 .45362 .88369 .45019 .8792 .44389 Mtetra
.8792 .44389 .88369 .45019 .89501 .44675 .89056 .44042 Mtetra
.89056 .44042 .89501 .44675 .90638 .44329 .90195 .43694 Mtetra
.90195 .43694 .90638 .44329 .91779 .43982 .9134 .43344 Mtetra
.566 .675 .912 r
.30063 .61155 .30647 .61807 .31564 .61652 .30976 .61077 Mtetra
.603 .716 .924 r
.30976 .61077 .31564 .61652 .32482 .61541 .31899 .60913 Mtetra
.309 .566 .929 r
.31899 .60913 .32482 .61541 .33466 .60317 .32802 .61161 Mtetra
0 0 0 r
.32802 .61161 .33466 .60317 .34364 .60684 .33785 .60045 Mtetra
.581 .687 .914 r
.33785 .60045 .34364 .60684 .35296 .60506 .34716 .59933 Mtetra
.615 .723 .922 r
.34716 .59933 .35296 .60506 .36232 .60333 .35654 .5974 Mtetra
.561 .697 .932 r
.35654 .5974 .36232 .60333 .37124 .61224 .36591 .59652 Mtetra
.723 .592 .708 r
.36591 .59652 .37124 .61224 .38137 .59464 .37573 .58649 Mtetra
.501 .598 .883 r
.37573 .58649 .38137 .59464 .39083 .5931 .3851 .58728 Mtetra
.62 .723 .92 r
.3851 .58728 .39083 .5931 .40034 .59091 .39463 .58521 Mtetra
.626 .73 .922 r
.39463 .58521 .40034 .59091 .40989 .58893 .4042 .58301 Mtetra
.581 .707 .929 r
.4042 .58301 .40989 .58893 .41929 .59304 .41379 .58174 Mtetra
.769 .655 .736 r
.41379 .58174 .41929 .59304 .42925 .57985 .42371 .57057 Mtetra
.465 .551 .86 r
.42371 .57057 .42925 .57985 .43889 .57831 .43327 .57241 Mtetra
.625 .725 .919 r
.43327 .57241 .43889 .57831 .4486 .57589 .44298 .5702 Mtetra
.639 .738 .92 r
.44298 .5702 .4486 .57589 .45834 .57331 .45275 .56765 Mtetra
.64 .74 .921 r
.45275 .56765 .45834 .57331 .46812 .57078 .46255 .56505 Mtetra
.632 .735 .922 r
.46255 .56505 .46812 .57078 .47793 .56874 .47239 .56263 Mtetra
.555 .694 .932 r
.47239 .56263 .47793 .56874 .4873 .61074 .48224 .56183 Mtetra
.627 .445 .616 r
.48224 .56183 .4873 .61074 .49772 .55941 .49223 .55187 Mtetra
.552 .645 .895 r
.49223 .55187 .49772 .55941 .50764 .55736 .50216 .55146 Mtetra
.636 .733 .919 r
.50216 .55146 .50764 .55736 .5176 .55464 .51214 .54893 Mtetra
.648 .745 .92 r
.51214 .54893 .5176 .55464 .5276 .55174 .52217 .54607 Mtetra
.653 .749 .92 r
.52217 .54607 .5276 .55174 .53764 .54874 .53223 .54309 Mtetra
.655 .751 .92 r
.53223 .54309 .53764 .54874 .54771 .54568 .54232 .54003 Mtetra
.657 .752 .92 r
.54232 .54003 .54771 .54568 .55782 .54257 .55246 .53691 Mtetra
.658 .753 .92 r
.55246 .53691 .55782 .54257 .56797 .53942 .56263 .53376 Mtetra
.659 .754 .92 r
.56263 .53376 .56797 .53942 .57815 .53626 .57284 .53057 Mtetra
.57284 .53057 .57815 .53626 .58837 .53308 .58308 .52738 Mtetra
.58308 .52738 .58837 .53308 .59863 .5299 .59337 .52417 Mtetra
.59337 .52417 .59863 .5299 .60892 .52671 .60369 .52096 Mtetra
.658 .753 .92 r
.60369 .52096 .60892 .52671 .61926 .52352 .61405 .51774 Mtetra
.61405 .51774 .61926 .52352 .62963 .52033 .62444 .51452 Mtetra
.62444 .51452 .62963 .52033 .64004 .51712 .63488 .51129 Mtetra
.63488 .51129 .64004 .51712 .65048 .51391 .64536 .50806 Mtetra
.64536 .50806 .65048 .51391 .66097 .51068 .65587 .50481 Mtetra
.65587 .50481 .66097 .51068 .6715 .50745 .66642 .50156 Mtetra
.657 .753 .92 r
.66642 .50156 .6715 .50745 .68206 .50421 .67701 .49829 Mtetra
.67701 .49829 .68206 .50421 .69267 .50096 .68765 .49501 Mtetra
.68765 .49501 .69267 .50096 .70331 .49769 .69832 .49173 Mtetra
.69832 .49173 .70331 .49769 .714 .49442 .70903 .48843 Mtetra
.657 .752 .92 r
.70903 .48843 .714 .49442 .72472 .49113 .71978 .48512 Mtetra
.71978 .48512 .72472 .49113 .73548 .48784 .73057 .4818 Mtetra
.73057 .4818 .73548 .48784 .74629 .48453 .74141 .47847 Mtetra
.74141 .47847 .74629 .48453 .75713 .48121 .75228 .47512 Mtetra
.75228 .47512 .75713 .48121 .76802 .47788 .7632 .47177 Mtetra
.7632 .47177 .76802 .47788 .77895 .47453 .77416 .4684 Mtetra
.77416 .4684 .77895 .47453 .78992 .47118 .78516 .46502 Mtetra
.78516 .46502 .78992 .47118 .80093 .46781 .7962 .46163 Mtetra
.7962 .46163 .80093 .46781 .81198 .46443 .80728 .45823 Mtetra
.80728 .45823 .81198 .46443 .82308 .46104 .81841 .45481 Mtetra
.81841 .45481 .82308 .46104 .83422 .45763 .82958 .45138 Mtetra
.82958 .45138 .83422 .45763 .8454 .45421 .84079 .44794 Mtetra
.84079 .44794 .8454 .45421 .85662 .45078 .85204 .44448 Mtetra
.85204 .44448 .85662 .45078 .86789 .44734 .86334 .44102 Mtetra
.86334 .44102 .86789 .44734 .8792 .44389 .87469 .43754 Mtetra
.87469 .43754 .8792 .44389 .89056 .44042 .88607 .43404 Mtetra
.88607 .43404 .89056 .44042 .90195 .43694 .8975 .43054 Mtetra
.8975 .43054 .90195 .43694 .9134 .43344 .90898 .42702 Mtetra
.266 .342 .755 r
.29524 .59776 .30063 .61155 .30976 .61077 .30386 .60484 Mtetra
.601 .71 .921 r
.30386 .60484 .30976 .61077 .31899 .60913 .3131 .60325 Mtetra
.576 .704 .929 r
.3131 .60325 .31899 .60913 .32802 .61161 .32235 .60211 Mtetra
.795 .682 .74 r
.32235 .60211 .32802 .61161 .33785 .60045 .33227 .58978 Mtetra
.387 .474 .828 r
.33227 .58978 .33785 .60045 .34716 .59933 .34132 .59343 Mtetra
.61 .716 .92 r
.34132 .59343 .34716 .59933 .35654 .5974 .35071 .59161 Mtetra
.606 .719 .925 r
.35071 .59161 .35654 .5974 .36591 .59652 .36015 .58983 Mtetra
0 .059 .585 r
.36015 .58983 .36591 .59652 .37573 .58649 .36913 .59874 Mtetra
0 0 0 r
.36913 .59874 .37573 .58649 .3851 .58728 .37935 .58104 Mtetra
.599 .703 .916 r
.37935 .58104 .3851 .58728 .39463 .58521 .38888 .57945 Mtetra
.627 .73 .921 r
.38888 .57945 .39463 .58521 .4042 .58301 .39847 .57721 Mtetra
.616 .726 .924 r
.39847 .57721 .4042 .58301 .41379 .58174 .4081 .57519 Mtetra
.171 .479 .896 r
.4081 .57519 .41379 .58174 .42371 .57057 .41757 .57928 Mtetra
0 0 0 r
.41757 .57928 .42371 .57057 .43327 .57241 .42762 .566 Mtetra
.599 .699 .914 r
.42762 .566 .43327 .57241 .44298 .5702 .43734 .56441 Mtetra
.635 .734 .92 r
.43734 .56441 .44298 .5702 .45275 .56765 .44712 .56194 Mtetra
.64 .74 .921 r
.44712 .56194 .45275 .56765 .46255 .56505 .45694 .55932 Mtetra
.638 .739 .922 r
.45694 .55932 .46255 .56505 .47239 .56263 .4668 .55674 Mtetra
.616 .726 .925 r
.4668 .55674 .47239 .56263 .48224 .56183 .47669 .55466 Mtetra
.949 .594 .269 r
.47669 .55466 .48224 .56183 .49223 .55187 .48613 .5968 Mtetra
0 0 .181 r
.48613 .5968 .49223 .55187 .50216 .55146 .49665 .54521 Mtetra
.618 .716 .916 r
.49665 .54521 .50216 .55146 .51214 .54893 .50665 .5431 Mtetra
.644 .741 .92 r
.50665 .5431 .51214 .54893 .52217 .54607 .5167 .54034 Mtetra
.651 .747 .92 r
.5167 .54034 .52217 .54607 .53223 .54309 .52678 .53739 Mtetra
.654 .75 .92 r
.52678 .53739 .53223 .54309 .54232 .54003 .5369 .53433 Mtetra
.656 .752 .92 r
.5369 .53433 .54232 .54003 .55246 .53691 .54706 .53122 Mtetra
.658 .753 .92 r
.54706 .53122 .55246 .53691 .56263 .53376 .55726 .52805 Mtetra
.659 .754 .92 r
.55726 .52805 .56263 .53376 .57284 .53057 .56749 .52485 Mtetra
.56749 .52485 .57284 .53057 .58308 .52738 .57776 .52163 Mtetra
.57776 .52163 .58308 .52738 .59337 .52417 .58807 .5184 Mtetra
.58807 .5184 .59337 .52417 .60369 .52096 .59842 .51517 Mtetra
.658 .753 .92 r
.59842 .51517 .60369 .52096 .61405 .51774 .6088 .51193 Mtetra
.6088 .51193 .61405 .51774 .62444 .51452 .61923 .50868 Mtetra
.61923 .50868 .62444 .51452 .63488 .51129 .62969 .50543 Mtetra
.62969 .50543 .63488 .51129 .64536 .50806 .64019 .50217 Mtetra
.64019 .50217 .64536 .50806 .65587 .50481 .65073 .4989 Mtetra
.65073 .4989 .65587 .50481 .66642 .50156 .66131 .49562 Mtetra
.657 .753 .92 r
.66131 .49562 .66642 .50156 .67701 .49829 .67193 .49233 Mtetra
.67193 .49233 .67701 .49829 .68765 .49501 .68259 .48903 Mtetra
.68259 .48903 .68765 .49501 .69832 .49173 .69329 .48572 Mtetra
.69329 .48572 .69832 .49173 .70903 .48843 .70403 .4824 Mtetra
.70403 .4824 .70903 .48843 .71978 .48512 .71481 .47906 Mtetra
.657 .752 .92 r
.71481 .47906 .71978 .48512 .73057 .4818 .72563 .47572 Mtetra
.72563 .47572 .73057 .4818 .74141 .47847 .73649 .47236 Mtetra
.73649 .47236 .74141 .47847 .75228 .47512 .7474 .469 Mtetra
.7474 .469 .75228 .47512 .7632 .47177 .75834 .46562 Mtetra
.75834 .46562 .7632 .47177 .77416 .4684 .76933 .46223 Mtetra
.76933 .46223 .77416 .4684 .78516 .46502 .78036 .45882 Mtetra
.78036 .45882 .78516 .46502 .7962 .46163 .79143 .45541 Mtetra
.79143 .45541 .7962 .46163 .80728 .45823 .80254 .45198 Mtetra
.80254 .45198 .80728 .45823 .81841 .45481 .8137 .44854 Mtetra
.8137 .44854 .81841 .45481 .82958 .45138 .8249 .44508 Mtetra
.8249 .44508 .82958 .45138 .84079 .44794 .83614 .44162 Mtetra
.83614 .44162 .84079 .44794 .85204 .44448 .84743 .43814 Mtetra
.84743 .43814 .85204 .44448 .86334 .44102 .85876 .43465 Mtetra
.85876 .43465 .86334 .44102 .87469 .43754 .87014 .43114 Mtetra
.87014 .43114 .87469 .43754 .88607 .43404 .88155 .42762 Mtetra
.88155 .42762 .88607 .43404 .8975 .43054 .89302 .42409 Mtetra
.89302 .42409 .8975 .43054 .90898 .42702 .90453 .42055 Mtetra
0 0 0 r
.28817 .6083 .29524 .59776 .30386 .60484 .29796 .59824 Mtetra
.566 .675 .912 r
.29796 .59824 .30386 .60484 .3131 .60325 .30716 .59741 Mtetra
.603 .716 .924 r
.30716 .59741 .3131 .60325 .32235 .60211 .31646 .59573 Mtetra
.311 .566 .929 r
.31646 .59573 .32235 .60211 .33227 .58978 .32556 .5982 Mtetra
0 0 0 r
.32556 .5982 .33227 .58978 .34132 .59343 .33548 .58695 Mtetra
.58 .687 .914 r
.33548 .58695 .34132 .59343 .35071 .59161 .34485 .58579 Mtetra
.615 .723 .922 r
.34485 .58579 .35071 .59161 .36015 .58983 .35431 .58381 Mtetra
.561 .697 .932 r
.35431 .58381 .36015 .58983 .36913 .59874 .36376 .5829 Mtetra
.723 .592 .708 r
.36376 .5829 .36913 .59874 .37935 .58104 .37366 .57278 Mtetra
.501 .598 .883 r
.37366 .57278 .37935 .58104 .38888 .57945 .3831 .57354 Mtetra
.62 .723 .92 r
.3831 .57354 .38888 .57945 .39847 .57721 .3927 .57143 Mtetra
.626 .73 .922 r
.3927 .57143 .39847 .57721 .4081 .57519 .40236 .56917 Mtetra
.581 .707 .929 r
.40236 .56917 .4081 .57519 .41757 .57928 .41202 .56786 Mtetra
.77 .655 .736 r
.41202 .56786 .41757 .57928 .42762 .566 .42202 .55661 Mtetra
.464 .551 .86 r
.42202 .55661 .42762 .566 .43734 .56441 .43166 .55842 Mtetra
.625 .725 .919 r
.43166 .55842 .43734 .56441 .44712 .56194 .44145 .55616 Mtetra
.639 .738 .92 r
.44145 .55616 .44712 .56194 .45694 .55932 .4513 .55356 Mtetra
.64 .74 .921 r
.4513 .55356 .45694 .55932 .4668 .55674 .46118 .55091 Mtetra
.632 .735 .922 r
.46118 .55091 .4668 .55674 .47669 .55466 .4711 .54845 Mtetra
.555 .694 .932 r
.4711 .54845 .47669 .55466 .48613 .5968 .48104 .54761 Mtetra
.626 .443 .615 r
.48104 .54761 .48613 .5968 .49665 .54521 .49112 .53756 Mtetra
.552 .645 .895 r
.49112 .53756 .49665 .54521 .50665 .5431 .50112 .53711 Mtetra
.636 .733 .919 r
.50112 .53711 .50665 .5431 .5167 .54034 .51119 .53453 Mtetra
.648 .745 .92 r
.51119 .53453 .5167 .54034 .52678 .53739 .5213 .53162 Mtetra
.653 .749 .92 r
.5213 .53162 .52678 .53739 .5369 .53433 .53144 .52859 Mtetra
.655 .751 .92 r
.53144 .52859 .5369 .53433 .54706 .53122 .54163 .52547 Mtetra
.657 .752 .92 r
.54163 .52547 .54706 .53122 .55726 .52805 .55185 .5223 Mtetra
.658 .753 .92 r
.55185 .5223 .55726 .52805 .56749 .52485 .56211 .51909 Mtetra
.659 .754 .92 r
.56211 .51909 .56749 .52485 .57776 .52163 .57241 .51585 Mtetra
.57241 .51585 .57776 .52163 .58807 .5184 .58274 .5126 Mtetra
.58274 .5126 .58807 .5184 .59842 .51517 .59311 .50934 Mtetra
.59311 .50934 .59842 .51517 .6088 .51193 .60352 .50607 Mtetra
.658 .753 .92 r
.60352 .50607 .6088 .51193 .61923 .50868 .61397 .5028 Mtetra
.61397 .5028 .61923 .50868 .62969 .50543 .62446 .49952 Mtetra
.62446 .49952 .62969 .50543 .64019 .50217 .63499 .49624 Mtetra
.63499 .49624 .64019 .50217 .65073 .4989 .64556 .49294 Mtetra
.64556 .49294 .65073 .4989 .66131 .49562 .65616 .48964 Mtetra
.65616 .48964 .66131 .49562 .67193 .49233 .66681 .48633 Mtetra
.657 .753 .92 r
.66681 .48633 .67193 .49233 .68259 .48903 .6775 .483 Mtetra
.6775 .483 .68259 .48903 .69329 .48572 .68823 .47967 Mtetra
.68823 .47967 .69329 .48572 .70403 .4824 .69899 .47632 Mtetra
.69899 .47632 .70403 .4824 .71481 .47906 .7098 .47297 Mtetra
.657 .752 .92 r
.7098 .47297 .71481 .47906 .72563 .47572 .72065 .4696 Mtetra
.72065 .4696 .72563 .47572 .73649 .47236 .73154 .46622 Mtetra
.73154 .46622 .73649 .47236 .7474 .469 .74248 .46283 Mtetra
.74248 .46283 .7474 .469 .75834 .46562 .75345 .45942 Mtetra
.75345 .45942 .75834 .46562 .76933 .46223 .76447 .45601 Mtetra
.76447 .45601 .76933 .46223 .78036 .45882 .77553 .45258 Mtetra
.77553 .45258 .78036 .45882 .79143 .45541 .78663 .44914 Mtetra
.78663 .44914 .79143 .45541 .80254 .45198 .79777 .44569 Mtetra
.79777 .44569 .80254 .45198 .8137 .44854 .80896 .44222 Mtetra
.80896 .44222 .8137 .44854 .8249 .44508 .82019 .43874 Mtetra
.82019 .43874 .8249 .44508 .83614 .44162 .83147 .43525 Mtetra
.83147 .43525 .83614 .44162 .84743 .43814 .84279 .43175 Mtetra
.84279 .43175 .84743 .43814 .85876 .43465 .85415 .42823 Mtetra
.85415 .42823 .85876 .43465 .87014 .43114 .86555 .4247 Mtetra
.86555 .4247 .87014 .43114 .88155 .42762 .87701 .42116 Mtetra
.87701 .42116 .88155 .42762 .89302 .42409 .8885 .4176 Mtetra
.8885 .4176 .89302 .42409 .90453 .42055 .90004 .41403 Mtetra
.828 .703 .725 r
.28233 .59985 .28817 .6083 .29796 .59824 .29253 .58432 Mtetra
.264 .34 .755 r
.29253 .58432 .29796 .59824 .30716 .59741 .3012 .5914 Mtetra
.601 .71 .921 r
.3012 .5914 .30716 .59741 .31646 .59573 .31051 .58977 Mtetra
.576 .704 .929 r
.31051 .58977 .31646 .59573 .32556 .5982 .31984 .58858 Mtetra
.796 .683 .74 r
.31984 .58858 .32556 .5982 .33548 .58695 .32984 .57617 Mtetra
.386 .474 .828 r
.32984 .57617 .33548 .58695 .34485 .58579 .33896 .57979 Mtetra
.61 .716 .92 r
.33896 .57979 .34485 .58579 .35431 .58381 .34843 .57793 Mtetra
.606 .719 .925 r
.34843 .57793 .35431 .58381 .36376 .5829 .35793 .57611 Mtetra
0 .065 .592 r
.35793 .57611 .36376 .5829 .37366 .57278 .36698 .58502 Mtetra
0 0 0 r
.36698 .58502 .37366 .57278 .3831 .57354 .37729 .5672 Mtetra
.599 .703 .916 r
.37729 .5672 .3831 .57354 .3927 .57143 .3869 .56557 Mtetra
.627 .73 .921 r
.3869 .56557 .3927 .57143 .40236 .56917 .39657 .56329 Mtetra
.616 .726 .924 r
.39657 .56329 .40236 .56917 .41202 .56786 .40627 .56121 Mtetra
.174 .48 .897 r
.40627 .56121 .41202 .56786 .42202 .55661 .41582 .56529 Mtetra
0 0 0 r
.41582 .56529 .42202 .55661 .43166 .55842 .42595 .55191 Mtetra
.599 .699 .914 r
.42595 .55191 .43166 .55842 .44145 .55616 .43575 .55028 Mtetra
.635 .734 .92 r
.43575 .55028 .44145 .55616 .4513 .55356 .44562 .54776 Mtetra
.64 .74 .921 r
.44562 .54776 .4513 .55356 .46118 .55091 .45552 .54509 Mtetra
.638 .739 .922 r
.45552 .54509 .46118 .55091 .4711 .54845 .46546 .54246 Mtetra
.616 .726 .925 r
.46546 .54246 .4711 .54845 .48104 .54761 .47544 .54032 Mtetra
.948 .592 .263 r
.47544 .54032 .48104 .54761 .49112 .53756 .48493 .58262 Mtetra
0 0 .174 r
.48493 .58262 .49112 .53756 .50112 .53711 .49556 .53076 Mtetra
.618 .716 .916 r
.49556 .53076 .50112 .53711 .51119 .53453 .50565 .5286 Mtetra
.644 .741 .92 r
.50565 .5286 .51119 .53453 .5213 .53162 .51578 .52579 Mtetra
.651 .747 .92 r
.51578 .52579 .5213 .53162 .53144 .52859 .52595 .52278 Mtetra
.654 .75 .92 r
.52595 .52278 .53144 .52859 .54163 .52547 .53616 .51968 Mtetra
.656 .752 .92 r
.53616 .51968 .54163 .52547 .55185 .5223 .5464 .5165 Mtetra
.658 .753 .92 r
.5464 .5165 .55185 .5223 .56211 .51909 .55669 .51328 Mtetra
.659 .754 .92 r
.55669 .51328 .56211 .51909 .57241 .51585 .56701 .51003 Mtetra
.56701 .51003 .57241 .51585 .58274 .5126 .57737 .50675 Mtetra
.57737 .50675 .58274 .5126 .59311 .50934 .58777 .50347 Mtetra
.58777 .50347 .59311 .50934 .60352 .50607 .59821 .50018 Mtetra
.658 .753 .92 r
.59821 .50018 .60352 .50607 .61397 .5028 .60868 .49688 Mtetra
.60868 .49688 .61397 .5028 .62446 .49952 .6192 .49358 Mtetra
.6192 .49358 .62446 .49952 .63499 .49624 .62975 .49027 Mtetra
.62975 .49027 .63499 .49624 .64556 .49294 .64035 .48695 Mtetra
.64035 .48695 .64556 .49294 .65616 .48964 .65098 .48362 Mtetra
.65098 .48362 .65616 .48964 .66681 .48633 .66166 .48028 Mtetra
.657 .753 .92 r
.66166 .48028 .66681 .48633 .6775 .483 .67237 .47694 Mtetra
.67237 .47694 .6775 .483 .68823 .47967 .68313 .47358 Mtetra
.68313 .47358 .68823 .47967 .69899 .47632 .69392 .47021 Mtetra
.69392 .47021 .69899 .47632 .7098 .47297 .70476 .46683 Mtetra
.70476 .46683 .7098 .47297 .72065 .4696 .71564 .46344 Mtetra
.657 .752 .92 r
.71564 .46344 .72065 .4696 .73154 .46622 .72656 .46003 Mtetra
.72656 .46003 .73154 .46622 .74248 .46283 .73752 .45662 Mtetra
.73752 .45662 .74248 .46283 .75345 .45942 .74853 .45319 Mtetra
.74853 .45319 .75345 .45942 .76447 .45601 .75957 .44975 Mtetra
.75957 .44975 .76447 .45601 .77553 .45258 .77066 .44629 Mtetra
.77066 .44629 .77553 .45258 .78663 .44914 .78179 .44283 Mtetra
.78179 .44283 .78663 .44914 .79777 .44569 .79297 .43935 Mtetra
.79297 .43935 .79777 .44569 .80896 .44222 .80419 .43586 Mtetra
.80419 .43586 .80896 .44222 .82019 .43874 .81545 .43236 Mtetra
.81545 .43236 .82019 .43874 .83147 .43525 .82676 .42884 Mtetra
.82676 .42884 .83147 .43525 .84279 .43175 .83811 .42531 Mtetra
.83811 .42531 .84279 .43175 .85415 .42823 .8495 .42177 Mtetra
.8495 .42177 .85415 .42823 .86555 .4247 .86094 .41821 Mtetra
.86094 .41821 .86555 .4247 .87701 .42116 .87242 .41464 Mtetra
.87242 .41464 .87701 .42116 .8885 .4176 .88395 .41106 Mtetra
.88395 .41106 .8885 .4176 .90004 .41403 .89553 .40746 Mtetra
.408 .62 .938 r
.27632 .59353 .28233 .59985 .29253 .58432 .28537 .59484 Mtetra
0 0 0 r
.28537 .59484 .29253 .58432 .3012 .5914 .29525 .5847 Mtetra
.565 .675 .912 r
.29525 .5847 .3012 .5914 .31051 .58977 .30452 .58384 Mtetra
.603 .716 .924 r
.30452 .58384 .31051 .58977 .31984 .58858 .31389 .58211 Mtetra
.312 .567 .929 r
.31389 .58211 .31984 .58858 .32984 .57617 .32306 .58455 Mtetra
0 0 0 r
.32306 .58455 .32984 .57617 .33896 .57979 .33306 .57321 Mtetra
.58 .687 .914 r
.33306 .57321 .33896 .57979 .34843 .57793 .34251 .57201 Mtetra
.615 .723 .922 r
.34251 .57201 .34843 .57793 .35793 .57611 .35204 .56999 Mtetra
.561 .697 .931 r
.35204 .56999 .35793 .57611 .36698 .58502 .36156 .56904 Mtetra
.724 .592 .708 r
.36156 .56904 .36698 .58502 .37729 .5672 .37155 .55884 Mtetra
.5 .598 .883 r
.37155 .55884 .37729 .5672 .3869 .56557 .38106 .55956 Mtetra
.62 .723 .92 r
.38106 .55956 .3869 .56557 .39657 .56329 .39075 .5574 Mtetra
.626 .73 .922 r
.39075 .5574 .39657 .56329 .40627 .56121 .40048 .5551 Mtetra
.581 .707 .929 r
.40048 .5551 .40627 .56121 .41582 .56529 .41021 .55375 Mtetra
.77 .656 .736 r
.41021 .55375 .41582 .56529 .42595 .55191 .42031 .54241 Mtetra
.463 .551 .86 r
.42031 .54241 .42595 .55191 .43575 .55028 .43002 .54419 Mtetra
.625 .725 .919 r
.43002 .54419 .43575 .55028 .44562 .54776 .4399 .54189 Mtetra
.639 .738 .92 r
.4399 .54189 .44562 .54776 .45552 .54509 .44982 .53923 Mtetra
.64 .74 .921 r
.44982 .53923 .45552 .54509 .46546 .54246 .45979 .53653 Mtetra
.632 .735 .922 r
.45979 .53653 .46546 .54246 .47544 .54032 .46979 .53402 Mtetra
.555 .694 .932 r
.46979 .53402 .47544 .54032 .48493 .58262 .47981 .53313 Mtetra
.625 .442 .614 r
.47981 .53313 .48493 .58262 .49556 .53076 .48998 .523 Mtetra
.552 .645 .895 r
.48998 .523 .49556 .53076 .50565 .5286 .50007 .52251 Mtetra
.636 .733 .919 r
.50007 .52251 .50565 .5286 .51578 .52579 .51022 .51987 Mtetra
.648 .745 .92 r
.51022 .51987 .51578 .52579 .52595 .52278 .52041 .51692 Mtetra
.653 .749 .92 r
.52041 .51692 .52595 .52278 .53616 .51968 .53065 .51383 Mtetra
.655 .751 .92 r
.53065 .51383 .53616 .51968 .5464 .5165 .54092 .51066 Mtetra
.657 .752 .92 r
.54092 .51066 .5464 .5165 .55669 .51328 .55123 .50743 Mtetra
.658 .753 .92 r
.55123 .50743 .55669 .51328 .56701 .51003 .56158 .50416 Mtetra
.659 .754 .92 r
.56158 .50416 .56701 .51003 .57737 .50675 .57196 .50087 Mtetra
.57196 .50087 .57737 .50675 .58777 .50347 .58239 .49756 Mtetra
.58239 .49756 .58777 .50347 .59821 .50018 .59285 .49424 Mtetra
.59285 .49424 .59821 .50018 .60868 .49688 .60335 .49092 Mtetra
.658 .753 .92 r
.60335 .49092 .60868 .49688 .6192 .49358 .6139 .48759 Mtetra
.6139 .48759 .6192 .49358 .62975 .49027 .62448 .48425 Mtetra
.62448 .48425 .62975 .49027 .64035 .48695 .6351 .48091 Mtetra
.6351 .48091 .64035 .48695 .65098 .48362 .64576 .47756 Mtetra
.64576 .47756 .65098 .48362 .66166 .48028 .65646 .4742 Mtetra
.65646 .4742 .66166 .48028 .67237 .47694 .66721 .47083 Mtetra
.657 .753 .92 r
.66721 .47083 .67237 .47694 .68313 .47358 .67799 .46744 Mtetra
.67799 .46744 .68313 .47358 .69392 .47021 .68882 .46405 Mtetra
.68882 .46405 .69392 .47021 .70476 .46683 .69968 .46064 Mtetra
.69968 .46064 .70476 .46683 .71564 .46344 .71059 .45723 Mtetra
.657 .752 .92 r
.71059 .45723 .71564 .46344 .72656 .46003 .72154 .4538 Mtetra
.72154 .4538 .72656 .46003 .73752 .45662 .73253 .45036 Mtetra
.73253 .45036 .73752 .45662 .74853 .45319 .74357 .44691 Mtetra
.74357 .44691 .74853 .45319 .75957 .44975 .75464 .44344 Mtetra
.75464 .44344 .75957 .44975 .77066 .44629 .76576 .43996 Mtetra
.76576 .43996 .77066 .44629 .78179 .44283 .77692 .43647 Mtetra
.77692 .43647 .78179 .44283 .79297 .43935 .78813 .43297 Mtetra
.78813 .43297 .79297 .43935 .80419 .43586 .79938 .42945 Mtetra
.79938 .42945 .80419 .43586 .81545 .43236 .81067 .42592 Mtetra
.81067 .42592 .81545 .43236 .82676 .42884 .82201 .42238 Mtetra
.82201 .42238 .82676 .42884 .83811 .42531 .83339 .41883 Mtetra
.83339 .41883 .83811 .42531 .8495 .42177 .84482 .41526 Mtetra
.84482 .41526 .8495 .42177 .86094 .41821 .85629 .41167 Mtetra
.85629 .41167 .86094 .41821 .87242 .41464 .86781 .40808 Mtetra
.86781 .40808 .87242 .41464 .88395 .41106 .87937 .40447 Mtetra
.87937 .40447 .88395 .41106 .89553 .40746 .89098 .40085 Mtetra
.576 .703 .928 r
.27024 .5875 .27632 .59353 .28537 .59484 .27948 .58629 Mtetra
.829 .703 .725 r
.27948 .58629 .28537 .59484 .29525 .5847 .28977 .57065 Mtetra
.262 .339 .755 r
.28977 .57065 .29525 .5847 .30452 .58384 .2985 .57773 Mtetra
.601 .71 .921 r
.2985 .57773 .30452 .58384 .31389 .58211 .30788 .57605 Mtetra
.576 .704 .929 r
.30788 .57605 .31389 .58211 .32306 .58455 .31728 .57483 Mtetra
.796 .683 .74 r
.31728 .57483 .32306 .58455 .33306 .57321 .32738 .56232 Mtetra
.384 .474 .828 r
.32738 .56232 .33306 .57321 .34251 .57201 .33656 .56592 Mtetra
.61 .716 .92 r
.33656 .56592 .34251 .57201 .35204 .56999 .3461 .56401 Mtetra
.606 .719 .925 r
.3461 .56401 .35204 .56999 .36156 .56904 .35568 .56215 Mtetra
0 .071 .598 r
.35568 .56215 .36156 .56904 .37155 .55884 .3648 .57107 Mtetra
0 0 0 r
.3648 .57107 .37155 .55884 .38106 .55956 .3752 .55313 Mtetra
.599 .703 .916 r
.3752 .55313 .38106 .55956 .39075 .5574 .38489 .55146 Mtetra
.627 .73 .921 r
.38489 .55146 .39075 .5574 .40048 .5551 .39464 .54912 Mtetra
.616 .726 .924 r
.39464 .54912 .40048 .5551 .41021 .55375 .40442 .547 Mtetra
.178 .481 .897 r
.40442 .547 .41021 .55375 .42031 .54241 .41404 .55105 Mtetra
0 0 0 r
.41404 .55105 .42031 .54241 .43002 .54419 .42426 .53758 Mtetra
.598 .699 .914 r
.42426 .53758 .43002 .54419 .4399 .54189 .43414 .5359 Mtetra
.634 .734 .92 r
.43414 .5359 .4399 .54189 .44982 .53923 .44409 .53333 Mtetra
.64 .74 .921 r
.44409 .53333 .44982 .53923 .45979 .53653 .45407 .53061 Mtetra
.638 .739 .922 r
.45407 .53061 .45979 .53653 .46979 .53402 .4641 .52793 Mtetra
.616 .726 .925 r
.4641 .52793 .46979 .53402 .47981 .53313 .47416 .52574 Mtetra
.948 .59 .257 r
.47416 .52574 .47981 .53313 .48998 .523 .48372 .56818 Mtetra
0 0 .167 r
.48372 .56818 .48998 .523 .50007 .52251 .49445 .51605 Mtetra
.618 .716 .916 r
.49445 .51605 .50007 .52251 .51022 .51987 .50463 .51385 Mtetra
.644 .741 .92 r
.50463 .51385 .51022 .51987 .52041 .51692 .51484 .51098 Mtetra
.651 .747 .92 r
.51484 .51098 .52041 .51692 .53065 .51383 .5251 .50792 Mtetra
.654 .75 .92 r
.5251 .50792 .53065 .51383 .54092 .51066 .5354 .50476 Mtetra
.656 .752 .92 r
.5354 .50476 .54092 .51066 .55123 .50743 .54573 .50153 Mtetra
.658 .753 .92 r
.54573 .50153 .55123 .50743 .56158 .50416 .55611 .49825 Mtetra
.659 .754 .92 r
.55611 .49825 .56158 .50416 .57196 .50087 .56652 .49494 Mtetra
.56652 .49494 .57196 .50087 .58239 .49756 .57697 .49161 Mtetra
.57697 .49161 .58239 .49756 .59285 .49424 .58746 .48827 Mtetra
.58746 .48827 .59285 .49424 .60335 .49092 .59799 .48492 Mtetra
.658 .753 .92 r
.59799 .48492 .60335 .49092 .6139 .48759 .60856 .48156 Mtetra
.60856 .48156 .6139 .48759 .62448 .48425 .61917 .4782 Mtetra
.61917 .4782 .62448 .48425 .6351 .48091 .62982 .47483 Mtetra
.62982 .47483 .6351 .48091 .64576 .47756 .64051 .47146 Mtetra
.64051 .47146 .64576 .47756 .65646 .4742 .65124 .46807 Mtetra
.65124 .46807 .65646 .4742 .66721 .47083 .66201 .46467 Mtetra
.657 .753 .92 r
.66201 .46467 .66721 .47083 .67799 .46744 .67282 .46127 Mtetra
.67282 .46127 .67799 .46744 .68882 .46405 .68367 .45785 Mtetra
.68367 .45785 .68882 .46405 .69968 .46064 .69457 .45442 Mtetra
.69457 .45442 .69968 .46064 .71059 .45723 .7055 .45098 Mtetra
.7055 .45098 .71059 .45723 .72154 .4538 .71648 .44752 Mtetra
.657 .752 .92 r
.71648 .44752 .72154 .4538 .73253 .45036 .7275 .44406 Mtetra
.7275 .44406 .73253 .45036 .74357 .44691 .73857 .44058 Mtetra
.73857 .44058 .74357 .44691 .75464 .44344 .74968 .43709 Mtetra
.74968 .43709 .75464 .44344 .76576 .43996 .76083 .43359 Mtetra
.76083 .43359 .76576 .43996 .77692 .43647 .77202 .43007 Mtetra
.77202 .43007 .77692 .43647 .78813 .43297 .78326 .42654 Mtetra
.78326 .42654 .78813 .43297 .79938 .42945 .79454 .423 Mtetra
.79454 .423 .79938 .42945 .81067 .42592 .80586 .41944 Mtetra
.80586 .41944 .81067 .42592 .82201 .42238 .81723 .41588 Mtetra
.81723 .41588 .82201 .42238 .83339 .41883 .82864 .41229 Mtetra
.82864 .41229 .83339 .41883 .84482 .41526 .8401 .4087 Mtetra
.8401 .4087 .84482 .41526 .85629 .41167 .85161 .40509 Mtetra
.85161 .40509 .85629 .41167 .86781 .40808 .86316 .40147 Mtetra
.86316 .40147 .86781 .40808 .87937 .40447 .87475 .39783 Mtetra
.87475 .39783 .87937 .40447 .89098 .40085 .88639 .39418 Mtetra
.594 .708 .923 r
.26413 .58142 .27024 .5875 .27948 .58629 .27341 .57987 Mtetra
.408 .62 .938 r
.27341 .57987 .27948 .58629 .28977 .57065 .28253 .58116 Mtetra
0 0 0 r
.28253 .58116 .28977 .57065 .2985 .57773 .29249 .57093 Mtetra
.565 .675 .912 r
.29249 .57093 .2985 .57773 .30788 .57605 .30183 .57003 Mtetra
.603 .716 .924 r
.30183 .57003 .30788 .57605 .31728 .57483 .31128 .56826 Mtetra
.314 .567 .929 r
.31128 .56826 .31728 .57483 .32738 .56232 .32051 .57067 Mtetra
0 0 0 r
.32051 .57067 .32738 .56232 .33656 .56592 .3306 .55925 Mtetra
.58 .687 .914 r
.3306 .55925 .33656 .56592 .3461 .56401 .34012 .55801 Mtetra
.615 .723 .922 r
.34012 .55801 .3461 .56401 .35568 .56215 .34973 .55594 Mtetra
.561 .697 .931 r
.34973 .55594 .35568 .56215 .3648 .57107 .35933 .55494 Mtetra
.724 .592 .708 r
.35933 .55494 .3648 .57107 .3752 .55313 .3694 .54466 Mtetra
.5 .598 .883 r
.3694 .54466 .3752 .55313 .38489 .55146 .37899 .54535 Mtetra
.62 .723 .92 r
.37899 .54535 .38489 .55146 .39464 .54912 .38876 .54314 Mtetra
.626 .73 .922 r
.38876 .54314 .39464 .54912 .40442 .547 .39857 .54079 Mtetra
.581 .707 .929 r
.39857 .54079 .40442 .547 .41404 .55105 .40838 .53939 Mtetra
.771 .656 .736 r
.40838 .53939 .41404 .55105 .42426 .53758 .41856 .52797 Mtetra
.463 .551 .86 r
.41856 .52797 .42426 .53758 .43414 .5359 .42835 .52971 Mtetra
.625 .725 .919 r
.42835 .52971 .43414 .5359 .44409 .53333 .43831 .52736 Mtetra
.639 .738 .92 r
.43831 .52736 .44409 .53333 .45407 .53061 .44832 .52465 Mtetra
.64 .74 .921 r
.44832 .52465 .45407 .53061 .4641 .52793 .45837 .5219 Mtetra
.632 .735 .922 r
.45837 .5219 .4641 .52793 .47416 .52574 .46846 .51933 Mtetra
.555 .694 .932 r
.46846 .51933 .47416 .52574 .48372 .56818 .47856 .5184 Mtetra
.624 .44 .613 r
.47856 .5184 .48372 .56818 .49445 .51605 .48882 .50819 Mtetra
.551 .645 .896 r
.48882 .50819 .49445 .51605 .50463 .51385 .49899 .50766 Mtetra
.636 .733 .919 r
.49899 .50766 .50463 .51385 .51484 .51098 .50923 .50496 Mtetra
.648 .745 .92 r
.50923 .50496 .51484 .51098 .5251 .50792 .51952 .50195 Mtetra
.653 .749 .92 r
.51952 .50195 .5251 .50792 .5354 .50476 .52984 .49881 Mtetra
.655 .751 .92 r
.52984 .49881 .5354 .50476 .54573 .50153 .5402 .49558 Mtetra
.657 .752 .92 r
.5402 .49558 .54573 .50153 .55611 .49825 .5506 .4923 Mtetra
.658 .753 .92 r
.5506 .4923 .55611 .49825 .56652 .49494 .56104 .48897 Mtetra
.659 .754 .92 r
.56104 .48897 .56652 .49494 .57697 .49161 .57151 .48562 Mtetra
.57151 .48562 .57697 .49161 .58746 .48827 .58203 .48225 Mtetra
.58203 .48225 .58746 .48827 .59799 .48492 .59259 .47888 Mtetra
.59259 .47888 .59799 .48492 .60856 .48156 .60318 .4755 Mtetra
.658 .753 .92 r
.60318 .4755 .60856 .48156 .61917 .4782 .61382 .47211 Mtetra
.61382 .47211 .61917 .4782 .62982 .47483 .6245 .46871 Mtetra
.6245 .46871 .62982 .47483 .64051 .47146 .63521 .46531 Mtetra
.63521 .46531 .64051 .47146 .65124 .46807 .64597 .4619 Mtetra
.64597 .4619 .65124 .46807 .66201 .46467 .65677 .45848 Mtetra
.65677 .45848 .66201 .46467 .67282 .46127 .66761 .45504 Mtetra
.657 .753 .92 r
.66761 .45504 .67282 .46127 .68367 .45785 .67849 .4516 Mtetra
.67849 .4516 .68367 .45785 .69457 .45442 .68942 .44815 Mtetra
.68942 .44815 .69457 .45442 .7055 .45098 .70038 .44468 Mtetra
.70038 .44468 .7055 .45098 .71648 .44752 .71139 .4412 Mtetra
.657 .752 .92 r
.71139 .4412 .71648 .44752 .7275 .44406 .72244 .43771 Mtetra
.72244 .43771 .7275 .44406 .73857 .44058 .73354 .43421 Mtetra
.73354 .43421 .73857 .44058 .74968 .43709 .74467 .43069 Mtetra
.74467 .43069 .74968 .43709 .76083 .43359 .75585 .42716 Mtetra
.75585 .42716 .76083 .43359 .77202 .43007 .76708 .42362 Mtetra
.76708 .42362 .77202 .43007 .78326 .42654 .77835 .42007 Mtetra
.77835 .42007 .78326 .42654 .79454 .423 .78966 .4165 Mtetra
.78966 .4165 .79454 .423 .80586 .41944 .80101 .41292 Mtetra
.80101 .41292 .80586 .41944 .81723 .41588 .81242 .40932 Mtetra
.81242 .40932 .81723 .41588 .82864 .41229 .82386 .40572 Mtetra
.82386 .40572 .82864 .41229 .8401 .4087 .83535 .40209 Mtetra
.83535 .40209 .8401 .4087 .85161 .40509 .84689 .39846 Mtetra
.84689 .39846 .85161 .40509 .86316 .40147 .85847 .39481 Mtetra
.85847 .39481 .86316 .40147 .87475 .39783 .8701 .39115 Mtetra
.8701 .39115 .87475 .39783 .88639 .39418 .88178 .38747 Mtetra
.574 .687 .917 r
.25801 .57488 .26413 .58142 .27341 .57987 .26727 .57375 Mtetra
.576 .703 .928 r
.26727 .57375 .27341 .57987 .28253 .58116 .27658 .5725 Mtetra
.83 .704 .726 r
.27658 .5725 .28253 .58116 .29249 .57093 .28696 .55676 Mtetra
.26 .338 .754 r
.28696 .55676 .29249 .57093 .30183 .57003 .29575 .56383 Mtetra
.6 .71 .921 r
.29575 .56383 .30183 .57003 .31128 .56826 .30521 .56211 Mtetra
.576 .704 .929 r
.30521 .56211 .31128 .56826 .32051 .57067 .31468 .56084 Mtetra
.797 .684 .74 r
.31468 .56084 .32051 .57067 .3306 .55925 .32486 .54824 Mtetra
.383 .473 .828 r
.32486 .54824 .3306 .55925 .34012 .55801 .33412 .55182 Mtetra
.61 .716 .92 r
.33412 .55182 .34012 .55801 .34973 .55594 .34374 .54986 Mtetra
.606 .719 .925 r
.34374 .54986 .34973 .55594 .35933 .55494 .35339 .54795 Mtetra
0 .076 .604 r
.35339 .54795 .35933 .55494 .3694 .54466 .36257 .55687 Mtetra
0 0 0 r
.36257 .55687 .3694 .54466 .37899 .54535 .37308 .53882 Mtetra
.599 .703 .916 r
.37308 .53882 .37899 .54535 .38876 .54314 .38284 .5371 Mtetra
.627 .73 .921 r
.38284 .5371 .38876 .54314 .39857 .54079 .39267 .53471 Mtetra
.616 .726 .924 r
.39267 .53471 .39857 .54079 .40838 .53939 .40253 .53254 Mtetra
.181 .482 .898 r
.40253 .53254 .40838 .53939 .41856 .52797 .41223 .53657 Mtetra
0 0 0 r
.41223 .53657 .41856 .52797 .42835 .52971 .42254 .523 Mtetra
.598 .699 .914 r
.42254 .523 .42835 .52971 .43831 .52736 .4325 .52127 Mtetra
.634 .734 .92 r
.4325 .52127 .43831 .52736 .44832 .52465 .44253 .51865 Mtetra
.64 .74 .921 r
.44253 .51865 .44832 .52465 .45837 .5219 .4526 .51587 Mtetra
.638 .739 .922 r
.4526 .51587 .45837 .5219 .46846 .51933 .46271 .51314 Mtetra
.616 .726 .925 r
.46271 .51314 .46846 .51933 .47856 .5184 .47286 .51091 Mtetra
.947 .588 .251 r
.47286 .51091 .47856 .5184 .48882 .50819 .48248 .55349 Mtetra
0 0 .16 r
.48248 .55349 .48882 .50819 .49899 .50766 .49333 .50109 Mtetra
.618 .716 .916 r
.49333 .50109 .49899 .50766 .50923 .50496 .50359 .49884 Mtetra
.644 .741 .92 r
.50359 .49884 .50923 .50496 .51952 .50195 .51389 .49591 Mtetra
.651 .747 .92 r
.51389 .49591 .51952 .50195 .52984 .49881 .52424 .4928 Mtetra
.654 .75 .92 r
.52424 .4928 .52984 .49881 .5402 .49558 .53463 .48958 Mtetra
.656 .752 .92 r
.53463 .48958 .5402 .49558 .5506 .4923 .54505 .48629 Mtetra
.658 .753 .92 r
.54505 .48629 .5506 .4923 .56104 .48897 .55552 .48296 Mtetra
.659 .754 .92 r
.55552 .48296 .56104 .48897 .57151 .48562 .56602 .47959 Mtetra
.56602 .47959 .57151 .48562 .58203 .48225 .57656 .4762 Mtetra
.57656 .4762 .58203 .48225 .59259 .47888 .58715 .4728 Mtetra
.58715 .4728 .59259 .47888 .60318 .4755 .59777 .46939 Mtetra
.658 .753 .92 r
.59777 .46939 .60318 .4755 .61382 .47211 .60843 .46597 Mtetra
.60843 .46597 .61382 .47211 .6245 .46871 .61914 .46255 Mtetra
.61914 .46255 .6245 .46871 .63521 .46531 .62988 .45912 Mtetra
.62988 .45912 .63521 .46531 .64597 .4619 .64067 .45569 Mtetra
.64067 .45569 .64597 .4619 .65677 .45848 .6515 .45224 Mtetra
.6515 .45224 .65677 .45848 .66761 .45504 .66236 .44878 Mtetra
.657 .753 .92 r
.66236 .44878 .66761 .45504 .67849 .4516 .67328 .44531 Mtetra
.67328 .44531 .67849 .4516 .68942 .44815 .68423 .44183 Mtetra
.68423 .44183 .68942 .44815 .70038 .44468 .69522 .43834 Mtetra
.69522 .43834 .70038 .44468 .71139 .4412 .70626 .43483 Mtetra
.70626 .43483 .71139 .4412 .72244 .43771 .71734 .43132 Mtetra
.657 .752 .92 r
.71734 .43132 .72244 .43771 .73354 .43421 .72847 .42779 Mtetra
.72847 .42779 .73354 .43421 .74467 .43069 .73963 .42425 Mtetra
.73963 .42425 .74467 .43069 .75585 .42716 .75085 .42069 Mtetra
.75085 .42069 .75585 .42716 .76708 .42362 .7621 .41713 Mtetra
.7621 .41713 .76708 .42362 .77835 .42007 .7734 .41355 Mtetra
.7734 .41355 .77835 .42007 .78966 .4165 .78474 .40995 Mtetra
.78474 .40995 .78966 .4165 .80101 .41292 .79613 .40634 Mtetra
.79613 .40634 .80101 .41292 .81242 .40932 .80757 .40272 Mtetra
.80757 .40272 .81242 .40932 .82386 .40572 .81904 .39909 Mtetra
.81904 .39909 .82386 .40572 .83535 .40209 .83057 .39544 Mtetra
.83057 .39544 .83535 .40209 .84689 .39846 .84214 .39178 Mtetra
.84214 .39178 .84689 .39846 .85847 .39481 .85375 .3881 Mtetra
.85375 .3881 .85847 .39481 .8701 .39115 .86542 .38441 Mtetra
.86542 .38441 .8701 .39115 .88178 .38747 .87712 .38071 Mtetra
.423 .529 .861 r
.25209 .56533 .25801 .57488 .26727 .57375 .26109 .56758 Mtetra
.594 .708 .923 r
.26109 .56758 .26727 .57375 .27658 .5725 .27045 .56599 Mtetra
.409 .62 .938 r
.27045 .56599 .27658 .5725 .28696 .55676 .27963 .56724 Mtetra
0 0 0 r
.27963 .56724 .28696 .55676 .29575 .56383 .28968 .55693 Mtetra
.565 .675 .913 r
.28968 .55693 .29575 .56383 .30521 .56211 .2991 .55599 Mtetra
.603 .716 .924 r
.2991 .55599 .30521 .56211 .31468 .56084 .30862 .55417 Mtetra
.316 .568 .929 r
.30862 .55417 .31468 .56084 .32486 .54824 .31792 .55656 Mtetra
0 0 0 r
.31792 .55656 .32486 .54824 .33412 .55182 .3281 .54505 Mtetra
.58 .687 .914 r
.3281 .54505 .33412 .55182 .34374 .54986 .3377 .54376 Mtetra
.615 .723 .922 r
.3377 .54376 .34374 .54986 .35339 .54795 .34739 .54164 Mtetra
.561 .697 .931 r
.34739 .54164 .35339 .54795 .36257 .55687 .35706 .5406 Mtetra
.724 .592 .708 r
.35706 .5406 .36257 .55687 .37308 .53882 .36722 .53024 Mtetra
.499 .598 .883 r
.36722 .53024 .37308 .53882 .38284 .5371 .37689 .53089 Mtetra
.62 .723 .92 r
.37689 .53089 .38284 .5371 .39267 .53471 .38673 .52863 Mtetra
.626 .73 .922 r
.38673 .52863 .39267 .53471 .40253 .53254 .39662 .52623 Mtetra
.581 .707 .929 r
.39662 .52623 .40253 .53254 .41223 .53657 .40652 .52478 Mtetra
.771 .657 .737 r
.40652 .52478 .41223 .53657 .42254 .523 .41679 .51327 Mtetra
.462 .551 .861 r
.41679 .51327 .42254 .523 .4325 .52127 .42666 .51498 Mtetra
.625 .725 .919 r
.42666 .51498 .4325 .52127 .44253 .51865 .4367 .51258 Mtetra
.639 .738 .92 r
.4367 .51258 .44253 .51865 .4526 .51587 .4468 .50982 Mtetra
.64 .74 .921 r
.4468 .50982 .4526 .51587 .46271 .51314 .45693 .50701 Mtetra
.632 .735 .922 r
.45693 .50701 .46271 .51314 .47286 .51091 .4671 .50439 Mtetra
.555 .694 .932 r
.4671 .50439 .47286 .51091 .48248 .55349 .47729 .50342 Mtetra
.623 .438 .611 r
.47729 .50342 .48248 .55349 .49333 .50109 .48764 .49312 Mtetra
.551 .645 .896 r
.48764 .49312 .49333 .50109 .50359 .49884 .4979 .49254 Mtetra
.636 .733 .919 r
.4979 .49254 .50359 .49884 .51389 .49591 .50823 .48979 Mtetra
.648 .745 .92 r
.50823 .48979 .51389 .49591 .52424 .4928 .5186 .48672 Mtetra
.653 .749 .92 r
.5186 .48672 .52424 .4928 .53463 .48958 .52901 .48352 Mtetra
.655 .751 .92 r
.52901 .48352 .53463 .48958 .54505 .48629 .53946 .48024 Mtetra
.657 .752 .92 r
.53946 .48024 .54505 .48629 .55552 .48296 .54996 .47689 Mtetra
.658 .753 .92 r
.54996 .47689 .55552 .48296 .56602 .47959 .56049 .47351 Mtetra
.659 .754 .92 r
.56049 .47351 .56602 .47959 .57656 .4762 .57106 .4701 Mtetra
.57106 .4701 .57656 .4762 .58715 .4728 .58167 .46667 Mtetra
.58167 .46667 .58715 .4728 .59777 .46939 .59232 .46324 Mtetra
.59232 .46324 .59777 .46939 .60843 .46597 .60301 .4598 Mtetra
.658 .753 .92 r
.60301 .4598 .60843 .46597 .61914 .46255 .61374 .45635 Mtetra
.61374 .45635 .61914 .46255 .62988 .45912 .62451 .45289 Mtetra
.62451 .45289 .62988 .45912 .64067 .45569 .63533 .44943 Mtetra
.63533 .44943 .64067 .45569 .6515 .45224 .64618 .44595 Mtetra
.64618 .44595 .6515 .45224 .66236 .44878 .65708 .44247 Mtetra
.65708 .44247 .66236 .44878 .67328 .44531 .66802 .43898 Mtetra
.657 .753 .92 r
.66802 .43898 .67328 .44531 .68423 .44183 .679 .43547 Mtetra
.679 .43547 .68423 .44183 .69522 .43834 .69003 .43195 Mtetra
.69003 .43195 .69522 .43834 .70626 .43483 .7011 .42842 Mtetra
.7011 .42842 .70626 .43483 .71734 .43132 .71221 .42488 Mtetra
.657 .752 .92 r
.71221 .42488 .71734 .43132 .72847 .42779 .72336 .42132 Mtetra
.72336 .42132 .72847 .42779 .73963 .42425 .73456 .41776 Mtetra
.73456 .41776 .73963 .42425 .75085 .42069 .7458 .41418 Mtetra
.7458 .41418 .75085 .42069 .7621 .41713 .75709 .41058 Mtetra
.75709 .41058 .7621 .41713 .7734 .41355 .76842 .40698 Mtetra
.76842 .40698 .7734 .41355 .78474 .40995 .77979 .40336 Mtetra
.77979 .40336 .78474 .40995 .79613 .40634 .79121 .39972 Mtetra
.79121 .39972 .79613 .40634 .80757 .40272 .80268 .39607 Mtetra
.80268 .39607 .80757 .40272 .81904 .39909 .81419 .39241 Mtetra
.81419 .39241 .81904 .39909 .83057 .39544 .82575 .38874 Mtetra
.82575 .38874 .83057 .39544 .84214 .39178 .83735 .38505 Mtetra
.83735 .38505 .84214 .39178 .85375 .3881 .849 .38135 Mtetra
.849 .38135 .85375 .3881 .86542 .38441 .8607 .37763 Mtetra
.8607 .37763 .86542 .38441 .87712 .38071 .87244 .3739 Mtetra
.635 .873 .518 r
.24466 .57381 .25209 .56533 .26109 .56758 .25491 .56094 Mtetra
.574 .687 .917 r
.25491 .56094 .26109 .56758 .27045 .56599 .26425 .55977 Mtetra
.576 .703 .928 r
.26425 .55977 .27045 .56599 .27963 .56724 .27363 .55848 Mtetra
.83 .705 .726 r
.27363 .55848 .27963 .56724 .28968 .55693 .2841 .54263 Mtetra
.257 .336 .754 r
.2841 .54263 .28968 .55693 .2991 .55599 .29296 .54969 Mtetra
.6 .71 .921 r
.29296 .54969 .2991 .55599 .30862 .55417 .30249 .54792 Mtetra
.576 .704 .929 r
.30249 .54792 .30862 .55417 .31792 .55656 .31204 .54661 Mtetra
.797 .685 .74 r
.31204 .54661 .31792 .55656 .3281 .54505 .32231 .53392 Mtetra
.382 .473 .828 r
.32231 .53392 .3281 .54505 .3377 .54376 .33163 .53747 Mtetra
.61 .716 .92 r
.33163 .53747 .3377 .54376 .34739 .54164 .34133 .53547 Mtetra
.606 .719 .925 r
.34133 .53547 .34739 .54164 .35706 .5406 .35107 .53351 Mtetra
0 .082 .61 r
.35107 .53351 .35706 .5406 .36722 .53024 .36031 .54243 Mtetra
0 0 0 r
.36031 .54243 .36722 .53024 .37689 .53089 .37091 .52426 Mtetra
.599 .703 .916 r
.37091 .52426 .37689 .53089 .38673 .52863 .38075 .52249 Mtetra
.627 .73 .921 r
.38075 .52249 .38673 .52863 .39662 .52623 .39067 .52005 Mtetra
.616 .726 .924 r
.39067 .52005 .39662 .52623 .40652 .52478 .40061 .51783 Mtetra
.184 .484 .898 r
.40061 .51783 .40652 .52478 .41679 .51327 .41038 .52184 Mtetra
0 0 0 r
.41038 .52184 .41679 .51327 .42666 .51498 .42079 .50817 Mtetra
.598 .699 .914 r
.42079 .50817 .42666 .51498 .4367 .51258 .43083 .50639 Mtetra
.634 .734 .92 r
.43083 .50639 .4367 .51258 .4468 .50982 .44095 .50371 Mtetra
.64 .74 .921 r
.44095 .50371 .4468 .50982 .45693 .50701 .45111 .50088 Mtetra
.638 .739 .922 r
.45111 .50088 .45693 .50701 .4671 .50439 .4613 .4981 Mtetra
.616 .726 .925 r
.4613 .4981 .4671 .50439 .47729 .50342 .47153 .49581 Mtetra
.946 .586 .245 r
.47153 .49581 .47729 .50342 .48764 .49312 .48122 .53854 Mtetra
0 0 .153 r
.48122 .53854 .48764 .49312 .4979 .49254 .49218 .48586 Mtetra
.618 .716 .916 r
.49218 .48586 .4979 .49254 .50823 .48979 .50253 .48356 Mtetra
.644 .741 .92 r
.50253 .48356 .50823 .48979 .5186 .48672 .51292 .48058 Mtetra
.651 .747 .92 r
.51292 .48058 .5186 .48672 .52901 .48352 .52336 .4774 Mtetra
.654 .75 .92 r
.52336 .4774 .52901 .48352 .53946 .48024 .53384 .47412 Mtetra
.656 .752 .92 r
.53384 .47412 .53946 .48024 .54996 .47689 .54436 .47078 Mtetra
.658 .753 .92 r
.54436 .47078 .54996 .47689 .56049 .47351 .55491 .46739 Mtetra
.659 .754 .92 r
.55491 .46739 .56049 .47351 .57106 .4701 .56551 .46396 Mtetra
.56551 .46396 .57106 .4701 .58167 .46667 .57615 .46051 Mtetra
.57615 .46051 .58167 .46667 .59232 .46324 .58683 .45704 Mtetra
.58683 .45704 .59232 .46324 .60301 .4598 .59755 .45358 Mtetra
.658 .753 .92 r
.59755 .45358 .60301 .4598 .61374 .45635 .6083 .4501 Mtetra
.6083 .4501 .61374 .45635 .62451 .45289 .61911 .44662 Mtetra
.61911 .44662 .62451 .45289 .63533 .44943 .62995 .44313 Mtetra
.62995 .44313 .63533 .44943 .64618 .44595 .64083 .43963 Mtetra
.64083 .43963 .64618 .44595 .65708 .44247 .65176 .43612 Mtetra
.65176 .43612 .65708 .44247 .66802 .43898 .66273 .4326 Mtetra
.657 .753 .92 r
.66273 .4326 .66802 .43898 .679 .43547 .67374 .42906 Mtetra
.67374 .42906 .679 .43547 .69003 .43195 .68479 .42552 Mtetra
.68479 .42552 .69003 .43195 .7011 .42842 .69589 .42196 Mtetra
.69589 .42196 .7011 .42842 .71221 .42488 .70703 .4184 Mtetra
.70703 .4184 .71221 .42488 .72336 .42132 .71822 .41481 Mtetra
.657 .752 .92 r
.71822 .41481 .72336 .42132 .73456 .41776 .72945 .41122 Mtetra
.72945 .41122 .73456 .41776 .7458 .41418 .74072 .40761 Mtetra
.74072 .40761 .7458 .41418 .75709 .41058 .75204 .40399 Mtetra
.75204 .40399 .75709 .41058 .76842 .40698 .7634 .40036 Mtetra
.7634 .40036 .76842 .40698 .77979 .40336 .77481 .39671 Mtetra
.77481 .39671 .77979 .40336 .79121 .39972 .78626 .39305 Mtetra
.78626 .39305 .79121 .39972 .80268 .39607 .79776 .38938 Mtetra
.79776 .38938 .80268 .39607 .81419 .39241 .8093 .38569 Mtetra
.8093 .38569 .81419 .39241 .82575 .38874 .82089 .38199 Mtetra
.82089 .38199 .82575 .38874 .83735 .38505 .83253 .37827 Mtetra
.83253 .37827 .83735 .38505 .849 .38135 .84421 .37454 Mtetra
.84421 .37454 .849 .38135 .8607 .37763 .85594 .37079 Mtetra
.85594 .37079 .8607 .37763 .87244 .3739 .86772 .36703 Mtetra
.766 .653 .737 r
.23881 .56234 .24466 .57381 .25491 .56094 .24894 .55128 Mtetra
.422 .529 .861 r
.24894 .55128 .25491 .56094 .26425 .55977 .25801 .5535 Mtetra
.594 .708 .923 r
.25801 .5535 .26425 .55977 .27363 .55848 .26743 .55186 Mtetra
.41 .62 .938 r
.26743 .55186 .27363 .55848 .2841 .54263 .27669 .55308 Mtetra
0 0 0 r
.27669 .55308 .2841 .54263 .29296 .54969 .28683 .54269 Mtetra
.565 .675 .913 r
.28683 .54269 .29296 .54969 .30249 .54792 .29632 .5417 Mtetra
.603 .716 .924 r
.29632 .5417 .30249 .54792 .31204 .54661 .30591 .53984 Mtetra
.317 .568 .929 r
.30591 .53984 .31204 .54661 .32231 .53392 .31529 .5422 Mtetra
0 0 0 r
.31529 .5422 .32231 .53392 .33163 .53747 .32556 .5306 Mtetra
.58 .687 .914 r
.32556 .5306 .33163 .53747 .34133 .53547 .33523 .52926 Mtetra
.615 .723 .922 r
.33523 .52926 .34133 .53547 .35107 .53351 .345 .5271 Mtetra
.562 .697 .931 r
.345 .5271 .35107 .53351 .36031 .54243 .35475 .52601 Mtetra
.724 .592 .708 r
.35475 .52601 .36031 .54243 .37091 .52426 .365 .51556 Mtetra
.499 .598 .883 r
.365 .51556 .37091 .52426 .38075 .52249 .37474 .51618 Mtetra
.62 .723 .92 r
.37474 .51618 .38075 .52249 .39067 .52005 .38467 .51387 Mtetra
.626 .73 .922 r
.38467 .51387 .39067 .52005 .40061 .51783 .39464 .51142 Mtetra
.581 .707 .929 r
.39464 .51142 .40061 .51783 .41038 .52184 .40462 .50992 Mtetra
.771 .657 .737 r
.40462 .50992 .41038 .52184 .42079 .50817 .41498 .49832 Mtetra
.462 .55 .861 r
.41498 .49832 .42079 .50817 .43083 .50639 .42493 .5 Mtetra
.625 .725 .919 r
.42493 .5 .43083 .50639 .44095 .50371 .43506 .49754 Mtetra
.639 .738 .92 r
.43506 .49754 .44095 .50371 .45111 .50088 .44524 .49472 Mtetra
.64 .74 .921 r
.44524 .49472 .45111 .50088 .4613 .4981 .45546 .49186 Mtetra
.632 .735 .922 r
.45546 .49186 .4613 .4981 .47153 .49581 .46572 .48919 Mtetra
.556 .694 .932 r
.46572 .48919 .47153 .49581 .48122 .53854 .476 .48816 Mtetra
.622 .437 .61 r
.476 .48816 .48122 .53854 .49218 .48586 .48644 .47778 Mtetra
.551 .645 .896 r
.48644 .47778 .49218 .48586 .50253 .48356 .49679 .47715 Mtetra
.636 .734 .919 r
.49679 .47715 .50253 .48356 .51292 .48058 .50721 .47435 Mtetra
.648 .745 .92 r
.50721 .47435 .51292 .48058 .52336 .4774 .51767 .47122 Mtetra
.653 .749 .92 r
.51767 .47122 .52336 .4774 .53384 .47412 .52817 .46796 Mtetra
.655 .751 .92 r
.52817 .46796 .53384 .47412 .54436 .47078 .53872 .46461 Mtetra
.657 .752 .92 r
.53872 .46461 .54436 .47078 .55491 .46739 .5493 .46121 Mtetra
.658 .753 .92 r
.5493 .46121 .55491 .46739 .56551 .46396 .55993 .45777 Mtetra
.659 .754 .92 r
.55993 .45777 .56551 .46396 .57615 .46051 .57059 .4543 Mtetra
.57059 .4543 .57615 .46051 .58683 .45704 .5813 .45081 Mtetra
.5813 .45081 .58683 .45704 .59755 .45358 .59204 .44731 Mtetra
.59204 .44731 .59755 .45358 .6083 .4501 .60283 .44381 Mtetra
.658 .753 .92 r
.60283 .44381 .6083 .4501 .61911 .44662 .61366 .4403 Mtetra
.61366 .4403 .61911 .44662 .62995 .44313 .62453 .43678 Mtetra
.62453 .43678 .62995 .44313 .64083 .43963 .63544 .43325 Mtetra
.63544 .43325 .64083 .43963 .65176 .43612 .6464 .42972 Mtetra
.6464 .42972 .65176 .43612 .66273 .4326 .6574 .42617 Mtetra
.6574 .42617 .66273 .4326 .67374 .42906 .66844 .42261 Mtetra
.657 .753 .92 r
.66844 .42261 .67374 .42906 .68479 .42552 .67952 .41904 Mtetra
.67952 .41904 .68479 .42552 .69589 .42196 .69065 .41546 Mtetra
.69065 .41546 .69589 .42196 .70703 .4184 .70182 .41186 Mtetra
.70182 .41186 .70703 .4184 .71822 .41481 .71304 .40826 Mtetra
.657 .752 .92 r
.71304 .40826 .71822 .41481 .72945 .41122 .7243 .40464 Mtetra
.7243 .40464 .72945 .41122 .74072 .40761 .7356 .401 Mtetra
.7356 .401 .74072 .40761 .75204 .40399 .74695 .39735 Mtetra
.74695 .39735 .75204 .40399 .7634 .40036 .75835 .39369 Mtetra
.75835 .39369 .7634 .40036 .77481 .39671 .76978 .39002 Mtetra
.76978 .39002 .77481 .39671 .78626 .39305 .78127 .38633 Mtetra
.78127 .38633 .78626 .39305 .79776 .38938 .7928 .38263 Mtetra
.7928 .38263 .79776 .38938 .8093 .38569 .80438 .37891 Mtetra
.80438 .37891 .8093 .38569 .82089 .38199 .816 .37518 Mtetra
.816 .37518 .82089 .38199 .83253 .37827 .82767 .37144 Mtetra
.82767 .37144 .83253 .37827 .84421 .37454 .83939 .36768 Mtetra
.83939 .36768 .84421 .37454 .85594 .37079 .85115 .36391 Mtetra
.85115 .36391 .85594 .37079 .86772 .36703 .86296 .36012 Mtetra
.096 .437 .876 r
.23254 .55548 .23881 .56234 .24894 .55128 .24142 .55972 Mtetra
.645 .881 .528 r
.24142 .55972 .24894 .55128 .25801 .5535 .25177 .54676 Mtetra
.574 .687 .917 r
.25177 .54676 .25801 .5535 .26743 .55186 .26117 .54555 Mtetra
.577 .703 .928 r
.26117 .54555 .26743 .55186 .27669 .55308 .27063 .54421 Mtetra
.831 .706 .726 r
.27063 .54421 .27669 .55308 .28683 .54269 .2812 .52825 Mtetra
.255 .335 .754 r
.2812 .52825 .28683 .54269 .29632 .5417 .29012 .53531 Mtetra
.6 .71 .921 r
.29012 .53531 .29632 .5417 .30591 .53984 .29973 .53349 Mtetra
.576 .704 .929 r
.29973 .53349 .30591 .53984 .31529 .5422 .30935 .53213 Mtetra
.798 .685 .74 r
.30935 .53213 .31529 .5422 .32556 .5306 .31971 .51935 Mtetra
.381 .472 .828 r
.31971 .51935 .32556 .5306 .33523 .52926 .3291 .52288 Mtetra
.61 .716 .92 r
.3291 .52288 .33523 .52926 .345 .5271 .33888 .52082 Mtetra
.607 .719 .925 r
.33888 .52082 .345 .5271 .35475 .52601 .3487 .51882 Mtetra
0 .088 .615 r
.3487 .51882 .35475 .52601 .365 .51556 .35801 .52773 Mtetra
0 0 0 r
.35801 .52773 .365 .51556 .37474 .51618 .36871 .50944 Mtetra
.599 .703 .916 r
.36871 .50944 .37474 .51618 .38467 .51387 .37863 .50762 Mtetra
.627 .73 .921 r
.37863 .50762 .38467 .51387 .39464 .51142 .38863 .50513 Mtetra
.616 .726 .924 r
.38863 .50513 .39464 .51142 .40462 .50992 .39866 .50286 Mtetra
.187 .485 .899 r
.39866 .50286 .40462 .50992 .41498 .49832 .40851 .50684 Mtetra
0 0 0 r
.40851 .50684 .41498 .49832 .42493 .5 .41901 .49307 Mtetra
.598 .699 .914 r
.41901 .49307 .42493 .5 .43506 .49754 .42914 .49124 Mtetra
.634 .734 .92 r
.42914 .49124 .43506 .49754 .44524 .49472 .43934 .48851 Mtetra
.64 .74 .921 r
.43934 .48851 .44524 .49472 .45546 .49186 .44958 .48562 Mtetra
.638 .739 .922 r
.44958 .48562 .45546 .49186 .46572 .48919 .45987 .48278 Mtetra
.616 .726 .924 r
.45987 .48278 .46572 .48919 .476 .48816 .47019 .48044 Mtetra
.945 .583 .238 r
.47019 .48044 .476 .48816 .48644 .47778 .47994 .52331 Mtetra
0 0 .146 r
.47994 .52331 .48644 .47778 .49679 .47715 .49101 .47037 Mtetra
.618 .716 .916 r
.49101 .47037 .49679 .47715 .50721 .47435 .50145 .468 Mtetra
.644 .741 .92 r
.50145 .468 .50721 .47435 .51767 .47122 .51194 .46496 Mtetra
.651 .747 .92 r
.51194 .46496 .51767 .47122 .52817 .46796 .52247 .46173 Mtetra
.654 .75 .92 r
.52247 .46173 .52817 .46796 .53872 .46461 .53304 .45839 Mtetra
.656 .752 .92 r
.53304 .45839 .53872 .46461 .5493 .46121 .54365 .45499 Mtetra
.658 .753 .92 r
.54365 .45499 .5493 .46121 .55993 .45777 .5543 .45153 Mtetra
.659 .754 .92 r
.5543 .45153 .55993 .45777 .57059 .4543 .56499 .44804 Mtetra
.56499 .44804 .57059 .4543 .5813 .45081 .57573 .44453 Mtetra
.57573 .44453 .5813 .45081 .59204 .44731 .5865 .44101 Mtetra
.5865 .44101 .59204 .44731 .60283 .44381 .59732 .43747 Mtetra
.658 .753 .92 r
.59732 .43747 .60283 .44381 .61366 .4403 .60817 .43394 Mtetra
.60817 .43394 .61366 .4403 .62453 .43678 .61907 .43039 Mtetra
.61907 .43039 .62453 .43678 .63544 .43325 .63002 .42684 Mtetra
.63002 .42684 .63544 .43325 .6464 .42972 .641 .42327 Mtetra
.641 .42327 .6464 .42972 .6574 .42617 .65203 .4197 Mtetra
.65203 .4197 .6574 .42617 .66844 .42261 .6631 .41611 Mtetra
.657 .753 .92 r
.6631 .41611 .66844 .42261 .67952 .41904 .67421 .41252 Mtetra
.67421 .41252 .67952 .41904 .69065 .41546 .68537 .40891 Mtetra
.68537 .40891 .69065 .41546 .70182 .41186 .69657 .40528 Mtetra
.69657 .40528 .70182 .41186 .71304 .40826 .70782 .40165 Mtetra
.70782 .40165 .71304 .40826 .7243 .40464 .71911 .398 Mtetra
.657 .752 .92 r
.71911 .398 .7243 .40464 .7356 .401 .73045 .39434 Mtetra
.73045 .39434 .7356 .401 .74695 .39735 .74183 .39067 Mtetra
.74183 .39067 .74695 .39735 .75835 .39369 .75325 .38698 Mtetra
.75325 .38698 .75835 .39369 .76978 .39002 .76472 .38328 Mtetra
.76472 .38328 .76978 .39002 .78127 .38633 .77624 .37956 Mtetra
.77624 .37956 .78127 .38633 .7928 .38263 .7878 .37583 Mtetra
.7878 .37583 .7928 .38263 .80438 .37891 .79941 .37209 Mtetra
.79941 .37209 .80438 .37891 .816 .37518 .81107 .36833 Mtetra
.81107 .36833 .816 .37518 .82767 .37144 .82277 .36456 Mtetra
.82277 .36456 .82767 .37144 .83939 .36768 .83453 .36077 Mtetra
.83453 .36077 .83939 .36768 .85115 .36391 .84632 .35697 Mtetra
.84632 .35697 .85115 .36391 .86296 .36012 .85817 .35315 Mtetra
.555 .692 .931 r
.22619 .54909 .23254 .55548 .24142 .55972 .23552 .54813 Mtetra
.767 .653 .737 r
.23552 .54813 .24142 .55972 .25177 .54676 .24574 .53699 Mtetra
.422 .529 .861 r
.24574 .53699 .25177 .54676 .26117 .54555 .25487 .53918 Mtetra
.594 .708 .923 r
.25487 .53918 .26117 .54555 .27063 .54421 .26437 .5375 Mtetra
.411 .62 .938 r
.26437 .5375 .27063 .54421 .2812 .52825 .2737 .53868 Mtetra
0 0 0 r
.2737 .53868 .2812 .52825 .29012 .53531 .28393 .5282 Mtetra
.565 .675 .913 r
.28393 .5282 .29012 .53531 .29973 .53349 .29349 .52717 Mtetra
.603 .716 .924 r
.29349 .52717 .29973 .53349 .30935 .53213 .30316 .52526 Mtetra
.319 .569 .929 r
.30316 .52526 .30935 .53213 .31971 .51935 .31261 .52759 Mtetra
0 0 0 r
.31261 .52759 .31971 .51935 .3291 .52288 .32297 .5159 Mtetra
.58 .687 .914 r
.32297 .5159 .3291 .52288 .33888 .52082 .33272 .51452 Mtetra
.615 .723 .922 r
.33272 .51452 .33888 .52082 .3487 .51882 .34257 .5123 Mtetra
.562 .697 .931 r
.34257 .5123 .3487 .51882 .35801 .52773 .3524 .51117 Mtetra
.724 .593 .708 r
.3524 .51117 .35801 .52773 .36871 .50944 .36274 .50063 Mtetra
.499 .598 .884 r
.36274 .50063 .36871 .50944 .37863 .50762 .37256 .50121 Mtetra
.62 .723 .92 r
.37256 .50121 .37863 .50762 .38863 .50513 .38257 .49885 Mtetra
.626 .73 .922 r
.38257 .49885 .38863 .50513 .39866 .50286 .39263 .49634 Mtetra
.581 .707 .929 r
.39263 .49634 .39866 .50286 .40851 .50684 .40269 .4948 Mtetra
.772 .658 .737 r
.40269 .4948 .40851 .50684 .41901 .49307 .41315 .4831 Mtetra
.461 .55 .861 r
.41315 .4831 .41901 .49307 .42914 .49124 .42318 .48474 Mtetra
.625 .725 .919 r
.42318 .48474 .42914 .49124 .43934 .48851 .43339 .48223 Mtetra
.639 .738 .921 r
.43339 .48223 .43934 .48851 .44958 .48562 .44366 .47936 Mtetra
.64 .74 .921 r
.44366 .47936 .44958 .48562 .45987 .48278 .45397 .47644 Mtetra
.632 .735 .922 r
.45397 .47644 .45987 .48278 .47019 .48044 .46432 .47371 Mtetra
.556 .694 .932 r
.46432 .47371 .47019 .48044 .47994 .52331 .47468 .47263 Mtetra
.621 .435 .609 r
.47468 .47263 .47994 .52331 .49101 .47037 .48522 .46216 Mtetra
.551 .645 .896 r
.48522 .46216 .49101 .47037 .50145 .468 .49566 .46148 Mtetra
.636 .734 .919 r
.49566 .46148 .50145 .468 .51194 .46496 .50617 .45862 Mtetra
.648 .745 .92 r
.50617 .45862 .51194 .46496 .52247 .46173 .51672 .45544 Mtetra
.653 .749 .92 r
.51672 .45544 .52247 .46173 .53304 .45839 .52732 .45211 Mtetra
.655 .751 .92 r
.52732 .45211 .53304 .45839 .54365 .45499 .53796 .44871 Mtetra
.657 .752 .92 r
.53796 .44871 .54365 .45499 .5543 .45153 .54864 .44525 Mtetra
.658 .753 .92 r
.54864 .44525 .5543 .45153 .56499 .44804 .55936 .44174 Mtetra
.659 .754 .92 r
.55936 .44174 .56499 .44804 .57573 .44453 .57012 .43821 Mtetra
.57012 .43821 .57573 .44453 .5865 .44101 .58092 .43466 Mtetra
.58092 .43466 .5865 .44101 .59732 .43747 .59176 .4311 Mtetra
.59176 .4311 .59732 .43747 .60817 .43394 .60265 .42753 Mtetra
.658 .753 .92 r
.60265 .42753 .60817 .43394 .61907 .43039 .61358 .42395 Mtetra
.61358 .42395 .61907 .43039 .63002 .42684 .62455 .42037 Mtetra
.62455 .42037 .63002 .42684 .641 .42327 .63556 .41678 Mtetra
.63556 .41678 .641 .42327 .65203 .4197 .64662 .41318 Mtetra
.64662 .41318 .65203 .4197 .6631 .41611 .65772 .40957 Mtetra
.65772 .40957 .6631 .41611 .67421 .41252 .66887 .40594 Mtetra
.657 .753 .92 r
.66887 .40594 .67421 .41252 .68537 .40891 .68005 .40231 Mtetra
.68005 .40231 .68537 .40891 .69657 .40528 .69129 .39866 Mtetra
.69129 .39866 .69657 .40528 .70782 .40165 .70256 .395 Mtetra
.70256 .395 .70782 .40165 .71911 .398 .71389 .39132 Mtetra
.657 .752 .92 r
.71389 .39132 .71911 .398 .73045 .39434 .72525 .38763 Mtetra
.72525 .38763 .73045 .39434 .74183 .39067 .73666 .38393 Mtetra
.73666 .38393 .74183 .39067 .75325 .38698 .74812 .38022 Mtetra
.74812 .38022 .75325 .38698 .76472 .38328 .75963 .37649 Mtetra
.75963 .37649 .76472 .38328 .77624 .37956 .77118 .37274 Mtetra
.77118 .37274 .77624 .37956 .7878 .37583 .78277 .36899 Mtetra
.78277 .36899 .7878 .37583 .79941 .37209 .79442 .36521 Mtetra
.79442 .36521 .79941 .37209 .81107 .36833 .80611 .36143 Mtetra
.80611 .36143 .81107 .36833 .82277 .36456 .81784 .35763 Mtetra
.81784 .35763 .82277 .36456 .83453 .36077 .82963 .35381 Mtetra
.82963 .35381 .83453 .36077 .84632 .35697 .84146 .34998 Mtetra
.84146 .34998 .84632 .35697 .85817 .35315 .85334 .34613 Mtetra
.583 .702 .924 r
.2198 .54264 .22619 .54909 .23552 .54813 .22919 .54118 Mtetra
.1 .438 .877 r
.22919 .54118 .23552 .54813 .24574 .53699 .23813 .5454 Mtetra
.654 .888 .538 r
.23813 .5454 .24574 .53699 .25487 .53918 .24857 .53234 Mtetra
.574 .687 .917 r
.24857 .53234 .25487 .53918 .26437 .5375 .25805 .53108 Mtetra
.577 .703 .928 r
.25805 .53108 .26437 .5375 .2737 .53868 .26758 .5297 Mtetra
.832 .706 .726 r
.26758 .5297 .2737 .53868 .28393 .5282 .27824 .51363 Mtetra
.253 .334 .753 r
.27824 .51363 .28393 .5282 .29349 .52717 .28723 .52067 Mtetra
.6 .71 .921 r
.28723 .52067 .29349 .52717 .30316 .52526 .29691 .51881 Mtetra
.576 .704 .929 r
.29691 .51881 .30316 .52526 .31261 .52759 .30661 .5174 Mtetra
.798 .686 .741 r
.30661 .5174 .31261 .52759 .32297 .5159 .31707 .50452 Mtetra
.38 .472 .829 r
.31707 .50452 .32297 .5159 .33272 .51452 .32653 .50803 Mtetra
.61 .716 .92 r
.32653 .50803 .33272 .51452 .34257 .5123 .33639 .50592 Mtetra
.607 .719 .925 r
.33639 .50592 .34257 .5123 .3524 .51117 .34629 .50386 Mtetra
0 .093 .621 r
.34629 .50386 .3524 .51117 .36274 .50063 .35567 .51277 Mtetra
0 0 0 r
.35567 .51277 .36274 .50063 .37256 .50121 .36647 .49436 Mtetra
.599 .703 .916 r
.36647 .49436 .37256 .50121 .38257 .49885 .37648 .49249 Mtetra
.627 .73 .921 r
.37648 .49249 .38257 .49885 .39263 .49634 .38655 .48995 Mtetra
.616 .726 .924 r
.38655 .48995 .39263 .49634 .40269 .4948 .39667 .48762 Mtetra
.19 .486 .899 r
.39667 .48762 .40269 .4948 .41315 .4831 .4066 .49158 Mtetra
.57 .816 .437 r
.4066 .49158 .41315 .4831 .42318 .48474 .41719 .47771 Mtetra
.598 .699 .914 r
.41719 .47771 .42318 .48474 .43339 .48223 .42741 .47582 Mtetra
.634 .734 .92 r
.42741 .47582 .43339 .48223 .44366 .47936 .4377 .47304 Mtetra
.64 .74 .921 r
.4377 .47304 .44366 .47936 .45397 .47644 .44803 .47009 Mtetra
.638 .739 .921 r
.44803 .47009 .45397 .47644 .46432 .47371 .45841 .4672 Mtetra
.616 .726 .924 r
.45841 .4672 .46432 .47371 .47468 .47263 .46881 .4648 Mtetra
.944 .581 .232 r
.46881 .4648 .47468 .47263 .48522 .46216 .47864 .50781 Mtetra
0 0 .138 r
.47864 .50781 .48522 .46216 .49566 .46148 .48983 .45459 Mtetra
.618 .716 .916 r
.48983 .45459 .49566 .46148 .50617 .45862 .50036 .45217 Mtetra
.644 .741 .92 r
.50036 .45217 .50617 .45862 .51672 .45544 .51094 .44907 Mtetra
.651 .747 .92 r
.51094 .44907 .51672 .45544 .52732 .45211 .52156 .44577 Mtetra
.654 .75 .92 r
.52156 .44577 .52732 .45211 .53796 .44871 .53222 .44238 Mtetra
.656 .752 .92 r
.53222 .44238 .53796 .44871 .54864 .44525 .54293 .43891 Mtetra
.658 .753 .92 r
.54293 .43891 .54864 .44525 .55936 .44174 .55368 .43539 Mtetra
.659 .754 .92 r
.55368 .43539 .55936 .44174 .57012 .43821 .56447 .43184 Mtetra
.56447 .43184 .57012 .43821 .58092 .43466 .5753 .42826 Mtetra
.5753 .42826 .58092 .43466 .59176 .4311 .58617 .42467 Mtetra
.58617 .42467 .59176 .4311 .60265 .42753 .59708 .42108 Mtetra
.658 .753 .92 r
.59708 .42108 .60265 .42753 .61358 .42395 .60804 .41747 Mtetra
.60804 .41747 .61358 .42395 .62455 .42037 .61904 .41386 Mtetra
.61904 .41386 .62455 .42037 .63556 .41678 .63009 .41024 Mtetra
.63009 .41024 .63556 .41678 .64662 .41318 .64117 .40661 Mtetra
.64117 .40661 .64662 .41318 .65772 .40957 .6523 .40297 Mtetra
.6523 .40297 .65772 .40957 .66887 .40594 .66348 .39932 Mtetra
.657 .753 .92 r
.66348 .39932 .66887 .40594 .68005 .40231 .6747 .39566 Mtetra
.6747 .39566 .68005 .40231 .69129 .39866 .68596 .39198 Mtetra
.68596 .39198 .69129 .39866 .70256 .395 .69727 .38829 Mtetra
.69727 .38829 .70256 .395 .71389 .39132 .70862 .38459 Mtetra
.70862 .38459 .71389 .39132 .72525 .38763 .72002 .38087 Mtetra
.657 .752 .92 r
.72002 .38087 .72525 .38763 .73666 .38393 .73146 .37715 Mtetra
.73146 .37715 .73666 .38393 .74812 .38022 .74295 .3734 Mtetra
.74295 .3734 .74812 .38022 .75963 .37649 .75449 .36964 Mtetra
.75449 .36964 .75963 .37649 .77118 .37274 .76607 .36587 Mtetra
.76607 .36587 .77118 .37274 .78277 .36899 .7777 .36209 Mtetra
.7777 .36209 .78277 .36899 .79442 .36521 .78938 .35829 Mtetra
.78938 .35829 .79442 .36521 .80611 .36143 .8011 .35447 Mtetra
.8011 .35447 .80611 .36143 .81784 .35763 .81287 .35064 Mtetra
.81287 .35064 .81784 .35763 .82963 .35381 .82469 .3468 Mtetra
.82469 .3468 .82963 .35381 .84146 .34998 .83656 .34294 Mtetra
.83656 .34294 .84146 .34998 .85334 .34613 .84848 .33906 Mtetra
.558 .674 .916 r
.21343 .5356 .2198 .54264 .22919 .54118 .22277 .53468 Mtetra
.556 .692 .931 r
.22277 .53468 .22919 .54118 .23813 .5454 .23217 .53368 Mtetra
.767 .654 .737 r
.23217 .53368 .23813 .5454 .24857 .53234 .24248 .52245 Mtetra
.421 .528 .861 r
.24248 .52245 .24857 .53234 .25805 .53108 .25168 .52461 Mtetra
.594 .708 .923 r
.25168 .52461 .25805 .53108 .26758 .5297 .26126 .52288 Mtetra
.412 .62 .937 r
.26126 .52288 .26758 .5297 .27824 .51363 .27066 .52403 Mtetra
0 0 0 r
.27066 .52403 .27824 .51363 .28723 .52067 .28097 .51347 Mtetra
.565 .675 .913 r
.28097 .51347 .28723 .52067 .29691 .51881 .29061 .51239 Mtetra
.603 .716 .924 r
.29061 .51239 .29691 .51881 .30661 .5174 .30036 .51043 Mtetra
.32 .569 .929 r
.30036 .51043 .30661 .5174 .31707 .50452 .30988 .51272 Mtetra
0 0 0 r
.30988 .51272 .31707 .50452 .32653 .50803 .32034 .50094 Mtetra
.58 .687 .914 r
.32034 .50094 .32653 .50803 .33639 .50592 .33017 .49951 Mtetra
.615 .723 .922 r
.33017 .49951 .33639 .50592 .34629 .50386 .3401 .49724 Mtetra
.562 .697 .931 r
.3401 .49724 .34629 .50386 .35567 .51277 .35001 .49606 Mtetra
.724 .593 .708 r
.35001 .49606 .35567 .51277 .36647 .49436 .36044 .48544 Mtetra
.498 .598 .884 r
.36044 .48544 .36647 .49436 .37648 .49249 .37034 .48597 Mtetra
.62 .723 .92 r
.37034 .48597 .37648 .49249 .38655 .48995 .38044 .48356 Mtetra
.626 .73 .922 r
.38044 .48356 .38655 .48995 .39667 .48762 .39058 .481 Mtetra
.581 .707 .929 r
.39058 .481 .39667 .48762 .4066 .49158 .40073 .4794 Mtetra
.772 .659 .737 r
.40073 .4794 .4066 .49158 .41719 .47771 .41128 .46761 Mtetra
.46 .55 .861 r
.41128 .46761 .41719 .47771 .42741 .47582 .42139 .46921 Mtetra
.625 .725 .919 r
.42139 .46921 .42741 .47582 .4377 .47304 .43169 .46664 Mtetra
.639 .738 .921 r
.43169 .46664 .4377 .47304 .44803 .47009 .44205 .46371 Mtetra
.64 .74 .921 r
.44205 .46371 .44803 .47009 .45841 .4672 .45245 .46074 Mtetra
.632 .735 .922 r
.45245 .46074 .45841 .4672 .46881 .4648 .46289 .45795 Mtetra
.556 .693 .931 r
.46289 .45795 .46881 .4648 .47864 .50781 .47334 .45682 Mtetra
.62 .433 .608 r
.47334 .45682 .47864 .50781 .48983 .45459 .48397 .44626 Mtetra
.551 .645 .896 r
.48397 .44626 .48983 .45459 .50036 .45217 .4945 .44553 Mtetra
.636 .734 .919 r
.4945 .44553 .50036 .45217 .51094 .44907 .50511 .44261 Mtetra
.648 .745 .92 r
.50511 .44261 .51094 .44907 .52156 .44577 .51576 .43936 Mtetra
.653 .749 .92 r
.51576 .43936 .52156 .44577 .53222 .44238 .52645 .43598 Mtetra
.655 .751 .92 r
.52645 .43598 .53222 .44238 .54293 .43891 .53718 .43251 Mtetra
.657 .752 .92 r
.53718 .43251 .54293 .43891 .55368 .43539 .54796 .42899 Mtetra
.658 .753 .92 r
.54796 .42899 .55368 .43539 .56447 .43184 .55878 .42542 Mtetra
.659 .754 .92 r
.55878 .42542 .56447 .43184 .5753 .42826 .56963 .42182 Mtetra
.56963 .42182 .5753 .42826 .58617 .42467 .58054 .41821 Mtetra
.58054 .41821 .58617 .42467 .59708 .42108 .59148 .41458 Mtetra
.59148 .41458 .59708 .42108 .60804 .41747 .60247 .41095 Mtetra
.658 .753 .92 r
.60247 .41095 .60804 .41747 .61904 .41386 .61349 .40731 Mtetra
.61349 .40731 .61904 .41386 .63009 .41024 .62457 .40366 Mtetra
.62457 .40366 .63009 .41024 .64117 .40661 .63568 .4 Mtetra
.63568 .4 .64117 .40661 .6523 .40297 .64684 .39633 Mtetra
.64684 .39633 .6523 .40297 .66348 .39932 .65805 .39265 Mtetra
.65805 .39265 .66348 .39932 .6747 .39566 .6693 .38896 Mtetra
.657 .753 .92 r
.6693 .38896 .6747 .39566 .68596 .39198 .68059 .38526 Mtetra
.68059 .38526 .68596 .39198 .69727 .38829 .69193 .38154 Mtetra
.69193 .38154 .69727 .38829 .70862 .38459 .70332 .37781 Mtetra
.70332 .37781 .70862 .38459 .72002 .38087 .71475 .37407 Mtetra
.657 .752 .92 r
.71475 .37407 .72002 .38087 .73146 .37715 .72622 .37031 Mtetra
.72622 .37031 .73146 .37715 .74295 .3734 .73775 .36654 Mtetra
.73775 .36654 .74295 .3734 .75449 .36964 .74932 .36275 Mtetra
.74932 .36275 .75449 .36964 .76607 .36587 .76093 .35895 Mtetra
.76093 .35895 .76607 .36587 .7777 .36209 .77259 .35514 Mtetra
.77259 .35514 .7777 .36209 .78938 .35829 .7843 .35131 Mtetra
.7843 .35131 .78938 .35829 .8011 .35447 .79606 .34746 Mtetra
.79606 .34746 .8011 .35447 .81287 .35064 .80787 .3436 Mtetra
.80787 .3436 .81287 .35064 .82469 .3468 .81972 .33973 Mtetra
.81972 .33973 .82469 .3468 .83656 .34294 .83162 .33584 Mtetra
.83162 .33584 .83656 .34294 .84848 .33906 .84358 .33194 Mtetra
.293 .394 .795 r
.20753 .52302 .21343 .5356 .22277 .53468 .21631 .52813 Mtetra
.583 .702 .924 r
.21631 .52813 .22277 .53468 .23217 .53368 .22577 .52662 Mtetra
.103 .44 .878 r
.22577 .52662 .23217 .53368 .24248 .52245 .23478 .53082 Mtetra
.664 .894 .548 r
.23478 .53082 .24248 .52245 .25168 .52461 .24531 .51767 Mtetra
.574 .687 .917 r
.24531 .51767 .25168 .52461 .26126 .52288 .25486 .51636 Mtetra
.577 .703 .928 r
.25486 .51636 .26126 .52288 .27066 .52403 .26447 .51493 Mtetra
.833 .707 .726 r
.26447 .51493 .27066 .52403 .28097 .51347 .27524 .49875 Mtetra
.25 .332 .753 r
.27524 .49875 .28097 .51347 .29061 .51239 .28429 .50578 Mtetra
.6 .71 .921 r
.28429 .50578 .29061 .51239 .30036 .51043 .29405 .50387 Mtetra
.576 .703 .929 r
.29405 .50387 .30036 .51043 .30988 .51272 .30382 .50242 Mtetra
.799 .687 .741 r
.30382 .50242 .30988 .51272 .32034 .50094 .31438 .48944 Mtetra
.379 .471 .829 r
.31438 .48944 .32034 .50094 .33017 .49951 .32392 .49291 Mtetra
.61 .716 .92 r
.32392 .49291 .33017 .49951 .3401 .49724 .33385 .49076 Mtetra
.607 .719 .925 r
.33385 .49076 .3401 .49724 .35001 .49606 .34383 .48864 Mtetra
0 .099 .627 r
.34383 .48864 .35001 .49606 .36044 .48544 .35329 .49755 Mtetra
.613 .793 .362 r
.35329 .49755 .36044 .48544 .37034 .48597 .36419 .47901 Mtetra
.599 .703 .916 r
.36419 .47901 .37034 .48597 .38044 .48356 .37428 .47709 Mtetra
.627 .73 .921 r
.37428 .47709 .38044 .48356 .39058 .481 .38444 .47449 Mtetra
.616 .726 .924 r
.38444 .47449 .39058 .481 .40073 .4794 .39464 .47211 Mtetra
.193 .487 .899 r
.39464 .47211 .40073 .4794 .41128 .46761 .40465 .47604 Mtetra
.581 .825 .448 r
.40465 .47604 .41128 .46761 .42139 .46921 .41535 .46206 Mtetra
.598 .699 .914 r
.41535 .46206 .42139 .46921 .43169 .46664 .42565 .46013 Mtetra
.634 .734 .92 r
.42565 .46013 .43169 .46664 .44205 .46371 .43603 .45728 Mtetra
.64 .74 .921 r
.43603 .45728 .44205 .46371 .45245 .46074 .44645 .45428 Mtetra
.638 .739 .921 r
.44645 .45428 .45245 .46074 .46289 .45795 .45692 .45132 Mtetra
.616 .726 .924 r
.45692 .45132 .46289 .45795 .47334 .45682 .46742 .44887 Mtetra
.943 .579 .225 r
.46742 .44887 .47334 .45682 .48397 .44626 .47731 .49202 Mtetra
0 0 .131 r
.47731 .49202 .48397 .44626 .4945 .44553 .48862 .43852 Mtetra
.618 .716 .916 r
.48862 .43852 .4945 .44553 .50511 .44261 .49924 .43604 Mtetra
.644 .741 .92 r
.49924 .43604 .50511 .44261 .51576 .43936 .50991 .43288 Mtetra
.651 .747 .92 r
.50991 .43288 .51576 .43936 .52645 .43598 .52063 .42952 Mtetra
.654 .75 .92 r
.52063 .42952 .52645 .43598 .53718 .43251 .53139 .42606 Mtetra
.656 .752 .92 r
.53139 .42606 .53718 .43251 .54796 .42899 .5422 .42253 Mtetra
.658 .753 .92 r
.5422 .42253 .54796 .42899 .55878 .42542 .55304 .41895 Mtetra
.659 .754 .92 r
.55304 .41895 .55878 .42542 .56963 .42182 .56393 .41533 Mtetra
.56393 .41533 .56963 .42182 .58054 .41821 .57486 .41169 Mtetra
.57486 .41169 .58054 .41821 .59148 .41458 .58583 .40804 Mtetra
.58583 .40804 .59148 .41458 .60247 .41095 .59685 .40437 Mtetra
.658 .753 .92 r
.59685 .40437 .60247 .41095 .61349 .40731 .60791 .40071 Mtetra
.60791 .40071 .61349 .40731 .62457 .40366 .61901 .39703 Mtetra
.61901 .39703 .62457 .40366 .63568 .4 .63016 .39334 Mtetra
.63016 .39334 .63568 .4 .64684 .39633 .64135 .38964 Mtetra
.64135 .38964 .64684 .39633 .65805 .39265 .65258 .38594 Mtetra
.65258 .38594 .65805 .39265 .6693 .38896 .66386 .38222 Mtetra
.657 .753 .92 r
.66386 .38222 .6693 .38896 .68059 .38526 .67519 .37848 Mtetra
.67519 .37848 .68059 .38526 .69193 .38154 .68656 .37474 Mtetra
.68656 .37474 .69193 .38154 .70332 .37781 .69797 .37098 Mtetra
.69797 .37098 .70332 .37781 .71475 .37407 .70944 .36721 Mtetra
.70944 .36721 .71475 .37407 .72622 .37031 .72095 .36342 Mtetra
.657 .752 .92 r
.72095 .36342 .72622 .37031 .73775 .36654 .7325 .35962 Mtetra
.7325 .35962 .73775 .36654 .74932 .36275 .7441 .35581 Mtetra
.7441 .35581 .74932 .36275 .76093 .35895 .75575 .35198 Mtetra
.75575 .35198 .76093 .35895 .77259 .35514 .76745 .34813 Mtetra
.76745 .34813 .77259 .35514 .7843 .35131 .77919 .34428 Mtetra
.77919 .34428 .7843 .35131 .79606 .34746 .79098 .3404 Mtetra
.79098 .3404 .79606 .34746 .80787 .3436 .80282 .33651 Mtetra
.80282 .33651 .80787 .3436 .81972 .33973 .81471 .33261 Mtetra
.81471 .33261 .81972 .33973 .83162 .33584 .82665 .32869 Mtetra
.82665 .32869 .83162 .33584 .84358 .33194 .83864 .32476 Mtetra
0 0 0 r
.19954 .53185 .20753 .52302 .21631 .52813 .20987 .52099 Mtetra
.558 .674 .916 r
.20987 .52099 .21631 .52813 .22577 .52662 .21929 .52002 Mtetra
.556 .692 .931 r
.21929 .52002 .22577 .52662 .23478 .53082 .22876 .51898 Mtetra
.767 .654 .737 r
.22876 .51898 .23478 .53082 .24531 .51767 .23916 .50766 Mtetra
.42 .528 .861 r
.23916 .50766 .24531 .51767 .25486 .51636 .24843 .50978 Mtetra
.594 .708 .923 r
.24843 .50978 .25486 .51636 .26447 .51493 .25809 .508 Mtetra
.412 .621 .937 r
.25809 .508 .26447 .51493 .27524 .49875 .26756 .50912 Mtetra
0 0 0 r
.26756 .50912 .27524 .49875 .28429 .50578 .27797 .49847 Mtetra
.565 .675 .913 r
.27797 .49847 .28429 .50578 .29405 .50387 .28769 .49734 Mtetra
.603 .716 .924 r
.28769 .49734 .29405 .50387 .30382 .50242 .29751 .49533 Mtetra
.322 .57 .928 r
.29751 .49533 .30382 .50242 .31438 .48944 .30711 .49759 Mtetra
.532 .817 .472 r
.30711 .49759 .31438 .48944 .32392 .49291 .31766 .48571 Mtetra
.58 .687 .914 r
.31766 .48571 .32392 .49291 .33385 .49076 .32757 .48424 Mtetra
.615 .723 .922 r
.32757 .48424 .33385 .49076 .34383 .48864 .33758 .48191 Mtetra
.562 .697 .931 r
.33758 .48191 .34383 .48864 .35329 .49755 .34757 .48068 Mtetra
.724 .593 .708 r
.34757 .48068 .35329 .49755 .36419 .47901 .3581 .46997 Mtetra
.498 .598 .884 r
.3581 .46997 .36419 .47901 .37428 .47709 .36808 .47046 Mtetra
.62 .723 .92 r
.36808 .47046 .37428 .47709 .38444 .47449 .37826 .46799 Mtetra
.626 .73 .922 r
.37826 .46799 .38444 .47449 .39464 .47211 .38849 .46538 Mtetra
.581 .707 .929 r
.38849 .46538 .39464 .47211 .40465 .47604 .39873 .46373 Mtetra
.773 .659 .737 r
.39873 .46373 .40465 .47604 .41535 .46206 .40937 .45184 Mtetra
.46 .55 .861 r
.40937 .45184 .41535 .46206 .42565 .46013 .41957 .4534 Mtetra
.625 .725 .919 r
.41957 .4534 .42565 .46013 .43603 .45728 .42997 .45077 Mtetra
.639 .738 .921 r
.42997 .45077 .43603 .45728 .44645 .45428 .44041 .44779 Mtetra
.64 .74 .921 r
.44041 .44779 .44645 .45428 .45692 .45132 .4509 .44475 Mtetra
.632 .735 .922 r
.4509 .44475 .45692 .45132 .46742 .44887 .46143 .4419 Mtetra
.556 .693 .931 r
.46143 .4419 .46742 .44887 .47731 .49202 .47198 .44073 Mtetra
.619 .431 .606 r
.47198 .44073 .47731 .49202 .48862 .43852 .48271 .43007 Mtetra
.55 .645 .896 r
.48271 .43007 .48862 .43852 .49924 .43604 .49333 .42929 Mtetra
.636 .734 .919 r
.49333 .42929 .49924 .43604 .50991 .43288 .50403 .42631 Mtetra
.648 .745 .92 r
.50403 .42631 .50991 .43288 .52063 .42952 .51477 .423 Mtetra
.653 .749 .92 r
.51477 .423 .52063 .42952 .53139 .42606 .52556 .41955 Mtetra
.655 .751 .92 r
.52556 .41955 .53139 .42606 .5422 .42253 .53639 .41602 Mtetra
.657 .752 .92 r
.53639 .41602 .5422 .42253 .55304 .41895 .54727 .41243 Mtetra
.658 .753 .92 r
.54727 .41243 .55304 .41895 .56393 .41533 .55818 .40879 Mtetra
.659 .754 .92 r
.55818 .40879 .56393 .41533 .57486 .41169 .56914 .40513 Mtetra
.56914 .40513 .57486 .41169 .58583 .40804 .58014 .40145 Mtetra
.58014 .40145 .58583 .40804 .59685 .40437 .59119 .39776 Mtetra
.59119 .39776 .59685 .40437 .60791 .40071 .60228 .39406 Mtetra
.658 .753 .92 r
.60228 .39406 .60791 .40071 .61901 .39703 .61341 .39035 Mtetra
.61341 .39035 .61901 .39703 .63016 .39334 .62459 .38663 Mtetra
.62459 .38663 .63016 .39334 .64135 .38964 .63581 .38291 Mtetra
.63581 .38291 .64135 .38964 .65258 .38594 .64707 .37917 Mtetra
.64707 .37917 .65258 .38594 .66386 .38222 .65838 .37542 Mtetra
.65838 .37542 .66386 .38222 .67519 .37848 .66974 .37166 Mtetra
.657 .753 .92 r
.66974 .37166 .67519 .37848 .68656 .37474 .68114 .36789 Mtetra
.68114 .36789 .68656 .37474 .69797 .37098 .69259 .3641 Mtetra
.69259 .3641 .69797 .37098 .70944 .36721 .70409 .3603 Mtetra
.70409 .3603 .70944 .36721 .72095 .36342 .71563 .35648 Mtetra
.657 .752 .92 r
.71563 .35648 .72095 .36342 .7325 .35962 .72721 .35265 Mtetra
.72721 .35265 .7325 .35962 .7441 .35581 .73885 .34881 Mtetra
.73885 .34881 .7441 .35581 .75575 .35198 .75053 .34495 Mtetra
.75053 .34495 .75575 .35198 .76745 .34813 .76226 .34108 Mtetra
.76226 .34108 .76745 .34813 .77919 .34428 .77404 .33719 Mtetra
.77404 .33719 .77919 .34428 .79098 .3404 .78587 .33329 Mtetra
.78587 .33329 .79098 .3404 .80282 .33651 .79774 .32937 Mtetra
.79774 .32937 .80282 .33651 .81471 .33261 .80966 .32544 Mtetra
.80966 .32544 .81471 .33261 .82665 .32869 .82164 .32149 Mtetra
.82164 .32149 .82665 .32869 .83864 .32476 .83366 .31752 Mtetra
.81 .693 .736 r
.19327 .52223 .19954 .53185 .20987 .52099 .20392 .50827 Mtetra
.291 .394 .795 r
.20392 .50827 .20987 .52099 .21929 .52002 .21277 .51337 Mtetra
.583 .702 .924 r
.21277 .51337 .21929 .52002 .22876 .51898 .2223 .51181 Mtetra
.106 .442 .879 r
.2223 .51181 .22876 .51898 .23916 .50766 .23137 .51599 Mtetra
.673 .901 .557 r
.23137 .51599 .23916 .50766 .24843 .50978 .242 .50273 Mtetra
.574 .687 .917 r
.242 .50273 .24843 .50978 .25809 .508 .25163 .50138 Mtetra
.577 .703 .928 r
.25163 .50138 .25809 .508 .26756 .50912 .26131 .4999 Mtetra
.833 .708 .726 r
.26131 .4999 .26756 .50912 .27797 .49847 .27218 .48361 Mtetra
.248 .331 .753 r
.27218 .48361 .27797 .49847 .28769 .49734 .28129 .49063 Mtetra
.6 .71 .921 r
.28129 .49063 .28769 .49734 .29751 .49533 .29113 .48866 Mtetra
.576 .703 .929 r
.29113 .48866 .29751 .49533 .30711 .49759 .30099 .48716 Mtetra
.799 .687 .741 r
.30099 .48716 .30711 .49759 .31766 .48571 .31164 .47408 Mtetra
.378 .471 .829 r
.31164 .47408 .31766 .48571 .32757 .48424 .32125 .47753 Mtetra
.61 .716 .92 r
.32125 .47753 .32757 .48424 .33758 .48191 .33127 .47532 Mtetra
.607 .719 .925 r
.33127 .47532 .33758 .48191 .34757 .48068 .34134 .47315 Mtetra
0 .104 .633 r
.34134 .47315 .34757 .48068 .3581 .46997 .35086 .48205 Mtetra
.623 .801 .371 r
.35086 .48205 .3581 .46997 .36808 .47046 .36187 .46339 Mtetra
.599 .703 .916 r
.36187 .46339 .36808 .47046 .37826 .46799 .37204 .46142 Mtetra
.626 .73 .921 r
.37204 .46142 .37826 .46799 .38849 .46538 .38229 .45876 Mtetra
.616 .725 .924 r
.38229 .45876 .38849 .46538 .39873 .46373 .39258 .45632 Mtetra
.196 .489 .9 r
.39258 .45632 .39873 .46373 .40937 .45184 .40268 .46022 Mtetra
.592 .833 .458 r
.40268 .46022 .40937 .45184 .41957 .4534 .41347 .44614 Mtetra
.598 .699 .914 r
.41347 .44614 .41957 .4534 .42997 .45077 .42386 .44415 Mtetra
.634 .734 .92 r
.42386 .44415 .42997 .45077 .44041 .44779 .43433 .44124 Mtetra
.64 .74 .921 r
.43433 .44124 .44041 .44779 .4509 .44475 .44484 .43818 Mtetra
.638 .739 .921 r
.44484 .43818 .4509 .44475 .46143 .4419 .4554 .43516 Mtetra
.616 .726 .924 r
.4554 .43516 .46143 .4419 .47198 .44073 .46599 .43265 Mtetra
.942 .576 .218 r
.46599 .43265 .47198 .44073 .48271 .43007 .47595 .47594 Mtetra
0 0 .124 r
.47595 .47594 .48271 .43007 .49333 .42929 .48738 .42216 Mtetra
.618 .716 .916 r
.48738 .42216 .49333 .42929 .50403 .42631 .4981 .41962 Mtetra
.644 .741 .92 r
.4981 .41962 .50403 .42631 .51477 .423 .50887 .4164 Mtetra
.651 .747 .92 r
.50887 .4164 .51477 .423 .52556 .41955 .51969 .41297 Mtetra
.654 .75 .92 r
.51969 .41297 .52556 .41955 .53639 .41602 .53055 .40945 Mtetra
.656 .752 .92 r
.53055 .40945 .53639 .41602 .54727 .41243 .54145 .40585 Mtetra
.658 .753 .92 r
.54145 .40585 .54727 .41243 .55818 .40879 .55239 .4022 Mtetra
.659 .754 .92 r
.55239 .4022 .55818 .40879 .56914 .40513 .56338 .39852 Mtetra
.56338 .39852 .56914 .40513 .58014 .40145 .57441 .39481 Mtetra
.57441 .39481 .58014 .40145 .59119 .39776 .58549 .39109 Mtetra
.58549 .39109 .59119 .39776 .60228 .39406 .59661 .38736 Mtetra
.658 .753 .92 r
.59661 .38736 .60228 .39406 .61341 .39035 .60777 .38362 Mtetra
.60777 .38362 .61341 .39035 .62459 .38663 .61898 .37988 Mtetra
.61898 .37988 .62459 .38663 .63581 .38291 .63023 .37612 Mtetra
.63023 .37612 .63581 .38291 .64707 .37917 .64152 .37235 Mtetra
.64152 .37235 .64707 .37917 .65838 .37542 .65287 .36858 Mtetra
.65287 .36858 .65838 .37542 .66974 .37166 .66425 .36479 Mtetra
.657 .753 .92 r
.66425 .36479 .66974 .37166 .68114 .36789 .67569 .36098 Mtetra
.67569 .36098 .68114 .36789 .69259 .3641 .68717 .35717 Mtetra
.68717 .35717 .69259 .3641 .70409 .3603 .6987 .35334 Mtetra
.6987 .35334 .70409 .3603 .71563 .35648 .71027 .34949 Mtetra
.71027 .34949 .71563 .35648 .72721 .35265 .72189 .34563 Mtetra
.657 .752 .92 r
.72189 .34563 .72721 .35265 .73885 .34881 .73356 .34176 Mtetra
.73356 .34176 .73885 .34881 .75053 .34495 .74527 .33787 Mtetra
.74527 .33787 .75053 .34495 .76226 .34108 .75704 .33397 Mtetra
.75704 .33397 .76226 .34108 .77404 .33719 .76885 .33005 Mtetra
.76885 .33005 .77404 .33719 .78587 .33329 .78071 .32612 Mtetra
.78071 .32612 .78587 .33329 .79774 .32937 .79262 .32217 Mtetra
.79262 .32217 .79774 .32937 .80966 .32544 .80458 .31821 Mtetra
.80458 .31821 .80966 .32544 .82164 .32149 .81659 .31423 Mtetra
.81659 .31423 .82164 .32149 .83366 .31752 .82864 .31023 Mtetra
.342 .584 .933 r
.1867 .51522 .19327 .52223 .20392 .50827 .19583 .51707 Mtetra
0 0 0 r
.19583 .51707 .20392 .50827 .21277 .51337 .20625 .50612 Mtetra
.558 .674 .916 r
.20625 .50612 .21277 .51337 .2223 .51181 .21575 .50511 Mtetra
.556 .692 .931 r
.21575 .50511 .2223 .51181 .23137 .51599 .22529 .50402 Mtetra
.768 .655 .738 r
.22529 .50402 .23137 .51599 .242 .50273 .23578 .49261 Mtetra
.419 .528 .861 r
.23578 .49261 .242 .50273 .25163 .50138 .24513 .4947 Mtetra
.594 .708 .923 r
.24513 .4947 .25163 .50138 .26131 .4999 .25486 .49287 Mtetra
.413 .621 .937 r
.25486 .49287 .26131 .4999 .27218 .48361 .2644 .49394 Mtetra
0 0 0 r
.2644 .49394 .27218 .48361 .28129 .49063 .27491 .4832 Mtetra
.565 .675 .913 r
.27491 .4832 .28129 .49063 .29113 .48866 .2847 .48203 Mtetra
.603 .715 .924 r
.2847 .48203 .29113 .48866 .30099 .48716 .29461 .47997 Mtetra
.323 .57 .928 r
.29461 .47997 .30099 .48716 .31164 .47408 .30428 .48219 Mtetra
.544 .827 .485 r
.30428 .48219 .31164 .47408 .32125 .47753 .31493 .47022 Mtetra
.58 .687 .914 r
.31493 .47022 .32125 .47753 .33127 .47532 .32492 .46869 Mtetra
.615 .723 .922 r
.32492 .46869 .33127 .47532 .34134 .47315 .33502 .46631 Mtetra
.562 .697 .931 r
.33502 .46631 .34134 .47315 .35086 .48205 .3451 .46503 Mtetra
.725 .593 .708 r
.3451 .46503 .35086 .48205 .36187 .46339 .35572 .45423 Mtetra
.498 .598 .884 r
.35572 .45423 .36187 .46339 .37204 .46142 .36579 .45467 Mtetra
.62 .723 .92 r
.36579 .45467 .37204 .46142 .38229 .45876 .37605 .45214 Mtetra
.626 .73 .922 r
.37605 .45214 .38229 .45876 .39258 .45632 .38637 .44947 Mtetra
.581 .707 .929 r
.38637 .44947 .39258 .45632 .40268 .46022 .39669 .44777 Mtetra
.773 .66 .737 r
.39669 .44777 .40268 .46022 .41347 .44614 .40743 .43578 Mtetra
.459 .55 .861 r
.40743 .43578 .41347 .44614 .42386 .44415 .41772 .4373 Mtetra
.625 .725 .919 r
.41772 .4373 .42386 .44415 .43433 .44124 .4282 .43462 Mtetra
.639 .738 .921 r
.4282 .43462 .43433 .44124 .44484 .43818 .43874 .43157 Mtetra
.64 .74 .921 r
.43874 .43157 .44484 .43818 .4554 .43516 .44933 .42847 Mtetra
.632 .735 .922 r
.44933 .42847 .4554 .43516 .46599 .43265 .45995 .42556 Mtetra
.556 .693 .931 r
.45995 .42556 .46599 .43265 .47595 .47594 .47059 .42433 Mtetra
.618 .429 .605 r
.47059 .42433 .47595 .47594 .48738 .42216 .48142 .41358 Mtetra
.55 .645 .896 r
.48142 .41358 .48738 .42216 .4981 .41962 .49214 .41275 Mtetra
.636 .734 .919 r
.49214 .41275 .4981 .41962 .50887 .4164 .50293 .4097 Mtetra
.648 .745 .92 r
.50293 .4097 .50887 .4164 .51969 .41297 .51377 .40633 Mtetra
.653 .749 .92 r
.51377 .40633 .51969 .41297 .53055 .40945 .52466 .40281 Mtetra
.655 .751 .92 r
.52466 .40281 .53055 .40945 .54145 .40585 .53559 .39922 Mtetra
.657 .752 .92 r
.53559 .39922 .54145 .40585 .55239 .4022 .54656 .39556 Mtetra
.658 .753 .92 r
.54656 .39556 .55239 .4022 .56338 .39852 .55758 .39186 Mtetra
.659 .754 .92 r
.55758 .39186 .56338 .39852 .57441 .39481 .56864 .38812 Mtetra
.56864 .38812 .57441 .39481 .58549 .39109 .57975 .38437 Mtetra
.57975 .38437 .58549 .39109 .59661 .38736 .59089 .38061 Mtetra
.59089 .38061 .59661 .38736 .60777 .38362 .60209 .37685 Mtetra
.658 .753 .92 r
.60209 .37685 .60777 .38362 .61898 .37988 .61332 .37307 Mtetra
.61332 .37307 .61898 .37988 .63023 .37612 .62461 .36928 Mtetra
.62461 .36928 .63023 .37612 .64152 .37235 .63593 .36549 Mtetra
.63593 .36549 .64152 .37235 .65287 .36858 .64731 .36168 Mtetra
.64731 .36168 .65287 .36858 .66425 .36479 .65873 .35786 Mtetra
.65873 .35786 .66425 .36479 .67569 .36098 .67019 .35403 Mtetra
.657 .753 .92 r
.67019 .35403 .67569 .36098 .68717 .35717 .6817 .35018 Mtetra
.6817 .35018 .68717 .35717 .6987 .35334 .69326 .34632 Mtetra
.69326 .34632 .6987 .35334 .71027 .34949 .70487 .34245 Mtetra
.70487 .34245 .71027 .34949 .72189 .34563 .71652 .33856 Mtetra
.657 .752 .92 r
.71652 .33856 .72189 .34563 .73356 .34176 .72822 .33466 Mtetra
.72822 .33466 .73356 .34176 .74527 .33787 .73997 .33074 Mtetra
.73997 .33074 .74527 .33787 .75704 .33397 .75177 .32681 Mtetra
.75177 .32681 .75704 .33397 .76885 .33005 .76362 .32286 Mtetra
.76362 .32286 .76885 .33005 .78071 .32612 .77551 .3189 Mtetra
.77551 .3189 .78071 .32612 .79262 .32217 .78746 .31492 Mtetra
.78746 .31492 .79262 .32217 .80458 .31821 .79945 .31092 Mtetra
.79945 .31092 .80458 .31821 .81659 .31423 .8115 .30691 Mtetra
.8115 .30691 .81659 .31423 .82864 .31023 .82359 .30289 Mtetra
.559 .692 .929 r
.18005 .50849 .1867 .51522 .19583 .51707 .18949 .50733 Mtetra
.811 .694 .736 r
.18949 .50733 .19583 .51707 .20625 .50612 .20025 .49327 Mtetra
.29 .393 .795 r
.20025 .49327 .20625 .50612 .21575 .50511 .20915 .49835 Mtetra
.583 .702 .924 r
.20915 .49835 .21575 .50511 .22529 .50402 .21876 .49674 Mtetra
.11 .443 .879 r
.21876 .49674 .22529 .50402 .23578 .49261 .2279 .50089 Mtetra
.682 .907 .566 r
.2279 .50089 .23578 .49261 .24513 .4947 .23862 .48754 Mtetra
.574 .687 .918 r
.23862 .48754 .24513 .4947 .25486 .49287 .24833 .48614 Mtetra
.577 .703 .928 r
.24833 .48614 .25486 .49287 .2644 .49394 .2581 .4846 Mtetra
.834 .709 .726 r
.2581 .4846 .2644 .49394 .27491 .4832 .26907 .4682 Mtetra
.246 .329 .752 r
.26907 .4682 .27491 .4832 .2847 .48203 .27824 .47521 Mtetra
.6 .71 .921 r
.27824 .47521 .2847 .48203 .29461 .47997 .28817 .47319 Mtetra
.576 .703 .929 r
.28817 .47319 .29461 .47997 .30428 .48219 .2981 .47163 Mtetra
.8 .688 .741 r
.2981 .47163 .30428 .48219 .31493 .47022 .30885 .45845 Mtetra
.377 .47 .829 r
.30885 .45845 .31493 .47022 .32492 .46869 .31854 .46187 Mtetra
.61 .716 .92 r
.31854 .46187 .32492 .46869 .33502 .46631 .32865 .4596 Mtetra
.607 .719 .925 r
.32865 .4596 .33502 .46631 .3451 .46503 .33879 .45738 Mtetra
0 .11 .638 r
.33879 .45738 .3451 .46503 .35572 .45423 .34839 .46627 Mtetra
.632 .809 .381 r
.34839 .46627 .35572 .45423 .36579 .45467 .3595 .44749 Mtetra
.599 .703 .916 r
.3595 .44749 .36579 .45467 .37605 .45214 .36977 .44546 Mtetra
.626 .73 .921 r
.36977 .44546 .37605 .45214 .38637 .44947 .38011 .44274 Mtetra
.616 .725 .924 r
.38011 .44274 .38637 .44947 .39669 .44777 .39048 .44025 Mtetra
.199 .49 .9 r
.39048 .44025 .39669 .44777 .40743 .43578 .40066 .44411 Mtetra
.602 .841 .469 r
.40066 .44411 .40743 .43578 .41772 .4373 .41155 .42992 Mtetra
.598 .699 .914 r
.41155 .42992 .41772 .4373 .4282 .43462 .42204 .42787 Mtetra
.634 .734 .92 r
.42204 .42787 .4282 .43462 .43874 .43157 .4326 .42491 Mtetra
.64 .74 .921 r
.4326 .42491 .43874 .43157 .44933 .42847 .44321 .42178 Mtetra
.638 .739 .921 r
.44321 .42178 .44933 .42847 .45995 .42556 .45386 .4187 Mtetra
.617 .726 .924 r
.45386 .4187 .45995 .42556 .47059 .42433 .46454 .41613 Mtetra
.941 .574 .211 r
.46454 .41613 .47059 .42433 .48142 .41358 .47457 .45955 Mtetra
0 0 .116 r
.47457 .45955 .48142 .41358 .49214 .41275 .48613 .40549 Mtetra
.617 .716 .916 r
.48613 .40549 .49214 .41275 .50293 .4097 .49694 .40289 Mtetra
.644 .741 .92 r
.49694 .40289 .50293 .4097 .51377 .40633 .50781 .3996 Mtetra
.651 .747 .92 r
.50781 .3996 .51377 .40633 .52466 .40281 .51873 .39611 Mtetra
.654 .75 .92 r
.51873 .39611 .52466 .40281 .53559 .39922 .52969 .39252 Mtetra
.656 .752 .92 r
.52969 .39252 .53559 .39922 .54656 .39556 .54069 .38886 Mtetra
.658 .753 .92 r
.54069 .38886 .54656 .39556 .55758 .39186 .55174 .38514 Mtetra
.659 .754 .92 r
.55174 .38514 .55758 .39186 .56864 .38812 .56283 .38139 Mtetra
.56283 .38139 .56864 .38812 .57975 .38437 .57396 .37761 Mtetra
.57396 .37761 .57975 .38437 .59089 .38061 .58514 .37382 Mtetra
.58514 .37382 .59089 .38061 .60209 .37685 .59636 .37002 Mtetra
.658 .753 .92 r
.59636 .37002 .60209 .37685 .61332 .37307 .60763 .36621 Mtetra
.60763 .36621 .61332 .37307 .62461 .36928 .61894 .3624 Mtetra
.61894 .3624 .62461 .36928 .63593 .36549 .6303 .35857 Mtetra
.6303 .35857 .63593 .36549 .64731 .36168 .64171 .35473 Mtetra
.64171 .35473 .64731 .36168 .65873 .35786 .65316 .35088 Mtetra
.65316 .35088 .65873 .35786 .67019 .35403 .66465 .34702 Mtetra
.657 .753 .92 r
.66465 .34702 .67019 .35403 .6817 .35018 .6762 .34314 Mtetra
.6762 .34314 .6817 .35018 .69326 .34632 .68779 .33926 Mtetra
.68779 .33926 .69326 .34632 .70487 .34245 .69943 .33535 Mtetra
.69943 .33535 .70487 .34245 .71652 .33856 .71112 .33143 Mtetra
.71112 .33143 .71652 .33856 .72822 .33466 .72285 .3275 Mtetra
.657 .752 .92 r
.72285 .3275 .72822 .33466 .73997 .33074 .73463 .32355 Mtetra
.73463 .32355 .73997 .33074 .75177 .32681 .74647 .31959 Mtetra
.74647 .31959 .75177 .32681 .76362 .32286 .75835 .31561 Mtetra
.75835 .31561 .76362 .32286 .77551 .3189 .77028 .31162 Mtetra
.77028 .31162 .77551 .3189 .78746 .31492 .78226 .30761 Mtetra
.78226 .30761 .78746 .31492 .79945 .31092 .79429 .30358 Mtetra
.79429 .30358 .79945 .31092 .8115 .30691 .80637 .29954 Mtetra
.80637 .29954 .8115 .30691 .82359 .30289 .8185 .29548 Mtetra
.569 .689 .922 r
.17339 .50152 .18005 .50849 .18949 .50733 .18285 .50021 Mtetra
.343 .584 .933 r
.18285 .50021 .18949 .50733 .20025 .49327 .19206 .50203 Mtetra
0 0 0 r
.19206 .50203 .20025 .49327 .20915 .49835 .20257 .49099 Mtetra
.557 .674 .916 r
.20257 .49099 .20915 .49835 .21876 .49674 .21214 .48993 Mtetra
.556 .692 .931 r
.21214 .48993 .21876 .49674 .2279 .50089 .22176 .48879 Mtetra
.768 .655 .738 r
.22176 .48879 .2279 .50089 .23862 .48754 .23235 .47729 Mtetra
.419 .528 .862 r
.23235 .47729 .23862 .48754 .24833 .48614 .24176 .47934 Mtetra
.594 .708 .923 r
.24176 .47934 .24833 .48614 .2581 .4846 .25157 .47746 Mtetra
.414 .621 .937 r
.25157 .47746 .2581 .4846 .26907 .4682 .26119 .47849 Mtetra
0 0 0 r
.26119 .47849 .26907 .4682 .27824 .47521 .27179 .46766 Mtetra
.565 .675 .913 r
.27179 .46766 .27824 .47521 .28817 .47319 .28167 .46644 Mtetra
.603 .715 .924 r
.28167 .46644 .28817 .47319 .2981 .47163 .29166 .46432 Mtetra
.325 .57 .928 r
.29166 .46432 .2981 .47163 .30885 .45845 .30141 .46651 Mtetra
.556 .837 .497 r
.30141 .46651 .30885 .45845 .31854 .46187 .31215 .45444 Mtetra
.58 .687 .914 r
.31215 .45444 .31854 .46187 .32865 .4596 .32223 .45286 Mtetra
.615 .723 .922 r
.32223 .45286 .32865 .4596 .33879 .45738 .33241 .45042 Mtetra
.562 .697 .931 r
.33241 .45042 .33879 .45738 .34839 .46627 .34257 .44909 Mtetra
.725 .593 .708 r
.34257 .44909 .34839 .46627 .3595 .44749 .35329 .43819 Mtetra
.497 .598 .884 r
.35329 .43819 .3595 .44749 .36977 .44546 .36344 .43859 Mtetra
.62 .723 .92 r
.36344 .43859 .36977 .44546 .38011 .44274 .3738 .43601 Mtetra
.626 .73 .922 r
.3738 .43601 .38011 .44274 .39048 .44025 .3842 .43327 Mtetra
.581 .707 .929 r
.3842 .43327 .39048 .44025 .40066 .44411 .39462 .43152 Mtetra
.774 .66 .738 r
.39462 .43152 .40066 .44411 .41155 .42992 .40546 .41943 Mtetra
.458 .55 .862 r
.40546 .41943 .41155 .42992 .42204 .42787 .41583 .42091 Mtetra
.625 .725 .919 r
.41583 .42091 .42204 .42787 .4326 .42491 .42641 .41816 Mtetra
.639 .738 .921 r
.42641 .41816 .4326 .42491 .44321 .42178 .43704 .41505 Mtetra
.64 .74 .921 r
.43704 .41505 .44321 .42178 .45386 .4187 .44772 .41189 Mtetra
.632 .735 .922 r
.44772 .41189 .45386 .4187 .46454 .41613 .45844 .40892 Mtetra
.556 .693 .931 r
.45844 .40892 .46454 .41613 .47457 .45955 .46917 .40763 Mtetra
.616 .428 .604 r
.46917 .40763 .47457 .45955 .48613 .40549 .4801 .39678 Mtetra
.55 .645 .897 r
.4801 .39678 .48613 .40549 .49694 .40289 .49092 .39589 Mtetra
.636 .734 .919 r
.49092 .39589 .49694 .40289 .50781 .3996 .50181 .39279 Mtetra
.648 .745 .92 r
.50181 .39279 .50781 .3996 .51873 .39611 .51275 .38934 Mtetra
.653 .749 .92 r
.51275 .38934 .51873 .39611 .52969 .39252 .52374 .38576 Mtetra
.655 .751 .92 r
.52374 .38576 .52969 .39252 .54069 .38886 .53477 .3821 Mtetra
.657 .752 .92 r
.53477 .3821 .54069 .38886 .55174 .38514 .54585 .37837 Mtetra
.658 .753 .92 r
.54585 .37837 .55174 .38514 .56283 .38139 .55697 .3746 Mtetra
.659 .754 .92 r
.55697 .3746 .56283 .38139 .57396 .37761 .56813 .3708 Mtetra
.56813 .3708 .57396 .37761 .58514 .37382 .57934 .36698 Mtetra
.57934 .36698 .58514 .37382 .59636 .37002 .59059 .36315 Mtetra
.59059 .36315 .59636 .37002 .60763 .36621 .60189 .35931 Mtetra
.658 .753 .92 r
.60189 .35931 .60763 .36621 .61894 .3624 .61323 .35546 Mtetra
.61323 .35546 .61894 .3624 .6303 .35857 .62463 .3516 Mtetra
.62463 .3516 .6303 .35857 .64171 .35473 .63606 .34773 Mtetra
.63606 .34773 .64171 .35473 .65316 .35088 .64754 .34385 Mtetra
.64754 .34385 .65316 .35088 .66465 .34702 .65907 .33996 Mtetra
.65907 .33996 .66465 .34702 .6762 .34314 .67065 .33605 Mtetra
.657 .753 .92 r
.67065 .33605 .6762 .34314 .68779 .33926 .68228 .33213 Mtetra
.68228 .33213 .68779 .33926 .69943 .33535 .69395 .3282 Mtetra
.69395 .3282 .69943 .33535 .71112 .33143 .70567 .32425 Mtetra
.70567 .32425 .71112 .33143 .72285 .3275 .71744 .32029 Mtetra
.657 .752 .92 r
.71744 .32029 .72285 .3275 .73463 .32355 .72925 .31631 Mtetra
.72925 .31631 .73463 .32355 .74647 .31959 .74112 .31232 Mtetra
.74112 .31232 .74647 .31959 .75835 .31561 .75304 .30831 Mtetra
.75304 .30831 .75835 .31561 .77028 .31162 .765 .30428 Mtetra
.765 .30428 .77028 .31162 .78226 .30761 .77702 .30024 Mtetra
.77702 .30024 .78226 .30761 .79429 .30358 .78908 .29618 Mtetra
.78908 .29618 .79429 .30358 .80637 .29954 .8012 .29211 Mtetra
.8012 .29211 .80637 .29954 .8185 .29548 .81336 .28802 Mtetra
.486 .607 .897 r
.16684 .49295 .17339 .50152 .18285 .50021 .17614 .49337 Mtetra
.559 .692 .929 r
.17614 .49337 .18285 .50021 .19206 .50203 .18566 .49217 Mtetra
.811 .695 .736 r
.18566 .49217 .19206 .50203 .20257 .49099 .19651 .478 Mtetra
.288 .392 .795 r
.19651 .478 .20257 .49099 .21214 .48993 .20548 .48306 Mtetra
.583 .702 .924 r
.20548 .48306 .21214 .48993 .22176 .48879 .21516 .4814 Mtetra
.113 .445 .88 r
.21516 .4814 .22176 .48879 .23235 .47729 .22436 .48552 Mtetra
.691 .913 .576 r
.22436 .48552 .23235 .47729 .24176 .47934 .23519 .47207 Mtetra
.574 .687 .918 r
.23519 .47207 .24176 .47934 .25157 .47746 .24498 .47062 Mtetra
.577 .703 .928 r
.24498 .47062 .25157 .47746 .26119 .47849 .25482 .46903 Mtetra
.835 .709 .726 r
.25482 .46903 .26119 .47849 .27179 .46766 .2659 .45252 Mtetra
.243 .328 .752 r
.2659 .45252 .27179 .46766 .28167 .46644 .27514 .45951 Mtetra
.6 .71 .921 r
.27514 .45951 .28167 .46644 .29166 .46432 .28515 .45743 Mtetra
.576 .703 .929 r
.28515 .45743 .29166 .46432 .30141 .46651 .29517 .45582 Mtetra
.801 .689 .741 r
.29517 .45582 .30141 .46651 .31215 .45444 .30602 .44254 Mtetra
.375 .47 .829 r
.30602 .44254 .31215 .45444 .32223 .45286 .31578 .44592 Mtetra
.61 .716 .92 r
.31578 .44592 .32223 .45286 .33241 .45042 .32597 .4436 Mtetra
.607 .719 .925 r
.32597 .4436 .33241 .45042 .34257 .44909 .33621 .44132 Mtetra
0 .115 .644 r
.33621 .44132 .34257 .44909 .35329 .43819 .34588 .4502 Mtetra
.642 .816 .391 r
.34588 .4502 .35329 .43819 .36344 .43859 .3571 .43129 Mtetra
.599 .703 .916 r
.3571 .43129 .36344 .43859 .3738 .43601 .36745 .4292 Mtetra
.626 .73 .921 r
.36745 .4292 .3738 .43601 .3842 .43327 .37788 .42643 Mtetra
.616 .725 .924 r
.37788 .42643 .3842 .43327 .39462 .43152 .38834 .42387 Mtetra
.201 .491 .901 r
.38834 .42387 .39462 .43152 .40546 .41943 .39861 .4277 Mtetra
.612 .849 .479 r
.39861 .4277 .40546 .41943 .41583 .42091 .40961 .4134 Mtetra
.598 .699 .914 r
.40961 .4134 .41583 .42091 .42641 .41816 .42018 .4113 Mtetra
.634 .734 .92 r
.42018 .4113 .42641 .41816 .43704 .41505 .43083 .40827 Mtetra
.64 .74 .921 r
.43083 .40827 .43704 .41505 .44772 .41189 .44154 .40508 Mtetra
.638 .739 .921 r
.44154 .40508 .44772 .41189 .45844 .40892 .45229 .40193 Mtetra
.617 .726 .924 r
.45229 .40193 .45844 .40892 .46917 .40763 .46307 .3993 Mtetra
.939 .571 .204 r
.46307 .3993 .46917 .40763 .4801 .39678 .47317 .44285 Mtetra
0 0 .108 r
.47317 .44285 .4801 .39678 .49092 .39589 .48485 .38851 Mtetra
.617 .716 .916 r
.48485 .38851 .49092 .39589 .50181 .39279 .49577 .38585 Mtetra
.644 .741 .92 r
.49577 .38585 .50181 .39279 .51275 .38934 .50673 .38249 Mtetra
.651 .747 .92 r
.50673 .38249 .51275 .38934 .52374 .38576 .51775 .37894 Mtetra
.654 .75 .92 r
.51775 .37894 .52374 .38576 .53477 .3821 .52881 .37528 Mtetra
.656 .752 .92 r
.52881 .37528 .53477 .3821 .54585 .37837 .53991 .37154 Mtetra
.658 .753 .92 r
.53991 .37154 .54585 .37837 .55697 .3746 .55106 .36776 Mtetra
.659 .754 .92 r
.55106 .36776 .55697 .3746 .56813 .3708 .56226 .36393 Mtetra
.56226 .36393 .56813 .3708 .57934 .36698 .5735 .36008 Mtetra
.5735 .36008 .57934 .36698 .59059 .36315 .58478 .35622 Mtetra
.58478 .35622 .59059 .36315 .60189 .35931 .59611 .35235 Mtetra
.658 .753 .92 r
.59611 .35235 .60189 .35931 .61323 .35546 .60749 .34847 Mtetra
.60749 .34847 .61323 .35546 .62463 .3516 .61891 .34458 Mtetra
.61891 .34458 .62463 .3516 .63606 .34773 .63037 .34068 Mtetra
.63037 .34068 .63606 .34773 .64754 .34385 .64189 .33677 Mtetra
.64189 .33677 .64754 .34385 .65907 .33996 .65345 .33285 Mtetra
.65345 .33285 .65907 .33996 .67065 .33605 .66506 .32891 Mtetra
.657 .753 .92 r
.66506 .32891 .67065 .33605 .68228 .33213 .67672 .32496 Mtetra
.67672 .32496 .68228 .33213 .69395 .3282 .68842 .321 Mtetra
.68842 .321 .69395 .3282 .70567 .32425 .70018 .31702 Mtetra
.70018 .31702 .70567 .32425 .71744 .32029 .71198 .31302 Mtetra
.71198 .31302 .71744 .32029 .72925 .31631 .72383 .30901 Mtetra
.657 .752 .92 r
.72383 .30901 .72925 .31631 .74112 .31232 .73573 .30499 Mtetra
.73573 .30499 .74112 .31232 .75304 .30831 .74768 .30095 Mtetra
.74768 .30095 .75304 .30831 .765 .30428 .75968 .29689 Mtetra
.75968 .29689 .765 .30428 .77702 .30024 .77173 .29282 Mtetra
.77173 .29282 .77702 .30024 .78908 .29618 .78384 .28873 Mtetra
.78384 .28873 .78908 .29618 .8012 .29211 .79599 .28462 Mtetra
.79599 .28462 .8012 .29211 .81336 .28802 .80819 .2805 Mtetra
.704 .808 .346 r
.15708 .51328 .16684 .49295 .17614 .49337 .1694 .48629 Mtetra
.569 .689 .922 r
.1694 .48629 .17614 .49337 .18566 .49217 .17894 .48493 Mtetra
.345 .584 .933 r
.17894 .48493 .18566 .49217 .19651 .478 .18822 .48671 Mtetra
0 0 0 r
.18822 .48671 .19651 .478 .20548 .48306 .19883 .47559 Mtetra
.557 .674 .916 r
.19883 .47559 .20548 .48306 .21516 .4814 .20847 .47448 Mtetra
.556 .692 .93 r
.20847 .47448 .21516 .4814 .22436 .48552 .21817 .47329 Mtetra
.769 .656 .738 r
.21817 .47329 .22436 .48552 .23519 .47207 .22885 .46169 Mtetra
.418 .527 .862 r
.22885 .46169 .23519 .47207 .24498 .47062 .23834 .46371 Mtetra
.594 .708 .923 r
.23834 .46371 .24498 .47062 .25482 .46903 .24823 .46177 Mtetra
.415 .621 .937 r
.24823 .46177 .25482 .46903 .2659 .45252 .25793 .46277 Mtetra
0 0 0 r
.25793 .46277 .2659 .45252 .27514 .45951 .26862 .45184 Mtetra
.565 .675 .913 r
.26862 .45184 .27514 .45951 .28515 .45743 .27858 .45057 Mtetra
.603 .715 .924 r
.27858 .45057 .28515 .45743 .29517 .45582 .28866 .4484 Mtetra
.326 .571 .928 r
.28866 .4484 .29517 .45582 .30602 .44254 .29848 .45054 Mtetra
.568 .846 .509 r
.29848 .45054 .30602 .44254 .31578 .44592 .30932 .43838 Mtetra
.58 .687 .914 r
.30932 .43838 .31578 .44592 .32597 .4436 .31949 .43674 Mtetra
.615 .723 .922 r
.31949 .43674 .32597 .4436 .33621 .44132 .32975 .43425 Mtetra
.562 .697 .931 r
.32975 .43425 .33621 .44132 .34588 .4502 .34 .43286 Mtetra
.725 .593 .708 r
.34 .43286 .34588 .4502 .3571 .43129 .35082 .42187 Mtetra
.497 .598 .884 r
.35082 .42187 .3571 .43129 .36745 .4292 .36106 .42222 Mtetra
.62 .723 .92 r
.36106 .42222 .36745 .4292 .37788 .42643 .3715 .41957 Mtetra
.626 .73 .922 r
.3715 .41957 .37788 .42643 .38834 .42387 .382 .41678 Mtetra
.582 .707 .929 r
.382 .41678 .38834 .42387 .39861 .4277 .3925 .41496 Mtetra
.774 .661 .738 r
.3925 .41496 .39861 .4277 .40961 .4134 .40345 .40278 Mtetra
.458 .55 .862 r
.40345 .40278 .40961 .4134 .42018 .4113 .41391 .40421 Mtetra
.625 .725 .919 r
.41391 .40421 .42018 .4113 .43083 .40827 .42458 .4014 Mtetra
.639 .738 .921 r
.42458 .4014 .43083 .40827 .44154 .40508 .43531 .39823 Mtetra
.64 .74 .921 r
.43531 .39823 .44154 .40508 .45229 .40193 .44608 .395 Mtetra
.632 .735 .922 r
.44608 .395 .45229 .40193 .46307 .3993 .4569 .39196 Mtetra
.557 .693 .931 r
.4569 .39196 .46307 .3993 .47317 .44285 .46773 .39062 Mtetra
.615 .426 .602 r
.46773 .39062 .47317 .44285 .48485 .38851 .47876 .37967 Mtetra
.55 .645 .897 r
.47876 .37967 .48485 .38851 .49577 .38585 .48968 .37872 Mtetra
.636 .734 .919 r
.48968 .37872 .49577 .38585 .50673 .38249 .50067 .37555 Mtetra
.648 .745 .92 r
.50067 .37555 .50673 .38249 .51775 .37894 .51171 .37204 Mtetra
.653 .749 .92 r
.51171 .37204 .51775 .37894 .52881 .37528 .5228 .36839 Mtetra
.655 .751 .92 r
.5228 .36839 .52881 .37528 .53991 .37154 .53394 .36465 Mtetra
.657 .752 .92 r
.53394 .36465 .53991 .37154 .55106 .36776 .54512 .36086 Mtetra
.658 .753 .92 r
.54512 .36086 .55106 .36776 .56226 .36393 .55634 .35701 Mtetra
.659 .754 .92 r
.55634 .35701 .56226 .36393 .5735 .36008 .56761 .35314 Mtetra
.56761 .35314 .5735 .36008 .58478 .35622 .57892 .34925 Mtetra
.57892 .34925 .58478 .35622 .59611 .35235 .59029 .34534 Mtetra
.59029 .34534 .59611 .35235 .60749 .34847 .60169 .34143 Mtetra
.658 .753 .92 r
.60169 .34143 .60749 .34847 .61891 .34458 .61314 .33751 Mtetra
.61314 .33751 .61891 .34458 .63037 .34068 .62464 .33358 Mtetra
.62464 .33358 .63037 .34068 .64189 .33677 .63619 .32964 Mtetra
.63619 .32964 .64189 .33677 .65345 .33285 .64779 .32568 Mtetra
.64779 .32568 .65345 .33285 .66506 .32891 .65943 .32171 Mtetra
.65943 .32171 .66506 .32891 .67672 .32496 .67112 .31773 Mtetra
.657 .753 .92 r
.67112 .31773 .67672 .32496 .68842 .321 .68286 .31374 Mtetra
.68286 .31374 .68842 .321 .70018 .31702 .69465 .30973 Mtetra
.69465 .30973 .70018 .31702 .71198 .31302 .70648 .3057 Mtetra
.70648 .3057 .71198 .31302 .72383 .30901 .71837 .30166 Mtetra
.657 .752 .92 r
.71837 .30166 .72383 .30901 .73573 .30499 .7303 .2976 Mtetra
.7303 .2976 .73573 .30499 .74768 .30095 .74229 .29353 Mtetra
.74229 .29353 .74768 .30095 .75968 .29689 .75432 .28944 Mtetra
.75432 .28944 .75968 .29689 .77173 .29282 .76641 .28534 Mtetra
.76641 .28534 .77173 .29282 .78384 .28873 .77855 .28122 Mtetra
.77855 .28122 .78384 .28873 .79599 .28462 .79074 .27708 Mtetra
.79074 .27708 .79599 .28462 .80819 .2805 .80298 .27293 Mtetra
.673 .516 .665 r
.15232 .48761 .15708 .51328 .1694 .48629 .16279 .47761 Mtetra
.486 .606 .897 r
.16279 .47761 .1694 .48629 .17894 .48493 .17216 .47799 Mtetra
.56 .692 .929 r
.17216 .47799 .17894 .48493 .18822 .48671 .18175 .47673 Mtetra
.812 .696 .736 r
.18175 .47673 .18822 .48671 .19883 .47559 .1927 .46247 Mtetra
.286 .391 .795 r
.1927 .46247 .19883 .47559 .20847 .47448 .20174 .4675 Mtetra
.583 .702 .924 r
.20174 .4675 .20847 .47448 .21817 .47329 .2115 .46579 Mtetra
.117 .446 .881 r
.2115 .46579 .21817 .47329 .22885 .46169 .22077 .46988 Mtetra
.699 .919 .584 r
.22077 .46988 .22885 .46169 .23834 .46371 .2317 .45632 Mtetra
.574 .687 .918 r
.2317 .45632 .23834 .46371 .24823 .46177 .24156 .45482 Mtetra
.577 .703 .928 r
.24156 .45482 .24823 .46177 .25793 .46277 .25149 .45318 Mtetra
.835 .71 .726 r
.25149 .45318 .25793 .46277 .26862 .45184 .26267 .43655 Mtetra
.241 .327 .752 r
.26267 .43655 .26862 .45184 .27858 .45057 .27198 .44352 Mtetra
.6 .71 .921 r
.27198 .44352 .27858 .45057 .28866 .4484 .28207 .44139 Mtetra
.576 .703 .929 r
.28207 .44139 .28866 .4484 .29848 .45054 .29217 .43972 Mtetra
.801 .689 .741 r
.29217 .43972 .29848 .45054 .30932 .43838 .30313 .42634 Mtetra
.374 .469 .829 r
.30313 .42634 .30932 .43838 .31949 .43674 .31297 .42969 Mtetra
.61 .716 .92 r
.31297 .42969 .31949 .43674 .32975 .43425 .32325 .4273 Mtetra
.607 .719 .925 r
.32325 .4273 .32975 .43425 .34 .43286 .33357 .42497 Mtetra
0 .121 .649 r
.33357 .42497 .34 .43286 .35082 .42187 .34331 .43383 Mtetra
.651 .824 .4 r
.34331 .43383 .35082 .42187 .36106 .42222 .35465 .41479 Mtetra
.599 .703 .916 r
.35465 .41479 .36106 .42222 .3715 .41957 .36509 .41265 Mtetra
.626 .73 .921 r
.36509 .41265 .3715 .41957 .382 .41678 .37561 .40981 Mtetra
.616 .725 .924 r
.37561 .40981 .382 .41678 .3925 .41496 .38616 .40719 Mtetra
.204 .492 .901 r
.38616 .40719 .3925 .41496 .40345 .40278 .39652 .41099 Mtetra
.622 .857 .49 r
.39652 .41099 .40345 .40278 .41391 .40421 .40762 .39658 Mtetra
.598 .699 .914 r
.40762 .39658 .41391 .40421 .42458 .4014 .41829 .39441 Mtetra
.634 .734 .92 r
.41829 .39441 .42458 .4014 .43531 .39823 .42904 .39132 Mtetra
.64 .74 .921 r
.42904 .39132 .43531 .39823 .44608 .395 .43984 .38806 Mtetra
.638 .739 .921 r
.43984 .38806 .44608 .395 .4569 .39196 .45068 .38485 Mtetra
.617 .726 .924 r
.45068 .38485 .4569 .39196 .46773 .39062 .46156 .38215 Mtetra
.938 .568 .197 r
.46156 .38215 .46773 .39062 .47876 .37967 .47174 .42583 Mtetra
0 0 .101 r
.47174 .42583 .47876 .37967 .48968 .37872 .48355 .37121 Mtetra
.617 .716 .916 r
.48355 .37121 .48968 .37872 .50067 .37555 .49456 .36848 Mtetra
.644 .741 .92 r
.49456 .36848 .50067 .37555 .51171 .37204 .50563 .36506 Mtetra
.651 .747 .92 r
.50563 .36506 .51171 .37204 .5228 .36839 .51675 .36143 Mtetra
.654 .75 .92 r
.51675 .36143 .5228 .36839 .53394 .36465 .52791 .3577 Mtetra
.656 .752 .92 r
.52791 .3577 .53394 .36465 .54512 .36086 .53912 .3539 Mtetra
.658 .753 .92 r
.53912 .3539 .54512 .36086 .55634 .35701 .55038 .35004 Mtetra
.659 .754 .92 r
.55038 .35004 .55634 .35701 .56761 .35314 .56168 .34614 Mtetra
.56168 .34614 .56761 .35314 .57892 .34925 .57302 .34222 Mtetra
.57302 .34222 .57892 .34925 .59029 .34534 .58442 .33829 Mtetra
.58442 .33829 .59029 .34534 .60169 .34143 .59585 .33434 Mtetra
.658 .753 .92 r
.59585 .33434 .60169 .34143 .61314 .33751 .60734 .33039 Mtetra
.60734 .33039 .61314 .33751 .62464 .33358 .61887 .32642 Mtetra
.61887 .32642 .62464 .33358 .63619 .32964 .63045 .32245 Mtetra
.63045 .32245 .63619 .32964 .64779 .32568 .64208 .31846 Mtetra
.64208 .31846 .64779 .32568 .65943 .32171 .65375 .31446 Mtetra
.65375 .31446 .65943 .32171 .67112 .31773 .66548 .31045 Mtetra
.657 .753 .92 r
.66548 .31045 .67112 .31773 .68286 .31374 .67725 .30642 Mtetra
.67725 .30642 .68286 .31374 .69465 .30973 .68907 .30238 Mtetra
.68907 .30238 .69465 .30973 .70648 .3057 .70094 .29832 Mtetra
.70094 .29832 .70648 .3057 .71837 .30166 .71286 .29425 Mtetra
.71286 .29425 .71837 .30166 .7303 .2976 .72483 .29016 Mtetra
.657 .752 .92 r
.72483 .29016 .7303 .2976 .74229 .29353 .73685 .28606 Mtetra
.73685 .28606 .74229 .29353 .75432 .28944 .74892 .28194 Mtetra
.74892 .28194 .75432 .28944 .76641 .28534 .76105 .2778 Mtetra
.76105 .2778 .76641 .28534 .77855 .28122 .77322 .27364 Mtetra
.77322 .27364 .77855 .28122 .79074 .27708 .78545 .26947 Mtetra
.78545 .26947 .79074 .27708 .80298 .27293 .79772 .26529 Mtetra
.881 .453 .06 r
.14554 .47975 .15232 .48761 .16279 .47761 .15289 .49794 Mtetra
.713 .815 .355 r
.15289 .49794 .16279 .47761 .17216 .47799 .16534 .47079 Mtetra
.569 .689 .922 r
.16534 .47079 .17216 .47799 .18175 .47673 .17496 .46939 Mtetra
.346 .585 .932 r
.17496 .46939 .18175 .47673 .1927 .46247 .1843 .47113 Mtetra
.524 .826 .5 r
.1843 .47113 .1927 .46247 .20174 .4675 .19501 .45991 Mtetra
.557 .674 .916 r
.19501 .45991 .20174 .4675 .2115 .46579 .20473 .45875 Mtetra
.556 .692 .93 r
.20473 .45875 .2115 .46579 .22077 .46988 .21451 .45751 Mtetra
.769 .656 .738 r
.21451 .45751 .22077 .46988 .2317 .45632 .22529 .44581 Mtetra
.417 .527 .862 r
.22529 .44581 .2317 .45632 .24156 .45482 .23485 .44779 Mtetra
.594 .708 .923 r
.23485 .44779 .24156 .45482 .25149 .45318 .24483 .4458 Mtetra
.416 .621 .937 r
.24483 .4458 .25149 .45318 .26267 .43655 .2546 .44675 Mtetra
0 0 0 r
.2546 .44675 .26267 .43655 .27198 .44352 .26539 .43574 Mtetra
.564 .675 .913 r
.26539 .43574 .27198 .44352 .28207 .44139 .27543 .43441 Mtetra
.603 .715 .924 r
.27543 .43441 .28207 .44139 .29217 .43972 .2856 .43218 Mtetra
.328 .571 .928 r
.2856 .43218 .29217 .43972 .30313 .42634 .2955 .43429 Mtetra
.579 .855 .52 r
.2955 .43429 .30313 .42634 .31297 .42969 .30644 .42202 Mtetra
.58 .687 .914 r
.30644 .42202 .31297 .42969 .32325 .4273 .31669 .42032 Mtetra
.615 .723 .922 r
.31669 .42032 .32325 .4273 .33357 .42497 .32705 .41777 Mtetra
.562 .697 .931 r
.32705 .41777 .33357 .42497 .34331 .43383 .33739 .41633 Mtetra
.725 .593 .708 r
.33739 .41633 .34331 .43383 .35465 .41479 .34831 .40524 Mtetra
.496 .598 .885 r
.34831 .40524 .35465 .41479 .36509 .41265 .35863 .40554 Mtetra
.62 .723 .92 r
.35863 .40554 .36509 .41265 .37561 .40981 .36917 .40283 Mtetra
.626 .73 .922 r
.36917 .40283 .37561 .40981 .38616 .40719 .37976 .39998 Mtetra
.582 .707 .928 r
.37976 .39998 .38616 .40719 .39652 .41099 .39035 .3981 Mtetra
.775 .662 .738 r
.39035 .3981 .39652 .41099 .40762 .39658 .4014 .38581 Mtetra
.457 .549 .862 r
.4014 .38581 .40762 .39658 .41829 .39441 .41196 .3872 Mtetra
.625 .725 .919 r
.41196 .3872 .41829 .39441 .42904 .39132 .42272 .38432 Mtetra
.639 .738 .921 r
.42272 .38432 .42904 .39132 .43984 .38806 .43355 .38108 Mtetra
.64 .74 .921 r
.43355 .38108 .43984 .38806 .45068 .38485 .44442 .37779 Mtetra
.632 .735 .922 r
.44442 .37779 .45068 .38485 .46156 .38215 .45533 .37469 Mtetra
.557 .693 .931 r
.45533 .37469 .46156 .38215 .47174 .42583 .46626 .37328 Mtetra
.614 .424 .601 r
.46626 .37328 .47174 .42583 .48355 .37121 .4774 .36223 Mtetra
.55 .645 .897 r
.4774 .36223 .48355 .37121 .49456 .36848 .48841 .36123 Mtetra
.636 .734 .919 r
.48841 .36123 .49456 .36848 .50563 .36506 .49951 .35798 Mtetra
.648 .745 .92 r
.49951 .35798 .50563 .36506 .51675 .36143 .51065 .3544 Mtetra
.653 .749 .92 r
.51065 .3544 .51675 .36143 .52791 .3577 .52185 .35068 Mtetra
.655 .751 .92 r
.52185 .35068 .52791 .3577 .53912 .3539 .53309 .34687 Mtetra
.657 .752 .92 r
.53309 .34687 .53912 .3539 .55038 .35004 .54437 .343 Mtetra
.658 .753 .92 r
.54437 .343 .55038 .35004 .56168 .34614 .5557 .33909 Mtetra
.659 .754 .92 r
.5557 .33909 .56168 .34614 .57302 .34222 .56708 .33514 Mtetra
.56708 .33514 .57302 .34222 .58442 .33829 .5785 .33117 Mtetra
.5785 .33117 .58442 .33829 .59585 .33434 .58997 .3272 Mtetra
.58997 .3272 .59585 .33434 .60734 .33039 .60149 .32321 Mtetra
.658 .753 .92 r
.60149 .32321 .60734 .33039 .61887 .32642 .61305 .31921 Mtetra
.61305 .31921 .61887 .32642 .63045 .32245 .62467 .3152 Mtetra
.62467 .3152 .63045 .32245 .64208 .31846 .63633 .31119 Mtetra
.63633 .31119 .64208 .31846 .65375 .31446 .64803 .30715 Mtetra
.64803 .30715 .65375 .31446 .66548 .31045 .65979 .30311 Mtetra
.65979 .30311 .66548 .31045 .67725 .30642 .6716 .29905 Mtetra
.657 .753 .92 r
.6716 .29905 .67725 .30642 .68907 .30238 .68345 .29497 Mtetra
.68345 .29497 .68907 .30238 .70094 .29832 .69536 .29089 Mtetra
.69536 .29089 .70094 .29832 .71286 .29425 .70731 .28678 Mtetra
.70731 .28678 .71286 .29425 .72483 .29016 .71932 .28266 Mtetra
.657 .752 .92 r
.71932 .28266 .72483 .29016 .73685 .28606 .73137 .27852 Mtetra
.73137 .27852 .73685 .28606 .74892 .28194 .74348 .27437 Mtetra
.74348 .27437 .74892 .28194 .76105 .2778 .75564 .2702 Mtetra
.75564 .2702 .76105 .2778 .77322 .27364 .76785 .26601 Mtetra
.76785 .26601 .77322 .27364 .78545 .26947 .78011 .26181 Mtetra
.78011 .26181 .78545 .26947 .79772 .26529 .79243 .25759 Mtetra
.516 .672 .934 r
.13864 .47263 .14554 .47975 .15289 .49794 .14809 .47208 Mtetra
.673 .516 .664 r
.14809 .47208 .15289 .49794 .16534 .47079 .15866 .46199 Mtetra
.485 .606 .898 r
.15866 .46199 .16534 .47079 .17496 .46939 .1681 .46232 Mtetra
.56 .692 .929 r
.1681 .46232 .17496 .46939 .1843 .47113 .17777 .46102 Mtetra
.813 .696 .737 r
.17777 .46102 .1843 .47113 .19501 .45991 .18883 .44665 Mtetra
.284 .39 .795 r
.18883 .44665 .19501 .45991 .20473 .45875 .19793 .45165 Mtetra
.583 .702 .924 r
.19793 .45165 .20473 .45875 .21451 .45751 .20777 .44989 Mtetra
.12 .448 .882 r
.20777 .44989 .21451 .45751 .22529 .44581 .21711 .45395 Mtetra
.707 .925 .593 r
.21711 .45395 .22529 .44581 .23485 .44779 .22814 .44029 Mtetra
.574 .687 .918 r
.22814 .44029 .23485 .44779 .24483 .4458 .23809 .43873 Mtetra
.577 .703 .928 r
.23809 .43873 .24483 .4458 .2546 .44675 .24809 .43704 Mtetra
.836 .711 .726 r
.24809 .43704 .2546 .44675 .26539 .43574 .25938 .42029 Mtetra
.239 .325 .751 r
.25938 .42029 .26539 .43574 .27543 .43441 .26876 .42724 Mtetra
.6 .71 .921 r
.26876 .42724 .27543 .43441 .2856 .43218 .27894 .42505 Mtetra
.577 .703 .929 r
.27894 .42505 .2856 .43218 .2955 .43429 .28913 .42333 Mtetra
.802 .69 .742 r
.28913 .42333 .2955 .43429 .30644 .42202 .30019 .40984 Mtetra
.373 .469 .829 r
.30019 .40984 .30644 .42202 .31669 .42032 .31011 .41315 Mtetra
.61 .716 .92 r
.31011 .41315 .31669 .42032 .32705 .41777 .32047 .41071 Mtetra
.607 .719 .925 r
.32047 .41071 .32705 .41777 .33739 .41633 .33088 .40831 Mtetra
0 .126 .654 r
.33088 .40831 .33739 .41633 .34831 .40524 .3407 .41716 Mtetra
.661 .831 .41 r
.3407 .41716 .34831 .40524 .35863 .40554 .35215 .39799 Mtetra
.599 .703 .916 r
.35215 .39799 .35863 .40554 .36917 .40283 .36268 .39578 Mtetra
.626 .73 .921 r
.36268 .39578 .36917 .40283 .37976 .39998 .37329 .39288 Mtetra
.616 .725 .924 r
.37329 .39288 .37976 .39998 .39035 .3981 .38395 .3902 Mtetra
.207 .493 .901 r
.38395 .3902 .39035 .3981 .4014 .38581 .39438 .39396 Mtetra
.632 .865 .5 r
.39438 .39396 .4014 .38581 .41196 .3872 .4056 .37944 Mtetra
.598 .699 .914 r
.4056 .37944 .41196 .3872 .42272 .38432 .41636 .3772 Mtetra
.634 .734 .92 r
.41636 .3772 .42272 .38432 .43355 .38108 .42721 .37404 Mtetra
.64 .74 .921 r
.42721 .37404 .43355 .38108 .44442 .37779 .43811 .37072 Mtetra
.638 .739 .921 r
.43811 .37072 .44442 .37779 .45533 .37469 .44905 .36744 Mtetra
.617 .726 .924 r
.44905 .36744 .45533 .37469 .46626 .37328 .46003 .36467 Mtetra
.936 .566 .19 r
.46003 .36467 .46626 .37328 .4774 .36223 .47028 .40848 Mtetra
0 0 .093 r
.47028 .40848 .4774 .36223 .48841 .36123 .48222 .35358 Mtetra
.617 .716 .916 r
.48222 .35358 .48841 .36123 .49951 .35798 .49334 .35078 Mtetra
.644 .741 .92 r
.49334 .35078 .49951 .35798 .51065 .3544 .50451 .34729 Mtetra
.651 .747 .92 r
.50451 .34729 .51065 .3544 .52185 .35068 .51573 .34359 Mtetra
.654 .75 .92 r
.51573 .34359 .52185 .35068 .53309 .34687 .527 .33979 Mtetra
.656 .752 .92 r
.527 .33979 .53309 .34687 .54437 .343 .53832 .33591 Mtetra
.658 .753 .92 r
.53832 .33591 .54437 .343 .5557 .33909 .54968 .33198 Mtetra
.659 .754 .92 r
.54968 .33198 .5557 .33909 .56708 .33514 .56109 .32801 Mtetra
.56109 .32801 .56708 .33514 .5785 .33117 .57254 .32401 Mtetra
.57254 .32401 .5785 .33117 .58997 .3272 .58405 .32 Mtetra
.58405 .32 .58997 .3272 .60149 .32321 .59559 .31598 Mtetra
.658 .753 .92 r
.59559 .31598 .60149 .32321 .61305 .31921 .60719 .31195 Mtetra
.60719 .31195 .61305 .31921 .62467 .3152 .61884 .30791 Mtetra
.61884 .30791 .62467 .3152 .63633 .31119 .63053 .30385 Mtetra
.63053 .30385 .63633 .31119 .64803 .30715 .64227 .29979 Mtetra
.64227 .29979 .64803 .30715 .65979 .30311 .65406 .29571 Mtetra
.65406 .29571 .65979 .30311 .6716 .29905 .6659 .29162 Mtetra
.657 .753 .92 r
.6659 .29162 .6716 .29905 .68345 .29497 .67779 .28751 Mtetra
.67779 .28751 .68345 .29497 .69536 .29089 .68973 .28339 Mtetra
.68973 .28339 .69536 .29089 .70731 .28678 .70172 .27925 Mtetra
.70172 .27925 .70731 .28678 .71932 .28266 .71376 .2751 Mtetra
.71376 .2751 .71932 .28266 .73137 .27852 .72585 .27093 Mtetra
.657 .752 .92 r
.72585 .27093 .73137 .27852 .74348 .27437 .738 .26674 Mtetra
.738 .26674 .74348 .27437 .75564 .2702 .75019 .26254 Mtetra
.75019 .26254 .75564 .2702 .76785 .26601 .76244 .25832 Mtetra
.76244 .25832 .76785 .26601 .78011 .26181 .77474 .25409 Mtetra
.77474 .25409 .78011 .26181 .79243 .25759 .78709 .24983 Mtetra
.561 .688 .925 r
.13169 .46542 .13864 .47263 .14809 .47208 .14125 .4641 Mtetra
.878 .45 .052 r
.14125 .4641 .14809 .47208 .15866 .46199 .14862 .48233 Mtetra
.721 .822 .364 r
.14862 .48233 .15866 .46199 .1681 .46232 .16122 .45502 Mtetra
.569 .689 .922 r
.16122 .45502 .1681 .46232 .17777 .46102 .17091 .45355 Mtetra
.347 .585 .932 r
.17091 .45355 .17777 .46102 .18883 .44665 .18032 .45526 Mtetra
.537 .837 .514 r
.18032 .45526 .18883 .44665 .19793 .45165 .19113 .44394 Mtetra
.557 .674 .916 r
.19113 .44394 .19793 .45165 .20777 .44989 .20093 .44273 Mtetra
.556 .692 .93 r
.20093 .44273 .20777 .44989 .21711 .45395 .21078 .44144 Mtetra
.769 .657 .738 r
.21078 .44144 .21711 .45395 .22814 .44029 .22167 .42965 Mtetra
.416 .527 .862 r
.22167 .42965 .22814 .44029 .23809 .43873 .2313 .43159 Mtetra
.594 .708 .923 r
.2313 .43159 .23809 .43873 .24809 .43704 .24136 .42954 Mtetra
.416 .621 .936 r
.24136 .42954 .24809 .43704 .25938 .42029 .25121 .43044 Mtetra
0 0 0 r
.25121 .43044 .25938 .42029 .26876 .42724 .2621 .41933 Mtetra
.564 .675 .913 r
.2621 .41933 .26876 .42724 .27894 .42505 .27223 .41795 Mtetra
.603 .715 .924 r
.27223 .41795 .27894 .42505 .28913 .42333 .28248 .41566 Mtetra
.329 .572 .928 r
.28248 .41566 .28913 .42333 .30019 .40984 .29246 .41772 Mtetra
.591 .864 .532 r
.29246 .41772 .30019 .40984 .31011 .41315 .30351 .40536 Mtetra
.58 .687 .915 r
.30351 .40536 .31011 .41315 .32047 .41071 .31385 .4036 Mtetra
.615 .723 .922 r
.31385 .4036 .32047 .41071 .33088 .40831 .32429 .40099 Mtetra
.563 .697 .931 r
.32429 .40099 .33088 .40831 .3407 .41716 .33472 .39949 Mtetra
.725 .593 .708 r
.33472 .39949 .3407 .41716 .35215 .39799 .34574 .3883 Mtetra
.496 .598 .885 r
.34574 .3883 .35215 .39799 .36268 .39578 .35616 .38855 Mtetra
.62 .723 .92 r
.35616 .38855 .36268 .39578 .37329 .39288 .36678 .38578 Mtetra
.626 .73 .922 r
.36678 .38578 .37329 .39288 .38395 .3902 .37747 .38286 Mtetra
.582 .707 .928 r
.37747 .38286 .38395 .3902 .39438 .39396 .38816 .38092 Mtetra
.775 .662 .738 r
.38816 .38092 .39438 .39396 .4056 .37944 .39932 .36853 Mtetra
.457 .549 .862 r
.39932 .36853 .4056 .37944 .41636 .3772 .40996 .36986 Mtetra
.625 .725 .919 r
.40996 .36986 .41636 .3772 .42721 .37404 .42083 .36692 Mtetra
.639 .738 .921 r
.42083 .36692 .42721 .37404 .43811 .37072 .43175 .36361 Mtetra
.64 .74 .921 r
.43175 .36361 .43811 .37072 .44905 .36744 .44272 .36025 Mtetra
.632 .735 .922 r
.44272 .36025 .44905 .36744 .46003 .36467 .45374 .35708 Mtetra
.557 .693 .931 r
.45374 .35708 .46003 .36467 .47028 .40848 .46477 .35561 Mtetra
.613 .422 .599 r
.46477 .35561 .47028 .40848 .48222 .35358 .47601 .34446 Mtetra
.549 .645 .897 r
.47601 .34446 .48222 .35358 .49334 .35078 .48712 .3434 Mtetra
.636 .734 .919 r
.48712 .3434 .49334 .35078 .50451 .34729 .49832 .34008 Mtetra
.648 .745 .92 r
.49832 .34008 .50451 .34729 .51573 .34359 .50957 .33643 Mtetra
.653 .749 .92 r
.50957 .33643 .51573 .34359 .527 .33979 .52087 .33263 Mtetra
.655 .751 .92 r
.52087 .33263 .527 .33979 .53832 .33591 .53222 .32875 Mtetra
.657 .752 .92 r
.53222 .32875 .53832 .33591 .54968 .33198 .54361 .32481 Mtetra
.658 .753 .92 r
.54361 .32481 .54968 .33198 .56109 .32801 .55505 .32081 Mtetra
.659 .754 .92 r
.55505 .32081 .56109 .32801 .57254 .32401 .56654 .31679 Mtetra
.56654 .31679 .57254 .32401 .58405 .32 .57807 .31275 Mtetra
.57807 .31275 .58405 .32 .59559 .31598 .58965 .30869 Mtetra
.58965 .30869 .59559 .31598 .60719 .31195 .60128 .30463 Mtetra
.658 .753 .92 r
.60128 .30463 .60719 .31195 .61884 .30791 .61296 .30055 Mtetra
.61296 .30055 .61884 .30791 .63053 .30385 .62469 .29647 Mtetra
.62469 .29647 .63053 .30385 .64227 .29979 .63646 .29237 Mtetra
.63646 .29237 .64227 .29979 .65406 .29571 .64829 .28826 Mtetra
.64829 .28826 .65406 .29571 .6659 .29162 .66016 .28413 Mtetra
.66016 .28413 .6659 .29162 .67779 .28751 .67208 .27999 Mtetra
.657 .753 .92 r
.67208 .27999 .67779 .28751 .68973 .28339 .68406 .27584 Mtetra
.68406 .27584 .68973 .28339 .70172 .27925 .69608 .27167 Mtetra
.69608 .27167 .70172 .27925 .71376 .2751 .70816 .26748 Mtetra
.70816 .26748 .71376 .2751 .72585 .27093 .72029 .26328 Mtetra
.657 .752 .92 r
.72029 .26328 .72585 .27093 .738 .26674 .73247 .25906 Mtetra
.73247 .25906 .738 .26674 .75019 .26254 .7447 .25482 Mtetra
.7447 .25482 .75019 .26254 .76244 .25832 .75698 .25057 Mtetra
.75698 .25057 .76244 .25832 .77474 .25409 .76932 .2463 Mtetra
.76932 .2463 .77474 .25409 .78709 .24983 .78171 .24201 Mtetra
.507 .632 .908 r
.12484 .45707 .13169 .46542 .14125 .4641 .13427 .45687 Mtetra
.517 .672 .934 r
.13427 .45687 .14125 .4641 .14862 .48233 .1438 .45626 Mtetra
.672 .515 .664 r
.1438 .45626 .14862 .48233 .16122 .45502 .15446 .44609 Mtetra
.485 .606 .898 r
.15446 .44609 .16122 .45502 .17091 .45355 .16397 .44638 Mtetra
.56 .692 .929 r
.16397 .44638 .17091 .45355 .18032 .45526 .17372 .44502 Mtetra
.813 .697 .737 r
.17372 .44502 .18032 .45526 .19113 .44394 .18488 .43054 Mtetra
.282 .389 .795 r
.18488 .43054 .19113 .44394 .20093 .44273 .19405 .43552 Mtetra
.583 .702 .924 r
.19405 .43552 .20093 .44273 .21078 .44144 .20397 .43369 Mtetra
.123 .449 .882 r
.20397 .43369 .21078 .44144 .22167 .42965 .21338 .43773 Mtetra
.716 .93 .602 r
.21338 .43773 .22167 .42965 .2313 .43159 .22452 .42396 Mtetra
.574 .687 .918 r
.22452 .42396 .2313 .43159 .24136 .42954 .23455 .42234 Mtetra
.577 .703 .928 r
.23455 .42234 .24136 .42954 .25121 .43044 .24464 .4206 Mtetra
.837 .712 .726 r
.24464 .4206 .25121 .43044 .2621 .41933 .25604 .40373 Mtetra
.236 .324 .751 r
.25604 .40373 .2621 .41933 .27223 .41795 .26549 .41065 Mtetra
.6 .71 .921 r
.26549 .41065 .27223 .41795 .28248 .41566 .27575 .4084 Mtetra
.577 .703 .929 r
.27575 .4084 .28248 .41566 .29246 .41772 .28602 .40663 Mtetra
.802 .691 .742 r
.28602 .40663 .29246 .41772 .30351 .40536 .29719 .39303 Mtetra
.372 .468 .829 r
.29719 .39303 .30351 .40536 .31385 .4036 .30719 .3963 Mtetra
.61 .716 .92 r
.30719 .3963 .31385 .4036 .32429 .40099 .31765 .3938 Mtetra
.607 .719 .925 r
.31765 .3938 .32429 .40099 .33472 .39949 .32815 .39134 Mtetra
0 .131 .659 r
.32815 .39134 .33472 .39949 .34574 .3883 .33805 .40017 Mtetra
.67 .838 .419 r
.33805 .40017 .34574 .3883 .35616 .38855 .34961 .38087 Mtetra
.599 .703 .917 r
.34961 .38087 .35616 .38855 .36678 .38578 .36023 .3786 Mtetra
.626 .73 .921 r
.36023 .3786 .36678 .38578 .37747 .38286 .37094 .37563 Mtetra
.616 .725 .924 r
.37094 .37563 .37747 .38286 .38816 .38092 .38169 .37289 Mtetra
.21 .495 .902 r
.38169 .37289 .38816 .38092 .39932 .36853 .39221 .3766 Mtetra
.642 .872 .51 r
.39221 .3766 .39932 .36853 .40996 .36986 .40353 .36197 Mtetra
.598 .7 .914 r
.40353 .36197 .40996 .36986 .42083 .36692 .4144 .35967 Mtetra
.634 .734 .92 r
.4144 .35967 .42083 .36692 .43175 .36361 .42534 .35644 Mtetra
.64 .74 .921 r
.42534 .35644 .43175 .36361 .44272 .36025 .43634 .35305 Mtetra
.638 .739 .921 r
.43634 .35305 .44272 .36025 .45374 .35708 .44739 .3497 Mtetra
.617 .726 .924 r
.44739 .3497 .45374 .35708 .46477 .35561 .45847 .34686 Mtetra
.934 .563 .182 r
.45847 .34686 .46477 .35561 .47601 .34446 .46879 .39079 Mtetra
0 0 .085 r
.46879 .39079 .47601 .34446 .48712 .3434 .48087 .33561 Mtetra
.617 .716 .916 r
.48087 .33561 .48712 .3434 .49832 .34008 .49209 .33275 Mtetra
.644 .741 .92 r
.49209 .33275 .49832 .34008 .50957 .33643 .50337 .32918 Mtetra
.651 .747 .92 r
.50337 .32918 .50957 .33643 .52087 .33263 .5147 .32541 Mtetra
.654 .75 .92 r
.5147 .32541 .52087 .33263 .53222 .32875 .52607 .32153 Mtetra
.656 .752 .92 r
.52607 .32153 .53222 .32875 .54361 .32481 .5375 .31757 Mtetra
.658 .753 .92 r
.5375 .31757 .54361 .32481 .55505 .32081 .54897 .31356 Mtetra
.659 .754 .92 r
.54897 .31356 .55505 .32081 .56654 .31679 .56049 .30952 Mtetra
.56049 .30952 .56654 .31679 .57807 .31275 .57205 .30544 Mtetra
.57205 .30544 .57807 .31275 .58965 .30869 .58367 .30135 Mtetra
.58367 .30135 .58965 .30869 .60128 .30463 .59533 .29725 Mtetra
.658 .753 .92 r
.59533 .29725 .60128 .30463 .61296 .30055 .60704 .29314 Mtetra
.60704 .29314 .61296 .30055 .62469 .29647 .6188 .28902 Mtetra
.6188 .28902 .62469 .29647 .63646 .29237 .63061 .28489 Mtetra
.63061 .28489 .63646 .29237 .64829 .28826 .64247 .28075 Mtetra
.64247 .28075 .64829 .28826 .66016 .28413 .65437 .27659 Mtetra
.65437 .27659 .66016 .28413 .67208 .27999 .66633 .27242 Mtetra
.657 .753 .92 r
.66633 .27242 .67208 .27999 .68406 .27584 .67834 .26823 Mtetra
.67834 .26823 .68406 .27584 .69608 .27167 .6904 .26402 Mtetra
.6904 .26402 .69608 .27167 .70816 .26748 .70251 .2598 Mtetra
.70251 .2598 .70816 .26748 .72029 .26328 .71468 .25557 Mtetra
.71468 .25557 .72029 .26328 .73247 .25906 .72689 .25131 Mtetra
.657 .752 .92 r
.72689 .25131 .73247 .25906 .7447 .25482 .73916 .24704 Mtetra
.73916 .24704 .7447 .25482 .75698 .25057 .75148 .24276 Mtetra
.75148 .24276 .75698 .25057 .76932 .2463 .76386 .23845 Mtetra
.76386 .23845 .76932 .2463 .78171 .24201 .77628 .23413 Mtetra
0 0 .152 r
.1311 .34288 .12484 .45707 .13427 .45687 .12725 .44954 Mtetra
.561 .688 .925 r
.12725 .44954 .13427 .45687 .1438 .45626 .13688 .44817 Mtetra
.876 .446 .045 r
.13688 .44817 .1438 .45626 .15446 .44609 .14428 .46643 Mtetra
.73 .828 .373 r
.14428 .46643 .15446 .44609 .16397 .44638 .15701 .43895 Mtetra
.569 .689 .922 r
.15701 .43895 .16397 .44638 .17372 .44502 .16678 .43744 Mtetra
.348 .585 .932 r
.16678 .43744 .17372 .44502 .18488 .43054 .17627 .4391 Mtetra
.55 .847 .527 r
.17627 .4391 .18488 .43054 .19405 .43552 .18718 .42769 Mtetra
.557 .674 .916 r
.18718 .42769 .19405 .43552 .20397 .43369 .19705 .42642 Mtetra
.556 .692 .93 r
.19705 .42642 .20397 .43369 .21338 .43773 .20699 .42507 Mtetra
.77 .658 .739 r
.20699 .42507 .21338 .43773 .22452 .42396 .21798 .41318 Mtetra
.415 .527 .862 r
.21798 .41318 .22452 .42396 .23455 .42234 .22769 .41508 Mtetra
.594 .708 .923 r
.22769 .41508 .23455 .42234 .24464 .4206 .23783 .41297 Mtetra
.417 .621 .936 r
.23783 .41297 .24464 .4206 .25604 .40373 .24776 .41383 Mtetra
0 0 0 r
.24776 .41383 .25604 .40373 .26549 .41065 .25875 .40262 Mtetra
.564 .675 .913 r
.25875 .40262 .26549 .41065 .27575 .4084 .26897 .40118 Mtetra
.603 .715 .924 r
.26897 .40118 .27575 .4084 .28602 .40663 .2793 .39883 Mtetra
.331 .572 .928 r
.2793 .39883 .28602 .40663 .29719 .39303 .28937 .40085 Mtetra
.602 .873 .543 r
.28937 .40085 .29719 .39303 .30719 .3963 .30052 .38838 Mtetra
.579 .687 .915 r
.30052 .38838 .30719 .3963 .31765 .3938 .31095 .38657 Mtetra
.615 .723 .922 r
.31095 .38657 .31765 .3938 .32815 .39134 .32149 .38389 Mtetra
.563 .697 .93 r
.32149 .38389 .32815 .39134 .33805 .40017 .332 .38233 Mtetra
.725 .594 .708 r
.332 .38233 .33805 .40017 .34961 .38087 .34313 .37104 Mtetra
.496 .598 .885 r
.34313 .37104 .34961 .38087 .36023 .3786 .35363 .37124 Mtetra
.62 .723 .92 r
.35363 .37124 .36023 .3786 .37094 .37563 .36436 .3684 Mtetra
.626 .73 .922 r
.36436 .3684 .37094 .37563 .38169 .37289 .37514 .36541 Mtetra
.582 .707 .928 r
.37514 .36541 .38169 .37289 .39221 .3766 .38593 .36341 Mtetra
.776 .663 .739 r
.38593 .36341 .39221 .3766 .40353 .36197 .39719 .35091 Mtetra
.456 .549 .862 r
.39719 .35091 .40353 .36197 .4144 .35967 .40793 .3522 Mtetra
.625 .725 .919 r
.40793 .3522 .4144 .35967 .42534 .35644 .41889 .34919 Mtetra
.639 .738 .921 r
.41889 .34919 .42534 .35644 .43634 .35305 .42992 .34581 Mtetra
.64 .74 .921 r
.42992 .34581 .43634 .35305 .44739 .3497 .44099 .34237 Mtetra
.632 .735 .922 r
.44099 .34237 .44739 .3497 .45847 .34686 .45211 .33913 Mtetra
.557 .693 .931 r
.45211 .33913 .45847 .34686 .46879 .39079 .46324 .3376 Mtetra
.611 .419 .598 r
.46324 .3376 .46879 .39079 .48087 .33561 .47459 .32635 Mtetra
.549 .645 .897 r
.47459 .32635 .48087 .33561 .49209 .33275 .48581 .32522 Mtetra
.636 .734 .919 r
.48581 .32522 .49209 .33275 .50337 .32918 .49712 .32183 Mtetra
.648 .745 .92 r
.49712 .32183 .50337 .32918 .5147 .32541 .50847 .3181 Mtetra
.653 .749 .92 r
.50847 .3181 .5147 .32541 .52607 .32153 .51988 .31423 Mtetra
.655 .751 .92 r
.51988 .31423 .52607 .32153 .5375 .31757 .53134 .31027 Mtetra
.657 .752 .92 r
.53134 .31027 .5375 .31757 .54897 .31356 .54284 .30625 Mtetra
.658 .753 .92 r
.54284 .30625 .54897 .31356 .56049 .30952 .55439 .30218 Mtetra
.659 .754 .92 r
.55439 .30218 .56049 .30952 .57205 .30544 .56599 .29808 Mtetra
.56599 .29808 .57205 .30544 .58367 .30135 .57763 .29396 Mtetra
.57763 .29396 .58367 .30135 .59533 .29725 .58933 .28982 Mtetra
.58933 .28982 .59533 .29725 .60704 .29314 .60107 .28568 Mtetra
.658 .753 .92 r
.60107 .28568 .60704 .29314 .6188 .28902 .61286 .28152 Mtetra
.61286 .28152 .6188 .28902 .63061 .28489 .62471 .27736 Mtetra
.62471 .27736 .63061 .28489 .64247 .28075 .6366 .27318 Mtetra
.6366 .27318 .64247 .28075 .65437 .27659 .64854 .26899 Mtetra
.64854 .26899 .65437 .27659 .66633 .27242 .66054 .26478 Mtetra
.66054 .26478 .66633 .27242 .67834 .26823 .67258 .26056 Mtetra
.657 .753 .92 r
.67258 .26056 .67834 .26823 .6904 .26402 .68468 .25632 Mtetra
.68468 .25632 .6904 .26402 .70251 .2598 .69682 .25207 Mtetra
.69682 .25207 .70251 .2598 .71468 .25557 .70902 .2478 Mtetra
.70902 .2478 .71468 .25557 .72689 .25131 .72128 .24351 Mtetra
.657 .752 .92 r
.72128 .24351 .72689 .25131 .73916 .24704 .73358 .2392 Mtetra
.73358 .2392 .73916 .24704 .75148 .24276 .74594 .23488 Mtetra
.74594 .23488 .75148 .24276 .76386 .23845 .75835 .23054 Mtetra
.75835 .23054 .76386 .23845 .77628 .23413 .77081 .22618 Mtetra
.466 .215 .45 r
.10964 .45104 .1311 .34288 .12725 .44954 .12031 .44107 Mtetra
.507 .632 .908 r
.12031 .44107 .12725 .44954 .13688 .44817 .12982 .44082 Mtetra
.517 .672 .934 r
.12982 .44082 .13688 .44817 .14428 .46643 .13942 .44016 Mtetra
.672 .514 .663 r
.13942 .44016 .14428 .46643 .15701 .43895 .15018 .4299 Mtetra
.485 .606 .898 r
.15018 .4299 .15701 .43895 .16678 .43744 .15977 .43014 Mtetra
.56 .692 .929 r
.15977 .43014 .16678 .43744 .17627 .4391 .16959 .42873 Mtetra
.814 .698 .737 r
.16959 .42873 .17627 .4391 .18718 .42769 .18087 .41414 Mtetra
.28 .388 .795 r
.18087 .41414 .18718 .42769 .19705 .42642 .1901 .41908 Mtetra
.583 .702 .924 r
.1901 .41908 .19705 .42642 .20699 .42507 .2001 .4172 Mtetra
.127 .451 .883 r
.2001 .4172 .20699 .42507 .21798 .41318 .20958 .4212 Mtetra
.723 .935 .61 r
.20958 .4212 .21798 .41318 .22769 .41508 .22083 .40733 Mtetra
.574 .687 .918 r
.22083 .40733 .22769 .41508 .23783 .41297 .23094 .40565 Mtetra
.577 .703 .928 r
.23094 .40565 .23783 .41297 .24776 .41383 .24111 .40385 Mtetra
.838 .713 .726 r
.24111 .40385 .24776 .41383 .25875 .40262 .25263 .38686 Mtetra
.234 .322 .75 r
.25263 .38686 .25875 .40262 .26897 .40118 .26215 .39376 Mtetra
.6 .71 .921 r
.26215 .39376 .26897 .40118 .2793 .39883 .2725 .39145 Mtetra
.577 .703 .928 r
.2725 .39145 .2793 .39883 .28937 .40085 .28286 .38961 Mtetra
.803 .692 .742 r
.28286 .38961 .28937 .40085 .30052 .38838 .29413 .37591 Mtetra
.371 .468 .829 r
.29413 .37591 .30052 .38838 .31095 .38657 .30422 .37914 Mtetra
.61 .716 .92 r
.30422 .37914 .31095 .38657 .32149 .38389 .31477 .37657 Mtetra
.607 .719 .925 r
.31477 .37657 .32149 .38389 .332 .38233 .32536 .37404 Mtetra
0 .137 .664 r
.32536 .37404 .332 .38233 .34313 .37104 .33534 .38286 Mtetra
.679 .845 .429 r
.33534 .38286 .34313 .37104 .35363 .37124 .34701 .36342 Mtetra
.599 .703 .917 r
.34701 .36342 .35363 .37124 .36436 .3684 .35773 .36109 Mtetra
.626 .73 .921 r
.35773 .36109 .36436 .3684 .37514 .36541 .36854 .35805 Mtetra
.616 .725 .924 r
.36854 .35805 .37514 .36541 .38593 .36341 .37938 .35524 Mtetra
.213 .496 .902 r
.37938 .35524 .38593 .36341 .39719 .35091 .39 .35892 Mtetra
.652 .879 .519 r
.39 .35892 .39719 .35091 .40793 .3522 .40143 .34417 Mtetra
.598 .7 .914 r
.40143 .34417 .40793 .3522 .41889 .34919 .4124 .3418 Mtetra
.634 .734 .92 r
.4124 .3418 .41889 .34919 .42992 .34581 .42344 .3385 Mtetra
.64 .74 .921 r
.42344 .3385 .42992 .34581 .44099 .34237 .43454 .33504 Mtetra
.638 .739 .921 r
.43454 .33504 .44099 .34237 .45211 .33913 .44569 .33162 Mtetra
.617 .726 .924 r
.44569 .33162 .45211 .33913 .46324 .3376 .45688 .32871 Mtetra
.933 .56 .175 r
.45688 .32871 .46324 .3376 .47459 .32635 .46727 .37276 Mtetra
0 0 .077 r
.46727 .37276 .47459 .32635 .48581 .32522 .47949 .31729 Mtetra
.617 .716 .916 r
.47949 .31729 .48581 .32522 .49712 .32183 .49082 .31435 Mtetra
.644 .741 .92 r
.49082 .31435 .49712 .32183 .50847 .3181 .5022 .31071 Mtetra
.651 .747 .92 r
.5022 .31071 .50847 .3181 .51988 .31423 .51364 .30686 Mtetra
.654 .75 .92 r
.51364 .30686 .51988 .31423 .53134 .31027 .52513 .30291 Mtetra
.656 .752 .92 r
.52513 .30291 .53134 .31027 .54284 .30625 .53666 .29887 Mtetra
.658 .753 .92 r
.53666 .29887 .54284 .30625 .55439 .30218 .54824 .29479 Mtetra
.659 .754 .92 r
.54824 .29479 .55439 .30218 .56599 .29808 .55987 .29066 Mtetra
.55987 .29066 .56599 .29808 .57763 .29396 .57155 .28651 Mtetra
.57155 .28651 .57763 .29396 .58933 .28982 .58328 .28234 Mtetra
.58328 .28234 .58933 .28982 .60107 .28568 .59506 .27816 Mtetra
.658 .753 .92 r
.59506 .27816 .60107 .28568 .61286 .28152 .60688 .27397 Mtetra
.60688 .27397 .61286 .28152 .62471 .27736 .61876 .26977 Mtetra
.61876 .26977 .62471 .27736 .6366 .27318 .63069 .26555 Mtetra
.63069 .26555 .6366 .27318 .64854 .26899 .64267 .26133 Mtetra
.64267 .26133 .64854 .26899 .66054 .26478 .65469 .25708 Mtetra
.65469 .25708 .66054 .26478 .67258 .26056 .66677 .25283 Mtetra
.657 .753 .92 r
.66677 .25283 .67258 .26056 .68468 .25632 .67891 .24855 Mtetra
.67891 .24855 .68468 .25632 .69682 .25207 .69109 .24427 Mtetra
.69109 .24427 .69682 .25207 .70902 .2478 .70332 .23996 Mtetra
.70332 .23996 .70902 .2478 .72128 .24351 .71561 .23564 Mtetra
.71561 .23564 .72128 .24351 .73358 .2392 .72796 .2313 Mtetra
.657 .752 .92 r
.72796 .2313 .73358 .2392 .74594 .23488 .74035 .22694 Mtetra
.74035 .22694 .74594 .23488 .75835 .23054 .7528 .22257 Mtetra
.7528 .22257 .75835 .23054 .77081 .22618 .7653 .21817 Mtetra
.925 .697 .573 r
.10264 .44249 .10964 .45104 .12031 .44107 .12677 .32634 Mtetra
0 0 .145 r
.12677 .32634 .12031 .44107 .12982 .44082 .12272 .43337 Mtetra
.561 .688 .925 r
.12272 .43337 .12982 .44082 .13942 .44016 .13242 .43194 Mtetra
.873 .442 .037 r
.13242 .43194 .13942 .44016 .15018 .4299 .13986 .45023 Mtetra
.738 .834 .382 r
.13986 .45023 .15018 .4299 .15977 .43014 .15273 .42259 Mtetra
.569 .689 .922 r
.15273 .42259 .15977 .43014 .16959 .42873 .16258 .42102 Mtetra
.349 .586 .932 r
.16258 .42102 .16959 .42873 .18087 .41414 .17214 .42264 Mtetra
.563 .857 .54 r
.17214 .42264 .18087 .41414 .1901 .41908 .18315 .41113 Mtetra
.557 .674 .916 r
.18315 .41113 .1901 .41908 .2001 .4172 .19311 .40981 Mtetra
.556 .692 .93 r
.19311 .40981 .2001 .4172 .20958 .4212 .20313 .4084 Mtetra
.77 .658 .739 r
.20313 .4084 .20958 .4212 .22083 .40733 .21422 .39641 Mtetra
.415 .526 .862 r
.21422 .39641 .22083 .40733 .23094 .40565 .22401 .39826 Mtetra
.594 .708 .923 r
.22401 .39826 .23094 .40565 .24111 .40385 .23423 .3961 Mtetra
.418 .621 .936 r
.23423 .3961 .24111 .40385 .25263 .38686 .24424 .39691 Mtetra
0 0 0 r
.24424 .39691 .25263 .38686 .26215 .39376 .25534 .3856 Mtetra
.564 .675 .913 r
.25534 .3856 .26215 .39376 .2725 .39145 .26564 .3841 Mtetra
.603 .715 .924 r
.26564 .3841 .2725 .39145 .28286 .38961 .27607 .38168 Mtetra
.332 .573 .928 r
.27607 .38168 .28286 .38961 .29413 .37591 .28621 .38366 Mtetra
.613 .881 .554 r
.28621 .38366 .29413 .37591 .30422 .37914 .29748 .37108 Mtetra
.579 .687 .915 r
.29748 .37108 .30422 .37914 .31477 .37657 .308 .36921 Mtetra
.615 .723 .922 r
.308 .36921 .31477 .37657 .32536 .37404 .31863 .36646 Mtetra
.563 .697 .93 r
.31863 .36646 .32536 .37404 .33534 .38286 .32924 .36484 Mtetra
.726 .594 .708 r
.32924 .36484 .33534 .38286 .34701 .36342 .34047 .35345 Mtetra
.495 .597 .885 r
.34047 .35345 .34701 .36342 .35773 .36109 .35106 .3536 Mtetra
.62 .723 .92 r
.35106 .3536 .35773 .36109 .36854 .35805 .36189 .35069 Mtetra
.626 .73 .922 r
.36189 .35069 .36854 .35805 .37938 .35524 .37276 .34763 Mtetra
.582 .707 .928 r
.37276 .34763 .37938 .35524 .39 .35892 .38365 .34556 Mtetra
.776 .663 .739 r
.38365 .34556 .39 .35892 .40143 .34417 .39502 .33296 Mtetra
.455 .549 .862 r
.39502 .33296 .40143 .34417 .4124 .3418 .40586 .33419 Mtetra
.625 .725 .919 r
.40586 .33419 .4124 .3418 .42344 .3385 .41692 .33111 Mtetra
.639 .738 .921 r
.41692 .33111 .42344 .3385 .43454 .33504 .42805 .32766 Mtetra
.64 .74 .921 r
.42805 .32766 .43454 .33504 .44569 .33162 .43923 .32415 Mtetra
.632 .735 .922 r
.43923 .32415 .44569 .33162 .45688 .32871 .45045 .32083 Mtetra
.557 .693 .931 r
.45045 .32083 .45688 .32871 .46727 .37276 .46168 .31923 Mtetra
.61 .417 .596 r
.46168 .31923 .46727 .37276 .47949 .31729 .47315 .30788 Mtetra
.549 .645 .897 r
.47315 .30788 .47949 .31729 .49082 .31435 .48447 .30668 Mtetra
.636 .734 .919 r
.48447 .30668 .49082 .31435 .5022 .31071 .49588 .30322 Mtetra
.648 .745 .92 r
.49588 .30322 .5022 .31071 .51364 .30686 .50735 .29941 Mtetra
.653 .749 .92 r
.50735 .29941 .51364 .30686 .52513 .30291 .51887 .29547 Mtetra
.655 .751 .92 r
.51887 .29547 .52513 .30291 .53666 .29887 .53044 .29143 Mtetra
.657 .752 .92 r
.53044 .29143 .53666 .29887 .54824 .29479 .54205 .28733 Mtetra
.658 .753 .92 r
.54205 .28733 .54824 .29479 .55987 .29066 .55371 .28318 Mtetra
.659 .754 .92 r
.55371 .28318 .55987 .29066 .57155 .28651 .56542 .279 Mtetra
.56542 .279 .57155 .28651 .58328 .28234 .57719 .2748 Mtetra
.57719 .2748 .58328 .28234 .59506 .27816 .589 .27058 Mtetra
.589 .27058 .59506 .27816 .60688 .27397 .60086 .26635 Mtetra
.658 .753 .92 r
.60086 .26635 .60688 .27397 .61876 .26977 .61277 .26211 Mtetra
.61277 .26211 .61876 .26977 .63069 .26555 .62473 .25787 Mtetra
.62473 .25787 .63069 .26555 .64267 .26133 .63674 .2536 Mtetra
.63674 .2536 .64267 .26133 .65469 .25708 .6488 .24933 Mtetra
.6488 .24933 .65469 .25708 .66677 .25283 .66092 .24504 Mtetra
.66092 .24504 .66677 .25283 .67891 .24855 .67309 .24073 Mtetra
.657 .753 .92 r
.67309 .24073 .67891 .24855 .69109 .24427 .68531 .2364 Mtetra
.68531 .2364 .69109 .24427 .70332 .23996 .69758 .23206 Mtetra
.69758 .23206 .70332 .23996 .71561 .23564 .70991 .22771 Mtetra
.70991 .22771 .71561 .23564 .72796 .2313 .72228 .22333 Mtetra
.657 .752 .92 r
.72228 .22333 .72796 .2313 .74035 .22694 .73472 .21894 Mtetra
.73472 .21894 .74035 .22694 .7528 .22257 .7472 .21453 Mtetra
.7472 .21453 .7528 .22257 .7653 .21817 .75975 .2101 Mtetra
.482 .655 .936 r
.09546 .43499 .10264 .44249 .12677 .32634 .10493 .43483 Mtetra
.461 .209 .445 r
.10493 .43483 .12677 .32634 .12272 .43337 .11571 .42478 Mtetra
.507 .632 .908 r
.11571 .42478 .12272 .43337 .13242 .43194 .12528 .42447 Mtetra
.517 .672 .934 r
.12528 .42447 .13242 .43194 .13986 .45023 .13496 .42377 Mtetra
.671 .514 .663 r
.13496 .42377 .13986 .45023 .15273 .42259 .14583 .41341 Mtetra
.484 .606 .898 r
.14583 .41341 .15273 .42259 .16258 .42102 .15549 .4136 Mtetra
.56 .692 .929 r
.15549 .4136 .16258 .42102 .17214 .42264 .16539 .41213 Mtetra
.814 .698 .737 r
.16539 .41213 .17214 .42264 .18315 .41113 .17678 .39743 Mtetra
.278 .387 .794 r
.17678 .39743 .18315 .41113 .19311 .40981 .18607 .40235 Mtetra
.583 .702 .924 r
.18607 .40235 .19311 .40981 .20313 .4084 .19616 .40041 Mtetra
.13 .452 .884 r
.19616 .40041 .20313 .4084 .21422 .39641 .20571 .40437 Mtetra
.731 .94 .618 r
.20571 .40437 .21422 .39641 .22401 .39826 .21707 .39039 Mtetra
.574 .687 .918 r
.21707 .39039 .22401 .39826 .23423 .3961 .22726 .38865 Mtetra
.577 .703 .928 r
.22726 .38865 .23423 .3961 .24424 .39691 .23753 .38678 Mtetra
.839 .713 .726 r
.23753 .38678 .24424 .39691 .25534 .3856 .24916 .36967 Mtetra
.231 .321 .75 r
.24916 .36967 .25534 .3856 .26564 .3841 .25875 .37655 Mtetra
.6 .71 .921 r
.25875 .37655 .26564 .3841 .27607 .38168 .26919 .37417 Mtetra
.577 .703 .928 r
.26919 .37417 .27607 .38168 .28621 .38366 .27964 .37227 Mtetra
.804 .692 .742 r
.27964 .37227 .28621 .38366 .29748 .37108 .29102 .35846 Mtetra
.37 .467 .829 r
.29102 .35846 .29748 .37108 .308 .36921 .30119 .36165 Mtetra
.61 .716 .92 r
.30119 .36165 .308 .36921 .31863 .36646 .31183 .35901 Mtetra
.607 .719 .924 r
.31183 .35901 .31863 .36646 .32924 .36484 .32252 .35642 Mtetra
0 .142 .669 r
.32252 .35642 .32924 .36484 .34047 .35345 .33257 .36522 Mtetra
.688 .852 .438 r
.33257 .36522 .34047 .35345 .35106 .3536 .34437 .34565 Mtetra
.598 .703 .917 r
.34437 .34565 .35106 .3536 .36189 .35069 .35519 .34324 Mtetra
.626 .73 .921 r
.35519 .34324 .36189 .35069 .37276 .34763 .36609 .34014 Mtetra
.616 .725 .924 r
.36609 .34014 .37276 .34763 .38365 .34556 .37703 .33726 Mtetra
.216 .497 .902 r
.37703 .33726 .38365 .34556 .39502 .33296 .38775 .34089 Mtetra
.661 .886 .529 r
.38775 .34089 .39502 .33296 .40586 .33419 .39929 .32602 Mtetra
.598 .7 .915 r
.39929 .32602 .40586 .33419 .41692 .33111 .41035 .32359 Mtetra
.634 .734 .92 r
.41035 .32359 .41692 .33111 .42805 .32766 .4215 .32021 Mtetra
.64 .74 .921 r
.4215 .32021 .42805 .32766 .43923 .32415 .43271 .31667 Mtetra
.638 .739 .921 r
.43271 .31667 .43923 .32415 .45045 .32083 .44396 .31318 Mtetra
.617 .726 .924 r
.44396 .31318 .45045 .32083 .46168 .31923 .45525 .3102 Mtetra
.931 .556 .167 r
.45525 .3102 .46168 .31923 .47315 .30788 .46572 .35436 Mtetra
0 0 .069 r
.46572 .35436 .47315 .30788 .48447 .30668 .47808 .29861 Mtetra
.617 .716 .916 r
.47808 .29861 .48447 .30668 .49588 .30322 .48952 .2956 Mtetra
.644 .741 .92 r
.48952 .2956 .49588 .30322 .50735 .29941 .50101 .29188 Mtetra
.651 .747 .92 r
.50101 .29188 .50735 .29941 .51887 .29547 .51256 .28795 Mtetra
.654 .75 .92 r
.51256 .28795 .51887 .29547 .53044 .29143 .52416 .28392 Mtetra
.656 .752 .92 r
.52416 .28392 .53044 .29143 .54205 .28733 .53581 .2798 Mtetra
.658 .753 .92 r
.53581 .2798 .54205 .28733 .55371 .28318 .5475 .27564 Mtetra
.659 .754 .92 r
.5475 .27564 .55371 .28318 .56542 .279 .55925 .27143 Mtetra
.55925 .27143 .56542 .279 .57719 .2748 .57104 .26719 Mtetra
.57104 .26719 .57719 .2748 .589 .27058 .58289 .26294 Mtetra
.58289 .26294 .589 .27058 .60086 .26635 .59478 .25868 Mtetra
.658 .753 .92 r
.59478 .25868 .60086 .26635 .61277 .26211 .60673 .2544 Mtetra
.60673 .2544 .61277 .26211 .62473 .25787 .61872 .25012 Mtetra
.61872 .25012 .62473 .25787 .63674 .2536 .63077 .24582 Mtetra
.63077 .24582 .63674 .2536 .6488 .24933 .64287 .24151 Mtetra
.64287 .24151 .6488 .24933 .66092 .24504 .65502 .23718 Mtetra
.65502 .23718 .66092 .24504 .67309 .24073 .66722 .23284 Mtetra
.657 .753 .92 r
.66722 .23284 .67309 .24073 .68531 .2364 .67948 .22848 Mtetra
.67948 .22848 .68531 .2364 .69758 .23206 .69179 .2241 Mtetra
.69179 .2241 .69758 .23206 .70991 .22771 .70415 .21971 Mtetra
.70415 .21971 .70991 .22771 .72228 .22333 .71657 .2153 Mtetra
.71657 .2153 .72228 .22333 .73472 .21894 .72904 .21087 Mtetra
.657 .752 .92 r
.72904 .21087 .73472 .21894 .7472 .21453 .74156 .20642 Mtetra
.74156 .20642 .7472 .21453 .75975 .2101 .75414 .20196 Mtetra
.55 .682 .926 r
.08823 .42742 .09546 .43499 .10493 .43483 .09786 .42616 Mtetra
.926 .697 .572 r
.09786 .42616 .10493 .43483 .11571 .42478 .12236 .30952 Mtetra
0 0 .137 r
.12236 .30952 .11571 .42478 .12528 .42447 .1181 .4169 Mtetra
.561 .688 .925 r
.1181 .4169 .12528 .42447 .13496 .42377 .12789 .41542 Mtetra
.87 .439 .03 r
.12789 .41542 .13496 .42377 .14583 .41341 .13535 .43373 Mtetra
.746 .84 .39 r
.13535 .43373 .14583 .41341 .15549 .4136 .14837 .40593 Mtetra
.569 .689 .922 r
.14837 .40593 .15549 .4136 .16539 .41213 .1583 .4043 Mtetra
.351 .586 .932 r
.1583 .4043 .16539 .41213 .17678 .39743 .16793 .40587 Mtetra
.576 .867 .552 r
.16793 .40587 .17678 .39743 .18607 .40235 .17905 .39426 Mtetra
.557 .674 .916 r
.17905 .39426 .18607 .40235 .19616 .40041 .18909 .39288 Mtetra
.556 .692 .93 r
.18909 .39288 .19616 .40041 .20571 .40437 .19919 .39142 Mtetra
.771 .659 .739 r
.19919 .39142 .20571 .40437 .21707 .39039 .21039 .37933 Mtetra
.414 .526 .862 r
.21039 .37933 .21707 .39039 .22726 .38865 .22025 .38113 Mtetra
.594 .708 .923 r
.22025 .38113 .22726 .38865 .23753 .38678 .23056 .3789 Mtetra
.419 .622 .936 r
.23056 .3789 .23753 .38678 .24916 .36967 .24066 .37966 Mtetra
0 0 0 r
.24066 .37966 .24916 .36967 .25875 .37655 .25187 .36825 Mtetra
.564 .675 .913 r
.25187 .36825 .25875 .37655 .26919 .37417 .26225 .36669 Mtetra
.603 .715 .924 r
.26225 .36669 .26919 .37417 .27964 .37227 .27277 .36421 Mtetra
.334 .573 .928 r
.27277 .36421 .27964 .37227 .29102 .35846 .283 .36614 Mtetra
.624 .889 .565 r
.283 .36614 .29102 .35846 .30119 .36165 .29437 .35346 Mtetra
.579 .687 .915 r
.29437 .35346 .30119 .36165 .31183 .35901 .30499 .35152 Mtetra
.615 .723 .922 r
.30499 .35152 .31183 .35901 .32252 .35642 .31571 .34871 Mtetra
.563 .696 .93 r
.31571 .34871 .32252 .35642 .33257 .36522 .32641 .34702 Mtetra
.726 .594 .709 r
.32641 .34702 .33257 .36522 .34437 .34565 .33776 .33553 Mtetra
.495 .597 .885 r
.33776 .33553 .34437 .34565 .35519 .34324 .34845 .33561 Mtetra
.62 .723 .92 r
.34845 .33561 .35519 .34324 .36609 .34014 .35937 .33264 Mtetra
.626 .73 .922 r
.35937 .33264 .36609 .34014 .37703 .33726 .37034 .3295 Mtetra
.582 .707 .928 r
.37034 .3295 .37703 .33726 .38775 .34089 .38133 .32737 Mtetra
.777 .664 .739 r
.38133 .32737 .38775 .34089 .39929 .32602 .39281 .31466 Mtetra
.455 .549 .863 r
.39281 .31466 .39929 .32602 .41035 .32359 .40375 .31583 Mtetra
.625 .725 .919 r
.40375 .31583 .41035 .32359 .4215 .32021 .41491 .31268 Mtetra
.639 .738 .921 r
.41491 .31268 .4215 .32021 .43271 .31667 .42614 .30915 Mtetra
.64 .74 .921 r
.42614 .30915 .43271 .31667 .44396 .31318 .43743 .30557 Mtetra
.632 .735 .922 r
.43743 .30557 .44396 .31318 .45525 .3102 .44875 .30218 Mtetra
.558 .693 .93 r
.44875 .30218 .45525 .3102 .46572 .35436 .4601 .30051 Mtetra
.608 .415 .594 r
.4601 .30051 .46572 .35436 .47808 .29861 .47167 .28905 Mtetra
.549 .645 .897 r
.47167 .28905 .47808 .29861 .48952 .2956 .48311 .28778 Mtetra
.636 .734 .919 r
.48311 .28778 .48952 .2956 .50101 .29188 .49463 .28424 Mtetra
.648 .745 .92 r
.49463 .28424 .50101 .29188 .51256 .28795 .50621 .28036 Mtetra
.653 .749 .92 r
.50621 .28036 .51256 .28795 .52416 .28392 .51784 .27633 Mtetra
.655 .751 .92 r
.51784 .27633 .52416 .28392 .53581 .2798 .52952 .27221 Mtetra
.657 .752 .92 r
.52952 .27221 .53581 .2798 .5475 .27564 .54124 .26803 Mtetra
.658 .753 .92 r
.54124 .26803 .5475 .27564 .55925 .27143 .55302 .2638 Mtetra
.659 .754 .92 r
.55302 .2638 .55925 .27143 .57104 .26719 .56485 .25953 Mtetra
.56485 .25953 .57104 .26719 .58289 .26294 .57673 .25525 Mtetra
.57673 .25525 .58289 .26294 .59478 .25868 .58866 .25095 Mtetra
.58866 .25095 .59478 .25868 .60673 .2544 .60064 .24663 Mtetra
.658 .753 .92 r
.60064 .24663 .60673 .2544 .61872 .25012 .61267 .24231 Mtetra
.61267 .24231 .61872 .25012 .63077 .24582 .62475 .23798 Mtetra
.62475 .23798 .63077 .24582 .64287 .24151 .63689 .23363 Mtetra
.63689 .23363 .64287 .24151 .65502 .23718 .64907 .22927 Mtetra
.64907 .22927 .65502 .23718 .66722 .23284 .66131 .22489 Mtetra
.66131 .22489 .66722 .23284 .67948 .22848 .6736 .22049 Mtetra
.657 .753 .92 r
.6736 .22049 .67948 .22848 .69179 .2241 .68595 .21608 Mtetra
.68595 .21608 .69179 .2241 .70415 .21971 .69835 .21165 Mtetra
.69835 .21165 .70415 .21971 .71657 .2153 .71081 .2072 Mtetra
.71081 .2072 .71657 .2153 .72904 .21087 .72331 .20274 Mtetra
.657 .752 .92 r
.72331 .20274 .72904 .21087 .74156 .20642 .73588 .19826 Mtetra
.73588 .19826 .74156 .20642 .75414 .20196 .7485 .19375 Mtetra
.487 .617 .905 r
.08114 .41852 .08823 .42742 .09786 .42616 .09059 .41854 Mtetra
.483 .655 .936 r
.09059 .41854 .09786 .42616 .12236 .30952 .10014 .41833 Mtetra
.456 .203 .44 r
.10014 .41833 .12236 .30952 .1181 .4169 .11102 .40818 Mtetra
.507 .632 .908 r
.11102 .40818 .1181 .4169 .12789 .41542 .12067 .40782 Mtetra
.517 .672 .934 r
.12067 .40782 .12789 .41542 .13535 .43373 .13042 .40706 Mtetra
.671 .513 .662 r
.13042 .40706 .13535 .43373 .14837 .40593 .14139 .39661 Mtetra
.484 .606 .898 r
.14139 .39661 .14837 .40593 .1583 .4043 .15112 .39675 Mtetra
.56 .692 .929 r
.15112 .39675 .1583 .4043 .16793 .40587 .16111 .39522 Mtetra
.815 .699 .737 r
.16111 .39522 .16793 .40587 .17905 .39426 .17261 .38041 Mtetra
.277 .386 .794 r
.17261 .38041 .17905 .39426 .18909 .39288 .18197 .38529 Mtetra
.583 .702 .924 r
.18197 .38529 .18909 .39288 .19919 .39142 .19214 .38329 Mtetra
.133 .454 .885 r
.19214 .38329 .19919 .39142 .21039 .37933 .20177 .38722 Mtetra
.739 .945 .626 r
.20177 .38722 .21039 .37933 .22025 .38113 .21324 .37312 Mtetra
.574 .687 .918 r
.21324 .37312 .22025 .38113 .23056 .3789 .22352 .37133 Mtetra
.577 .703 .928 r
.22352 .37133 .23056 .3789 .24066 .37966 .23387 .3694 Mtetra
.839 .714 .726 r
.23387 .3694 .24066 .37966 .25187 .36825 .24562 .35216 Mtetra
.229 .319 .75 r
.24562 .35216 .25187 .36825 .26225 .36669 .25528 .35901 Mtetra
.6 .71 .921 r
.25528 .35901 .26225 .36669 .27277 .36421 .26581 .35657 Mtetra
.577 .703 .928 r
.26581 .35657 .27277 .36421 .283 .36614 .27636 .35461 Mtetra
.804 .693 .742 r
.27636 .35461 .283 .36614 .29437 .35346 .28785 .34068 Mtetra
.368 .467 .829 r
.28785 .34068 .29437 .35346 .30499 .35152 .2981 .34382 Mtetra
.61 .716 .92 r
.2981 .34382 .30499 .35152 .31571 .34871 .30884 .34112 Mtetra
.607 .719 .924 r
.30884 .34112 .31571 .34871 .32641 .34702 .31962 .33846 Mtetra
0 .147 .674 r
.31962 .33846 .32641 .34702 .33776 .33553 .32976 .34723 Mtetra
.696 .858 .447 r
.32976 .34723 .33776 .33553 .34845 .33561 .34168 .32752 Mtetra
.598 .703 .917 r
.34168 .32752 .34845 .33561 .35937 .33264 .35259 .32505 Mtetra
.626 .73 .921 r
.35259 .32505 .35937 .33264 .37034 .3295 .3636 .32187 Mtetra
.616 .725 .924 r
.3636 .32187 .37034 .3295 .38133 .32737 .37464 .31892 Mtetra
.218 .498 .902 r
.37464 .31892 .38133 .32737 .39281 .31466 .38545 .3225 Mtetra
.67 .893 .539 r
.38545 .3225 .39281 .31466 .40375 .31583 .39711 .30751 Mtetra
.598 .7 .915 r
.39711 .30751 .40375 .31583 .41491 .31268 .40827 .30501 Mtetra
.634 .734 .92 r
.40827 .30501 .41491 .31268 .42614 .30915 .41953 .30156 Mtetra
.64 .74 .921 r
.41953 .30156 .42614 .30915 .43743 .30557 .43084 .29795 Mtetra
.638 .739 .921 r
.43084 .29795 .43743 .30557 .44875 .30218 .4422 .29437 Mtetra
.617 .726 .924 r
.4422 .29437 .44875 .30218 .4601 .30051 .4536 .29132 Mtetra
.929 .553 .159 r
.4536 .29132 .4601 .30051 .47167 .28905 .46414 .33559 Mtetra
0 0 .061 r
.46414 .33559 .47167 .28905 .48311 .28778 .47665 .27956 Mtetra
.617 .716 .916 r
.47665 .27956 .48311 .28778 .49463 .28424 .48819 .27647 Mtetra
.644 .741 .92 r
.48819 .27647 .49463 .28424 .50621 .28036 .4998 .27267 Mtetra
.651 .747 .92 r
.4998 .27267 .50621 .28036 .51784 .27633 .51146 .26866 Mtetra
.654 .75 .92 r
.51146 .26866 .51784 .27633 .52952 .27221 .52317 .26455 Mtetra
.656 .752 .92 r
.52317 .26455 .52952 .27221 .54124 .26803 .53494 .26035 Mtetra
.658 .753 .92 r
.53494 .26035 .54124 .26803 .55302 .2638 .54675 .2561 Mtetra
.659 .754 .92 r
.54675 .2561 .55302 .2638 .56485 .25953 .55861 .25181 Mtetra
.55861 .25181 .56485 .25953 .57673 .25525 .57052 .24749 Mtetra
.57052 .24749 .57673 .25525 .58866 .25095 .58249 .24315 Mtetra
.58249 .24315 .58866 .25095 .60064 .24663 .5945 .2388 Mtetra
.658 .753 .92 r
.5945 .2388 .60064 .24663 .61267 .24231 .60657 .23444 Mtetra
.60657 .23444 .61267 .24231 .62475 .23798 .61868 .23007 Mtetra
.61868 .23007 .62475 .23798 .63689 .23363 .63085 .22569 Mtetra
.63085 .22569 .63689 .23363 .64907 .22927 .64308 .22129 Mtetra
.64308 .22129 .64907 .22927 .66131 .22489 .65535 .21687 Mtetra
.65535 .21687 .66131 .22489 .6736 .22049 .66768 .21244 Mtetra
.657 .753 .92 r
.66768 .21244 .6736 .22049 .68595 .21608 .68007 .20799 Mtetra
.68007 .20799 .68595 .21608 .69835 .21165 .6925 .20353 Mtetra
.6925 .20353 .69835 .21165 .71081 .2072 .705 .19904 Mtetra
.705 .19904 .71081 .2072 .72331 .20274 .71754 .19454 Mtetra
.71754 .19454 .72331 .20274 .73588 .19826 .73015 .19002 Mtetra
.657 .752 .92 r
.73015 .19002 .73588 .19826 .7485 .19375 .7428 .18548 Mtetra
.702 .741 .231 r
.06608 .46632 .08114 .41852 .09059 .41854 .08329 .41084 Mtetra
.55 .682 .926 r
.08329 .41084 .09059 .41854 .10014 .41833 .09299 .40953 Mtetra
.927 .698 .57 r
.09299 .40953 .10014 .41833 .11102 .40818 .11787 .29239 Mtetra
0 0 .129 r
.11787 .29239 .11102 .40818 .12067 .40782 .1134 .40012 Mtetra
.561 .688 .925 r
.1134 .40012 .12067 .40782 .13042 .40706 .12327 .39859 Mtetra
.867 .435 .022 r
.12327 .39859 .13042 .40706 .14139 .39661 .13076 .41692 Mtetra
.754 .846 .399 r
.13076 .41692 .14139 .39661 .15112 .39675 .14392 .38895 Mtetra
.568 .689 .922 r
.14392 .38895 .15112 .39675 .16111 .39522 .15394 .38726 Mtetra
.352 .586 .932 r
.15394 .38726 .16111 .39522 .17261 .38041 .16364 .38879 Mtetra
.588 .876 .565 r
.16364 .38879 .17261 .38041 .18197 .38529 .17487 .37708 Mtetra
.557 .674 .916 r
.17487 .37708 .18197 .38529 .19214 .38329 .18499 .37564 Mtetra
.556 .692 .93 r
.18499 .37564 .19214 .38329 .20177 .38722 .19518 .37411 Mtetra
.771 .659 .739 r
.19518 .37411 .20177 .38722 .21324 .37312 .20648 .36192 Mtetra
.413 .526 .863 r
.20648 .36192 .21324 .37312 .22352 .37133 .21643 .36368 Mtetra
.594 .708 .923 r
.21643 .36368 .22352 .37133 .23387 .3694 .22683 .36138 Mtetra
.42 .622 .936 r
.22683 .36138 .23387 .3694 .24562 .35216 .23701 .36209 Mtetra
0 0 0 r
.23701 .36209 .24562 .35216 .25528 .35901 .24832 .35058 Mtetra
.564 .675 .913 r
.24832 .35058 .25528 .35901 .26581 .35657 .2588 .34895 Mtetra
.603 .715 .924 r
.2588 .34895 .26581 .35657 .27636 .35461 .26941 .3464 Mtetra
.335 .573 .928 r
.26941 .3464 .27636 .35461 .28785 .34068 .27973 .34828 Mtetra
.635 .897 .576 r
.27973 .34828 .28785 .34068 .2981 .34382 .29121 .33549 Mtetra
.579 .687 .915 r
.29121 .33549 .2981 .34382 .30884 .34112 .30192 .33349 Mtetra
.615 .723 .922 r
.30192 .33349 .30884 .34112 .31962 .33846 .31274 .3306 Mtetra
.563 .696 .93 r
.31274 .3306 .31962 .33846 .32976 .34723 .32354 .32885 Mtetra
.726 .594 .709 r
.32354 .32885 .32976 .34723 .34168 .32752 .33499 .31726 Mtetra
.494 .597 .885 r
.33499 .31726 .34168 .32752 .35259 .32505 .34577 .31728 Mtetra
.62 .723 .92 r
.34577 .31728 .35259 .32505 .3636 .32187 .3568 .31423 Mtetra
.626 .73 .922 r
.3568 .31423 .3636 .32187 .37464 .31892 .36787 .31102 Mtetra
.582 .707 .928 r
.36787 .31102 .37464 .31892 .38545 .3225 .37896 .30882 Mtetra
.777 .665 .739 r
.37896 .30882 .38545 .3225 .39711 .30751 .39056 .296 Mtetra
.454 .549 .863 r
.39056 .296 .39711 .30751 .40827 .30501 .40159 .29711 Mtetra
.625 .725 .919 r
.40159 .29711 .40827 .30501 .41953 .30156 .41286 .29388 Mtetra
.639 .738 .921 r
.41286 .29388 .41953 .30156 .43084 .29795 .4242 .29028 Mtetra
.64 .74 .921 r
.4242 .29028 .43084 .29795 .4422 .29437 .43559 .28662 Mtetra
.632 .735 .922 r
.43559 .28662 .4422 .29437 .4536 .29132 .44703 .28315 Mtetra
.558 .693 .93 r
.44703 .28315 .4536 .29132 .46414 .33559 .45848 .28141 Mtetra
.607 .413 .593 r
.45848 .28141 .46414 .33559 .47665 .27956 .47017 .26984 Mtetra
.549 .645 .897 r
.47017 .26984 .47665 .27956 .48819 .27647 .48171 .2685 Mtetra
.636 .734 .919 r
.48171 .2685 .48819 .27647 .4998 .27267 .49335 .26488 Mtetra
.648 .745 .92 r
.49335 .26488 .4998 .27267 .51146 .26866 .50504 .26092 Mtetra
.653 .749 .92 r
.50504 .26092 .51146 .26866 .52317 .26455 .51678 .25681 Mtetra
.655 .751 .92 r
.51678 .25681 .52317 .26455 .53494 .26035 .52858 .2526 Mtetra
.657 .752 .92 r
.52858 .2526 .53494 .26035 .54675 .2561 .54042 .24834 Mtetra
.658 .753 .92 r
.54042 .24834 .54675 .2561 .55861 .25181 .55232 .24402 Mtetra
.659 .754 .92 r
.55232 .24402 .55861 .25181 .57052 .24749 .56427 .23967 Mtetra
.56427 .23967 .57052 .24749 .58249 .24315 .57626 .2353 Mtetra
.57626 .2353 .58249 .24315 .5945 .2388 .58831 .23091 Mtetra
.58831 .23091 .5945 .2388 .60657 .23444 .60041 .22651 Mtetra
.658 .753 .92 r
.60041 .22651 .60657 .23444 .61868 .23007 .61257 .2221 Mtetra
.61257 .2221 .61868 .23007 .63085 .22569 .62477 .21768 Mtetra
.62477 .21768 .63085 .22569 .64308 .22129 .63703 .21324 Mtetra
.63703 .21324 .64308 .22129 .65535 .21687 .64935 .20879 Mtetra
.64935 .20879 .65535 .21687 .66768 .21244 .66171 .20432 Mtetra
.66171 .20432 .66768 .21244 .68007 .20799 .67413 .19984 Mtetra
.657 .753 .92 r
.67413 .19984 .68007 .20799 .6925 .20353 .68661 .19533 Mtetra
.68661 .19533 .6925 .20353 .705 .19904 .69914 .19081 Mtetra
.69914 .19081 .705 .19904 .71754 .19454 .71172 .18627 Mtetra
.71172 .18627 .71754 .19454 .73015 .19002 .72437 .18172 Mtetra
.657 .752 .92 r
.72437 .18172 .73015 .19002 .7428 .18548 .73706 .17714 Mtetra
.602 .409 .592 r
.0652 .41197 .06608 .46632 .08329 .41084 .07611 .40181 Mtetra
.487 .617 .905 r
.07611 .40181 .08329 .41084 .09299 .40953 .08564 .40178 Mtetra
.483 .655 .936 r
.08564 .40178 .09299 .40953 .11787 .29239 .09526 .40151 Mtetra
.451 .196 .434 r
.09526 .40151 .11787 .29239 .1134 .40012 .10624 .39127 Mtetra
.507 .632 .908 r
.10624 .39127 .1134 .40012 .12327 .39859 .11596 .39086 Mtetra
.517 .672 .934 r
.11596 .39086 .12327 .39859 .13076 .41692 .1258 .39005 Mtetra
.671 .512 .662 r
.1258 .39005 .13076 .41692 .14392 .38895 .13687 .3795 Mtetra
.484 .606 .898 r
.13687 .3795 .14392 .38895 .15394 .38726 .14668 .37958 Mtetra
.56 .692 .929 r
.14668 .37958 .15394 .38726 .16364 .38879 .15675 .378 Mtetra
.816 .7 .737 r
.15675 .378 .16364 .38879 .17487 .37708 .16836 .36307 Mtetra
.275 .385 .794 r
.16836 .36307 .17487 .37708 .18499 .37564 .17779 .36792 Mtetra
.583 .702 .924 r
.17779 .36792 .18499 .37564 .19518 .37411 .18805 .36585 Mtetra
.137 .455 .885 r
.18805 .36585 .19518 .37411 .20648 .36192 .19775 .36974 Mtetra
.746 .949 .634 r
.19775 .36974 .20648 .36192 .21643 .36368 .20933 .35553 Mtetra
.573 .687 .918 r
.20933 .35553 .21643 .36368 .22683 .36138 .2197 .35367 Mtetra
.577 .703 .928 r
.2197 .35367 .22683 .36138 .23701 .36209 .23014 .35168 Mtetra
.84 .715 .726 r
.23014 .35168 .23701 .36209 .24832 .35058 .24201 .33432 Mtetra
.226 .318 .749 r
.24201 .33432 .24832 .35058 .2588 .34895 .25175 .34113 Mtetra
.6 .71 .921 r
.25175 .34113 .2588 .34895 .26941 .3464 .26237 .33862 Mtetra
.577 .703 .928 r
.26237 .33862 .26941 .3464 .27973 .34828 .27301 .33659 Mtetra
.805 .694 .742 r
.27301 .33659 .27973 .34828 .29121 .33549 .28462 .32255 Mtetra
.367 .466 .83 r
.28462 .32255 .29121 .33549 .30192 .33349 .29496 .32565 Mtetra
.61 .716 .921 r
.29496 .32565 .30192 .33349 .31274 .3306 .30579 .32288 Mtetra
.607 .719 .924 r
.30579 .32288 .31274 .3306 .32354 .32885 .31667 .32014 Mtetra
0 .152 .679 r
.31667 .32014 .32354 .32885 .33499 .31726 .32689 .32889 Mtetra
.705 .865 .456 r
.32689 .32889 .33499 .31726 .34577 .31728 .33893 .30904 Mtetra
.598 .703 .917 r
.33893 .30904 .34577 .31728 .3568 .31423 .34995 .3065 Mtetra
.626 .73 .921 r
.34995 .3065 .3568 .31423 .36787 .31102 .36105 .30325 Mtetra
.616 .725 .924 r
.36105 .30325 .36787 .31102 .37896 .30882 .3722 .30022 Mtetra
.221 .499 .903 r
.3722 .30022 .37896 .30882 .39056 .296 .3831 .30376 Mtetra
.679 .899 .548 r
.3831 .30376 .39056 .296 .40159 .29711 .39488 .28865 Mtetra
.598 .7 .915 r
.39488 .28865 .40159 .29711 .41286 .29388 .40615 .28607 Mtetra
.634 .734 .92 r
.40615 .28607 .41286 .29388 .4242 .29028 .41751 .28254 Mtetra
.64 .74 .921 r
.41751 .28254 .4242 .29028 .43559 .28662 .42893 .27885 Mtetra
.638 .739 .921 r
.42893 .27885 .43559 .28662 .44703 .28315 .4404 .2752 Mtetra
.617 .726 .924 r
.4404 .2752 .44703 .28315 .45848 .28141 .45191 .27206 Mtetra
.926 .55 .151 r
.45191 .27206 .45848 .28141 .47017 .26984 .46253 .31645 Mtetra
0 0 .053 r
.46253 .31645 .47017 .26984 .48171 .2685 .47519 .26013 Mtetra
.617 .716 .916 r
.47519 .26013 .48171 .2685 .49335 .26488 .48684 .25696 Mtetra
.644 .741 .92 r
.48684 .25696 .49335 .26488 .50504 .26092 .49857 .25308 Mtetra
.651 .747 .92 r
.49857 .25308 .50504 .26092 .51678 .25681 .51034 .24899 Mtetra
.654 .75 .92 r
.51034 .24899 .51678 .25681 .52858 .2526 .52217 .24478 Mtetra
.656 .752 .92 r
.52217 .24478 .52858 .2526 .54042 .24834 .53405 .2405 Mtetra
.658 .753 .92 r
.53405 .2405 .54042 .24834 .55232 .24402 .54598 .23617 Mtetra
.659 .754 .92 r
.54598 .23617 .55232 .24402 .56427 .23967 .55796 .23179 Mtetra
.55796 .23179 .56427 .23967 .57626 .2353 .56999 .22738 Mtetra
.56999 .22738 .57626 .2353 .58831 .23091 .58208 .22296 Mtetra
.58208 .22296 .58831 .23091 .60041 .22651 .59421 .21852 Mtetra
.658 .753 .92 r
.59421 .21852 .60041 .22651 .61257 .2221 .6064 .21407 Mtetra
.6064 .21407 .61257 .2221 .62477 .21768 .61864 .20961 Mtetra
.61864 .20961 .62477 .21768 .63703 .21324 .63094 .20514 Mtetra
.63094 .20514 .63703 .21324 .64935 .20879 .64329 .20065 Mtetra
.64329 .20065 .64935 .20879 .66171 .20432 .65569 .19614 Mtetra
.65569 .19614 .66171 .20432 .67413 .19984 .66815 .19162 Mtetra
.657 .753 .92 r
.66815 .19162 .67413 .19984 .68661 .19533 .68066 .18708 Mtetra
.68066 .18708 .68661 .19533 .69914 .19081 .69323 .18252 Mtetra
.69323 .18252 .69914 .19081 .71172 .18627 .70586 .17794 Mtetra
.70586 .17794 .71172 .18627 .72437 .18172 .71854 .17334 Mtetra
.71854 .17334 .72437 .18172 .73706 .17714 .73128 .16873 Mtetra
.95 .628 .384 r
.05789 .40328 .0652 .41197 .07611 .40181 .06081 .44972 Mtetra
.711 .748 .24 r
.06081 .44972 .07611 .40181 .08564 .40178 .07825 .39395 Mtetra
.55 .682 .926 r
.07825 .39395 .08564 .40178 .09526 .40151 .08802 .39258 Mtetra
.929 .698 .569 r
.08802 .39258 .09526 .40151 .10624 .39127 .1133 .27495 Mtetra
0 0 .122 r
.1133 .27495 .10624 .39127 .11596 .39086 .10862 .38303 Mtetra
.561 .688 .925 r
.10862 .38303 .11596 .39086 .1258 .39005 .11856 .38144 Mtetra
.864 .431 .014 r
.11856 .38144 .1258 .39005 .13687 .3795 .12608 .39979 Mtetra
.761 .852 .407 r
.12608 .39979 .13687 .3795 .14668 .37958 .1394 .37165 Mtetra
.568 .689 .922 r
.1394 .37165 .14668 .37958 .15675 .378 .14949 .3699 Mtetra
.353 .586 .932 r
.14949 .3699 .15675 .378 .16836 .36307 .15928 .37138 Mtetra
.6 .885 .577 r
.15928 .37138 .16836 .36307 .17779 .36792 .17061 .35957 Mtetra
.557 .674 .916 r
.17061 .35957 .17779 .36792 .18805 .36585 .18082 .35806 Mtetra
.557 .692 .93 r
.18082 .35806 .18805 .36585 .19775 .36974 .19109 .35648 Mtetra
.772 .66 .739 r
.19109 .35648 .19775 .36974 .20933 .35553 .20251 .34418 Mtetra
.412 .526 .863 r
.20251 .34418 .20933 .35553 .2197 .35367 .21253 .34589 Mtetra
.594 .708 .923 r
.21253 .34589 .2197 .35367 .23014 .35168 .22302 .34352 Mtetra
.42 .622 .936 r
.22302 .34352 .23014 .35168 .24201 .33432 .23329 .34417 Mtetra
0 0 0 r
.23329 .34417 .24201 .33432 .25175 .34113 .24471 .33256 Mtetra
.564 .675 .914 r
.24471 .33256 .25175 .34113 .26237 .33862 .25528 .33087 Mtetra
.603 .715 .924 r
.25528 .33087 .26237 .33862 .27301 .33659 .26598 .32825 Mtetra
.337 .574 .928 r
.26598 .32825 .27301 .33659 .28462 .32255 .27639 .33008 Mtetra
.645 .904 .587 r
.27639 .33008 .28462 .32255 .29496 .32565 .28799 .31718 Mtetra
.579 .687 .915 r
.28799 .31718 .29496 .32565 .30579 .32288 .29879 .3151 Mtetra
.615 .723 .922 r
.29879 .3151 .30579 .32288 .31667 .32014 .30971 .31215 Mtetra
.563 .696 .93 r
.30971 .31215 .31667 .32014 .32689 .32889 .32061 .31032 Mtetra
.726 .594 .709 r
.32061 .31032 .32689 .32889 .33893 .30904 .33217 .29862 Mtetra
.494 .597 .886 r
.33217 .29862 .33893 .30904 .34995 .3065 .34305 .29858 Mtetra
.62 .723 .92 r
.34305 .29858 .34995 .3065 .36105 .30325 .35417 .29546 Mtetra
.626 .73 .922 r
.35417 .29546 .36105 .30325 .3722 .30022 .36536 .29218 Mtetra
.582 .707 .928 r
.36536 .29218 .3722 .30022 .3831 .30376 .37654 .2899 Mtetra
.778 .665 .739 r
.37654 .2899 .3831 .30376 .39488 .28865 .38826 .27697 Mtetra
.453 .548 .863 r
.38826 .27697 .39488 .28865 .40615 .28607 .3994 .27802 Mtetra
.625 .725 .919 r
.3994 .27802 .40615 .28607 .41751 .28254 .41077 .27471 Mtetra
.639 .738 .921 r
.41077 .27471 .41751 .28254 .42893 .27885 .42222 .27103 Mtetra
.64 .74 .921 r
.42222 .27103 .42893 .27885 .4404 .2752 .43372 .26729 Mtetra
.632 .735 .922 r
.43372 .26729 .4404 .2752 .45191 .27206 .44527 .26374 Mtetra
.558 .693 .93 r
.44527 .26374 .45191 .27206 .46253 .31645 .45683 .26192 Mtetra
.605 .41 .591 r
.45683 .26192 .46253 .31645 .47519 .26013 .46864 .25024 Mtetra
.548 .645 .898 r
.46864 .25024 .47519 .26013 .48684 .25696 .48029 .24884 Mtetra
.636 .734 .919 r
.48029 .24884 .48684 .25696 .49857 .25308 .49204 .24513 Mtetra
.648 .745 .92 r
.49204 .24513 .49857 .25308 .51034 .24899 .50385 .24108 Mtetra
.653 .749 .92 r
.50385 .24108 .51034 .24899 .52217 .24478 .51571 .23689 Mtetra
.655 .751 .92 r
.51571 .23689 .52217 .24478 .53405 .2405 .52762 .2326 Mtetra
.657 .752 .92 r
.52762 .2326 .53405 .2405 .54598 .23617 .53959 .22824 Mtetra
.658 .753 .92 r
.53959 .22824 .54598 .23617 .55796 .23179 .5516 .22384 Mtetra
.659 .754 .92 r
.5516 .22384 .55796 .23179 .56999 .22738 .56367 .2194 Mtetra
.56367 .2194 .56999 .22738 .58208 .22296 .57579 .21494 Mtetra
.57579 .21494 .58208 .22296 .59421 .21852 .58796 .21047 Mtetra
.58796 .21047 .59421 .21852 .6064 .21407 .60019 .20598 Mtetra
.658 .753 .92 r
.60019 .20598 .6064 .21407 .61864 .20961 .61246 .20148 Mtetra
.61246 .20148 .61864 .20961 .63094 .20514 .6248 .19696 Mtetra
.6248 .19696 .63094 .20514 .64329 .20065 .63718 .19244 Mtetra
.63718 .19244 .64329 .20065 .65569 .19614 .64962 .18789 Mtetra
.64962 .18789 .65569 .19614 .66815 .19162 .66212 .18333 Mtetra
.66212 .18333 .66815 .19162 .68066 .18708 .67467 .17875 Mtetra
.657 .753 .92 r
.67467 .17875 .68066 .18708 .69323 .18252 .68728 .17415 Mtetra
.68728 .17415 .69323 .18252 .70586 .17794 .69994 .16954 Mtetra
.69994 .16954 .70586 .17794 .71854 .17334 .71266 .1649 Mtetra
.71266 .1649 .71854 .17334 .73128 .16873 .72544 .16025 Mtetra
.49 .658 .935 r
.05041 .39545 .05789 .40328 .06081 .44972 .05997 .39504 Mtetra
.6 .406 .591 r
.05997 .39504 .06081 .44972 .07825 .39395 .07099 .38479 Mtetra
.486 .617 .905 r
.07099 .38479 .07825 .39395 .08802 .39258 .08059 .3847 Mtetra
.483 .655 .936 r
.08059 .3847 .08802 .39258 .1133 .27495 .09029 .38438 Mtetra
.446 .189 .429 r
.09029 .38438 .1133 .27495 .10862 .38303 .10137 .37405 Mtetra
.506 .632 .908 r
.10137 .37405 .10862 .38303 .11856 .38144 .11117 .37358 Mtetra
.518 .672 .934 r
.11117 .37358 .11856 .38144 .12608 .39979 .12109 .37271 Mtetra
.67 .512 .661 r
.12109 .37271 .12608 .39979 .1394 .37165 .13226 .36206 Mtetra
.483 .606 .898 r
.13226 .36206 .1394 .37165 .14949 .3699 .14215 .36209 Mtetra
.56 .692 .929 r
.14215 .36209 .14949 .3699 .15928 .37138 .1523 .36044 Mtetra
.816 .701 .737 r
.1523 .36044 .15928 .37138 .17061 .35957 .16403 .3454 Mtetra
.273 .384 .794 r
.16403 .3454 .17061 .35957 .18082 .35806 .17353 .35021 Mtetra
.583 .702 .924 r
.17353 .35021 .18082 .35806 .19109 .35648 .18388 .34808 Mtetra
.14 .457 .886 r
.18388 .34808 .19109 .35648 .20251 .34418 .19365 .35192 Mtetra
.753 .953 .641 r
.19365 .35192 .20251 .34418 .21253 .34589 .20535 .3376 Mtetra
.573 .687 .918 r
.20535 .3376 .21253 .34589 .22302 .34352 .21581 .33568 Mtetra
.577 .703 .928 r
.21581 .33568 .22302 .34352 .23329 .34417 .22635 .33361 Mtetra
.841 .716 .726 r
.22635 .33361 .23329 .34417 .24471 .33256 .23834 .31613 Mtetra
.224 .316 .749 r
.23834 .31613 .24471 .33256 .25528 .33087 .24815 .32291 Mtetra
.6 .71 .921 r
.24815 .32291 .25528 .33087 .26598 .32825 .25887 .32033 Mtetra
.577 .703 .928 r
.25887 .32033 .26598 .32825 .27639 .33008 .2696 .31823 Mtetra
.806 .695 .743 r
.2696 .31823 .27639 .33008 .28799 .31718 .28133 .30407 Mtetra
.366 .466 .83 r
.28133 .30407 .28799 .31718 .29879 .3151 .29175 .30712 Mtetra
.61 .716 .921 r
.29175 .30712 .29879 .3151 .30971 .31215 .30268 .30428 Mtetra
.607 .719 .924 r
.30268 .30428 .30971 .31215 .32061 .31032 .31366 .30147 Mtetra
0 .157 .684 r
.31366 .30147 .32061 .31032 .33217 .29862 .32396 .31019 Mtetra
.713 .871 .465 r
.32396 .31019 .33217 .29862 .34305 .29858 .33613 .2902 Mtetra
.598 .703 .917 r
.33613 .2902 .34305 .29858 .35417 .29546 .34725 .28758 Mtetra
.626 .73 .921 r
.34725 .28758 .35417 .29546 .36536 .29218 .35846 .28425 Mtetra
.616 .725 .924 r
.35846 .28425 .36536 .29218 .37654 .2899 .36971 .28115 Mtetra
.224 .5 .903 r
.36971 .28115 .37654 .2899 .38826 .27697 .38071 .28463 Mtetra
.688 .905 .557 r
.38071 .28463 .38826 .27697 .3994 .27802 .39261 .2694 Mtetra
.598 .7 .915 r
.39261 .2694 .3994 .27802 .41077 .27471 .40399 .26675 Mtetra
.634 .734 .92 r
.40399 .26675 .41077 .27471 .42222 .27103 .41546 .26314 Mtetra
.64 .74 .921 r
.41546 .26314 .42222 .27103 .43372 .26729 .42699 .25937 Mtetra
.638 .739 .921 r
.42699 .25937 .43372 .26729 .44527 .26374 .43857 .25563 Mtetra
.617 .726 .924 r
.43857 .25563 .44527 .26374 .45683 .26192 .45019 .25242 Mtetra
.924 .546 .143 r
.45019 .25242 .45683 .26192 .46864 .25024 .46088 .2969 Mtetra
0 0 .044 r
.46088 .2969 .46864 .25024 .48029 .24884 .47369 .2403 Mtetra
.617 .716 .916 r
.47369 .2403 .48029 .24884 .49204 .24513 .48547 .23705 Mtetra
.644 .741 .92 r
.48547 .23705 .49204 .24513 .50385 .24108 .4973 .23308 Mtetra
.651 .747 .92 r
.4973 .23308 .50385 .24108 .51571 .23689 .5092 .22891 Mtetra
.654 .75 .92 r
.5092 .22891 .51571 .23689 .52762 .2326 .52114 .22462 Mtetra
.656 .752 .92 r
.52114 .22462 .52762 .2326 .53959 .22824 .53314 .22025 Mtetra
.658 .753 .92 r
.53314 .22025 .53959 .22824 .5516 .22384 .54519 .21582 Mtetra
.659 .754 .92 r
.54519 .21582 .5516 .22384 .56367 .2194 .55729 .21136 Mtetra
.55729 .21136 .56367 .2194 .57579 .21494 .56945 .20686 Mtetra
.56945 .20686 .57579 .21494 .58796 .21047 .58166 .20235 Mtetra
.58166 .20235 .58796 .21047 .60019 .20598 .59392 .19782 Mtetra
.658 .753 .92 r
.59392 .19782 .60019 .20598 .61246 .20148 .60623 .19328 Mtetra
.60623 .19328 .61246 .20148 .6248 .19696 .6186 .18873 Mtetra
.6186 .18873 .6248 .19696 .63718 .19244 .63103 .18416 Mtetra
.63103 .18416 .63718 .19244 .64962 .18789 .64351 .17957 Mtetra
.64351 .17957 .64962 .18789 .66212 .18333 .65604 .17497 Mtetra
.65604 .17497 .66212 .18333 .67467 .17875 .66863 .17036 Mtetra
.657 .753 .92 r
.66863 .17036 .67467 .17875 .68728 .17415 .68128 .16572 Mtetra
.68128 .16572 .68728 .17415 .69994 .16954 .69398 .16107 Mtetra
.69398 .16107 .69994 .16954 .71266 .1649 .70674 .15639 Mtetra
.70674 .15639 .71266 .1649 .72544 .16025 .71955 .1517 Mtetra
.537 .671 .924 r
.0429 .38737 .05041 .39545 .05997 .39504 .05258 .38622 Mtetra
.951 .628 .38 r
.05258 .38622 .05997 .39504 .07099 .38479 .05543 .4328 Mtetra
.72 .755 .249 r
.05543 .4328 .07099 .38479 .08059 .3847 .07311 .37674 Mtetra
.55 .682 .926 r
.07311 .37674 .08059 .3847 .09029 .38438 .08297 .37531 Mtetra
.93 .699 .567 r
.08297 .37531 .09029 .38438 .10137 .37405 .10864 .2572 Mtetra
0 0 .114 r
.10864 .2572 .10137 .37405 .11117 .37358 .10374 .36562 Mtetra
.561 .688 .925 r
.10374 .36562 .11117 .37358 .12109 .37271 .11376 .36396 Mtetra
.861 .427 .006 r
.11376 .36396 .12109 .37271 .13226 .36206 .12132 .38234 Mtetra
.769 .858 .416 r
.12132 .38234 .13226 .36206 .14215 .36209 .13478 .35402 Mtetra
.568 .689 .922 r
.13478 .35402 .14215 .36209 .1523 .36044 .14497 .35221 Mtetra
.354 .587 .932 r
.14497 .35221 .1523 .36044 .16403 .3454 .15482 .35363 Mtetra
.612 .894 .589 r
.15482 .35363 .16403 .3454 .17353 .35021 .16627 .34172 Mtetra
.557 .674 .917 r
.16627 .34172 .17353 .35021 .18388 .34808 .17656 .34015 Mtetra
.557 .692 .93 r
.17656 .34015 .18388 .34808 .19365 .35192 .18692 .3385 Mtetra
.772 .661 .74 r
.18692 .3385 .19365 .35192 .20535 .3376 .19845 .3261 Mtetra
.411 .525 .863 r
.19845 .3261 .20535 .3376 .21581 .33568 .20856 .32775 Mtetra
.594 .708 .923 r
.20856 .32775 .21581 .33568 .22635 .33361 .21914 .32532 Mtetra
.421 .622 .935 r
.21914 .32532 .22635 .33361 .23834 .31613 .22949 .32591 Mtetra
0 0 0 r
.22949 .32591 .23834 .31613 .24815 .32291 .24103 .31419 Mtetra
.564 .675 .914 r
.24103 .31419 .24815 .32291 .25887 .32033 .25169 .31243 Mtetra
.603 .715 .924 r
.25169 .31243 .25887 .32033 .2696 .31823 .26249 .30974 Mtetra
.338 .574 .928 r
.26249 .30974 .2696 .31823 .28133 .30407 .27298 .31152 Mtetra
.655 .911 .597 r
.27298 .31152 .28133 .30407 .29175 .30712 .2847 .2985 Mtetra
.579 .687 .915 r
.2847 .2985 .29175 .30712 .30268 .30428 .2956 .29636 Mtetra
.615 .723 .922 r
.2956 .29636 .30268 .30428 .31366 .30147 .30662 .29332 Mtetra
.563 .696 .93 r
.30662 .29332 .31366 .30147 .32396 .31019 .31761 .29143 Mtetra
.726 .594 .709 r
.31761 .29143 .32396 .31019 .33613 .2902 .3293 .27962 Mtetra
.494 .597 .886 r
.3293 .27962 .33613 .2902 .34725 .28758 .34028 .27952 Mtetra
.62 .723 .92 r
.34028 .27952 .34725 .28758 .35846 .28425 .3515 .27632 Mtetra
.626 .73 .922 r
.3515 .27632 .35846 .28425 .36971 .28115 .36279 .27296 Mtetra
.582 .707 .928 r
.36279 .27296 .36971 .28115 .38071 .28463 .37408 .27061 Mtetra
.778 .666 .74 r
.37408 .27061 .38071 .28463 .39261 .2694 .38592 .25756 Mtetra
.453 .548 .863 r
.38592 .25756 .39261 .2694 .40399 .26675 .39715 .25855 Mtetra
.625 .725 .919 r
.39715 .25855 .40399 .26675 .41546 .26314 .40864 .25516 Mtetra
.639 .738 .921 r
.40864 .25516 .41546 .26314 .42699 .25937 .4202 .25139 Mtetra
.64 .74 .921 r
.4202 .25139 .42699 .25937 .43857 .25563 .43181 .24757 Mtetra
.632 .735 .922 r
.43181 .24757 .43857 .25563 .45019 .25242 .44347 .24394 Mtetra
.558 .693 .93 r
.44347 .24394 .45019 .25242 .46088 .2969 .45514 .24205 Mtetra
.604 .408 .589 r
.45514 .24205 .46088 .2969 .47369 .2403 .46707 .23025 Mtetra
.548 .645 .898 r
.46707 .23025 .47369 .2403 .48547 .23705 .47884 .22877 Mtetra
.636 .734 .919 r
.47884 .22877 .48547 .23705 .4973 .23308 .49071 .22498 Mtetra
.648 .745 .92 r
.49071 .22498 .4973 .23308 .5092 .22891 .50263 .22084 Mtetra
.653 .749 .92 r
.50263 .22084 .5092 .22891 .52114 .22462 .51461 .21656 Mtetra
.655 .751 .92 r
.51461 .21656 .52114 .22462 .53314 .22025 .52664 .21218 Mtetra
.657 .752 .92 r
.52664 .21218 .53314 .22025 .54519 .21582 .53873 .20774 Mtetra
.658 .753 .92 r
.53873 .20774 .54519 .21582 .55729 .21136 .55087 .20324 Mtetra
.659 .754 .92 r
.55087 .20324 .55729 .21136 .56945 .20686 .56306 .19871 Mtetra
.56306 .19871 .56945 .20686 .58166 .20235 .5753 .19416 Mtetra
.5753 .19416 .58166 .20235 .59392 .19782 .5876 .1896 Mtetra
.5876 .1896 .59392 .19782 .60623 .19328 .59995 .18501 Mtetra
.658 .753 .92 r
.59995 .18501 .60623 .19328 .6186 .18873 .61236 .18042 Mtetra
.61236 .18042 .6186 .18873 .63103 .18416 .62482 .17581 Mtetra
.62482 .17581 .63103 .18416 .64351 .17957 .63734 .17119 Mtetra
.63734 .17119 .64351 .17957 .65604 .17497 .64991 .16655 Mtetra
.64991 .16655 .65604 .17497 .66863 .17036 .66254 .16189 Mtetra
.66254 .16189 .66863 .17036 .68128 .16572 .67522 .15722 Mtetra
.657 .753 .92 r
.67522 .15722 .68128 .16572 .69398 .16107 .68796 .15252 Mtetra
.68796 .15252 .69398 .16107 .70674 .15639 .70076 .14781 Mtetra
.70076 .14781 .70674 .15639 .71955 .1517 .71362 .14308 Mtetra
.396 .533 .876 r
.03574 .37671 .0429 .38737 .05258 .38622 .04501 .37826 Mtetra
.49 .658 .935 r
.04501 .37826 .05258 .38622 .05543 .4328 .05465 .3778 Mtetra
.599 .404 .589 r
.05465 .3778 .05543 .4328 .07311 .37674 .06577 .36744 Mtetra
.486 .616 .905 r
.06577 .36744 .07311 .37674 .08297 .37531 .07544 .3673 Mtetra
.484 .655 .936 r
.07544 .3673 .08297 .37531 .10864 .2572 .08522 .36693 Mtetra
.441 .182 .423 r
.08522 .36693 .10864 .2572 .10374 .36562 .09641 .35649 Mtetra
.506 .632 .909 r
.09641 .35649 .10374 .36562 .11376 .36396 .10629 .35597 Mtetra
.518 .672 .934 r
.10629 .35597 .11376 .36396 .12132 .38234 .11628 .35503 Mtetra
.67 .511 .661 r
.11628 .35503 .12132 .38234 .13478 .35402 .12757 .34429 Mtetra
.483 .606 .898 r
.12757 .34429 .13478 .35402 .14497 .35221 .13754 .34426 Mtetra
.56 .692 .929 r
.13754 .34426 .14497 .35221 .15482 .35363 .14777 .34255 Mtetra
.817 .702 .737 r
.14777 .34255 .15482 .35363 .16627 .34172 .15962 .32739 Mtetra
.271 .383 .794 r
.15962 .32739 .16627 .34172 .17656 .34015 .16919 .33216 Mtetra
.583 .702 .924 r
.16919 .33216 .17656 .34015 .18692 .3385 .17963 .32996 Mtetra
.143 .458 .887 r
.17963 .32996 .18692 .3385 .19845 .3261 .18948 .33376 Mtetra
.76 .957 .649 r
.18948 .33376 .19845 .3261 .20856 .32775 .2013 .31932 Mtetra
.573 .687 .918 r
.2013 .31932 .20856 .32775 .21914 .32532 .21185 .31733 Mtetra
.577 .703 .928 r
.21185 .31733 .21914 .32532 .22949 .32591 .22247 .3152 Mtetra
.842 .717 .726 r
.22247 .3152 .22949 .32591 .24103 .31419 .23459 .29758 Mtetra
.221 .315 .748 r
.23459 .29758 .24103 .31419 .25169 .31243 .24448 .30433 Mtetra
.6 .71 .921 r
.24448 .30433 .25169 .31243 .26249 .30974 .25529 .30168 Mtetra
.577 .703 .928 r
.25529 .30168 .26249 .30974 .27298 .31152 .26612 .29951 Mtetra
.806 .696 .743 r
.26612 .29951 .27298 .31152 .2847 .2985 .27797 .28523 Mtetra
.365 .465 .83 r
.27797 .28523 .2847 .2985 .2956 .29636 .28848 .28823 Mtetra
.61 .716 .921 r
.28848 .28823 .2956 .29636 .30662 .29332 .29951 .28531 Mtetra
.607 .719 .924 r
.29951 .28531 .30662 .29332 .31761 .29143 .31059 .28243 Mtetra
0 .162 .689 r
.31059 .28243 .31761 .29143 .3293 .27962 .32097 .29111 Mtetra
.721 .877 .473 r
.32097 .29111 .3293 .27962 .34028 .27952 .33328 .27098 Mtetra
.598 .703 .917 r
.33328 .27098 .34028 .27952 .3515 .27632 .3445 .26829 Mtetra
.626 .73 .921 r
.3445 .26829 .3515 .27632 .36279 .27296 .35581 .26488 Mtetra
.617 .725 .924 r
.35581 .26488 .36279 .27296 .37408 .27061 .36717 .2617 Mtetra
.227 .501 .903 r
.36717 .2617 .37408 .27061 .38592 .25756 .37827 .26513 Mtetra
.696 .911 .566 r
.37827 .26513 .38592 .25756 .39715 .25855 .39029 .24977 Mtetra
.597 .7 .915 r
.39029 .24977 .39715 .25855 .40864 .25516 .40178 .24704 Mtetra
.634 .734 .92 r
.40178 .24704 .40864 .25516 .4202 .25139 .41336 .24335 Mtetra
.64 .74 .921 r
.41336 .24335 .4202 .25139 .43181 .24757 .425 .23949 Mtetra
.638 .739 .921 r
.425 .23949 .43181 .24757 .44347 .24394 .43669 .23567 Mtetra
.617 .726 .924 r
.43669 .23567 .44347 .24394 .45514 .24205 .44843 .23238 Mtetra
.921 .543 .135 r
.44843 .23238 .45514 .24205 .46707 .23025 .45921 .27695 Mtetra
0 0 .036 r
.45921 .27695 .46707 .23025 .47884 .22877 .47217 .22007 Mtetra
.617 .716 .916 r
.47217 .22007 .47884 .22877 .49071 .22498 .48406 .21673 Mtetra
.644 .741 .92 r
.48406 .21673 .49071 .22498 .50263 .22084 .49602 .21268 Mtetra
.651 .747 .92 r
.49602 .21268 .50263 .22084 .51461 .21656 .50803 .20841 Mtetra
.654 .75 .92 r
.50803 .20841 .51461 .21656 .52664 .21218 .5201 .20404 Mtetra
.656 .752 .92 r
.5201 .20404 .52664 .21218 .53873 .20774 .53222 .19958 Mtetra
.658 .753 .92 r
.53222 .19958 .53873 .20774 .55087 .20324 .54439 .19506 Mtetra
.659 .754 .92 r
.54439 .19506 .55087 .20324 .56306 .19871 .55662 .1905 Mtetra
.55662 .1905 .56306 .19871 .5753 .19416 .5689 .18591 Mtetra
.5689 .18591 .5753 .19416 .5876 .1896 .58123 .18131 Mtetra
.58123 .18131 .5876 .1896 .59995 .18501 .59362 .17668 Mtetra
.658 .753 .92 r
.59362 .17668 .59995 .18501 .61236 .18042 .60606 .17205 Mtetra
.60606 .17205 .61236 .18042 .62482 .17581 .61856 .1674 Mtetra
.61856 .1674 .62482 .17581 .63734 .17119 .63112 .16274 Mtetra
.63112 .16274 .63734 .17119 .64991 .16655 .64373 .15806 Mtetra
.64373 .15806 .64991 .16655 .66254 .16189 .65639 .15336 Mtetra
.65639 .15336 .66254 .16189 .67522 .15722 .66912 .14865 Mtetra
.657 .753 .92 r
.66912 .14865 .67522 .15722 .68796 .15252 .6819 .14391 Mtetra
.6819 .14391 .68796 .15252 .70076 .14781 .69474 .13916 Mtetra
.69474 .13916 .70076 .14781 .71362 .14308 .70764 .13439 Mtetra
.827 .979 .688 r
.02552 .38538 .03574 .37671 .04501 .37826 .03742 .37005 Mtetra
.537 .671 .924 r
.03742 .37005 .04501 .37826 .05465 .3778 .04717 .36884 Mtetra
.951 .627 .376 r
.04717 .36884 .05465 .3778 .06577 .36744 .04995 .41556 Mtetra
.728 .761 .258 r
.04995 .41556 .06577 .36744 .07544 .3673 .06788 .35921 Mtetra
.55 .682 .926 r
.06788 .35921 .07544 .3673 .08522 .36693 .07781 .35772 Mtetra
.931 .699 .566 r
.07781 .35772 .08522 .36693 .09641 .35649 .1039 .23911 Mtetra
0 0 .106 r
.1039 .23911 .09641 .35649 .10629 .35597 .09877 .34787 Mtetra
.561 .688 .925 r
.09877 .34787 .10629 .35597 .11628 .35503 .10887 .34615 Mtetra
.858 .422 0 r
.10887 .34615 .11628 .35503 .12757 .34429 .11646 .36454 Mtetra
.776 .863 .424 r
.11646 .36454 .12757 .34429 .13754 .34426 .13008 .33605 Mtetra
.568 .689 .922 r
.13008 .33605 .13754 .34426 .14777 .34255 .14035 .33417 Mtetra
.355 .587 .932 r
.14035 .33417 .14777 .34255 .15962 .32739 .15028 .33555 Mtetra
.624 .902 .6 r
.15028 .33555 .15962 .32739 .16919 .33216 .16184 .32352 Mtetra
.557 .674 .917 r
.16184 .32352 .16919 .33216 .17963 .32996 .17222 .32189 Mtetra
.557 .692 .93 r
.17222 .32189 .17963 .32996 .18948 .33376 .18267 .32017 Mtetra
.773 .661 .74 r
.18267 .32017 .18948 .33376 .2013 .31932 .19432 .30766 Mtetra
.411 .525 .863 r
.19432 .30766 .2013 .31932 .21185 .31733 .20451 .30926 Mtetra
.594 .708 .923 r
.20451 .30926 .21185 .31733 .22247 .3152 .21518 .30676 Mtetra
.422 .622 .935 r
.21518 .30676 .22247 .3152 .23459 .29758 .22562 .30729 Mtetra
0 0 0 r
.22562 .30729 .23459 .29758 .24448 .30433 .23728 .29546 Mtetra
.564 .675 .914 r
.23728 .29546 .24448 .30433 .25529 .30168 .24803 .29363 Mtetra
.603 .715 .924 r
.24803 .29363 .25529 .30168 .26612 .29951 .25893 .29087 Mtetra
.34 .575 .927 r
.25893 .29087 .26612 .29951 .27797 .28523 .26951 .29258 Mtetra
.665 .918 .607 r
.26951 .29258 .27797 .28523 .28848 .28823 .28135 .27945 Mtetra
.579 .687 .915 r
.28135 .27945 .28848 .28823 .29951 .28531 .29234 .27724 Mtetra
.615 .723 .922 r
.29234 .27724 .29951 .28531 .31059 .28243 .30347 .27413 Mtetra
.563 .696 .93 r
.30347 .27413 .31059 .28243 .32097 .29111 .31456 .27216 Mtetra
.727 .595 .709 r
.31456 .27216 .32097 .29111 .33328 .27098 .32636 .26024 Mtetra
.493 .597 .886 r
.32636 .26024 .33328 .27098 .3445 .26829 .33744 .26007 Mtetra
.62 .723 .92 r
.33744 .26007 .3445 .26829 .35581 .26488 .34878 .25679 Mtetra
.626 .73 .922 r
.34878 .25679 .35581 .26488 .36717 .2617 .36017 .25335 Mtetra
.582 .706 .928 r
.36017 .25335 .36717 .2617 .37827 .26513 .37157 .25092 Mtetra
.779 .667 .74 r
.37157 .25092 .37827 .26513 .39029 .24977 .38353 .23775 Mtetra
.452 .548 .863 r
.38353 .23775 .39029 .24977 .40178 .24704 .39487 .23868 Mtetra
.625 .725 .919 r
.39487 .23868 .40178 .24704 .41336 .24335 .40647 .23521 Mtetra
.639 .738 .921 r
.40647 .23521 .41336 .24335 .425 .23949 .41814 .23136 Mtetra
.64 .74 .921 r
.41814 .23136 .425 .23949 .43669 .23567 .42986 .22745 Mtetra
.632 .735 .922 r
.42986 .22745 .43669 .23567 .44843 .23238 .44164 .22373 Mtetra
.558 .693 .93 r
.44164 .22373 .44843 .23238 .45921 .27695 .45342 .22176 Mtetra
.602 .405 .587 r
.45342 .22176 .45921 .27695 .47217 .22007 .46548 .20985 Mtetra
.548 .645 .898 r
.46548 .20985 .47217 .22007 .48406 .21673 .47736 .20829 Mtetra
.636 .734 .919 r
.47736 .20829 .48406 .21673 .49602 .21268 .48935 .20441 Mtetra
.648 .745 .92 r
.48935 .20441 .49602 .21268 .50803 .20841 .50139 .20018 Mtetra
.653 .749 .92 r
.50139 .20018 .50803 .20841 .5201 .20404 .51349 .19581 Mtetra
.655 .751 .92 r
.51349 .19581 .5201 .20404 .53222 .19958 .52565 .19134 Mtetra
.657 .752 .92 r
.52565 .19134 .53222 .19958 .54439 .19506 .53786 .1868 Mtetra
.658 .753 .92 r
.53786 .1868 .54439 .19506 .55662 .1905 .55012 .18222 Mtetra
.659 .754 .92 r
.55012 .18222 .55662 .1905 .5689 .18591 .56244 .17759 Mtetra
.56244 .17759 .5689 .18591 .58123 .18131 .57481 .17295 Mtetra
.57481 .17295 .58123 .18131 .59362 .17668 .58723 .16829 Mtetra
.58723 .16829 .59362 .17668 .60606 .17205 .59971 .16361 Mtetra
.658 .753 .92 r
.59971 .16361 .60606 .17205 .61856 .1674 .61225 .15892 Mtetra
.61225 .15892 .61856 .1674 .63112 .16274 .62484 .15422 Mtetra
.62484 .15422 .63112 .16274 .64373 .15806 .63749 .14949 Mtetra
.63749 .14949 .64373 .15806 .65639 .15336 .6502 .14476 Mtetra
.6502 .14476 .65639 .15336 .66912 .14865 .66296 .14 Mtetra
.66296 .14 .66912 .14865 .6819 .14391 .67578 .13523 Mtetra
.657 .753 .92 r
.67578 .13523 .6819 .14391 .69474 .13916 .68866 .13043 Mtetra
.68866 .13043 .69474 .13916 .70764 .13439 .7016 .12562 Mtetra
.748 .632 .731 r
.01886 .37062 .02552 .38538 .03742 .37005 .03017 .35924 Mtetra
.396 .533 .877 r
.03017 .35924 .03742 .37005 .04717 .36884 .03951 .36074 Mtetra
.49 .658 .935 r
.03951 .36074 .04717 .36884 .04995 .41556 .04922 .36022 Mtetra
.597 .401 .587 r
.04922 .36022 .04995 .41556 .06788 .35921 .06045 .34977 Mtetra
.486 .616 .906 r
.06045 .34977 .06788 .35921 .07781 .35772 .0702 .34957 Mtetra
.484 .655 .936 r
.0702 .34957 .07781 .35772 .1039 .23911 .08005 .34913 Mtetra
.435 .174 .417 r
.08005 .34913 .1039 .23911 .09877 .34787 .09135 .3386 Mtetra
.506 .632 .909 r
.09135 .3386 .09877 .34787 .10887 .34615 .10131 .33802 Mtetra
.518 .672 .933 r
.10131 .33802 .10887 .34615 .11646 .36454 .11139 .33702 Mtetra
.669 .51 .66 r
.11139 .33702 .11646 .36454 .13008 .33605 .12278 .32618 Mtetra
.483 .606 .899 r
.12278 .32618 .13008 .33605 .14035 .33417 .13283 .32609 Mtetra
.56 .692 .929 r
.13283 .32609 .14035 .33417 .15028 .33555 .14315 .32431 Mtetra
.818 .702 .738 r
.14315 .32431 .15028 .33555 .16184 .32352 .15513 .30903 Mtetra
.269 .382 .794 r
.15513 .30903 .16184 .32352 .17222 .32189 .16477 .31375 Mtetra
.583 .702 .924 r
.16477 .31375 .17222 .32189 .18267 .32017 .17529 .31149 Mtetra
.146 .46 .887 r
.17529 .31149 .18267 .32017 .19432 .30766 .18522 .31524 Mtetra
.766 .961 .656 r
.18522 .31524 .19432 .30766 .20451 .30926 .19716 .30068 Mtetra
.573 .687 .918 r
.19716 .30068 .20451 .30926 .21518 .30676 .20781 .29862 Mtetra
.577 .703 .928 r
.20781 .29862 .21518 .30676 .22562 .30729 .21852 .29642 Mtetra
.843 .718 .726 r
.21852 .29642 .22562 .30729 .23728 .29546 .23077 .27867 Mtetra
.218 .313 .748 r
.23077 .27867 .23728 .29546 .24803 .29363 .24073 .28538 Mtetra
.6 .71 .921 r
.24073 .28538 .24803 .29363 .25893 .29087 .25164 .28265 Mtetra
.577 .703 .928 r
.25164 .28265 .25893 .29087 .26951 .29258 .26257 .28041 Mtetra
.807 .696 .743 r
.26257 .28041 .26951 .29258 .28135 .27945 .27454 .26602 Mtetra
.363 .465 .83 r
.27454 .26602 .28135 .27945 .29234 .27724 .28514 .26895 Mtetra
.61 .716 .921 r
.28514 .26895 .29234 .27724 .30347 .27413 .29627 .26596 Mtetra
.607 .719 .924 r
.29627 .26596 .30347 .27413 .31456 .27216 .30746 .263 Mtetra
0 .167 .693 r
.30746 .263 .31456 .27216 .32636 .26024 .31793 .27165 Mtetra
.729 .883 .482 r
.31793 .27165 .32636 .26024 .33744 .26007 .33036 .25138 Mtetra
.598 .703 .917 r
.33036 .25138 .33744 .26007 .34878 .25679 .34169 .24861 Mtetra
.626 .73 .921 r
.34169 .24861 .34878 .25679 .36017 .25335 .35311 .24511 Mtetra
.617 .725 .924 r
.35311 .24511 .36017 .25335 .37157 .25092 .36458 .24185 Mtetra
.229 .502 .903 r
.36458 .24185 .37157 .25092 .38353 .23775 .37578 .24522 Mtetra
.705 .917 .575 r
.37578 .24522 .38353 .23775 .39487 .23868 .38793 .22974 Mtetra
.597 .7 .915 r
.38793 .22974 .39487 .23868 .40647 .23521 .39953 .22692 Mtetra
.634 .734 .92 r
.39953 .22692 .40647 .23521 .41814 .23136 .41122 .22315 Mtetra
.64 .74 .921 r
.41122 .22315 .41814 .23136 .42986 .22745 .42298 .2192 Mtetra
.638 .739 .921 r
.42298 .2192 .42986 .22745 .44164 .22373 .43478 .2153 Mtetra
.617 .726 .924 r
.43478 .2153 .44164 .22373 .45342 .22176 .44663 .21192 Mtetra
.919 .539 .126 r
.44663 .21192 .45342 .22176 .46548 .20985 .45749 .25659 Mtetra
0 0 .028 r
.45749 .25659 .46548 .20985 .47736 .20829 .47062 .19942 Mtetra
.617 .716 .916 r
.47062 .19942 .47736 .20829 .48935 .20441 .48262 .196 Mtetra
.644 .741 .92 r
.48262 .196 .48935 .20441 .50139 .20018 .4947 .19185 Mtetra
.651 .747 .92 r
.4947 .19185 .50139 .20018 .51349 .19581 .50684 .1875 Mtetra
.654 .75 .92 r
.50684 .1875 .51349 .19581 .52565 .19134 .51903 .18302 Mtetra
.656 .752 .92 r
.51903 .18302 .52565 .19134 .53786 .1868 .53127 .17847 Mtetra
.658 .753 .92 r
.53127 .17847 .53786 .1868 .55012 .18222 .54357 .17386 Mtetra
.659 .754 .92 r
.54357 .17386 .55012 .18222 .56244 .17759 .55592 .16921 Mtetra
.55592 .16921 .56244 .17759 .57481 .17295 .56833 .16452 Mtetra
.56833 .16452 .57481 .17295 .58723 .16829 .58079 .15982 Mtetra
.58079 .15982 .58723 .16829 .59971 .16361 .59331 .1551 Mtetra
.658 .753 .92 r
.59331 .1551 .59971 .16361 .61225 .15892 .60589 .15037 Mtetra
.60589 .15037 .61225 .15892 .62484 .15422 .61852 .14562 Mtetra
.61852 .14562 .62484 .15422 .63749 .14949 .63121 .14086 Mtetra
.63121 .14086 .63749 .14949 .6502 .14476 .64395 .13608 Mtetra
.64395 .13608 .6502 .14476 .66296 .14 .65676 .13129 Mtetra
.65676 .13129 .66296 .14 .67578 .13523 .66962 .12647 Mtetra
.657 .753 .92 r
.66962 .12647 .67578 .13523 .68866 .13043 .68254 .12163 Mtetra
.68254 .12163 .68866 .13043 .7016 .12562 .69552 .11678 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`8006Aoo`03D_aBoE;l009Bo008D_eB
o5;lD_aBoE;l001Bo1Moo`03001oogoo04Uoo`00Sgoo0`00I7oo00mBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_d05Woo00<007oo0000BWoo002=Ool3001ROol00e;lD_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo000009Bo1Moo`03001oogoo04Qoo`00RWoo0`000goo00<007ooOol0GGoo
01MBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m01Moo`03001oogoo
04Moo`00Qgoo0`00Hgoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eB
o000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069oo`0PD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoAIoo`03001oogoo04Ioo`00
PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eoo`00P7oo0P00Hgoo02EBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00=BoE;lOol0
5Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1MOol0;5;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EB
oE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00HGoo03ABo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo049oo`00Lgoo0`00HGoo0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00ABoE;lD_aBo1Moo`03001oogoo045oo`00LGoo0P00
HWoo03UBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_`0
5Goo00<007oo0000@Woo001^Ool3001ROol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;m001Bo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001oogoo041oo`00Jgoo0`00Hgoo03iBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
5goo00<007ooOol0?goo001YOol20003Ool00`00Oomoo`1KOol00e;lD_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m009Bo1Io
o`03001oogoo03moo`00IWoo0`00HGoo04MBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Ioo`03001oogoo
03ioo`00I7oo0P00HWoo0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol0?Goo001Q
Ool3001POol0Ce;mC]aBoE;lD_e>o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Eoo`03001oogoo
02Eoo`<001Eoo`00=Goo10009Woo0P00Ggoo00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00=BoE;lOol05Goo00<007ooOol09Woo00<007ooOol04goo000dOol00`00
Oomoo`02Ool00`00Oomoo`0POol3001POol0EDkLD_e>o5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo02Eoo`03001oogoo01=oo`00>Goo00<007ooOol0
7Woo0P000Woo00<007ooOol0G7oo00ABo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`00e;mD_aoo`0DOol00`00Oomoo`0TOol00`00Ool0000DOol002aoo`H000Mo
o`03001oogoo01]oo`<005moo`1LB[a>gD[LC]e:_5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo02=oo`03001oo`0001Aoo`00=Goo1000
77oo0P00HWoo00<004[LC]`00dkL00ABo4klD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@0FOol00`00Oomoo`0QOol01@00Oomoogoo00004goo000eOol0
0`00Oomoo`0JOol3001SOol20000GDkMB[a>gD[LC]e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0DOol2000SOol01@00Oomoogoo00004goo000eOol0
0`00Oomoo`0GOol3001VOol300001TkmC]a>g4kLC_e>o09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol07goo0`0000Aoo`000000019o
o`00=Goo1@004goo0P00Igoo069f8`00AYa2NdJL@W]BoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkL
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Woo00<007ooOol0=goo001:Ool30000
0goo001oo`1MOol01DkMB]a>gDkLMP<00goo00ef0g830012W4JL@W]6W4kLC_e>g5;lC_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007oo
Ool027oo1000:goo0018Ool2001OOol02DkLD_e>g5;mC]a>gD[LC_eb0`02Ool0IGHSLP<004UaCI92
NdJL@W]6W4kLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d05Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0:7oo0015Ool3001O
Ool03E;mC]a>o4klD_e>g4klC]a>gD[LC]eb0gH3009b0`030019TTVB00=>g008B]a>g4klD_e>g5;l
C_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
2E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Ioo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo02Qoo`00@goo0P00H7oo07E>g5;mC]aBoDkLD_e>
g5;mC]aBoD:lA[e2_7HSLP=f0g830019TDfB001>gD[LC]e:_4kMC]aBoDkLD_e>g5;mC]aBoE;lD_e>
o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Woo00<007ooOol01Goo00<0
07ooOol00Woo00<007ooOol0:7oo0010Ool3001NOol01TkmC]a>g4kLC_e>g09>o007D_e>g4kmC]a>
oDkLC_d00TJm0g8300If0`00BI99TP00B]`2C]`01TkmC]a>g5;lD_e>o09Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Ioo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo02Qoo`00?Woo0P00GGoo01]:_4[MB[a:gDZlD_e>g5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4KM@[af0g83MR=b0dfBBG400`00065>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003]oo`@005eoo`04Ei5KTDZlB]`2B[`01dkLC_e>g4kl
C]aBoDkL009>o009D_e>g4kmC]a>oDkLA[eb0gH3009b0`99TP04@W]6W4:LAY`3C]`01DkmC]aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009
D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l
Ool057oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0:7oo000iOol20004Ool00`00Oomo
o`1IOol0PeNAFk9GTE^bB[a:gDZlB]e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4kM@[a6gG83MP<0
04fBBI5=TT9kAYa2NdJLC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol00goo1000:goo000fOol3001R
Ool01e^AEi5KTUNAFi5>g4kM00=>g006D_e>g4klC]aBoDkL0Tkl00IBoD[LC]e>g4kMA[d2LP<00`00
BI99TP02BI800d[LC]a>g002C]`00e;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo015oo`800003Ool007oo039oo`00<goo
0`00I7oo08EK/UjFH[Lf6SXk=QXj>dkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a6_G83
MR=9TDfBBI5=TTVA001:_4kMB]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0aOol0035oo`8005mo
o`05C]a>gD[LC]e>g0036O`2HYL01F:F=S/f6SXk=QX00TkL00I>gDkLC]a>g5;mC]`2C_`01E;mC]a>
o4klD_d00dJm00=f0g83BI800dVB0P0000=>g4[LC]`00TkL00A>o5;lD_aBo@=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00P0000=B
o5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<0
07ooOol0<7oo000^Ool3000>Ool00cB<Oomoo`1<Ool0:dkmC]a>oDkLC_e:g4kMB]a>oAWl7OaNUV:g
HYIR]ejF>S/f6SXk=QYBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkLC_e2_4KMLP=f0dUaCI99TDfB
00<00015D_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00<0000MD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0_Ool002aoo`@000moo`03=:ao
ogoo04Qoo`=:_00;B]a:_4kLC]a>gDkLC]e>g4kMB]a>g@02HYL00f:FHYMRU`02Ei42B[`01D[LB[a>
g4kLC_d00TkL00=>o5;mC]`00Tkl00E>oDkLC_e>g4km0096_@030019TTVB0099TP05AYa2NdJL@Ya>
o@03C]`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00<00006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol0;goo000ZOol2000COol00c2<Oomoo`17Ool0LU]^
Ghm:_4kMB[a:gDZlC_e>g4kmC]a:gDJlB]e6_6:gHYIR]ejFH[MGTE^AB[a:gDZlB]e:_5;mC]aBoDkL
D_e>g5;mC]aBoDkLC]e:g4kmB]a6_D:lCI99TDfBBI5=TT9kAYa2NdJLC]aBoDkLD_e>g5;mC]aBoDkl
D_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@<0000TD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l5Goo00<007ooOol0;Woo000ZOol2000COol00cB/Oomoo`17Ool2Ffh03U]_B[a:_4ZlB]a:_4kM
C]a>gDkLB]e6_D[MA[`3HYL4Ei43C]`01TkMC]a>o4kLD_e>g09>o007D_e>g4klC_a>gD[LC]d00TJm
1DVB00]6W4:LAYa2NdJLC_aBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo000001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`05Goo00<007ooOol0;Woo000@Ool50003
Ool40004Ool40006Ool00`00Ool0000AOol00cB]=8aoo`17Ool0KUn?FfiOSe]^Ghm:g4kmB]a>gD[L
C_e>g4kmC]a>oDJlB]eNUV:gEi5R]ejF>S/f6SXkB]a>oDkLC]e>g5;mC]aBoDkLD_e>g5;mC]aBoD[L
C]e:g4km@[a=TTUaCI99TDfBBI5>gD[LC]e:_4kMC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`30000:U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001B
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo
02eoo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`80
0003Ool007oo00moo`03=8`d[7oo04Moo`9JEP@nF`=>g00:C]e>g4kMC]a>gD[LC]e6_D[MHYH3HYL0
13HJ=S/f6SXk0dkL00I>gDkLC_a>o5;mC]`2C_`00e;mC]a>o005A[d5BI802@01C]a>g4kLB]a>g5;l
D_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l0`000e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aoo`0EOol00`00Oomoo`0/Ool0019oo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0=Ool013B]<8aoocB<?Goo00E:
g4kMB]a>gD[L00=oo`1YFfiNEUYE?U`jFciL>U]>gD[LC_e>g4kmC]a>oD[LC]e:g1gl6OaR]ejFH[MR
UV:g=QXj>cHJ>S]>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;m@[a6_D:lA]e9TDfBBI5=TTVB005:
_4kMB]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00<0000aD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol0;7oo0007Ool60005Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol037oo00@dS7ooOold[CEoo`9V]`0@;MXYfBgJB]a>g4[LC]e:g4[MB]a>g@2EOol0UEYFFUD2
FUH4?U/02TkMC]a>g4kLC]e:g4kMC]a>gD[L0f:G00ARUV:GHYM:g0=:_006B]a>g4kLC]a>oDkL0Tkl
00IBoDkLC_e>g4kmC]`4A[d4BI830043C]`01TkmC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eB
o0<000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001B
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Aoo`03001o
ogoo02]oo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo00Yoo`05>W`d[GooOoldS00dOol0M6KGH[IVebVi;MXYfBgJB[a>
gD[LC]e:_4kMB]a>gEYEGUIJEEiFFUEKKe]^B]e:_4kMB[a>oDkLC_e>g4kmA[a:gDJlB]eNUV:gHYIR
]ejFEi5GT4[MB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4KM@[a=TTVACI99TTfB@W]6
W49kAYa>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_`30000>E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Ool0000/Ool0019oo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool20006Ool2000:Ool01CB/
=8aoogoo=:d0=7oo16Jg00TYfBgJ:MT]fT[LC]e>g4kMB]`00TJm00=JEUYEFUH00UYF0e]^00i:g4Zl
B[a:_4kMC]a>gDkLC]e6_4[MA[e:gF:F0V:G0eNA00=:_4[LB[`00TZl00IBoDkLC_a>g5;mC]`2C_`0
1E;mC]a>gDkLC]d00TJm1DVB00Y=TT9kAYa2W4JLC]aBo4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_`000020003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d05Goo00<007ooOol0:Woo000@Ool30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol01goo00DdS3B]Oold[CB<03=oo`0DH[IVef:fI]MR]TZm
AYa:_DJlB[e:g4kmB]a>gDJlA]e6_5iFFUENEP=KKP1HFfmKKTkMB]a>oD[LC_e>g4kmC]a:gDJlB]e6
_6:gGYIR]f:FH[Lf6SXkC]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kM@[a=TTVACI99
TDfBBI9=TTZlC]e:g4kMC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_`30000@5;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<007ooOol0:Goo000B
Ool00`00Oomoo`03Ool40004Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01CB/=8aoocB/
=:d09goo00=ZeQTgOol027oo1FJg0U>B00U:_4JlB[a6_4kMB]a>gDkLC]d00TJm0UYF00=JEEYFFUH0
13iK00i>gDkLC]a>g4kMC]a>gDkLB]e6_4[MA[eRUf:F0V:G00Dj>cHJ=S]>g4kM00=>g006D_e>g4kl
C_aBoDkL0Tkl00EBoDkLC]e>g4Jm00M9TP09005:g4kLC]aBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo000008000=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;m
D_aBo5;l5Woo00<007ooOol0:7oo000XOol00`00Oomoo`0:Ool00`00Oomoo`05Ool01S2<=:eoocB]
=8`h[BIoo`1AI[IZeaTg6CM:_4kMB[a:gDZlB]e6_4[MH[IVef:fEk=CTUNcDi9:_DJLB[e6_4kMB]a>
gD[LC]e6_5iFFUEKKUYEGUHjFciL>U/nG4[LC]e:g4kmB]a>gD[LC_e:g1Wl6M/Mo1WlH[MNUV:gHYHj
>cHJ>S]>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a6gD:lA[e9TDfBBI9=TTVA00800@0SC]e:
_4kMB]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7@020000Ae;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol0:7oo000XOol3000;
Ool00`00Oomoo`03Ool01cB<=:`dS7oo=:aoocB/02Eoo`=ZeP<I=`05B[a:g4[LB]e6_002A[d5I[L0
3BWI;MX]fDkMB]a>g4[LC]e:g4[MB]`0UDJm00=JEP03FUEJESiK00<nF`03C]a>gDkL009>g004C]e:
g4kMC]`26O`3HYL016:FHYM:_4[L0TZl00M>g4kmC]a>g4klD_e>g002C_`01DkmC]a>oDkLC_d00dJm
14VB00E=TP0100400Dkm00=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eBo5;l00<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol0
9goo000XOol00`00Oomoo`0<Ool00`00Oomoo`02Ool01cB]=8`d[CYl=:eoocR]02Aoo`05I[IZef[F
J]IV]P026CL0Jd[MB[a>gDZlB]e6_4[MA[aVef:fI]MR]RgJ:KT]fRWIC]e:_4kMB]a>gD[LC]e:g5YF
FUENEUYEFUIJEDkMB[a:gDZlC]e>g4kmC]a>oDkLC]e:g4kmB]aR]ejFH[MRUV:gDg1GTDZlB]e:_4kM
C]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mC]a>oD:lA]e9TDfBBI5=/TVBAYa2NdJL@W]BoDkLD_e>g5;m
C]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDad00`0004iC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0VOol002Qoo`03001oogoo00eoo`0;
001oogooOoldS3B/=8`d[CB/Oold[@0TOol5J]H36CL01T[MB]a:gD[LB]dZ?08Z?@AV]`08;MXYfBgJ
B]a>gD[LC]a:g0=6_@9JEP03FUEJEUYF009KKP9:_00BB]a:_4ZlC]a>gDkLC]e>g4[MA[a:gDJmHYMR
UV:GEi1GTE>@0TZl00I:g4ZlB[a>g5;mC]`2C_`025;mC]a>o4klC]e:g4kMC]`2A[d5BI802T:LAYa2
NdJLC]a>oDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0VOol002Qoo`80
00moo`0:001oogoo=:d`S3B]=8`d[Goo>:dSOol01F[GJ]IZeVJfJ]L00P0006I6W4JmAYa>gDZlC]e:
g2YM9SaVef:fI]MR]VKG:MT]fRVi;MY:g4kMB]a>oD[LA]e6_4KMFUEJEUYEGUIGCU]^EdeKKT[LC]e:
g4kmC]a>oDkLC_e6_4[MA[a:gF:FH[MNUUNADg1GTE=`C_e>g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e>
g4kMB]a>oD:lA[e9TDfBBI9=TTVBCK92NdJL@W]6W4kLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lD_d30000EU<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`DOol00`00Oomoo`0UOol002Qoo`03001oogoo00moo`0;000jWCB<=:`dS3B]=:`d[CB/
Oold[@0MOol01DJlA[e6_D[MA[`016[F00XI=`00A[a6W4JlAYa:gD[LB]e:g0EV]`9CTP09A[a:_4Jl
B[a>g4kMB]a>gDkL0096_@=JEP03FfhnFciK00<nF`03C]a>gDkL009>g007C]e>g4kMA[e:gDJlB]d0
0V:G00ERUSXk=QXj>cHJ009>g006C]e>g4kLC_aBoDkL0Tkl00QBoDkLC_a>g4kMB]a>gDJm14VB00==
TTVBC]`00TkL00Q:g4kLC_aBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m009Bo0<0009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Eoo`03001oogoo
02Aoo`00:7oo00<007ooOol047oo00X`S3B]=8`d[CB<=:dd[3R]OolhcAUoo`0>HmAO/dZmA[a:_DJl
B]e6_4[MI[IZec9mJ]IV]P8I=`0[A[a6W4JmAYa:gDJlB]e6_6KGH[IVef:fDi9?TU>bA[a:_DJLB[e:
g4kMB]a>gD[LA]eJEEiFEdiJEUYE?U`jFciL>U]>oD[LC]e:g4kmB]a>gD[LC_d00QWl038Iff:gGYIR
]cHJ>S/f6SXkB]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoD:lA[e2_4KM@[a=TTVACK99TTfb005>
gD[LC]e:_4kMC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;m0`0005eBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04goo0P009Woo000WOol0
0`00Oomoo`0AOol01SB/=8`d[3B<=:dd[08d[@03Oold[Goo01Moo`03HmAOe6?D00=6_006A[e6_4Jm
A[e:gC9m0f[F0aTg00I:gDZlB]a:g4[MA[`2A[d4I[L03RgJ:MT]fT[LC]e:g4kLB]a>gD[LB]d0UDJm
FUD3FUH5?U/2C]`01TkMC]a>g4kLC]e:g08Io003HYMRUV:G009RU`04=QXj>cHJ>S/3C]`02dkmC]a>
o4klD_e>g4klC]a>oDkLC_d014Jm00=9TTfBBI800TVB0P010TkL00I>oDkLC]aBo5;mC_`2D_`00e;m
D_aBo0030002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00U;l57oo00<007ooOol08goo000WOol3000AOol02SB<=:d`S3B]
=8`d[CB/>:eoocS=67oo015NUV:g<OXb6dZlB]e:_4[MB[`fOC9mJ]IV]V[GJ]HI=aTf008I=`1GB]e:
_4kMB[a:gDJlB]eR]VKGH[IVebWI;MXY^BgJB]a>gDZlC]e:g4kMB]a>gEYEFUIJEEiFFUEJETZlC]e:
_4[MB[a>oDkLC_e>g4kmB]a>gD[LH[MNUV:gGYIR]e=`Ei1:_4kMB[a:gDkLD_e>g5;mC]aBoDkLD_e>
g5;mC]a>oDkLD_e>g4Jm@[a=/TVBCK99TTJL@W]6W49kD_e>g5;mC]aBoDklD_e>g5;m00<0001TD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0ROol002Moo`03001oogoo011oo`09>Ydd[3B<=:`d
S3B]=:`d[CB/008d[@]oo`04I[HQNAeh8GP8Ool2HYL02UjF<Q/b6S8KB[a:gD[LB]dbOCIm1F[F11Tg
00M:gD[LB]e:g2Xm:S`Z?@04I[L022gI;MXYfDkLB]a>gD[LC]`3A[d3FUH015YEFUIGKE]^0dZl00Y:
g4kLC]a>g4kMC]a:gDJmB]e6_0=RU`04HYICT5=`Ei03B[`01T[LC]a>o4kLD_e>g09>o007D_e>g4kl
C]a>gD[LC]d00TJm0dVB00E=TT9kAYa2W4JL00=>g004D_e>g5;lD_`20002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_eBo1Aoo`03001oogoo029oo`005Goo100017oo10001Woo00<007ooOol047oo00/d
[C2<=:ddS3B]=8`d[CB/>:dd[3S=00Yoo`0JI[IZefJf8GTMN26IA[a:gDJlB]d=^a7L3K]R]ejFHYMN
USHK<OXb6dZlB]e:_4[MI[IZe`9ZeP1GI[IZedJLA[a6W4JmAYa>gDZlC]e:g2YM9SaVef:fI[MR]RgJ
:MT]fRViC_e:g4kMB]a>oDJlA]e6_5iFFUEJEUYEFfiGCE]^B[a>gDZlB]e>g4kmC]a>oDkLB]e6_4[M
A[aR]ejFEi1CL5NADg1GT4[LC_e>g4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a6gD:lCI99TDfb
BI96W49kAYa2NdJLC]aBoDkL00<0001ZC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol0
0`00Oomoo`0QOol001Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomo
o`0@Ool01cB<=:`dS3B/=8`d[CB/008d[@03>:dd[CR]00Uoo`0:I]MV]VJg7GPQNAeh8GQ:_4[MA[`2
4M/00f:GGYIRU`02HYL01C8J<Q/b6S8KA[`00TJm00=:gF[FJ]H00V[F00/I=`00AYa6_4JLA[a:g4[M
B]a:gD[L00IV]`08B[a6_4ZlA[a>gDkLC]e:g0=6_@08FUEJEUYFFfiGCE]^EfeKKP=>g00:C]e>g4kM
C]a>gDkLB]e6_D[MHYH3HYL013HJ>S/f6SXk0dkL00IBoDkLC_a>o5;mC]`2C_`02E;mC]a>gDkLC]e:
g4JmBI9=TP03BI8014kLB]a>g4kL0`0000=>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo003D_eoogoo01=oo`03001oogoo021oo`006Goo00@007ooOol000Aoo`03001oogoo00=oo`80
015oo`0<=:ddS3B]<8`d[CB<=:dd[3R]=:eoocB]27oo01eZefJfI]MV]V[G7GPQNAeh8IU6_4[MA[aR
]ejFHYMNUV:gGk=Se4JLB[e6_4ZmA[a:gDJlJ]IV]SIm009ZeP1?6CHM=dJLA[a6W4JmA[a:gDJlB]e6
_6JgH[IVef:fDi9?LDZmA[a:_DJLC_e:g4kMB]a6gDJlFUIJEE]^FUEJESYK?U`jFciLB]a>oD[LC]e:
g4kmB]a>gD[L6O`InaWlGYIR]ejF>S/f6SXk=QY>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLA]e2
_4Jm@[a=/TVBCK99TTfb00400`00079:g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_dDOol00`00Oomoo`0POol000aoo`H000Moo`04001oogoo0004Ool00`00Oomoo`02
Ool00`00Oomoo`0AOol033B<=:`dS3B/008d[CB/=:dd[3B]Oolhc@Moo`0;I]MV]VJgI[IVefJfA[a6
W4JlAYa6_003A[d3HYL015ndGmAO]4Jm0dJl00E6_DJlA[e6_CIm00=ZeP<I=`08B]a:gDZlB]a6_D[M
A[a6_@AV]`0;;MT]fRWIC]a:g4kMB]a:gD[LC]e:g002A[d015YFFUEJEUYF1CiK0dkL00E>gD[LC]e>
g4kM008Io09RU`08HYIRUf:G>S/f6SXk=QY>o@=>g00:D_e>g4klC_aBoDkLC_e>g4kmC]`3A[d3BI83
00000`01009>g002C]`01TkmC_aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eB
o5;lD_`EOol00`00Oomoo`0OOol001Eoo`@000=oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo011oo`0=>Ydd[C2<=:ddS003=8`d[CB/>:dd[000=:d017oo01m6_D:lA]e6_6KGI[IZefJfCi9;
LTJm@Ya6_D:LA]e2_4JmGYIR]ejFHmAO/f?DGk=:gDZlB]e:_4[M<U`fO@02J]H0BfJfJ]LI=aTg6CHM
=dZlB]e:_4kMA[a:gDJlB]eR]VJgH[H]fRWI;MXY^DkMB]a>gDZlC]e:g4kMB]aNEUYEFUIJEEiFFUE:
gDZlC]e:_4[MC]a>oDkLC_e:g4kmB]a>gEjFH[MNUV:GGYIR]dZlB]e:_4kMB[aBoDkLD_e>g5;mC]aB
oDkLD_e>g5;mC]a>oDkLA]e2_0030000NDVBAYa2NdJL@W]6W4kLD_e>g5;mC]aBoDklD_e>g5;mD_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01moo`005Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo0P004Goo00@d[3B<=:`dS08d[006=:dd[3B]=:dh[Goo0U7d
018nO3YL>U`jG4JmA[a6_FJfI]MV]VJgI[HQNDnBA[a6W4JlAY`3A[d03EjFGmARUf:G<QXb6c8JB]e:
_4[MB]`fOC9m00EZeP@I=`04B]a:gD[LB]d2:Sd03BXlI[MV]fJgI[H]fRgI;MY:g4kLB]a>gD[L00=6
_@05FUEJEUYFFUIJE@02Edd01D[LB[a:_4ZlC]d00dkL00I>gDJlB]e6_D[MHYH3HYL2Dg000dZlB]a:
_002B[`01U;mC]a>o4kLD_e>g09>o004D_e:g4kMC]`300002TVBCI99TTfBBI96W49kAYa2W4km0dkL
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Aoo`03001oogoo01io
o`005Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol047oo038`S3B]
=8`d[C2<=:ddS3B]=:`hcCB]EQAAm5HDDO@nO3YK?W`jFdJm@[a6gFJfI]MV]V[G7GPQVAehB]e6_4[M
A[`Ag0fk4MaNUV:gGYHb6c7j=Q/anT[MB[a:gDZlJ]IV]V[G0V[F04=V]TJmAYa6_4JLA[e:g4kMB[a>
gBHl:UeR]VKGH[IV]bVi;MXYfBgJB]a>oD[LC]e:g4KMA[a6gEYEGUIJEEYFEdeKKTZlB]e:_4kMB[a>
oDkLC_e>g4kmA[a:gDJlHYMNUV:gDg1CT5=_Ei1>g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e>g0030000
PD[LA[e2_4fbBI9=/TVBCK=2NdJL@W]6W49kD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0MOol001Eoo`D000=oo`@000Eoo`03001oogoo
011oo`04=:`dS3B/=8`2=:`013B]=:`d[CB]0U7d00QEm57dDOAAm4JmA[a6_DJl0bYM00aV]VKGI[IV
]b5h8GTMN4ZmB[a:g@fk4M/2HYL02EjFHYMRUc8K<QXb6c8JB]e6_002A[d5J]H02QTgA[a6W4JlAYa:
gD[LB]e:g4[M0VJg00aV]VJgI[MV]dJlB[a6_4ZlB]a>gDkLC]d3A[d01EYFFUEJEUM=Efd00UM=00=>
g4kMC]`00TkL00Y>gDkLC]e>g4kMA[a:gDJmHYMCL09RU`05>S/f6SXkC]a>g@03C]`015;mC]a>o4kl
0`0000I>o4kMB]a>gDkLA[d3BI800dfBBI9=TP02C]`024[LC]a>g5;mC]aBo4klD_d3D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`04goo0P007goo000VOol00`00Oomoo`0?Ool01CjM
=8`d[C2<@Y`00cil06]2_CjL@[eAm5HDDOAF557dHfeOC4JmA[a:_BXl;UeV]V[GI[IVefJf8ITMN26I
7GQ:gDJlB]eNUV:gGYIRUejFGmAO/dZmAYa:_DJlB]e6_4[MA[aZeVJfJ]MZeQTg6CHMEdJLA[a6W4[M
A[a:gDJlB]eR]VJgH[IVedmaDi96W4ZmA[a:_D[LC_e:g4kMA[a6gEYEFUIGCEiFFUDnG3YK?Ua:g4kM
B]a>oD[LC]e:g4kmB]a>gAGK6O`Inf:GGYIR]cHJ>S/f6TkmC]a>gD[LC_e>g5;m00800028C]aBoDkL
D_e>g4Jm@[a6gD:lCK99TTfbBI9=/TVB009:g4kMB[a>gD[LD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`0LOol002Eoo`03001oo`00011oo`03
=8`d[3B<009f/@@nO003@[dnWEGd00=Am00BEOASC6=]A[a6_DJlA[eV]VKGI[IV]fJfI]MV]TJlAYa6
_4JL0dJm00QNUV:GHYMRUencGkAO/dJm0dJl00E:gDJlA[e6_CIm00=ZeP<I=`03B]a:gDZl0096_@03
B]e6_6Jg009V]`0<H[H]fRgI;MY:g4kLB]a>gD[LB]e:g4kM0TJm0UYF00=JEEYF?U/013iK00Q>gDkL
C]a>g4kMB]a>gDkL0QWl0f:G00ERUV:G=QXj>cHJ009>g006C_d00000001BoDkL0Tkl00A>oDkLC_e>
g0A6_@09CI99TTfBBI9=/P01009>g4km00=>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol01goo1@003goo000UOol2000AOol01cB]L[5f
dG:aM]4nO4:L00<nO00Y@[eAm5HDDOAF55m<HfeOC6=]A[a6_D:lA]eV]VKGI[IZefJfCi9;LDJm@Ya6
_D:lA]e2_4JmGYIR]ejFHYLanSHK<OY:gDZlB]e:_3Im<U`fO@02J]H0>6JfJ]LI=aTg6CI>gDZlB]e:
_4[MA[a:gDJlI]MR]VJgH[H]fRWI;MY:_4kMB]a>gD[LC]e:g4kMFUENEUYEFUIJEEiFB[a:gDZlC]e:
_4kmC]a>oD[LC]e:g4kmB]aRUejFH[MNUV:GCfmCT4ZlB]`30000SU;mC]aBoDkLD_e>g5;mC]a>oDkL
D_e>g4km@[a6gDVBCK99TTfc@W]6W49kAYa>g5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007ooOol01goo00D007ooOomoo`0000moo`009Goo
00<007ooOol047oo1WJa00E6_4JmA[a6_CjM009Am007EOAAm57dDO@nO3YK>U`00TJm00a6_4JmI[IV
efJfI[LQN25i7GQ6_4JLA[`3A[d00f:GGYIRU`02HYL02C8J<Q/b6T[MB[a:gD[L=WdbO@05J]H36CL0
14[MB]a:gD[L0bXm00`V?6JgI[MV]bgI;MX]fDkMB]a>g4[LC]d3A[d00eYFFUEJEP02FUH2Edd01TZl
B]a:_4ZlC]a>g@9>g00:A[e:gDJlB]e6_F:GHYIRUe=_Dg0300001T[LB[a:_4kLD_e>g09>o008D_e>
g4klC_a>gD[LC]e>g096_@08CI99TTfbBI96W4:LAYa2N`9>g005C_e>g4kLD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l57oo00<007ooOol01goo00<007ooOol0
47oo000UOol00`00Oomoo`09Ool0?4UaBI8jFcil>U`nWG:aM]5b/GKAL[5fdG:a00=2_4JmA[a6_CjL
EQAAm6=]DOAF5CYK?W`jFcil>U]6_D:lJ]MV]VKGI[IVeaeh8ITMN4[MA[a:g@fk4M`=^f:GGYIRUejF
<Q/anSHKB[a:gDZlB]e:_6[FI[IZe`9ZeP0`I[I6_DJLA[a6W4kMB]a>gDZl:UdV?6JgH[IVef:fI[LY
^BgJ:MU>gD[LC_e:g4kMA[a6gDJlFUIJEEiFFUEGKEM=C]e:_4[MB[a>gDkLC_e>g4kmA[a:gDJlB]eN
UV:G0`0009ICL4m_C_e>g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD:lA[e9TTfbBI9=/T9k
AYa2NdJL@W]BoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`DOol00`00Oomoo`07Ool00`00Oomoo`0?Ool002Eoo`8000Uoo`=9TP04?W`jG3il>Yd7
M[401P0200<00TJmA[a2_@=Am008EOAAm57dA[a6_DJlA[e6_0<ZG@03I[IVefJf008QN0078GU6_4Zm
B[a:g@fk3M/00V:G00UNUV:GHYLb6c8J<Q]6_D[MA[`00TJm16[F00XI=`00A[a6W4JlB]a:gD[LB]e:
g0=V]`0;H[IV]fJgB[a6_4ZlA[a>gD[LC]e>g003A[d2FUH00eYEEdeGC@02Edd2C]`02DkMC]a>g4kL
C]e>g4kMC]a:g@0300001V:GHYHj>cHJ>S/f6P9>g006C]e>g4klC]aBoDkL0Tkl00iBoDkLC_a>g4kM
B]a>gDJmCI99TTfBBI9=/T[L0dkL00E:g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04Woo00<007ooOol027oo00<007ooOol03Woo000U
Ool00`00Oomoo`07Ool044UaBI99LDVBBG4nO3YK?Wab/GKAL[5fdG:aM]5b/D:L0cil02U2_CjLEQAA
m5HEDOAF557dHfe6_4JmA[a:_BXl;UeV]VKGI[IVefJf8ITMN26IA[a:gDJlB]eNUV:GGYIRUejFGmAK
/dZmAYa:_DJlB]e6_4[M009ZeP07<UaZefJf7CLI=TJmAY`00TJl02=:gDJlB]e6_6KGH[IV]f:fCi5?
LDZmAYa:_DJlC]e:g4kmB]a6gDJlGUIJEEM]FUENESYK?U`jFdkmB]a>gD[LC_e:g4kM00<0002M6O`E
faWlGYIRUejF>S/f6SXkB]a>oDkLC]e:g5;mC]aBoDkLD_e>g5;mC]aBoD:lA[e2_4KMBI9=/TVBCK=9
TP02B[a>gD[LC]e:_5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d057oo00<007ooOol027oo00<007ooOol03Goo000UOol01P00OomNMUif<Q/^6`=o
o`I9TP04F^M6_D:lA[d7M[43?W`013jM@[eAm5Gd0e7d015SK5m<HdaOC4JmA[a6_FJfI]MV]VJgI[IV
edJLA[a6W4Jl00A6_@03GYIRUf:G00=O/`09A[a6_DJlA[a6_D[MA[a6_C9m00=ZeP<I=`9:g006B]e6
_4JmA[e:gF:f0fJg00]R]RgJ;MU>gD[LC]a:g4kMB]a:gD[L0096_@=JEP03FUDnFciK008nF`9>g007
C]d00000001>gD[LC]d00QWl00QRUV:GHYMRUf:F>S/f6SXk0dkL00]>oDkLC_a>o5;mC]a>oDkLC_e>
g4km00=6_@05CI99TTfbBI9=/P020083C]`01TkmC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol00goo00D007ooOomoo`0000moo`00
97oo01d007ooGWMJMUjG;Q/b6bhK?YdjWDVBBG59TTUaBI9Jiel8F^M6_D:LA[eb/GKAL[5fdW:aM]4n
O4:L008nO01@?Ya2_E7dEQAAm5HEDO@nO3YK?W`jFdJm@[a6gFJfI]MV]VKGBg5;TT:LA[e2W4Jm@[a6
gD:lHYMNUV:GGYIRUc7j=Q]:_4[MB[a:gC9m=WdbG6[GI[IZeVJfJ]LI=adgB[a>gDZlB]e:_4[MA[a:
gF:fI]MR]VJg:KT]fRWIC]e:_4kMB]a>gD[LC]e:g5YFFUENEUYEFUIJEDkMB[a:g@<0002TC_e>g4km
B]a>gD[LC_eNUV:GGYIR]ejFDg1?CdkMB[a:g4kLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e2_4Jm
BI9=/dVBCK99TTJL@W]6W4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Aoo`03001oogoo00Aoo`<0011oo`0097oo00@005ifGWINM`9N
MP8b6`03>YdnWDVB00A9TPAJi`03A[e2_4Jm00Ef/@0600=6_4JmA[a6_CjM0U7d00MEm57dDOAAm3il
>U/jG002A[d034JlI[MV]T]bI[IV]b5h8GU6W4JlAYa6_0=6_@0=HYMNUV:GHYLb6c8J<Q]:g4[MB[a:
gC9m=Wd01F[F0aTg00E:g4[MB]a:gD[L00<Z?@0;H[IV]fJgI[L]fBgJB]a>gD[LC]a:g003A[d2FUH0
1EYEFUIJEUM=Dd`00P0000]:g4ZlB[a>g4kMC]a>gDJmB]e6_4[M009RU`04HYICKdm_Dfl3B[`01T[L
C]a>o4kLD_e>g09>o006D_e>g4kMC]a>gD[L0TJm00i=/TVBCI99TTfb@W]6W4:LAYa>g5;lC_aBoDkL
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo
0P0000=oo`00Ool05goo000TOol0C000FWINUeifGWMJMS8K;Q/b6cZLBI99LDVBBG59TU[WBI8jFcil
>U`nWG:aM]9b/GKAL[5fdP0200=2_4JmA[a2_E7dEQEAm5HDDOAF5CYK?W`jFcilA[a6_D:l;UeV]VKG
I[HQVAeh8IU6_4[MA[a:g@fk4MaNUV:GGYIRUejF<Q/anSHKB[a:gDZlB]eV]V[FI[IZefJf0P0001a6
_DJLA[a:_4kMB]a>gBHl:UeR]VJgH[IVef:f;MXY^BgJB]a>gD[LC_e:g4KMA[a6gEYEFUIJE@<0002[
Dda>oD[LC]e:g4kmC]a>oDkLB]e6_4[MA[aR]ejFHYMNUSXk=QXj>d[LC_e>g4kMC]aBoDkLD_e>g5;m
C]aBoDkLC_e:g4kM@[a6gDVBCK99TTfcBI9=/TZlC]e:g4kMC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo01Eoo`00
6Woo10001Woo00<005igGWH00Uif00E[eFOE@Ye2W3jM00A9TP07F^M9TTVB?W`jG3il>Yd01WJa0`03
00A6_4JmA[aEm0=Am007EQAAm57dA[a6_DJlA[d00bYM00AV]fJfI]MV]P8QN0068GU6_4ZmB[a:gEjF
0f:G00ANUV:GA[a6_@96_004A[e:gDJlA[d4J]H02aTg0016W4JlAYa6_4[LB]e:g4[MH[H00fJg00]R
]TmaBg5:_4JlB[a>g4kMB]a>gDkL0096_@<00003FUEJESiK008nF`9>g00AC]e>g4kMC]a>gDkLB]e6
_D[MA[aRUf:FHYLf6SXk=QXj>`03C]`01TkMC]a>o4klD_e>g09>o00>D_e>g4kMC]a>gDJmCI99TTfb
BI9=/TfB009:g09>g005D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo004D_eBo5;lD_`COol00`00Oomoo`0EOol001Uoo`03001oogoo009oo`03001o
ogoo00=oo`0M001NMUigFWI[mFOEJoEWeDJm>Ye9TTUaBI99LEl8BG5=TTVA?W`jFcilL[5fdG:aM]9b
/GKAL[52W002?W`0ACjL@[dnWEHDDOAF5E7dEQAOC6=/A[a6_DJl;UdZ?6KGI[IVefJfI]LMN26I7GPQ
VD:lA]e2_6:GGYIRUejFHYMK/eoCA[a:_DJLB[e6_4[MA[aZefJfJ]IV]V[G6CLMEdZlC]e:_4[MA[a:
gDJlB]eR]VKGH[I?LD]`Ci56_4ZmAYa:_D[LC]e:g0030000/eYEGUICC5YFFUDnO3YK?Ua:g4kmB]a>
gD[LC_e:g4kMB]`Io1GK6OaNUV:gGYIRUcHJ>S/f6SXkC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a6
gD:lA[e9TTfcBI9=/TVBCK<00TkMB[a>gD[LD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007ooOol057oo000IOol00`00
Oomoo`02Ool00`00Oomoo`03Ool01@00GWINMUigImD00Woo00<b6bhK?Yd014VB00QJidVBBI99TU[W
A[e2_4Jm1WJa00Qb/Cil?W`nO3jM@[eAm5HD0e7d0em<00Q6_4JmA[aV]fJfI]MV]VJg0T]a00A6W4Jl
AYa6_0=6_@03HYMNUV:G009O/`04Fk=6_4JlA[d2A[`014JmB]e6_39m0f[F0QTg00HM=dZlB]a:g4[M
A[`2A[d00fJgH[I?L@02I[L01BgI;MY:g4kMB]`00`0000E:g4[M07A6_EYE00=JEP04FUDnFciK?U/3
C]`034kMC]a>gDkLC]dEo1WlHYIRUf:FHYMRUPE:_0=>g00:D_e>g4klC_aBoDkLC_e>g4kmC]`3A[d0
14VBCK9=TTfb0`0200I>oDkLC]a>g5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol04goo000IOol00`00Oomoo`02
Ool00`00Oomoo`02Ool01000OomooejG17oo01P^6c8K>Ya9TTUaBI9JidfBBI59TU[VF`M2W4Jm@Ya6
_G:aM]5b/GKBL[5fd@02@Y`2?W`0?CjLEQEAm5HDDOAF5E7d?W`jFcilA[a6_D:lI]MV]VKGI[IVeaeh
Bg52W4Jm@Ya6_D:lA]eNUV:GGYIRUejF<Q/anT[MB[a:gDZlB]dbOCImI[IZefJfJ]IV]QeG6CM:gDZl
C]e:_4[MA[a:gDJl:UeR]VKGH[H]fRVi00<0002jB[a>gD[LC]e:g4kMFUEJEUYEGUIJEEYFB[a>gDZl
B]e>g4kmC]a>oDkLC_e:g4kMGYIR]ejFHYMNUU=_Cdm:g4ZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkL
D_e>g4kmC]a6gD:lCK99TTfcBI96W49kAYa2Ne;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m4goo00<007ooOol04goo000I
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00c8K?Ye9TP02BI8015[WBI99TTVB
0e[W00A2_DJm@[a6_@9f/@03L[5f/GJa00800`03A[e6_4:m00=Am007EQAAm57d>U`nO3YK>U`00TJm
00a6_6JgI[IV]fJfI[LQN25iA[a:_DZlB]d2A[d2HYL02UjFHYLb6S8K<QY:gD[LB]e:_4[M1V[F0aTg
00M:gD[LB]e:g4[M9S`Z?@02I[L02V:f00000000;MT]fT[LC]e:g4kL0dJm0eYF00AJEEYFDdaGC@=:
_00?B]a>g4kMC]a>gDkLB]e6_D[MHYIRUf:FHYM?Cdm_00E:_006D_e>g4klC]aBoDkL0Tkl00EBoD[L
C]e>g4kM0096_@0>BI9=/TVBCK92W4JL@W]6W4:LD_e>g5;lC_aBo@=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0COol00`00Oomoo`0BOol0
01Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Ioo`0EA[djWDVBBG59TTVABI99LDfB
BI8nO3YK?W`jWCjML[5fdW:aM]5b/GKB00800`0^@[a6_DJl@[eAm5HEDOAF557dEQDjFcil>U/nO4Jl
A[e2_2iMI[IVefJf8ITMN26IA[a:gDJl4M`=^f:GGYIRUejFHYLanS8K<OXf6dJlB]e6_4[MI[IZeVJf
J]L200002DJLA[e6W4kMB[a>gD[LC]eR]P030000`F:fI]M6_4ZmAYa:_D[LC]e:g4kmA[a6gDJlGUIJ
EEYFFUEGCE</Ede:g4kmB]a>gDkLC_e>g4kmA[a:gDJlB]eNUV:gGYIRUcHJ>S]>g4kMB]a>oDkLD_e>
g5;mC]aBoDkLD_e>g5;mB]a>oD[LA[e2_4fcBI9=/TVBCK=:g4kMB[a>gD[LD_e>g5;mC]aBoDkLD_eB
o5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ao
o`03001oogoo015oo`006Goo00<007ooOol00Woo00<007ooOol00Woo0P0027oo00<nWDVBBI801dVB
00HnO3YL?W`jO7JaL[43M[4027:a00<00`03A[a6_CjMEQ@3DO@01eHDDOAOC4JlA[e6_4Jm008ZG@05
I[IV]fJfI[MV]P028GP01R5iA[a:_DZlHYMNUP=RU`04GYI6_4JlA[d2A[`00dJmB]e6_004J]H021Tg
0016_4JLA[a6W4[MA[`3000016:fI[MV]fJg0T]`00Q6_4ZlA[a>gDkLC]e:g4kM0TJm00EJEEYFFUIJ
EUYE00<nF`=>g00AC]e>g4kMC]a>gDJlB]e6_F:GHYIRUf:F>S/f6SXkC]a>g@03C]`01U;mC]a>o4kl
D_e>g09>o00;D_e:g4kMC]a6_DVBCK9=TTfbBI800P02C]`01D[LC]a>g5;mC_`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0
4Woo00<007ooOol04Goo000JOol40005Ool00`00Oomoo`08Ool05DVBBG5O24UaCI99TDVBBG5=TTVB
A[e2W4Jm@YafdG:aM]9b/GKAL[52W002?W`0<SjL@[eAm5HDDOAF5E7dGdaOBf=<A[a6_DJlB[eV]VKG
I[IVefJfI]M2W4Jm@Ya6_D:lA]e2_6:GGYIRUejFGk=K/TZmA[a:_DJLB]e6_4[MA[aZefJfJ]IV]QeG
6CM:gDZlC]d20000b4JlB]e6_6JgH[IVed]`Cg5;D4ZmA[a:_DJLC]e:g4kMB]a>gDJlFUIJEEM=FUEJ
ESYK?W`jFciLC]a>oDkLC_e>g4kmB]a>gAGK6OaNUV:GGYIR]ejF>S/f6SXkC]aBoDkLD_e>g5;mC]aB
oDkLD_e>g5;mC]a>oD:lA]e2_4fbBI9=/dVBCK<00P03C]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oDklD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dBOol3000B
Ool000Eoo`800003Ool0000001Uoo`03001oogoo00Qoo`Y9TP04F^M6_D:lA[d2M[4017:aM[5f/GJa
13il00@nWE7dDOAF509Am0AOC096_@0;A[a6_FJfI[MV]VJgAg5;LDJLA[a6W004A[d01F:GGYIRUe^c
Gk<00U^c00=6_4JmA[`00TJm00=:gC9mJ]H00V[F0QTg0`000T[L00I:gDJlA[e6_FJgBg02I[L03RgJ
;MU>g4[LC]e:g4[MB]a>gD[L07A6_EYFFUD3FUH3B[`03d[LC]a>g4kLC]e:g4kMC]a>gF:FHYMRUV:G
HYIRU`04B[`00dkLC_e>g002C]`025;mC]a>o4klD_e>g4kmC]`3A[d02TVBCK99TTfb@Ya6W49kAYa>
g4km0TkL00=Bo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04Goo00<007ooOol047oo0004Ool00`00Oomoo`02000J
Ool00`00Oomoo`08Ool01dVBBG5=TTVABI99LDfB0099TP0jE/IJieKVA[e2W4JmL[5fdG:aM]9b/@03
@[a6_DJlA[dnW5HEDOAF55m;EQDjFcil>U/nO4JlA[e2_6KGI[IVefJfI]M7D4Jm@Ya6_D:LA[e2_4KM
GYIRUejFHYLanSHK<OXf6dZlB]e:_3Im<UeZeVJfJ]L30000caeG6CM>gDZlC]e:g4kM9S`ZGBHlI[MR
]VJg;MT]fRViC]e:g4kMB[a>gD[LC]e:g5iFFUEJEUXeGUIC;5=<B[a>gDZlC_e>g4kmC]a>oDJlB]e6
_4[MGYIR]ejFHYM;CTm_B[a:g4ZlC]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4Jm@[a=/dVBCK99
TTfc@W]6W49kD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol00`00Oomoo`0?Ool000Aoo`05001oogoo
Ool0000IOol30009Ool00dVBF^M9TP07BI801CYL?W`jO3jML[400gJa00Qb/GJa00<00dJlA[e6_4:m
0e7d00MF557dDO@jG3il>U/jG002A[d01DJlI[MV]VJgI[H00R5h00E:gDJlB[e:_0gK00<=^`0;HYMN
US8K<QXb6c8JB]e:g4[MB[aZeP030002J]H02TJlAYa6_4JLB]e:g4[MB]`Z?BHl0fJg00UR]VJg;MT]
fRgIC]e>g4kMB]`00dJm00QJEEYFFUIJEUYEDdaC;4[L0dZl015>gDkLC]e>g4kMA[a:gDJmHYMRUV:G
Cdm?Kdm>Cdm>g4kM00=>g006D_e>g4klC]aBoDkL0Tkl00=BoD[LC]d00TJm00e9TTfbCI9=/TVBAYa2
W4JL@W]Bo4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d04goo00<007ooOol03Woo0004Ool01@00Oomoogoo
00006Goo00<007ooOol02Goo00E9TSZMBI99LDfB0099TP0>BG5=TTVB?W`jFcil>YefdG:aM]9b/GKA
L[4010<00`0UA[e6_5HDDOASC57dEQAAm5HEA[a6_DJlB[dZ?2YM:SaVefJfI]MV]R6I8GQ:gDJlB]e6
_0gL3K]RUejFHYMNUSHK<OXf6c7jB]d00`000=IZefJfJ]IV]QeG0016_4JLA[e6W4kMB[a>gD[LI[MR
]VJgH[IV]f:fB[e6_4ZmAYa>oD[LC]e:g4KMA[a6gEXeGUIJEE=<DbaGC5</C]e:g4kmB]a>oDkLC_e>
g4kmA[a:gDJlHYMNUV:g=QXj>cHJ>S]>g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a6gD:lCK99
TTfcBI9=/dVBC]e:g4kMB[aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1=oo`03001oogoo00ioo`0017oo00D0
07ooOomoo`0001Uoo`03001oogoo00Uoo`03BI9oodVB00Q9TP03?W`jG3il009f/@04L[5f/GJaM[45
?W`00d:m?YeF5003DO@01UHDGd]OBdJlA[e6_08ZG@05I[MV]VJgI[IV]`038GP01T[MA[a:_DZlHYMN
UP9RU`03Fk=K/TJl00<00096_@04B]eZeV[F<Wd2J]H021dg6CM6_4JLA[a6W4[MA[`2A[d03VJgH[IV
]fJgBg1;D4ZlA[a:_4JlC]e>g4kMB]`2A[d015YFFUEJEUYF13iK019>gDkLC]a>g4kMB]a>gDkLC]dE
g1Wl5OaRUf:FHYLj6SXk=QX2C]`01TkMC]a>o4klD_e>g09>o004D_e>g4klC_`3A[d00dfBCK99TP03
CK801@02C]a>g4kLB]`00U;l00EBoDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo00eoo`000goo
0P000Woo0P006Goo00<007ooOol02goo01E=TTVABI99LDfBBI9=TTVACI9FaTJm@Ya6_G:aM]5b/GKB
L[5fdSil@Y`00Sil01hnW4:mGd]F557dEQEAm5m<Fb]OC4JlA[e6_6KGI[IVefJfI]M7D4Ma@Ya6_D:L
A[e2_4KM@[aRUejFHYL30000gTZmA[a:_DJLB]e6_4[M<UaZefJfJ]HI=aeG6CM:gDZlC]e:_4[MA[a:
gF:fI[MR]VJgH[H]fRWIC]e:g4kMB[a>gD[LC]e:g4KMA[aJEUXeGUHjFciL>U/nO3YKC_e>g4kmC]a>
gD[LC_e:g1Wl5M]R]ejFHYMNUV:g=QXj>cHJD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4Jm@[a6
gDVBCK=9TTfcBI800`02D_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1=oo`03001oogoo00aoo`00
8Woo0P0037oo24VB00IFaUKVE^I6_D:lA[d2M[401G:aM[5f/GJa00<00cil00@nWE7dDOAF50=Am003
?W`jFcYL0096_@0<A[aV]fJfI[MV]R5hAe16_4JLA[a6W4Jl0TJm0`000V:G00Hb6c8JB]e:g4[MB[`2
<Wd5J]H01ATg7CM:g4[MB[`00T[L00=:gDJlA[d00VJg00eR]VJg;MT]fRgIC]a:g4kMB]a:gD[LC]e:
g003FUH015YEFUI:_4[L0dZl00m>gDkLC]a>g4kMB]a>gDkLHYMRUV:GHYIRUd]>Cdh00dZl0TkL00a>
oDkLC]a>o5;mC]a>o4kLC_e>g4kmC]`2A[d3CK801DVBAYa2W4JL@W/00TkL00E>oDkLD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo5;l01=oo`03001oogoo00aoo`008Woo00<007ooOol02goo00=9TTUaCI800TVB02Y9TDfB
BI9JieK6F^MFaTJm@Ya6_G:aM]9b/GKBL[401003A[e6_4:mDOAF5E7dEQAAm5HE>U/nO3YKA]e6_4Jm
I[IVebXlI]MV]R6I8GQ:gDJlB]d30000iDKMGYIRUejFHYLanSHK<OY:gDZlB]dbG3ImI[IZeVJfJ]MV
]QeG6CLMEd[LC]e:_4kMB]`ZGBHlI[MR]VJgH[IV]bgI;MXYfDkMB]a>gD:lA]e6_4KMFSENEUYEFUIJ
=E=<B[a:gDZlC]e:_4kmC]a>oDkLB]e6_4[MA[aRUejFH[M;CTm?Bdi>gDZlB]a:_5;mC]aBoDkLD_e>
g5;mC]aBoD[LC]e:g4km@[a6_DVBCK=9TTfc@W]6W49kAYa2Ne;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m01=oo`03001oogoo00]oo`008Goo00<007ooOol037oo00=9TSjMBI801DVB00MFiWoo>U`nO3Yl
?Yeb/@03M[4027:aM[400`04A[a6_DJl@[d3DO@01UHDDOAAm3YL?W`jF`=6_@04:UeV]fJfI[L38GP2
000014ZmB[`=f`fk0f:G00QNUV:G<QXb6c8JB]e:g4[M1F[F00`M=`00A[a6W4JlB]a:gD[LB]e:g6Jg
H[H3I[L026:fB[a6_4ZlA[a>gDkLC]d4A[d00eYEFUIJEP04Db`04TkMC]a>g4kLC]e>g4kMC]a:gDJl
B]eRUV:GHYIRUcXJ>S/f6P9>g006C]e>g4klC]aBoDkL0Tkl00IBoDkLC_a>g4kMB]`2A[d00dfbBI9=
/P02CK85C]`015;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0BOol2000<Ool0025oo`03001oo`00
00aoo`08CI8jWDVBBG5=TTVBCI99T@9oo`0P?W`jFcil>UafdW:aM]9b/GKBL[40100300A2_4Jm?YeF
557dEQEAm5HDDOAOC4JlA[e6_2iM:S`ZGFJfI]MV]P<0003[8GQ:gDJlB]e6_6:GGYIRUejFHYMNUTZm
A[a:_DJLB]e6_4[MI[IZefJfJ]IV]QeGAYa6_4JLA[e6W4[MA[a:gDJlI[MR]VJgH[I;L4M?B[e6_4Zl
B]a>oD[LC]e:g4KMA[aJEUXeGUIJECiL>U/nO3iKC]e:g4kmC]a>oDkLC_e>g4[MA[a:gEjFHYMNUSXk
=QXj>cHJC_e>g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a6gDVBCK=9TTfcBI800dZlC]e:g4kM
B[aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007ooOol02Woo000QOol2000=Ool00dVBOom9
TP04BI802U[WOomoogooA[e2_4Jm@[ef/G:a0gJa00Qb/Cil?W`nO3jM@[eAm5HD0e7d00QOBe/[A[e6
_4JmA[a6_FJf0`0000=V]R6I8GP00R5h14Jm00ARUejFHYMRU`9K/P96_004A[e6_4JmA[d5J]H01ATg
7CM:g4[MB[`00T[L00=:gDJlA[d00VJg00iR]VJgI[M;D4JlB[a6_4ZlB]a:gD[LC]e:g4Jm0UYF00=J
EEYF?U/013iK019>gDkLC]a>g4kMB]a>gDkL6O`Eg6:GHYIRUf:F>S/j6SXk=QX2C]`02dkmC]a>o4kl
D_e>g4klC]a>oDkLC_d00dJm0dfb00A=TTfb00<00`=>g005C_e>o5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003
D_eBo7oo015oo`8000]oo`003goo100017oo10001Woo00<007ooOol03Woo00I=TTVBCI99TDfBE/H4
Ool02dJm@Ya6_G:aM]9b/GKBL[5fdSil@Y`00Sil00/nW5HEDOAF557dEQEK:em;Fb]6gDJl00<0003c
I[IVefJfAe13CdJm@Ya6_D:LA[e2_4KMGYIRUejFFk=KTU^cEi9:_DJlB[e6_4[MA[aZeVJfJ]MV]QeG
6CLMEdZlB]e:_4kMB[a:gDJlB]eR]VJgH[IV]bgI;MY:_4kMB]a>gD[LC]e:g4kM05=6gEYEFUIJ=EiF
B[a:gDZlC]e:_4kmC]a>oD[LC]e:g4kmB]aRUejFHYMNUV:GB[a>gDZlB]a:_5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4KM@[a6_DVBCK=9TTfc@W]6W49kAYa>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l00ioo`<00003Ool007oo00Yoo`003Woo00<007ooOol00Woo00@007ooOol000Aoo`03001o
ogoo00=oo`03001oogoo00ioo`E9TPIoo`0>A[e2_4Jm>Yef/G:aM[5b/@04A[a6_DJlA[dnW@9Am004
EQAK:eGd>U`30002A[d02dJlI[MV]VJgI[IV]b5h8IU6W4JlAY`00dJm00YRUe^bGYIRUc8J<Q/b6T[M
B]a:g@8bO@EZeP0;7ELI=adgB]a:gD[LB]e:g2Xm9S`V?@02I[L03F:fI[L]fBgJB]a>g4[LC]e:g4[M
B]a>gEYE00=JEP04FUEC;4ZlB]`2B[`034kLC]e>g4kLA[e:gDJlB]e6_F:GHYIRU`9;CPE:_004C_a>
g5;mC]`2C_`01U;mC]a>o4kLC_e>g096_@09CK99TTfbCK9=/d9kAYa2W4km00=>g005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00Yoo`@000Aoo`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03
001oogoo00=oo`8000moo`05BI99TDfBBI9=TP07Ool043jM>WafdW:aM]9b/GKB00<014:lA[e6_4:m
DOAF5E7d0`000?XjFcil>U/nO4JlA[e2_6KGI[IVefJf8ITQN26IA[a:gDJl3M/9^f:GGYIRUejF=Q/a
nSHKB[a:gDZlB]eV]V[GI[IZeVJfJ]M6W4JlAYa6_D[LC]e:_4kM9S`ZGF:fI[MR]VJgH[H]fRgI;MY:
g4kmB]a>gD:lA]e6_5YFFSENEUYEDba?:e</B[a:gDZlC]e>g4kmC]a>oDJlB]e6_4[MGYIRUejFCdi;
CTm>B]a>oDkLC]e:g5;mC]aBoDkLD_e>g5;mC]aBoD[LC]e2_4KMBI9=/dVBCK=9TTJL@W]6W49kD_e>
g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@Ioo`<000Qoo`03001oogoo00Uoo`004goo00@0
07ooOol000Aoo`03001oogoo009oo`80011oo`05BI9oodVBBI9FiP08Ool01SjML[5f/G:aM[5b/@<0
100300=6_DJl00<00008DOAF557dEOA6_4JmA[a6_@8ZG@05:SeV]fJfI[MV]P028GP03T[MA[a:_DZl
HYMNUV:GGYIRUejF<Q/b6S8KA[`2A[d00d[MJ]IZeP02J]H02QTg0016W4JlAYa6_4JLB]e:g4[M0VJg
00=R]VJgI[L00TM?00M:_4JlB[a:g4kMC]a>g@03A[d015YFFUEJEUYF0ciK00=>g4kMC]`00TkL00e>
gDkLC]e6_D[MA[a:gF:FHYMNUSXk>QXj>`03C]`01TkMC]a>o4klD_e>g09>o004D_e>g4kMC]`2A[d3
CK800dfBCK800`04C]`01E;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0=oo`<000aoo`03001o
ogoo00Qoo`003goo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol03goo00E=TWoo
CI99TE[W00Uoo`04M]9b/GKBL[42Ool00d:L?W`000020000ocjMEQAAm5HEDOAF55/ZGd]6_4JmA[`^
GBXlI]MV]VKGI[IVeb5h8ITQN4Jm@[a6gEjFHYMNUV:GGYIK/UNAB[e6_4ZmA[a:gDJlB]eV]V[GI[IZ
eQTg7EM:_4[MB[a>gDZlB]e6_4[MH[IV]f:fBe17CdM@AYa:_DJlB[a:g4kMB]a>gD:lA]eJEEYFFSEN
ESiK?U`jFdkmB]a>gD[LC_e:g4kMB]a>oAGK6O`Eff:GGYIRUcHJ>S/f6SXkC]aBoDkLD_e>g5;mC]aB
oDkLD_e>g5;mC]a6gD:lA[e9TTfcBI9=/dVB00A:g4kMB[a>gD[LD_e>g5;mC]aBoDkLD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo001D_d1D_`2000?Ool00`00Oomoo`08Ool000moo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo015oo`99TP]oo`04M[5b/GJaOol30002?W`023jM@[eKBeHDDOAE
m57dFd/2Fb/03DJlA[e6_6JgI[IV]fJfI[M3Cd=@AYa6_4JL00=6_@06GYIRUejFFk9GTU^b0dJl00I6
_DJlA[e6_D[MI[H2J]H02QeG6CLM=d[LB]e:_4[LA[e:gDJl0fJg00iR]RgJ;MT]fT[LC]a:g4kMB]a:
gD[L07@0DdJm0UYF00=JEEYF?U/00SiK0TkL00I>gDkLC]a>g4kMB]`25O`01F:GGYIRUf:FHYL014Zl
0dkL00Y>oDkLC_a>o5;mC]a>oDkLC_e>g0=6_@04BI9=/TfbCK<200<00dkLC_e>g002C]`01E;mC_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo11oo`03001oogoo00Qoo`003goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol04Goo00==TTVBOol02Woo00Ab/GKB0000009oo`3o
00=2W3il?W`nW5HEDOAF557dEQEAm3il>U/nO4JlA[e2_6KGI[IVefJf8IU3;dJm@Ya6_D:LA[e2_6:G
GYIRUeifHYLanSHKB[a:gDZlB]dbG3Im<UeZeVJfJ]MV]QeG6CLMEdZlB]e:_4kMA[a:gDJl:UeR]VJg
:MT]fRgI;MY:_4kMB]a>gD[LC]e:g5YFFSENEUYEFUI?2e</B[a:gDZlC_e>g4kmC]a>oD[LC]e:g6:G
GYIRUejFHYM;;D]>B[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4KM@[a=/dVBCK=9TTJL
@W]6W4kLD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0008D_eBo5;mD_aBoE;lD_eBo0moo`03001oogoo
00Qoo`003goo1@000goo10001Goo0P004Woo00=9TUKVOol02Goo0`0017oo0P0400e6_DJl@[eAm5Gd
DOAF557dEO@jG3il>U/nG002A[d01FJfI[MV]VJgI[H00R5h00A:gDJlB[e:_096_@0<HYMNUV:GGYHb
6c8J<Q]:_4[MB]a:gDZl0f[F00eV]V[FAYa6_4JLA[a:g4[MB]a:gBHm:SeR]P03I[L022gI;MX]fBgJ
B]a>gDkLC]d2A[d2FUH00eYEFUIJEP02Cb/2B[`03T[LB[a>gDkLC]e>g4kMA[e:gDJlHYMRUV:GBbd3
Bdh3B[`01U;mC]a>o4kLD_e>g09>o005D_e:g4kMC]a>g@02A[d4CK82AY`0249kAYa>o5;mC]aBo4kl
D_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`03goo00<007ooOol027oo000POol00`00Oomoo`0A
Ool00dfBOomoo`06Ool30007Ool0C00300A2_4JmA[a2_E7dEQEAm5HDDOAF5DJlA[e6_4Zm:S`ZGBXl
I]MV]VKG8GPQVB5hB]e6_4[M2K/=feifHYMNUV:GGWHf6c7j=Q]6_4[MA[a:gDJlJ]MV]V[F6CL004JL
A[a6W4JmB]a>gDZlC]eR]VJgH[IV]f:fB[a6W4ZmA[a:_4[LC_e:g4KM@[a6gEYEFUIJ=E</0Tl[0;Y?
2dkmB]a>gD[LC_e>g4kmC]a>oDJlB]eNUV:GGYIRUcHJ>S/f6SXkB]a>oDkLD_e>g5;mC]aBoDkLD_e>
g5;mB]a>oD[LA[e2_4fcBI9=/dVBCK=:g4kMB[a>gDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d>Ool00`00Oomoo`08Ool0021oo`03001oogoo015oo`03BI9oogoo00=oo`<000Yo
o`<0100=?Ye2_CjMEQAAm5GdDOAF557dFb]6_4JmA[`00RYM00EV]fJfI[MV]VJg00<QN00:B]e6_4Zm
GYIRUejFHYMNUUNbEi42A[`01TJmA[a6_DJmB]eV]P=ZeP8M=`08AYa6_4JLA[a6_D[MA[a6_@9V]`0;
H[I7CdM?B[a6_4ZlA[a:_4[LC]e>g002A[d3FUH00eYEFUHnF`02?U/2C]`04DkMC]a>g4kLC]e:g4kM
A[e:gEjFHYMRUSXk=QXj>cXJC]d00dkL00IBoDkLC_a>o5;mC]`2C_`00e;mA[e6_@02A[d01TfBCK9=
/TfcCK800`A>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00=
Ool00`00Oomoo`08Ool001moo`03001oogoo019oo`03CI9oogoo00<000ioo`3o@Y`nO3il?Ya2_E7d
EQAAm5HEDOAKBe/ZFd]6_4JmA[aVefJfI]MV]VKGI[I6_D:LA[e2W4Jm@[a6gEjFHYMNMU^bEi5K/TJL
B[e6_4ZmA[a:gDJlB]dbG6[GI[HMEaTg7EM:_4[MB[a>gDJlB]e6_6JgH[IV]f:f;MX]fBgJB[a>gD[L
C]e:g4kMB]a6gEXeGUI?:eYFFSDnO3iK?U`jFdkmC]a>oDkLC_e:g4kMB]`Io1GKHYMNUV:GGYHj>cHJ
>S/f6U;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4km@[a6gD:lCK=9TTfcBI9=/`0300A>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m000:D_aBoE;lD_eBo5;mD_aBoE;lD_d=Ool00`00Oomoo`07Ool001mo
o`8001=oo`<0019oo`<nO00:?YeEm57dEQAAm5GdDO@nO3YK?U`2A[d02dJlI[MV]VJgI[HQV4<_A[a6
W4JlAY`00TJm00]RUejFHYMNUV:G<QXf6dZlB]e:g4[M00<bO@06J]IV]V[FJ]HMEadg0T[L01I:gDZl
B]a6_D[MA[aV]f:gI[L]fBgJ;MT]fT[LC]a:g4kMB]a:gD[LA[eJE@=JEP05FUE:_4ZlB]a:_002C]`0
34kMC]a>g4kLC]e:g6:GHYIRUejFBbe7;@A:_006C_e>g4kLC]aBoDkL0Tkl00EBoDkLC_e>g4km0096
_@04CK9=/dfbCK82AY`0149kAYa>g4km0TkL00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eBo7oo00aoo`03001oogoo00Moo`007goo00<007ooOol03goo0`005Woo0?m6_DJl
A[dnW5HEDOAF557dEQDjFcil>U]6gDJlA[eV]VKG:SaVef:f9ITQN4[MA[a:gDJlA[e2_6:G2K]RUeif
=Q/anSHKB[a:gDZlB]dbG3ImI[IZeVJfJ]LI=aeG6CM>gD[LC]e:_4kM9S`Z?F:fI[MR]VJg;MT]fRgI
;MY:_4kMB]a6gD:lA]eJEEYFFSENEUYECb];2TkMB[a:gDZlC_e>g4kmC]a>oDJlB]e6_6:GGYIRUdL]
Bdi:_4[LB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LA[e2_4fcBI9=/dVBAYa2NdJL@W]6W4kL
D_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d000UBo5;mD_aBoE;lD_eBo5;mD_`037oo00<007ooOol0
1goo000OOol00`00Oomoo`0<Ool3000IOol03DJlA[e6_4:mDOAEm57dEQAAm5HD>U`nO3YK00=6_@0I
:SeV]fJfI[LQN26H8GQ:gDJlB[e:_0fk2K]RUejFHYMNUS8K<QXf6dZlB]e:g4[MI[H00f[F01LM=`00
AYa6_4JLB]e:g4[MB]a:gF:gI[MR]VJgH[M:_4JlB[a6_4ZlB]a>gDkL00=6_@9JEP05FUEJETl[Cb]?
2`02C]`04DkMC]a>gDkLC]e>g4[MA[e:gEjFHYMRUV:G=QXj>dkLC]d00dkL00IBoDkLC_a>g5;mC]`2
C_`00e;mB]a>g@02A[d3CK800dfcCK9>g004C]`00dklD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eBo7oo00Yoo`03001oogoo00Moo`007goo00<007ooOol02Goo0`007Goo
0?m2_4JmA[aF557dEQEAm5HDDOAK:dJlA[e6_2YM:S`ZGF:fI]MV]VKG8GPUVB5hB]e6_4[MA[aRUeif
HYMNUUNBEi5:_DJlB[e6_4[MA[a:gFJfJ]MV]V[F6CM6_DJLA[a6W4JmA[a:gDJlB]eR]VJgH[I7Cd<^
B[a6W4ZmA[a>gD[LC_e:g4KM@[aNEUYEFUIJ=EiF?U/nG3YKC_e:g4kMB]a>oDkLC_e>g4[MA[a:gEjF
HYMNUSXk=QXj>dkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4km@[a=/dVBCK=9TTfc00=>gD[L
C]e:_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`000YBoE;lD_eBo5;mD_aBoE;lD_eBo0Yoo`03
001oogoo00Moo`007goo0P0027oo0P008Goo00LnWD:m?YeF557dEQAAm003FbX03DJlA[e6_4JmI[IV
]fJfI[MV]TJlAYa6_4JL00A6_@05HYMNUV:GEi5GTP03A[`01TJmA[a6_DJmJ]IV]P9ZeP0N7ELM=d[L
B]a:gDZlB]a6_D[MA[aV]f:gI[MR]RgJ;MU:_4JlB[a6_4kMB]a:gD[LA[eJEEYFCb]JEUYE13iK0TkL
015>gDkLC]e>g4kMB]`Eo1GLHYMNUV:GHYHj>cHJ>S]>g4km00=>g008D_e>g4klC_a>oDkLC_e>g0=6
_@03CK9=/dfb009=/P0500@00dkLC]a>o@02C]`00e;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo003D_eoogoo00Qoo`03001oogoo00Moo`007Woo00<007ooOol01Goo0`009Goo
0?m2_E7dEQAAm5HEDO@nO3YK?Wa6_4Jm@[a6gFJfI]MR]VKG8GQ6_D:LA[e2W4Jm@[a6gEjFHYMNMV:G
<QXf6dZlB]e:_4[MB[`fOC9MJ]IV]V[GI[HMEaTgC]e:_4[MB[a>gDJlB]e6_6JgH[IV]bgI;MX]fDkM
B[a>gD[LC]e:g4kMB]a6gEXeGUIJEEYFFSE>gDZlB]e:_4kmC]a>oDkLC_e:g4kMB]aRUejFHYMNUT/]
Abe:g4ZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4Jm@[a6gDVBCK=9TTfc@W]6W49kD_e>g5;m
C]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d000QBo5;mD_aBoE;lD_eBo5;m2Woo00<007oo
Ool01Woo000NOol00`00Oomoo`02Ool3000XOol02SjMEQAAm5HDDOAF557d?W`jFciL0TJm00]6_6Jg
I[IV]fJf8IPQN4JlAYa6_4JL00=6_@0:GYIRUejF<Q/b6SHKB[a:gD[LB]d2<Wd2J]H02VJfJ]HM=aeG
7CM:gD[LB]e:g4[M0RHm00]R]VJgH[MV]bgI;MX]fBgJB]a>g4[L00=6_@9JEP05FUEJEUYFCb];2P02
B[`03D[LB[a>gDkLC]e>g4[MA[e:gDJlHYMRUV:G0097;@A:_007C]aBoDkLC_a>g5;mC]`00Tkl00=>
gD[LC]d00dJm0Tfb00==/dfbAY`00TJL00E2Ne;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo004D_eBo5;lD_`:Ool00`00Oomoo`06Ool001ioo`03001oo`00008002aoo`3o
?YaF5E7dEQEAm5HEDO@nO3YK?Wa6_4Jm@[`ZGFJfI[MR]RFI8GQ:gDJlB]e6_0fk2K]RUejFHYMNMSHK
<QXf6c7jB]e:_4[MI[IZefJfJ]HI=`00AYa6_4JLC]e:g4kMB[a>gF:fI[MRUVJgH[I:_4JLB[e6_4Zl
B]a>oD[LA]e2_4KMFUEJEUXeGUI;2Tl[B`Y>oD[LC]e:g4kmC]a>oDJlB]e6_4[MGYIRUejFHYLf6SXk
C]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC_e2_4fcBI9=/dVbCK=9TTkMB]a>gDZlD_e>g5;m
C]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0008D_eBo5;mD_aBoE;lD_eBo0Uoo`03001oogoo
00Ioo`007Woo0`00;Woo00]2_E7dEQAAm5HDDOAF55LZA[e6_4Jm008ZG@0@I[IV]fJfI[LQN26H8GPQ
VDJlB[e:_6:GGYIRUejFHYL3A[`01TJmA[a6_DJmB]eV]P=ZeP0=7CM6_4JLA[a6W4JlA[e:gDJlA[eR
]fJgH[H00T<^00Q:_4JlB[a6_4kMB]a>gDkL0TJm0eYF00=JECiK?U/00SiK0TkL015>gDkLC]e>g4kM
A[a:gDJmB]eNUV:GHYHj>cXJ>S]>g4kM009>g003C_aBoDkL009>o009D_e>g4kmC_a>gD[LA[e=/Tfc
00==/P03CK<014kL00=>g09Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo0Qoo`03001oogoo00Ioo`0017oo1@000goo100017oo10001goo00<007ooOol0;Goo0?ln
WEHDDOAF5E7dEQEG2U/ZE`Y6_DJlB[eV]VJgH[IVefJfA[e2W4Jm@Ya6_D:lA]e2_6:GGWIRUe>AEi56
W4ZmA[a:_DJLB]e6_6[FI[IZefJf7ELI=dkMB[a:gDZlC]e6_4[MA[aV]f:fI[MRUS7J;MU:_4JLB[e6
_4kMB]a>gD[LA]eJ=EiFFUEJESYK?W`nFciL>U]>oDkLC_e>g4kmB]a>gAGK5OaNUV:GGYIRUejF>S/f
6SXkC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mC]a6_D:lCK=9TTfcBI9=/dfb00@00e;mC]aBoDkLD_e>
g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`000YBoE;lD_eBo5;mD_aBoE;lD_eBo0Moo`03001o
ogoo00Ioo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eo
o`8002moo`0DEQAAm5HDDOAoocYK?U`jG4JmA[a6_FJfI[MV]VJg8GQ6_4JLA[a6W0=6_@0;GYIRUejF
HYLb6SHKB[a:gD[LB]e:_002<Wd01V[FI[IZeV[F7ELM=`9:g00FB]e:_4[LA[e:gDJlI[MR]fJg;MT]
fRgIC]e:g4kLB]a>gD[LB]e:g4JmFUD3FUH3B[`03T[LB[a>g4kLC]e>g4kMC]a>gEjFHYMRUV:GGYH2
0003B[`01dkLC_e>g4kLC_aBoDkL009>o004C_e>g4kmC]`2A[d2CK800dfcCK96W002AY`01D9kC]a>
g4kmC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l1goo
00<007ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo
Ool01goo00<007ooOol0;7oo00=Am5HEDO@00Woo050nO3YK?Wa6_4Jm@[aVefJfI[MR]VKG8GPUVD:L
A[e2W4Jm@[a6gEjFHYMNMSHK<QXf6dZlB]e:_4[M<U`fOFJfJ]IV]V[G7CLMEaTgC]e:g4kMB[a>gBHl
:SeRUVJgH[IV]bgI<MY:g4kMB[a>gD[LA]e2_4KMFUEJEUXeGUIJE@00B[a>gDZlB]e:_4kmC]a>oDkL
B]e6_4[MGYIRUejF0`000;1:_4[LB[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD:lA[e9TTfcCK9=
/d9kAYa2NdJLC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m1Woo00<007ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol027oo00<007ooOol0:goo00=F557dEQ@00goo00<nO3YK?U`00TJm01U6_2YM
I[IV]fJf8IPQN26IA[a:_DZl3K/9^f:GGYIRUejF<Q/b6SHK<QY:gD[LB]eV]P03J]H05adg0016W4Jl
AYa:gD[LB]e:g4[MH[MV]f:fI[MR]bgJ;MT]fTkLC]e:g4kMC]`00dJm0UYF00AJE@00000000=>g00A
C]e>g4kMC]a>gDJlB]e6_F:GGYIRUf:F>S/j6SXkC]a>g@03C]`02U;mC]a>o4klD_e>g4kmC_a>gD[L
0TJm00E=/dfbCK==/Tfc00E>g004D_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Ioo`03001oogoo00Eoo`001Woo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo00Uoo`03001oogoo02Yoo`03DOAF5Goo00Aoo`0^
A[e6_4Zm:S`ZGF:fI]MV]VJgH[HUVB5h9IU6_4[MA[aRUeifHYMNUV:GAYa:_DJlB[e6W4[MA[a:gFJf
J]MV]V[F6CM6_DJLA[a6W4JmA[a:gDJlB]eR]VJgHYH20000dTZlAYa:_D[LC]e:g4kmB]a6gD:lGUIJ
EEYFFSDnO3iK?Ua:g4kmB]a>gD[LC_e>g4kmA[a:gDJlHYMNUV:G=QXj>cHJ>S]>g4kMB]a>oDkLD_e>
g5;mC]aBoDkLD_e:g4kMB]a6gDVbCK=9TTfcCK8014ZlC]e:g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Ioo`03001oogoo00Eoo`001Woo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Yoo`8002]oo`03DOAoogoo
00Aoo`0=A[e6_4JmI[IV]fJfI[MV]VJgAYa6_4JLA[`00dJm00ERUejFHYMCTENA00E6_096_@06J]IV
]V[FJ[HMEadg0T[L01I:gDZlB]a6_D[MA[aV]f:gI[MR]RgJ;MU:_4JlB[a:g4kMB]a:gD[LA[eJE@=J
EP@nF`=>g00>C]e>g4kMC]a>gAGL5OaRUV:GGYIRUcXJ>S/j6P9>g00;C_e>g4kLC_aBoDkLC_a>g4km
C]a>o@03A[d2CK800dfcCK9=/`0200@3C]`01DkmC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`04Ool00`00Oomoo`05Ool000Aoo`<000Ao
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0<Ool00`00Oomoo`0`Ool0CDJm@[a6gFJf
I[MR]VKG8GP004:LA[e2W4Jm@[a6gEjFHYMNMV:GGYHf6c7jB]e:_4[MB[`fOC9MJ]IV]V[GI[HMEaTg
C]e:_4[MB[a>gDJlB]e6_6JgH[IV]bgI<MX]fDkMB[a>gD[LC]e:g4kMB]a6gEXeGUIJEEYFB[a>gDZl
B]e>g4kmC]a>oDkLC_e:g4kMGYIRUejFHYL00P000;=:_4[LB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4km
C]aBoD:lA[e2_4fcCK9=/d9kAYa2NdJLC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Aoo`03001oogoo00Eoo`001Woo00<007ooOol0
0goo100017oo100047oo00<007ooOol0;goo0TJm00]6_6JgI[IV]fJfI[LQN26IAYa6_4JL00=6_@0:
GYIRUejFHYLb6SHK<QY:gD[LB]d2<Wd036ZfJ]IV]V[F7CLMEadgB]e:g4[MB]a:g@8V?@0:H[IV]f:g
I[L]fBgJ;MU>gD[LC]`4A[d2FUH015YEFUIJEP000dZl00a:g4kLC]e>g4kMC]a:gDJmB]eNUV:GHYH2
0004B[`014klC]aBoDkL0Tkl00IBoDkLC_a>g4kMB]`3A[d01DfbCK==/Tfc@W/00dJL00A>g5;lC_aB
o@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo
009oo`03001oogoo00Eoo`00:Goo00<007ooOol0;goo03]6_4Jm@[`ZGFJfI[MR]RFI8GPUVDJlB]e6
_0fk2K]RUejFHYMNMV:G<QXf6c7jB]e:_4[MI[IZefJfJ]HM=`00AYa6_4JLC]e:g4kMB[a>gF:fI[MR
UVJgH[I:_4JLB[e6_4kMB]a>oDJlA]e2_4KMFUEJEUXe00<00034B]a>oD[LC]e>g4kmC]a>oDJlB]e6
_6:GGYIRUejF>S/f6TkmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD:lA]e2_4fcBI9=/dfbC]e:
_4kMB]a>gDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d3Ool00`00Oomoo`05Ool002Yoo`03001oogoo02moo`8ZG@0BI[IV]fJfI[MV]R6H
8GPQVDJlB[e:_6:GGYIRUejFHYMCL5>A0dJl0TJm019:gFJfJ]IZ]V[F7CLMEdJLA[a6W4KMA[e:gDJl
A]eR]fJgH[H2000024ZlA[a:_4kLC]e:g4kMC]`2A[d3FUH015YE?U/nFciK0dkL00i>gDkLC]e>g4kM
A[a:gDJmHYMNUV:G>SXj>cXJ0TkL00I>gDkLC_a>o5;mC]`2C_`035;mC]a>oDkLC]e6_DfcCK9=/dfb
CK<010E>g004C_aBo5;lD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`3Ool00`00Oomoo`05Ool002]oo`80031oo`3oI[IV]f:fI]MV]VJg@Ya6_D:LA[e2_4KM
@[aRUeifHYMCL5>ADg1:_DJlB[e6W4[MA[aZeVJfJ]MV]QeG7CLMEdZlB]e:_4[MA[a:gDJlI[MR]VJg
HYHafRgIB[a6W4ZmB]a>gD[LC]e:g4KMFSENEUYEFUHjFcil?U/nG4kLC_e>g4kmB]a>oD[LC]dAfaGl
GYIRUejFHYLf6SXk=QYBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoD:lA[e9TTfcCK9=/dVb00D015;m
C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l005Bo@5Bo0=oo`03001oogoo00Aoo`00;Goo00<007ooOol0;Woo00YV]VJgI[IV]goo0016
W4JlAYa6_096_@0;GYIRUejFHYMNUSHK<QY:gD[LB]e:_002<Wd01V[FI[IZeVJf7ELM=`9:g009B]e:
_4[LA[e:gDJlI[MR]fJg00<]f@0:C]e:g4kLB]a>gD[LB]eJETJmFUD3FUH3B[`03D[LC]a>g4kLC]e:
g4kMC]a>gEjFHYMRUV:G008000=:_09>g00;C_e>g4klC_aBoDkLC_a>g4kmC]a>o@02A[d01DfbCK==
/Tfc@W/00TJL00E>oDkLC]a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;l0Woo00<007ooOol017oo000^Ool00`00Oomoo`0]Ool00fKG
I[Ioo`02Ool0=25h9IU6_4[MA[a:gD:lA]eNUV:GGWIRUc8J=Q/anT[MB[a:gDZlJ]MV]V[FI[IZeadg
7ELM=dkMB]a>gDZlC]dV?2HmHYIV]f:fI[L]fC7J;MU>gDZlC]e6_4KM@[aNEUYEFUIJ=EiF0P0000i:
_4kMB[a:gDkLC_e>g4kmA[a:gDJlHYMNUV:G10000;M:_4[LB[aBoDkLD_e>g5;mC]aBoDkLC_e:g4kM
B]a6gD:lCK=9/TfcCK96W49kAYa2Ne;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo7oo00001Woo000_Ool00`00Oomoo`0bOol0
1B5h9IU6_4ZmB[`00PVk00QRUejFHYMNUV:G<QXf6c8J0TJm01]:gDJlJ]IV]V[F7CL004JLA[a6W4[M
B]a:gD[LB]eR]fJgH[IV]f:gB[a6_4ZlA[a>gD[LC]d00dJm0eYF00AJE@00000000=>g00MC]e>g4kM
C]a>gDJlB]e6_F:GGYIRUcXj>S/j6SXkC]a>gDkLC_a>g5;mC]a>oDklD_e>g4kMC]a>g@02A[d00dfb
CK==/P02CK<4C]`01E;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lOol00006Ool0031oo`80039oo`0T9ITQN2FIA[a:gDJlHYMN
MV:GGYIRUdm`Di56_4ZmAYa:gDJlB]eV]V[GI[IZeQdg8EQ6W4JlAYa:gDJlB]e6_4[MH[IV]f:F0P00
0=Q:_4JLB[e6_4kMB]a>oDJlA]eJ=EiFFUEJEUXe?W`nFciLB]a>oD[LC]e:g4kmB]a>gDJlB]eNUV:G
GWHj>cHJ>S/f6SXkC]a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmB]a>gD:lCK==/TfcBK9=d`04C]e:_4kM
B]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m0006Ool0039oo`03001oogoo031oo`03A[a6W4Jl00=6_@06HYMNUV:GDg1CT5=`
14Jl0TJm019:gFJfJ]IV]QeG7CLMEd[LB]e:_4KMA[e:gDJlI[MR]fJgH[H2;MT02dkMB]a>g4[LC]e:
g4[MA[eJEUYE00000UYF00AJECiK?U/nF`=>g00:C]e:g4kMC]`Eo1GKHYMRUV:GGYH5B[`00dkLC_e>
g002C_`01U;mC]a>oDkLC_e>g0=6_@08CK9=/dfbCK==/P0500A>o@=>g005D_e>o5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_`00006Ool0
03=oo`03001oogoo02moo`13@Ya6_D:LA[e2_4KMGYIRUeifHYMNUSHK<OY:gDZlB]e:_3Im<UeZeVJf
J]MV]QeG7CLQF4ZlB]e:_4[MA[a:gDJlI[MR]VJg;MTanRgIC]e:_4kMB]a>gD[LC]e6_5YFFSENEUYE
001:_4kMB[a:gDkLC_e>g4kmB]a>oD[LHYMNMV:GGYH00P000;A>gDZlB]a:_5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4KM@[a=/dVbCK==/TJL@W]6W49kD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`4Ool00`00Oomoo`03Ool003Aoo`03
001oogoo02moo`04A[a:_DZlB]d2A[d05ejFHYMNUV:G<QXf6c8JB]e:g4[MB[aZeVJfJ]IV]V[FAYa6
_4JLA[a:g4[MB]`00RHm00EV]f:fI[MR]fJg00<]f@04C]e:g4kMC]`2A[d3FUH015YEFUH000000dZl
00]:g4kLC]e>g4kMA[a:gDJmHYMNUV:G00<0009>g006C]e>g4klC]aBoDkL0Tkl00EBoDkLC]e>g4kM
0096_@04CK9=/dfbCK<2AY`0249kAYa>o5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@08Ool00`00Oomoo`03Ool003Eoo`80031oo`0RA[a:gDJlB]eN
MV:GGYIRUeifHYLb6SHK<OY:gDJlB]e6_6[GI[IZeVJf0016W4JlAYa6_D[LC]e:_6JgH[IV]f:FI[L2
0000c4JLB[e6_4kMB]a>oD[LA]e2_5iFFUEJEUXe?W`nFdkMB]a>oD[LC]e>g4kmC]a>oDJlB]eNUV:G
GWIRUcHJ>S/f6TkmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmB]a6_D:lCK==/TfcBK9=dd[LC]e:_4kM
C]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBo@]oo`03001o
ogoo00=oo`00=goo00<007ooOol0;Woo14Jm00INUV:GGYIRUdm`Dg03A[`2A[d01D[MI[IZeVJfJ]H0
0QeG00Y:g4[MB[a:g4JmB]e6_6JgH[MV]`<0000:B[a6_4ZlA[a>gD[LB]e:g4JmFUD3FUH3?U/04TkM
C]a>g4kLC]e:g4kMC]a>gA7K5MaRUV:GGYHj>cXj>S/j6P9>g00:C_e>g4klC_aBoDkLC_e>o5;mC]`3
A[d01TfbCK==/dfcCK801@A>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d0
0e;l3goo00<007ooOol00goo000hOol00`00Oomoo`0^Ool0id:lA]e2_6:GGWIRUdm`Dg1?Ke>@A[a:
_DJLB]e6_4[MI[IZefJfJ]HM=b5HB[a:gDZlC]e6_4[MHYIV]`00I[MRUS7j;MU>gDZlC]e:g4kMB]a>
g@0bA]eJ=EiFFUEJESYK?W`nFdkmC]a>oDkLC_e:g4kmB]a>gEifHYMNUV:GGWI>gDZlB]a:_5;mC]aB
oDkLD_e>g5;mC]aBoDkLC_e>g4KM@[a=/dVbCM==/Tfc00@01DkLD_e>g5;mC]aBoDkLD_eBo5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d0000BOol00`00Oomoo`03Ool003Uoo`03001oogoo02ioo`=6_@0:HYM?
L6:GGYHf6c8J=Q]:g4[MB[`2<Wd016[FI[IZeVJf0aeG00A:g4[MB]a:g@8V?@049SaV]f:gI[L3;MT0
1dkMB]a>g4[LC]e:g4[M009JEP04FUEJEUYF0003B[`034kMC]a>g4kLC]e6_4[MA[e:gEjFHYMRUP80
00A:_004C_a>g5;mC]`2C_`01U;mC]a>oDkLC_e>g096_@09CK==/TfcCK=6W49kAYa>g4km009>g003
D_aBoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`4Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003Yoo`80
02moo`0]2I/9^ejFHYMNMV:G<QXf6c7j=Q]:_4[MB[aZefJfJ]IV]R5H0016_4JLA[e:g4kMB[`VGBHl
I[MRUVJgH[IV]bgI<OX]fDkMB]a>oD[LA]e2_5iFFUEJEUXe00<0002]B[a>gDZlC_e>g4kmC]a>oDJl
B]e6_6:GGWIRUcHJ>S/f6TkmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmB]a>gD:lA]e=/TfcCK9=dd9k
AYa2NdJLC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo008Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool003ao
o`03001oogoo02eoo`06GYIRUejFHYMNUV:G14Jl01A6_D[MA[aZeVJfJ]IV]QeGAYa6_4JLA[a:g4[M
B]aV]f:gI[MR]VJg0P0000M6_4ZlA[a>gD[LC]e>g002A[d3FUH015YE?U/nFciK0dkL00i>gDkLC]e>
g4[MA[a:gDJmHYMNUV:G>SXj>cXJ0TkL00a>gDkLC_a>o5;mC]a>oDklD_e>g4kMC]`2A[d3CK<00dfb
00E>g004C]`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01U;mD_aBo5;lD_eBo0aoo`03001oogoo00moo`03001oogoo009oo`00?Goo00<007oo
Ool0;Goo0=ANMV:GGYIRUdm?Dg16_4ZmAYa:_DJlB]eV]V[GI[IZeQdg8EQ:_4[MB[a>gDJlB]e6_6Jg
H[IV]f:F<OX]fC7JAYa:_DJlC]e:g4kMB]a6gEXeGUIJEEYF>U/nO3iK?Ua>g4kmC]a>oD[LC_e:g1Gl
4M]RUejFHYMNMSXk=QXj>cHJD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLA]e2_4JmBK9=ddfbCK<01005
C]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m4Goo00<007ooOol03Woo00<007ooOol00Woo000nOol00`00Oomoo`0/Ool00f:G
GYIRU`02Ool01S8J=Q]:g4[MB[a:g@8bO@04I[IZeVJfJ]H27EL02T[LB]e:_4[LA[e:gF:fI[MR]fJg
0bgI00X]fT[LC]a:g4kMB]a:gD[LA[eJE@=JEP=:_00<B]a>g4kLC]a>gD[LC]e>g6:GGYIRUf:F0P00
14Zl0TkL00Y>oDkLC_a>o5;mC]a>oDkLC_e>g096_@09CK==/TfcCK=6W49kAYa>g4km009>g003D_aB
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol0
4goo00<007ooOol03Goo00<007ooOol00Woo000oOol00`00Oomoo`0/Ool0>f:GOomoogoo=Q/anSHK
B[a:gDZlB]eV]V[FI[IZefJf8ELM=b5HB]a>gDZlC]dV?2HmHYIV]f:FI[L]fC7j;MU>gDZlC]e:g4KM
@[a6gEYEFUIJ=EiFFUD004ZlC]e:_4[MC]a>oDkLC_e6_4[MA[aRUeifHYL00`0008i>gDZlB]a>g5;m
C]aBoDkLD_e>g5;mC]a>oD[LC_e2_4KMCK9=/dfbCM=2NdJL@W]6W4kLD_e>g5;mC_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Uoo`03001oogoo00eoo`03001oogoo009o
o`00@7oo0P00<Goo01Hf6c8J=Q]6_D[MA[a6_FJfJ]IV]QeG0016_4JLA[a:g4[MB]a:gF:gI[MR]P9R
]`08B[a6_4ZlA[a>gD[LC]e>g0=6_@9JEP04FUD000000003C]`03TkMC]a>gDkLC]e6_4[MHYIRUejF
HYLj>SXk>QX2C]`034kMC]a>o4kLD_e>g4kmC_aBoDkLC]e>g096_@==/`03CK9=/dkL00=>g003C_aB
oDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l7Goo00<007ooOol037oo
00<007ooOol00Woo0012Ool00`00Oomoo`0_Ool05TZmAYa:_DJlB]e6_6[GI[IZeVJf8EPM=dJlAYa6
_DJlB]e6_4[MHYIV]f:F0P000:A:_4JLB[e6_4kMB]a>oD[LA]e2_5iFFUEJEUXe?W`nFciLB]a>oD[L
C]e:g4kmB]a>gDJlB]eNUV:GGWHj>cXJ>S/f6TkmC]a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a6_Dfb
CM==/TgCCK801T[LC]e:_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l9Goo00<007ooOol0
2goo00<007ooOol00Woo0013Ool00`00Oomoo`0_Ool3A[`01TJmB]e6_6ZfI[IZeP<ME`06B]e:_4[L
A[e:gDJl0V:g00iV]f:f;MT]fDkMB]a>g4[LC]e:g4[MB]a6_EYE0eYF00AJECiK?U/nF`=>g00:C]e:
g4kMC]`Eg17KHYMNUV:GGYH4B[`2C]`02TkmC]a>o4klD_e>g4kmC]a>oDkL0TJm00==/dfbCK<00Tfc
0P0500M>g4kmC]a>g5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`XOol00`00Oomoo`0;Ool00`00Oomoo`02
Ool004Aoo`03001oogoo02moo`0TB]e:_4[M<UdbOFJfJ]MV]V[F7CLQF1dgB]e:_4kMA[a:gDJl9UeR
UVJg;MTanRgIC]e:_4kMB]a>gD[LC]eJEDKMFSENEUYE0P0000i>gDZlB]e>g4kmC]a>oD[LC_e:g6:G
GWIRUejF0P0007e>gDZlB]a:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e2_4KM@[a=/dfbCM=2NdJL@W]6
W4kLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m02eoo`03001oogoo00]oo`03001oogoo005oo`00AGoo0P00<7oo
00m:gDZlB]eV]V[FI[IZ]VJfA[a6W4JlAYa:gD[LB]d00RHm00AR]V:gH[MV]`<]f@04C]e:g4kMC]`2
A[d3FUH015YEFUH000000dZl00i:g4kLC]e>g4kMA[a:gDJmHYMNUV:G>SXj>cXJ0TkL00a>gDkLC_a>
g5;mC]a>oDklD_e>g4kMC]`3A[d2CK<02DfbCK=6W4JL@W]Bo4klD_e>g002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l035oo`03001o
ogoo00Yoo`03001oogoo005oo`00Agoo00<007ooOol0;Woo01=:gDJlB]eV]V[FI[IZeaeGA[a6W4Jm
AYa>gDZlC]eRUVJgHYIV]`020000UTJLB[e6_4kMB]a>oD[LA]e2_5iFFUEJEUXe?W`nFciLB]a>oD[L
C]e>g4kmC]a>oDJlB]eNUV:GGWIRUcXJ>S/f6TkmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g4km@[a6_Dfb
CM==/TgCCK801T[LC]e:_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoCEoo`03001oogoo00Uoo`03001oogoo005oo`00B7oo00<007oo
Ool0;Woo00I:gDJlJ[IV]V[FI[H27EL05T[MB[a:g4[LB]e6_4KMH[MV]f:fH[L]fC7JA[a:_4JlC]e:
g4[MB]a6_EYE0eYF13iK0dkL00i>gD[LC]e>g4kM4M]RUejFHYMNUSXk>SXj>cXJ0TkL00Y>oDkLC_a>
o5;mC]a>oDkLC_e>g096_@03CK==/Tfc009=/`801@07C]a>oDkLC]aBo5;mC_`00U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo03Qoo`03001oogoo00Uoo`03001o
ogoo005oo`00BGoo00<007ooOol0;Woo030bOC9MJ]MV]V[FI[HQF1eGB]e:_4kMB[a:gDJlI[MRUVJg
HYHanRgI<MY:_4kMB]a>gD[LC]e:g4KMFSENEUYEFUI:_4kMB[a:gDkLC_e>g4kmB]a>oD[LHYMNMV:G
GYH20000L4kMB[a:g4ZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLA]e=/TfcCK9Add9kAYa2NdJLC]aB
oDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l?Goo00<007oo
Ool027oo00<007ooOol00Goo001:Ool2000_Ool01F[FI[IV]VJfJ]H00aeG00I:gD[LB]e:g2Hm9S`2
H[L026JgH[H]fBgI<MY:g4kLB]`3A[d2FUH015YEFUIJEP000dZl00]:g4kLC]e>g4kMA[a:gDJmHYMN
UV:G00<000=:_005C]a>o4kLD_e>g002C_`01e;mC]a>gDkLC]e2_DJm00A=/`96W005@W]6W4klD_e>
g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo45oo`03001oogoo00Moo`03
001oogoo005oo`00C7oo00<007ooOol0;Goo01iZeVJfJ]Moo`00AYa6_DJLC]e:_4kMB]aV]f:FI[MR
UVJgAYa:_DJlB[a:g4kmB]a6gD:lA]eJEEYFFSD30000N4[LC_e:g4kMC]a>oDkLC_e6_4[MGYIRUeif
HYLj6SXk=QY>oDkLC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LA[e2_4gCCK9=ddfbC]e:g4kMB[a>gDkL
D_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoDIoo`03001oogoo00Ioo`03001oogoo005o
o`00CGoo00<007ooOol0;7oo011V]V[FOomooaeG8EM6W4JlAYa:gDJlA]e6_FJgH[IR]`800007A[a:
_4JlB[a:g4kMC]`00TJm0eYF00AJECiK?U/nF`=>g00:C]e:g4kMC]a>gDJlB]eNUV:GGYH2>SX01SXk
>QY>g4kLC]e>g09>o00:D_e>g4kmC_aBoD[LC]e>g4JmCK83CK<00`05C]a>g002C]`2D_`01E;mC_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mOomoo`17Ool00`00Oomoo`07Ool10001Ool1Ool004ioo`03001o
ogoo031oo`0L7ELQEdZlC]e:_4[MA[a:gF:FI[MRUVJg;MTafTZlC]e:g4kMB]a>gD[LA]eJ=EiFFUEJ
EUXe?W`2?U/0L4kLC_e>g4kmB]a>oD[LC]eNMV:GGYIRUeifC]e:_4[LB[aBoDkLD_e>g5;mC]aBoDkL
D_e>g4km@[a6gD:lCM==/U7CCK801P05D_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mCGoo00<0
07ooOol01Woo0@000Goo0Goo001?Ool2000`Ool0125G7ELQEdZl0T[L00I:gDJlA]dV?FJgH[H2;MT0
2S7JB]a>g4[LC]e:g4[MB]a6_EYE0eYF00@004ZlB[a:g0=>g008C]e6_4[MA[e:gEjFHYMNUP8000A:
_004C_a>g5;mC]`2C_`01e;mC]a>oDkLC_e2_DJm00A=/`96W005@W]6W4kLC_e>g002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o59oo`03001oogoo00Eoo`40005oo`5oo`00DGoo00<007ooOol0;Woo01U6_DJLA[a:_4kMB]`V?B8l
I[MRUVJgHYHanRgI<MY:g4kmB]a>gD:lA]eJEEYFFSENEP030000JTkMB[a:gDkLC_e>g4kmA[a:gDJl
HYMNMV:GGYHj>cHJC_e>g4kMB]aBoDkLD_e>g5;mC]aBoDkLC_e:g4Jm@[a=ddfbCM==/U7CB]a>gDZl
C]e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lEGoo00<007ooOol01Goo0@000Goo0Goo001BOol00`00Oomoo`0^Ool024JlAYa6
_4[LB]e:g6JgH[H2H[L200001dZlA[a:_4[LC]e>g4kM0096_@9JEP03FUEJESiK008nF`9>g00>C]e>
g4kMC]a>gDJlB]e6_F:GGYIRUcXj>S/j6P9>g00;C]e>g4klC_aBoDkLC_e>o5;mC]a>g@02A[d01Tfb
CK==/dgCCK<01PA>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_aIOol00`00Oomoo`04Ool10001Ool1Ool005=oo`03001oogoo02ioo`0I
C]e:_4[MA[a:gDJlI[MRUVJg;MTafRgIB[e6_4ZlB]a>gD[LC]e2_5iFFUEJEUXeGUH00ciK069>oDkL
C_e>g4kmB]a>gA7K5OaNUV:GGWIRUcXJ>S/f6U;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4KM@[a=ddfb
DM==/TgC00D01TkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lGGoo00<007ooOol00goo0@000Goo0Goo001DOol00`00Oomoo`0^Ool2B]`04T[M
A[a6gF:gI[MR]V:g;MTafRgIC]a:g4kMB]a:gD[LC]e6_@=JEP800003B[a:g4Zl009>g009C]e>g4kM
C]a>gEjFHYMNUV:G008000=:_09>g00;C_e>g4klC_aBoDkLC_e>g4kmC]a6_@04CK<2AY`01D9kAYa>
g4kmC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0HWoo00<0
07ooOol00goo0@000Goo001EOol2000_Ool05TkMB]a>gB8lI[MRUVJgHYHanRgI<MY:g4kmB]a>gD[L
A]e6_5YFFSENEUYE0P0005e>gDZlB]e>g4kmC]a>oDkLB]e6_6:GGWIRUejF>S/f6TkmC]a>gD[LD_e>
g5;mC]aBoDkLD_e:g4kmB]a>oD:lA]e=/TgCCK9Add9kAYa2Ne;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0IGoo00<007ooOol00goo0@000Goo001GOol00`00Oomoo`0/
Ool01D[LB]e:g6JgH[H00V:g0P0000M:_4JlB[a:g4kMC]a>g@02A[d2FUH00eYEFUHnF`02?U/2C]`0
3TkMC]a>gDkLC]e6_D[MA[eRUejFHYLj>SXk>QX2C]`03TkMC]a>o4klD_e>g4kmC_aBoDkLC]e>g4Jm
@[d2CK<00dgCCK<01P03C]`015;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo01Y
Ool00`00Oomoo`02Ool10001Ool005Qoo`03001oogoo02aoo`0FA[a:gDJlI[MRUVJgHYHafRgIB[e6
_4ZlB]a>gD[LC]e2_4KMFUEJEUXe?W`3?U/08dkmB]a>gD[LC_e:g4kM4M/Ao5jFHYMNMV:G>QXj>cHJ
D_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLA]e2_4JmCK9AddfbCM<00P0602a:g4kMB[aBoDkLD_e>g5;m
D_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mLGoo00D007ooOomoo`00005oo`00FGoo00<007ooOol0;7oo0156_4KMH[MV]f:f
H[L]fC7J;MU>g4[LC]e:g4[MB]a>gDJm00=JEP05FUE:_4ZlB]a:_002C]`02DkMC]a>gDkLC]eNUV:G
GYIRU`020003B[`2C]`02TkmC]a>o4klD_e>g4kmC]a>oDkL0TJm0dfc00I6VdJL@W]6W4kLC_d2C]`0
0e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00U;lMGoo00@007ooOol0005oo`00FWoo0P00;Goo01<R?2HmHYIV]f:FI[L]fC7J
;MU>gD[LC]e2_4KMA[aJEUXeGUIJE@0200003TkMB[a:gDZlC_e>g4kmC]a:gDJlB]eNMV:GGYH30000
?4ZlB]a:_5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e2_4KMCK9=ddfbDM=2NdJL@W]6W4kLD_e>g5;mC_aB
oDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oGQoo`04001oogoo0001Ool005aoo`03001oogoo02]oo`0<H[IR]f:gI[MR]TZlA[a:_4JlC]e>g4kM
0dJm00AJEUYEFUIJEP8nF`9>g00AC]e>g4kMC]a>gDkLB]e6_F:GGYIRUejF>S/j6SXjC]a>g@03C]`0
2U;mC]a>oDklD_e>g4kMC]a6_D:m0Tfc00==ddfcC]`014kL00=>o5;mC]`00U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0O7oo00<007oo00000Goo
001MOol00`00Oomoo`0[Ool04V:FI[MRUWoo001:_DJlB[a6W4kmB]a>gD:lA]eJEEYFFSENEP<nF`15
?Wa:g4kMB]a>oD[LC]e:g4[MA[aRUeifHYLj6SXk=QXj>dkLD_e>g5;mC]aBoDkLD_e>g5;mC]a6gD:l
A[e=/U7CCK9Ad`0600M:g4kMB[aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<M081oo`40005oo`400000GWoo00<007ooOol0:Woo00eV]f:fOomooc7J
;MU>g4[LC]e:g4[MB]a>g@02A[d2FUH015YEFUI:_4[L0TZl00a>g4kMC]a>gDkLC]e:g6:GGYIRUejF
HYL4B[`00dkLC_e>g002C_`01U;mC]a>oDkLC_e>g096_@09CM==/dfcCK=6W49kAYa>g4km009>g003
D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0Q7oo0P00001O
Ool2000_Ool07C7J;MTanT[LC]e:_4kMB]a>gEXeGUIJEEYFFSD004ZlB]e:_4kMC]a>oDkLB]e6_4[M
GWIRUeifHYL00P0002m:_4[LB[aBoDkLD_e>g5;mC]aBoDkLC_e:g4km@[a6gDfbCM==/U7C@W]6W49k
AYa>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l08Qoo`800000HGoo
00<007ooOol0;7oo00M6_4ZlA[a:_4kLC]e:g002A[d015YFFUEJEUYF0`0000=>g4kMC]`00TkL01m>
gDkLB]e6_D[MGYIRUejF>S/j6SXjC]a>gDkLC_a>g5;mC]a>oDklD_e>g4kMC]a6_D:mA[e=/dgCCK==
d`04C]`00dklD_e>g002D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_b;Ool20000069oo`03
001oogoo02aoo`0=A[a:_4JLB[e:g4kMB]a6gDJlFUIJ=EiFFUD00SiK03PnO4[LC]e:g4kmB]a>gD[L
B]e6_6:GGWIRUcXJ>S/f6SXkC]a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmB]a6_D:lDM==/e7CCK801d[L
C]e:_4kMC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lRWoo10000Woo001SOol00`00Oomoo`0/
Ool024[LC]e:g4kLB]a>gD[LA[d2FUH00eYEFUHnF`02?U/2C]`02dkMC]a>gDkLC]e:g6:GGYIRUejF
HYL014Zl00]>g4kmC]a>g4klD_e>g4klC]a>oDkL0096_@06CM==/dfcCK==d`060TkL00I>oDkLC]aB
o5;mC_`2D_`01U;mD_aBo5;lD_eBo8Uoo`@000Ioo`00I7oo0P00;Woo01U>gDZlC]e:g4kMB]a6gEYE
FUIJ=@00B[a:gDZlC]e>g4kmC]a:gDJlB]e6_6:GGWIRU`02000084ZlB]a:_4kMC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g4KMCK9=ddfbDM=2NdJL@W]6W4kLD_e>g5;mC_aBoDkLD_f;Ool4000:Ool006Ioo`03
001oogoo02aoo`03C]e:g4kM0096_@03FUEJEUYF00<00003C]a>gDkL009>g00=C]e>g4kMA[e:gEjF
HYMNUSXk>QXj>TkLC]d00dkL00mBoDkLC_a>o5;mC]a>oDkLC]e2_DJmCK==ddfcCM<014kL00A>o5;m
C]aBo8Yoo`@000ioo`00Igoo00<007ooOol0:goo00U:g4kMB]a6gDJlFUIJ=EiFFUD00SiK02TnO4[L
C]e:g4kmB]a>gD[LC_e6_4[MGWIRUeif>S/j6SXkC]a>gD[LC_e>g5;mC]aBoDkLD_e>g4kmB]a6_D:l
DM==/e7CCK801d[LC]e:_4kM08Yoo`<0019oo`00J7oo00<007ooOol0:goo00=:g4kMB]`00TJm00AJ
EUYEFUIJEP<nF`03C]a>gDkL009>g007C]e:g4kMGYIRUejFHYL014Zl00]>g4kmC]a>g4klD_e>g4km
C]a>oDkL00=6_@06CK==ddfcCM<01P07RGoo10005Goo001YOol2000/Ool05T[LC]e:g4KMFUEJEUXe
GUH004[MB[a>gDZlC_e>g4kmA[a:gDJlHYMNMV:G0P0001A:_4[LB[a>gDkLD_e>g5;mC]aBoDkLD_e>
g4kmC]a6gD:lDM==/U7CR7oo10006Goo001[Ool00`00Oomoo`0ZOol2A[d015YEFUIJEUYF0`00015>
gDkLC]a>g4kMC]a>gDJmB]e6_F:GGYIRUcXJ>SY>g4kM00=>g00>D_e>g4klC_aBoDkLC_e>g4kM@[e6
_DfcCM==/hAoo`@001eoo`00K7oo00<007ooOol0:Woo02Y6_4KMFSENEUYEFUHnFd9l?U]>gD[LC_e:
g4kMB]a>oDJlB]eNMV:GGWHj>cXJ>S/j6TkMB]a>oDkLD_e>g5;mC]aBoDkLD_e:g4Jm@[aAddfcDM>0
Ool4000QOol006eoo`03001oogoo02Yoo`03A[eJEUYE00=JEP<nF`0<C]e>g4kLC]a>gD[LC]eNUV:G
GYIRUUjF14Zl00M>oDkLC]a>g5;mC]a>o005Ool014JmCK==ddfcOGoo0`009Goo001^Ool00`00Oomo
o`0ZOol014JlFUIJ=EYF0P0000e:_4kMB[a>oDkLC_e6_4[MA[a:gEifHYMNMP02000014[LB[a>gDZl
2goo00A2_57CCK9AdgUoo`@002Qoo`00Kgoo0P00:Woo0eYF00AJE@00001>g@=>g009C]e>g4kMC]a:
gDJmHYINUV:G015oo`04A[e=/dgCCK=eOol4000/Ool0075oo`03001oogoo02Moo`0BFSEJEUYEOoln
Fd9l?U]>gD[LC_e:g4kMB]a>oD[LB]e6_6:G4Woo00=2_4KMCK<0LWoo1000<7oo001bOol00`00Oomo
o`0WOol015YEOomoogoo0ciK00Q>gDkLC]a>g4kMB]a>gDkL5Goo00==/dgCOol0KGoo1000=7oo001c
Ool00`00Oomoo`0VOol00eYFOomoo`02Ool01dZlC]e:_4[MC]a>oDkL01Qoo`03DM==/Woo06Uoo`@0
03Qoo`00M7oo0P00;7oo00<007ooOol06goo00==/dgCOol0IWoo0`00?7oo001fOol00`00Oomoo`0Y
Ool00`00Oomoo`0KOol00dKMCK=oo`1ROol4000oOol007Moo`03001oogoo02Qoo`03001oogoo07ao
o`@004=oo`00N7oo00<007ooOol09goo00<007ooOol0N7oo1000Agoo001iOol2000WOol00`00Oomo
o`1dOol4001;Ool007]oo`03001oogoo02Aoo`03001oogoo075oo`<004moo`00O7oo00<007ooOol0
8goo00<007ooOol0KGoo1000DWoo001mOol00`00Oomoo`0ROol00`00Oomoo`1YOol4001FOol007io
o`80029oo`03001oogoo06Eoo`@005Yoo`00P7oo00<007ooOol07goo00<007ooOol0HGoo1000GWoo
0021Ool00`00Oomoo`0NOol00`00Oomoo`1NOol3001ROol0089oo`03001oogoo01eoo`03001oogoo
05Yoo`@006Eoo`00Pgoo00<007ooOol077oo00<007ooOol0EWoo1000JGoo0024Ool2000LOol00`00
Oomoo`1BOol4001]Ool008Ioo`03001oogoo01Uoo`03001oogoo04ioo`@0075oo`00Qgoo00<007oo
Ool067oo00<007ooOol0Bgoo0`00MGoo0028Ool00`00Oomoo`0GOol00`00Oomoo`17Ool4001hOol0
08Uoo`8001Moo`03001oogoo04=oo`@007aoo`00Rgoo00<007ooOol057oo00<007ooOol0?goo1000
P7oo002<Ool00`00Oomoo`0BOol00`00Oomoo`0lOol40024Ool008eoo`03001oogoo015oo`03001o
ogoo03Uoo`<008Qoo`00SWoo0P004Goo00<007ooOol0=Goo1000Rgoo002@Ool00`00Oomoo`0>Ool0
0`00Oomoo`0aOol4002?Ool0095oo`03001oogoo00eoo`03001oogoo02eoo`@009=oo`00TWoo00<0
07ooOol037oo00<007ooOol0:Goo1000Ugoo002COol2000<Ool00`00Oomoo`0UOol4002KOol009Eo
o`03001oogoo00Uoo`03001oogoo029oo`<009moo`00UWoo00<007ooOol027oo00<007ooOol07Woo
1000XWoo002GOol00`00Oomoo`07Ool00`00Oomoo`0JOol4002VOol009Qoo`03001oogoo00Ioo`03
001oogoo01Ioo`@00:Yoo`00VGoo0P001Woo00<007ooOol04Woo1000[Woo002KOol00`00Oomoo`03
Ool00`00Oomoo`0?Ool3002bOol009aoo`03001oogoo009oo`03001oogoo00]oo`@00;Eoo`00WGoo
00D007ooOomoo`0000Uoo`@00;Uoo`00WWoo0P0000=oo`00Ool017oo1000_Goo002POol200000goo
000000020031Ool00:5oo`800<Eoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
0 0 0 r
.39615 .70291 .40198 .69369 .41064 .6986 .40537 .6928 Mtetra
.583 .685 .911 r
.40537 .6928 .41064 .6986 .41956 .69699 .41428 .69193 Mtetra
.625 .728 .921 r
.41428 .69193 .41956 .69699 .42852 .69512 .42326 .69008 Mtetra
.621 .728 .923 r
.42326 .69008 .42852 .69512 .43751 .69382 .43227 .68832 Mtetra
.471 .653 .939 r
.43227 .68832 .43751 .69382 .44691 .67527 .44126 .6891 Mtetra
.199 0 .196 r
.44126 .6891 .44691 .67527 .45569 .68567 .45051 .67964 Mtetra
.579 .677 .907 r
.45051 .67964 .45569 .68567 .46478 .68397 .45959 .67889 Mtetra
.632 .732 .92 r
.45959 .67889 .46478 .68397 .4739 .68182 .46873 .67685 Mtetra
.64 .739 .921 r
.46873 .67685 .4739 .68182 .48306 .6796 .47791 .67463 Mtetra
.639 .739 .921 r
.47791 .67463 .48306 .6796 .49226 .67751 .48712 .67242 Mtetra
.624 .731 .924 r
.48712 .67242 .49226 .67751 .50147 .67638 .49636 .67054 Mtetra
.193 .493 .903 r
.49636 .67054 .50147 .67638 .51077 .66567 .50561 .67457 Mtetra
0 0 0 r
.50561 .67457 .51077 .66567 .52004 .6676 .51497 .66189 Mtetra
.606 .702 .912 r
.51497 .66189 .52004 .6676 .52936 .66556 .5243 .66047 Mtetra
.642 .739 .919 r
.5243 .66047 .52936 .66556 .53871 .66314 .53367 .65817 Mtetra
.65 .746 .92 r
.53367 .65817 .53871 .66314 .54809 .66059 .54308 .65565 Mtetra
.654 .749 .92 r
.54308 .65565 .54809 .66059 .55751 .65795 .55251 .65303 Mtetra
.656 .751 .92 r
.55251 .65303 .55751 .65795 .56695 .65526 .56198 .65034 Mtetra
.658 .753 .92 r
.56198 .65034 .56695 .65526 .57643 .65253 .57148 .6476 Mtetra
.659 .753 .92 r
.57148 .6476 .57643 .65253 .58594 .64978 .58102 .64484 Mtetra
.659 .754 .92 r
.58102 .64484 .58594 .64978 .59549 .64701 .59058 .64205 Mtetra
.59058 .64205 .59549 .64701 .60506 .64423 .60018 .63926 Mtetra
.60018 .63926 .60506 .64423 .61467 .64145 .60981 .63646 Mtetra
.658 .754 .92 r
.60981 .63646 .61467 .64145 .62431 .63867 .61947 .63365 Mtetra
.658 .753 .92 r
.61947 .63365 .62431 .63867 .63398 .63588 .62917 .63085 Mtetra
.62917 .63085 .63398 .63588 .64369 .63309 .6389 .62804 Mtetra
.6389 .62804 .64369 .63309 .65343 .63029 .64866 .62522 Mtetra
.64866 .62522 .65343 .63029 .66321 .62749 .65846 .6224 Mtetra
.65846 .6224 .66321 .62749 .67301 .62468 .66829 .61957 Mtetra
.66829 .61957 .67301 .62468 .68286 .62186 .67816 .61673 Mtetra
.657 .753 .92 r
.67816 .61673 .68286 .62186 .69273 .61904 .68806 .61389 Mtetra
.68806 .61389 .69273 .61904 .70265 .6162 .69799 .61103 Mtetra
.69799 .61103 .70265 .6162 .71259 .61336 .70796 .60817 Mtetra
.70796 .60817 .71259 .61336 .72257 .61051 .71797 .6053 Mtetra
.657 .752 .92 r
.71797 .6053 .72257 .61051 .73259 .60765 .72801 .60242 Mtetra
.72801 .60242 .73259 .60765 .74264 .60478 .73808 .59953 Mtetra
.73808 .59953 .74264 .60478 .75272 .6019 .7482 .59663 Mtetra
.7482 .59663 .75272 .6019 .76284 .59901 .75834 .59373 Mtetra
.75834 .59373 .76284 .59901 .773 .59611 .76852 .59081 Mtetra
.76852 .59081 .773 .59611 .78319 .5932 .77874 .58788 Mtetra
.77874 .58788 .78319 .5932 .79342 .59029 .789 .58495 Mtetra
.789 .58495 .79342 .59029 .80369 .58736 .79929 .582 Mtetra
.79929 .582 .80369 .58736 .81399 .58442 .80962 .57904 Mtetra
.80962 .57904 .81399 .58442 .82433 .58148 .81998 .57608 Mtetra
.81998 .57608 .82433 .58148 .8347 .57852 .83038 .5731 Mtetra
.83038 .5731 .8347 .57852 .84512 .57556 .84082 .57012 Mtetra
.84082 .57012 .84512 .57556 .85557 .57258 .8513 .56712 Mtetra
.8513 .56712 .85557 .57258 .86605 .56959 .86181 .56412 Mtetra
.86181 .56412 .86605 .56959 .87658 .5666 .87237 .5611 Mtetra
.87237 .5611 .87658 .5666 .88714 .56359 .88296 .55807 Mtetra
.88296 .55807 .88714 .56359 .89774 .56057 .89359 .55503 Mtetra
.89359 .55503 .89774 .56057 .90838 .55755 .90425 .55198 Mtetra
.90425 .55198 .90838 .55755 .91906 .55451 .91496 .54893 Mtetra
.91496 .54893 .91906 .55451 .92978 .55146 .92571 .54586 Mtetra
.92571 .54586 .92978 .55146 .94053 .5484 .93649 .54278 Mtetra
.93649 .54278 .94053 .5484 .95133 .54533 .94731 .53968 Mtetra
.94731 .53968 .95133 .54533 .96216 .54224 .95818 .53658 Mtetra
.95818 .53658 .96216 .54224 .97303 .53915 .96908 .53347 Mtetra
.96908 .53347 .97303 .53915 .98395 .53605 .98002 .53034 Mtetra
.809 .691 .735 r
.39092 .69473 .39615 .70291 .40537 .6928 .40025 .68178 Mtetra
.37 .439 .802 r
.40025 .68178 .40537 .6928 .41428 .69193 .40898 .68668 Mtetra
.616 .718 .919 r
.40898 .68668 .41428 .69193 .42326 .69008 .41796 .68503 Mtetra
.627 .73 .922 r
.41796 .68503 .42326 .69008 .43227 .68832 .427 .68313 Mtetra
.599 .717 .927 r
.427 .68313 .43227 .68832 .44126 .6891 .43605 .68179 Mtetra
.854 .713 .705 r
.43605 .68179 .44126 .6891 .45051 .67964 .44553 .66313 Mtetra
.26 .293 .707 r
.44553 .66313 .45051 .67964 .45959 .67889 .45437 .67355 Mtetra
.619 .719 .917 r
.45437 .67355 .45959 .67889 .46873 .67685 .46353 .67181 Mtetra
.638 .737 .92 r
.46353 .67181 .46873 .67685 .47791 .67463 .47272 .66963 Mtetra
.64 .74 .921 r
.47272 .66963 .47791 .67463 .48712 .67242 .48195 .66737 Mtetra
.635 .737 .922 r
.48195 .66737 .48712 .67242 .49636 .67054 .49122 .66523 Mtetra
.588 .712 .929 r
.49122 .66523 .49636 .67054 .50561 .67457 .50051 .66407 Mtetra
.77 .654 .735 r
.50051 .66407 .50561 .67457 .51497 .66189 .50988 .65328 Mtetra
.481 .557 .857 r
.50988 .65328 .51497 .66189 .5243 .66047 .51922 .65519 Mtetra
.632 .729 .918 r
.51922 .65519 .5243 .66047 .53367 .65817 .52861 .65311 Mtetra
.647 .743 .92 r
.52861 .65311 .53367 .65817 .54308 .65565 .53803 .65065 Mtetra
.652 .748 .92 r
.53803 .65065 .54308 .65565 .55251 .65303 .54749 .64805 Mtetra
.655 .751 .92 r
.54749 .64805 .55251 .65303 .56198 .65034 .55698 .64538 Mtetra
.657 .752 .92 r
.55698 .64538 .56198 .65034 .57148 .6476 .5665 .64264 Mtetra
.658 .753 .92 r
.5665 .64264 .57148 .6476 .58102 .64484 .57606 .63987 Mtetra
.659 .754 .92 r
.57606 .63987 .58102 .64484 .59058 .64205 .58565 .63707 Mtetra
.58565 .63707 .59058 .64205 .60018 .63926 .59527 .63425 Mtetra
.59527 .63425 .60018 .63926 .60981 .63646 .60492 .63143 Mtetra
.60492 .63143 .60981 .63646 .61947 .63365 .6146 .62861 Mtetra
.658 .753 .92 r
.6146 .62861 .61947 .63365 .62917 .63085 .62432 .62578 Mtetra
.62432 .62578 .62917 .63085 .6389 .62804 .63408 .62295 Mtetra
.63408 .62295 .6389 .62804 .64866 .62522 .64386 .62011 Mtetra
.64386 .62011 .64866 .62522 .65846 .6224 .65369 .61727 Mtetra
.65369 .61727 .65846 .6224 .66829 .61957 .66354 .61442 Mtetra
.66354 .61442 .66829 .61957 .67816 .61673 .67343 .61157 Mtetra
.657 .753 .92 r
.67343 .61157 .67816 .61673 .68806 .61389 .68335 .6087 Mtetra
.68335 .6087 .68806 .61389 .69799 .61103 .69331 .60583 Mtetra
.69331 .60583 .69799 .61103 .70796 .60817 .70331 .60295 Mtetra
.70331 .60295 .70796 .60817 .71797 .6053 .71334 .60006 Mtetra
.71334 .60006 .71797 .6053 .72801 .60242 .7234 .59716 Mtetra
.657 .752 .92 r
.7234 .59716 .72801 .60242 .73808 .59953 .7335 .59425 Mtetra
.7335 .59425 .73808 .59953 .7482 .59663 .74364 .59133 Mtetra
.74364 .59133 .7482 .59663 .75834 .59373 .75381 .58841 Mtetra
.75381 .58841 .75834 .59373 .76852 .59081 .76402 .58547 Mtetra
.76402 .58547 .76852 .59081 .77874 .58788 .77426 .58253 Mtetra
.77426 .58253 .77874 .58788 .789 .58495 .78454 .57957 Mtetra
.78454 .57957 .789 .58495 .79929 .582 .79486 .5766 Mtetra
.79486 .5766 .79929 .582 .80962 .57904 .80521 .57363 Mtetra
.80521 .57363 .80962 .57904 .81998 .57608 .81561 .57064 Mtetra
.81561 .57064 .81998 .57608 .83038 .5731 .82603 .56765 Mtetra
.82603 .56765 .83038 .5731 .84082 .57012 .8365 .56464 Mtetra
.8365 .56464 .84082 .57012 .8513 .56712 .84701 .56163 Mtetra
.84701 .56163 .8513 .56712 .86181 .56412 .85755 .5586 Mtetra
.85755 .5586 .86181 .56412 .87237 .5611 .86813 .55556 Mtetra
.86813 .55556 .87237 .5611 .88296 .55807 .87875 .55251 Mtetra
.87875 .55251 .88296 .55807 .89359 .55503 .8894 .54946 Mtetra
.8894 .54946 .89359 .55503 .90425 .55198 .9001 .54639 Mtetra
.9001 .54639 .90425 .55198 .91496 .54893 .91083 .54331 Mtetra
.91083 .54331 .91496 .54893 .92571 .54586 .92161 .54022 Mtetra
.92161 .54022 .92571 .54586 .93649 .54278 .93242 .53712 Mtetra
.93242 .53712 .93649 .54278 .94731 .53968 .94327 .534 Mtetra
.94327 .534 .94731 .53968 .95818 .53658 .95417 .53088 Mtetra
.95417 .53088 .95818 .53658 .96908 .53347 .9651 .52774 Mtetra
.9651 .52774 .96908 .53347 .98002 .53034 .97607 .5246 Mtetra
.377 .604 .937 r
.38556 .68907 .39092 .69473 .40025 .68178 .39437 .69098 Mtetra
0 0 0 r
.39437 .69098 .40025 .68178 .40898 .68668 .40366 .6808 Mtetra
.583 .685 .911 r
.40366 .6808 .40898 .68668 .41796 .68503 .41264 .6799 Mtetra
.625 .728 .921 r
.41264 .6799 .41796 .68503 .427 .68313 .42169 .67802 Mtetra
.621 .728 .923 r
.42169 .67802 .427 .68313 .43605 .68179 .43077 .67621 Mtetra
.472 .653 .939 r
.43077 .67621 .43605 .68179 .44553 .66313 .43982 .67697 Mtetra
.19 0 .187 r
.43982 .67697 .44553 .66313 .45437 .67355 .44914 .66743 Mtetra
.579 .677 .907 r
.44914 .66743 .45437 .67355 .46353 .67181 .45829 .66665 Mtetra
.632 .732 .92 r
.45829 .66665 .46353 .67181 .47272 .66963 .4675 .66458 Mtetra
.64 .739 .921 r
.4675 .66458 .47272 .66963 .48195 .66737 .47675 .66231 Mtetra
.639 .739 .921 r
.47675 .66231 .48195 .66737 .49122 .66523 .48604 .66006 Mtetra
.624 .731 .924 r
.48604 .66006 .49122 .66523 .50051 .66407 .49535 .65815 Mtetra
.196 .494 .903 r
.49535 .65815 .50051 .66407 .50988 .65328 .50467 .66216 Mtetra
0 0 0 r
.50467 .66216 .50988 .65328 .51922 .65519 .5141 .6494 Mtetra
.606 .702 .912 r
.5141 .6494 .51922 .65519 .52861 .65311 .52351 .64794 Mtetra
.642 .739 .919 r
.52351 .64794 .52861 .65311 .53803 .65065 .53296 .6456 Mtetra
.65 .746 .92 r
.53296 .6456 .53803 .65065 .54749 .64805 .54244 .64303 Mtetra
.654 .749 .92 r
.54244 .64303 .54749 .64805 .55698 .64538 .55195 .64037 Mtetra
.656 .751 .92 r
.55195 .64037 .55698 .64538 .5665 .64264 .56149 .63764 Mtetra
.658 .753 .92 r
.56149 .63764 .5665 .64264 .57606 .63987 .57107 .63486 Mtetra
.659 .753 .92 r
.57107 .63486 .57606 .63987 .58565 .63707 .58068 .63205 Mtetra
.659 .754 .92 r
.58068 .63205 .58565 .63707 .59527 .63425 .59032 .62922 Mtetra
.59032 .62922 .59527 .63425 .60492 .63143 .6 .62638 Mtetra
.6 .62638 .60492 .63143 .6146 .62861 .6097 .62353 Mtetra
.658 .754 .92 r
.6097 .62353 .6146 .62861 .62432 .62578 .61945 .62068 Mtetra
.658 .753 .92 r
.61945 .62068 .62432 .62578 .63408 .62295 .62922 .61783 Mtetra
.62922 .61783 .63408 .62295 .64386 .62011 .63903 .61498 Mtetra
.63903 .61498 .64386 .62011 .65369 .61727 .64888 .61211 Mtetra
.64888 .61211 .65369 .61727 .66354 .61442 .65876 .60925 Mtetra
.65876 .60925 .66354 .61442 .67343 .61157 .66867 .60637 Mtetra
.66867 .60637 .67343 .61157 .68335 .6087 .67862 .60349 Mtetra
.657 .753 .92 r
.67862 .60349 .68335 .6087 .69331 .60583 .6886 .60059 Mtetra
.6886 .60059 .69331 .60583 .70331 .60295 .69862 .59769 Mtetra
.69862 .59769 .70331 .60295 .71334 .60006 .70867 .59478 Mtetra
.70867 .59478 .71334 .60006 .7234 .59716 .71876 .59187 Mtetra
.657 .752 .92 r
.71876 .59187 .7234 .59716 .7335 .59425 .72889 .58894 Mtetra
.72889 .58894 .7335 .59425 .74364 .59133 .73905 .586 Mtetra
.73905 .586 .74364 .59133 .75381 .58841 .74925 .58306 Mtetra
.74925 .58306 .75381 .58841 .76402 .58547 .75948 .5801 Mtetra
.75948 .5801 .76402 .58547 .77426 .58253 .76975 .57713 Mtetra
.76975 .57713 .77426 .58253 .78454 .57957 .78006 .57416 Mtetra
.78006 .57416 .78454 .57957 .79486 .5766 .7904 .57117 Mtetra
.7904 .57117 .79486 .5766 .80521 .57363 .80078 .56818 Mtetra
.80078 .56818 .80521 .57363 .81561 .57064 .8112 .56517 Mtetra
.8112 .56517 .81561 .57064 .82603 .56765 .82166 .56216 Mtetra
.82166 .56216 .82603 .56765 .8365 .56464 .83215 .55913 Mtetra
.83215 .55913 .8365 .56464 .84701 .56163 .84268 .55609 Mtetra
.84268 .55609 .84701 .56163 .85755 .5586 .85325 .55305 Mtetra
.85325 .55305 .85755 .5586 .86813 .55556 .86386 .54999 Mtetra
.86386 .54999 .86813 .55556 .87875 .55251 .87451 .54692 Mtetra
.87451 .54692 .87875 .55251 .8894 .54946 .88519 .54384 Mtetra
.88519 .54384 .8894 .54946 .9001 .54639 .89591 .54075 Mtetra
.89591 .54075 .9001 .54639 .91083 .54331 .90668 .53765 Mtetra
.90668 .53765 .91083 .54331 .92161 .54022 .91748 .53454 Mtetra
.91748 .53454 .92161 .54022 .93242 .53712 .92832 .53142 Mtetra
.92832 .53142 .93242 .53712 .94327 .534 .93921 .52828 Mtetra
.93921 .52828 .94327 .534 .95417 .53088 .95013 .52514 Mtetra
.95013 .52514 .95417 .53088 .9651 .52774 .96109 .52198 Mtetra
.96109 .52198 .9651 .52774 .97607 .5246 .97209 .51881 Mtetra
.585 .709 .928 r
.38015 .6838 .38556 .68907 .39437 .69098 .38909 .68271 Mtetra
.809 .692 .735 r
.38909 .68271 .39437 .69098 .40366 .6808 .3985 .66968 Mtetra
.369 .439 .802 r
.3985 .66968 .40366 .6808 .41264 .6799 .40729 .67457 Mtetra
.616 .718 .919 r
.40729 .67457 .41264 .6799 .42169 .67802 .41634 .67289 Mtetra
.627 .73 .922 r
.41634 .67289 .42169 .67802 .43077 .67621 .42544 .67095 Mtetra
.599 .717 .927 r
.42544 .67095 .43077 .67621 .43982 .67697 .43456 .66957 Mtetra
.855 .713 .705 r
.43456 .66957 .43982 .67697 .44914 .66743 .44412 .6508 Mtetra
.258 .292 .706 r
.44412 .6508 .44914 .66743 .45829 .66665 .45303 .66124 Mtetra
.619 .719 .918 r
.45303 .66124 .45829 .66665 .4675 .66458 .46226 .65946 Mtetra
.638 .737 .92 r
.46226 .65946 .4675 .66458 .47675 .66231 .47152 .65723 Mtetra
.64 .74 .921 r
.47152 .65723 .47675 .66231 .48604 .66006 .48083 .65493 Mtetra
.635 .737 .922 r
.48083 .65493 .48604 .66006 .49535 .65815 .49016 .65276 Mtetra
.588 .712 .929 r
.49016 .65276 .49535 .65815 .50467 .66216 .49952 .65156 Mtetra
.77 .655 .735 r
.49952 .65156 .50467 .66216 .5141 .6494 .50897 .64069 Mtetra
.48 .557 .857 r
.50897 .64069 .5141 .6494 .52351 .64794 .51838 .64258 Mtetra
.632 .729 .918 r
.51838 .64258 .52351 .64794 .53296 .6456 .52785 .64046 Mtetra
.647 .743 .92 r
.52785 .64046 .53296 .6456 .54244 .64303 .53735 .63796 Mtetra
.652 .748 .92 r
.53735 .63796 .54244 .64303 .55195 .64037 .54688 .63532 Mtetra
.655 .751 .92 r
.54688 .63532 .55195 .64037 .56149 .63764 .55645 .63259 Mtetra
.657 .752 .92 r
.55645 .63259 .56149 .63764 .57107 .63486 .56605 .62981 Mtetra
.658 .753 .92 r
.56605 .62981 .57107 .63486 .58068 .63205 .57568 .627 Mtetra
.659 .754 .92 r
.57568 .627 .58068 .63205 .59032 .62922 .58534 .62415 Mtetra
.58534 .62415 .59032 .62922 .6 .62638 .59504 .62129 Mtetra
.59504 .62129 .6 .62638 .6097 .62353 .60477 .61843 Mtetra
.60477 .61843 .6097 .62353 .61945 .62068 .61454 .61556 Mtetra
.658 .753 .92 r
.61454 .61556 .61945 .62068 .62922 .61783 .62434 .61268 Mtetra
.62434 .61268 .62922 .61783 .63903 .61498 .63417 .60981 Mtetra
.63417 .60981 .63903 .61498 .64888 .61211 .64404 .60692 Mtetra
.64404 .60692 .64888 .61211 .65876 .60925 .65394 .60404 Mtetra
.65394 .60404 .65876 .60925 .66867 .60637 .66388 .60114 Mtetra
.66388 .60114 .66867 .60637 .67862 .60349 .67385 .59824 Mtetra
.657 .753 .92 r
.67385 .59824 .67862 .60349 .6886 .60059 .68386 .59532 Mtetra
.68386 .59532 .6886 .60059 .69862 .59769 .6939 .5924 Mtetra
.6939 .5924 .69862 .59769 .70867 .59478 .70398 .58947 Mtetra
.70398 .58947 .70867 .59478 .71876 .59187 .7141 .58654 Mtetra
.7141 .58654 .71876 .59187 .72889 .58894 .72425 .58359 Mtetra
.657 .752 .92 r
.72425 .58359 .72889 .58894 .73905 .586 .73443 .58063 Mtetra
.73443 .58063 .73905 .586 .74925 .58306 .74466 .57767 Mtetra
.74466 .57767 .74925 .58306 .75948 .5801 .75491 .57469 Mtetra
.75491 .57469 .75948 .5801 .76975 .57713 .76521 .57171 Mtetra
.76521 .57171 .76975 .57713 .78006 .57416 .77554 .56871 Mtetra
.77554 .56871 .78006 .57416 .7904 .57117 .78591 .56571 Mtetra
.78591 .56571 .7904 .57117 .80078 .56818 .79632 .56269 Mtetra
.79632 .56269 .80078 .56818 .8112 .56517 .80677 .55966 Mtetra
.80677 .55966 .8112 .56517 .82166 .56216 .81725 .55663 Mtetra
.81725 .55663 .82166 .56216 .83215 .55913 .82777 .55358 Mtetra
.82777 .55358 .83215 .55913 .84268 .55609 .83833 .55052 Mtetra
.83833 .55052 .84268 .55609 .85325 .55305 .84893 .54746 Mtetra
.84893 .54746 .85325 .55305 .86386 .54999 .85956 .54438 Mtetra
.85956 .54438 .86386 .54999 .87451 .54692 .87024 .54129 Mtetra
.87024 .54129 .87451 .54692 .88519 .54384 .88095 .53819 Mtetra
.88095 .53819 .88519 .54384 .89591 .54075 .8917 .53508 Mtetra
.8917 .53508 .89591 .54075 .90668 .53765 .90249 .53196 Mtetra
.90249 .53196 .90668 .53765 .91748 .53454 .91333 .52882 Mtetra
.91333 .52882 .91748 .53454 .92832 .53142 .9242 .52568 Mtetra
.9242 .52568 .92832 .53142 .93921 .52828 .93511 .52252 Mtetra
.93511 .52252 .93921 .52828 .95013 .52514 .94606 .51936 Mtetra
.94606 .51936 .95013 .52514 .96109 .52198 .95706 .51618 Mtetra
.95706 .51618 .96109 .52198 .97209 .51881 .96809 .51299 Mtetra
.612 .722 .924 r
.37471 .67859 .38015 .6838 .38909 .68271 .38368 .67698 Mtetra
.378 .604 .937 r
.38368 .67698 .38909 .68271 .3985 .66968 .39256 .67887 Mtetra
0 0 0 r
.39256 .67887 .3985 .66968 .40729 .67457 .40192 .66861 Mtetra
.583 .685 .911 r
.40192 .66861 .40729 .67457 .41634 .67289 .41097 .66768 Mtetra
.625 .728 .921 r
.41097 .66768 .41634 .67289 .42544 .67095 .42009 .66576 Mtetra
.621 .728 .923 r
.42009 .66576 .42544 .67095 .43456 .66957 .42924 .66391 Mtetra
.472 .653 .939 r
.42924 .66391 .43456 .66957 .44412 .6508 .43836 .66465 Mtetra
.18 0 .178 r
.43836 .66465 .44412 .6508 .45303 .66124 .44775 .65504 Mtetra
.578 .677 .907 r
.44775 .65504 .45303 .66124 .46226 .65946 .45698 .65422 Mtetra
.632 .732 .92 r
.45698 .65422 .46226 .65946 .47152 .65723 .46626 .65211 Mtetra
.64 .739 .921 r
.46626 .65211 .47152 .65723 .48083 .65493 .47558 .6498 Mtetra
.639 .739 .921 r
.47558 .6498 .48083 .65493 .49016 .65276 .48494 .64751 Mtetra
.624 .731 .924 r
.48494 .64751 .49016 .65276 .49952 .65156 .49432 .64555 Mtetra
.199 .495 .903 r
.49432 .64555 .49952 .65156 .50897 .64069 .50371 .64956 Mtetra
0 0 0 r
.50371 .64956 .50897 .64069 .51838 .64258 .51322 .63671 Mtetra
.606 .702 .912 r
.51322 .63671 .51838 .64258 .52785 .64046 .52271 .63521 Mtetra
.642 .739 .919 r
.52271 .63521 .52785 .64046 .53735 .63796 .53223 .63282 Mtetra
.65 .746 .92 r
.53223 .63282 .53735 .63796 .54688 .63532 .54178 .63021 Mtetra
.654 .749 .92 r
.54178 .63021 .54688 .63532 .55645 .63259 .55137 .62751 Mtetra
.656 .751 .92 r
.55137 .62751 .55645 .63259 .56605 .62981 .56099 .62473 Mtetra
.658 .753 .92 r
.56099 .62473 .56605 .62981 .57568 .627 .57065 .62191 Mtetra
.659 .753 .92 r
.57065 .62191 .57568 .627 .58534 .62415 .58034 .61905 Mtetra
.659 .754 .92 r
.58034 .61905 .58534 .62415 .59504 .62129 .59006 .61617 Mtetra
.59006 .61617 .59504 .62129 .60477 .61843 .59981 .61329 Mtetra
.59981 .61329 .60477 .61843 .61454 .61556 .6096 .6104 Mtetra
.658 .754 .92 r
.6096 .6104 .61454 .61556 .62434 .61268 .61942 .6075 Mtetra
.658 .753 .92 r
.61942 .6075 .62434 .61268 .63417 .60981 .62928 .6046 Mtetra
.62928 .6046 .63417 .60981 .64404 .60692 .63917 .6017 Mtetra
.63917 .6017 .64404 .60692 .65394 .60404 .6491 .59879 Mtetra
.6491 .59879 .65394 .60404 .66388 .60114 .65906 .59588 Mtetra
.65906 .59588 .66388 .60114 .67385 .59824 .66905 .59295 Mtetra
.66905 .59295 .67385 .59824 .68386 .59532 .67909 .59002 Mtetra
.657 .753 .92 r
.67909 .59002 .68386 .59532 .6939 .5924 .68915 .58708 Mtetra
.68915 .58708 .6939 .5924 .70398 .58947 .69926 .58413 Mtetra
.69926 .58413 .70398 .58947 .7141 .58654 .7094 .58117 Mtetra
.7094 .58117 .7141 .58654 .72425 .58359 .71957 .57821 Mtetra
.657 .752 .92 r
.71957 .57821 .72425 .58359 .73443 .58063 .72978 .57523 Mtetra
.72978 .57523 .73443 .58063 .74466 .57767 .74003 .57224 Mtetra
.74003 .57224 .74466 .57767 .75491 .57469 .75032 .56925 Mtetra
.75032 .56925 .75491 .57469 .76521 .57171 .76064 .56624 Mtetra
.76064 .56624 .76521 .57171 .77554 .56871 .771 .56323 Mtetra
.771 .56323 .77554 .56871 .78591 .56571 .7814 .5602 Mtetra
.7814 .5602 .78591 .56571 .79632 .56269 .79183 .55717 Mtetra
.79183 .55717 .79632 .56269 .80677 .55966 .8023 .55412 Mtetra
.8023 .55412 .80677 .55966 .81725 .55663 .81281 .55106 Mtetra
.81281 .55106 .81725 .55663 .82777 .55358 .82336 .548 Mtetra
.82336 .548 .82777 .55358 .83833 .55052 .83395 .54492 Mtetra
.83395 .54492 .83833 .55052 .84893 .54746 .84457 .54183 Mtetra
.84457 .54183 .84893 .54746 .85956 .54438 .85523 .53873 Mtetra
.85523 .53873 .85956 .54438 .87024 .54129 .86594 .53562 Mtetra
.86594 .53562 .87024 .54129 .88095 .53819 .87668 .5325 Mtetra
.87668 .5325 .88095 .53819 .8917 .53508 .88746 .52937 Mtetra
.88746 .52937 .8917 .53508 .90249 .53196 .89828 .52622 Mtetra
.89828 .52622 .90249 .53196 .91333 .52882 .90914 .52307 Mtetra
.90914 .52307 .91333 .52882 .9242 .52568 .92005 .5199 Mtetra
.92005 .5199 .9242 .52568 .93511 .52252 .93099 .51673 Mtetra
.93099 .51673 .93511 .52252 .94606 .51936 .94197 .51354 Mtetra
.94197 .51354 .94606 .51936 .95706 .51618 .95299 .51034 Mtetra
.95299 .51034 .95706 .51618 .96809 .51299 .96406 .50713 Mtetra
.615 .721 .922 r
.36923 .67332 .37471 .67859 .38368 .67698 .37823 .67163 Mtetra
.585 .709 .928 r
.37823 .67163 .38368 .67698 .39256 .67887 .38723 .67051 Mtetra
.81 .692 .735 r
.38723 .67051 .39256 .67887 .40192 .66861 .39672 .65739 Mtetra
.368 .438 .802 r
.39672 .65739 .40192 .66861 .41097 .66768 .40557 .66227 Mtetra
.616 .718 .919 r
.40557 .66227 .41097 .66768 .42009 .66576 .4147 .66055 Mtetra
.627 .73 .922 r
.4147 .66055 .42009 .66576 .42924 .66391 .42387 .65857 Mtetra
.599 .717 .927 r
.42387 .65857 .42924 .66391 .43836 .66465 .43306 .65716 Mtetra
.856 .714 .705 r
.43306 .65716 .43836 .66465 .44775 .65504 .4427 .63827 Mtetra
.255 .29 .706 r
.4427 .63827 .44775 .65504 .45698 .65422 .45167 .64873 Mtetra
.619 .719 .918 r
.45167 .64873 .45698 .65422 .46626 .65211 .46096 .64691 Mtetra
.638 .737 .92 r
.46096 .64691 .46626 .65211 .47558 .6498 .4703 .64464 Mtetra
.64 .74 .921 r
.4703 .64464 .47558 .6498 .48494 .64751 .47968 .6423 Mtetra
.635 .737 .922 r
.47968 .6423 .48494 .64751 .49432 .64555 .48909 .64008 Mtetra
.588 .712 .929 r
.48909 .64008 .49432 .64555 .50371 .64956 .49853 .63885 Mtetra
.771 .656 .735 r
.49853 .63885 .50371 .64956 .51322 .63671 .50805 .6279 Mtetra
.48 .557 .857 r
.50805 .6279 .51322 .63671 .52271 .63521 .51754 .62976 Mtetra
.632 .729 .918 r
.51754 .62976 .52271 .63521 .53223 .63282 .52708 .6276 Mtetra
.647 .743 .92 r
.52708 .6276 .53223 .63282 .54178 .63021 .53665 .62506 Mtetra
.652 .748 .92 r
.53665 .62506 .54178 .63021 .55137 .62751 .54626 .62237 Mtetra
.655 .751 .92 r
.54626 .62237 .55137 .62751 .56099 .62473 .55591 .6196 Mtetra
.657 .752 .92 r
.55591 .6196 .56099 .62473 .57065 .62191 .56558 .61678 Mtetra
.658 .753 .92 r
.56558 .61678 .57065 .62191 .58034 .61905 .57529 .61391 Mtetra
.659 .754 .92 r
.57529 .61391 .58034 .61905 .59006 .61617 .58504 .61102 Mtetra
.58504 .61102 .59006 .61617 .59981 .61329 .59482 .60812 Mtetra
.59482 .60812 .59981 .61329 .6096 .6104 .60463 .6052 Mtetra
.60463 .6052 .6096 .6104 .61942 .6075 .61447 .60229 Mtetra
.658 .753 .92 r
.61447 .60229 .61942 .6075 .62928 .6046 .62435 .59937 Mtetra
.62435 .59937 .62928 .6046 .63917 .6017 .63427 .59644 Mtetra
.63427 .59644 .63917 .6017 .6491 .59879 .64422 .59351 Mtetra
.64422 .59351 .6491 .59879 .65906 .59588 .6542 .59058 Mtetra
.6542 .59058 .65906 .59588 .66905 .59295 .66423 .58763 Mtetra
.66423 .58763 .66905 .59295 .67909 .59002 .67428 .58468 Mtetra
.657 .753 .92 r
.67428 .58468 .67909 .59002 .68915 .58708 .68437 .58172 Mtetra
.68437 .58172 .68915 .58708 .69926 .58413 .6945 .57875 Mtetra
.6945 .57875 .69926 .58413 .7094 .58117 .70467 .57577 Mtetra
.70467 .57577 .7094 .58117 .71957 .57821 .71487 .57279 Mtetra
.71487 .57279 .71957 .57821 .72978 .57523 .7251 .56979 Mtetra
.657 .752 .92 r
.7251 .56979 .72978 .57523 .74003 .57224 .73538 .56678 Mtetra
.73538 .56678 .74003 .57224 .75032 .56925 .74569 .56377 Mtetra
.74569 .56377 .75032 .56925 .76064 .56624 .75604 .56074 Mtetra
.75604 .56074 .76064 .56624 .771 .56323 .76642 .55771 Mtetra
.76642 .55771 .771 .56323 .7814 .5602 .77685 .55466 Mtetra
.77685 .55466 .7814 .5602 .79183 .55717 .78731 .5516 Mtetra
.78731 .5516 .79183 .55717 .8023 .55412 .79781 .54854 Mtetra
.79781 .54854 .8023 .55412 .81281 .55106 .80834 .54546 Mtetra
.80834 .54546 .81281 .55106 .82336 .548 .81892 .54237 Mtetra
.81892 .54237 .82336 .548 .83395 .54492 .82953 .53927 Mtetra
.82953 .53927 .83395 .54492 .84457 .54183 .84019 .53616 Mtetra
.84019 .53616 .84457 .54183 .85523 .53873 .85088 .53304 Mtetra
.85088 .53304 .85523 .53873 .86594 .53562 .86161 .52991 Mtetra
.86161 .52991 .86594 .53562 .87668 .5325 .87238 .52677 Mtetra
.87238 .52677 .87668 .5325 .88746 .52937 .88319 .52362 Mtetra
.88319 .52362 .88746 .52937 .89828 .52622 .89404 .52045 Mtetra
.89404 .52045 .89828 .52622 .90914 .52307 .90493 .51727 Mtetra
.90493 .51727 .90914 .52307 .92005 .5199 .91586 .51409 Mtetra
.91586 .51409 .92005 .5199 .93099 .51673 .92684 .51089 Mtetra
.92684 .51089 .93099 .51673 .94197 .51354 .93785 .50768 Mtetra
.93785 .50768 .94197 .51354 .95299 .51034 .9489 .50446 Mtetra
.9489 .50446 .95299 .51034 .96406 .50713 .96 .50122 Mtetra
.604 .71 .919 r
.36373 .66779 .36923 .67332 .37823 .67163 .37273 .66634 Mtetra
.612 .722 .924 r
.37273 .66634 .37823 .67163 .38723 .67051 .38178 .6647 Mtetra
.379 .605 .937 r
.38178 .6647 .38723 .67051 .39672 .65739 .39072 .66656 Mtetra
0 0 0 r
.39072 .66656 .39672 .65739 .40557 .66227 .40016 .65623 Mtetra
.583 .685 .911 r
.40016 .65623 .40557 .66227 .4147 .66055 .40927 .65526 Mtetra
.625 .728 .921 r
.40927 .65526 .4147 .66055 .42387 .65857 .41846 .6533 Mtetra
.621 .728 .923 r
.41846 .6533 .42387 .65857 .43306 .65716 .42768 .65142 Mtetra
.473 .653 .938 r
.42768 .65142 .43306 .65716 .4427 .63827 .43687 .65213 Mtetra
.171 0 .168 r
.43687 .65213 .4427 .63827 .45167 .64873 .44634 .64244 Mtetra
.578 .677 .907 r
.44634 .64244 .45167 .64873 .46096 .64691 .45564 .64159 Mtetra
.632 .732 .92 r
.45564 .64159 .46096 .64691 .4703 .64464 .46499 .63944 Mtetra
.64 .739 .921 r
.46499 .63944 .4703 .64464 .47968 .6423 .47439 .63709 Mtetra
.639 .739 .921 r
.47439 .63709 .47968 .6423 .48909 .64008 .48382 .63475 Mtetra
.624 .731 .924 r
.48382 .63475 .48909 .64008 .49853 .63885 .49328 .63275 Mtetra
.202 .497 .904 r
.49328 .63275 .49853 .63885 .50805 .6279 .50274 .63674 Mtetra
0 0 0 r
.50274 .63674 .50805 .6279 .51754 .62976 .51233 .6238 Mtetra
.606 .702 .912 r
.51233 .6238 .51754 .62976 .52708 .6276 .52189 .62227 Mtetra
.642 .739 .919 r
.52189 .62227 .52708 .6276 .53665 .62506 .53149 .61983 Mtetra
.65 .746 .92 r
.53149 .61983 .53665 .62506 .54626 .62237 .54112 .61718 Mtetra
.654 .749 .92 r
.54112 .61718 .54626 .62237 .55591 .6196 .55079 .61443 Mtetra
.656 .751 .92 r
.55079 .61443 .55591 .6196 .56558 .61678 .56049 .61161 Mtetra
.658 .753 .92 r
.56049 .61161 .56558 .61678 .57529 .61391 .57022 .60874 Mtetra
.659 .753 .92 r
.57022 .60874 .57529 .61391 .58504 .61102 .57999 .60584 Mtetra
.659 .754 .92 r
.57999 .60584 .58504 .61102 .59482 .60812 .58979 .60291 Mtetra
.58979 .60291 .59482 .60812 .60463 .6052 .59962 .59998 Mtetra
.59962 .59998 .60463 .6052 .61447 .60229 .60949 .59704 Mtetra
.658 .754 .92 r
.60949 .59704 .61447 .60229 .62435 .59937 .6194 .5941 Mtetra
.658 .753 .92 r
.6194 .5941 .62435 .59937 .63427 .59644 .62933 .59115 Mtetra
.62933 .59115 .63427 .59644 .64422 .59351 .63931 .5882 Mtetra
.63931 .5882 .64422 .59351 .6542 .59058 .64932 .58524 Mtetra
.64932 .58524 .6542 .59058 .66423 .58763 .65936 .58228 Mtetra
.65936 .58228 .66423 .58763 .67428 .58468 .66945 .57931 Mtetra
.66945 .57931 .67428 .58468 .68437 .58172 .67956 .57633 Mtetra
.657 .753 .92 r
.67956 .57633 .68437 .58172 .6945 .57875 .68972 .57334 Mtetra
.68972 .57334 .6945 .57875 .70467 .57577 .69991 .57034 Mtetra
.69991 .57034 .70467 .57577 .71487 .57279 .71013 .56733 Mtetra
.71013 .56733 .71487 .57279 .7251 .56979 .72039 .56432 Mtetra
.657 .752 .92 r
.72039 .56432 .7251 .56979 .73538 .56678 .73069 .56129 Mtetra
.73069 .56129 .73538 .56678 .74569 .56377 .74103 .55825 Mtetra
.74103 .55825 .74569 .56377 .75604 .56074 .75141 .55521 Mtetra
.75141 .55521 .75604 .56074 .76642 .55771 .76182 .55215 Mtetra
.76182 .55215 .76642 .55771 .77685 .55466 .77227 .54908 Mtetra
.77227 .54908 .77685 .55466 .78731 .5516 .78276 .546 Mtetra
.78276 .546 .78731 .5516 .79781 .54854 .79328 .54292 Mtetra
.79328 .54292 .79781 .54854 .80834 .54546 .80385 .53982 Mtetra
.80385 .53982 .80834 .54546 .81892 .54237 .81445 .53671 Mtetra
.81445 .53671 .81892 .54237 .82953 .53927 .82509 .53359 Mtetra
.82509 .53359 .82953 .53927 .84019 .53616 .83577 .53046 Mtetra
.83577 .53046 .84019 .53616 .85088 .53304 .84649 .52732 Mtetra
.84649 .52732 .85088 .53304 .86161 .52991 .85725 .52416 Mtetra
.85725 .52416 .86161 .52991 .87238 .52677 .86805 .521 Mtetra
.86805 .521 .87238 .52677 .88319 .52362 .87889 .51783 Mtetra
.87889 .51783 .88319 .52362 .89404 .52045 .88977 .51464 Mtetra
.88977 .51464 .89404 .52045 .90493 .51727 .90069 .51144 Mtetra
.90069 .51144 .90493 .51727 .91586 .51409 .91165 .50823 Mtetra
.91165 .50823 .91586 .51409 .92684 .51089 .92265 .50501 Mtetra
.92265 .50501 .92684 .51089 .93785 .50768 .9337 .50178 Mtetra
.9337 .50178 .93785 .50768 .9489 .50446 .94478 .49853 Mtetra
.94478 .49853 .9489 .50446 .96 .50122 .95591 .49528 Mtetra
.555 .659 .905 r
.35825 .66133 .36373 .66779 .37273 .66634 .36721 .66099 Mtetra
.615 .721 .922 r
.36721 .66099 .37273 .66634 .38178 .6647 .37627 .65926 Mtetra
.586 .709 .928 r
.37627 .65926 .38178 .6647 .39072 .66656 .38535 .65811 Mtetra
.811 .693 .735 r
.38535 .65811 .39072 .66656 .40016 .65623 .39491 .6449 Mtetra
.366 .437 .802 r
.39491 .6449 .40016 .65623 .40927 .65526 .40383 .64977 Mtetra
.616 .718 .919 r
.40383 .64977 .40927 .65526 .41846 .6533 .41302 .64801 Mtetra
.627 .73 .922 r
.41302 .64801 .41846 .6533 .42768 .65142 .42226 .64599 Mtetra
.599 .717 .927 r
.42226 .64599 .42768 .65142 .43687 .65213 .43152 .64454 Mtetra
.857 .715 .705 r
.43152 .64454 .43687 .65213 .44634 .64244 .44125 .62555 Mtetra
.253 .288 .705 r
.44125 .62555 .44634 .64244 .45564 .64159 .45028 .63601 Mtetra
.619 .719 .918 r
.45028 .63601 .45564 .64159 .46499 .63944 .45965 .63415 Mtetra
.638 .737 .92 r
.45965 .63415 .46499 .63944 .47439 .63709 .46907 .63184 Mtetra
.64 .74 .921 r
.46907 .63184 .47439 .63709 .48382 .63475 .47852 .62946 Mtetra
.635 .737 .922 r
.47852 .62946 .48382 .63475 .49328 .63275 .488 .6272 Mtetra
.588 .712 .929 r
.488 .6272 .49328 .63275 .50274 .63674 .49751 .62592 Mtetra
.771 .656 .736 r
.49751 .62592 .50274 .63674 .51233 .6238 .50711 .6149 Mtetra
.479 .557 .857 r
.50711 .6149 .51233 .6238 .52189 .62227 .51667 .61674 Mtetra
.632 .729 .918 r
.51667 .61674 .52189 .62227 .53149 .61983 .52629 .61453 Mtetra
.647 .743 .92 r
.52629 .61453 .53149 .61983 .54112 .61718 .53595 .61194 Mtetra
.652 .748 .92 r
.53595 .61194 .54112 .61718 .55079 .61443 .54563 .60921 Mtetra
.655 .751 .92 r
.54563 .60921 .55079 .61443 .56049 .61161 .55536 .6064 Mtetra
.657 .752 .92 r
.55536 .6064 .56049 .61161 .57022 .60874 .56511 .60353 Mtetra
.658 .753 .92 r
.56511 .60353 .57022 .60874 .57999 .60584 .5749 .60061 Mtetra
.659 .754 .92 r
.5749 .60061 .57999 .60584 .58979 .60291 .58473 .59768 Mtetra
.58473 .59768 .58979 .60291 .59962 .59998 .59458 .59472 Mtetra
.59458 .59472 .59962 .59998 .60949 .59704 .60448 .59176 Mtetra
.60448 .59176 .60949 .59704 .6194 .5941 .61441 .5888 Mtetra
.658 .753 .92 r
.61441 .5888 .6194 .5941 .62933 .59115 .62437 .58583 Mtetra
.62437 .58583 .62933 .59115 .63931 .5882 .63437 .58286 Mtetra
.63437 .58286 .63931 .5882 .64932 .58524 .6444 .57988 Mtetra
.6444 .57988 .64932 .58524 .65936 .58228 .65447 .57689 Mtetra
.65447 .57689 .65936 .58228 .66945 .57931 .66458 .5739 Mtetra
.66458 .5739 .66945 .57931 .67956 .57633 .67472 .5709 Mtetra
.657 .753 .92 r
.67472 .5709 .67956 .57633 .68972 .57334 .6849 .56789 Mtetra
.6849 .56789 .68972 .57334 .69991 .57034 .69511 .56487 Mtetra
.69511 .56487 .69991 .57034 .71013 .56733 .70536 .56184 Mtetra
.70536 .56184 .71013 .56733 .72039 .56432 .71565 .5588 Mtetra
.71565 .5588 .72039 .56432 .73069 .56129 .72598 .55576 Mtetra
.657 .752 .92 r
.72598 .55576 .73069 .56129 .74103 .55825 .73634 .5527 Mtetra
.73634 .5527 .74103 .55825 .75141 .55521 .74674 .54963 Mtetra
.74674 .54963 .75141 .55521 .76182 .55215 .75718 .54655 Mtetra
.75718 .54655 .76182 .55215 .77227 .54908 .76766 .54347 Mtetra
.76766 .54347 .77227 .54908 .78276 .546 .77817 .54037 Mtetra
.77817 .54037 .78276 .546 .79328 .54292 .78873 .53726 Mtetra
.78873 .53726 .79328 .54292 .80385 .53982 .79932 .53414 Mtetra
.79932 .53414 .80385 .53982 .81445 .53671 .80995 .53101 Mtetra
.80995 .53101 .81445 .53671 .82509 .53359 .82062 .52787 Mtetra
.82062 .52787 .82509 .53359 .83577 .53046 .83133 .52472 Mtetra
.83133 .52472 .83577 .53046 .84649 .52732 .84208 .52155 Mtetra
.84208 .52155 .84649 .52732 .85725 .52416 .85287 .51838 Mtetra
.85287 .51838 .85725 .52416 .86805 .521 .86369 .51519 Mtetra
.86369 .51519 .86805 .521 .87889 .51783 .87456 .51199 Mtetra
.87456 .51199 .87889 .51783 .88977 .51464 .88547 .50879 Mtetra
.88547 .50879 .88977 .51464 .90069 .51144 .89642 .50557 Mtetra
.89642 .50557 .90069 .51144 .91165 .50823 .90741 .50233 Mtetra
.90741 .50233 .91165 .50823 .92265 .50501 .91845 .49909 Mtetra
.91845 .49909 .92265 .50501 .9337 .50178 .92952 .49584 Mtetra
.92952 .49584 .9337 .50178 .94478 .49853 .94063 .49257 Mtetra
.94063 .49257 .94478 .49853 .95591 .49528 .95179 .48929 Mtetra
.031 .034 .526 r
.35408 .62763 .35825 .66133 .36721 .66099 .36166 .65539 Mtetra
.604 .71 .919 r
.36166 .65539 .36721 .66099 .37627 .65926 .37073 .6539 Mtetra
.612 .722 .924 r
.37073 .6539 .37627 .65926 .38535 .65811 .37984 .65221 Mtetra
.38 .605 .936 r
.37984 .65221 .38535 .65811 .39491 .6449 .38885 .65406 Mtetra
0 0 0 r
.38885 .65406 .39491 .6449 .40383 .64977 .39837 .64365 Mtetra
.583 .685 .911 r
.39837 .64365 .40383 .64977 .41302 .64801 .40755 .64264 Mtetra
.625 .728 .921 r
.40755 .64264 .41302 .64801 .42226 .64599 .41681 .64064 Mtetra
.621 .728 .923 r
.41681 .64064 .42226 .64599 .43152 .64454 .4261 .63872 Mtetra
.473 .653 .938 r
.4261 .63872 .43152 .64454 .44125 .62555 .43536 .6394 Mtetra
.161 0 .158 r
.43536 .6394 .44125 .62555 .45028 .63601 .44491 .62964 Mtetra
.578 .677 .907 r
.44491 .62964 .45028 .63601 .45965 .63415 .45428 .62875 Mtetra
.632 .732 .92 r
.45428 .62875 .45965 .63415 .46907 .63184 .46371 .62655 Mtetra
.64 .739 .921 r
.46371 .62655 .46907 .63184 .47852 .62946 .47318 .62416 Mtetra
.639 .739 .921 r
.47318 .62416 .47852 .62946 .488 .6272 .48268 .62178 Mtetra
.624 .731 .924 r
.48268 .62178 .488 .6272 .49751 .62592 .49222 .61975 Mtetra
.205 .498 .904 r
.49222 .61975 .49751 .62592 .50711 .6149 .50175 .62372 Mtetra
0 0 0 r
.50175 .62372 .50711 .6149 .51667 .61674 .51143 .61069 Mtetra
.606 .702 .912 r
.51143 .61069 .51667 .61674 .52629 .61453 .52106 .60911 Mtetra
.642 .739 .919 r
.52106 .60911 .52629 .61453 .53595 .61194 .53074 .60663 Mtetra
.65 .746 .92 r
.53074 .60663 .53595 .61194 .54563 .60921 .54045 .60394 Mtetra
.654 .749 .92 r
.54045 .60394 .54563 .60921 .55536 .6064 .55019 .60114 Mtetra
.656 .751 .92 r
.55019 .60114 .55536 .6064 .56511 .60353 .55997 .59827 Mtetra
.658 .753 .92 r
.55997 .59827 .56511 .60353 .5749 .60061 .56978 .59535 Mtetra
.659 .753 .92 r
.56978 .59535 .5749 .60061 .58473 .59768 .57963 .5924 Mtetra
.659 .754 .92 r
.57963 .5924 .58473 .59768 .59458 .59472 .58951 .58943 Mtetra
.58951 .58943 .59458 .59472 .60448 .59176 .59943 .58645 Mtetra
.59943 .58645 .60448 .59176 .61441 .5888 .60938 .58346 Mtetra
.658 .754 .92 r
.60938 .58346 .61441 .5888 .62437 .58583 .61937 .58047 Mtetra
.658 .753 .92 r
.61937 .58047 .62437 .58583 .63437 .58286 .62939 .57748 Mtetra
.62939 .57748 .63437 .58286 .6444 .57988 .63945 .57448 Mtetra
.63945 .57448 .6444 .57988 .65447 .57689 .64954 .57147 Mtetra
.64954 .57147 .65447 .57689 .66458 .5739 .65968 .56846 Mtetra
.65968 .56846 .66458 .5739 .67472 .5709 .66984 .56543 Mtetra
.66984 .56543 .67472 .5709 .6849 .56789 .68005 .5624 Mtetra
.657 .753 .92 r
.68005 .5624 .6849 .56789 .69511 .56487 .69029 .55936 Mtetra
.69029 .55936 .69511 .56487 .70536 .56184 .70056 .55631 Mtetra
.70056 .55631 .70536 .56184 .71565 .5588 .71088 .55326 Mtetra
.71088 .55326 .71565 .5588 .72598 .55576 .72123 .55019 Mtetra
.657 .752 .92 r
.72123 .55019 .72598 .55576 .73634 .5527 .73162 .54711 Mtetra
.73162 .54711 .73634 .5527 .74674 .54963 .74205 .54402 Mtetra
.74205 .54402 .74674 .54963 .75718 .54655 .75251 .54092 Mtetra
.75251 .54092 .75718 .54655 .76766 .54347 .76302 .53781 Mtetra
.76302 .53781 .76766 .54347 .77817 .54037 .77356 .53469 Mtetra
.77356 .53469 .77817 .54037 .78873 .53726 .78414 .53156 Mtetra
.78414 .53156 .78873 .53726 .79932 .53414 .79476 .52842 Mtetra
.79476 .52842 .79932 .53414 .80995 .53101 .80542 .52527 Mtetra
.80542 .52527 .80995 .53101 .82062 .52787 .81612 .52211 Mtetra
.81612 .52211 .82062 .52787 .83133 .52472 .82685 .51893 Mtetra
.82685 .51893 .83133 .52472 .84208 .52155 .83763 .51575 Mtetra
.83763 .51575 .84208 .52155 .85287 .51838 .84845 .51255 Mtetra
.84845 .51255 .85287 .51838 .86369 .51519 .85931 .50934 Mtetra
.85931 .50934 .86369 .51519 .87456 .51199 .87021 .50612 Mtetra
.87021 .50612 .87456 .51199 .88547 .50879 .88114 .50289 Mtetra
.88114 .50289 .88547 .50879 .89642 .50557 .89212 .49965 Mtetra
.89212 .49965 .89642 .50557 .90741 .50233 .90314 .4964 Mtetra
.90314 .4964 .90741 .50233 .91845 .49909 .91421 .49313 Mtetra
.91421 .49313 .91845 .49909 .92952 .49584 .92531 .48985 Mtetra
.92531 .48985 .92952 .49584 .94063 .49257 .93646 .48656 Mtetra
.93646 .48656 .94063 .49257 .95179 .48929 .94764 .48326 Mtetra
.421 .159 .408 r
.34669 .65801 .35408 .62763 .36166 .65539 .35613 .64883 Mtetra
.555 .659 .905 r
.35613 .64883 .36166 .65539 .37073 .6539 .36515 .64846 Mtetra
.615 .721 .922 r
.36515 .64846 .37073 .6539 .37984 .65221 .37429 .6467 Mtetra
.586 .709 .928 r
.37429 .6467 .37984 .65221 .38885 .65406 .38343 .64551 Mtetra
.811 .694 .735 r
.38343 .64551 .38885 .65406 .39837 .64365 .39308 .63221 Mtetra
.365 .437 .802 r
.39308 .63221 .39837 .64365 .40755 .64264 .40205 .63707 Mtetra
.616 .718 .919 r
.40205 .63707 .40755 .64264 .41681 .64064 .41132 .63527 Mtetra
.627 .73 .922 r
.41132 .63527 .41681 .64064 .4261 .63872 .42063 .63321 Mtetra
.599 .717 .927 r
.42063 .63321 .4261 .63872 .43536 .6394 .42997 .63172 Mtetra
.858 .716 .705 r
.42997 .63172 .43536 .6394 .44491 .62964 .43978 .61261 Mtetra
.25 .287 .705 r
.43978 .61261 .44491 .62964 .45428 .62875 .44887 .62309 Mtetra
.619 .719 .918 r
.44887 .62309 .45428 .62875 .46371 .62655 .45832 .62119 Mtetra
.638 .737 .92 r
.45832 .62119 .46371 .62655 .47318 .62416 .46781 .61884 Mtetra
.64 .74 .921 r
.46781 .61884 .47318 .62416 .48268 .62178 .47733 .61641 Mtetra
.635 .737 .922 r
.47733 .61641 .48268 .62178 .49222 .61975 .48689 .6141 Mtetra
.588 .712 .929 r
.48689 .6141 .49222 .61975 .50175 .62372 .49648 .61279 Mtetra
.771 .657 .736 r
.49648 .61279 .50175 .62372 .51143 .61069 .50616 .60168 Mtetra
.478 .557 .857 r
.50616 .60168 .51143 .61069 .52106 .60911 .5158 .60349 Mtetra
.632 .729 .918 r
.5158 .60349 .52106 .60911 .53074 .60663 .52549 .60125 Mtetra
.647 .743 .92 r
.52549 .60125 .53074 .60663 .54045 .60394 .53523 .59861 Mtetra
.652 .748 .92 r
.53523 .59861 .54045 .60394 .55019 .60114 .54499 .59583 Mtetra
.655 .751 .92 r
.54499 .59583 .55019 .60114 .55997 .59827 .5548 .59297 Mtetra
.657 .752 .92 r
.5548 .59297 .55997 .59827 .56978 .59535 .56463 .59005 Mtetra
.658 .753 .92 r
.56463 .59005 .56978 .59535 .57963 .5924 .5745 .58709 Mtetra
.659 .754 .92 r
.5745 .58709 .57963 .5924 .58951 .58943 .58441 .58411 Mtetra
.58441 .58411 .58951 .58943 .59943 .58645 .59435 .5811 Mtetra
.59435 .5811 .59943 .58645 .60938 .58346 .60433 .57809 Mtetra
.60433 .57809 .60938 .58346 .61937 .58047 .61434 .57508 Mtetra
.658 .753 .92 r
.61434 .57508 .61937 .58047 .62939 .57748 .62438 .57206 Mtetra
.62438 .57206 .62939 .57748 .63945 .57448 .63447 .56904 Mtetra
.63447 .56904 .63945 .57448 .64954 .57147 .64459 .56601 Mtetra
.64459 .56601 .64954 .57147 .65968 .56846 .65474 .56298 Mtetra
.65474 .56298 .65968 .56846 .66984 .56543 .66493 .55993 Mtetra
.66493 .55993 .66984 .56543 .68005 .5624 .67516 .55688 Mtetra
.657 .753 .92 r
.67516 .55688 .68005 .5624 .69029 .55936 .68543 .55382 Mtetra
.68543 .55382 .69029 .55936 .70056 .55631 .69573 .55075 Mtetra
.69573 .55075 .70056 .55631 .71088 .55326 .70607 .54767 Mtetra
.70607 .54767 .71088 .55326 .72123 .55019 .71645 .54458 Mtetra
.71645 .54458 .72123 .55019 .73162 .54711 .72687 .54148 Mtetra
.657 .752 .92 r
.72687 .54148 .73162 .54711 .74205 .54402 .73732 .53837 Mtetra
.73732 .53837 .74205 .54402 .75251 .54092 .74781 .53525 Mtetra
.74781 .53525 .75251 .54092 .76302 .53781 .75834 .53212 Mtetra
.75834 .53212 .76302 .53781 .77356 .53469 .76891 .52898 Mtetra
.76891 .52898 .77356 .53469 .78414 .53156 .77952 .52583 Mtetra
.77952 .52583 .78414 .53156 .79476 .52842 .79017 .52267 Mtetra
.79017 .52267 .79476 .52842 .80542 .52527 .80086 .51949 Mtetra
.80086 .51949 .80542 .52527 .81612 .52211 .81158 .51631 Mtetra
.81158 .51631 .81612 .52211 .82685 .51893 .82235 .51311 Mtetra
.82235 .51311 .82685 .51893 .83763 .51575 .83316 .5099 Mtetra
.83316 .5099 .83763 .51575 .84845 .51255 .844 .50669 Mtetra
.844 .50669 .84845 .51255 .85931 .50934 .85489 .50346 Mtetra
.85489 .50346 .85931 .50934 .87021 .50612 .86582 .50021 Mtetra
.86582 .50021 .87021 .50612 .88114 .50289 .87678 .49696 Mtetra
.87678 .49696 .88114 .50289 .89212 .49965 .88779 .4937 Mtetra
.88779 .4937 .89212 .49965 .90314 .4964 .89885 .49042 Mtetra
.89885 .49042 .90314 .4964 .91421 .49313 .90994 .48713 Mtetra
.90994 .48713 .91421 .49313 .92531 .48985 .92107 .48383 Mtetra
.92107 .48383 .92531 .48985 .93646 .48656 .93225 .48052 Mtetra
.93225 .48052 .93646 .48656 .94764 .48326 .94347 .47719 Mtetra
.895 .71 .645 r
.34113 .65089 .34669 .65801 .35613 .64883 .35193 .61493 Mtetra
.025 .029 .523 r
.35193 .61493 .35613 .64883 .36515 .64846 .35956 .64278 Mtetra
.604 .71 .919 r
.35956 .64278 .36515 .64846 .37429 .6467 .36869 .64125 Mtetra
.612 .722 .924 r
.36869 .64125 .37429 .6467 .38343 .64551 .37788 .63953 Mtetra
.381 .605 .936 r
.37788 .63953 .38343 .64551 .39308 .63221 .38695 .64135 Mtetra
0 0 0 r
.38695 .64135 .39308 .63221 .40205 .63707 .39655 .63086 Mtetra
.583 .685 .911 r
.39655 .63086 .40205 .63707 .41132 .63527 .4058 .62982 Mtetra
.625 .728 .921 r
.4058 .62982 .41132 .63527 .42063 .63321 .41513 .62778 Mtetra
.621 .728 .923 r
.41513 .62778 .42063 .63321 .42997 .63172 .42449 .62581 Mtetra
.474 .653 .938 r
.42449 .62581 .42997 .63172 .43978 .61261 .43383 .62646 Mtetra
.151 0 .148 r
.43383 .62646 .43978 .61261 .44887 .62309 .44346 .61662 Mtetra
.578 .677 .907 r
.44346 .61662 .44887 .62309 .45832 .62119 .4529 .6157 Mtetra
.632 .732 .92 r
.4529 .6157 .45832 .62119 .46781 .61884 .4624 .61346 Mtetra
.64 .739 .921 r
.4624 .61346 .46781 .61884 .47733 .61641 .47195 .61103 Mtetra
.639 .739 .921 r
.47195 .61103 .47733 .61641 .48689 .6141 .48153 .6086 Mtetra
.624 .731 .924 r
.48153 .6086 .48689 .6141 .49648 .61279 .49114 .60652 Mtetra
.208 .499 .904 r
.49114 .60652 .49648 .61279 .50616 .60168 .50075 .61048 Mtetra
0 0 0 r
.50075 .61048 .50616 .60168 .5158 .60349 .5105 .59736 Mtetra
.606 .702 .912 r
.5105 .59736 .5158 .60349 .52549 .60125 .52022 .59574 Mtetra
.642 .739 .919 r
.52022 .59574 .52549 .60125 .53523 .59861 .52997 .59322 Mtetra
.65 .746 .92 r
.52997 .59322 .53523 .59861 .54499 .59583 .53976 .59047 Mtetra
.654 .749 .92 r
.53976 .59047 .54499 .59583 .5548 .59297 .54959 .58762 Mtetra
.656 .751 .92 r
.54959 .58762 .5548 .59297 .56463 .59005 .55945 .58471 Mtetra
.658 .753 .92 r
.55945 .58471 .56463 .59005 .5745 .58709 .56934 .58174 Mtetra
.659 .753 .92 r
.56934 .58174 .5745 .58709 .58441 .58411 .57927 .57874 Mtetra
.659 .754 .92 r
.57927 .57874 .58441 .58411 .59435 .5811 .58924 .57572 Mtetra
.58924 .57572 .59435 .5811 .60433 .57809 .59923 .57269 Mtetra
.59923 .57269 .60433 .57809 .61434 .57508 .60927 .56965 Mtetra
.658 .754 .92 r
.60927 .56965 .61434 .57508 .62438 .57206 .61934 .56661 Mtetra
.658 .753 .92 r
.61934 .56661 .62438 .57206 .63447 .56904 .62945 .56357 Mtetra
.62945 .56357 .63447 .56904 .64459 .56601 .63959 .56052 Mtetra
.63959 .56052 .64459 .56601 .65474 .56298 .64977 .55746 Mtetra
.64977 .55746 .65474 .56298 .66493 .55993 .65999 .5544 Mtetra
.65999 .5544 .66493 .55993 .67516 .55688 .67025 .55132 Mtetra
.67025 .55132 .67516 .55688 .68543 .55382 .68054 .54824 Mtetra
.657 .753 .92 r
.68054 .54824 .68543 .55382 .69573 .55075 .69087 .54515 Mtetra
.69087 .54515 .69573 .55075 .70607 .54767 .70123 .54205 Mtetra
.70123 .54205 .70607 .54767 .71645 .54458 .71164 .53894 Mtetra
.71164 .53894 .71645 .54458 .72687 .54148 .72208 .53582 Mtetra
.657 .752 .92 r
.72208 .53582 .72687 .54148 .73732 .53837 .73256 .53268 Mtetra
.73256 .53268 .73732 .53837 .74781 .53525 .74308 .52954 Mtetra
.74308 .52954 .74781 .53525 .75834 .53212 .75364 .52639 Mtetra
.75364 .52639 .75834 .53212 .76891 .52898 .76424 .52323 Mtetra
.76424 .52323 .76891 .52898 .77952 .52583 .77487 .52005 Mtetra
.77487 .52005 .77952 .52583 .79017 .52267 .78555 .51687 Mtetra
.78555 .51687 .79017 .52267 .80086 .51949 .79626 .51367 Mtetra
.79626 .51367 .80086 .51949 .81158 .51631 .80702 .51047 Mtetra
.80702 .51047 .81158 .51631 .82235 .51311 .81781 .50725 Mtetra
.81781 .50725 .82235 .51311 .83316 .5099 .82865 .50402 Mtetra
.82865 .50402 .83316 .5099 .844 .50669 .83952 .50078 Mtetra
.83952 .50078 .844 .50669 .85489 .50346 .85044 .49753 Mtetra
.85044 .49753 .85489 .50346 .86582 .50021 .8614 .49426 Mtetra
.8614 .49426 .86582 .50021 .87678 .49696 .8724 .49099 Mtetra
.8724 .49099 .87678 .49696 .88779 .4937 .88344 .4877 Mtetra
.88344 .4877 .88779 .4937 .89885 .49042 .89452 .4844 Mtetra
.89452 .4844 .89885 .49042 .90994 .48713 .90564 .48109 Mtetra
.90564 .48109 .90994 .48713 .92107 .48383 .91681 .47776 Mtetra
.91681 .47776 .92107 .48383 .93225 .48052 .92801 .47443 Mtetra
.92801 .47443 .93225 .48052 .94347 .47719 .93926 .47108 Mtetra
.494 .664 .938 r
.33546 .64508 .34113 .65089 .35193 .61493 .34446 .64539 Mtetra
.416 .152 .403 r
.34446 .64539 .35193 .61493 .35956 .64278 .35397 .63614 Mtetra
.555 .659 .906 r
.35397 .63614 .35956 .64278 .36869 .64125 .36307 .63574 Mtetra
.615 .721 .922 r
.36307 .63574 .36869 .64125 .37788 .63953 .37227 .63393 Mtetra
.586 .709 .928 r
.37227 .63393 .37788 .63953 .38695 .64135 .38148 .6327 Mtetra
.812 .694 .735 r
.38148 .6327 .38695 .64135 .39655 .63086 .39121 .61931 Mtetra
.364 .436 .802 r
.39121 .61931 .39655 .63086 .4058 .62982 .40025 .62416 Mtetra
.616 .718 .919 r
.40025 .62416 .4058 .62982 .41513 .62778 .40959 .62232 Mtetra
.627 .73 .922 r
.40959 .62232 .41513 .62778 .42449 .62581 .41898 .62022 Mtetra
.599 .717 .927 r
.41898 .62022 .42449 .62581 .43383 .62646 .42838 .61869 Mtetra
.858 .717 .705 r
.42838 .61869 .43383 .62646 .44346 .61662 .43828 .59946 Mtetra
.248 .285 .704 r
.43828 .59946 .44346 .61662 .4529 .6157 .44744 .60995 Mtetra
.619 .719 .918 r
.44744 .60995 .4529 .6157 .4624 .61346 .45696 .60801 Mtetra
.638 .737 .92 r
.45696 .60801 .4624 .61346 .47195 .61103 .46653 .60561 Mtetra
.64 .74 .921 r
.46653 .60561 .47195 .61103 .48153 .6086 .47613 .60314 Mtetra
.635 .737 .922 r
.47613 .60314 .48153 .6086 .49114 .60652 .48577 .60079 Mtetra
.589 .712 .928 r
.48577 .60079 .49114 .60652 .50075 .61048 .49543 .59944 Mtetra
.772 .657 .736 r
.49543 .59944 .50075 .61048 .5105 .59736 .50519 .58825 Mtetra
.478 .556 .857 r
.50519 .58825 .5105 .59736 .52022 .59574 .51491 .59003 Mtetra
.632 .729 .918 r
.51491 .59003 .52022 .59574 .52997 .59322 .52468 .58774 Mtetra
.647 .743 .92 r
.52468 .58774 .52997 .59322 .53976 .59047 .5345 .58505 Mtetra
.652 .748 .92 r
.5345 .58505 .53976 .59047 .54959 .58762 .54434 .58223 Mtetra
.655 .751 .92 r
.54434 .58223 .54959 .58762 .55945 .58471 .55423 .57932 Mtetra
.657 .752 .92 r
.55423 .57932 .55945 .58471 .56934 .58174 .56414 .57635 Mtetra
.658 .753 .92 r
.56414 .57635 .56934 .58174 .57927 .57874 .5741 .57334 Mtetra
.659 .754 .92 r
.5741 .57334 .57927 .57874 .58924 .57572 .58409 .57031 Mtetra
.58409 .57031 .58924 .57572 .59923 .57269 .59411 .56725 Mtetra
.59411 .56725 .59923 .57269 .60927 .56965 .60417 .56419 Mtetra
.60417 .56419 .60927 .56965 .61934 .56661 .61427 .56113 Mtetra
.658 .753 .92 r
.61427 .56113 .61934 .56661 .62945 .56357 .6244 .55806 Mtetra
.6244 .55806 .62945 .56357 .63959 .56052 .63457 .55499 Mtetra
.63457 .55499 .63959 .56052 .64977 .55746 .64477 .55191 Mtetra
.64477 .55191 .64977 .55746 .65999 .5544 .65502 .54882 Mtetra
.65502 .54882 .65999 .5544 .67025 .55132 .6653 .54573 Mtetra
.6653 .54573 .67025 .55132 .68054 .54824 .67561 .54262 Mtetra
.657 .753 .92 r
.67561 .54262 .68054 .54824 .69087 .54515 .68597 .53951 Mtetra
.68597 .53951 .69087 .54515 .70123 .54205 .69636 .53639 Mtetra
.69636 .53639 .70123 .54205 .71164 .53894 .70679 .53325 Mtetra
.70679 .53325 .71164 .53894 .72208 .53582 .71726 .53011 Mtetra
.71726 .53011 .72208 .53582 .73256 .53268 .72777 .52696 Mtetra
.657 .752 .92 r
.72777 .52696 .73256 .53268 .74308 .52954 .73832 .5238 Mtetra
.73832 .5238 .74308 .52954 .75364 .52639 .7489 .52062 Mtetra
.7489 .52062 .75364 .52639 .76424 .52323 .75953 .51744 Mtetra
.75953 .51744 .76424 .52323 .77487 .52005 .77019 .51424 Mtetra
.77019 .51424 .77487 .52005 .78555 .51687 .78089 .51103 Mtetra
.78089 .51103 .78555 .51687 .79626 .51367 .79164 .50782 Mtetra
.79164 .50782 .79626 .51367 .80702 .51047 .80242 .50459 Mtetra
.80242 .50459 .80702 .51047 .81781 .50725 .81324 .50135 Mtetra
.81324 .50135 .81781 .50725 .82865 .50402 .82411 .49809 Mtetra
.82411 .49809 .82865 .50402 .83952 .50078 .83501 .49483 Mtetra
.83501 .49483 .83952 .50078 .85044 .49753 .84596 .49156 Mtetra
.84596 .49156 .85044 .49753 .8614 .49426 .85695 .48827 Mtetra
.85695 .48827 .8614 .49426 .8724 .49099 .86798 .48497 Mtetra
.86798 .48497 .8724 .49099 .88344 .4877 .87905 .48166 Mtetra
.87905 .48166 .88344 .4877 .89452 .4844 .89016 .47834 Mtetra
.89016 .47834 .89452 .4844 .90564 .48109 .90131 .475 Mtetra
.90131 .475 .90564 .48109 .91681 .47776 .91251 .47165 Mtetra
.91251 .47165 .91681 .47776 .92801 .47443 .92375 .46829 Mtetra
.92375 .46829 .92801 .47443 .93926 .47108 .93503 .46492 Mtetra
.591 .711 .927 r
.32975 .63949 .33546 .64508 .34446 .64539 .33884 .63818 Mtetra
.896 .711 .644 r
.33884 .63818 .34446 .64539 .35397 .63614 .34976 .60203 Mtetra
.02 .025 .52 r
.34976 .60203 .35397 .63614 .36307 .63574 .35742 .62997 Mtetra
.604 .71 .919 r
.35742 .62997 .36307 .63574 .37227 .63393 .36662 .6284 Mtetra
.612 .722 .924 r
.36662 .6284 .37227 .63393 .38148 .6327 .37588 .62664 Mtetra
.382 .605 .936 r
.37588 .62664 .38148 .6327 .39121 .61931 .38502 .62843 Mtetra
0 0 0 r
.38502 .62843 .39121 .61931 .40025 .62416 .39469 .61786 Mtetra
.583 .685 .911 r
.39469 .61786 .40025 .62416 .40959 .62232 .40402 .61679 Mtetra
.625 .728 .921 r
.40402 .61679 .40959 .62232 .41898 .62022 .41343 .6147 Mtetra
.621 .728 .923 r
.41343 .6147 .41898 .62022 .42838 .61869 .42286 .61269 Mtetra
.474 .653 .938 r
.42286 .61269 .42838 .61869 .43828 .59946 .43227 .61331 Mtetra
.14 0 .138 r
.43227 .61331 .43828 .59946 .44744 .60995 .44198 .6034 Mtetra
.578 .677 .907 r
.44198 .6034 .44744 .60995 .45696 .60801 .45149 .60243 Mtetra
.632 .732 .92 r
.45149 .60243 .45696 .60801 .46653 .60561 .46107 .60015 Mtetra
.64 .739 .921 r
.46107 .60015 .46653 .60561 .47613 .60314 .47069 .59767 Mtetra
.639 .739 .921 r
.47069 .59767 .47613 .60314 .48577 .60079 .48035 .5952 Mtetra
.624 .731 .924 r
.48035 .5952 .48577 .60079 .49543 .59944 .49004 .59308 Mtetra
.211 .5 .905 r
.49004 .59308 .49543 .59944 .50519 .58825 .49973 .59702 Mtetra
0 0 0 r
.49973 .59702 .50519 .58825 .51491 .59003 .50957 .5838 Mtetra
.605 .702 .912 r
.50957 .5838 .51491 .59003 .52468 .58774 .51936 .58214 Mtetra
.642 .739 .919 r
.51936 .58214 .52468 .58774 .5345 .58505 .52919 .57957 Mtetra
.65 .746 .92 r
.52919 .57957 .5345 .58505 .54434 .58223 .53907 .57678 Mtetra
.654 .749 .92 r
.53907 .57678 .54434 .58223 .55423 .57932 .54897 .57388 Mtetra
.656 .751 .92 r
.54897 .57388 .55423 .57932 .56414 .57635 .55891 .57092 Mtetra
.658 .753 .92 r
.55891 .57092 .56414 .57635 .5741 .57334 .56889 .5679 Mtetra
.659 .753 .92 r
.56889 .5679 .5741 .57334 .58409 .57031 .5789 .56485 Mtetra
.659 .754 .92 r
.5789 .56485 .58409 .57031 .59411 .56725 .58895 .56178 Mtetra
.58895 .56178 .59411 .56725 .60417 .56419 .59904 .5587 Mtetra
.59904 .5587 .60417 .56419 .61427 .56113 .60916 .55561 Mtetra
.658 .754 .92 r
.60916 .55561 .61427 .56113 .6244 .55806 .61931 .55252 Mtetra
.658 .753 .92 r
.61931 .55252 .6244 .55806 .63457 .55499 .62951 .54942 Mtetra
.62951 .54942 .63457 .55499 .64477 .55191 .63974 .54632 Mtetra
.63974 .54632 .64477 .55191 .65502 .54882 .65001 .54321 Mtetra
.65001 .54321 .65502 .54882 .6653 .54573 .66031 .54009 Mtetra
.66031 .54009 .6653 .54573 .67561 .54262 .67066 .53697 Mtetra
.67066 .53697 .67561 .54262 .68597 .53951 .68104 .53383 Mtetra
.657 .753 .92 r
.68104 .53383 .68597 .53951 .69636 .53639 .69146 .53069 Mtetra
.69146 .53069 .69636 .53639 .70679 .53325 .70191 .52753 Mtetra
.70191 .52753 .70679 .53325 .71726 .53011 .71241 .52437 Mtetra
.71241 .52437 .71726 .53011 .72777 .52696 .72295 .52119 Mtetra
.657 .752 .92 r
.72295 .52119 .72777 .52696 .73832 .5238 .73352 .51801 Mtetra
.73352 .51801 .73832 .5238 .7489 .52062 .74413 .51481 Mtetra
.74413 .51481 .7489 .52062 .75953 .51744 .75478 .51161 Mtetra
.75478 .51161 .75953 .51744 .77019 .51424 .76548 .50839 Mtetra
.76548 .50839 .77019 .51424 .78089 .51103 .77621 .50516 Mtetra
.77621 .50516 .78089 .51103 .79164 .50782 .78698 .50192 Mtetra
.78698 .50192 .79164 .50782 .80242 .50459 .79779 .49867 Mtetra
.79779 .49867 .80242 .50459 .81324 .50135 .80865 .4954 Mtetra
.80865 .4954 .81324 .50135 .82411 .49809 .81954 .49213 Mtetra
.81954 .49213 .82411 .49809 .83501 .49483 .83047 .48884 Mtetra
.83047 .48884 .83501 .49483 .84596 .49156 .84145 .48554 Mtetra
.84145 .48554 .84596 .49156 .85695 .48827 .85247 .48223 Mtetra
.85247 .48223 .85695 .48827 .86798 .48497 .86352 .47891 Mtetra
.86352 .47891 .86798 .48497 .87905 .48166 .87462 .47558 Mtetra
.87462 .47558 .87905 .48166 .89016 .47834 .88577 .47223 Mtetra
.88577 .47223 .89016 .47834 .90131 .475 .89695 .46887 Mtetra
.89695 .46887 .90131 .475 .91251 .47165 .90818 .4655 Mtetra
.90818 .4655 .91251 .47165 .92375 .46829 .91945 .46212 Mtetra
.91945 .46212 .92375 .46829 .93503 .46492 .93077 .45872 Mtetra
.604 .715 .923 r
.324 .63388 .32975 .63949 .33884 .63818 .33313 .63228 Mtetra
.494 .664 .938 r
.33313 .63228 .33884 .63818 .34976 .60203 .34219 .63256 Mtetra
.411 .146 .398 r
.34219 .63256 .34976 .60203 .35742 .62997 .35178 .62324 Mtetra
.554 .659 .906 r
.35178 .62324 .35742 .62997 .36662 .6284 .36094 .6228 Mtetra
.615 .721 .922 r
.36094 .6228 .36662 .6284 .37588 .62664 .37022 .62095 Mtetra
.586 .709 .928 r
.37022 .62095 .37588 .62664 .38502 .62843 .3795 .61968 Mtetra
.812 .695 .735 r
.3795 .61968 .38502 .62843 .39469 .61786 .38931 .6062 Mtetra
.362 .435 .802 r
.38931 .6062 .39469 .61786 .40402 .61679 .39842 .61104 Mtetra
.616 .718 .919 r
.39842 .61104 .40402 .61679 .41343 .6147 .40784 .60916 Mtetra
.627 .73 .922 r
.40784 .60916 .41343 .6147 .42286 .61269 .4173 .60701 Mtetra
.599 .717 .927 r
.4173 .60701 .42286 .61269 .43227 .61331 .42678 .60544 Mtetra
.859 .717 .704 r
.42678 .60544 .43227 .61331 .44198 .6034 .43676 .5861 Mtetra
.245 .283 .704 r
.43676 .5861 .44198 .6034 .45149 .60243 .44599 .5966 Mtetra
.619 .719 .918 r
.44599 .5966 .45149 .60243 .46107 .60015 .45558 .59461 Mtetra
.638 .737 .92 r
.45558 .59461 .46107 .60015 .47069 .59767 .46523 .59217 Mtetra
.64 .74 .921 r
.46523 .59217 .47069 .59767 .48035 .5952 .47491 .58965 Mtetra
.635 .737 .922 r
.47491 .58965 .48035 .5952 .49004 .59308 .48462 .58726 Mtetra
.589 .711 .928 r
.48462 .58726 .49004 .59308 .49973 .59702 .49436 .58586 Mtetra
.772 .658 .736 r
.49436 .58586 .49973 .59702 .50957 .5838 .50421 .57458 Mtetra
.477 .556 .858 r
.50421 .57458 .50957 .5838 .51936 .58214 .514 .57634 Mtetra
.632 .729 .918 r
.514 .57634 .51936 .58214 .52919 .57957 .52386 .574 Mtetra
.647 .743 .92 r
.52386 .574 .52919 .57957 .53907 .57678 .53375 .57127 Mtetra
.652 .748 .92 r
.53375 .57127 .53907 .57678 .54897 .57388 .54368 .56839 Mtetra
.655 .751 .92 r
.54368 .56839 .54897 .57388 .55891 .57092 .55365 .56544 Mtetra
.657 .752 .92 r
.55365 .56544 .55891 .57092 .56889 .5679 .56365 .56242 Mtetra
.658 .753 .92 r
.56365 .56242 .56889 .5679 .5789 .56485 .57369 .55936 Mtetra
.659 .754 .92 r
.57369 .55936 .5789 .56485 .58895 .56178 .58376 .55627 Mtetra
.58376 .55627 .58895 .56178 .59904 .5587 .59387 .55317 Mtetra
.59387 .55317 .59904 .5587 .60916 .55561 .60401 .55006 Mtetra
.60401 .55006 .60916 .55561 .61931 .55252 .6142 .54694 Mtetra
.658 .753 .92 r
.6142 .54694 .61931 .55252 .62951 .54942 .62441 .54382 Mtetra
.62441 .54382 .62951 .54942 .63974 .54632 .63467 .54069 Mtetra
.63467 .54069 .63974 .54632 .65001 .54321 .64496 .53756 Mtetra
.64496 .53756 .65001 .54321 .66031 .54009 .6553 .53442 Mtetra
.6553 .53442 .66031 .54009 .67066 .53697 .66567 .53127 Mtetra
.66567 .53127 .67066 .53697 .68104 .53383 .67607 .52812 Mtetra
.657 .753 .92 r
.67607 .52812 .68104 .53383 .69146 .53069 .68652 .52495 Mtetra
.68652 .52495 .69146 .53069 .70191 .52753 .697 .52177 Mtetra
.697 .52177 .70191 .52753 .71241 .52437 .70753 .51859 Mtetra
.70753 .51859 .71241 .52437 .72295 .52119 .71809 .51539 Mtetra
.71809 .51539 .72295 .52119 .73352 .51801 .72869 .51218 Mtetra
.657 .752 .92 r
.72869 .51218 .73352 .51801 .74413 .51481 .73933 .50896 Mtetra
.73933 .50896 .74413 .51481 .75478 .51161 .75001 .50573 Mtetra
.75001 .50573 .75478 .51161 .76548 .50839 .76073 .50249 Mtetra
.76073 .50249 .76548 .50839 .77621 .50516 .77149 .49924 Mtetra
.77149 .49924 .77621 .50516 .78698 .50192 .78229 .49598 Mtetra
.78229 .49598 .78698 .50192 .79779 .49867 .79313 .49271 Mtetra
.79313 .49271 .79779 .49867 .80865 .4954 .80401 .48942 Mtetra
.80401 .48942 .80865 .4954 .81954 .49213 .81494 .48612 Mtetra
.81494 .48612 .81954 .49213 .83047 .48884 .8259 .48281 Mtetra
.8259 .48281 .83047 .48884 .84145 .48554 .83691 .47949 Mtetra
.83691 .47949 .84145 .48554 .85247 .48223 .84795 .47616 Mtetra
.84795 .47616 .85247 .48223 .86352 .47891 .85904 .47281 Mtetra
.85904 .47281 .86352 .47891 .87462 .47558 .87017 .46945 Mtetra
.87017 .46945 .87462 .47558 .88577 .47223 .88135 .46608 Mtetra
.88135 .46608 .88577 .47223 .89695 .46887 .89256 .4627 Mtetra
.89256 .4627 .89695 .46887 .90818 .4655 .90382 .4593 Mtetra
.90382 .4593 .90818 .4655 .91945 .46212 .91512 .4559 Mtetra
.91512 .4559 .91945 .46212 .93077 .45872 .92647 .45248 Mtetra
.594 .703 .919 r
.31824 .62799 .324 .63388 .33313 .63228 .32736 .62661 Mtetra
.591 .711 .927 r
.32736 .62661 .33313 .63228 .34219 .63256 .33652 .62525 Mtetra
.897 .712 .643 r
.33652 .62525 .34219 .63256 .35178 .62324 .34754 .58892 Mtetra
.014 .02 .518 r
.34754 .58892 .35178 .62324 .36094 .6228 .35524 .61694 Mtetra
.604 .71 .919 r
.35524 .61694 .36094 .6228 .37022 .62095 .36452 .61534 Mtetra
.612 .722 .924 r
.36452 .61534 .37022 .62095 .3795 .61968 .37385 .61353 Mtetra
.383 .605 .936 r
.37385 .61353 .3795 .61968 .38931 .6062 .38306 .6153 Mtetra
0 0 0 r
.38306 .6153 .38931 .6062 .39842 .61104 .39281 .60465 Mtetra
.583 .685 .912 r
.39281 .60465 .39842 .61104 .40784 .60916 .40221 .60354 Mtetra
.625 .728 .921 r
.40221 .60354 .40784 .60916 .4173 .60701 .41169 .60141 Mtetra
.621 .728 .923 r
.41169 .60141 .4173 .60701 .42678 .60544 .4212 .59936 Mtetra
.475 .653 .938 r
.4212 .59936 .42678 .60544 .43676 .5861 .43068 .59994 Mtetra
.129 0 .127 r
.43068 .59994 .43676 .5861 .44599 .5966 .44047 .58995 Mtetra
.578 .677 .908 r
.44047 .58995 .44599 .5966 .45558 .59461 .45006 .58895 Mtetra
.632 .732 .92 r
.45006 .58895 .45558 .59461 .46523 .59217 .45972 .58662 Mtetra
.64 .739 .921 r
.45972 .58662 .46523 .59217 .47491 .58965 .46942 .58409 Mtetra
.639 .739 .921 r
.46942 .58409 .47491 .58965 .48462 .58726 .47916 .58158 Mtetra
.624 .731 .924 r
.47916 .58158 .48462 .58726 .49436 .58586 .48893 .57941 Mtetra
.213 .501 .905 r
.48893 .57941 .49436 .58586 .50421 .57458 .49869 .58333 Mtetra
0 0 0 r
.49869 .58333 .50421 .57458 .514 .57634 .50861 .57002 Mtetra
.605 .703 .912 r
.50861 .57002 .514 .57634 .52386 .574 .51849 .56831 Mtetra
.642 .739 .919 r
.51849 .56831 .52386 .574 .53375 .57127 .5284 .56569 Mtetra
.65 .746 .92 r
.5284 .56569 .53375 .57127 .54368 .56839 .53836 .56285 Mtetra
.654 .749 .92 r
.53836 .56285 .54368 .56839 .55365 .56544 .54835 .55991 Mtetra
.656 .751 .92 r
.54835 .55991 .55365 .56544 .56365 .56242 .55837 .55689 Mtetra
.658 .753 .92 r
.55837 .55689 .56365 .56242 .57369 .55936 .56843 .55382 Mtetra
.659 .753 .92 r
.56843 .55382 .57369 .55936 .58376 .55627 .57853 .55072 Mtetra
.659 .754 .92 r
.57853 .55072 .58376 .55627 .59387 .55317 .58866 .5476 Mtetra
.58866 .5476 .59387 .55317 .60401 .55006 .59883 .54447 Mtetra
.59883 .54447 .60401 .55006 .6142 .54694 .60904 .54133 Mtetra
.658 .754 .92 r
.60904 .54133 .6142 .54694 .62441 .54382 .61929 .53818 Mtetra
.658 .753 .92 r
.61929 .53818 .62441 .54382 .63467 .54069 .62957 .53503 Mtetra
.62957 .53503 .63467 .54069 .64496 .53756 .63989 .53188 Mtetra
.63989 .53188 .64496 .53756 .6553 .53442 .65025 .52871 Mtetra
.65025 .52871 .6553 .53442 .66567 .53127 .66064 .52554 Mtetra
.66064 .52554 .66567 .53127 .67607 .52812 .67107 .52236 Mtetra
.67107 .52236 .67607 .52812 .68652 .52495 .68155 .51917 Mtetra
.657 .753 .92 r
.68155 .51917 .68652 .52495 .697 .52177 .69206 .51598 Mtetra
.69206 .51598 .697 .52177 .70753 .51859 .70261 .51277 Mtetra
.70261 .51277 .70753 .51859 .71809 .51539 .7132 .50955 Mtetra
.7132 .50955 .71809 .51539 .72869 .51218 .72383 .50632 Mtetra
.657 .752 .92 r
.72383 .50632 .72869 .51218 .73933 .50896 .73449 .50308 Mtetra
.73449 .50308 .73933 .50896 .75001 .50573 .7452 .49982 Mtetra
.7452 .49982 .75001 .50573 .76073 .50249 .75595 .49656 Mtetra
.75595 .49656 .76073 .50249 .77149 .49924 .76674 .49329 Mtetra
.76674 .49329 .77149 .49924 .78229 .49598 .77757 .49 Mtetra
.77757 .49 .78229 .49598 .79313 .49271 .78844 .4867 Mtetra
.78844 .4867 .79313 .49271 .80401 .48942 .79935 .48339 Mtetra
.79935 .48339 .80401 .48942 .81494 .48612 .8103 .48007 Mtetra
.8103 .48007 .81494 .48612 .8259 .48281 .8213 .47674 Mtetra
.8213 .47674 .8259 .48281 .83691 .47949 .83233 .47339 Mtetra
.83233 .47339 .83691 .47949 .84795 .47616 .84341 .47004 Mtetra
.84341 .47004 .84795 .47616 .85904 .47281 .85453 .46667 Mtetra
.85453 .46667 .85904 .47281 .87017 .46945 .86569 .46328 Mtetra
.86569 .46328 .87017 .46945 .88135 .46608 .87689 .45989 Mtetra
.87689 .45989 .88135 .46608 .89256 .4627 .88814 .45648 Mtetra
.88814 .45648 .89256 .4627 .90382 .4593 .89943 .45306 Mtetra
.89943 .45306 .90382 .4593 .91512 .4559 .91077 .44963 Mtetra
.91077 .44963 .91512 .4559 .92647 .45248 .92215 .44619 Mtetra
.531 .638 .901 r
.31251 .62087 .31824 .62799 .32736 .62661 .32156 .62091 Mtetra
.604 .715 .923 r
.32156 .62091 .32736 .62661 .33652 .62525 .33075 .61927 Mtetra
.495 .664 .937 r
.33075 .61927 .33652 .62525 .34754 .58892 .33988 .61952 Mtetra
.406 .139 .392 r
.33988 .61952 .34754 .58892 .35524 .61694 .34955 .61012 Mtetra
.554 .659 .906 r
.34955 .61012 .35524 .61694 .36452 .61534 .35879 .60965 Mtetra
.615 .721 .922 r
.35879 .60965 .36452 .61534 .37385 .61353 .36813 .60776 Mtetra
.586 .709 .928 r
.36813 .60776 .37385 .61353 .38306 .6153 .37749 .60645 Mtetra
.813 .696 .736 r
.37749 .60645 .38306 .6153 .39281 .60465 .38739 .59288 Mtetra
.361 .435 .802 r
.38739 .59288 .39281 .60465 .40221 .60354 .39656 .5977 Mtetra
.616 .719 .919 r
.39656 .5977 .40221 .60354 .41169 .60141 .40605 .59578 Mtetra
.627 .73 .922 r
.40605 .59578 .41169 .60141 .4212 .59936 .41559 .59359 Mtetra
.599 .717 .927 r
.41559 .59359 .4212 .59936 .43068 .59994 .42514 .59198 Mtetra
.86 .718 .704 r
.42514 .59198 .43068 .59994 .44047 .58995 .43521 .57251 Mtetra
.242 .281 .703 r
.43521 .57251 .44047 .58995 .45006 .58895 .44451 .58302 Mtetra
.619 .719 .918 r
.44451 .58302 .45006 .58895 .45972 .58662 .45418 .58099 Mtetra
.638 .737 .92 r
.45418 .58099 .45972 .58662 .46942 .58409 .4639 .5785 Mtetra
.64 .74 .921 r
.4639 .5785 .46942 .58409 .47916 .58158 .47366 .57594 Mtetra
.635 .737 .922 r
.47366 .57594 .47916 .58158 .48893 .57941 .48346 .57349 Mtetra
.589 .711 .928 r
.48346 .57349 .48893 .57941 .49869 .58333 .49328 .57206 Mtetra
.773 .658 .736 r
.49328 .57206 .49869 .58333 .50861 .57002 .50321 .56069 Mtetra
.477 .556 .858 r
.50321 .56069 .50861 .57002 .51849 .56831 .51308 .56242 Mtetra
.632 .729 .918 r
.51308 .56242 .51849 .56831 .5284 .56569 .52302 .56003 Mtetra
.647 .743 .92 r
.52302 .56003 .5284 .56569 .53836 .56285 .533 .55725 Mtetra
.652 .748 .92 r
.533 .55725 .53836 .56285 .54835 .55991 .54301 .55433 Mtetra
.655 .751 .92 r
.54301 .55433 .54835 .55991 .55837 .55689 .55306 .55132 Mtetra
.657 .752 .92 r
.55306 .55132 .55837 .55689 .56843 .55382 .56314 .54825 Mtetra
.658 .753 .92 r
.56314 .54825 .56843 .55382 .57853 .55072 .57327 .54513 Mtetra
.659 .754 .92 r
.57327 .54513 .57853 .55072 .58866 .5476 .58343 .54199 Mtetra
.58343 .54199 .58866 .5476 .59883 .54447 .59362 .53884 Mtetra
.59362 .53884 .59883 .54447 .60904 .54133 .60385 .53568 Mtetra
.60385 .53568 .60904 .54133 .61929 .53818 .61412 .53251 Mtetra
.658 .753 .92 r
.61412 .53251 .61929 .53818 .62957 .53503 .62443 .52933 Mtetra
.62443 .52933 .62957 .53503 .63989 .53188 .63478 .52615 Mtetra
.63478 .52615 .63989 .53188 .65025 .52871 .64516 .52297 Mtetra
.64516 .52297 .65025 .52871 .66064 .52554 .65558 .51977 Mtetra
.65558 .51977 .66064 .52554 .67107 .52236 .66604 .51657 Mtetra
.66604 .51657 .67107 .52236 .68155 .51917 .67654 .51336 Mtetra
.657 .753 .92 r
.67654 .51336 .68155 .51917 .69206 .51598 .68708 .51014 Mtetra
.68708 .51014 .69206 .51598 .70261 .51277 .69766 .5069 Mtetra
.69766 .5069 .70261 .51277 .7132 .50955 .70827 .50366 Mtetra
.70827 .50366 .7132 .50955 .72383 .50632 .71893 .50041 Mtetra
.71893 .50041 .72383 .50632 .73449 .50308 .72963 .49715 Mtetra
.657 .752 .92 r
.72963 .49715 .73449 .50308 .7452 .49982 .74036 .49387 Mtetra
.74036 .49387 .7452 .49982 .75595 .49656 .75114 .49058 Mtetra
.75114 .49058 .75595 .49656 .76674 .49329 .76196 .48729 Mtetra
.76196 .48729 .76674 .49329 .77757 .49 .77281 .48398 Mtetra
.77281 .48398 .77757 .49 .78844 .4867 .78371 .48066 Mtetra
.78371 .48066 .78844 .4867 .79935 .48339 .79465 .47732 Mtetra
.79465 .47732 .79935 .48339 .8103 .48007 .80563 .47398 Mtetra
.80563 .47398 .8103 .48007 .8213 .47674 .81666 .47062 Mtetra
.81666 .47062 .8213 .47674 .83233 .47339 .82772 .46725 Mtetra
.82772 .46725 .83233 .47339 .84341 .47004 .83883 .46387 Mtetra
.83883 .46387 .84341 .47004 .85453 .46667 .84998 .46048 Mtetra
.84998 .46048 .85453 .46667 .86569 .46328 .86117 .45707 Mtetra
.86117 .45707 .86569 .46328 .87689 .45989 .87241 .45365 Mtetra
.87241 .45365 .87689 .45989 .88814 .45648 .88369 .45022 Mtetra
.88369 .45022 .88814 .45648 .89943 .45306 .89501 .44678 Mtetra
.89501 .44678 .89943 .45306 .91077 .44963 .90638 .44332 Mtetra
.90638 .44332 .91077 .44963 .92215 .44619 .91779 .43985 Mtetra
0 0 .163 r
.30033 .71481 .31251 .62087 .32156 .62091 .31574 .61493 Mtetra
.594 .703 .919 r
.31574 .61493 .32156 .62091 .33075 .61927 .32493 .61352 Mtetra
.591 .711 .927 r
.32493 .61352 .33075 .61927 .33988 .61952 .33416 .61212 Mtetra
.898 .712 .642 r
.33416 .61212 .33988 .61952 .34955 .61012 .34529 .5756 Mtetra
.009 .016 .515 r
.34529 .5756 .34955 .61012 .35879 .60965 .35303 .6037 Mtetra
.604 .71 .919 r
.35303 .6037 .35879 .60965 .36813 .60776 .36238 .60206 Mtetra
.612 .722 .924 r
.36238 .60206 .36813 .60776 .37749 .60645 .37178 .60021 Mtetra
.384 .606 .936 r
.37178 .60021 .37749 .60645 .38739 .59288 .38107 .60195 Mtetra
0 0 0 r
.38107 .60195 .38739 .59288 .39656 .5977 .3909 .59122 Mtetra
.583 .685 .912 r
.3909 .59122 .39656 .5977 .40605 .59578 .40038 .59007 Mtetra
.625 .728 .921 r
.40038 .59007 .40605 .59578 .41559 .59359 .40993 .58789 Mtetra
.621 .728 .923 r
.40993 .58789 .41559 .59359 .42514 .59198 .41952 .5858 Mtetra
.475 .653 .937 r
.41952 .5858 .42514 .59198 .43521 .57251 .42907 .58635 Mtetra
.118 0 .116 r
.42907 .58635 .43521 .57251 .44451 .58302 .43894 .57628 Mtetra
.578 .677 .908 r
.43894 .57628 .44451 .58302 .45418 .58099 .44861 .57523 Mtetra
.632 .732 .92 r
.44861 .57523 .45418 .58099 .4639 .5785 .45835 .57286 Mtetra
.64 .739 .921 r
.45835 .57286 .4639 .5785 .47366 .57594 .46813 .57028 Mtetra
.639 .739 .921 r
.46813 .57028 .47366 .57594 .48346 .57349 .47794 .56772 Mtetra
.624 .731 .924 r
.47794 .56772 .48346 .57349 .49328 .57206 .4878 .5655 Mtetra
.216 .502 .905 r
.4878 .5655 .49328 .57206 .50321 .56069 .49764 .5694 Mtetra
0 0 0 r
.49764 .5694 .50321 .56069 .51308 .56242 .50764 .556 Mtetra
.605 .703 .913 r
.50764 .556 .51308 .56242 .52302 .56003 .5176 .55425 Mtetra
.642 .739 .919 r
.5176 .55425 .52302 .56003 .533 .55725 .5276 .55158 Mtetra
.65 .746 .92 r
.5276 .55158 .533 .55725 .54301 .55433 .53764 .54869 Mtetra
.654 .749 .92 r
.53764 .54869 .54301 .55433 .55306 .55132 .54771 .54569 Mtetra
.656 .751 .92 r
.54771 .54569 .55306 .55132 .56314 .54825 .55782 .54262 Mtetra
.658 .753 .92 r
.55782 .54262 .56314 .54825 .57327 .54513 .56797 .5395 Mtetra
.659 .753 .92 r
.56797 .5395 .57327 .54513 .58343 .54199 .57815 .53635 Mtetra
.659 .754 .92 r
.57815 .53635 .58343 .54199 .59362 .53884 .58837 .53317 Mtetra
.58837 .53317 .59362 .53884 .60385 .53568 .59863 .52999 Mtetra
.59863 .52999 .60385 .53568 .61412 .53251 .60892 .52679 Mtetra
.658 .754 .92 r
.60892 .52679 .61412 .53251 .62443 .52933 .61926 .5236 Mtetra
.658 .753 .92 r
.61926 .5236 .62443 .52933 .63478 .52615 .62963 .52039 Mtetra
.62963 .52039 .63478 .52615 .64516 .52297 .64004 .51718 Mtetra
.64004 .51718 .64516 .52297 .65558 .51977 .65049 .51396 Mtetra
.65049 .51396 .65558 .51977 .66604 .51657 .66097 .51074 Mtetra
.66097 .51074 .66604 .51657 .67654 .51336 .6715 .5075 Mtetra
.6715 .5075 .67654 .51336 .68708 .51014 .68206 .50426 Mtetra
.657 .753 .92 r
.68206 .50426 .68708 .51014 .69766 .5069 .69267 .501 Mtetra
.69267 .501 .69766 .5069 .70827 .50366 .70331 .49774 Mtetra
.70331 .49774 .70827 .50366 .71893 .50041 .714 .49446 Mtetra
.714 .49446 .71893 .50041 .72963 .49715 .72472 .49118 Mtetra
.657 .752 .92 r
.72472 .49118 .72963 .49715 .74036 .49387 .73549 .48788 Mtetra
.73549 .48788 .74036 .49387 .75114 .49058 .74629 .48457 Mtetra
.74629 .48457 .75114 .49058 .76196 .48729 .75714 .48125 Mtetra
.75714 .48125 .76196 .48729 .77281 .48398 .76802 .47791 Mtetra
.76802 .47791 .77281 .48398 .78371 .48066 .77895 .47457 Mtetra
.77895 .47457 .78371 .48066 .79465 .47732 .78992 .47121 Mtetra
.78992 .47121 .79465 .47732 .80563 .47398 .80093 .46784 Mtetra
.80093 .46784 .80563 .47398 .81666 .47062 .81199 .46446 Mtetra
.81199 .46446 .81666 .47062 .82772 .46725 .82308 .46107 Mtetra
.82308 .46107 .82772 .46725 .83883 .46387 .83422 .45767 Mtetra
.83422 .45767 .83883 .46387 .84998 .46048 .8454 .45425 Mtetra
.8454 .45425 .84998 .46048 .86117 .45707 .85663 .45082 Mtetra
.85663 .45082 .86117 .45707 .87241 .45365 .86789 .44737 Mtetra
.86789 .44737 .87241 .45365 .88369 .45022 .87921 .44392 Mtetra
.87921 .44392 .88369 .45022 .89501 .44678 .89056 .44045 Mtetra
.89056 .44045 .89501 .44678 .90638 .44332 .90196 .43697 Mtetra
.90196 .43697 .90638 .44332 .91779 .43985 .9134 .43347 Mtetra
.594 .397 .584 r
.30028 .61699 .30033 .71481 .31574 .61493 .30995 .60772 Mtetra
.531 .638 .901 r
.30995 .60772 .31574 .61493 .32493 .61352 .31907 .60773 Mtetra
.604 .715 .923 r
.31907 .60773 .32493 .61352 .33416 .61212 .32834 .60605 Mtetra
.495 .664 .937 r
.32834 .60605 .33416 .61212 .34529 .5756 .33754 .60627 Mtetra
.401 .132 .387 r
.33754 .60627 .34529 .5756 .35303 .6037 .34729 .59679 Mtetra
.554 .659 .906 r
.34729 .59679 .35303 .6037 .36238 .60206 .35659 .59628 Mtetra
.615 .721 .922 r
.35659 .59628 .36238 .60206 .37178 .60021 .36601 .59435 Mtetra
.586 .709 .928 r
.36601 .59435 .37178 .60021 .38107 .60195 .37545 .593 Mtetra
.814 .696 .736 r
.37545 .593 .38107 .60195 .3909 .59122 .38542 .57933 Mtetra
.36 .434 .802 r
.38542 .57933 .3909 .59122 .40038 .59007 .39467 .58414 Mtetra
.616 .719 .919 r
.39467 .58414 .40038 .59007 .40993 .58789 .40423 .58217 Mtetra
.627 .73 .922 r
.40423 .58217 .40993 .58789 .41952 .5858 .41385 .57993 Mtetra
.599 .717 .927 r
.41385 .57993 .41952 .5858 .42907 .58635 .42348 .57828 Mtetra
.861 .719 .704 r
.42348 .57828 .42907 .58635 .43894 .57628 .43364 .55869 Mtetra
.24 .279 .702 r
.43364 .55869 .43894 .57628 .44861 .57523 .44301 .56921 Mtetra
.619 .719 .918 r
.44301 .56921 .44861 .57523 .45835 .57286 .45276 .56714 Mtetra
.638 .737 .92 r
.45276 .56714 .45835 .57286 .46813 .57028 .46256 .5646 Mtetra
.64 .74 .921 r
.46256 .5646 .46813 .57028 .47794 .56772 .4724 .56199 Mtetra
.635 .737 .922 r
.4724 .56199 .47794 .56772 .4878 .5655 .48227 .5595 Mtetra
.589 .711 .928 r
.48227 .5595 .4878 .5655 .49764 .5694 .49218 .55801 Mtetra
.773 .659 .736 r
.49218 .55801 .49764 .5694 .50764 .556 .50219 .54656 Mtetra
.476 .556 .858 r
.50219 .54656 .50764 .556 .5176 .55425 .51214 .54826 Mtetra
.632 .729 .918 r
.51214 .54826 .5176 .55425 .5276 .55158 .52217 .54582 Mtetra
.647 .743 .92 r
.52217 .54582 .5276 .55158 .53764 .54869 .53223 .54299 Mtetra
.652 .748 .92 r
.53223 .54299 .53764 .54869 .54771 .54569 .54232 .54001 Mtetra
.655 .751 .92 r
.54232 .54001 .54771 .54569 .55782 .54262 .55246 .53695 Mtetra
.657 .752 .92 r
.55246 .53695 .55782 .54262 .56797 .5395 .56263 .53383 Mtetra
.658 .753 .92 r
.56263 .53383 .56797 .5395 .57815 .53635 .57284 .53066 Mtetra
.659 .754 .92 r
.57284 .53066 .57815 .53635 .58837 .53317 .58309 .52747 Mtetra
.58309 .52747 .58837 .53317 .59863 .52999 .59337 .52426 Mtetra
.59337 .52426 .59863 .52999 .60892 .52679 .60369 .52104 Mtetra
.60369 .52104 .60892 .52679 .61926 .5236 .61405 .51782 Mtetra
.658 .753 .92 r
.61405 .51782 .61926 .5236 .62963 .52039 .62445 .51459 Mtetra
.62445 .51459 .62963 .52039 .64004 .51718 .63488 .51136 Mtetra
.63488 .51136 .64004 .51718 .65049 .51396 .64536 .50812 Mtetra
.64536 .50812 .65049 .51396 .66097 .51074 .65587 .50487 Mtetra
.65587 .50487 .66097 .51074 .6715 .5075 .66642 .50161 Mtetra
.66642 .50161 .6715 .5075 .68206 .50426 .67702 .49834 Mtetra
.657 .753 .92 r
.67702 .49834 .68206 .50426 .69267 .501 .68765 .49506 Mtetra
.68765 .49506 .69267 .501 .70331 .49774 .69832 .49177 Mtetra
.69832 .49177 .70331 .49774 .714 .49446 .70903 .48847 Mtetra
.70903 .48847 .714 .49446 .72472 .49118 .71978 .48516 Mtetra
.71978 .48516 .72472 .49118 .73549 .48788 .73058 .48184 Mtetra
.657 .752 .92 r
.73058 .48184 .73549 .48788 .74629 .48457 .74141 .47851 Mtetra
.74141 .47851 .74629 .48457 .75714 .48125 .75229 .47516 Mtetra
.75229 .47516 .75714 .48125 .76802 .47791 .7632 .47181 Mtetra
.7632 .47181 .76802 .47791 .77895 .47457 .77416 .46844 Mtetra
.77416 .46844 .77895 .47457 .78992 .47121 .78516 .46506 Mtetra
.78516 .46506 .78992 .47121 .80093 .46784 .7962 .46167 Mtetra
.7962 .46167 .80093 .46784 .81199 .46446 .80728 .45826 Mtetra
.80728 .45826 .81199 .46446 .82308 .46107 .81841 .45484 Mtetra
.81841 .45484 .82308 .46107 .83422 .45767 .82958 .45141 Mtetra
.82958 .45141 .83422 .45767 .8454 .45425 .84079 .44797 Mtetra
.84079 .44797 .8454 .45425 .85663 .45082 .85205 .44452 Mtetra
.85205 .44452 .85663 .45082 .86789 .44737 .86335 .44105 Mtetra
.86335 .44105 .86789 .44737 .87921 .44392 .87469 .43757 Mtetra
.87469 .43757 .87921 .44392 .89056 .44045 .88608 .43408 Mtetra
.88608 .43408 .89056 .44045 .90196 .43697 .89751 .43057 Mtetra
.89751 .43057 .90196 .43697 .9134 .43347 .90898 .42705 Mtetra
.947 .661 .465 r
.29442 .60994 .30028 .61699 .30995 .60772 .29759 .70204 Mtetra
0 0 .156 r
.29759 .70204 .30995 .60772 .31907 .60773 .3132 .60166 Mtetra
.594 .703 .919 r
.3132 .60166 .31907 .60773 .32834 .60605 .32246 .6002 Mtetra
.591 .711 .927 r
.32246 .6002 .32834 .60605 .33754 .60627 .33177 .59877 Mtetra
.899 .713 .642 r
.33177 .59877 .33754 .60627 .34729 .59679 .34301 .56205 Mtetra
.003 .011 .512 r
.34301 .56205 .34729 .59679 .35659 .59628 .35078 .59024 Mtetra
.604 .71 .919 r
.35078 .59024 .35659 .59628 .36601 .59435 .36021 .58855 Mtetra
.612 .722 .924 r
.36021 .58855 .36601 .59435 .37545 .593 .36968 .58666 Mtetra
.385 .606 .936 r
.36968 .58666 .37545 .593 .38542 .57933 .37904 .58838 Mtetra
0 0 0 r
.37904 .58838 .38542 .57933 .39467 .58414 .38895 .57757 Mtetra
.583 .685 .912 r
.38895 .57757 .39467 .58414 .40423 .58217 .39851 .57637 Mtetra
.625 .728 .921 r
.39851 .57637 .40423 .58217 .41385 .57993 .40813 .57415 Mtetra
.621 .728 .923 r
.40813 .57415 .41385 .57993 .42348 .57828 .4178 .57201 Mtetra
.476 .653 .937 r
.4178 .57201 .42348 .57828 .43364 .55869 .42743 .57253 Mtetra
.107 0 .105 r
.42743 .57253 .43364 .55869 .44301 .56921 .43739 .56237 Mtetra
.578 .677 .908 r
.43739 .56237 .44301 .56921 .45276 .56714 .44713 .56129 Mtetra
.632 .732 .92 r
.44713 .56129 .45276 .56714 .46256 .5646 .45695 .55887 Mtetra
.64 .739 .921 r
.45695 .55887 .46256 .5646 .4724 .56199 .46681 .55624 Mtetra
.639 .739 .921 r
.46681 .55624 .4724 .56199 .48227 .5595 .47671 .55363 Mtetra
.624 .731 .923 r
.47671 .55363 .48227 .5595 .49218 .55801 .48664 .55136 Mtetra
.219 .503 .906 r
.48664 .55136 .49218 .55801 .50219 .54656 .49656 .55524 Mtetra
0 0 0 r
.49656 .55524 .50219 .54656 .51214 .54826 .50666 .54174 Mtetra
.605 .703 .913 r
.50666 .54174 .51214 .54826 .52217 .54582 .5167 .53994 Mtetra
.642 .739 .919 r
.5167 .53994 .52217 .54582 .53223 .54299 .52678 .53722 Mtetra
.65 .746 .92 r
.52678 .53722 .53223 .54299 .54232 .54001 .5369 .53428 Mtetra
.654 .749 .92 r
.5369 .53428 .54232 .54001 .55246 .53695 .54706 .53123 Mtetra
.656 .751 .92 r
.54706 .53123 .55246 .53695 .56263 .53383 .55726 .52811 Mtetra
.658 .753 .92 r
.55726 .52811 .56263 .53383 .57284 .53066 .56749 .52494 Mtetra
.659 .753 .92 r
.56749 .52494 .57284 .53066 .58309 .52747 .57776 .52173 Mtetra
.659 .754 .92 r
.57776 .52173 .58309 .52747 .59337 .52426 .58807 .5185 Mtetra
.58807 .5185 .59337 .52426 .60369 .52104 .59842 .51526 Mtetra
.59842 .51526 .60369 .52104 .61405 .51782 .60881 .51201 Mtetra
.658 .754 .92 r
.60881 .51201 .61405 .51782 .62445 .51459 .61923 .50875 Mtetra
.658 .753 .92 r
.61923 .50875 .62445 .51459 .63488 .51136 .62969 .50549 Mtetra
.62969 .50549 .63488 .51136 .64536 .50812 .64019 .50223 Mtetra
.64019 .50223 .64536 .50812 .65587 .50487 .65073 .49895 Mtetra
.65073 .49895 .65587 .50487 .66642 .50161 .66131 .49567 Mtetra
.66131 .49567 .66642 .50161 .67702 .49834 .67193 .49238 Mtetra
.67193 .49238 .67702 .49834 .68765 .49506 .68259 .48908 Mtetra
.657 .753 .92 r
.68259 .48908 .68765 .49506 .69832 .49177 .69329 .48577 Mtetra
.69329 .48577 .69832 .49177 .70903 .48847 .70403 .48244 Mtetra
.70403 .48244 .70903 .48847 .71978 .48516 .71481 .47911 Mtetra
.71481 .47911 .71978 .48516 .73058 .48184 .72563 .47576 Mtetra
.657 .752 .92 r
.72563 .47576 .73058 .48184 .74141 .47851 .7365 .47241 Mtetra
.7365 .47241 .74141 .47851 .75229 .47516 .7474 .46904 Mtetra
.7474 .46904 .75229 .47516 .7632 .47181 .75835 .46566 Mtetra
.75835 .46566 .7632 .47181 .77416 .46844 .76933 .46227 Mtetra
.76933 .46227 .77416 .46844 .78516 .46506 .78036 .45886 Mtetra
.78036 .45886 .78516 .46506 .7962 .46167 .79143 .45544 Mtetra
.79143 .45544 .7962 .46167 .80728 .45826 .80255 .45201 Mtetra
.80255 .45201 .80728 .45826 .81841 .45484 .8137 .44857 Mtetra
.8137 .44857 .81841 .45484 .82958 .45141 .8249 .44512 Mtetra
.8249 .44512 .82958 .45141 .84079 .44797 .83615 .44165 Mtetra
.83615 .44165 .84079 .44797 .85205 .44452 .84743 .43817 Mtetra
.84743 .43817 .85205 .44452 .86335 .44105 .85877 .43468 Mtetra
.85877 .43468 .86335 .44105 .87469 .43757 .87014 .43117 Mtetra
.87014 .43117 .87469 .43757 .88608 .43408 .88156 .42765 Mtetra
.88156 .42765 .88608 .43408 .89751 .43057 .89302 .42412 Mtetra
.89302 .42412 .89751 .43057 .90898 .42705 .90453 .42058 Mtetra
.518 .675 .936 r
.28847 .60386 .29442 .60994 .29759 .70204 .2976 .6037 Mtetra
.593 .395 .582 r
.2976 .6037 .29759 .70204 .3132 .60166 .30736 .59435 Mtetra
.531 .638 .901 r
.30736 .59435 .3132 .60166 .32246 .6002 .31655 .59432 Mtetra
.604 .715 .923 r
.31655 .59432 .32246 .6002 .33177 .59877 .32588 .59261 Mtetra
.496 .664 .937 r
.32588 .59261 .33177 .59877 .34301 .56205 .33515 .59279 Mtetra
.395 .125 .381 r
.33515 .59279 .34301 .56205 .35078 .59024 .34499 .58323 Mtetra
.554 .659 .906 r
.34499 .58323 .35078 .59024 .36021 .58855 .35437 .58269 Mtetra
.615 .721 .922 r
.35437 .58269 .36021 .58855 .36968 .58666 .36386 .58071 Mtetra
.586 .709 .928 r
.36386 .58071 .36968 .58666 .37904 .58838 .37336 .57932 Mtetra
.814 .697 .736 r
.37336 .57932 .37904 .58838 .38895 .57757 .38343 .56556 Mtetra
.358 .433 .802 r
.38343 .56556 .38895 .57757 .39851 .57637 .39275 .57035 Mtetra
.616 .719 .919 r
.39275 .57035 .39851 .57637 .40813 .57415 .40239 .56834 Mtetra
.627 .73 .922 r
.40239 .56834 .40813 .57415 .4178 .57201 .41208 .56605 Mtetra
.599 .717 .926 r
.41208 .56605 .4178 .57201 .42743 .57253 .42179 .56435 Mtetra
.862 .72 .704 r
.42179 .56435 .42743 .57253 .43739 .56237 .43204 .54464 Mtetra
.237 .278 .702 r
.43204 .54464 .43739 .56237 .44713 .56129 .44148 .55517 Mtetra
.619 .719 .918 r
.44148 .55517 .44713 .56129 .45695 .55887 .45131 .55305 Mtetra
.638 .737 .92 r
.45131 .55305 .45695 .55887 .46681 .55624 .46119 .55046 Mtetra
.64 .74 .921 r
.46119 .55046 .46681 .55624 .47671 .55363 .47111 .5478 Mtetra
.635 .737 .922 r
.47111 .5478 .47671 .55363 .48664 .55136 .48107 .54526 Mtetra
.589 .711 .928 r
.48107 .54526 .48664 .55136 .49656 .55524 .49105 .54373 Mtetra
.774 .659 .737 r
.49105 .54373 .49656 .55524 .50666 .54174 .50116 .53219 Mtetra
.476 .556 .858 r
.50116 .53219 .50666 .54174 .5167 .53994 .51119 .53385 Mtetra
.631 .729 .918 r
.51119 .53385 .5167 .53994 .52678 .53722 .5213 .53137 Mtetra
.647 .743 .92 r
.5213 .53137 .52678 .53722 .5369 .53428 .53144 .52848 Mtetra
.652 .748 .92 r
.53144 .52848 .5369 .53428 .54706 .53123 .54163 .52545 Mtetra
.655 .751 .92 r
.54163 .52545 .54706 .53123 .55726 .52811 .55185 .52234 Mtetra
.657 .752 .92 r
.55185 .52234 .55726 .52811 .56749 .52494 .56211 .51916 Mtetra
.658 .753 .92 r
.56211 .51916 .56749 .52494 .57776 .52173 .57241 .51594 Mtetra
.659 .754 .92 r
.57241 .51594 .57776 .52173 .58807 .5185 .58274 .51269 Mtetra
.58274 .51269 .58807 .5185 .59842 .51526 .59311 .50943 Mtetra
.59311 .50943 .59842 .51526 .60881 .51201 .60353 .50616 Mtetra
.60353 .50616 .60881 .51201 .61923 .50875 .61397 .50288 Mtetra
.658 .753 .92 r
.61397 .50288 .61923 .50875 .62969 .50549 .62446 .49959 Mtetra
.62446 .49959 .62969 .50549 .64019 .50223 .63499 .4963 Mtetra
.63499 .4963 .64019 .50223 .65073 .49895 .64556 .493 Mtetra
.64556 .493 .65073 .49895 .66131 .49567 .65617 .4897 Mtetra
.65617 .4897 .66131 .49567 .67193 .49238 .66681 .48638 Mtetra
.66681 .48638 .67193 .49238 .68259 .48908 .6775 .48305 Mtetra
.657 .753 .92 r
.6775 .48305 .68259 .48908 .69329 .48577 .68823 .47972 Mtetra
.68823 .47972 .69329 .48577 .70403 .48244 .699 .47637 Mtetra
.699 .47637 .70403 .48244 .71481 .47911 .70981 .47301 Mtetra
.70981 .47301 .71481 .47911 .72563 .47576 .72066 .46964 Mtetra
.72066 .46964 .72563 .47576 .7365 .47241 .73155 .46626 Mtetra
.657 .752 .92 r
.73155 .46626 .7365 .47241 .7474 .46904 .74248 .46287 Mtetra
.74248 .46287 .7474 .46904 .75835 .46566 .75345 .45946 Mtetra
.75345 .45946 .75835 .46566 .76933 .46227 .76447 .45605 Mtetra
.76447 .45605 .76933 .46227 .78036 .45886 .77553 .45262 Mtetra
.77553 .45262 .78036 .45886 .79143 .45544 .78663 .44918 Mtetra
.78663 .44918 .79143 .45544 .80255 .45201 .79778 .44572 Mtetra
.79778 .44572 .80255 .45201 .8137 .44857 .80896 .44226 Mtetra
.80896 .44226 .8137 .44857 .8249 .44512 .8202 .43878 Mtetra
.8202 .43878 .8249 .44512 .83615 .44165 .83147 .43529 Mtetra
.83147 .43529 .83615 .44165 .84743 .43817 .84279 .43178 Mtetra
.84279 .43178 .84743 .43817 .85877 .43468 .85415 .42826 Mtetra
.85415 .42826 .85877 .43468 .87014 .43117 .86556 .42473 Mtetra
.86556 .42473 .87014 .43117 .88156 .42765 .87701 .42119 Mtetra
.87701 .42119 .88156 .42765 .89302 .42412 .88851 .41763 Mtetra
.88851 .41763 .89302 .42412 .90453 .42058 .90005 .41406 Mtetra
.588 .707 .926 r
.28247 .59793 .28847 .60386 .2976 .6037 .29169 .59655 Mtetra
.948 .661 .462 r
.29169 .59655 .2976 .6037 .30736 .59435 .29481 .68904 Mtetra
0 0 .148 r
.29481 .68904 .30736 .59435 .31655 .59432 .31061 .58817 Mtetra
.594 .703 .919 r
.31061 .58817 .31655 .59432 .32588 .59261 .31995 .58667 Mtetra
.591 .711 .927 r
.31995 .58667 .32588 .59261 .33515 .59279 .32933 .58519 Mtetra
.9 .714 .641 r
.32933 .58519 .33515 .59279 .34499 .58323 .34068 .54828 Mtetra
0 .007 .51 r
.34068 .54828 .34499 .58323 .35437 .58269 .3485 .57656 Mtetra
.604 .71 .919 r
.3485 .57656 .35437 .58269 .36386 .58071 .358 .57482 Mtetra
.612 .722 .924 r
.358 .57482 .36386 .58071 .37336 .57932 .36754 .57289 Mtetra
.386 .606 .936 r
.36754 .57289 .37336 .57932 .38343 .56556 .37697 .57457 Mtetra
0 0 0 r
.37697 .57457 .38343 .56556 .39275 .57035 .38698 .56368 Mtetra
.583 .685 .912 r
.38698 .56368 .39275 .57035 .40239 .56834 .3966 .56244 Mtetra
.625 .728 .921 r
.3966 .56244 .40239 .56834 .41208 .56605 .40631 .56017 Mtetra
.621 .728 .923 r
.40631 .56017 .41208 .56605 .42179 .56435 .41606 .55798 Mtetra
.476 .653 .937 r
.41606 .55798 .42179 .56435 .43204 .54464 .42576 .55847 Mtetra
.096 0 .093 r
.42576 .55847 .43204 .54464 .44148 .55517 .43581 .54823 Mtetra
.578 .677 .908 r
.43581 .54823 .44148 .55517 .45131 .55305 .44563 .5471 Mtetra
.632 .732 .92 r
.44563 .5471 .45131 .55305 .46119 .55046 .45553 .54463 Mtetra
.64 .739 .921 r
.45553 .54463 .46119 .55046 .47111 .5478 .46547 .54196 Mtetra
.639 .739 .921 r
.46547 .54196 .47111 .5478 .48107 .54526 .47545 .53929 Mtetra
.624 .731 .923 r
.47545 .53929 .48107 .54526 .49105 .54373 .48547 .53698 Mtetra
.222 .504 .906 r
.48547 .53698 .49105 .54373 .50116 .53219 .49547 .54083 Mtetra
0 0 0 r
.49547 .54083 .50116 .53219 .51119 .53385 .50565 .52723 Mtetra
.605 .703 .913 r
.50565 .52723 .51119 .53385 .5213 .53137 .51578 .52539 Mtetra
.642 .739 .919 r
.51578 .52539 .5213 .53137 .53144 .52848 .52595 .52262 Mtetra
.65 .746 .92 r
.52595 .52262 .53144 .52848 .54163 .52545 .53616 .51962 Mtetra
.654 .749 .92 r
.53616 .51962 .54163 .52545 .55185 .52234 .5464 .51652 Mtetra
.656 .751 .92 r
.5464 .51652 .55185 .52234 .56211 .51916 .55669 .51334 Mtetra
.658 .753 .92 r
.55669 .51334 .56211 .51916 .57241 .51594 .56701 .51011 Mtetra
.659 .753 .92 r
.56701 .51011 .57241 .51594 .58274 .51269 .57737 .50685 Mtetra
.659 .754 .92 r
.57737 .50685 .58274 .51269 .59311 .50943 .58777 .50356 Mtetra
.58777 .50356 .59311 .50943 .60353 .50616 .59821 .50027 Mtetra
.59821 .50027 .60353 .50616 .61397 .50288 .60868 .49696 Mtetra
.658 .754 .92 r
.60868 .49696 .61397 .50288 .62446 .49959 .6192 .49365 Mtetra
.658 .753 .92 r
.6192 .49365 .62446 .49959 .63499 .4963 .62975 .49033 Mtetra
.62975 .49033 .63499 .4963 .64556 .493 .64035 .48701 Mtetra
.64035 .48701 .64556 .493 .65617 .4897 .65098 .48368 Mtetra
.65098 .48368 .65617 .4897 .66681 .48638 .66166 .48034 Mtetra
.66166 .48034 .66681 .48638 .6775 .48305 .67237 .47699 Mtetra
.67237 .47699 .6775 .48305 .68823 .47972 .68313 .47363 Mtetra
.657 .753 .92 r
.68313 .47363 .68823 .47972 .699 .47637 .69393 .47026 Mtetra
.69393 .47026 .699 .47637 .70981 .47301 .70476 .46687 Mtetra
.70476 .46687 .70981 .47301 .72066 .46964 .71564 .46348 Mtetra
.71564 .46348 .72066 .46964 .73155 .46626 .72656 .46007 Mtetra
.657 .752 .92 r
.72656 .46007 .73155 .46626 .74248 .46287 .73752 .45666 Mtetra
.73752 .45666 .74248 .46287 .75345 .45946 .74853 .45323 Mtetra
.74853 .45323 .75345 .45946 .76447 .45605 .75958 .44979 Mtetra
.75958 .44979 .76447 .45605 .77553 .45262 .77067 .44633 Mtetra
.77067 .44633 .77553 .45262 .78663 .44918 .7818 .44287 Mtetra
.7818 .44287 .78663 .44918 .79778 .44572 .79297 .43939 Mtetra
.79297 .43939 .79778 .44572 .80896 .44226 .80419 .4359 Mtetra
.80419 .4359 .80896 .44226 .8202 .43878 .81545 .43239 Mtetra
.81545 .43239 .8202 .43878 .83147 .43529 .82676 .42887 Mtetra
.82676 .42887 .83147 .43529 .84279 .43178 .83811 .42534 Mtetra
.83811 .42534 .84279 .43178 .85415 .42826 .8495 .4218 Mtetra
.8495 .4218 .85415 .42826 .86556 .42473 .86094 .41824 Mtetra
.86094 .41824 .86556 .42473 .87701 .42119 .87243 .41467 Mtetra
.87243 .41467 .87701 .42119 .88851 .41763 .88396 .41109 Mtetra
.88396 .41109 .88851 .41763 .90005 .41406 .89553 .40749 Mtetra
.592 .704 .922 r
.27644 .59184 .28247 .59793 .29169 .59655 .28568 .59039 Mtetra
.518 .675 .935 r
.28568 .59039 .29169 .59655 .29481 .68904 .29488 .59019 Mtetra
.591 .393 .581 r
.29488 .59019 .29481 .68904 .31061 .58817 .30472 .58076 Mtetra
.53 .638 .901 r
.30472 .58076 .31061 .58817 .31995 .58667 .31398 .5807 Mtetra
.604 .715 .923 r
.31398 .5807 .31995 .58667 .32933 .58519 .32339 .57894 Mtetra
.496 .664 .937 r
.32339 .57894 .32933 .58519 .34068 .54828 .33273 .57908 Mtetra
.389 .117 .375 r
.33273 .57908 .34068 .54828 .3485 .57656 .34265 .56945 Mtetra
.554 .659 .906 r
.34265 .56945 .3485 .57656 .358 .57482 .3521 .56886 Mtetra
.615 .721 .922 r
.3521 .56886 .358 .57482 .36754 .57289 .36167 .56684 Mtetra
.586 .709 .928 r
.36167 .56684 .36754 .57289 .37697 .57457 .37125 .56541 Mtetra
.815 .698 .736 r
.37125 .56541 .37697 .57457 .38698 .56368 .3814 .55155 Mtetra
.357 .433 .802 r
.3814 .55155 .38698 .56368 .3966 .56244 .39079 .55632 Mtetra
.616 .719 .919 r
.39079 .55632 .3966 .56244 .40631 .56017 .40051 .55427 Mtetra
.627 .73 .922 r
.40051 .55427 .40631 .56017 .41606 .55798 .41028 .55193 Mtetra
.599 .717 .926 r
.41028 .55193 .41606 .55798 .42576 .55847 .42007 .55019 Mtetra
.863 .721 .704 r
.42007 .55019 .42576 .55847 .43581 .54823 .43041 .53035 Mtetra
.234 .276 .701 r
.43041 .53035 .43581 .54823 .44563 .5471 .43992 .54089 Mtetra
.619 .719 .918 r
.43992 .54089 .44563 .5471 .45553 .54463 .44983 .53872 Mtetra
.638 .737 .92 r
.44983 .53872 .45553 .54463 .46547 .54196 .4598 .53608 Mtetra
.64 .74 .921 r
.4598 .53608 .46547 .54196 .47545 .53929 .4698 .53336 Mtetra
.635 .737 .922 r
.4698 .53336 .47545 .53929 .48547 .53698 .47984 .53077 Mtetra
.589 .711 .928 r
.47984 .53077 .48547 .53698 .49547 .54083 .48991 .5292 Mtetra
.774 .66 .737 r
.48991 .5292 .49547 .54083 .50565 .52723 .5001 .51757 Mtetra
.475 .556 .858 r
.5001 .51757 .50565 .52723 .51578 .52539 .51022 .5192 Mtetra
.631 .729 .918 r
.51022 .5192 .51578 .52539 .52595 .52262 .52041 .51666 Mtetra
.647 .743 .92 r
.52041 .51666 .52595 .52262 .53616 .51962 .53065 .51372 Mtetra
.652 .748 .92 r
.53065 .51372 .53616 .51962 .5464 .51652 .54092 .51064 Mtetra
.655 .751 .92 r
.54092 .51064 .5464 .51652 .55669 .51334 .55123 .50747 Mtetra
.657 .752 .92 r
.55123 .50747 .55669 .51334 .56701 .51011 .56158 .50424 Mtetra
.658 .753 .92 r
.56158 .50424 .56701 .51011 .57737 .50685 .57197 .50096 Mtetra
.659 .754 .92 r
.57197 .50096 .57737 .50685 .58777 .50356 .58239 .49766 Mtetra
.58239 .49766 .58777 .50356 .59821 .50027 .59285 .49433 Mtetra
.59285 .49433 .59821 .50027 .60868 .49696 .60336 .491 Mtetra
.60336 .491 .60868 .49696 .6192 .49365 .6139 .48767 Mtetra
.658 .753 .92 r
.6139 .48767 .6192 .49365 .62975 .49033 .62448 .48432 Mtetra
.62448 .48432 .62975 .49033 .64035 .48701 .6351 .48098 Mtetra
.6351 .48098 .64035 .48701 .65098 .48368 .64576 .47762 Mtetra
.64576 .47762 .65098 .48368 .66166 .48034 .65647 .47425 Mtetra
.65647 .47425 .66166 .48034 .67237 .47699 .66721 .47088 Mtetra
.66721 .47088 .67237 .47699 .68313 .47363 .67799 .46749 Mtetra
.657 .753 .92 r
.67799 .46749 .68313 .47363 .69393 .47026 .68882 .4641 Mtetra
.68882 .4641 .69393 .47026 .70476 .46687 .69968 .46069 Mtetra
.69968 .46069 .70476 .46687 .71564 .46348 .71059 .45727 Mtetra
.71059 .45727 .71564 .46348 .72656 .46007 .72154 .45384 Mtetra
.72154 .45384 .72656 .46007 .73752 .45666 .73253 .4504 Mtetra
.657 .752 .92 r
.73253 .4504 .73752 .45666 .74853 .45323 .74357 .44695 Mtetra
.74357 .44695 .74853 .45323 .75958 .44979 .75464 .44348 Mtetra
.75464 .44348 .75958 .44979 .77067 .44633 .76576 .44 Mtetra
.76576 .44 .77067 .44633 .7818 .44287 .77693 .43651 Mtetra
.77693 .43651 .7818 .44287 .79297 .43939 .78813 .43301 Mtetra
.78813 .43301 .79297 .43939 .80419 .4359 .79938 .42949 Mtetra
.79938 .42949 .80419 .4359 .81545 .43239 .81068 .42596 Mtetra
.81068 .42596 .81545 .43239 .82676 .42887 .82201 .42242 Mtetra
.82201 .42242 .82676 .42887 .83811 .42534 .8334 .41886 Mtetra
.8334 .41886 .83811 .42534 .8495 .4218 .84482 .41529 Mtetra
.84482 .41529 .8495 .4218 .86094 .41824 .85629 .41171 Mtetra
.85629 .41171 .86094 .41824 .87243 .41467 .86781 .40811 Mtetra
.86781 .40811 .87243 .41467 .88396 .41109 .87937 .4045 Mtetra
.87937 .4045 .88396 .41109 .89553 .40749 .89098 .40088 Mtetra
.553 .665 .911 r
.27043 .58498 .27644 .59184 .28568 .59039 .27962 .58436 Mtetra
.588 .707 .926 r
.27962 .58436 .28568 .59039 .29488 .59019 .28891 .58294 Mtetra
.949 .661 .459 r
.28891 .58294 .29488 .59019 .30472 .58076 .29197 .67582 Mtetra
0 0 .141 r
.29197 .67582 .30472 .58076 .31398 .5807 .30799 .57445 Mtetra
.594 .703 .919 r
.30799 .57445 .31398 .5807 .32339 .57894 .3174 .57291 Mtetra
.591 .711 .926 r
.3174 .57291 .32339 .57894 .33273 .57908 .32685 .57139 Mtetra
.901 .714 .64 r
.32685 .57139 .33273 .57908 .34265 .56945 .33832 .53428 Mtetra
0 .002 .507 r
.33832 .53428 .34265 .56945 .3521 .56886 .34617 .56264 Mtetra
.604 .71 .919 r
.34617 .56264 .3521 .56886 .36167 .56684 .35575 .56086 Mtetra
.612 .722 .924 r
.35575 .56086 .36167 .56684 .37125 .56541 .36537 .55888 Mtetra
.388 .606 .935 r
.36537 .55888 .37125 .56541 .3814 .55155 .37488 .56053 Mtetra
0 0 0 r
.37488 .56053 .3814 .55155 .39079 .55632 .38497 .54955 Mtetra
.582 .685 .912 r
.38497 .54955 .39079 .55632 .40051 .55427 .39467 .54827 Mtetra
.625 .728 .921 r
.39467 .54827 .40051 .55427 .41028 .55193 .40446 .54595 Mtetra
.621 .728 .923 r
.40446 .54595 .41028 .55193 .42007 .55019 .41428 .54372 Mtetra
.477 .653 .937 r
.41428 .54372 .42007 .55019 .43041 .53035 .42406 .54416 Mtetra
.084 0 .081 r
.42406 .54416 .43041 .53035 .43992 .54089 .4342 .53384 Mtetra
.577 .677 .908 r
.4342 .53384 .43992 .54089 .44983 .53872 .4441 .53267 Mtetra
.632 .732 .92 r
.4441 .53267 .44983 .53872 .4598 .53608 .45408 .53015 Mtetra
.64 .739 .921 r
.45408 .53015 .4598 .53608 .4698 .53336 .46411 .52742 Mtetra
.639 .739 .921 r
.46411 .52742 .4698 .53336 .47984 .53077 .47417 .52471 Mtetra
.624 .731 .923 r
.47417 .52471 .47984 .53077 .48991 .5292 .48427 .52234 Mtetra
.225 .505 .906 r
.48427 .52234 .48991 .5292 .5001 .51757 .49436 .52617 Mtetra
0 0 0 r
.49436 .52617 .5001 .51757 .51022 .5192 .50463 .51248 Mtetra
.605 .703 .913 r
.50463 .51248 .51022 .5192 .52041 .51666 .51484 .51058 Mtetra
.642 .739 .919 r
.51484 .51058 .52041 .51666 .53065 .51372 .5251 .50776 Mtetra
.65 .746 .92 r
.5251 .50776 .53065 .51372 .54092 .51064 .5354 .5047 Mtetra
.654 .749 .92 r
.5354 .5047 .54092 .51064 .55123 .50747 .54573 .50154 Mtetra
.656 .751 .92 r
.54573 .50154 .55123 .50747 .56158 .50424 .55611 .49831 Mtetra
.658 .753 .92 r
.55611 .49831 .56158 .50424 .57197 .50096 .56652 .49503 Mtetra
.659 .753 .92 r
.56652 .49503 .57197 .50096 .58239 .49766 .57697 .49171 Mtetra
.659 .754 .92 r
.57697 .49171 .58239 .49766 .59285 .49433 .58746 .48836 Mtetra
.58746 .48836 .59285 .49433 .60336 .491 .59799 .48501 Mtetra
.59799 .48501 .60336 .491 .6139 .48767 .60856 .48164 Mtetra
.658 .754 .92 r
.60856 .48164 .6139 .48767 .62448 .48432 .61917 .47828 Mtetra
.658 .753 .92 r
.61917 .47828 .62448 .48432 .6351 .48098 .62982 .4749 Mtetra
.62982 .4749 .6351 .48098 .64576 .47762 .64051 .47152 Mtetra
.64051 .47152 .64576 .47762 .65647 .47425 .65124 .46813 Mtetra
.65124 .46813 .65647 .47425 .66721 .47088 .66201 .46473 Mtetra
.66201 .46473 .66721 .47088 .67799 .46749 .67282 .46132 Mtetra
.67282 .46132 .67799 .46749 .68882 .4641 .68367 .4579 Mtetra
.657 .753 .92 r
.68367 .4579 .68882 .4641 .69968 .46069 .69457 .45447 Mtetra
.69457 .45447 .69968 .46069 .71059 .45727 .70551 .45102 Mtetra
.70551 .45102 .71059 .45727 .72154 .45384 .71649 .44757 Mtetra
.71649 .44757 .72154 .45384 .73253 .4504 .72751 .4441 Mtetra
.657 .752 .92 r
.72751 .4441 .73253 .4504 .74357 .44695 .73857 .44062 Mtetra
.73857 .44062 .74357 .44695 .75464 .44348 .74968 .43713 Mtetra
.74968 .43713 .75464 .44348 .76576 .44 .76083 .43363 Mtetra
.76083 .43363 .76576 .44 .77693 .43651 .77202 .43011 Mtetra
.77202 .43011 .77693 .43651 .78813 .43301 .78326 .42658 Mtetra
.78326 .42658 .78813 .43301 .79938 .42949 .79454 .42304 Mtetra
.79454 .42304 .79938 .42949 .81068 .42596 .80586 .41948 Mtetra
.80586 .41948 .81068 .42596 .82201 .42242 .81723 .41591 Mtetra
.81723 .41591 .82201 .42242 .8334 .41886 .82865 .41233 Mtetra
.82865 .41233 .8334 .41886 .84482 .41529 .84011 .40873 Mtetra
.84011 .40873 .84482 .41529 .85629 .41171 .85161 .40513 Mtetra
.85161 .40513 .85629 .41171 .86781 .40811 .86316 .4015 Mtetra
.86316 .4015 .86781 .40811 .87937 .4045 .87476 .39787 Mtetra
.87476 .39787 .87937 .4045 .89098 .40088 .8864 .39421 Mtetra
.143 .206 .67 r
.26524 .56681 .27043 .58498 .27962 .58436 .27353 .57818 Mtetra
.592 .704 .922 r
.27353 .57818 .27962 .58436 .28891 .58294 .28284 .57668 Mtetra
.518 .675 .935 r
.28284 .57668 .28891 .58294 .29197 .67582 .29211 .57645 Mtetra
.59 .39 .579 r
.29211 .57645 .29197 .67582 .30799 .57445 .30204 .56694 Mtetra
.53 .638 .901 r
.30204 .56694 .30799 .57445 .3174 .57291 .31137 .56684 Mtetra
.604 .715 .923 r
.31137 .56684 .3174 .57291 .32685 .57139 .32085 .56503 Mtetra
.496 .664 .937 r
.32085 .56503 .32685 .57139 .33832 .53428 .33026 .56514 Mtetra
.384 .11 .369 r
.33026 .56514 .33832 .53428 .34617 .56264 .34026 .55543 Mtetra
.554 .659 .906 r
.34026 .55543 .34617 .56264 .35575 .56086 .34979 .5548 Mtetra
.615 .721 .922 r
.34979 .5548 .35575 .56086 .36537 .55888 .35944 .55274 Mtetra
.586 .709 .928 r
.35944 .55274 .36537 .55888 .37488 .56053 .3691 .55126 Mtetra
.815 .699 .736 r
.3691 .55126 .37488 .56053 .38497 .54955 .37934 .5373 Mtetra
.355 .432 .802 r
.37934 .5373 .38497 .54955 .39467 .54827 .3888 .54205 Mtetra
.616 .719 .919 r
.3888 .54205 .39467 .54827 .40446 .54595 .3986 .53995 Mtetra
.627 .73 .922 r
.3986 .53995 .40446 .54595 .41428 .54372 .40845 .53757 Mtetra
.599 .717 .926 r
.40845 .53757 .41428 .54372 .42406 .54416 .41832 .53578 Mtetra
.864 .722 .704 r
.41832 .53578 .42406 .54416 .4342 .53384 .42875 .51582 Mtetra
.232 .274 .701 r
.42875 .51582 .4342 .53384 .4441 .53267 .43834 .52636 Mtetra
.619 .719 .918 r
.43834 .52636 .4441 .53267 .45408 .53015 .44833 .52414 Mtetra
.638 .737 .92 r
.44833 .52414 .45408 .53015 .46411 .52742 .45838 .52145 Mtetra
.64 .74 .921 r
.45838 .52145 .46411 .52742 .47417 .52471 .46847 .51868 Mtetra
.635 .737 .922 r
.46847 .51868 .47417 .52471 .48427 .52234 .47859 .51604 Mtetra
.589 .711 .928 r
.47859 .51604 .48427 .52234 .49436 .52617 .48875 .51441 Mtetra
.775 .661 .737 r
.48875 .51441 .49436 .52617 .50463 .51248 .49903 .50269 Mtetra
.474 .556 .859 r
.49903 .50269 .50463 .51248 .51484 .51058 .50924 .50429 Mtetra
.631 .729 .918 r
.50924 .50429 .51484 .51058 .5251 .50776 .51952 .5017 Mtetra
.647 .743 .92 r
.51952 .5017 .5251 .50776 .5354 .5047 .52984 .4987 Mtetra
.652 .748 .92 r
.52984 .4987 .5354 .5047 .54573 .50154 .5402 .49556 Mtetra
.655 .751 .92 r
.5402 .49556 .54573 .50154 .55611 .49831 .5506 .49233 Mtetra
.657 .752 .92 r
.5506 .49233 .55611 .49831 .56652 .49503 .56104 .48905 Mtetra
.658 .753 .92 r
.56104 .48905 .56652 .49503 .57697 .49171 .57152 .48571 Mtetra
.659 .754 .92 r
.57152 .48571 .57697 .49171 .58746 .48836 .58203 .48235 Mtetra
.58203 .48235 .58746 .48836 .59799 .48501 .59259 .47897 Mtetra
.59259 .47897 .59799 .48501 .60856 .48164 .60319 .47558 Mtetra
.60319 .47558 .60856 .48164 .61917 .47828 .61382 .47219 Mtetra
.658 .753 .92 r
.61382 .47219 .61917 .47828 .62982 .4749 .6245 .46878 Mtetra
.6245 .46878 .62982 .4749 .64051 .47152 .63521 .46538 Mtetra
.63521 .46538 .64051 .47152 .65124 .46813 .64597 .46196 Mtetra
.64597 .46196 .65124 .46813 .66201 .46473 .65677 .45853 Mtetra
.65677 .45853 .66201 .46473 .67282 .46132 .66761 .4551 Mtetra
.66761 .4551 .67282 .46132 .68367 .4579 .67849 .45165 Mtetra
.657 .753 .92 r
.67849 .45165 .68367 .4579 .69457 .45447 .68942 .4482 Mtetra
.68942 .4482 .69457 .45447 .70551 .45102 .70039 .44473 Mtetra
.70039 .44473 .70551 .45102 .71649 .44757 .71139 .44125 Mtetra
.71139 .44125 .71649 .44757 .72751 .4441 .72244 .43775 Mtetra
.72244 .43775 .72751 .4441 .73857 .44062 .73354 .43425 Mtetra
.657 .752 .92 r
.73354 .43425 .73857 .44062 .74968 .43713 .74468 .43073 Mtetra
.74468 .43073 .74968 .43713 .76083 .43363 .75586 .4272 Mtetra
.75586 .4272 .76083 .43363 .77202 .43011 .76708 .42366 Mtetra
.76708 .42366 .77202 .43011 .78326 .42658 .77835 .42011 Mtetra
.77835 .42011 .78326 .42658 .79454 .42304 .78966 .41654 Mtetra
.78966 .41654 .79454 .42304 .80586 .41948 .80102 .41296 Mtetra
.80102 .41296 .80586 .41948 .81723 .41591 .81242 .40936 Mtetra
.81242 .40936 .81723 .41591 .82865 .41233 .82386 .40575 Mtetra
.82386 .40575 .82865 .41233 .84011 .40873 .83536 .40213 Mtetra
.83536 .40213 .84011 .40873 .85161 .40513 .84689 .39849 Mtetra
.84689 .39849 .85161 .40513 .86316 .4015 .85848 .39484 Mtetra
.85848 .39484 .86316 .4015 .87476 .39787 .8701 .39118 Mtetra
.8701 .39118 .87476 .39787 .8864 .39421 .88178 .3875 Mtetra
.06 0 .048 r
.25753 .581 .26524 .56681 .27353 .57818 .26746 .57122 Mtetra
.553 .665 .911 r
.26746 .57122 .27353 .57818 .28284 .57668 .27672 .57057 Mtetra
.588 .707 .926 r
.27672 .57057 .28284 .57668 .29211 .57645 .28609 .5691 Mtetra
.95 .661 .456 r
.28609 .5691 .29211 .57645 .30204 .56694 .28909 .66237 Mtetra
0 0 .133 r
.28909 .66237 .30204 .56694 .31137 .56684 .30532 .56049 Mtetra
.594 .703 .919 r
.30532 .56049 .31137 .56684 .32085 .56503 .3148 .55891 Mtetra
.591 .711 .926 r
.3148 .55891 .32085 .56503 .33026 .56514 .32432 .55734 Mtetra
.902 .715 .639 r
.32432 .55734 .33026 .56514 .34026 .55543 .33591 .52004 Mtetra
0 0 .504 r
.33591 .52004 .34026 .55543 .34979 .5548 .34381 .54848 Mtetra
.604 .71 .919 r
.34381 .54848 .34979 .5548 .35944 .55274 .35346 .54666 Mtetra
.612 .722 .924 r
.35346 .54666 .35944 .55274 .3691 .55126 .36316 .54463 Mtetra
.389 .607 .935 r
.36316 .54463 .3691 .55126 .37934 .5373 .37274 .54625 Mtetra
0 0 0 r
.37274 .54625 .37934 .5373 .3888 .54205 .38292 .53518 Mtetra
.582 .685 .912 r
.38292 .53518 .3888 .54205 .3986 .53995 .3927 .53386 Mtetra
.625 .728 .921 r
.3927 .53386 .3986 .53995 .40845 .53757 .40257 .53149 Mtetra
.621 .728 .923 r
.40257 .53149 .40845 .53757 .41832 .53578 .41247 .5292 Mtetra
.477 .653 .937 r
.41247 .5292 .41832 .53578 .42875 .51582 .42234 .52961 Mtetra
.072 0 .069 r
.42234 .52961 .42875 .51582 .43834 .52636 .43256 .51921 Mtetra
.577 .677 .908 r
.43256 .51921 .43834 .52636 .44833 .52414 .44255 .51799 Mtetra
.632 .732 .92 r
.44255 .51799 .44833 .52414 .45838 .52145 .45261 .51542 Mtetra
.64 .739 .921 r
.45261 .51542 .45838 .52145 .46847 .51868 .46272 .51264 Mtetra
.639 .739 .921 r
.46272 .51264 .46847 .51868 .47859 .51604 .47287 .50987 Mtetra
.624 .731 .923 r
.47287 .50987 .47859 .51604 .48875 .51441 .48306 .50745 Mtetra
.227 .507 .906 r
.48306 .50745 .48875 .51441 .49903 .50269 .49323 .51126 Mtetra
0 0 0 r
.49323 .51126 .49903 .50269 .50924 .50429 .50359 .49746 Mtetra
.605 .703 .913 r
.50359 .49746 .50924 .50429 .51952 .5017 .51389 .49551 Mtetra
.642 .739 .919 r
.51389 .49551 .51952 .5017 .52984 .4987 .52424 .49263 Mtetra
.65 .746 .92 r
.52424 .49263 .52984 .4987 .5402 .49556 .53463 .48952 Mtetra
.654 .749 .92 r
.53463 .48952 .5402 .49556 .5506 .49233 .54505 .4863 Mtetra
.656 .751 .92 r
.54505 .4863 .5506 .49233 .56104 .48905 .55552 .48301 Mtetra
.658 .753 .92 r
.55552 .48301 .56104 .48905 .57152 .48571 .56602 .47967 Mtetra
.659 .753 .92 r
.56602 .47967 .57152 .48571 .58203 .48235 .57656 .47629 Mtetra
.659 .754 .92 r
.57656 .47629 .58203 .48235 .59259 .47897 .58715 .47289 Mtetra
.58715 .47289 .59259 .47897 .60319 .47558 .59777 .46948 Mtetra
.59777 .46948 .60319 .47558 .61382 .47219 .60843 .46605 Mtetra
.658 .754 .92 r
.60843 .46605 .61382 .47219 .6245 .46878 .61914 .46263 Mtetra
.658 .753 .92 r
.61914 .46263 .6245 .46878 .63521 .46538 .62988 .45919 Mtetra
.62988 .45919 .63521 .46538 .64597 .46196 .64067 .45575 Mtetra
.64067 .45575 .64597 .46196 .65677 .45853 .6515 .4523 Mtetra
.6515 .4523 .65677 .45853 .66761 .4551 .66237 .44883 Mtetra
.66237 .44883 .66761 .4551 .67849 .45165 .67328 .44536 Mtetra
.67328 .44536 .67849 .45165 .68942 .4482 .68423 .44188 Mtetra
.657 .753 .92 r
.68423 .44188 .68942 .4482 .70039 .44473 .69523 .43839 Mtetra
.69523 .43839 .70039 .44473 .71139 .44125 .70626 .43488 Mtetra
.70626 .43488 .71139 .44125 .72244 .43775 .71735 .43136 Mtetra
.71735 .43136 .72244 .43775 .73354 .43425 .72847 .42783 Mtetra
.657 .752 .92 r
.72847 .42783 .73354 .43425 .74468 .43073 .73964 .42429 Mtetra
.73964 .42429 .74468 .43073 .75586 .4272 .75085 .42073 Mtetra
.75085 .42073 .75586 .4272 .76708 .42366 .7621 .41717 Mtetra
.7621 .41717 .76708 .42366 .77835 .42011 .7734 .41358 Mtetra
.7734 .41358 .77835 .42011 .78966 .41654 .78475 .40999 Mtetra
.78475 .40999 .78966 .41654 .80102 .41296 .79614 .40638 Mtetra
.79614 .40638 .80102 .41296 .81242 .40936 .80757 .40276 Mtetra
.80757 .40276 .81242 .40936 .82386 .40575 .81905 .39913 Mtetra
.81905 .39913 .82386 .40575 .83536 .40213 .83057 .39548 Mtetra
.83057 .39548 .83536 .40213 .84689 .39849 .84214 .39181 Mtetra
.84214 .39181 .84689 .39849 .85848 .39484 .85376 .38814 Mtetra
.85376 .38814 .85848 .39484 .8701 .39118 .86542 .38445 Mtetra
.86542 .38445 .8701 .39118 .88178 .3875 .87713 .38074 Mtetra
.853 .71 .704 r
.25149 .57278 .25753 .581 .26746 .57122 .26223 .55291 Mtetra
.139 .203 .669 r
.26223 .55291 .26746 .57122 .27672 .57057 .27057 .56429 Mtetra
.592 .704 .922 r
.27057 .56429 .27672 .57057 .28609 .5691 .27996 .56274 Mtetra
.519 .675 .935 r
.27996 .56274 .28609 .5691 .28909 .66237 .2893 .56247 Mtetra
.588 .388 .577 r
.2893 .56247 .28909 .66237 .30532 .56049 .29931 .55289 Mtetra
.53 .638 .901 r
.29931 .55289 .30532 .56049 .3148 .55891 .30871 .55275 Mtetra
.604 .715 .923 r
.30871 .55275 .3148 .55891 .32432 .55734 .31827 .55089 Mtetra
.497 .664 .937 r
.31827 .55089 .32432 .55734 .33591 .52004 .32776 .55097 Mtetra
.377 .102 .363 r
.32776 .55097 .33591 .52004 .34381 .54848 .33784 .54117 Mtetra
.553 .659 .906 r
.33784 .54117 .34381 .54848 .35346 .54666 .34745 .5405 Mtetra
.615 .721 .922 r
.34745 .5405 .35346 .54666 .36316 .54463 .35717 .53839 Mtetra
.586 .709 .928 r
.35717 .53839 .36316 .54463 .37274 .54625 .36691 .53686 Mtetra
.816 .699 .736 r
.36691 .53686 .37274 .54625 .38292 .53518 .37724 .5228 Mtetra
.354 .431 .802 r
.37724 .5228 .38292 .53518 .3927 .53386 .38678 .52754 Mtetra
.616 .719 .919 r
.38678 .52754 .3927 .53386 .40257 .53149 .39665 .52539 Mtetra
.627 .73 .922 r
.39665 .52539 .40257 .53149 .41247 .5292 .40658 .52295 Mtetra
.599 .716 .926 r
.40658 .52295 .41247 .5292 .42234 .52961 .41654 .52111 Mtetra
.865 .722 .703 r
.41654 .52111 .42234 .52961 .43256 .51921 .42707 .50103 Mtetra
.229 .272 .7 r
.42707 .50103 .43256 .51921 .44255 .51799 .43673 .51157 Mtetra
.619 .719 .918 r
.43673 .51157 .44255 .51799 .45261 .51542 .44681 .5093 Mtetra
.638 .737 .92 r
.44681 .5093 .45261 .51542 .46272 .51264 .45694 .50656 Mtetra
.64 .74 .921 r
.45694 .50656 .46272 .51264 .47287 .50987 .46711 .50373 Mtetra
.635 .737 .922 r
.46711 .50373 .47287 .50987 .48306 .50745 .47733 .50104 Mtetra
.589 .711 .928 r
.47733 .50104 .48306 .50745 .49323 .51126 .48757 .49937 Mtetra
.775 .661 .737 r
.48757 .49937 .49323 .51126 .50359 .49746 .49794 .48755 Mtetra
.474 .555 .859 r
.49794 .48755 .50359 .49746 .51389 .49551 .50823 .48911 Mtetra
.631 .729 .918 r
.50823 .48911 .51389 .49551 .52424 .49263 .5186 .48647 Mtetra
.647 .743 .92 r
.5186 .48647 .52424 .49263 .53463 .48952 .52901 .48342 Mtetra
.652 .748 .92 r
.52901 .48342 .53463 .48952 .54505 .4863 .53946 .48022 Mtetra
.655 .751 .92 r
.53946 .48022 .54505 .4863 .55552 .48301 .54996 .47693 Mtetra
.657 .752 .92 r
.54996 .47693 .55552 .48301 .56602 .47967 .56049 .47358 Mtetra
.658 .753 .92 r
.56049 .47358 .56602 .47967 .57656 .47629 .57106 .47019 Mtetra
.659 .754 .92 r
.57106 .47019 .57656 .47629 .58715 .47289 .58167 .46677 Mtetra
.58167 .46677 .58715 .47289 .59777 .46948 .59232 .46333 Mtetra
.59232 .46333 .59777 .46948 .60843 .46605 .60301 .45988 Mtetra
.60301 .45988 .60843 .46605 .61914 .46263 .61374 .45642 Mtetra
.658 .753 .92 r
.61374 .45642 .61914 .46263 .62988 .45919 .62452 .45296 Mtetra
.62452 .45296 .62988 .45919 .64067 .45575 .63533 .44949 Mtetra
.63533 .44949 .64067 .45575 .6515 .4523 .64619 .44601 Mtetra
.64619 .44601 .6515 .4523 .66237 .44883 .65708 .44253 Mtetra
.65708 .44253 .66237 .44883 .67328 .44536 .66802 .43903 Mtetra
.66802 .43903 .67328 .44536 .68423 .44188 .67901 .43552 Mtetra
.657 .753 .92 r
.67901 .43552 .68423 .44188 .69523 .43839 .69003 .432 Mtetra
.69003 .432 .69523 .43839 .70626 .43488 .7011 .42847 Mtetra
.7011 .42847 .70626 .43488 .71735 .43136 .71221 .42493 Mtetra
.71221 .42493 .71735 .43136 .72847 .42783 .72336 .42137 Mtetra
.72336 .42137 .72847 .42783 .73964 .42429 .73456 .4178 Mtetra
.657 .752 .92 r
.73456 .4178 .73964 .42429 .75085 .42073 .7458 .41422 Mtetra
.7458 .41422 .75085 .42073 .7621 .41717 .75709 .41062 Mtetra
.75709 .41062 .7621 .41717 .7734 .41358 .76842 .40702 Mtetra
.76842 .40702 .7734 .41358 .78475 .40999 .7798 .4034 Mtetra
.7798 .4034 .78475 .40999 .79614 .40638 .79122 .39976 Mtetra
.79122 .39976 .79614 .40638 .80757 .40276 .80268 .39611 Mtetra
.80268 .39611 .80757 .40276 .81905 .39913 .81419 .39245 Mtetra
.81419 .39245 .81905 .39913 .83057 .39548 .82575 .38877 Mtetra
.82575 .38877 .83057 .39548 .84214 .39181 .83735 .38508 Mtetra
.83735 .38508 .84214 .39181 .85376 .38814 .849 .38138 Mtetra
.849 .38138 .85376 .38814 .86542 .38445 .8607 .37766 Mtetra
.8607 .37766 .86542 .38445 .87713 .38074 .87244 .37393 Mtetra
.442 .637 .938 r
.24528 .56627 .25149 .57278 .26223 .55291 .25442 .56709 Mtetra
.047 0 .034 r
.25442 .56709 .26223 .55291 .27057 .56429 .26444 .55723 Mtetra
.553 .665 .911 r
.26444 .55723 .27057 .56429 .27996 .56274 .27378 .55653 Mtetra
.588 .707 .926 r
.27378 .55653 .27996 .56274 .2893 .56247 .28322 .55502 Mtetra
.951 .661 .453 r
.28322 .55502 .2893 .56247 .29931 .55289 .28615 .64868 Mtetra
0 0 .126 r
.28615 .64868 .29931 .55289 .30871 .55275 .3026 .5463 Mtetra
.594 .703 .919 r
.3026 .5463 .30871 .55275 .31827 .55089 .31216 .54467 Mtetra
.591 .71 .926 r
.31216 .54467 .31827 .55089 .32776 .55097 .32176 .54306 Mtetra
.903 .716 .639 r
.32176 .54306 .32776 .55097 .33784 .54117 .33347 .50556 Mtetra
0 0 .501 r
.33347 .50556 .33784 .54117 .34745 .5405 .34141 .53408 Mtetra
.604 .71 .919 r
.34141 .53408 .34745 .5405 .35717 .53839 .35113 .53221 Mtetra
.612 .722 .924 r
.35113 .53221 .35717 .53839 .36691 .53686 .36092 .53013 Mtetra
.39 .607 .935 r
.36092 .53013 .36691 .53686 .37724 .5228 .37057 .53172 Mtetra
0 0 0 r
.37057 .53172 .37724 .5228 .38678 .52754 .38084 .52057 Mtetra
.582 .686 .912 r
.38084 .52057 .38678 .52754 .39665 .52539 .3907 .51919 Mtetra
.625 .728 .921 r
.3907 .51919 .39665 .52539 .40658 .52295 .40065 .51677 Mtetra
.621 .728 .923 r
.40065 .51677 .40658 .52295 .41654 .52111 .41064 .51444 Mtetra
.478 .653 .937 r
.41064 .51444 .41654 .52111 .42707 .50103 .42058 .51481 Mtetra
.059 0 .056 r
.42058 .51481 .42707 .50103 .43673 .51157 .43089 .50431 Mtetra
.577 .677 .908 r
.43089 .50431 .43673 .51157 .44681 .5093 .44096 .50305 Mtetra
.632 .732 .92 r
.44096 .50305 .44681 .5093 .45694 .50656 .45112 .50042 Mtetra
.64 .739 .921 r
.45112 .50042 .45694 .50656 .46711 .50373 .46131 .49759 Mtetra
.639 .739 .921 r
.46131 .49759 .46711 .50373 .47733 .50104 .47155 .49477 Mtetra
.624 .73 .923 r
.47155 .49477 .47733 .50104 .48757 .49937 .48182 .49229 Mtetra
.23 .508 .907 r
.48182 .49229 .48757 .49937 .49794 .48755 .49208 .49607 Mtetra
0 0 0 r
.49208 .49607 .49794 .48755 .50823 .48911 .50254 .48217 Mtetra
.605 .703 .913 r
.50254 .48217 .50823 .48911 .5186 .48647 .51293 .48017 Mtetra
.642 .739 .919 r
.51293 .48017 .5186 .48647 .52901 .48342 .52336 .47724 Mtetra
.65 .746 .92 r
.52336 .47724 .52901 .48342 .53946 .48022 .53384 .47407 Mtetra
.654 .749 .92 r
.53384 .47407 .53946 .48022 .54996 .47693 .54436 .47079 Mtetra
.656 .751 .92 r
.54436 .47079 .54996 .47693 .56049 .47358 .55491 .46744 Mtetra
.658 .753 .92 r
.55491 .46744 .56049 .47358 .57106 .47019 .56551 .46404 Mtetra
.659 .753 .92 r
.56551 .46404 .57106 .47019 .58167 .46677 .57615 .4606 Mtetra
.659 .754 .92 r
.57615 .4606 .58167 .46677 .59232 .46333 .58683 .45714 Mtetra
.58683 .45714 .59232 .46333 .60301 .45988 .59755 .45367 Mtetra
.59755 .45367 .60301 .45988 .61374 .45642 .60831 .45018 Mtetra
.658 .754 .92 r
.60831 .45018 .61374 .45642 .62452 .45296 .61911 .44669 Mtetra
.658 .753 .92 r
.61911 .44669 .62452 .45296 .63533 .44949 .62995 .44319 Mtetra
.62995 .44319 .63533 .44949 .64619 .44601 .64084 .43969 Mtetra
.64084 .43969 .64619 .44601 .65708 .44253 .65176 .43618 Mtetra
.65176 .43618 .65708 .44253 .66802 .43903 .66273 .43265 Mtetra
.66273 .43265 .66802 .43903 .67901 .43552 .67374 .42912 Mtetra
.67374 .42912 .67901 .43552 .69003 .432 .6848 .42557 Mtetra
.657 .753 .92 r
.6848 .42557 .69003 .432 .7011 .42847 .6959 .42201 Mtetra
.6959 .42201 .7011 .42847 .71221 .42493 .70704 .41844 Mtetra
.70704 .41844 .71221 .42493 .72336 .42137 .71822 .41486 Mtetra
.71822 .41486 .72336 .42137 .73456 .4178 .72945 .41126 Mtetra
.657 .752 .92 r
.72945 .41126 .73456 .4178 .7458 .41422 .74072 .40766 Mtetra
.74072 .40766 .7458 .41422 .75709 .41062 .75204 .40403 Mtetra
.75204 .40403 .75709 .41062 .76842 .40702 .7634 .4004 Mtetra
.7634 .4004 .76842 .40702 .7798 .4034 .77481 .39675 Mtetra
.77481 .39675 .7798 .4034 .79122 .39976 .78626 .39309 Mtetra
.78626 .39309 .79122 .39976 .80268 .39611 .79776 .38942 Mtetra
.79776 .38942 .80268 .39611 .81419 .39245 .80931 .38573 Mtetra
.80931 .38573 .81419 .39245 .82575 .38877 .8209 .38202 Mtetra
.8209 .38202 .82575 .38877 .83735 .38508 .83253 .37831 Mtetra
.83253 .37831 .83735 .38508 .849 .38138 .84421 .37457 Mtetra
.84421 .37457 .849 .38138 .8607 .37766 .85594 .37083 Mtetra
.85594 .37083 .8607 .37766 .87244 .37393 .86772 .36707 Mtetra
.573 .7 .928 r
.23901 .55999 .24528 .56627 .25442 .56709 .24833 .55876 Mtetra
.854 .711 .704 r
.24833 .55876 .25442 .56709 .26444 .55723 .25917 .53877 Mtetra
.135 .201 .667 r
.25917 .53877 .26444 .55723 .27378 .55653 .26757 .55016 Mtetra
.592 .704 .922 r
.26757 .55016 .27378 .55653 .28322 .55502 .27702 .54857 Mtetra
.519 .675 .935 r
.27702 .54857 .28322 .55502 .28615 .64868 .28644 .54825 Mtetra
.586 .385 .575 r
.28644 .54825 .28615 .64868 .3026 .5463 .29653 .53859 Mtetra
.53 .638 .901 r
.29653 .53859 .3026 .5463 .31216 .54467 .30601 .53841 Mtetra
.604 .715 .923 r
.30601 .53841 .31216 .54467 .32176 .54306 .31564 .53651 Mtetra
.497 .664 .937 r
.31564 .53651 .32176 .54306 .33347 .50556 .3252 .53654 Mtetra
.371 .094 .356 r
.3252 .53654 .33347 .50556 .34141 .53408 .33538 .52667 Mtetra
.553 .659 .906 r
.33538 .52667 .34141 .53408 .35113 .53221 .34506 .52596 Mtetra
.615 .721 .922 r
.34506 .52596 .35113 .53221 .36092 .53013 .35486 .52379 Mtetra
.586 .709 .928 r
.35486 .52379 .36092 .53013 .37057 .53172 .36468 .52222 Mtetra
.817 .7 .736 r
.36468 .52222 .37057 .53172 .38084 .52057 .37511 .50806 Mtetra
.353 .431 .802 r
.37511 .50806 .38084 .52057 .3907 .51919 .38472 .51277 Mtetra
.616 .719 .919 r
.38472 .51277 .3907 .51919 .40065 .51677 .39468 .51057 Mtetra
.627 .73 .922 r
.39468 .51057 .40065 .51677 .41064 .51444 .40469 .50808 Mtetra
.6 .716 .926 r
.40469 .50808 .41064 .51444 .42058 .51481 .41472 .50619 Mtetra
.866 .723 .703 r
.41472 .50619 .42058 .51481 .43089 .50431 .42536 .48598 Mtetra
.226 .27 .699 r
.42536 .48598 .43089 .50431 .44096 .50305 .43509 .49652 Mtetra
.619 .719 .918 r
.43509 .49652 .44096 .50305 .45112 .50042 .44525 .4942 Mtetra
.638 .737 .92 r
.44525 .4942 .45112 .50042 .46131 .49759 .45547 .4914 Mtetra
.64 .74 .921 r
.45547 .4914 .46131 .49759 .47155 .49477 .46573 .48853 Mtetra
.635 .737 .922 r
.46573 .48853 .47155 .49477 .48182 .49229 .47603 .48577 Mtetra
.589 .711 .928 r
.47603 .48577 .48182 .49229 .49208 .49607 .48636 .48405 Mtetra
.775 .662 .737 r
.48636 .48405 .49208 .49607 .50254 .48217 .49683 .47214 Mtetra
.473 .555 .859 r
.49683 .47214 .50254 .48217 .51293 .48017 .50721 .47366 Mtetra
.631 .729 .918 r
.50721 .47366 .51293 .48017 .52336 .47724 .51767 .47096 Mtetra
.647 .743 .92 r
.51767 .47096 .52336 .47724 .53384 .47407 .52817 .46785 Mtetra
.652 .748 .92 r
.52817 .46785 .53384 .47407 .54436 .47079 .53872 .4646 Mtetra
.655 .751 .92 r
.53872 .4646 .54436 .47079 .55491 .46744 .5493 .46125 Mtetra
.657 .752 .92 r
.5493 .46125 .55491 .46744 .56551 .46404 .55993 .45784 Mtetra
.658 .753 .92 r
.55993 .45784 .56551 .46404 .57615 .4606 .57059 .45439 Mtetra
.659 .754 .92 r
.57059 .45439 .57615 .4606 .58683 .45714 .5813 .45091 Mtetra
.5813 .45091 .58683 .45714 .59755 .45367 .59204 .44741 Mtetra
.59204 .44741 .59755 .45367 .60831 .45018 .60283 .44389 Mtetra
.60283 .44389 .60831 .45018 .61911 .44669 .61366 .44038 Mtetra
.658 .753 .92 r
.61366 .44038 .61911 .44669 .62995 .44319 .62453 .43685 Mtetra
.62453 .43685 .62995 .44319 .64084 .43969 .63545 .43332 Mtetra
.63545 .43332 .64084 .43969 .65176 .43618 .6464 .42978 Mtetra
.6464 .42978 .65176 .43618 .66273 .43265 .6574 .42623 Mtetra
.6574 .42623 .66273 .43265 .67374 .42912 .66844 .42267 Mtetra
.66844 .42267 .67374 .42912 .6848 .42557 .67953 .41909 Mtetra
.657 .753 .92 r
.67953 .41909 .6848 .42557 .6959 .42201 .69065 .41551 Mtetra
.69065 .41551 .6959 .42201 .70704 .41844 .70183 .41191 Mtetra
.70183 .41191 .70704 .41844 .71822 .41486 .71304 .4083 Mtetra
.71304 .4083 .71822 .41486 .72945 .41126 .7243 .40468 Mtetra
.7243 .40468 .72945 .41126 .74072 .40766 .73561 .40105 Mtetra
.657 .752 .92 r
.73561 .40105 .74072 .40766 .75204 .40403 .74695 .3974 Mtetra
.74695 .3974 .75204 .40403 .7634 .4004 .75835 .39374 Mtetra
.75835 .39374 .7634 .4004 .77481 .39675 .76979 .39006 Mtetra
.76979 .39006 .77481 .39675 .78626 .39309 .78127 .38637 Mtetra
.78127 .38637 .78626 .39309 .79776 .38942 .7928 .38267 Mtetra
.7928 .38267 .79776 .38942 .80931 .38573 .80438 .37895 Mtetra
.80438 .37895 .80931 .38573 .8209 .38202 .816 .37522 Mtetra
.816 .37522 .8209 .38202 .83253 .37831 .82767 .37148 Mtetra
.82767 .37148 .83253 .37831 .84421 .37457 .83939 .36772 Mtetra
.83939 .36772 .84421 .37457 .85594 .37083 .85115 .36394 Mtetra
.85115 .36394 .85594 .37083 .86772 .36707 .86297 .36015 Mtetra
.581 .697 .922 r
.23271 .55353 .23901 .55999 .24833 .55876 .24205 .55216 Mtetra
.442 .637 .938 r
.24205 .55216 .24833 .55876 .25917 .53877 .25127 .55294 Mtetra
.033 0 .021 r
.25127 .55294 .25917 .53877 .26757 .55016 .26137 .54299 Mtetra
.553 .665 .911 r
.26137 .54299 .26757 .55016 .27702 .54857 .27078 .54226 Mtetra
.588 .707 .926 r
.27078 .54226 .27702 .54857 .28644 .54825 .28029 .5407 Mtetra
.951 .661 .45 r
.28029 .5407 .28644 .54825 .29653 .53859 .28317 .63475 Mtetra
0 0 .118 r
.28317 .63475 .29653 .53859 .30601 .53841 .29984 .53186 Mtetra
.594 .703 .919 r
.29984 .53186 .30601 .53841 .31564 .53651 .30947 .53019 Mtetra
.591 .71 .926 r
.30947 .53019 .31564 .53651 .3252 .53654 .31915 .52853 Mtetra
.905 .717 .638 r
.31915 .52853 .3252 .53654 .33538 .52667 .33098 .49083 Mtetra
0 0 .498 r
.33098 .49083 .33538 .52667 .34506 .52596 .33896 .51943 Mtetra
.604 .71 .919 r
.33896 .51943 .34506 .52596 .35486 .52379 .34877 .51751 Mtetra
.612 .722 .924 r
.34877 .51751 .35486 .52379 .36468 .52222 .35863 .51538 Mtetra
.391 .607 .935 r
.35863 .51538 .36468 .52222 .37511 .50806 .36836 .51694 Mtetra
0 0 0 r
.36836 .51694 .37511 .50806 .38472 .51277 .37872 .50569 Mtetra
.582 .686 .912 r
.37872 .50569 .38472 .51277 .39468 .51057 .38866 .50427 Mtetra
.625 .728 .921 r
.38866 .50427 .39468 .51057 .40469 .50808 .3987 .5018 Mtetra
.621 .728 .923 r
.3987 .5018 .40469 .50808 .41472 .50619 .40877 .49941 Mtetra
.478 .653 .936 r
.40877 .49941 .41472 .50619 .42536 .48598 .4188 .49974 Mtetra
.046 0 .044 r
.4188 .49974 .42536 .48598 .43509 .49652 .4292 .48916 Mtetra
.577 .677 .908 r
.4292 .48916 .43509 .49652 .44525 .4942 .43935 .48784 Mtetra
.632 .732 .92 r
.43935 .48784 .44525 .4942 .45547 .4914 .44959 .48516 Mtetra
.64 .739 .921 r
.44959 .48516 .45547 .4914 .46573 .48853 .45988 .48227 Mtetra
.639 .739 .921 r
.45988 .48227 .46573 .48853 .47603 .48577 .4702 .47939 Mtetra
.624 .73 .923 r
.4702 .47939 .47603 .48577 .48636 .48405 .48057 .47687 Mtetra
.233 .509 .907 r
.48057 .47687 .48636 .48405 .49683 .47214 .49091 .48062 Mtetra
0 0 0 r
.49091 .48062 .49683 .47214 .50721 .47366 .50146 .46661 Mtetra
.605 .703 .913 r
.50146 .46661 .50721 .47366 .51767 .47096 .51194 .46456 Mtetra
.642 .739 .919 r
.51194 .46456 .51767 .47096 .52817 .46785 .52247 .46156 Mtetra
.65 .746 .92 r
.52247 .46156 .52817 .46785 .53872 .4646 .53304 .45834 Mtetra
.654 .749 .92 r
.53304 .45834 .53872 .4646 .5493 .46125 .54365 .455 Mtetra
.656 .751 .92 r
.54365 .455 .5493 .46125 .55993 .45784 .5543 .45159 Mtetra
.658 .753 .92 r
.5543 .45159 .55993 .45784 .57059 .45439 .56499 .44813 Mtetra
.659 .753 .92 r
.56499 .44813 .57059 .45439 .5813 .45091 .57573 .44463 Mtetra
.659 .754 .92 r
.57573 .44463 .5813 .45091 .59204 .44741 .5865 .4411 Mtetra
.5865 .4411 .59204 .44741 .60283 .44389 .59732 .43756 Mtetra
.59732 .43756 .60283 .44389 .61366 .44038 .60818 .43402 Mtetra
.658 .754 .92 r
.60818 .43402 .61366 .44038 .62453 .43685 .61908 .43046 Mtetra
.658 .753 .92 r
.61908 .43046 .62453 .43685 .63545 .43332 .63002 .4269 Mtetra
.63002 .4269 .63545 .43332 .6464 .42978 .641 .42334 Mtetra
.641 .42334 .6464 .42978 .6574 .42623 .65203 .41976 Mtetra
.65203 .41976 .6574 .42623 .66844 .42267 .6631 .41617 Mtetra
.6631 .41617 .66844 .42267 .67953 .41909 .67422 .41257 Mtetra
.67422 .41257 .67953 .41909 .69065 .41551 .68537 .40896 Mtetra
.657 .753 .92 r
.68537 .40896 .69065 .41551 .70183 .41191 .69658 .40533 Mtetra
.69658 .40533 .70183 .41191 .71304 .4083 .70782 .4017 Mtetra
.70782 .4017 .71304 .4083 .7243 .40468 .71911 .39805 Mtetra
.71911 .39805 .7243 .40468 .73561 .40105 .73045 .39439 Mtetra
.657 .752 .92 r
.73045 .39439 .73561 .40105 .74695 .3974 .74183 .39071 Mtetra
.74183 .39071 .74695 .3974 .75835 .39374 .75326 .38702 Mtetra
.75326 .38702 .75835 .39374 .76979 .39006 .76473 .38332 Mtetra
.76473 .38332 .76979 .39006 .78127 .38637 .77624 .3796 Mtetra
.77624 .3796 .78127 .38637 .7928 .38267 .78781 .37587 Mtetra
.78781 .37587 .7928 .38267 .80438 .37895 .79942 .37213 Mtetra
.79942 .37213 .80438 .37895 .816 .37522 .81107 .36837 Mtetra
.81107 .36837 .816 .37522 .82767 .37148 .82278 .3646 Mtetra
.82278 .3646 .82767 .37148 .83939 .36772 .83453 .36081 Mtetra
.83453 .36081 .83939 .36772 .85115 .36394 .84633 .357 Mtetra
.84633 .357 .85115 .36394 .86297 .36015 .85817 .35319 Mtetra
.527 .642 .906 r
.22647 .54598 .23271 .55353 .24205 .55216 .23572 .54578 Mtetra
.573 .7 .928 r
.23572 .54578 .24205 .55216 .25127 .55294 .24511 .5445 Mtetra
.855 .712 .703 r
.24511 .5445 .25127 .55294 .26137 .54299 .25606 .52438 Mtetra
.132 .198 .666 r
.25606 .52438 .26137 .54299 .27078 .54226 .2645 .53578 Mtetra
.592 .705 .922 r
.2645 .53578 .27078 .54226 .28029 .5407 .27404 .53415 Mtetra
.519 .675 .935 r
.27404 .53415 .28029 .5407 .28317 .63475 .28352 .53379 Mtetra
.585 .383 .574 r
.28352 .53379 .28317 .63475 .29984 .53186 .29371 .52405 Mtetra
.529 .638 .902 r
.29371 .52405 .29984 .53186 .30947 .53019 .30326 .52383 Mtetra
.604 .715 .923 r
.30326 .52383 .30947 .53019 .31915 .52853 .31297 .52188 Mtetra
.497 .664 .936 r
.31297 .52188 .31915 .52853 .33098 .49083 .32261 .52187 Mtetra
.365 .085 .35 r
.32261 .52187 .33098 .49083 .33896 .51943 .33287 .51191 Mtetra
.553 .659 .906 r
.33287 .51191 .33896 .51943 .34877 .51751 .34263 .51115 Mtetra
.615 .721 .922 r
.34263 .51115 .34877 .51751 .35863 .51538 .35252 .50894 Mtetra
.586 .709 .928 r
.35252 .50894 .35863 .51538 .36836 .51694 .36241 .50732 Mtetra
.817 .701 .736 r
.36241 .50732 .36836 .51694 .37872 .50569 .37294 .49305 Mtetra
.351 .43 .802 r
.37294 .49305 .37872 .50569 .38866 .50427 .38262 .49775 Mtetra
.616 .719 .919 r
.38262 .49775 .38866 .50427 .3987 .5018 .39266 .49549 Mtetra
.627 .73 .922 r
.39266 .49549 .3987 .5018 .40877 .49941 .40276 .49295 Mtetra
.6 .716 .926 r
.40276 .49295 .40877 .49941 .4188 .49974 .41288 .49101 Mtetra
.866 .724 .703 r
.41288 .49101 .4188 .49974 .4292 .48916 .42361 .47067 Mtetra
.223 .268 .699 r
.42361 .47067 .4292 .48916 .43935 .48784 .43342 .48121 Mtetra
.619 .719 .918 r
.43342 .48121 .43935 .48784 .44959 .48516 .44367 .47883 Mtetra
.638 .737 .92 r
.44367 .47883 .44959 .48516 .45988 .48227 .45398 .47598 Mtetra
.64 .74 .921 r
.45398 .47598 .45988 .48227 .4702 .47939 .46433 .47304 Mtetra
.635 .737 .922 r
.46433 .47304 .4702 .47939 .48057 .47687 .47472 .47024 Mtetra
.589 .711 .928 r
.47472 .47024 .48057 .47687 .49091 .48062 .48514 .46846 Mtetra
.776 .662 .738 r
.48514 .46846 .49091 .48062 .50146 .46661 .4957 .45646 Mtetra
.473 .555 .859 r
.4957 .45646 .50146 .46661 .51194 .46456 .50617 .45794 Mtetra
.631 .729 .918 r
.50617 .45794 .51194 .46456 .52247 .46156 .51672 .45518 Mtetra
.647 .743 .92 r
.51672 .45518 .52247 .46156 .53304 .45834 .52732 .45201 Mtetra
.652 .748 .92 r
.52732 .45201 .53304 .45834 .54365 .455 .53796 .44869 Mtetra
.655 .751 .92 r
.53796 .44869 .54365 .455 .5543 .45159 .54864 .44529 Mtetra
.657 .752 .92 r
.54864 .44529 .5543 .45159 .56499 .44813 .55936 .44182 Mtetra
.658 .753 .92 r
.55936 .44182 .56499 .44813 .57573 .44463 .57012 .4383 Mtetra
.659 .754 .92 r
.57012 .4383 .57573 .44463 .5865 .4411 .58092 .43475 Mtetra
.58092 .43475 .5865 .4411 .59732 .43756 .59177 .43119 Mtetra
.59177 .43119 .59732 .43756 .60818 .43402 .60265 .42762 Mtetra
.60265 .42762 .60818 .43402 .61908 .43046 .61358 .42403 Mtetra
.658 .753 .92 r
.61358 .42403 .61908 .43046 .63002 .4269 .62455 .42044 Mtetra
.62455 .42044 .63002 .4269 .641 .42334 .63557 .41685 Mtetra
.63557 .41685 .641 .42334 .65203 .41976 .64662 .41324 Mtetra
.64662 .41324 .65203 .41976 .6631 .41617 .65772 .40962 Mtetra
.65772 .40962 .6631 .41617 .67422 .41257 .66887 .406 Mtetra
.66887 .406 .67422 .41257 .68537 .40896 .68006 .40236 Mtetra
.657 .753 .92 r
.68006 .40236 .68537 .40896 .69658 .40533 .69129 .39871 Mtetra
.69129 .39871 .69658 .40533 .70782 .4017 .70257 .39504 Mtetra
.70257 .39504 .70782 .4017 .71911 .39805 .71389 .39137 Mtetra
.71389 .39137 .71911 .39805 .73045 .39439 .72525 .38768 Mtetra
.72525 .38768 .73045 .39439 .74183 .39071 .73667 .38397 Mtetra
.657 .752 .92 r
.73667 .38397 .74183 .39071 .75326 .38702 .74813 .38026 Mtetra
.74813 .38026 .75326 .38702 .76473 .38332 .75963 .37653 Mtetra
.75963 .37653 .76473 .38332 .77624 .3796 .77118 .37278 Mtetra
.77118 .37278 .77624 .3796 .78781 .37587 .78278 .36902 Mtetra
.78278 .36902 .78781 .37587 .79942 .37213 .79442 .36525 Mtetra
.79442 .36525 .79942 .37213 .81107 .36837 .80611 .36146 Mtetra
.80611 .36146 .81107 .36837 .82278 .3646 .81785 .35766 Mtetra
.81785 .35766 .82278 .3646 .83453 .36081 .82963 .35385 Mtetra
.82963 .35385 .83453 .36081 .84633 .357 .84146 .35002 Mtetra
.84146 .35002 .84633 .357 .85817 .35319 .85335 .34617 Mtetra
0 0 .271 r
.22833 .44862 .22647 .54598 .23572 .54578 .22936 .53921 Mtetra
.581 .697 .922 r
.22936 .53921 .23572 .54578 .24511 .5445 .23877 .5378 Mtetra
.443 .637 .938 r
.23877 .5378 .24511 .5445 .25606 .52438 .24806 .53854 Mtetra
.02 0 .007 r
.24806 .53854 .25606 .52438 .2645 .53578 .25825 .52852 Mtetra
.553 .665 .911 r
.25825 .52852 .2645 .53578 .27404 .53415 .26773 .52773 Mtetra
.588 .707 .926 r
.26773 .52773 .27404 .53415 .28352 .53379 .27732 .52613 Mtetra
.952 .66 .447 r
.27732 .52613 .28352 .53379 .29371 .52405 .28013 .62057 Mtetra
0 0 .11 r
.28013 .62057 .29371 .52405 .30326 .52383 .29702 .51717 Mtetra
.594 .703 .919 r
.29702 .51717 .30326 .52383 .31297 .52188 .30674 .51545 Mtetra
.591 .71 .926 r
.30674 .51545 .31297 .52188 .32261 .52187 .31649 .51374 Mtetra
.906 .717 .637 r
.31649 .51374 .32261 .52187 .33287 .51191 .32845 .47584 Mtetra
0 0 .495 r
.32845 .47584 .33287 .51191 .34263 .51115 .33647 .50453 Mtetra
.604 .71 .919 r
.33647 .50453 .34263 .51115 .35252 .50894 .34636 .50255 Mtetra
.612 .722 .924 r
.34636 .50255 .35252 .50894 .36241 .50732 .3563 .50037 Mtetra
.392 .607 .935 r
.3563 .50037 .36241 .50732 .37294 .49305 .36611 .50189 Mtetra
0 0 0 r
.36611 .50189 .37294 .49305 .38262 .49775 .37656 .49055 Mtetra
.582 .686 .912 r
.37656 .49055 .38262 .49775 .39266 .49549 .38659 .48908 Mtetra
.625 .728 .921 r
.38659 .48908 .39266 .49549 .40276 .49295 .39671 .48656 Mtetra
.621 .728 .923 r
.39671 .48656 .40276 .49295 .41288 .49101 .40686 .48412 Mtetra
.479 .653 .936 r
.40686 .48412 .41288 .49101 .42361 .47067 .41698 .4844 Mtetra
.033 0 .03 r
.41698 .4844 .42361 .47067 .43342 .48121 .42747 .47373 Mtetra
.577 .677 .908 r
.42747 .47373 .43342 .48121 .44367 .47883 .43772 .47237 Mtetra
.632 .732 .92 r
.43772 .47237 .44367 .47883 .45398 .47598 .44804 .46963 Mtetra
.64 .739 .921 r
.44804 .46963 .45398 .47598 .46433 .47304 .45842 .46668 Mtetra
.639 .739 .921 r
.45842 .46668 .46433 .47304 .47472 .47024 .46883 .46374 Mtetra
.624 .73 .923 r
.46883 .46374 .47472 .47024 .48514 .46846 .47928 .46116 Mtetra
.235 .51 .907 r
.47928 .46116 .48514 .46846 .4957 .45646 .48972 .46488 Mtetra
0 0 0 r
.48972 .46488 .4957 .45646 .50617 .45794 .50037 .45077 Mtetra
.605 .703 .913 r
.50037 .45077 .50617 .45794 .51672 .45518 .51094 .44866 Mtetra
.642 .739 .919 r
.51094 .44866 .51672 .45518 .52732 .45201 .52156 .44561 Mtetra
.65 .746 .92 r
.52156 .44561 .52732 .45201 .53796 .44869 .53222 .44232 Mtetra
.654 .749 .92 r
.53222 .44232 .53796 .44869 .54864 .44529 .54293 .43892 Mtetra
.656 .751 .92 r
.54293 .43892 .54864 .44529 .55936 .44182 .55368 .43545 Mtetra
.658 .753 .92 r
.55368 .43545 .55936 .44182 .57012 .4383 .56447 .43192 Mtetra
.659 .753 .92 r
.56447 .43192 .57012 .4383 .58092 .43475 .5753 .42836 Mtetra
.659 .754 .92 r
.5753 .42836 .58092 .43475 .59177 .43119 .58617 .42477 Mtetra
.58617 .42477 .59177 .43119 .60265 .42762 .59709 .42117 Mtetra
.59709 .42117 .60265 .42762 .61358 .42403 .60804 .41756 Mtetra
.658 .754 .92 r
.60804 .41756 .61358 .42403 .62455 .42044 .61904 .41394 Mtetra
.658 .753 .92 r
.61904 .41394 .62455 .42044 .63557 .41685 .63009 .41031 Mtetra
.63009 .41031 .63557 .41685 .64662 .41324 .64117 .40668 Mtetra
.64117 .40668 .64662 .41324 .65772 .40962 .65231 .40303 Mtetra
.65231 .40303 .65772 .40962 .66887 .406 .66348 .39938 Mtetra
.66348 .39938 .66887 .406 .68006 .40236 .6747 .39571 Mtetra
.6747 .39571 .68006 .40236 .69129 .39871 .68596 .39203 Mtetra
.657 .753 .92 r
.68596 .39203 .69129 .39871 .70257 .39504 .69727 .38834 Mtetra
.69727 .38834 .70257 .39504 .71389 .39137 .70862 .38464 Mtetra
.70862 .38464 .71389 .39137 .72525 .38768 .72002 .38092 Mtetra
.72002 .38092 .72525 .38768 .73667 .38397 .73147 .37719 Mtetra
.657 .752 .92 r
.73147 .37719 .73667 .38397 .74813 .38026 .74296 .37344 Mtetra
.74296 .37344 .74813 .38026 .75963 .37653 .75449 .36969 Mtetra
.75449 .36969 .75963 .37653 .77118 .37278 .76608 .36591 Mtetra
.76608 .36591 .77118 .37278 .78278 .36902 .77771 .36213 Mtetra
.77771 .36213 .78278 .36902 .79442 .36525 .78938 .35833 Mtetra
.78938 .35833 .79442 .36525 .80611 .36146 .80111 .35451 Mtetra
.80111 .35451 .80611 .36146 .81785 .35766 .81288 .35068 Mtetra
.81288 .35068 .81785 .35766 .82963 .35385 .8247 .34683 Mtetra
.8247 .34683 .82963 .35385 .84146 .35002 .83656 .34297 Mtetra
.83656 .34297 .84146 .35002 .85335 .34617 .84848 .3391 Mtetra
.489 .248 .475 r
.21291 .54115 .22833 .44862 .22936 .53921 .22305 .53156 Mtetra
.527 .642 .906 r
.22305 .53156 .22936 .53921 .23877 .5378 .23237 .53132 Mtetra
.573 .7 .927 r
.23237 .53132 .23877 .5378 .24806 .53854 .24184 .52999 Mtetra
.856 .713 .703 r
.24184 .52999 .24806 .53854 .25825 .52852 .25289 .50975 Mtetra
.128 .196 .665 r
.25289 .50975 .25825 .52852 .26773 .52773 .26139 .52116 Mtetra
.592 .705 .922 r
.26139 .52116 .26773 .52773 .27732 .52613 .271 .51947 Mtetra
.519 .675 .935 r
.271 .51947 .27732 .52613 .28013 .62057 .28056 .51908 Mtetra
.583 .38 .572 r
.28056 .51908 .28013 .62057 .29702 .51717 .29083 .50925 Mtetra
.529 .638 .902 r
.29083 .50925 .29702 .51717 .30674 .51545 .30046 .50899 Mtetra
.604 .715 .923 r
.30046 .50899 .30674 .51545 .31649 .51374 .31025 .50698 Mtetra
.498 .664 .936 r
.31025 .50698 .31649 .51374 .32845 .47584 .31997 .50693 Mtetra
.358 .077 .343 r
.31997 .50693 .32845 .47584 .33647 .50453 .33032 .49689 Mtetra
.553 .659 .907 r
.33032 .49689 .33647 .50453 .34636 .50255 .34016 .49609 Mtetra
.615 .721 .922 r
.34016 .49609 .34636 .50255 .3563 .50037 .35013 .49382 Mtetra
.586 .709 .928 r
.35013 .49382 .3563 .50037 .36611 .50189 .36011 .49215 Mtetra
.818 .702 .737 r
.36011 .49215 .36611 .50189 .37656 .49055 .37073 .47778 Mtetra
.35 .429 .802 r
.37073 .47778 .37656 .49055 .38659 .48908 .38048 .48245 Mtetra
.616 .719 .919 r
.38048 .48245 .38659 .48908 .39671 .48656 .39061 .48014 Mtetra
.627 .73 .922 r
.39061 .48014 .39671 .48656 .40686 .48412 .4008 .47754 Mtetra
.6 .716 .926 r
.4008 .47754 .40686 .48412 .41698 .4844 .411 .47555 Mtetra
.867 .725 .703 r
.411 .47555 .41698 .4844 .42747 .47373 .42184 .45508 Mtetra
.22 .266 .698 r
.42184 .45508 .42747 .47373 .43772 .47237 .43172 .46562 Mtetra
.619 .719 .918 r
.43172 .46562 .43772 .47237 .44804 .46963 .44206 .46319 Mtetra
.638 .737 .92 r
.44206 .46319 .44804 .46963 .45842 .46668 .45246 .46028 Mtetra
.64 .74 .921 r
.45246 .46028 .45842 .46668 .46883 .46374 .4629 .45728 Mtetra
.635 .737 .922 r
.4629 .45728 .46883 .46374 .47928 .46116 .47338 .45442 Mtetra
.589 .711 .928 r
.47338 .45442 .47928 .46116 .48972 .46488 .48389 .45259 Mtetra
.776 .663 .738 r
.48389 .45259 .48972 .46488 .50037 .45077 .49455 .44048 Mtetra
.472 .555 .859 r
.49455 .44048 .50037 .45077 .51094 .44866 .50511 .44192 Mtetra
.631 .729 .918 r
.50511 .44192 .51094 .44866 .52156 .44561 .51576 .43911 Mtetra
.647 .743 .92 r
.51576 .43911 .52156 .44561 .53222 .44232 .52645 .43588 Mtetra
.652 .748 .92 r
.52645 .43588 .53222 .44232 .54293 .43892 .53718 .4325 Mtetra
.655 .751 .92 r
.53718 .4325 .54293 .43892 .55368 .43545 .54796 .42903 Mtetra
.657 .752 .92 r
.54796 .42903 .55368 .43545 .56447 .43192 .55878 .42549 Mtetra
.658 .753 .92 r
.55878 .42549 .56447 .43192 .5753 .42836 .56964 .42191 Mtetra
.659 .754 .92 r
.56964 .42191 .5753 .42836 .58617 .42477 .58054 .4183 Mtetra
.58054 .4183 .58617 .42477 .59709 .42117 .59148 .41467 Mtetra
.59148 .41467 .59709 .42117 .60804 .41756 .60247 .41103 Mtetra
.60247 .41103 .60804 .41756 .61904 .41394 .6135 .40739 Mtetra
.658 .753 .92 r
.6135 .40739 .61904 .41394 .63009 .41031 .62457 .40373 Mtetra
.62457 .40373 .63009 .41031 .64117 .40668 .63569 .40007 Mtetra
.63569 .40007 .64117 .40668 .65231 .40303 .64685 .39639 Mtetra
.64685 .39639 .65231 .40303 .66348 .39938 .65805 .39271 Mtetra
.65805 .39271 .66348 .39938 .6747 .39571 .6693 .38902 Mtetra
.6693 .38902 .6747 .39571 .68596 .39203 .6806 .38531 Mtetra
.657 .753 .92 r
.6806 .38531 .68596 .39203 .69727 .38834 .69194 .38159 Mtetra
.69194 .38159 .69727 .38834 .70862 .38464 .70332 .37786 Mtetra
.70332 .37786 .70862 .38464 .72002 .38092 .71475 .37411 Mtetra
.71475 .37411 .72002 .38092 .73147 .37719 .72623 .37035 Mtetra
.72623 .37035 .73147 .37719 .74296 .37344 .73775 .36658 Mtetra
.657 .752 .92 r
.73775 .36658 .74296 .37344 .75449 .36969 .74932 .36279 Mtetra
.74932 .36279 .75449 .36969 .76608 .36591 .76093 .35899 Mtetra
.76093 .35899 .76608 .36591 .77771 .36213 .7726 .35518 Mtetra
.7726 .35518 .77771 .36213 .78938 .35833 .78431 .35135 Mtetra
.78431 .35135 .78938 .35833 .80111 .35451 .79607 .3475 Mtetra
.79607 .3475 .80111 .35451 .81288 .35068 .80787 .34364 Mtetra
.80787 .34364 .81288 .35068 .8247 .34683 .81973 .33977 Mtetra
.81973 .33977 .8247 .34683 .83656 .34297 .83163 .33588 Mtetra
.83163 .33588 .83656 .34297 .84848 .3391 .84358 .33197 Mtetra
.923 .698 .579 r
.20656 .53328 .21291 .54115 .22305 .53156 .22501 .43373 Mtetra
0 0 .265 r
.22501 .43373 .22305 .53156 .23237 .53132 .22595 .52465 Mtetra
.581 .697 .922 r
.22595 .52465 .23237 .53132 .24184 .52999 .23544 .52319 Mtetra
.444 .637 .938 r
.23544 .52319 .24184 .52999 .25289 .50975 .24479 .5239 Mtetra
.005 0 0 r
.24479 .5239 .25289 .50975 .26139 .52116 .25507 .51378 Mtetra
.552 .665 .912 r
.25507 .51378 .26139 .52116 .271 .51947 .26463 .51296 Mtetra
.588 .707 .926 r
.26463 .51296 .271 .51947 .28056 .51908 .27429 .51131 Mtetra
.953 .66 .444 r
.27429 .51131 .28056 .51908 .29083 .50925 .27703 .60614 Mtetra
0 0 .103 r
.27703 .60614 .29083 .50925 .30046 .50899 .29416 .50223 Mtetra
.594 .703 .919 r
.29416 .50223 .30046 .50899 .31025 .50698 .30395 .50045 Mtetra
.591 .71 .926 r
.30395 .50045 .31025 .50698 .31997 .50693 .31379 .4987 Mtetra
.907 .718 .636 r
.31379 .4987 .31997 .50693 .33032 .49689 .32588 .46059 Mtetra
0 0 .492 r
.32588 .46059 .33032 .49689 .34016 .49609 .33394 .48935 Mtetra
.604 .71 .919 r
.33394 .48935 .34016 .49609 .35013 .49382 .34391 .48733 Mtetra
.612 .722 .924 r
.34391 .48733 .35013 .49382 .36011 .49215 .35393 .4851 Mtetra
.393 .607 .935 r
.35393 .4851 .36011 .49215 .37073 .47778 .36382 .48658 Mtetra
0 0 0 r
.36382 .48658 .37073 .47778 .38048 .48245 .37437 .47515 Mtetra
.582 .686 .912 r
.37437 .47515 .38048 .48245 .39061 .48014 .38448 .47362 Mtetra
.625 .728 .921 r
.38448 .47362 .39061 .48014 .4008 .47754 .39468 .47104 Mtetra
.621 .728 .923 r
.39468 .47104 .4008 .47754 .411 .47555 .40493 .46855 Mtetra
.479 .653 .936 r
.40493 .46855 .411 .47555 .42184 .45508 .41512 .46879 Mtetra
.02 0 .017 r
.41512 .46879 .42184 .45508 .43172 .46562 .42572 .45803 Mtetra
.577 .677 .908 r
.42572 .45803 .43172 .46562 .44206 .46319 .43605 .45661 Mtetra
.632 .732 .92 r
.43605 .45661 .44206 .46319 .45246 .46028 .44646 .45381 Mtetra
.64 .739 .921 r
.44646 .45381 .45246 .46028 .4629 .45728 .45693 .45081 Mtetra
.639 .739 .921 r
.45693 .45081 .4629 .45728 .47338 .45442 .46743 .44781 Mtetra
.624 .73 .923 r
.46743 .44781 .47338 .45442 .48389 .45259 .47798 .44517 Mtetra
.238 .511 .907 r
.47798 .44517 .48389 .45259 .49455 .44048 .4885 .44886 Mtetra
0 0 0 r
.4885 .44886 .49455 .44048 .50511 .44192 .49925 .43464 Mtetra
.605 .703 .913 r
.49925 .43464 .50511 .44192 .51576 .43911 .50992 .43247 Mtetra
.642 .739 .919 r
.50992 .43247 .51576 .43911 .52645 .43588 .52063 .42936 Mtetra
.65 .746 .92 r
.52063 .42936 .52645 .43588 .53718 .4325 .53139 .42601 Mtetra
.654 .749 .92 r
.53139 .42601 .53718 .4325 .54796 .42903 .5422 .42255 Mtetra
.656 .751 .92 r
.5422 .42255 .54796 .42903 .55878 .42549 .55304 .41901 Mtetra
.658 .753 .92 r
.55304 .41901 .55878 .42549 .56964 .42191 .56393 .41542 Mtetra
.659 .753 .92 r
.56393 .41542 .56964 .42191 .58054 .4183 .57486 .41179 Mtetra
.659 .754 .92 r
.57486 .41179 .58054 .4183 .59148 .41467 .58583 .40813 Mtetra
.58583 .40813 .59148 .41467 .60247 .41103 .59685 .40447 Mtetra
.59685 .40447 .60247 .41103 .6135 .40739 .60791 .40079 Mtetra
.658 .754 .92 r
.60791 .40079 .6135 .40739 .62457 .40373 .61901 .3971 Mtetra
.658 .753 .92 r
.61901 .3971 .62457 .40373 .63569 .40007 .63016 .39341 Mtetra
.63016 .39341 .63569 .40007 .64685 .39639 .64135 .38971 Mtetra
.64135 .38971 .64685 .39639 .65805 .39271 .65258 .386 Mtetra
.65258 .386 .65805 .39271 .6693 .38902 .66386 .38227 Mtetra
.66386 .38227 .6693 .38902 .6806 .38531 .67519 .37854 Mtetra
.67519 .37854 .6806 .38531 .69194 .38159 .68656 .37479 Mtetra
.657 .753 .92 r
.68656 .37479 .69194 .38159 .70332 .37786 .69798 .37103 Mtetra
.69798 .37103 .70332 .37786 .71475 .37411 .70944 .36725 Mtetra
.70944 .36725 .71475 .37411 .72623 .37035 .72095 .36347 Mtetra
.72095 .36347 .72623 .37035 .73775 .36658 .7325 .35967 Mtetra
.657 .752 .92 r
.7325 .35967 .73775 .36658 .74932 .36279 .74411 .35585 Mtetra
.74411 .35585 .74932 .36279 .76093 .35899 .75575 .35202 Mtetra
.75575 .35202 .76093 .35899 .7726 .35518 .76745 .34818 Mtetra
.76745 .34818 .7726 .35518 .78431 .35135 .77919 .34432 Mtetra
.77919 .34432 .78431 .35135 .79607 .3475 .79099 .34044 Mtetra
.79099 .34044 .79607 .3475 .80787 .34364 .80283 .33655 Mtetra
.80283 .33655 .80787 .34364 .81973 .33977 .81472 .33265 Mtetra
.81472 .33265 .81973 .33977 .83163 .33588 .82665 .32873 Mtetra
.82665 .32873 .83163 .33588 .84358 .33197 .83864 .32479 Mtetra
.491 .66 .937 r
.20006 .52654 .20656 .53328 .22501 .43373 .20935 .52656 Mtetra
.485 .243 .471 r
.20935 .52656 .22501 .43373 .22595 .52465 .21957 .51689 Mtetra
.526 .642 .907 r
.21957 .51689 .22595 .52465 .23544 .52319 .22897 .5166 Mtetra
.573 .7 .927 r
.22897 .5166 .23544 .52319 .24479 .5239 .23851 .51523 Mtetra
.857 .714 .703 r
.23851 .51523 .24479 .5239 .25507 .51378 .24967 .49486 Mtetra
.124 .193 .664 r
.24967 .49486 .25507 .51378 .26463 .51296 .25822 .50628 Mtetra
.592 .705 .922 r
.25822 .50628 .26463 .51296 .27429 .51131 .26791 .50454 Mtetra
.52 .675 .935 r
.26791 .50454 .27429 .51131 .27703 .60614 .27755 .5041 Mtetra
.581 .377 .57 r
.27755 .5041 .27703 .60614 .29416 .50223 .28791 .49419 Mtetra
.529 .638 .902 r
.28791 .49419 .29416 .50223 .30395 .50045 .29761 .49388 Mtetra
.604 .715 .923 r
.29761 .49388 .30395 .50045 .31379 .4987 .30749 .49183 Mtetra
.498 .664 .936 r
.30749 .49183 .31379 .4987 .32588 .46059 .31728 .49174 Mtetra
.351 .068 .336 r
.31728 .49174 .32588 .46059 .33394 .48935 .32773 .48161 Mtetra
.553 .659 .907 r
.32773 .48161 .33394 .48935 .34391 .48733 .33765 .48076 Mtetra
.615 .721 .922 r
.33765 .48076 .34391 .48733 .35393 .4851 .3477 .47843 Mtetra
.586 .709 .928 r
.3477 .47843 .35393 .4851 .36382 .48658 .35776 .47671 Mtetra
.819 .702 .737 r
.35776 .47671 .36382 .48658 .37437 .47515 .36848 .46224 Mtetra
.348 .428 .802 r
.36848 .46224 .37437 .47515 .38448 .47362 .37831 .46688 Mtetra
.616 .719 .919 r
.37831 .46688 .38448 .47362 .39468 .47104 .38853 .46452 Mtetra
.627 .73 .922 r
.38853 .46452 .39468 .47104 .40493 .46855 .3988 .46186 Mtetra
.6 .716 .926 r
.3988 .46186 .40493 .46855 .41512 .46879 .40909 .45981 Mtetra
.868 .726 .702 r
.40909 .45981 .41512 .46879 .42572 .45803 .42003 .43921 Mtetra
.218 .264 .697 r
.42003 .43921 .42572 .45803 .43605 .45661 .42999 .44975 Mtetra
.619 .719 .918 r
.42999 .44975 .43605 .45661 .44646 .45381 .44043 .44726 Mtetra
.638 .737 .92 r
.44043 .44726 .44646 .45381 .45693 .45081 .45091 .44429 Mtetra
.64 .74 .921 r
.45091 .44429 .45693 .45081 .46743 .44781 .46144 .44123 Mtetra
.635 .737 .922 r
.46144 .44123 .46743 .44781 .47798 .44517 .47202 .43831 Mtetra
.59 .711 .928 r
.47202 .43831 .47798 .44517 .4885 .44886 .48262 .43642 Mtetra
.777 .664 .738 r
.48262 .43642 .4885 .44886 .49925 .43464 .49338 .42422 Mtetra
.472 .555 .859 r
.49338 .42422 .49925 .43464 .50992 .43247 .50403 .42562 Mtetra
.631 .729 .918 r
.50403 .42562 .50992 .43247 .52063 .42936 .51477 .42274 Mtetra
.647 .743 .92 r
.51477 .42274 .52063 .42936 .53139 .42601 .52556 .41945 Mtetra
.652 .748 .92 r
.52556 .41945 .53139 .42601 .5422 .42255 .53639 .416 Mtetra
.655 .751 .92 r
.53639 .416 .5422 .42255 .55304 .41901 .54727 .41247 Mtetra
.657 .752 .92 r
.54727 .41247 .55304 .41901 .56393 .41542 .55818 .40887 Mtetra
.658 .753 .92 r
.55818 .40887 .56393 .41542 .57486 .41179 .56914 .40522 Mtetra
.659 .754 .92 r
.56914 .40522 .57486 .41179 .58583 .40813 .58015 .40155 Mtetra
.58015 .40155 .58583 .40813 .59685 .40447 .59119 .39785 Mtetra
.59119 .39785 .59685 .40447 .60791 .40079 .60228 .39414 Mtetra
.60228 .39414 .60791 .40079 .61901 .3971 .61341 .39043 Mtetra
.658 .753 .92 r
.61341 .39043 .61901 .3971 .63016 .39341 .62459 .3867 Mtetra
.62459 .3867 .63016 .39341 .64135 .38971 .63581 .38297 Mtetra
.63581 .38297 .64135 .38971 .65258 .386 .64708 .37923 Mtetra
.64708 .37923 .65258 .386 .66386 .38227 .65839 .37548 Mtetra
.65839 .37548 .66386 .38227 .67519 .37854 .66974 .37171 Mtetra
.66974 .37171 .67519 .37854 .68656 .37479 .68115 .36794 Mtetra
.657 .753 .92 r
.68115 .36794 .68656 .37479 .69798 .37103 .69259 .36415 Mtetra
.69259 .36415 .69798 .37103 .70944 .36725 .70409 .36035 Mtetra
.70409 .36035 .70944 .36725 .72095 .36347 .71563 .35653 Mtetra
.71563 .35653 .72095 .36347 .7325 .35967 .72722 .3527 Mtetra
.72722 .3527 .7325 .35967 .74411 .35585 .73885 .34885 Mtetra
.657 .752 .92 r
.73885 .34885 .74411 .35585 .75575 .35202 .75053 .34499 Mtetra
.75053 .34499 .75575 .35202 .76745 .34818 .76226 .34112 Mtetra
.76226 .34112 .76745 .34818 .77919 .34432 .77404 .33723 Mtetra
.77404 .33723 .77919 .34432 .79099 .34044 .78587 .33333 Mtetra
.78587 .33333 .79099 .34044 .80283 .33655 .79774 .32941 Mtetra
.79774 .32941 .80283 .33655 .81472 .33265 .80967 .32547 Mtetra
.80967 .32547 .81472 .33265 .82665 .32873 .82164 .32152 Mtetra
.82164 .32152 .82665 .32873 .83864 .32479 .83366 .31756 Mtetra
.57 .696 .926 r
.1935 .51988 .20006 .52654 .20935 .52656 .20293 .51858 Mtetra
.924 .698 .578 r
.20293 .51858 .20935 .52656 .21957 .51689 .22163 .41858 Mtetra
0 0 .259 r
.22163 .41858 .21957 .51689 .22897 .5166 .22248 .50983 Mtetra
.581 .697 .922 r
.22248 .50983 .22897 .5166 .23851 .51523 .23204 .50832 Mtetra
.444 .637 .938 r
.23204 .50832 .23851 .51523 .24967 .49486 .24146 .50899 Mtetra
0 0 0 r
.24146 .50899 .24967 .49486 .25822 .50628 .25184 .49879 Mtetra
.552 .665 .912 r
.25184 .49879 .25822 .50628 .26791 .50454 .26147 .49792 Mtetra
.588 .707 .926 r
.26147 .49792 .26791 .50454 .27755 .5041 .27122 .49622 Mtetra
.954 .66 .44 r
.27122 .49622 .27755 .5041 .28791 .49419 .27388 .59144 Mtetra
0 0 .095 r
.27388 .59144 .28791 .49419 .29761 .49388 .29125 .48702 Mtetra
.594 .703 .919 r
.29125 .48702 .29761 .49388 .30749 .49183 .30112 .48519 Mtetra
.591 .71 .926 r
.30112 .48519 .30749 .49183 .31728 .49174 .31104 .48338 Mtetra
.908 .719 .635 r
.31104 .48338 .31728 .49174 .32773 .48161 .32325 .44508 Mtetra
0 0 .489 r
.32325 .44508 .32773 .48161 .33765 .48076 .33136 .47391 Mtetra
.604 .71 .919 r
.33136 .47391 .33765 .48076 .3477 .47843 .34141 .47183 Mtetra
.612 .722 .924 r
.34141 .47183 .3477 .47843 .35776 .47671 .35152 .46954 Mtetra
.394 .608 .934 r
.35152 .46954 .35776 .47671 .36848 .46224 .36149 .47099 Mtetra
0 0 0 r
.36149 .47099 .36848 .46224 .37831 .46688 .37213 .45946 Mtetra
.582 .686 .912 r
.37213 .45946 .37831 .46688 .38853 .46452 .38233 .45789 Mtetra
.625 .728 .921 r
.38233 .45789 .38853 .46452 .3988 .46186 .39262 .45525 Mtetra
.621 .728 .923 r
.39262 .45525 .3988 .46186 .40909 .45981 .40296 .45269 Mtetra
.48 .653 .936 r
.40296 .45269 .40909 .45981 .42003 .43921 .41324 .45289 Mtetra
.006 0 .003 r
.41324 .45289 .42003 .43921 .42999 .44975 .42393 .44204 Mtetra
.577 .677 .908 r
.42393 .44204 .42999 .44975 .44043 .44726 .43435 .44057 Mtetra
.632 .732 .92 r
.43435 .44057 .44043 .44726 .45091 .44429 .44486 .43771 Mtetra
.64 .739 .921 r
.44486 .43771 .45091 .44429 .46144 .44123 .45541 .43464 Mtetra
.639 .739 .921 r
.45541 .43464 .46144 .44123 .47202 .43831 .46601 .43159 Mtetra
.624 .73 .923 r
.46601 .43159 .47202 .43831 .48262 .43642 .47665 .42888 Mtetra
.241 .512 .908 r
.47665 .42888 .48262 .43642 .49338 .42422 .48726 .43254 Mtetra
0 0 0 r
.48726 .43254 .49338 .42422 .50403 .42562 .49811 .41821 Mtetra
.605 .703 .913 r
.49811 .41821 .50403 .42562 .51477 .42274 .50888 .41599 Mtetra
.642 .739 .919 r
.50888 .41599 .51477 .42274 .52556 .41945 .51969 .41281 Mtetra
.65 .746 .92 r
.51969 .41281 .52556 .41945 .53639 .416 .53055 .40939 Mtetra
.654 .749 .92 r
.53055 .40939 .53639 .416 .54727 .41247 .54145 .40586 Mtetra
.656 .751 .92 r
.54145 .40586 .54727 .41247 .55818 .40887 .5524 .40226 Mtetra
.658 .753 .92 r
.5524 .40226 .55818 .40887 .56914 .40522 .56338 .3986 Mtetra
.659 .753 .92 r
.56338 .3986 .56914 .40522 .58015 .40155 .57442 .39491 Mtetra
.659 .754 .92 r
.57442 .39491 .58015 .40155 .59119 .39785 .58549 .39119 Mtetra
.58549 .39119 .59119 .39785 .60228 .39414 .59661 .38745 Mtetra
.59661 .38745 .60228 .39414 .61341 .39043 .60777 .3837 Mtetra
.658 .754 .92 r
.60777 .3837 .61341 .39043 .62459 .3867 .61898 .37995 Mtetra
.658 .753 .92 r
.61898 .37995 .62459 .3867 .63581 .38297 .63023 .37619 Mtetra
.63023 .37619 .63581 .38297 .64708 .37923 .64153 .37242 Mtetra
.64153 .37242 .64708 .37923 .65839 .37548 .65287 .36864 Mtetra
.65287 .36864 .65839 .37548 .66974 .37171 .66426 .36484 Mtetra
.66426 .36484 .66974 .37171 .68115 .36794 .67569 .36104 Mtetra
.67569 .36104 .68115 .36794 .69259 .36415 .68717 .35722 Mtetra
.657 .753 .92 r
.68717 .35722 .69259 .36415 .70409 .36035 .6987 .35338 Mtetra
.6987 .35338 .70409 .36035 .71563 .35653 .71027 .34954 Mtetra
.71027 .34954 .71563 .35653 .72722 .3527 .72189 .34568 Mtetra
.72189 .34568 .72722 .3527 .73885 .34885 .73356 .3418 Mtetra
.657 .752 .92 r
.73356 .3418 .73885 .34885 .75053 .34499 .74528 .33792 Mtetra
.74528 .33792 .75053 .34499 .76226 .34112 .75704 .33401 Mtetra
.75704 .33401 .76226 .34112 .77404 .33723 .76885 .33009 Mtetra
.76885 .33009 .77404 .33723 .78587 .33333 .78071 .32616 Mtetra
.78071 .32616 .78587 .33333 .79774 .32941 .79262 .32221 Mtetra
.79262 .32221 .79774 .32941 .80967 .32547 .80458 .31825 Mtetra
.80458 .31825 .80967 .32547 .82164 .32152 .81659 .31427 Mtetra
.81659 .31427 .82164 .32152 .83366 .31756 .82865 .31027 Mtetra
.557 .677 .918 r
.18695 .51275 .1935 .51988 .20293 .51858 .19636 .51173 Mtetra
.491 .66 .936 r
.19636 .51173 .20293 .51858 .22163 .41858 .20572 .51171 Mtetra
.482 .237 .467 r
.20572 .51171 .22163 .41858 .22248 .50983 .21604 .50196 Mtetra
.526 .642 .907 r
.21604 .50196 .22248 .50983 .23204 .50832 .22551 .50163 Mtetra
.573 .7 .927 r
.22551 .50163 .23204 .50832 .24146 .50899 .23512 .50021 Mtetra
.858 .714 .703 r
.23512 .50021 .24146 .50899 .25184 .49879 .24639 .47971 Mtetra
.12 .19 .663 r
.24639 .47971 .25184 .49879 .26147 .49792 .255 .49113 Mtetra
.592 .705 .922 r
.255 .49113 .26147 .49792 .27122 .49622 .26476 .48935 Mtetra
.52 .675 .935 r
.26476 .48935 .27122 .49622 .27388 .59144 .27448 .48886 Mtetra
.579 .375 .568 r
.27448 .48886 .27388 .59144 .29125 .48702 .28493 .47886 Mtetra
.529 .638 .902 r
.28493 .47886 .29125 .48702 .30112 .48519 .29472 .47851 Mtetra
.604 .715 .923 r
.29472 .47851 .30112 .48519 .31104 .48338 .30467 .4764 Mtetra
.498 .664 .936 r
.30467 .4764 .31104 .48338 .32325 .44508 .31454 .47626 Mtetra
.344 .059 .328 r
.31454 .47626 .32325 .44508 .33136 .47391 .32508 .46605 Mtetra
.553 .659 .907 r
.32508 .46605 .33136 .47391 .34141 .47183 .33509 .46515 Mtetra
.615 .721 .922 r
.33509 .46515 .34141 .47183 .35152 .46954 .34522 .46277 Mtetra
.586 .709 .928 r
.34522 .46277 .35152 .46954 .36149 .47099 .35537 .46099 Mtetra
.819 .703 .737 r
.35537 .46099 .36149 .47099 .37213 .45946 .36619 .44641 Mtetra
.347 .428 .802 r
.36619 .44641 .37213 .45946 .38233 .45789 .3761 .45103 Mtetra
.616 .719 .919 r
.3761 .45103 .38233 .45789 .39262 .45525 .3864 .44861 Mtetra
.627 .73 .922 r
.3864 .44861 .39262 .45525 .40296 .45269 .39676 .4459 Mtetra
.6 .716 .926 r
.39676 .4459 .40296 .45269 .41324 .45289 .40715 .44379 Mtetra
.869 .727 .702 r
.40715 .44379 .41324 .45289 .42393 .44204 .41819 .42305 Mtetra
.215 .263 .697 r
.41819 .42305 .42393 .44204 .43435 .44057 .42823 .43359 Mtetra
.619 .719 .918 r
.42823 .43359 .43435 .44057 .44486 .43771 .43876 .43104 Mtetra
.638 .737 .92 r
.43876 .43104 .44486 .43771 .45541 .43464 .44934 .42801 Mtetra
.64 .74 .921 r
.44934 .42801 .45541 .43464 .46601 .43159 .45996 .42489 Mtetra
.635 .737 .922 r
.45996 .42489 .46601 .43159 .47665 .42888 .47063 .4219 Mtetra
.59 .711 .928 r
.47063 .4219 .47665 .42888 .48726 .43254 .48133 .41996 Mtetra
.777 .664 .738 r
.48133 .41996 .48726 .43254 .49811 .41821 .49219 .40766 Mtetra
.471 .555 .86 r
.49219 .40766 .49811 .41821 .50888 .41599 .50294 .40901 Mtetra
.631 .729 .918 r
.50294 .40901 .50888 .41599 .51969 .41281 .51377 .40607 Mtetra
.647 .744 .92 r
.51377 .40607 .51969 .41281 .53055 .40939 .52466 .40271 Mtetra
.652 .748 .92 r
.52466 .40271 .53055 .40939 .54145 .40586 .53559 .3992 Mtetra
.655 .751 .92 r
.53559 .3992 .54145 .40586 .5524 .40226 .54656 .3956 Mtetra
.657 .752 .92 r
.54656 .3956 .5524 .40226 .56338 .3986 .55758 .39193 Mtetra
.658 .753 .92 r
.55758 .39193 .56338 .3986 .57442 .39491 .56864 .38822 Mtetra
.659 .754 .92 r
.56864 .38822 .57442 .39491 .58549 .39119 .57975 .38447 Mtetra
.57975 .38447 .58549 .39119 .59661 .38745 .5909 .38071 Mtetra
.5909 .38071 .59661 .38745 .60777 .3837 .60209 .37693 Mtetra
.60209 .37693 .60777 .3837 .61898 .37995 .61333 .37315 Mtetra
.658 .753 .92 r
.61333 .37315 .61898 .37995 .63023 .37619 .62461 .36936 Mtetra
.62461 .36936 .63023 .37619 .64153 .37242 .63594 .36555 Mtetra
.63594 .36555 .64153 .37242 .65287 .36864 .64731 .36174 Mtetra
.64731 .36174 .65287 .36864 .66426 .36484 .65873 .35792 Mtetra
.65873 .35792 .66426 .36484 .67569 .36104 .67019 .35408 Mtetra
.67019 .35408 .67569 .36104 .68717 .35722 .68171 .35023 Mtetra
.657 .753 .92 r
.68171 .35023 .68717 .35722 .6987 .35338 .69327 .34637 Mtetra
.69327 .34637 .6987 .35338 .71027 .34954 .70487 .3425 Mtetra
.70487 .3425 .71027 .34954 .72189 .34568 .71653 .33861 Mtetra
.71653 .33861 .72189 .34568 .73356 .3418 .72823 .3347 Mtetra
.72823 .3347 .73356 .3418 .74528 .33792 .73998 .33078 Mtetra
.657 .752 .92 r
.73998 .33078 .74528 .33792 .75704 .33401 .75177 .32685 Mtetra
.75177 .32685 .75704 .33401 .76885 .33009 .76362 .3229 Mtetra
.76362 .3229 .76885 .33009 .78071 .32616 .77552 .31894 Mtetra
.77552 .31894 .78071 .32616 .79262 .32221 .78746 .31496 Mtetra
.78746 .31496 .79262 .32221 .80458 .31825 .79946 .31096 Mtetra
.79946 .31096 .80458 .31825 .81659 .31427 .8115 .30695 Mtetra
.8115 .30695 .81659 .31427 .82865 .31027 .82359 .30292 Mtetra
.361 .475 .84 r
.18075 .50178 .18695 .51275 .19636 .51173 .18973 .50497 Mtetra
.57 .696 .926 r
.18973 .50497 .19636 .51173 .20572 .51171 .19923 .50362 Mtetra
.925 .699 .576 r
.19923 .50362 .20572 .51171 .21604 .50196 .2182 .40318 Mtetra
0 0 .253 r
.2182 .40318 .21604 .50196 .22551 .50163 .21894 .49475 Mtetra
.581 .697 .922 r
.21894 .49475 .22551 .50163 .23512 .50021 .22858 .49319 Mtetra
.445 .637 .938 r
.22858 .49319 .23512 .50021 .24639 .47971 .23808 .49382 Mtetra
0 0 0 r
.23808 .49382 .24639 .47971 .255 .49113 .24855 .48354 Mtetra
.552 .665 .912 r
.24855 .48354 .255 .49113 .26476 .48935 .25826 .48262 Mtetra
.588 .707 .926 r
.25826 .48262 .26476 .48935 .27448 .48886 .26808 .48086 Mtetra
.955 .66 .437 r
.26808 .48086 .27448 .48886 .28493 .47886 .27067 .57647 Mtetra
0 0 .087 r
.27067 .57647 .28493 .47886 .29472 .47851 .28829 .47153 Mtetra
.594 .703 .919 r
.28829 .47153 .29472 .47851 .30467 .4764 .29824 .46965 Mtetra
.591 .71 .926 r
.29824 .46965 .30467 .4764 .31454 .47626 .30824 .46779 Mtetra
.909 .72 .634 r
.30824 .46779 .31454 .47626 .32508 .46605 .32059 .42928 Mtetra
0 0 .485 r
.32059 .42928 .32508 .46605 .33509 .46515 .32873 .45819 Mtetra
.604 .71 .919 r
.32873 .45819 .33509 .46515 .34522 .46277 .33887 .45605 Mtetra
.612 .722 .923 r
.33887 .45605 .34522 .46277 .35537 .46099 .34907 .45371 Mtetra
.395 .608 .934 r
.34907 .45371 .35537 .46099 .36619 .44641 .35912 .45511 Mtetra
0 0 0 r
.35912 .45511 .36619 .44641 .3761 .45103 .36986 .44349 Mtetra
.582 .686 .912 r
.36986 .44349 .3761 .45103 .3864 .44861 .38014 .44186 Mtetra
.625 .728 .921 r
.38014 .44186 .3864 .44861 .39676 .4459 .39052 .43917 Mtetra
.621 .728 .923 r
.39052 .43917 .39676 .4459 .40715 .44379 .40095 .43655 Mtetra
.48 .653 .936 r
.40095 .43655 .40715 .44379 .41819 .42305 .41132 .4367 Mtetra
0 0 0 r
.41132 .4367 .41819 .42305 .42823 .43359 .42211 .42575 Mtetra
.577 .677 .908 r
.42211 .42575 .42823 .43359 .43876 .43104 .43262 .42423 Mtetra
.632 .732 .92 r
.43262 .42423 .43876 .43104 .44934 .42801 .44322 .42131 Mtetra
.64 .739 .921 r
.44322 .42131 .44934 .42801 .45996 .42489 .45387 .41818 Mtetra
.639 .739 .921 r
.45387 .41818 .45996 .42489 .47063 .4219 .46456 .41506 Mtetra
.624 .73 .923 r
.46456 .41506 .47063 .4219 .48133 .41996 .4753 .4123 Mtetra
.243 .513 .908 r
.4753 .4123 .48133 .41996 .49219 .40766 .486 .41591 Mtetra
0 0 0 r
.486 .41591 .49219 .40766 .50294 .40901 .49696 .40147 Mtetra
.605 .703 .913 r
.49696 .40147 .50294 .40901 .51377 .40607 .50782 .39919 Mtetra
.642 .739 .919 r
.50782 .39919 .51377 .40607 .52466 .40271 .51873 .39595 Mtetra
.65 .746 .92 r
.51873 .39595 .52466 .40271 .53559 .3992 .52969 .39247 Mtetra
.654 .749 .92 r
.52969 .39247 .53559 .3992 .54656 .3956 .54069 .38887 Mtetra
.656 .751 .92 r
.54069 .38887 .54656 .3956 .55758 .39193 .55174 .3852 Mtetra
.658 .753 .92 r
.55174 .3852 .55758 .39193 .56864 .38822 .56283 .38148 Mtetra
.659 .753 .92 r
.56283 .38148 .56864 .38822 .57975 .38447 .57396 .37771 Mtetra
.659 .754 .92 r
.57396 .37771 .57975 .38447 .5909 .38071 .58514 .37392 Mtetra
.58514 .37392 .5909 .38071 .60209 .37693 .59636 .37011 Mtetra
.59636 .37011 .60209 .37693 .61333 .37315 .60763 .3663 Mtetra
.658 .754 .92 r
.60763 .3663 .61333 .37315 .62461 .36936 .61894 .36247 Mtetra
.658 .753 .92 r
.61894 .36247 .62461 .36936 .63594 .36555 .6303 .35864 Mtetra
.6303 .35864 .63594 .36555 .64731 .36174 .64171 .3548 Mtetra
.64171 .3548 .64731 .36174 .65873 .35792 .65316 .35094 Mtetra
.65316 .35094 .65873 .35792 .67019 .35408 .66466 .34708 Mtetra
.66466 .34708 .67019 .35408 .68171 .35023 .6762 .3432 Mtetra
.6762 .3432 .68171 .35023 .69327 .34637 .68779 .33931 Mtetra
.657 .753 .92 r
.68779 .33931 .69327 .34637 .70487 .3425 .69943 .3354 Mtetra
.69943 .3354 .70487 .3425 .71653 .33861 .71112 .33148 Mtetra
.71112 .33148 .71653 .33861 .72823 .3347 .72285 .32755 Mtetra
.72285 .32755 .72823 .3347 .73998 .33078 .73464 .3236 Mtetra
.657 .752 .92 r
.73464 .3236 .73998 .33078 .75177 .32685 .74647 .31963 Mtetra
.74647 .31963 .75177 .32685 .76362 .3229 .75835 .31565 Mtetra
.75835 .31565 .76362 .3229 .77552 .31894 .77028 .31166 Mtetra
.77028 .31166 .77552 .31894 .78746 .31496 .78226 .30765 Mtetra
.78226 .30765 .78746 .31496 .79946 .31096 .79429 .30362 Mtetra
.79429 .30362 .79946 .31096 .8115 .30695 .80637 .29958 Mtetra
.80637 .29958 .8115 .30695 .82359 .30292 .8185 .29552 Mtetra
.653 .906 .586 r
.17252 .50973 .18075 .50178 .18973 .50497 .18311 .49773 Mtetra
.557 .677 .918 r
.18311 .49773 .18973 .50497 .19923 .50362 .19259 .49667 Mtetra
.491 .66 .936 r
.19259 .49667 .19923 .50362 .2182 .40318 .20203 .49661 Mtetra
.478 .232 .463 r
.20203 .49661 .2182 .40318 .21894 .49475 .21244 .48677 Mtetra
.526 .642 .907 r
.21244 .48677 .21894 .49475 .22858 .49319 .22198 .48639 Mtetra
.573 .7 .927 r
.22198 .48639 .22858 .49319 .23808 .49382 .23167 .48493 Mtetra
.858 .715 .703 r
.23167 .48493 .23808 .49382 .24855 .48354 .24306 .46429 Mtetra
.116 .188 .662 r
.24306 .46429 .24855 .48354 .25826 .48262 .25172 .47572 Mtetra
.592 .705 .922 r
.25172 .47572 .25826 .48262 .26808 .48086 .26156 .47388 Mtetra
.52 .675 .934 r
.26156 .47388 .26808 .48086 .27067 .57647 .27135 .47335 Mtetra
.577 .372 .566 r
.27135 .47335 .27067 .57647 .28829 .47153 .28191 .46326 Mtetra
.529 .638 .902 r
.28191 .46326 .28829 .47153 .29824 .46965 .29177 .46286 Mtetra
.604 .715 .923 r
.29177 .46286 .29824 .46965 .30824 .46779 .3018 .4607 Mtetra
.499 .664 .936 r
.3018 .4607 .30824 .46779 .32059 .42928 .31176 .46051 Mtetra
.337 .049 .321 r
.31176 .46051 .32059 .42928 .32873 .45819 .32239 .45021 Mtetra
.553 .659 .907 r
.32239 .45021 .32873 .45819 .33887 .45605 .33248 .44926 Mtetra
.615 .721 .922 r
.33248 .44926 .33887 .45605 .34907 .45371 .3427 .44682 Mtetra
.587 .709 .928 r
.3427 .44682 .34907 .45371 .35912 .45511 .35293 .44499 Mtetra
.82 .704 .737 r
.35293 .44499 .35912 .45511 .36986 .44349 .36385 .4303 Mtetra
.346 .427 .802 r
.36385 .4303 .36986 .44349 .38014 .44186 .37385 .43489 Mtetra
.616 .719 .919 r
.37385 .43489 .38014 .44186 .39052 .43917 .38424 .43241 Mtetra
.627 .73 .922 r
.38424 .43241 .39052 .43917 .40095 .43655 .39469 .42964 Mtetra
.6 .716 .926 r
.39469 .42964 .40095 .43655 .41132 .4367 .40516 .42747 Mtetra
.87 .728 .702 r
.40516 .42747 .41132 .4367 .42211 .42575 .41632 .4066 Mtetra
.212 .261 .696 r
.41632 .4066 .42211 .42575 .43262 .42423 .42644 .41713 Mtetra
.619 .719 .918 r
.42644 .41713 .43262 .42423 .44322 .42131 .43706 .41452 Mtetra
.638 .737 .92 r
.43706 .41452 .44322 .42131 .45387 .41818 .44773 .41142 Mtetra
.64 .74 .921 r
.44773 .41142 .45387 .41818 .46456 .41506 .45845 .40824 Mtetra
.635 .737 .922 r
.45845 .40824 .46456 .41506 .4753 .4123 .46922 .40519 Mtetra
.59 .711 .928 r
.46922 .40519 .4753 .4123 .486 .41591 .48001 .40319 Mtetra
.778 .665 .738 r
.48001 .40319 .486 .41591 .49696 .40147 .49097 .39078 Mtetra
.47 .555 .86 r
.49097 .39078 .49696 .40147 .50782 .39919 .50182 .39209 Mtetra
.631 .729 .918 r
.50182 .39209 .50782 .39919 .51873 .39595 .51275 .38908 Mtetra
.647 .744 .92 r
.51275 .38908 .51873 .39595 .52969 .39247 .52374 .38566 Mtetra
.652 .748 .92 r
.52374 .38566 .52969 .39247 .54069 .38887 .53477 .38208 Mtetra
.655 .751 .92 r
.53477 .38208 .54069 .38887 .55174 .3852 .54585 .37841 Mtetra
.657 .752 .92 r
.54585 .37841 .55174 .3852 .56283 .38148 .55697 .37468 Mtetra
.658 .753 .92 r
.55697 .37468 .56283 .38148 .57396 .37771 .56813 .37089 Mtetra
.659 .754 .92 r
.56813 .37089 .57396 .37771 .58514 .37392 .57934 .36708 Mtetra
.57934 .36708 .58514 .37392 .59636 .37011 .59059 .36324 Mtetra
.59059 .36324 .59636 .37011 .60763 .3663 .60189 .35939 Mtetra
.60189 .35939 .60763 .3663 .61894 .36247 .61324 .35554 Mtetra
.658 .753 .92 r
.61324 .35554 .61894 .36247 .6303 .35864 .62463 .35167 Mtetra
.62463 .35167 .6303 .35864 .64171 .3548 .63606 .3478 Mtetra
.63606 .3478 .64171 .3548 .65316 .35094 .64755 .34392 Mtetra
.64755 .34392 .65316 .35094 .66466 .34708 .65908 .34002 Mtetra
.65908 .34002 .66466 .34708 .6762 .3432 .67065 .33611 Mtetra
.67065 .33611 .6762 .3432 .68779 .33931 .68228 .33219 Mtetra
.657 .753 .92 r
.68228 .33219 .68779 .33931 .69943 .3354 .69395 .32825 Mtetra
.69395 .32825 .69943 .3354 .71112 .33148 .70567 .3243 Mtetra
.70567 .3243 .71112 .33148 .72285 .32755 .71744 .32034 Mtetra
.71744 .32034 .72285 .32755 .73464 .3236 .72926 .31636 Mtetra
.72926 .31636 .73464 .3236 .74647 .31963 .74112 .31236 Mtetra
.657 .752 .92 r
.74112 .31236 .74647 .31963 .75835 .31565 .75304 .30835 Mtetra
.75304 .30835 .75835 .31565 .77028 .31166 .765 .30432 Mtetra
.765 .30432 .77028 .31166 .78226 .30765 .77702 .30028 Mtetra
.77702 .30028 .78226 .30765 .79429 .30362 .78908 .29622 Mtetra
.78908 .29622 .79429 .30362 .80637 .29958 .8012 .29215 Mtetra
.8012 .29215 .80637 .29958 .8185 .29552 .81337 .28806 Mtetra
.784 .673 .741 r
.16621 .49881 .17252 .50973 .18311 .49773 .17685 .48663 Mtetra
.36 .475 .841 r
.17685 .48663 .18311 .49773 .19259 .49667 .1859 .4898 Mtetra
.57 .696 .926 r
.1859 .4898 .19259 .49667 .20203 .49661 .19547 .4884 Mtetra
.926 .699 .575 r
.19547 .4884 .20203 .49661 .21244 .48677 .21471 .38751 Mtetra
0 0 .246 r
.21471 .38751 .21244 .48677 .22198 .48639 .21535 .4794 Mtetra
.581 .697 .922 r
.21535 .4794 .22198 .48639 .23167 .48493 .22507 .47779 Mtetra
.445 .637 .937 r
.22507 .47779 .23167 .48493 .24306 .46429 .23464 .47838 Mtetra
0 0 0 r
.23464 .47838 .24306 .46429 .25172 .47572 .2452 .46801 Mtetra
.552 .665 .912 r
.2452 .46801 .25172 .47572 .26156 .47388 .25499 .46704 Mtetra
.588 .707 .926 r
.25499 .46704 .26156 .47388 .27135 .47335 .26489 .46523 Mtetra
.955 .659 .434 r
.26489 .46523 .27135 .47335 .28191 .46326 .2674 .56122 Mtetra
0 0 .079 r
.2674 .56122 .28191 .46326 .29177 .46286 .28527 .45577 Mtetra
.594 .703 .919 r
.28527 .45577 .29177 .46286 .3018 .4607 .29531 .45383 Mtetra
.591 .71 .926 r
.29531 .45383 .3018 .4607 .31176 .46051 .30539 .45192 Mtetra
.91 .72 .633 r
.30539 .45192 .31176 .46051 .32239 .45021 .31787 .4132 Mtetra
0 0 .482 r
.31787 .4132 .32239 .45021 .33248 .44926 .32606 .44218 Mtetra
.604 .71 .919 r
.32606 .44218 .33248 .44926 .3427 .44682 .33628 .43999 Mtetra
.612 .722 .923 r
.33628 .43999 .3427 .44682 .35293 .44499 .34657 .43759 Mtetra
.396 .608 .934 r
.34657 .43759 .35293 .44499 .36385 .4303 .3567 .43895 Mtetra
0 0 0 r
.3567 .43895 .36385 .4303 .37385 .43489 .36754 .42723 Mtetra
.582 .686 .912 r
.36754 .42723 .37385 .43489 .38424 .43241 .37792 .42555 Mtetra
.625 .728 .921 r
.37792 .42555 .38424 .43241 .39469 .42964 .38839 .42279 Mtetra
.621 .728 .923 r
.38839 .42279 .39469 .42964 .40516 .42747 .3989 .42011 Mtetra
.481 .653 .935 r
.3989 .42011 .40516 .42747 .41632 .4066 .40936 .42021 Mtetra
0 0 0 r
.40936 .42021 .41632 .4066 .42644 .41713 .42025 .40917 Mtetra
.577 .677 .909 r
.42025 .40917 .42644 .41713 .43706 .41452 .43085 .40758 Mtetra
.632 .732 .92 r
.43085 .40758 .43706 .41452 .44773 .41142 .44155 .4046 Mtetra
.64 .739 .921 r
.44155 .4046 .44773 .41142 .45845 .40824 .4523 .40141 Mtetra
.639 .739 .921 r
.4523 .40141 .45845 .40824 .46922 .40519 .46309 .39822 Mtetra
.624 .73 .923 r
.46309 .39822 .46922 .40519 .48001 .40319 .47392 .3954 Mtetra
.246 .514 .908 r
.47392 .3954 .48001 .40319 .49097 .39078 .48472 .39898 Mtetra
.566 .811 .43 r
.48472 .39898 .49097 .39078 .50182 .39209 .49578 .38443 Mtetra
.605 .703 .913 r
.49578 .38443 .50182 .39209 .51275 .38908 .50674 .38208 Mtetra
.642 .739 .919 r
.50674 .38208 .51275 .38908 .52374 .38566 .51775 .37877 Mtetra
.65 .746 .92 r
.51775 .37877 .52374 .38566 .53477 .38208 .52881 .37522 Mtetra
.654 .749 .92 r
.52881 .37522 .53477 .38208 .54585 .37841 .53991 .37156 Mtetra
.656 .751 .92 r
.53991 .37156 .54585 .37841 .55697 .37468 .55106 .36782 Mtetra
.658 .753 .92 r
.55106 .36782 .55697 .37468 .56813 .37089 .56226 .36402 Mtetra
.659 .753 .92 r
.56226 .36402 .56813 .37089 .57934 .36708 .5735 .36018 Mtetra
.659 .754 .92 r
.5735 .36018 .57934 .36708 .59059 .36324 .58478 .35632 Mtetra
.58478 .35632 .59059 .36324 .60189 .35939 .59611 .35244 Mtetra
.59611 .35244 .60189 .35939 .61324 .35554 .60749 .34855 Mtetra
.658 .754 .92 r
.60749 .34855 .61324 .35554 .62463 .35167 .61891 .34466 Mtetra
.658 .753 .92 r
.61891 .34466 .62463 .35167 .63606 .3478 .63038 .34075 Mtetra
.63038 .34075 .63606 .3478 .64755 .34392 .64189 .33684 Mtetra
.64189 .33684 .64755 .34392 .65908 .34002 .65345 .33291 Mtetra
.65345 .33291 .65908 .34002 .67065 .33611 .66506 .32897 Mtetra
.66506 .32897 .67065 .33611 .68228 .33219 .67672 .32501 Mtetra
.67672 .32501 .68228 .33219 .69395 .32825 .68843 .32105 Mtetra
.657 .753 .92 r
.68843 .32105 .69395 .32825 .70567 .3243 .70018 .31707 Mtetra
.70018 .31707 .70567 .3243 .71744 .32034 .71198 .31307 Mtetra
.71198 .31307 .71744 .32034 .72926 .31636 .72384 .30906 Mtetra
.72384 .30906 .72926 .31636 .74112 .31236 .73574 .30503 Mtetra
.657 .752 .92 r
.73574 .30503 .74112 .31236 .75304 .30835 .74769 .30099 Mtetra
.74769 .30099 .75304 .30835 .765 .30432 .75969 .29693 Mtetra
.75969 .29693 .765 .30432 .77702 .30028 .77174 .29286 Mtetra
.77174 .29286 .77702 .30028 .78908 .29622 .78384 .28877 Mtetra
.78384 .28877 .78908 .29622 .8012 .29215 .79599 .28466 Mtetra
.79599 .28466 .8012 .29215 .81337 .28806 .80819 .28054 Mtetra
.217 .511 .911 r
.15948 .49149 .16621 .49881 .17685 .48663 .16852 .49454 Mtetra
.662 .913 .596 r
.16852 .49454 .17685 .48663 .1859 .4898 .1792 .48245 Mtetra
.557 .677 .918 r
.1792 .48245 .1859 .4898 .19547 .4884 .18876 .48134 Mtetra
.492 .66 .936 r
.18876 .48134 .19547 .4884 .21471 .38751 .19827 .48123 Mtetra
.473 .226 .458 r
.19827 .48123 .21471 .38751 .21535 .4794 .20877 .47131 Mtetra
.526 .642 .907 r
.20877 .47131 .21535 .4794 .22507 .47779 .21839 .47088 Mtetra
.573 .7 .927 r
.21839 .47088 .22507 .47779 .23464 .47838 .22816 .46936 Mtetra
.859 .716 .703 r
.22816 .46936 .23464 .47838 .2452 .46801 .23966 .4486 Mtetra
.113 .185 .66 r
.23966 .4486 .2452 .46801 .25499 .46704 .24838 .46002 Mtetra
.592 .705 .922 r
.24838 .46002 .25499 .46704 .26489 .46523 .2583 .45813 Mtetra
.52 .675 .934 r
.2583 .45813 .26489 .46523 .2674 .56122 .26817 .45755 Mtetra
.575 .369 .564 r
.26817 .45755 .2674 .56122 .28527 .45577 .27882 .44738 Mtetra
.528 .638 .902 r
.27882 .44738 .28527 .45577 .29531 .45383 .28876 .44693 Mtetra
.604 .715 .923 r
.28876 .44693 .29531 .45383 .30539 .45192 .29888 .44471 Mtetra
.499 .664 .936 r
.29888 .44471 .30539 .45192 .31787 .4132 .30892 .44447 Mtetra
.329 .04 .313 r
.30892 .44447 .31787 .4132 .32606 .44218 .31966 .43408 Mtetra
.552 .659 .907 r
.31966 .43408 .32606 .44218 .33628 .43999 .32982 .43307 Mtetra
.615 .721 .922 r
.32982 .43307 .33628 .43999 .34657 .43759 .34013 .43058 Mtetra
.587 .709 .927 r
.34013 .43058 .34657 .43759 .3567 .43895 .35045 .42869 Mtetra
.821 .705 .737 r
.35045 .42869 .3567 .43895 .36754 .42723 .36148 .41389 Mtetra
.344 .426 .802 r
.36148 .41389 .36754 .42723 .37792 .42555 .37156 .41845 Mtetra
.616 .719 .919 r
.37156 .41845 .37792 .42555 .38839 .42279 .38204 .41591 Mtetra
.627 .73 .922 r
.38204 .41591 .38839 .42279 .3989 .42011 .39258 .41307 Mtetra
.6 .716 .926 r
.39258 .41307 .3989 .42011 .40936 .42021 .40315 .41085 Mtetra
.871 .729 .702 r
.40315 .41085 .40936 .42021 .42025 .40917 .41441 .38984 Mtetra
.209 .259 .695 r
.41441 .38984 .42025 .40917 .43085 .40758 .42462 .40036 Mtetra
.619 .719 .918 r
.42462 .40036 .43085 .40758 .44155 .4046 .43533 .39769 Mtetra
.638 .737 .92 r
.43533 .39769 .44155 .4046 .4523 .40141 .4461 .39453 Mtetra
.64 .74 .921 r
.4461 .39453 .4523 .40141 .46309 .39822 .45691 .39128 Mtetra
.635 .737 .922 r
.45691 .39128 .46309 .39822 .47392 .3954 .46778 .38817 Mtetra
.59 .711 .927 r
.46778 .38817 .47392 .3954 .48472 .39898 .47867 .3861 Mtetra
.779 .666 .739 r
.47867 .3861 .48472 .39898 .49578 .38443 .48973 .37359 Mtetra
.47 .554 .86 r
.48973 .37359 .49578 .38443 .50674 .38208 .50068 .37485 Mtetra
.631 .729 .918 r
.50068 .37485 .50674 .38208 .51775 .37877 .51171 .37178 Mtetra
.647 .744 .92 r
.51171 .37178 .51775 .37877 .52881 .37522 .5228 .36828 Mtetra
.652 .748 .92 r
.5228 .36828 .52881 .37522 .53991 .37156 .53394 .36464 Mtetra
.655 .751 .92 r
.53394 .36464 .53991 .37156 .55106 .36782 .54512 .3609 Mtetra
.657 .752 .92 r
.54512 .3609 .55106 .36782 .56226 .36402 .55634 .35709 Mtetra
.658 .753 .92 r
.55634 .35709 .56226 .36402 .5735 .36018 .56761 .35323 Mtetra
.659 .754 .92 r
.56761 .35323 .5735 .36018 .58478 .35632 .57893 .34935 Mtetra
.57893 .34935 .58478 .35632 .59611 .35244 .59029 .34544 Mtetra
.59029 .34544 .59611 .35244 .60749 .34855 .60169 .34152 Mtetra
.60169 .34152 .60749 .34855 .61891 .34466 .61315 .33759 Mtetra
.658 .753 .92 r
.61315 .33759 .61891 .34466 .63038 .34075 .62465 .33365 Mtetra
.62465 .33365 .63038 .34075 .64189 .33684 .63619 .3297 Mtetra
.63619 .3297 .64189 .33684 .65345 .33291 .64779 .32574 Mtetra
.64779 .32574 .65345 .33291 .66506 .32897 .65943 .32177 Mtetra
.65943 .32177 .66506 .32897 .67672 .32501 .67112 .31779 Mtetra
.67112 .31779 .67672 .32501 .68843 .32105 .68286 .31379 Mtetra
.657 .753 .92 r
.68286 .31379 .68843 .32105 .70018 .31707 .69465 .30978 Mtetra
.69465 .30978 .70018 .31707 .71198 .31307 .70649 .30575 Mtetra
.70649 .30575 .71198 .31307 .72384 .30906 .71837 .30171 Mtetra
.71837 .30171 .72384 .30906 .73574 .30503 .73031 .29765 Mtetra
.73031 .29765 .73574 .30503 .74769 .30099 .74229 .29357 Mtetra
.657 .752 .92 r
.74229 .29357 .74769 .30099 .75969 .29693 .75433 .28948 Mtetra
.75433 .28948 .75969 .29693 .77174 .29286 .76641 .28538 Mtetra
.76641 .28538 .77174 .29286 .78384 .28877 .77855 .28126 Mtetra
.77855 .28126 .78384 .28877 .79599 .28466 .79074 .27712 Mtetra
.79074 .27712 .79599 .28466 .80819 .28054 .80298 .27296 Mtetra
.547 .685 .93 r
.15266 .48451 .15948 .49149 .16852 .49454 .16215 .48349 Mtetra
.785 .674 .741 r
.16215 .48349 .16852 .49454 .1792 .48245 .17288 .47122 Mtetra
.359 .474 .841 r
.17288 .47122 .1792 .48245 .18876 .48134 .18199 .47435 Mtetra
.57 .696 .926 r
.18199 .47435 .18876 .48134 .19827 .48123 .19165 .4729 Mtetra
.928 .7 .574 r
.19165 .4729 .19827 .48123 .20877 .47131 .21116 .37157 Mtetra
0 0 .24 r
.21116 .37157 .20877 .47131 .21839 .47088 .21169 .46378 Mtetra
.581 .697 .922 r
.21169 .46378 .21839 .47088 .22816 .46936 .22148 .46212 Mtetra
.446 .637 .937 r
.22148 .46212 .22816 .46936 .23966 .4486 .23113 .46266 Mtetra
0 0 0 r
.23113 .46266 .23966 .4486 .24838 .46002 .24179 .45219 Mtetra
.552 .665 .912 r
.24179 .45219 .24838 .46002 .2583 .45813 .25166 .45118 Mtetra
.588 .707 .926 r
.25166 .45118 .2583 .45813 .26817 .45755 .26164 .44931 Mtetra
.956 .659 .43 r
.26164 .44931 .26817 .45755 .27882 .44738 .26407 .54569 Mtetra
0 0 .071 r
.26407 .54569 .27882 .44738 .28876 .44693 .2822 .43972 Mtetra
.594 .703 .919 r
.2822 .43972 .28876 .44693 .29888 .44471 .29232 .43773 Mtetra
.591 .71 .926 r
.29232 .43773 .29888 .44471 .30892 .44447 .30248 .43576 Mtetra
.911 .721 .632 r
.30248 .43576 .30892 .44447 .31966 .43408 .31511 .39683 Mtetra
0 0 .479 r
.31511 .39683 .31966 .43408 .32982 .43307 .32334 .42588 Mtetra
.604 .71 .919 r
.32334 .42588 .32982 .43307 .34013 .43058 .33365 .42363 Mtetra
.612 .722 .923 r
.33365 .42363 .34013 .43058 .35045 .42869 .34402 .42117 Mtetra
.397 .608 .934 r
.34402 .42117 .35045 .42869 .36148 .41389 .35424 .42248 Mtetra
0 0 0 r
.35424 .42248 .36148 .41389 .37156 .41845 .36518 .41067 Mtetra
.582 .686 .912 r
.36518 .41067 .37156 .41845 .38204 .41591 .37565 .40892 Mtetra
.625 .728 .921 r
.37565 .40892 .38204 .41591 .39258 .41307 .38621 .4061 Mtetra
.621 .728 .923 r
.38621 .4061 .39258 .41307 .40315 .41085 .39682 .40337 Mtetra
.481 .653 .935 r
.39682 .40337 .40315 .41085 .41441 .38984 .40737 .40341 Mtetra
0 0 0 r
.40737 .40341 .41441 .38984 .42462 .40036 .41836 .39227 Mtetra
.576 .677 .909 r
.41836 .39227 .42462 .40036 .43533 .39769 .42906 .39063 Mtetra
.632 .732 .92 r
.42906 .39063 .43533 .39769 .4461 .39453 .43985 .38759 Mtetra
.64 .739 .921 r
.43985 .38759 .4461 .39453 .45691 .39128 .4507 .38432 Mtetra
.639 .739 .921 r
.4507 .38432 .45691 .39128 .46778 .38817 .46159 .38107 Mtetra
.624 .73 .923 r
.46159 .38107 .46778 .38817 .47867 .3861 .47252 .37818 Mtetra
.248 .514 .908 r
.47252 .37818 .47867 .3861 .48973 .37359 .48341 .38172 Mtetra
.576 .82 .441 r
.48341 .38172 .48973 .37359 .50068 .37485 .49458 .36706 Mtetra
.605 .703 .913 r
.49458 .36706 .50068 .37485 .51171 .37178 .50564 .36465 Mtetra
.642 .739 .919 r
.50564 .36465 .51171 .37178 .5228 .36828 .51675 .36126 Mtetra
.65 .746 .92 r
.51675 .36126 .5228 .36828 .53394 .36464 .52791 .35764 Mtetra
.654 .749 .92 r
.52791 .35764 .53394 .36464 .54512 .3609 .53912 .35391 Mtetra
.656 .751 .92 r
.53912 .35391 .54512 .3609 .55634 .35709 .55038 .3501 Mtetra
.658 .753 .92 r
.55038 .3501 .55634 .35709 .56761 .35323 .56168 .34623 Mtetra
.659 .753 .92 r
.56168 .34623 .56761 .35323 .57893 .34935 .57303 .34232 Mtetra
.659 .754 .92 r
.57303 .34232 .57893 .34935 .59029 .34544 .58442 .33838 Mtetra
.58442 .33838 .59029 .34544 .60169 .34152 .59586 .33443 Mtetra
.59586 .33443 .60169 .34152 .61315 .33759 .60734 .33047 Mtetra
.658 .754 .92 r
.60734 .33047 .61315 .33759 .62465 .33365 .61887 .3265 Mtetra
.658 .753 .92 r
.61887 .3265 .62465 .33365 .63619 .3297 .63045 .32252 Mtetra
.63045 .32252 .63619 .3297 .64779 .32574 .64208 .31853 Mtetra
.64208 .31853 .64779 .32574 .65943 .32177 .65376 .31452 Mtetra
.65376 .31452 .65943 .32177 .67112 .31779 .66548 .3105 Mtetra
.66548 .3105 .67112 .31779 .68286 .31379 .67725 .30647 Mtetra
.67725 .30647 .68286 .31379 .69465 .30978 .68907 .30243 Mtetra
.657 .753 .92 r
.68907 .30243 .69465 .30978 .70649 .30575 .70094 .29837 Mtetra
.70094 .29837 .70649 .30575 .71837 .30171 .71287 .2943 Mtetra
.71287 .2943 .71837 .30171 .73031 .29765 .72484 .29021 Mtetra
.72484 .29021 .73031 .29765 .74229 .29357 .73686 .2861 Mtetra
.657 .752 .92 r
.73686 .2861 .74229 .29357 .75433 .28948 .74893 .28198 Mtetra
.74893 .28198 .75433 .28948 .76641 .28538 .76105 .27784 Mtetra
.76105 .27784 .76641 .28538 .77855 .28126 .77322 .27369 Mtetra
.77322 .27369 .77855 .28126 .79074 .27712 .78545 .26952 Mtetra
.78545 .26952 .79074 .27712 .80298 .27296 .79773 .26533 Mtetra
.556 .68 .921 r
.14583 .47721 .15266 .48451 .16215 .48349 .15534 .47606 Mtetra
.219 .512 .911 r
.15534 .47606 .16215 .48349 .17288 .47122 .16444 .47908 Mtetra
.672 .919 .605 r
.16444 .47908 .17288 .47122 .18199 .47435 .17523 .46689 Mtetra
.557 .677 .918 r
.17523 .46689 .18199 .47435 .19165 .4729 .18486 .46573 Mtetra
.492 .66 .936 r
.18486 .46573 .19165 .4729 .21116 .37157 .19444 .46557 Mtetra
.469 .22 .454 r
.19444 .46557 .21116 .37157 .21169 .46378 .20504 .45556 Mtetra
.526 .642 .907 r
.20504 .45556 .21169 .46378 .22148 .46212 .21474 .45509 Mtetra
.573 .7 .927 r
.21474 .45509 .22148 .46212 .23113 .46266 .22459 .45352 Mtetra
.86 .717 .702 r
.22459 .45352 .23113 .46266 .24179 .45219 .2362 .43262 Mtetra
.109 .182 .659 r
.2362 .43262 .24179 .45219 .25166 .45118 .24498 .44404 Mtetra
.592 .705 .922 r
.24498 .44404 .25166 .45118 .26164 .44931 .25498 .4421 Mtetra
.52 .675 .934 r
.25498 .4421 .26164 .44931 .26407 .54569 .26494 .44147 Mtetra
.573 .366 .562 r
.26494 .44147 .26407 .54569 .2822 .43972 .27568 .4312 Mtetra
.528 .638 .902 r
.27568 .4312 .2822 .43972 .29232 .43773 .2857 .4307 Mtetra
.604 .715 .923 r
.2857 .4307 .29232 .43773 .30248 .43576 .29591 .42843 Mtetra
.499 .664 .935 r
.29591 .42843 .30248 .43576 .31511 .39683 .30603 .42814 Mtetra
.321 .03 .305 r
.30603 .42814 .31511 .39683 .32334 .42588 .31687 .41765 Mtetra
.552 .659 .907 r
.31687 .41765 .32334 .42588 .33365 .42363 .32712 .41659 Mtetra
.615 .721 .922 r
.32712 .41659 .33365 .42363 .34402 .42117 .33752 .41404 Mtetra
.587 .709 .927 r
.33752 .41404 .34402 .42117 .35424 .42248 .34793 .41209 Mtetra
.821 .706 .737 r
.34793 .41209 .35424 .42248 .36518 .41067 .35906 .39718 Mtetra
.343 .425 .802 r
.35906 .39718 .36518 .41067 .37565 .40892 .36922 .4017 Mtetra
.616 .719 .919 r
.36922 .4017 .37565 .40892 .38621 .4061 .3798 .3991 Mtetra
.627 .73 .922 r
.3798 .3991 .38621 .4061 .39682 .40337 .39043 .3962 Mtetra
.6 .716 .926 r
.39043 .3962 .39682 .40337 .40737 .40341 .40109 .39392 Mtetra
.872 .73 .702 r
.40109 .39392 .40737 .40341 .41836 .39227 .41246 .37277 Mtetra
.206 .257 .694 r
.41246 .37277 .41836 .39227 .42906 .39063 .42276 .38328 Mtetra
.619 .72 .918 r
.42276 .38328 .42906 .39063 .43985 .38759 .43356 .38055 Mtetra
.638 .737 .92 r
.43356 .38055 .43985 .38759 .4507 .38432 .44443 .37732 Mtetra
.64 .74 .921 r
.44443 .37732 .4507 .38432 .46159 .38107 .45535 .374 Mtetra
.635 .737 .922 r
.45535 .374 .46159 .38107 .47252 .37818 .46631 .37082 Mtetra
.59 .711 .927 r
.46631 .37082 .47252 .37818 .48341 .38172 .4773 .36869 Mtetra
.779 .666 .739 r
.4773 .36869 .48341 .38172 .49458 .36706 .48847 .35608 Mtetra
.469 .554 .86 r
.48847 .35608 .49458 .36706 .50564 .36465 .49951 .35728 Mtetra
.631 .729 .918 r
.49951 .35728 .50564 .36465 .51675 .36126 .51066 .35414 Mtetra
.647 .744 .92 r
.51066 .35414 .51675 .36126 .52791 .35764 .52185 .35058 Mtetra
.652 .748 .92 r
.52185 .35058 .52791 .35764 .53912 .35391 .53309 .34686 Mtetra
.655 .751 .92 r
.53309 .34686 .53912 .35391 .55038 .3501 .54437 .34304 Mtetra
.657 .752 .92 r
.54437 .34304 .55038 .3501 .56168 .34623 .5557 .33916 Mtetra
.658 .753 .92 r
.5557 .33916 .56168 .34623 .57303 .34232 .56708 .33524 Mtetra
.659 .754 .92 r
.56708 .33524 .57303 .34232 .58442 .33838 .5785 .33128 Mtetra
.5785 .33128 .58442 .33838 .59586 .33443 .58997 .32729 Mtetra
.58997 .32729 .59586 .33443 .60734 .33047 .60149 .3233 Mtetra
.60149 .3233 .60734 .33047 .61887 .3265 .61306 .31929 Mtetra
.658 .753 .92 r
.61306 .31929 .61887 .3265 .63045 .32252 .62467 .31528 Mtetra
.62467 .31528 .63045 .32252 .64208 .31853 .63633 .31125 Mtetra
.63633 .31125 .64208 .31853 .65376 .31452 .64804 .30722 Mtetra
.64804 .30722 .65376 .31452 .66548 .3105 .65979 .30317 Mtetra
.65979 .30317 .66548 .3105 .67725 .30647 .6716 .2991 Mtetra
.6716 .2991 .67725 .30647 .68907 .30243 .68346 .29503 Mtetra
.657 .753 .92 r
.68346 .29503 .68907 .30243 .70094 .29837 .69536 .29094 Mtetra
.69536 .29094 .70094 .29837 .71287 .2943 .70732 .28683 Mtetra
.70732 .28683 .71287 .2943 .72484 .29021 .71932 .28271 Mtetra
.71932 .28271 .72484 .29021 .73686 .2861 .73138 .27857 Mtetra
.73138 .27857 .73686 .2861 .74893 .28198 .74348 .27441 Mtetra
.657 .752 .92 r
.74348 .27441 .74893 .28198 .76105 .27784 .75564 .27024 Mtetra
.75564 .27024 .76105 .27784 .77322 .27369 .76785 .26606 Mtetra
.76785 .26606 .77322 .27369 .78545 .26952 .78011 .26185 Mtetra
.78011 .26185 .78545 .26952 .79773 .26533 .79243 .25763 Mtetra
.428 .552 .878 r
.13924 .46748 .14583 .47721 .15534 .47606 .14845 .46896 Mtetra
.547 .685 .93 r
.14845 .46896 .15534 .47606 .16444 .47908 .15801 .4679 Mtetra
.785 .674 .742 r
.15801 .4679 .16444 .47908 .17523 .46689 .16884 .45553 Mtetra
.358 .474 .841 r
.16884 .45553 .17523 .46689 .18486 .46573 .17802 .45863 Mtetra
.57 .696 .926 r
.17802 .45863 .18486 .46573 .19444 .46557 .18775 .45713 Mtetra
.929 .7 .572 r
.18775 .45713 .19444 .46557 .20504 .45556 .20754 .35535 Mtetra
0 0 .233 r
.20754 .35535 .20504 .45556 .21474 .45509 .20796 .44787 Mtetra
.581 .697 .922 r
.20796 .44787 .21474 .45509 .22459 .45352 .21784 .44615 Mtetra
.446 .637 .937 r
.21784 .44615 .22459 .45352 .2362 .43262 .22756 .44665 Mtetra
0 0 0 r
.22756 .44665 .2362 .43262 .24498 .44404 .23832 .4361 Mtetra
.552 .665 .912 r
.23832 .4361 .24498 .44404 .25498 .4421 .24827 .43502 Mtetra
.588 .707 .926 r
.24827 .43502 .25498 .4421 .26494 .44147 .25833 .43311 Mtetra
.957 .658 .427 r
.25833 .43311 .26494 .44147 .27568 .4312 .26068 .52986 Mtetra
0 0 .062 r
.26068 .52986 .27568 .4312 .2857 .4307 .27907 .42337 Mtetra
.594 .703 .919 r
.27907 .42337 .2857 .4307 .29591 .42843 .28927 .42132 Mtetra
.591 .71 .926 r
.28927 .42132 .29591 .42843 .30603 .42814 .29953 .41929 Mtetra
.912 .722 .632 r
.29953 .41929 .30603 .42814 .31687 .41765 .31229 .38016 Mtetra
0 0 .476 r
.31229 .38016 .31687 .41765 .32712 .41659 .32056 .40927 Mtetra
.604 .71 .919 r
.32056 .40927 .32712 .41659 .33752 .41404 .33096 .40697 Mtetra
.612 .722 .923 r
.33096 .40697 .33752 .41404 .34793 .41209 .34143 .40444 Mtetra
.398 .608 .934 r
.34143 .40444 .34793 .41209 .35906 .39718 .35174 .40571 Mtetra
0 0 0 r
.35174 .40571 .35906 .39718 .36922 .4017 .36278 .39379 Mtetra
.582 .686 .913 r
.36278 .39379 .36922 .4017 .3798 .3991 .37334 .39199 Mtetra
.625 .728 .921 r
.37334 .39199 .3798 .3991 .39043 .3962 .38399 .38911 Mtetra
.621 .728 .923 r
.38399 .38911 .39043 .3962 .40109 .39392 .3947 .38631 Mtetra
.482 .653 .935 r
.3947 .38631 .40109 .39392 .41246 .37277 .40534 .3863 Mtetra
0 0 0 r
.40534 .3863 .41246 .37277 .42276 .38328 .41643 .37506 Mtetra
.576 .677 .909 r
.41643 .37506 .42276 .38328 .43356 .38055 .42723 .37336 Mtetra
.632 .732 .92 r
.42723 .37336 .43356 .38055 .44443 .37732 .43812 .37024 Mtetra
.64 .739 .921 r
.43812 .37024 .44443 .37732 .45535 .374 .44906 .36691 Mtetra
.639 .739 .921 r
.44906 .36691 .45535 .374 .46631 .37082 .46005 .36359 Mtetra
.624 .73 .923 r
.46005 .36359 .46631 .37082 .4773 .36869 .47108 .36064 Mtetra
.251 .515 .908 r
.47108 .36064 .4773 .36869 .48847 .35608 .48208 .36413 Mtetra
.587 .828 .452 r
.48208 .36413 .48847 .35608 .49951 .35728 .49335 .34935 Mtetra
.605 .703 .913 r
.49335 .34935 .49951 .35728 .51066 .35414 .50451 .34687 Mtetra
.642 .739 .919 r
.50451 .34687 .51066 .35414 .52185 .35058 .51573 .34342 Mtetra
.65 .746 .92 r
.51573 .34342 .52185 .35058 .53309 .34686 .527 .33973 Mtetra
.654 .749 .92 r
.527 .33973 .53309 .34686 .54437 .34304 .53832 .33592 Mtetra
.656 .751 .92 r
.53832 .33592 .54437 .34304 .5557 .33916 .54968 .33204 Mtetra
.658 .753 .92 r
.54968 .33204 .5557 .33916 .56708 .33524 .56109 .32809 Mtetra
.659 .753 .92 r
.56109 .32809 .56708 .33524 .5785 .33128 .57255 .32411 Mtetra
.659 .754 .92 r
.57255 .32411 .5785 .33128 .58997 .32729 .58405 .3201 Mtetra
.58405 .3201 .58997 .32729 .60149 .3233 .5956 .31607 Mtetra
.5956 .31607 .60149 .3233 .61306 .31929 .60719 .31203 Mtetra
.658 .754 .92 r
.60719 .31203 .61306 .31929 .62467 .31528 .61884 .30798 Mtetra
.658 .753 .92 r
.61884 .30798 .62467 .31528 .63633 .31125 .63053 .30392 Mtetra
.63053 .30392 .63633 .31125 .64804 .30722 .64227 .29985 Mtetra
.64227 .29985 .64804 .30722 .65979 .30317 .65406 .29577 Mtetra
.65406 .29577 .65979 .30317 .6716 .2991 .6659 .29168 Mtetra
.6659 .29168 .6716 .2991 .68346 .29503 .67779 .28757 Mtetra
.67779 .28757 .68346 .29503 .69536 .29094 .68973 .28344 Mtetra
.657 .753 .92 r
.68973 .28344 .69536 .29094 .70732 .28683 .70172 .2793 Mtetra
.70172 .2793 .70732 .28683 .71932 .28271 .71376 .27515 Mtetra
.71376 .27515 .71932 .28271 .73138 .27857 .72586 .27098 Mtetra
.72586 .27098 .73138 .27857 .74348 .27441 .738 .26679 Mtetra
.657 .752 .92 r
.738 .26679 .74348 .27441 .75564 .27024 .75019 .26259 Mtetra
.75019 .26259 .75564 .27024 .76785 .26606 .76244 .25837 Mtetra
.76244 .25837 .76785 .26606 .78011 .26185 .77474 .25413 Mtetra
.77474 .25413 .78011 .26185 .79243 .25763 .78709 .24987 Mtetra
.771 .944 .605 r
.13032 .47692 .13924 .46748 .14845 .46896 .14155 .46155 Mtetra
.556 .68 .921 r
.14155 .46155 .14845 .46896 .15801 .4679 .15113 .46035 Mtetra
.221 .513 .911 r
.15113 .46035 .15801 .4679 .16884 .45553 .16029 .46333 Mtetra
.681 .925 .615 r
.16029 .46333 .16884 .45553 .17802 .45863 .17118 .45105 Mtetra
.557 .677 .918 r
.17118 .45105 .17802 .45863 .18775 .45713 .18089 .44983 Mtetra
.492 .66 .936 r
.18089 .44983 .18775 .45713 .20754 .35535 .19055 .44963 Mtetra
.465 .214 .449 r
.19055 .44963 .20754 .35535 .20796 .44787 .20125 .43953 Mtetra
.525 .642 .907 r
.20125 .43953 .20796 .44787 .21784 .44615 .21102 .43901 Mtetra
.574 .7 .927 r
.21102 .43901 .21784 .44615 .22756 .44665 .22095 .43738 Mtetra
.861 .718 .702 r
.22095 .43738 .22756 .44665 .23832 .4361 .23268 .41635 Mtetra
.105 .179 .658 r
.23268 .41635 .23832 .4361 .24827 .43502 .24151 .42777 Mtetra
.592 .705 .922 r
.24151 .42777 .24827 .43502 .25833 .43311 .2516 .42577 Mtetra
.521 .675 .934 r
.2516 .42577 .25833 .43311 .26068 .52986 .26164 .42509 Mtetra
.571 .363 .559 r
.26164 .42509 .26068 .52986 .27907 .42337 .27248 .41473 Mtetra
.528 .638 .902 r
.27248 .41473 .27907 .42337 .28927 .42132 .28259 .41418 Mtetra
.604 .715 .923 r
.28259 .41418 .28927 .42132 .29953 .41929 .29288 .41184 Mtetra
.5 .664 .935 r
.29288 .41184 .29953 .41929 .31229 .38016 .30309 .4115 Mtetra
.313 .019 .296 r
.30309 .4115 .31229 .38016 .32056 .40927 .31402 .40092 Mtetra
.552 .659 .907 r
.31402 .40092 .32056 .40927 .33096 .40697 .32437 .39981 Mtetra
.615 .721 .922 r
.32437 .39981 .33096 .40697 .34143 .40444 .33486 .39719 Mtetra
.587 .709 .927 r
.33486 .39719 .34143 .40444 .35174 .40571 .34536 .39518 Mtetra
.822 .706 .737 r
.34536 .39518 .35174 .40571 .36278 .39379 .3566 .38016 Mtetra
.341 .425 .802 r
.3566 .38016 .36278 .39379 .37334 .39199 .36684 .38465 Mtetra
.616 .719 .919 r
.36684 .38465 .37334 .39199 .38399 .38911 .37751 .38198 Mtetra
.627 .73 .922 r
.37751 .38198 .38399 .38911 .3947 .38631 .38824 .37902 Mtetra
.6 .716 .926 r
.38824 .37902 .3947 .38631 .40534 .3863 .39899 .37667 Mtetra
.873 .731 .701 r
.39899 .37667 .40534 .3863 .41643 .37506 .41048 .35538 Mtetra
.203 .254 .694 r
.41048 .35538 .41643 .37506 .42723 .37336 .42086 .36588 Mtetra
.619 .72 .918 r
.42086 .36588 .42723 .37336 .43812 .37024 .43176 .36307 Mtetra
.638 .737 .92 r
.43176 .36307 .43812 .37024 .44906 .36691 .44273 .35978 Mtetra
.64 .74 .921 r
.44273 .35978 .44906 .36691 .46005 .36359 .45375 .35639 Mtetra
.635 .737 .922 r
.45375 .35639 .46005 .36359 .47108 .36064 .46481 .35314 Mtetra
.59 .711 .927 r
.46481 .35314 .47108 .36064 .48208 .36413 .47591 .35095 Mtetra
.78 .667 .739 r
.47591 .35095 .48208 .36413 .49335 .34935 .48719 .33823 Mtetra
.469 .554 .86 r
.48719 .33823 .49335 .34935 .50451 .34687 .49833 .33938 Mtetra
.631 .729 .918 r
.49833 .33938 .50451 .34687 .51573 .34342 .50958 .33616 Mtetra
.647 .744 .92 r
.50958 .33616 .51573 .34342 .527 .33973 .52087 .33253 Mtetra
.652 .748 .92 r
.52087 .33253 .527 .33973 .53832 .33592 .53222 .32873 Mtetra
.655 .751 .92 r
.53222 .32873 .53832 .33592 .54968 .33204 .54361 .32485 Mtetra
.657 .752 .92 r
.54361 .32485 .54968 .33204 .56109 .32809 .55505 .32089 Mtetra
.658 .753 .92 r
.55505 .32089 .56109 .32809 .57255 .32411 .56654 .31689 Mtetra
.659 .754 .92 r
.56654 .31689 .57255 .32411 .58405 .3201 .57807 .31285 Mtetra
.57807 .31285 .58405 .3201 .5956 .31607 .58966 .30879 Mtetra
.58966 .30879 .5956 .31607 .60719 .31203 .60128 .30472 Mtetra
.60128 .30472 .60719 .31203 .61884 .30798 .61296 .30063 Mtetra
.658 .753 .92 r
.61296 .30063 .61884 .30798 .63053 .30392 .62469 .29654 Mtetra
.62469 .29654 .63053 .30392 .64227 .29985 .63646 .29244 Mtetra
.63646 .29244 .64227 .29985 .65406 .29577 .64829 .28832 Mtetra
.64829 .28832 .65406 .29577 .6659 .29168 .66016 .28419 Mtetra
.66016 .28419 .6659 .29168 .67779 .28757 .67209 .28005 Mtetra
.67209 .28005 .67779 .28757 .68973 .28344 .68406 .27589 Mtetra
.657 .753 .92 r
.68406 .27589 .68973 .28344 .70172 .2793 .69609 .27172 Mtetra
.69609 .27172 .70172 .2793 .71376 .27515 .70816 .26753 Mtetra
.70816 .26753 .71376 .27515 .72586 .27098 .72029 .26333 Mtetra
.72029 .26333 .72586 .27098 .738 .26679 .73247 .25911 Mtetra
.73247 .25911 .738 .26679 .75019 .26259 .7447 .25487 Mtetra
.657 .752 .92 r
.7447 .25487 .75019 .26259 .76244 .25837 .75698 .25061 Mtetra
.75698 .25061 .76244 .25837 .77474 .25413 .76932 .24634 Mtetra
.76932 .24634 .77474 .25413 .78709 .24987 .78171 .24205 Mtetra
.743 .624 .727 r
.12417 .46252 .13032 .47692 .14155 .46155 .13488 .45169 Mtetra
.427 .551 .878 r
.13488 .45169 .14155 .46155 .15113 .46035 .14416 .45314 Mtetra
.547 .685 .93 r
.14416 .45314 .15113 .46035 .16029 .46333 .15379 .45202 Mtetra
.786 .675 .742 r
.15379 .45202 .16029 .46333 .17118 .45105 .16473 .43955 Mtetra
.357 .473 .841 r
.16473 .43955 .17118 .45105 .18089 .44983 .17398 .44262 Mtetra
.57 .696 .926 r
.17398 .44262 .18089 .44983 .19055 .44963 .18378 .44106 Mtetra
.93 .701 .57 r
.18378 .44106 .19055 .44963 .20125 .43953 .20386 .33884 Mtetra
0 0 .227 r
.20386 .33884 .20125 .43953 .21102 .43901 .20417 .43167 Mtetra
.581 .697 .922 r
.20417 .43167 .21102 .43901 .22095 .43738 .21412 .4299 Mtetra
.447 .637 .937 r
.21412 .4299 .22095 .43738 .23268 .41635 .22393 .43035 Mtetra
0 0 0 r
.22393 .43035 .23268 .41635 .24151 .42777 .23478 .4197 Mtetra
.552 .665 .912 r
.23478 .4197 .24151 .42777 .2516 .42577 .24481 .41857 Mtetra
.588 .707 .926 r
.24481 .41857 .2516 .42577 .26164 .42509 .25497 .4166 Mtetra
.958 .658 .423 r
.25497 .4166 .26164 .42509 .27248 .41473 .25722 .51373 Mtetra
0 0 .054 r
.25722 .51373 .27248 .41473 .28259 .41418 .27588 .40672 Mtetra
.594 .703 .919 r
.27588 .40672 .28259 .41418 .29288 .41184 .28617 .40461 Mtetra
.591 .71 .926 r
.28617 .40461 .29288 .41184 .30309 .4115 .29652 .40252 Mtetra
.914 .723 .631 r
.29652 .40252 .30309 .4115 .31402 .40092 .30943 .36319 Mtetra
0 0 .472 r
.30943 .36319 .31402 .40092 .32437 .39981 .31774 .39236 Mtetra
.604 .71 .919 r
.31774 .39236 .32437 .39981 .33486 .39719 .32823 .38999 Mtetra
.612 .722 .923 r
.32823 .38999 .33486 .39719 .34536 .39518 .33879 .3874 Mtetra
.399 .609 .933 r
.33879 .3874 .34536 .39518 .3566 .38016 .34918 .38862 Mtetra
0 0 0 r
.34918 .38862 .3566 .38016 .36684 .38465 .36033 .3766 Mtetra
.581 .686 .913 r
.36033 .3766 .36684 .38465 .37751 .38198 .37098 .37474 Mtetra
.625 .728 .921 r
.37098 .37474 .37751 .38198 .38824 .37902 .38173 .37179 Mtetra
.621 .728 .923 r
.38173 .37179 .38824 .37902 .39899 .37667 .39253 .36892 Mtetra
.482 .653 .935 r
.39253 .36892 .39899 .37667 .41048 .35538 .40327 .36886 Mtetra
0 0 0 r
.40327 .36886 .41048 .35538 .42086 .36588 .41447 .35752 Mtetra
.576 .677 .909 r
.41447 .35752 .42086 .36588 .43176 .36307 .42537 .35575 Mtetra
.632 .732 .92 r
.42537 .35575 .43176 .36307 .44273 .35978 .43636 .35257 Mtetra
.64 .739 .921 r
.43636 .35257 .44273 .35978 .45375 .35639 .4474 .34917 Mtetra
.639 .739 .921 r
.4474 .34917 .45375 .35639 .46481 .35314 .45849 .34578 Mtetra
.624 .73 .923 r
.45849 .34578 .46481 .35314 .47591 .35095 .46963 .34275 Mtetra
.253 .516 .908 r
.46963 .34275 .47591 .35095 .48719 .33823 .48072 .3462 Mtetra
.597 .837 .462 r
.48072 .3462 .48719 .33823 .49833 .33938 .4921 .33131 Mtetra
.605 .703 .913 r
.4921 .33131 .49833 .33938 .50958 .33616 .50337 .32876 Mtetra
.642 .739 .919 r
.50337 .32876 .50958 .33616 .52087 .33253 .5147 .32523 Mtetra
.65 .746 .92 r
.5147 .32523 .52087 .33253 .53222 .32873 .52607 .32147 Mtetra
.654 .749 .92 r
.52607 .32147 .53222 .32873 .54361 .32485 .5375 .31759 Mtetra
.656 .751 .92 r
.5375 .31759 .54361 .32485 .55505 .32089 .54897 .31362 Mtetra
.658 .753 .92 r
.54897 .31362 .55505 .32089 .56654 .31689 .56049 .3096 Mtetra
.659 .753 .92 r
.56049 .3096 .56654 .31689 .57807 .31285 .57205 .30554 Mtetra
.659 .754 .92 r
.57205 .30554 .57807 .31285 .58966 .30879 .58367 .30145 Mtetra
.58367 .30145 .58966 .30879 .60128 .30472 .59533 .29735 Mtetra
.59533 .29735 .60128 .30472 .61296 .30063 .60704 .29323 Mtetra
.658 .754 .92 r
.60704 .29323 .61296 .30063 .62469 .29654 .6188 .2891 Mtetra
.658 .753 .92 r
.6188 .2891 .62469 .29654 .63646 .29244 .63061 .28496 Mtetra
.63061 .28496 .63646 .29244 .64829 .28832 .64247 .28081 Mtetra
.64247 .28081 .64829 .28832 .66016 .28419 .65438 .27665 Mtetra
.65438 .27665 .66016 .28419 .67209 .28005 .66634 .27247 Mtetra
.66634 .27247 .67209 .28005 .68406 .27589 .67834 .26828 Mtetra
.67834 .26828 .68406 .27589 .69609 .27172 .69041 .26408 Mtetra
.657 .753 .92 r
.69041 .26408 .69609 .27172 .70816 .26753 .70252 .25985 Mtetra
.70252 .25985 .70816 .26753 .72029 .26333 .71468 .25562 Mtetra
.71468 .25562 .72029 .26333 .73247 .25911 .7269 .25136 Mtetra
.7269 .25136 .73247 .25911 .7447 .25487 .73916 .24709 Mtetra
.657 .752 .92 r
.73916 .24709 .7447 .25487 .75698 .25061 .75149 .2428 Mtetra
.75149 .2428 .75698 .25061 .76932 .24634 .76386 .23849 Mtetra
.76386 .23849 .76932 .24634 .78171 .24205 .77629 .23417 Mtetra
0 .226 .732 r
.11719 .45471 .12417 .46252 .13488 .45169 .12584 .46109 Mtetra
.777 .947 .612 r
.12584 .46109 .13488 .45169 .14416 .45314 .13718 .44561 Mtetra
.556 .68 .921 r
.13718 .44561 .14416 .45314 .15379 .45202 .14684 .44436 Mtetra
.223 .513 .911 r
.14684 .44436 .15379 .45202 .16473 .43955 .15607 .4473 Mtetra
.69 .931 .624 r
.15607 .4473 .16473 .43955 .17398 .44262 .16706 .43492 Mtetra
.557 .677 .918 r
.16706 .43492 .17398 .44262 .18378 .44106 .17685 .43365 Mtetra
.493 .66 .936 r
.17685 .43365 .18378 .44106 .20386 .33884 .18658 .4334 Mtetra
.46 .208 .444 r
.18658 .4334 .20386 .33884 .20417 .43167 .19738 .42321 Mtetra
.525 .642 .907 r
.19738 .42321 .20417 .43167 .21412 .4299 .20723 .42263 Mtetra
.574 .7 .927 r
.20723 .42263 .21412 .4299 .22393 .43035 .21724 .42095 Mtetra
.862 .718 .702 r
.21724 .42095 .22393 .43035 .23478 .4197 .22909 .39978 Mtetra
.101 .177 .657 r
.22909 .39978 .23478 .4197 .24481 .41857 .23798 .4112 Mtetra
.591 .705 .922 r
.23798 .4112 .24481 .41857 .25497 .4166 .24816 .40914 Mtetra
.521 .675 .934 r
.24816 .40914 .25497 .4166 .25722 .51373 .25828 .4084 Mtetra
.569 .36 .557 r
.25828 .4084 .25722 .51373 .27588 .40672 .26922 .39795 Mtetra
.528 .638 .903 r
.26922 .39795 .27588 .40672 .28617 .40461 .27942 .39734 Mtetra
.604 .715 .923 r
.27942 .39734 .28617 .40461 .29652 .40252 .2898 .39494 Mtetra
.5 .664 .935 r
.2898 .39494 .29652 .40252 .30943 .36319 .30009 .39455 Mtetra
.304 .009 .287 r
.30009 .39455 .30943 .36319 .31774 .39236 .31113 .38387 Mtetra
.552 .659 .907 r
.31113 .38387 .31774 .39236 .32823 .38999 .32156 .3827 Mtetra
.615 .721 .922 r
.32156 .3827 .32823 .38999 .33879 .3874 .33214 .38002 Mtetra
.587 .709 .927 r
.33214 .38002 .33879 .3874 .34918 .38862 .34274 .37795 Mtetra
.823 .707 .737 r
.34274 .37795 .34918 .38862 .36033 .3766 .35409 .36281 Mtetra
.34 .424 .802 r
.35409 .36281 .36033 .3766 .37098 .37474 .36442 .36726 Mtetra
.615 .719 .919 r
.36442 .36726 .37098 .37474 .38173 .37179 .37518 .36453 Mtetra
.627 .73 .922 r
.37518 .36453 .38173 .37179 .39253 .36892 .38601 .3615 Mtetra
.6 .716 .926 r
.38601 .3615 .39253 .36892 .40327 .36886 .39686 .35909 Mtetra
.874 .732 .701 r
.39686 .35909 .40327 .36886 .41447 .35752 .40846 .33766 Mtetra
.2 .252 .693 r
.40846 .33766 .41447 .35752 .42537 .35575 .41893 .34814 Mtetra
.619 .72 .918 r
.41893 .34814 .42537 .35575 .43636 .35257 .42993 .34527 Mtetra
.638 .737 .92 r
.42993 .34527 .43636 .35257 .4474 .34917 .441 .3419 Mtetra
.64 .74 .921 r
.441 .3419 .4474 .34917 .45849 .34578 .45212 .33844 Mtetra
.635 .737 .922 r
.45212 .33844 .45849 .34578 .46963 .34275 .46329 .33512 Mtetra
.59 .711 .927 r
.46329 .33512 .46963 .34275 .48072 .3462 .47449 .33286 Mtetra
.78 .668 .739 r
.47449 .33286 .48072 .3462 .4921 .33131 .48587 .32003 Mtetra
.468 .554 .861 r
.48587 .32003 .4921 .33131 .50337 .32876 .49712 .32112 Mtetra
.631 .729 .918 r
.49712 .32112 .50337 .32876 .5147 .32523 .50848 .31784 Mtetra
.647 .744 .92 r
.50848 .31784 .5147 .32523 .52607 .32147 .51988 .31413 Mtetra
.652 .748 .92 r
.51988 .31413 .52607 .32147 .5375 .31759 .53134 .31026 Mtetra
.655 .751 .92 r
.53134 .31026 .5375 .31759 .54897 .31362 .54284 .30629 Mtetra
.657 .752 .92 r
.54284 .30629 .54897 .31362 .56049 .3096 .55439 .30226 Mtetra
.658 .753 .92 r
.55439 .30226 .56049 .3096 .57205 .30554 .56599 .29818 Mtetra
.659 .754 .92 r
.56599 .29818 .57205 .30554 .58367 .30145 .57764 .29406 Mtetra
.57764 .29406 .58367 .30145 .59533 .29735 .58933 .28992 Mtetra
.58933 .28992 .59533 .29735 .60704 .29323 .60107 .28577 Mtetra
.60107 .28577 .60704 .29323 .6188 .2891 .61287 .28161 Mtetra
.658 .753 .92 r
.61287 .28161 .6188 .2891 .63061 .28496 .62471 .27743 Mtetra
.62471 .27743 .63061 .28496 .64247 .28081 .6366 .27325 Mtetra
.6366 .27325 .64247 .28081 .65438 .27665 .64855 .26905 Mtetra
.64855 .26905 .65438 .27665 .66634 .27247 .66054 .26484 Mtetra
.66054 .26484 .66634 .27247 .67834 .26828 .67258 .26061 Mtetra
.67258 .26061 .67834 .26828 .69041 .26408 .68468 .25637 Mtetra
.657 .753 .92 r
.68468 .25637 .69041 .26408 .70252 .25985 .69683 .25212 Mtetra
.69683 .25212 .70252 .25985 .71468 .25562 .70903 .24784 Mtetra
.70903 .24784 .71468 .25562 .7269 .25136 .72128 .24356 Mtetra
.72128 .24356 .7269 .25136 .73916 .24709 .73358 .23925 Mtetra
.73358 .23925 .73916 .24709 .75149 .2428 .74594 .23493 Mtetra
.657 .752 .92 r
.74594 .23493 .75149 .2428 .76386 .23849 .75835 .23058 Mtetra
.75835 .23058 .76386 .23849 .77629 .23417 .77082 .22623 Mtetra
.529 .676 .932 r
.1101 .44737 .11719 .45471 .12584 .46109 .11964 .44654 Mtetra
.743 .624 .727 r
.11964 .44654 .12584 .46109 .13718 .44561 .13044 .43562 Mtetra
.427 .551 .878 r
.13044 .43562 .13718 .44561 .14684 .44436 .13979 .43703 Mtetra
.547 .685 .93 r
.13979 .43703 .14684 .44436 .15607 .4473 .1495 .43586 Mtetra
.786 .676 .742 r
.1495 .43586 .15607 .4473 .16706 .43492 .16054 .42329 Mtetra
.356 .473 .841 r
.16054 .42329 .16706 .43492 .17685 .43365 .16986 .42632 Mtetra
.57 .696 .926 r
.16986 .42632 .17685 .43365 .18658 .4334 .17974 .4247 Mtetra
.931 .701 .569 r
.17974 .4247 .18658 .4334 .19738 .42321 .20012 .32203 Mtetra
0 0 .22 r
.20012 .32203 .19738 .42321 .20723 .42263 .2003 .41517 Mtetra
.581 .697 .922 r
.2003 .41517 .20723 .42263 .21724 .42095 .21034 .41334 Mtetra
.448 .637 .937 r
.21034 .41334 .21724 .42095 .22909 .39978 .22022 .41375 Mtetra
0 0 0 r
.22022 .41375 .22909 .39978 .23798 .4112 .23118 .403 Mtetra
.552 .665 .912 r
.23118 .403 .23798 .4112 .24816 .40914 .24129 .40182 Mtetra
.588 .707 .926 r
.24129 .40182 .24816 .40914 .25828 .4084 .25153 .39978 Mtetra
.958 .658 .42 r
.25153 .39978 .25828 .4084 .26922 .39795 .25369 .49729 Mtetra
0 0 .046 r
.25369 .49729 .26922 .39795 .27942 .39734 .27263 .38976 Mtetra
.594 .703 .919 r
.27263 .38976 .27942 .39734 .2898 .39494 .28301 .38759 Mtetra
.591 .71 .926 r
.28301 .38759 .2898 .39494 .30009 .39455 .29345 .38544 Mtetra
.915 .724 .63 r
.29345 .38544 .30009 .39455 .31113 .38387 .30651 .34589 Mtetra
0 0 .469 r
.30651 .34589 .31113 .38387 .32156 .3827 .31486 .37513 Mtetra
.604 .71 .919 r
.31486 .37513 .32156 .3827 .33214 .38002 .32545 .37269 Mtetra
.612 .722 .923 r
.32545 .37269 .33214 .38002 .34274 .37795 .33609 .37004 Mtetra
.4 .609 .933 r
.33609 .37004 .34274 .37795 .35409 .36281 .34658 .37121 Mtetra
0 0 0 r
.34658 .37121 .35409 .36281 .36442 .36726 .35784 .35909 Mtetra
.581 .686 .913 r
.35784 .35909 .36442 .36726 .37518 .36453 .36858 .35716 Mtetra
.625 .728 .921 r
.36858 .35716 .37518 .36453 .38601 .3615 .37943 .35414 Mtetra
.621 .728 .923 r
.37943 .35414 .38601 .3615 .39686 .35909 .39033 .3512 Mtetra
.483 .653 .935 r
.39033 .3512 .39686 .35909 .40846 .33766 .40116 .35108 Mtetra
0 0 0 r
.40116 .35108 .40846 .33766 .41893 .34814 .41247 .33964 Mtetra
.576 .677 .909 r
.41247 .33964 .41893 .34814 .42993 .34527 .42346 .33781 Mtetra
.632 .732 .92 r
.42346 .33781 .42993 .34527 .441 .3419 .43456 .33456 Mtetra
.64 .739 .921 r
.43456 .33456 .441 .3419 .45212 .33844 .4457 .33108 Mtetra
.639 .739 .921 r
.4457 .33108 .45212 .33844 .46329 .33512 .4569 .32762 Mtetra
.624 .73 .923 r
.4569 .32762 .46329 .33512 .47449 .33286 .46814 .32452 Mtetra
.256 .517 .908 r
.46814 .32452 .47449 .33286 .48587 .32003 .47934 .32793 Mtetra
.608 .845 .473 r
.47934 .32793 .48587 .32003 .49712 .32112 .49083 .31291 Mtetra
.604 .703 .913 r
.49083 .31291 .49712 .32112 .50848 .31784 .50221 .31029 Mtetra
.642 .739 .919 r
.50221 .31029 .50848 .31784 .51988 .31413 .51364 .30669 Mtetra
.65 .746 .92 r
.51364 .30669 .51988 .31413 .53134 .31026 .52513 .30285 Mtetra
.654 .75 .92 r
.52513 .30285 .53134 .31026 .54284 .30629 .53666 .29889 Mtetra
.656 .751 .92 r
.53666 .29889 .54284 .30629 .55439 .30226 .54824 .29485 Mtetra
.658 .753 .92 r
.54824 .29485 .55439 .30226 .56599 .29818 .55988 .29075 Mtetra
.659 .753 .92 r
.55988 .29075 .56599 .29818 .57764 .29406 .57155 .28661 Mtetra
.659 .754 .92 r
.57155 .28661 .57764 .29406 .58933 .28992 .58328 .28244 Mtetra
.58328 .28244 .58933 .28992 .60107 .28577 .59506 .27825 Mtetra
.59506 .27825 .60107 .28577 .61287 .28161 .60689 .27405 Mtetra
.658 .754 .92 r
.60689 .27405 .61287 .28161 .62471 .27743 .61876 .26984 Mtetra
.658 .753 .92 r
.61876 .26984 .62471 .27743 .6366 .27325 .63069 .26562 Mtetra
.63069 .26562 .6366 .27325 .64855 .26905 .64267 .26139 Mtetra
.64267 .26139 .64855 .26905 .66054 .26484 .6547 .25714 Mtetra
.6547 .25714 .66054 .26484 .67258 .26061 .66678 .25288 Mtetra
.66678 .25288 .67258 .26061 .68468 .25637 .67891 .24861 Mtetra
.67891 .24861 .68468 .25637 .69683 .25212 .69109 .24432 Mtetra
.657 .753 .92 r
.69109 .24432 .69683 .25212 .70903 .24784 .70333 .24001 Mtetra
.70333 .24001 .70903 .24784 .72128 .24356 .71562 .23569 Mtetra
.71562 .23569 .72128 .24356 .73358 .23925 .72796 .23135 Mtetra
.72796 .23135 .73358 .23925 .74594 .23493 .74035 .22699 Mtetra
.657 .752 .92 r
.74035 .22699 .74594 .23493 .75835 .23058 .7528 .22261 Mtetra
.7528 .22261 .75835 .23058 .77082 .22623 .76531 .21822 Mtetra
.545 .673 .922 r
.103 .4397 .1101 .44737 .11964 .44654 .11258 .43861 Mtetra
0 .23 .735 r
.11258 .43861 .11964 .44654 .13044 .43562 .12128 .44497 Mtetra
.783 .951 .619 r
.12128 .44497 .13044 .43562 .13979 .43703 .13273 .42937 Mtetra
.556 .68 .921 r
.13273 .42937 .13979 .43703 .1495 .43586 .14247 .42807 Mtetra
.225 .514 .911 r
.14247 .42807 .1495 .43586 .16054 .42329 .15177 .43098 Mtetra
.699 .937 .633 r
.15177 .43098 .16054 .42329 .16986 .42632 .16286 .41849 Mtetra
.557 .677 .918 r
.16286 .41849 .16986 .42632 .17974 .4247 .17273 .41717 Mtetra
.493 .66 .936 r
.17273 .41717 .17974 .4247 .20012 .32203 .18254 .41686 Mtetra
.455 .201 .439 r
.18254 .41686 .20012 .32203 .2003 .41517 .19344 .40658 Mtetra
.525 .642 .907 r
.19344 .40658 .2003 .41517 .21034 .41334 .20337 .40595 Mtetra
.574 .7 .927 r
.20337 .40595 .21034 .41334 .22022 .41375 .21347 .40421 Mtetra
.863 .719 .702 r
.21347 .40421 .22022 .41375 .23118 .403 .22544 .38291 Mtetra
.097 .174 .655 r
.22544 .38291 .23118 .403 .24129 .40182 .23439 .39432 Mtetra
.591 .705 .922 r
.23439 .39432 .24129 .40182 .25153 .39978 .24465 .3922 Mtetra
.521 .675 .934 r
.24465 .3922 .25153 .39978 .25369 .49729 .25486 .3914 Mtetra
.567 .357 .555 r
.25486 .3914 .25369 .49729 .27263 .38976 .2659 .38085 Mtetra
.527 .638 .903 r
.2659 .38085 .27263 .38976 .28301 .38759 .27618 .38019 Mtetra
.604 .715 .923 r
.27618 .38019 .28301 .38759 .29345 .38544 .28666 .37773 Mtetra
.5 .664 .935 r
.28666 .37773 .29345 .38544 .30651 .34589 .29704 .37728 Mtetra
.295 0 .278 r
.29704 .37728 .30651 .34589 .31486 .37513 .30818 .3665 Mtetra
.552 .659 .907 r
.30818 .3665 .31486 .37513 .32545 .37269 .3187 .36527 Mtetra
.615 .721 .922 r
.3187 .36527 .32545 .37269 .33609 .37004 .32938 .36252 Mtetra
.587 .709 .927 r
.32938 .36252 .33609 .37004 .34658 .37121 .34007 .36039 Mtetra
.824 .708 .737 r
.34007 .36039 .34658 .37121 .35784 .35909 .35153 .34514 Mtetra
.338 .423 .802 r
.35153 .34514 .35784 .35909 .36858 .35716 .36194 .34955 Mtetra
.615 .719 .919 r
.36194 .34955 .36858 .35716 .37943 .35414 .37281 .34674 Mtetra
.627 .73 .922 r
.37281 .34674 .37943 .35414 .39033 .3512 .38373 .34364 Mtetra
.6 .716 .926 r
.38373 .34364 .39033 .3512 .40116 .35108 .39468 .34116 Mtetra
.875 .732 .701 r
.39468 .34116 .40116 .35108 .41247 .33964 .40641 .3196 Mtetra
.197 .25 .692 r
.40641 .3196 .41247 .33964 .42346 .33781 .41696 .33006 Mtetra
.619 .72 .918 r
.41696 .33006 .42346 .33781 .43456 .33456 .42807 .32711 Mtetra
.638 .737 .92 r
.42807 .32711 .43456 .33456 .4457 .33108 .43924 .32367 Mtetra
.64 .74 .921 r
.43924 .32367 .4457 .33108 .4569 .32762 .45046 .32014 Mtetra
.635 .737 .922 r
.45046 .32014 .4569 .32762 .46814 .32452 .46173 .31675 Mtetra
.59 .711 .927 r
.46173 .31675 .46814 .32452 .47934 .32793 .47304 .31441 Mtetra
.781 .668 .739 r
.47304 .31441 .47934 .32793 .49083 .31291 .48454 .30147 Mtetra
.467 .554 .861 r
.48454 .30147 .49083 .31291 .50221 .31029 .49589 .30251 Mtetra
.631 .729 .918 r
.49589 .30251 .50221 .31029 .51364 .30669 .50735 .29915 Mtetra
.647 .744 .92 r
.50735 .29915 .51364 .30669 .52513 .30285 .51887 .29536 Mtetra
.652 .748 .92 r
.51887 .29536 .52513 .30285 .53666 .29889 .53044 .29141 Mtetra
.655 .751 .92 r
.53044 .29141 .53666 .29889 .54824 .29485 .54205 .28737 Mtetra
.657 .752 .92 r
.54205 .28737 .54824 .29485 .55988 .29075 .55371 .28326 Mtetra
.658 .753 .92 r
.55371 .28326 .55988 .29075 .57155 .28661 .56543 .27909 Mtetra
.659 .754 .92 r
.56543 .27909 .57155 .28661 .58328 .28244 .57719 .2749 Mtetra
.57719 .2749 .58328 .28244 .59506 .27825 .589 .27068 Mtetra
.589 .27068 .59506 .27825 .60689 .27405 .60086 .26644 Mtetra
.60086 .26644 .60689 .27405 .61876 .26984 .61277 .2622 Mtetra
.658 .753 .92 r
.61277 .2622 .61876 .26984 .63069 .26562 .62473 .25794 Mtetra
.62473 .25794 .63069 .26562 .64267 .26139 .63674 .25367 Mtetra
.63674 .25367 .64267 .26139 .6547 .25714 .64881 .24939 Mtetra
.64881 .24939 .6547 .25714 .66678 .25288 .66092 .24509 Mtetra
.66092 .24509 .66678 .25288 .67891 .24861 .67309 .24078 Mtetra
.67309 .24078 .67891 .24861 .69109 .24432 .68531 .23646 Mtetra
.657 .753 .92 r
.68531 .23646 .69109 .24432 .70333 .24001 .69758 .23212 Mtetra
.69758 .23212 .70333 .24001 .71562 .23569 .70991 .22776 Mtetra
.70991 .22776 .71562 .23569 .72796 .23135 .72229 .22338 Mtetra
.72229 .22338 .72796 .23135 .74035 .22699 .73472 .21898 Mtetra
.73472 .21898 .74035 .22699 .7528 .22261 .74721 .21457 Mtetra
.657 .752 .92 r
.74721 .21457 .7528 .22261 .76531 .21822 .75975 .21014 Mtetra
.384 .512 .864 r
.09625 .429 .103 .4397 .11258 .43861 .10541 .43115 Mtetra
.529 .676 .932 r
.10541 .43115 .11258 .43861 .12128 .44497 .11502 .43027 Mtetra
.744 .625 .727 r
.11502 .43027 .12128 .44497 .13273 .42937 .12593 .41926 Mtetra
.426 .551 .878 r
.12593 .41926 .13273 .42937 .14247 .42807 .13534 .42061 Mtetra
.547 .685 .93 r
.13534 .42061 .14247 .42807 .15177 .43098 .14513 .41939 Mtetra
.787 .676 .742 r
.14513 .41939 .15177 .43098 .16286 .41849 .15627 .40672 Mtetra
.354 .472 .841 r
.15627 .40672 .16286 .41849 .17273 .41717 .16566 .40971 Mtetra
.57 .696 .926 r
.16566 .40971 .17273 .41717 .18254 .41686 .17563 .40804 Mtetra
.932 .702 .567 r
.17563 .40804 .18254 .41686 .19344 .40658 .19631 .30493 Mtetra
0 0 .213 r
.19631 .30493 .19344 .40658 .20337 .40595 .19636 .39836 Mtetra
.581 .697 .922 r
.19636 .39836 .20337 .40595 .21347 .40421 .20649 .39648 Mtetra
.448 .637 .937 r
.20649 .39648 .21347 .40421 .22544 .38291 .21645 .39683 Mtetra
0 0 0 r
.21645 .39683 .22544 .38291 .23439 .39432 .22751 .38599 Mtetra
.551 .665 .912 r
.22751 .38599 .23439 .39432 .24465 .3922 .23771 .38475 Mtetra
.588 .707 .926 r
.23771 .38475 .24465 .3922 .25486 .3914 .24804 .38265 Mtetra
.959 .657 .416 r
.24804 .38265 .25486 .3914 .2659 .38085 .2501 .48052 Mtetra
0 0 .037 r
.2501 .48052 .2659 .38085 .27618 .38019 .26932 .37248 Mtetra
.594 .703 .92 r
.26932 .37248 .27618 .38019 .28666 .37773 .2798 .37025 Mtetra
.591 .71 .926 r
.2798 .37025 .28666 .37773 .29704 .37728 .29032 .36803 Mtetra
.916 .724 .629 r
.29032 .36803 .29704 .37728 .30818 .3665 .30353 .32827 Mtetra
0 0 .465 r
.30353 .32827 .30818 .3665 .3187 .36527 .31193 .35756 Mtetra
.604 .71 .919 r
.31193 .35756 .3187 .36527 .32938 .36252 .32261 .35506 Mtetra
.612 .722 .923 r
.32261 .35506 .32938 .36252 .34007 .36039 .33335 .35234 Mtetra
.401 .609 .933 r
.33335 .35234 .34007 .36039 .35153 .34514 .34393 .35346 Mtetra
0 0 0 r
.34393 .35346 .35153 .34514 .36194 .34955 .35529 .34123 Mtetra
.581 .686 .913 r
.35529 .34123 .36194 .34955 .37281 .34674 .36614 .33924 Mtetra
.625 .728 .921 r
.36614 .33924 .37281 .34674 .38373 .34364 .37709 .33615 Mtetra
.621 .728 .923 r
.37709 .33615 .38373 .34364 .39468 .34116 .38808 .33314 Mtetra
.483 .653 .934 r
.38808 .33314 .39468 .34116 .40641 .3196 .39901 .33296 Mtetra
0 0 0 r
.39901 .33296 .40641 .3196 .41696 .33006 .41043 .32141 Mtetra
.576 .677 .909 r
.41043 .32141 .41696 .33006 .42807 .32711 .42153 .31952 Mtetra
.632 .732 .92 r
.42153 .31952 .42807 .32711 .43924 .32367 .43272 .31619 Mtetra
.64 .739 .921 r
.43272 .31619 .43924 .32367 .45046 .32014 .44398 .31264 Mtetra
.639 .739 .921 r
.44398 .31264 .45046 .32014 .46173 .31675 .45528 .3091 Mtetra
.624 .73 .923 r
.45528 .3091 .46173 .31675 .47304 .31441 .46662 .30593 Mtetra
.258 .518 .909 r
.46662 .30593 .47304 .31441 .48454 .30147 .47792 .30929 Mtetra
.618 .853 .483 r
.47792 .30929 .48454 .30147 .49589 .30251 .48953 .29415 Mtetra
.604 .703 .913 r
.48953 .29415 .49589 .30251 .50735 .29915 .50102 .29146 Mtetra
.642 .739 .919 r
.50102 .29146 .50735 .29915 .51887 .29536 .51256 .28778 Mtetra
.65 .746 .92 r
.51256 .28778 .51887 .29536 .53044 .29141 .52416 .28386 Mtetra
.654 .75 .92 r
.52416 .28386 .53044 .29141 .54205 .28737 .53581 .27982 Mtetra
.656 .751 .92 r
.53581 .27982 .54205 .28737 .55371 .28326 .5475 .2757 Mtetra
.658 .753 .92 r
.5475 .2757 .55371 .28326 .56543 .27909 .55925 .27152 Mtetra
.659 .753 .92 r
.55925 .27152 .56543 .27909 .57719 .2749 .57104 .26729 Mtetra
.659 .754 .92 r
.57104 .26729 .57719 .2749 .589 .27068 .58289 .26304 Mtetra
.58289 .26304 .589 .27068 .60086 .26644 .59478 .25877 Mtetra
.59478 .25877 .60086 .26644 .61277 .2622 .60673 .25449 Mtetra
.658 .754 .92 r
.60673 .25449 .61277 .2622 .62473 .25794 .61872 .2502 Mtetra
.658 .753 .92 r
.61872 .2502 .62473 .25794 .63674 .25367 .63077 .24589 Mtetra
.63077 .24589 .63674 .25367 .64881 .24939 .64287 .24157 Mtetra
.64287 .24157 .64881 .24939 .66092 .24509 .65502 .23724 Mtetra
.65502 .23724 .66092 .24509 .67309 .24078 .66723 .2329 Mtetra
.66723 .2329 .67309 .24078 .68531 .23646 .67948 .22853 Mtetra
.67948 .22853 .68531 .23646 .69758 .23212 .69179 .22416 Mtetra
.657 .753 .92 r
.69179 .22416 .69758 .23212 .70991 .22776 .70415 .21976 Mtetra
.70415 .21976 .70991 .22776 .72229 .22338 .71657 .21535 Mtetra
.71657 .21535 .72229 .22338 .73472 .21898 .72904 .21092 Mtetra
.72904 .21092 .73472 .21898 .74721 .21457 .74157 .20647 Mtetra
.657 .752 .92 r
.74157 .20647 .74721 .21457 .75975 .21014 .75415 .202 Mtetra
.775 .967 .669 r
.08694 .43705 .09625 .429 .10541 .43115 .09823 .42335 Mtetra
.545 .673 .922 r
.09823 .42335 .10541 .43115 .11502 .43027 .10788 .42222 Mtetra
0 .233 .738 r
.10788 .42222 .11502 .43027 .12593 .41926 .11664 .42855 Mtetra
.79 .955 .626 r
.11664 .42855 .12593 .41926 .13534 .42061 .1282 .41284 Mtetra
.556 .68 .921 r
.1282 .41284 .13534 .42061 .14513 .41939 .13802 .41148 Mtetra
.228 .515 .912 r
.13802 .41148 .14513 .41939 .15627 .40672 .14739 .41435 Mtetra
.707 .942 .642 r
.14739 .41435 .15627 .40672 .16566 .40971 .15859 .40176 Mtetra
.557 .677 .919 r
.15859 .40176 .16566 .40971 .17563 .40804 .16854 .40038 Mtetra
.493 .66 .936 r
.16854 .40038 .17563 .40804 .19631 .30493 .17843 .40002 Mtetra
.45 .195 .434 r
.17843 .40002 .19631 .30493 .19636 .39836 .18943 .38965 Mtetra
.525 .642 .907 r
.18943 .38965 .19636 .39836 .20649 .39648 .19944 .38896 Mtetra
.574 .7 .927 r
.19944 .38896 .20649 .39648 .21645 .39683 .20962 .38716 Mtetra
.864 .72 .702 r
.20962 .38716 .21645 .39683 .22751 .38599 .22172 .36571 Mtetra
.093 .171 .654 r
.22172 .36571 .22751 .38599 .23771 .38475 .23073 .37712 Mtetra
.591 .705 .922 r
.23073 .37712 .23771 .38475 .24804 .38265 .24108 .37493 Mtetra
.521 .675 .934 r
.24108 .37493 .24804 .38265 .2501 .48052 .25137 .37408 Mtetra
.565 .353 .552 r
.25137 .37408 .2501 .48052 .26932 .37248 .26252 .36343 Mtetra
.527 .638 .903 r
.26252 .36343 .26932 .37248 .2798 .37025 .27289 .36271 Mtetra
.604 .715 .923 r
.27289 .36271 .2798 .37025 .29032 .36803 .28345 .36019 Mtetra
.501 .664 .935 r
.28345 .36019 .29032 .36803 .30353 .32827 .29392 .35968 Mtetra
.286 0 .269 r
.29392 .35968 .30353 .32827 .31193 .35756 .30517 .3488 Mtetra
.552 .659 .907 r
.30517 .3488 .31193 .35756 .32261 .35506 .31579 .34751 Mtetra
.615 .721 .922 r
.31579 .34751 .32261 .35506 .33335 .35234 .32656 .34469 Mtetra
.587 .709 .927 r
.32656 .34469 .33335 .35234 .34393 .35346 .33734 .34249 Mtetra
.824 .709 .738 r
.33734 .34249 .34393 .35346 .35529 .34123 .34892 .32712 Mtetra
.337 .422 .802 r
.34892 .32712 .35529 .34123 .36614 .33924 .35943 .33149 Mtetra
.615 .719 .919 r
.35943 .33149 .36614 .33924 .37709 .33615 .37039 .32862 Mtetra
.627 .73 .922 r
.37039 .32862 .37709 .33615 .38808 .33314 .38141 .32544 Mtetra
.6 .716 .926 r
.38141 .32544 .38808 .33314 .39901 .33296 .39246 .32289 Mtetra
.876 .733 .701 r
.39246 .32289 .39901 .33296 .41043 .32141 .40431 .30118 Mtetra
.194 .248 .691 r
.40431 .30118 .41043 .32141 .42153 .31952 .41495 .31162 Mtetra
.619 .72 .918 r
.41495 .31162 .42153 .31952 .43272 .31619 .42616 .30861 Mtetra
.638 .737 .92 r
.42616 .30861 .43272 .31619 .44398 .31264 .43744 .30509 Mtetra
.64 .74 .921 r
.43744 .30509 .44398 .31264 .45528 .3091 .44877 .30148 Mtetra
.635 .737 .922 r
.44877 .30148 .45528 .3091 .46662 .30593 .46015 .29801 Mtetra
.59 .711 .927 r
.46015 .29801 .46662 .30593 .47792 .30929 .47156 .29561 Mtetra
.781 .669 .74 r
.47156 .29561 .47792 .30929 .48953 .29415 .48318 .28255 Mtetra
.467 .554 .861 r
.48318 .28255 .48953 .29415 .50102 .29146 .49464 .28353 Mtetra
.631 .729 .918 r
.49464 .28353 .50102 .29146 .51256 .28778 .50621 .28009 Mtetra
.647 .744 .92 r
.50621 .28009 .51256 .28778 .52416 .28386 .51784 .27622 Mtetra
.652 .748 .92 r
.51784 .27622 .52416 .28386 .53581 .27982 .52952 .27219 Mtetra
.655 .751 .92 r
.52952 .27219 .53581 .27982 .5475 .2757 .54124 .26807 Mtetra
.657 .752 .92 r
.54124 .26807 .5475 .2757 .55925 .27152 .55302 .26387 Mtetra
.658 .753 .92 r
.55302 .26387 .55925 .27152 .57104 .26729 .56485 .25963 Mtetra
.659 .754 .92 r
.56485 .25963 .57104 .26729 .58289 .26304 .57673 .25535 Mtetra
.57673 .25535 .58289 .26304 .59478 .25877 .58866 .25104 Mtetra
.58866 .25104 .59478 .25877 .60673 .25449 .60064 .24672 Mtetra
.60064 .24672 .60673 .25449 .61872 .2502 .61267 .24239 Mtetra
.658 .753 .92 r
.61267 .24239 .61872 .2502 .63077 .24589 .62475 .23805 Mtetra
.62475 .23805 .63077 .24589 .64287 .24157 .63689 .2337 Mtetra
.63689 .2337 .64287 .24157 .65502 .23724 .64907 .22933 Mtetra
.64907 .22933 .65502 .23724 .66723 .2329 .66131 .22495 Mtetra
.66131 .22495 .66723 .2329 .67948 .22853 .67361 .22055 Mtetra
.67361 .22055 .67948 .22853 .69179 .22416 .68595 .21613 Mtetra
.657 .753 .92 r
.68595 .21613 .69179 .22416 .70415 .21976 .69835 .2117 Mtetra
.69835 .2117 .70415 .21976 .71657 .21535 .71081 .20725 Mtetra
.71081 .20725 .71657 .21535 .72904 .21092 .72332 .20279 Mtetra
.72332 .20279 .72904 .21092 .74157 .20647 .73588 .1983 Mtetra
.73588 .1983 .74157 .20647 .75415 .202 .7485 .1938 Mtetra
.764 .651 .738 r
.08037 .42411 .08694 .43705 .09823 .42335 .0914 .41253 Mtetra
.383 .512 .864 r
.0914 .41253 .09823 .42335 .10788 .42222 .10062 .41463 Mtetra
.529 .676 .931 r
.10062 .41463 .10788 .42222 .11664 .42855 .11031 .4137 Mtetra
.744 .625 .727 r
.11031 .4137 .11664 .42855 .1282 .41284 .12132 .40259 Mtetra
.426 .551 .879 r
.12132 .40259 .1282 .41284 .13802 .41148 .13081 .4039 Mtetra
.547 .685 .93 r
.13081 .4039 .13802 .41148 .14739 .41435 .14067 .40262 Mtetra
.787 .677 .742 r
.14067 .40262 .14739 .41435 .15859 .40176 .15193 .38984 Mtetra
.353 .472 .841 r
.15193 .38984 .15859 .40176 .16854 .40038 .16138 .39279 Mtetra
.57 .696 .926 r
.16138 .39279 .16854 .40038 .17843 .40002 .17144 .39106 Mtetra
.933 .702 .566 r
.17144 .39106 .17843 .40002 .18943 .38965 .19242 .28751 Mtetra
0 0 .206 r
.19242 .28751 .18943 .38965 .19944 .38896 .19235 .38124 Mtetra
.581 .697 .922 r
.19235 .38124 .19944 .38896 .20962 .38716 .20256 .37929 Mtetra
.449 .637 .936 r
.20256 .37929 .20962 .38716 .22172 .36571 .2126 .37959 Mtetra
0 0 0 r
.2126 .37959 .22172 .36571 .23073 .37712 .22377 .36865 Mtetra
.551 .665 .912 r
.22377 .36865 .23073 .37712 .24108 .37493 .23406 .36735 Mtetra
.588 .707 .926 r
.23406 .36735 .24108 .37493 .25137 .37408 .24447 .36519 Mtetra
.96 .657 .412 r
.24447 .36519 .25137 .37408 .26252 .36343 .24643 .46343 Mtetra
0 0 .029 r
.24643 .46343 .26252 .36343 .27289 .36271 .26595 .35487 Mtetra
.594 .703 .92 r
.26595 .35487 .27289 .36271 .28345 .36019 .27652 .35257 Mtetra
.591 .71 .926 r
.27652 .35257 .28345 .36019 .29392 .35968 .28713 .35029 Mtetra
.917 .725 .628 r
.28713 .35029 .29392 .35968 .30517 .3488 .3005 .31032 Mtetra
0 0 .461 r
.3005 .31032 .30517 .3488 .31579 .34751 .30894 .33966 Mtetra
.604 .71 .919 r
.30894 .33966 .31579 .34751 .32656 .34469 .31971 .33709 Mtetra
.612 .722 .923 r
.31971 .33709 .32656 .34469 .33734 .34249 .33055 .33431 Mtetra
.402 .609 .933 r
.33055 .33431 .33734 .34249 .34892 .32712 .34122 .33537 Mtetra
.519 .817 .484 r
.34122 .33537 .34892 .32712 .35943 .33149 .3527 .32303 Mtetra
.581 .686 .913 r
.3527 .32303 .35943 .33149 .37039 .32862 .36364 .32097 Mtetra
.625 .728 .921 r
.36364 .32097 .37039 .32862 .38141 .32544 .37469 .31781 Mtetra
.621 .728 .923 r
.37469 .31781 .38141 .32544 .39246 .32289 .38579 .31473 Mtetra
.484 .653 .934 r
.38579 .31473 .39246 .32289 .40431 .30118 .39682 .31449 Mtetra
0 0 0 r
.39682 .31449 .40431 .30118 .41495 .31162 .40836 .30283 Mtetra
.576 .678 .909 r
.40836 .30283 .41495 .31162 .42616 .30861 .41955 .30086 Mtetra
.632 .732 .92 r
.41955 .30086 .42616 .30861 .43744 .30509 .43085 .29746 Mtetra
.64 .739 .921 r
.43085 .29746 .43744 .30509 .44877 .30148 .44221 .29384 Mtetra
.639 .739 .921 r
.44221 .29384 .44877 .30148 .46015 .29801 .45362 .29022 Mtetra
.624 .73 .923 r
.45362 .29022 .46015 .29801 .47156 .29561 .46508 .28697 Mtetra
.261 .519 .909 r
.46508 .28697 .47156 .29561 .48318 .28255 .47648 .29028 Mtetra
.628 .86 .493 r
.47648 .29028 .48318 .28255 .49464 .28353 .48821 .27502 Mtetra
.604 .703 .913 r
.48821 .27502 .49464 .28353 .50621 .28009 .49981 .27225 Mtetra
.641 .739 .919 r
.49981 .27225 .50621 .28009 .51784 .27622 .51146 .26849 Mtetra
.65 .746 .92 r
.51146 .26849 .51784 .27622 .52952 .27219 .52317 .26449 Mtetra
.654 .75 .92 r
.52317 .26449 .52952 .27219 .54124 .26807 .53494 .26037 Mtetra
.656 .751 .92 r
.53494 .26037 .54124 .26807 .55302 .26387 .54675 .25616 Mtetra
.658 .753 .92 r
.54675 .25616 .55302 .26387 .56485 .25963 .55861 .2519 Mtetra
.659 .753 .92 r
.55861 .2519 .56485 .25963 .57673 .25535 .57052 .24759 Mtetra
.659 .754 .92 r
.57052 .24759 .57673 .25535 .58866 .25104 .58249 .24325 Mtetra
.58249 .24325 .58866 .25104 .60064 .24672 .5945 .2389 Mtetra
.5945 .2389 .60064 .24672 .61267 .24239 .60657 .23453 Mtetra
.658 .754 .92 r
.60657 .23453 .61267 .24239 .62475 .23805 .61869 .23015 Mtetra
.658 .753 .92 r
.61869 .23015 .62475 .23805 .63689 .2337 .63086 .22576 Mtetra
.63086 .22576 .63689 .2337 .64907 .22933 .64308 .22135 Mtetra
.64308 .22135 .64907 .22933 .66131 .22495 .65536 .21693 Mtetra
.65536 .21693 .66131 .22495 .67361 .22055 .66769 .2125 Mtetra
.66769 .2125 .67361 .22055 .68595 .21613 .68007 .20805 Mtetra
.68007 .20805 .68595 .21613 .69835 .2117 .69251 .20358 Mtetra
.657 .753 .92 r
.69251 .20358 .69835 .2117 .71081 .20725 .705 .19909 Mtetra
.705 .19909 .71081 .20725 .72332 .20279 .71755 .19459 Mtetra
.71755 .19459 .72332 .20279 .73588 .1983 .73015 .19007 Mtetra
.73015 .19007 .73588 .1983 .7485 .1938 .74281 .18553 Mtetra
.028 .39 .849 r
.07309 .41606 .08037 .42411 .0914 .41253 .08197 .42051 Mtetra
.781 .97 .675 r
.08197 .42051 .0914 .41253 .10062 .41463 .09336 .40671 Mtetra
.545 .673 .922 r
.09336 .40671 .10062 .41463 .11031 .4137 .10309 .40551 Mtetra
0 .237 .742 r
.10309 .40551 .11031 .4137 .12132 .40259 .11191 .41182 Mtetra
.795 .958 .633 r
.11191 .41182 .12132 .40259 .13081 .4039 .12359 .396 Mtetra
.556 .68 .922 r
.12359 .396 .13081 .4039 .14067 .40262 .13348 .39458 Mtetra
.23 .516 .912 r
.13348 .39458 .14067 .40262 .15193 .38984 .14292 .3974 Mtetra
.715 .947 .65 r
.14292 .3974 .15193 .38984 .16138 .39279 .15423 .38471 Mtetra
.557 .677 .919 r
.15423 .38471 .16138 .39279 .17144 .39106 .16426 .38327 Mtetra
.493 .66 .935 r
.16426 .38327 .17144 .39106 .19242 .28751 .17424 .38286 Mtetra
.445 .188 .428 r
.17424 .38286 .19242 .28751 .19235 .38124 .18534 .37239 Mtetra
.525 .642 .908 r
.18534 .37239 .19235 .38124 .20256 .37929 .19543 .37165 Mtetra
.574 .699 .927 r
.19543 .37165 .20256 .37929 .2126 .37959 .2057 .36978 Mtetra
.865 .721 .701 r
.2057 .36978 .2126 .37959 .22377 .36865 .21793 .3482 Mtetra
.089 .168 .653 r
.21793 .3482 .22377 .36865 .23406 .36735 .227 .35959 Mtetra
.591 .705 .922 r
.227 .35959 .23406 .36735 .24447 .36519 .23744 .35734 Mtetra
.522 .675 .934 r
.23744 .35734 .24447 .36519 .24643 .46343 .24781 .35643 Mtetra
.562 .35 .55 r
.24781 .35643 .24643 .46343 .26595 .35487 .25908 .34568 Mtetra
.527 .638 .903 r
.25908 .34568 .26595 .35487 .27652 .35257 .26953 .3449 Mtetra
.604 .715 .923 r
.26953 .3449 .27652 .35257 .28713 .35029 .28019 .3423 Mtetra
.501 .664 .935 r
.28019 .3423 .28713 .35029 .3005 .31032 .29075 .34174 Mtetra
.277 0 .259 r
.29075 .34174 .3005 .31032 .30894 .33966 .30211 .33076 Mtetra
.551 .659 .908 r
.30211 .33076 .30894 .33966 .31971 .33709 .31282 .3294 Mtetra
.615 .721 .922 r
.31282 .3294 .31971 .33709 .33055 .33431 .32369 .32651 Mtetra
.587 .709 .927 r
.32369 .32651 .33055 .33431 .34122 .33537 .33457 .32425 Mtetra
.825 .71 .738 r
.33457 .32425 .34122 .33537 .3527 .32303 .34626 .30875 Mtetra
.335 .422 .802 r
.34626 .30875 .3527 .32303 .36364 .32097 .35686 .31308 Mtetra
.615 .719 .919 r
.35686 .31308 .36364 .32097 .37469 .31781 .36792 .31013 Mtetra
.627 .73 .922 r
.36792 .31013 .37469 .31781 .38579 .31473 .37905 .30689 Mtetra
.6 .716 .926 r
.37905 .30689 .38579 .31473 .39682 .31449 .3902 .30426 Mtetra
.877 .734 .7 r
.3902 .30426 .39682 .31449 .40836 .30283 .40217 .28241 Mtetra
.191 .246 .691 r
.40217 .28241 .40836 .30283 .41955 .30086 .4129 .29282 Mtetra
.619 .72 .918 r
.4129 .29282 .41955 .30086 .43085 .29746 .42422 .28973 Mtetra
.638 .737 .92 r
.42422 .28973 .43085 .29746 .44221 .29384 .43561 .28614 Mtetra
.64 .74 .921 r
.43561 .28614 .44221 .29384 .45362 .29022 .44704 .28245 Mtetra
.635 .737 .922 r
.44704 .28245 .45362 .29022 .46508 .28697 .45853 .2789 Mtetra
.59 .711 .927 r
.45853 .2789 .46508 .28697 .47648 .29028 .47005 .27642 Mtetra
.782 .67 .74 r
.47005 .27642 .47648 .29028 .48821 .27502 .48179 .26325 Mtetra
.466 .554 .861 r
.48179 .26325 .48821 .27502 .49981 .27225 .49336 .26417 Mtetra
.631 .729 .918 r
.49336 .26417 .49981 .27225 .51146 .26849 .50504 .26065 Mtetra
.647 .744 .92 r
.50504 .26065 .51146 .26849 .52317 .26449 .51678 .2567 Mtetra
.652 .748 .92 r
.51678 .2567 .52317 .26449 .53494 .26037 .52858 .25259 Mtetra
.655 .751 .92 r
.52858 .25259 .53494 .26037 .54675 .25616 .54042 .24838 Mtetra
.657 .752 .92 r
.54042 .24838 .54675 .25616 .55861 .2519 .55232 .2441 Mtetra
.658 .753 .92 r
.55232 .2441 .55861 .2519 .57052 .24759 .56427 .23977 Mtetra
.659 .754 .92 r
.56427 .23977 .57052 .24759 .58249 .24325 .57627 .2354 Mtetra
.57627 .2354 .58249 .24325 .5945 .2389 .58831 .23101 Mtetra
.58831 .23101 .5945 .2389 .60657 .23453 .60042 .2266 Mtetra
.60042 .2266 .60657 .23453 .61869 .23015 .61257 .22219 Mtetra
.658 .753 .92 r
.61257 .22219 .61869 .23015 .63086 .22576 .62478 .21775 Mtetra
.62478 .21775 .63086 .22576 .64308 .22135 .63703 .21331 Mtetra
.63703 .21331 .64308 .22135 .65536 .21693 .64935 .20885 Mtetra
.64935 .20885 .65536 .21693 .66769 .2125 .66171 .20438 Mtetra
.66171 .20438 .66769 .2125 .68007 .20805 .67414 .19989 Mtetra
.67414 .19989 .68007 .20805 .69251 .20358 .68661 .19539 Mtetra
.657 .753 .92 r
.68661 .19539 .69251 .20358 .705 .19909 .69914 .19086 Mtetra
.69914 .19086 .705 .19909 .71755 .19459 .71173 .18632 Mtetra
.71173 .18632 .71755 .19459 .73015 .19007 .72437 .18176 Mtetra
.72437 .18176 .73015 .19007 .74281 .18553 .73707 .17719 Mtetra
.527 .673 .931 r
.06571 .40835 .07309 .41606 .08197 .42051 .07533 .40742 Mtetra
.764 .652 .738 r
.07533 .40742 .08197 .42051 .09336 .40671 .08646 .39574 Mtetra
.382 .512 .864 r
.08646 .39574 .09336 .40671 .10309 .40551 .09575 .3978 Mtetra
.529 .676 .931 r
.09575 .3978 .10309 .40551 .11191 .41182 .10552 .39681 Mtetra
.744 .625 .727 r
.10552 .39681 .11191 .41182 .12359 .396 .11663 .3856 Mtetra
.425 .551 .879 r
.11663 .3856 .12359 .396 .13348 .39458 .12619 .38687 Mtetra
.548 .685 .93 r
.12619 .38687 .13348 .39458 .14292 .3974 .13614 .38553 Mtetra
.788 .678 .743 r
.13614 .38553 .14292 .3974 .15423 .38471 .1475 .37265 Mtetra
.352 .471 .841 r
.1475 .37265 .15423 .38471 .16426 .38327 .15703 .37556 Mtetra
.57 .696 .926 r
.15703 .37556 .16426 .38327 .17424 .38286 .16716 .37377 Mtetra
.934 .703 .564 r
.16716 .37377 .17424 .38286 .18534 .37239 .18847 .26976 Mtetra
0 0 .199 r
.18847 .26976 .18534 .37239 .19543 .37165 .18827 .36379 Mtetra
.581 .697 .922 r
.18827 .36379 .19543 .37165 .2057 .36978 .19856 .36178 Mtetra
.449 .637 .936 r
.19856 .36178 .2057 .36978 .21793 .3482 .20869 .36203 Mtetra
0 0 0 r
.20869 .36203 .21793 .3482 .227 .35959 .21996 .35099 Mtetra
.551 .665 .912 r
.21996 .35099 .227 .35959 .23744 .35734 .23033 .34962 Mtetra
.588 .707 .926 r
.23033 .34962 .23744 .35734 .24781 .35643 .24084 .34739 Mtetra
.96 .656 .408 r
.24084 .34739 .24781 .35643 .25908 .34568 .2427 .446 Mtetra
0 0 .02 r
.2427 .446 .25908 .34568 .26953 .3449 .26252 .33691 Mtetra
.594 .703 .92 r
.26252 .33691 .26953 .3449 .28019 .3423 .27317 .33455 Mtetra
.591 .71 .926 r
.27317 .33455 .28019 .3423 .29075 .34174 .28388 .3322 Mtetra
.918 .726 .627 r
.28388 .3322 .29075 .34174 .30211 .33076 .29741 .29202 Mtetra
0 0 .458 r
.29741 .29202 .30211 .33076 .31282 .3294 .30589 .32141 Mtetra
.604 .71 .919 r
.30589 .32141 .31282 .3294 .32369 .32651 .31676 .31877 Mtetra
.612 .721 .923 r
.31676 .31877 .32369 .32651 .33457 .32425 .3277 .31591 Mtetra
.403 .609 .933 r
.3277 .31591 .33457 .32425 .34626 .30875 .33846 .31692 Mtetra
.533 .828 .497 r
.33846 .31692 .34626 .30875 .35686 .31308 .35006 .30447 Mtetra
.581 .686 .913 r
.35006 .30447 .35686 .31308 .36792 .31013 .3611 .30234 Mtetra
.625 .728 .921 r
.3611 .30234 .36792 .31013 .37905 .30689 .37225 .29911 Mtetra
.621 .728 .923 r
.37225 .29911 .37905 .30689 .3902 .30426 .38345 .29595 Mtetra
.484 .653 .934 r
.38345 .29595 .3902 .30426 .40217 .28241 .39459 .29564 Mtetra
0 0 0 r
.39459 .29564 .40217 .28241 .4129 .29282 .40624 .28388 Mtetra
.576 .678 .909 r
.40624 .28388 .4129 .29282 .42422 .28973 .41754 .28184 Mtetra
.632 .732 .92 r
.41754 .28184 .42422 .28973 .43561 .28614 .42895 .27836 Mtetra
.64 .739 .921 r
.42895 .27836 .43561 .28614 .44704 .28245 .44042 .27466 Mtetra
.639 .739 .921 r
.44042 .27466 .44704 .28245 .45853 .2789 .45193 .27096 Mtetra
.624 .73 .923 r
.45193 .27096 .45853 .2789 .47005 .27642 .4635 .26763 Mtetra
.263 .52 .909 r
.4635 .26763 .47005 .27642 .48179 .26325 .47501 .27088 Mtetra
.638 .868 .503 r
.47501 .27088 .48179 .26325 .49336 .26417 .48686 .2555 Mtetra
.604 .703 .914 r
.48686 .2555 .49336 .26417 .50504 .26065 .49857 .25265 Mtetra
.641 .739 .919 r
.49857 .25265 .50504 .26065 .51678 .2567 .51034 .24881 Mtetra
.65 .746 .92 r
.51034 .24881 .51678 .2567 .52858 .25259 .52217 .24473 Mtetra
.654 .75 .92 r
.52217 .24473 .52858 .25259 .54042 .24838 .53405 .24052 Mtetra
.656 .751 .92 r
.53405 .24052 .54042 .24838 .55232 .2441 .54598 .23623 Mtetra
.658 .753 .92 r
.54598 .23623 .55232 .2441 .56427 .23977 .55796 .23188 Mtetra
.659 .753 .92 r
.55796 .23188 .56427 .23977 .57627 .2354 .56999 .22748 Mtetra
.659 .754 .92 r
.56999 .22748 .57627 .2354 .58831 .23101 .58208 .22306 Mtetra
.58208 .22306 .58831 .23101 .60042 .2266 .59421 .21862 Mtetra
.59421 .21862 .60042 .2266 .61257 .22219 .6064 .21416 Mtetra
.658 .754 .92 r
.6064 .21416 .61257 .22219 .62478 .21775 .61865 .20969 Mtetra
.658 .753 .92 r
.61865 .20969 .62478 .21775 .63703 .21331 .63094 .20521 Mtetra
.63094 .20521 .63703 .21331 .64935 .20885 .64329 .20071 Mtetra
.64329 .20071 .64935 .20885 .66171 .20438 .6557 .1962 Mtetra
.6557 .1962 .66171 .20438 .67414 .19989 .66815 .19167 Mtetra
.66815 .19167 .67414 .19989 .68661 .19539 .68067 .18713 Mtetra
.68067 .18713 .68661 .19539 .69914 .19086 .69324 .18257 Mtetra
.657 .753 .92 r
.69324 .18257 .69914 .19086 .71173 .18632 .70586 .17799 Mtetra
.70586 .17799 .71173 .18632 .72437 .18176 .71854 .17339 Mtetra
.71854 .17339 .72437 .18176 .73707 .17719 .73128 .16878 Mtetra
.523 .655 .918 r
.05836 .40004 .06571 .40835 .07533 .40742 .06796 .39924 Mtetra
.032 .392 .851 r
.06796 .39924 .07533 .40742 .08646 .39574 .0769 .40366 Mtetra
.787 .973 .682 r
.0769 .40366 .08646 .39574 .09575 .3978 .08841 .38975 Mtetra
.545 .673 .922 r
.08841 .38975 .09575 .3978 .10552 .39681 .09821 .3885 Mtetra
0 .241 .745 r
.09821 .3885 .10552 .39681 .11663 .3856 .10709 .39478 Mtetra
.801 .961 .639 r
.10709 .39478 .11663 .3856 .12619 .38687 .11889 .37883 Mtetra
.556 .68 .922 r
.11889 .37883 .12619 .38687 .13614 .38553 .12886 .37735 Mtetra
.232 .517 .912 r
.12886 .37735 .13614 .38553 .1475 .37265 .13837 .38014 Mtetra
.723 .952 .659 r
.13837 .38014 .1475 .37265 .15703 .37556 .1498 .36734 Mtetra
.557 .677 .919 r
.1498 .36734 .15703 .37556 .16716 .37377 .15991 .36584 Mtetra
.494 .66 .935 r
.15991 .36584 .16716 .37377 .18847 .26976 .16996 .36537 Mtetra
.44 .181 .423 r
.16996 .36537 .18847 .26976 .18827 .36379 .18117 .3548 Mtetra
.524 .642 .908 r
.18117 .3548 .18827 .36379 .19856 .36178 .19135 .354 Mtetra
.574 .699 .927 r
.19135 .354 .19856 .36178 .20869 .36203 .2017 .35207 Mtetra
.866 .722 .701 r
.2017 .35207 .20869 .36203 .21996 .35099 .21406 .33034 Mtetra
.084 .165 .651 r
.21406 .33034 .21996 .35099 .23033 .34962 .22319 .34172 Mtetra
.591 .705 .922 r
.22319 .34172 .23033 .34962 .24084 .34739 .23373 .33941 Mtetra
.522 .675 .934 r
.23373 .33941 .24084 .34739 .2427 .446 .24419 .33843 Mtetra
.56 .346 .547 r
.24419 .33843 .2427 .446 .26252 .33691 .25556 .32758 Mtetra
.527 .638 .903 r
.25556 .32758 .26252 .33691 .27317 .33455 .26611 .32674 Mtetra
.604 .715 .923 r
.26611 .32674 .27317 .33455 .28388 .3322 .27686 .32408 Mtetra
.501 .664 .935 r
.27686 .32408 .28388 .3322 .29741 .29202 .28751 .32345 Mtetra
.267 0 .249 r
.28751 .32345 .29741 .29202 .30589 .32141 .29899 .31236 Mtetra
.551 .659 .908 r
.29899 .31236 .30589 .32141 .31676 .31877 .30979 .31094 Mtetra
.615 .721 .922 r
.30979 .31094 .31676 .31877 .3277 .31591 .32076 .30798 Mtetra
.587 .709 .927 r
.32076 .30798 .3277 .31591 .33846 .31692 .33174 .30564 Mtetra
.826 .711 .738 r
.33174 .30564 .33846 .31692 .35006 .30447 .34355 .29003 Mtetra
.333 .421 .802 r
.34355 .29003 .35006 .30447 .3611 .30234 .35424 .2943 Mtetra
.615 .719 .919 r
.35424 .2943 .3611 .30234 .37225 .29911 .3654 .29128 Mtetra
.627 .73 .922 r
.3654 .29128 .37225 .29911 .38345 .29595 .37664 .28796 Mtetra
.6 .716 .926 r
.37664 .28796 .38345 .29595 .39459 .29564 .3879 .28527 Mtetra
.878 .735 .7 r
.3879 .28527 .39459 .29564 .40624 .28388 .39999 .26326 Mtetra
.187 .244 .69 r
.39999 .26326 .40624 .28388 .41754 .28184 .41081 .27365 Mtetra
.619 .72 .918 r
.41081 .27365 .41754 .28184 .42895 .27836 .42224 .27048 Mtetra
.638 .737 .92 r
.42224 .27048 .42895 .27836 .44042 .27466 .43373 .26681 Mtetra
.64 .74 .921 r
.43373 .26681 .44042 .27466 .45193 .27096 .44528 .26304 Mtetra
.635 .737 .922 r
.44528 .26304 .45193 .27096 .4635 .26763 .45688 .25941 Mtetra
.59 .711 .927 r
.45688 .25941 .4635 .26763 .47501 .27088 .46852 .25685 Mtetra
.782 .67 .74 r
.46852 .25685 .47501 .27088 .48686 .2555 .48037 .24357 Mtetra
.466 .553 .861 r
.48037 .24357 .48686 .2555 .49857 .25265 .49205 .24441 Mtetra
.631 .729 .918 r
.49205 .24441 .49857 .25265 .51034 .24881 .50385 .24081 Mtetra
.647 .744 .92 r
.50385 .24081 .51034 .24881 .52217 .24473 .51571 .23678 Mtetra
.652 .748 .92 r
.51571 .23678 .52217 .24473 .53405 .24052 .52762 .23258 Mtetra
.655 .751 .92 r
.52762 .23258 .53405 .24052 .54598 .23623 .53959 .22829 Mtetra
.657 .752 .92 r
.53959 .22829 .54598 .23623 .55796 .23188 .5516 .22392 Mtetra
.658 .753 .92 r
.5516 .22392 .55796 .23188 .56999 .22748 .56367 .2195 Mtetra
.659 .754 .92 r
.56367 .2195 .56999 .22748 .58208 .22306 .57579 .21504 Mtetra
.57579 .21504 .58208 .22306 .59421 .21862 .58796 .21056 Mtetra
.58796 .21056 .59421 .21862 .6064 .21416 .60019 .20607 Mtetra
.60019 .20607 .6064 .21416 .61865 .20969 .61247 .20156 Mtetra
.658 .753 .92 r
.61247 .20156 .61865 .20969 .63094 .20521 .6248 .19704 Mtetra
.6248 .19704 .63094 .20521 .64329 .20071 .63719 .1925 Mtetra
.63719 .1925 .64329 .20071 .6557 .1962 .64963 .18795 Mtetra
.64963 .18795 .6557 .1962 .66815 .19167 .66212 .18339 Mtetra
.66212 .18339 .66815 .19167 .68067 .18713 .67467 .17881 Mtetra
.67467 .17881 .68067 .18713 .69324 .18257 .68728 .17421 Mtetra
.657 .753 .92 r
.68728 .17421 .69324 .18257 .70586 .17799 .69995 .16959 Mtetra
.69995 .16959 .70586 .17799 .71854 .17339 .71267 .16495 Mtetra
.71267 .16495 .71854 .17339 .73128 .16878 .72544 .1603 Mtetra
.098 .221 .704 r
.0522 .38333 .05836 .40004 .06796 .39924 .0605 .39141 Mtetra
.527 .673 .931 r
.0605 .39141 .06796 .39924 .0769 .40366 .07019 .39042 Mtetra
.764 .652 .738 r
.07019 .39042 .0769 .40366 .08841 .38975 .08143 .37864 Mtetra
.381 .511 .864 r
.08143 .37864 .08841 .38975 .09821 .3885 .09079 .38066 Mtetra
.529 .676 .931 r
.09079 .38066 .09821 .3885 .10709 .39478 .10063 .37961 Mtetra
.745 .626 .727 r
.10063 .37961 .10709 .39478 .11889 .37883 .11185 .3683 Mtetra
.424 .551 .879 r
.11185 .3683 .11889 .37883 .12886 .37735 .12149 .36952 Mtetra
.548 .685 .93 r
.12149 .36952 .12886 .37735 .13837 .38014 .13151 .36812 Mtetra
.788 .678 .743 r
.13151 .36812 .13837 .38014 .1498 .36734 .14299 .35513 Mtetra
.351 .471 .841 r
.14299 .35513 .1498 .36734 .15991 .36584 .15259 .35799 Mtetra
.57 .696 .926 r
.15259 .35799 .15991 .36584 .16996 .36537 .16281 .35614 Mtetra
.936 .703 .562 r
.16281 .35614 .16996 .36537 .18117 .3548 .18444 .2517 Mtetra
0 0 .192 r
.18444 .2517 .18117 .3548 .19135 .354 .1841 .34601 Mtetra
.581 .697 .922 r
.1841 .34601 .19135 .354 .2017 .35207 .19449 .34393 Mtetra
.45 .637 .936 r
.19449 .34393 .2017 .35207 .21406 .33034 .20469 .34412 Mtetra
0 0 0 r
.20469 .34412 .21406 .33034 .22319 .34172 .21608 .33298 Mtetra
.551 .665 .912 r
.21608 .33298 .22319 .34172 .23373 .33941 .22654 .33155 Mtetra
.588 .707 .926 r
.22654 .33155 .23373 .33941 .24419 .33843 .23714 .32925 Mtetra
.961 .656 .404 r
.23714 .32925 .24419 .33843 .25556 .32758 .23888 .42822 Mtetra
0 0 .012 r
.23888 .42822 .25556 .32758 .26611 .32674 .25901 .31861 Mtetra
.594 .703 .92 r
.25901 .31861 .26611 .32674 .27686 .32408 .26977 .31618 Mtetra
.591 .71 .926 r
.26977 .31618 .27686 .32408 .28751 .32345 .28057 .31376 Mtetra
.92 .727 .625 r
.28057 .31376 .28751 .32345 .29899 .31236 .29426 .27336 Mtetra
0 0 .454 r
.29426 .27336 .29899 .31236 .30979 .31094 .30278 .30281 Mtetra
.604 .71 .919 r
.30278 .30281 .30979 .31094 .32076 .30798 .31376 .3001 Mtetra
.612 .721 .923 r
.31376 .3001 .32076 .30798 .33174 .30564 .32479 .29716 Mtetra
.404 .609 .933 r
.32479 .29716 .33174 .30564 .34355 .29003 .33565 .29811 Mtetra
.546 .839 .51 r
.33565 .29811 .34355 .29003 .35424 .2943 .34736 .28555 Mtetra
.581 .686 .913 r
.34736 .28555 .35424 .2943 .3654 .29128 .35851 .28335 Mtetra
.625 .728 .921 r
.35851 .28335 .3654 .29128 .37664 .28796 .36976 .28003 Mtetra
.621 .728 .923 r
.36976 .28003 .37664 .28796 .3879 .28527 .38107 .2768 Mtetra
.485 .653 .934 r
.38107 .2768 .3879 .28527 .39999 .26326 .39231 .27643 Mtetra
0 0 0 r
.39231 .27643 .39999 .26326 .41081 .27365 .40407 .26455 Mtetra
.576 .678 .909 r
.40407 .26455 .41081 .27365 .42224 .27048 .41548 .26244 Mtetra
.632 .732 .92 r
.41548 .26244 .42224 .27048 .43373 .26681 .427 .25888 Mtetra
.64 .739 .921 r
.427 .25888 .43373 .26681 .44528 .26304 .43858 .25509 Mtetra
.639 .739 .921 r
.43858 .25509 .44528 .26304 .45688 .25941 .45021 .25132 Mtetra
.624 .73 .923 r
.45021 .25132 .45688 .25941 .46852 .25685 .46189 .2479 Mtetra
.265 .521 .909 r
.46189 .2479 .46852 .25685 .48037 .24357 .47351 .2511 Mtetra
.647 .875 .513 r
.47351 .2511 .48037 .24357 .49205 .24441 .48548 .23559 Mtetra
.604 .703 .914 r
.48548 .23559 .49205 .24441 .50385 .24081 .49731 .23266 Mtetra
.641 .739 .919 r
.49731 .23266 .50385 .24081 .51571 .23678 .5092 .22873 Mtetra
.65 .746 .92 r
.5092 .22873 .51571 .23678 .52762 .23258 .52114 .22456 Mtetra
.654 .75 .92 r
.52114 .22456 .52762 .23258 .53959 .22829 .53314 .22026 Mtetra
.656 .751 .92 r
.53314 .22026 .53959 .22829 .5516 .22392 .54519 .21589 Mtetra
.658 .753 .92 r
.54519 .21589 .5516 .22392 .56367 .2195 .5573 .21145 Mtetra
.659 .753 .92 r
.5573 .21145 .56367 .2195 .57579 .21504 .56945 .20696 Mtetra
.659 .754 .92 r
.56945 .20696 .57579 .21504 .58796 .21056 .58166 .20245 Mtetra
.58166 .20245 .58796 .21056 .60019 .20607 .59392 .19791 Mtetra
.59392 .19791 .60019 .20607 .61247 .20156 .60624 .19337 Mtetra
.658 .754 .92 r
.60624 .19337 .61247 .20156 .6248 .19704 .6186 .1888 Mtetra
.658 .753 .92 r
.6186 .1888 .6248 .19704 .63719 .1925 .63103 .18423 Mtetra
.63103 .18423 .63719 .1925 .64963 .18795 .64351 .17964 Mtetra
.64351 .17964 .64963 .18795 .66212 .18339 .65604 .17504 Mtetra
.65604 .17504 .66212 .18339 .67467 .17881 .66863 .17041 Mtetra
.66863 .17041 .67467 .17881 .68728 .17421 .68128 .16578 Mtetra
.68128 .16578 .68728 .17421 .69995 .16959 .69398 .16112 Mtetra
.657 .753 .92 r
.69398 .16112 .69995 .16959 .71267 .16495 .70674 .15644 Mtetra
.70674 .15644 .71267 .16495 .72544 .1603 .71956 .15175 Mtetra
0 0 0 r
.04194 .39383 .0522 .38333 .0605 .39141 .05306 .38296 Mtetra
.523 .655 .918 r
.05306 .38296 .0605 .39141 .07019 .39042 .06274 .38211 Mtetra
.036 .394 .852 r
.06274 .38211 .07019 .39042 .08143 .37864 .07173 .38649 Mtetra
.793 .975 .688 r
.07173 .38649 .08143 .37864 .09079 .38066 .08336 .37247 Mtetra
.545 .673 .922 r
.08336 .37247 .09079 .38066 .10063 .37961 .09324 .37116 Mtetra
0 .245 .748 r
.09324 .37116 .10063 .37961 .11185 .3683 .10218 .37741 Mtetra
.807 .964 .646 r
.10218 .37741 .11185 .3683 .12149 .36952 .1141 .36135 Mtetra
.556 .68 .922 r
.1141 .36135 .12149 .36952 .13151 .36812 .12415 .35981 Mtetra
.234 .517 .912 r
.12415 .35981 .13151 .36812 .14299 .35513 .13374 .36255 Mtetra
.731 .957 .667 r
.13374 .36255 .14299 .35513 .15259 .35799 .14527 .34964 Mtetra
.557 .677 .919 r
.14527 .34964 .15259 .35799 .16281 .35614 .15547 .34808 Mtetra
.494 .66 .935 r
.15547 .34808 .16281 .35614 .18444 .2517 .16561 .34755 Mtetra
.434 .173 .417 r
.16561 .34755 .18444 .2517 .1841 .34601 .17692 .33688 Mtetra
.524 .642 .908 r
.17692 .33688 .1841 .34601 .19449 .34393 .18719 .33601 Mtetra
.574 .699 .927 r
.18719 .33601 .19449 .34393 .20469 .34412 .19763 .33402 Mtetra
.867 .723 .701 r
.19763 .33402 .20469 .34412 .21608 .33298 .21013 .31215 Mtetra
.08 .162 .65 r
.21013 .31215 .21608 .33298 .22654 .33155 .21932 .32351 Mtetra
.591 .705 .922 r
.21932 .32351 .22654 .33155 .23714 .32925 .22994 .32112 Mtetra
.522 .675 .933 r
.22994 .32112 .23714 .32925 .23888 .42822 .2405 .32008 Mtetra
.558 .343 .544 r
.2405 .32008 .23888 .42822 .25901 .31861 .25198 .30913 Mtetra
.526 .638 .903 r
.25198 .30913 .25901 .31861 .26977 .31618 .26262 .30823 Mtetra
.604 .715 .923 r
.26262 .30823 .26977 .31618 .28057 .31376 .27347 .30549 Mtetra
.502 .664 .934 r
.27347 .30549 .28057 .31376 .29426 .27336 .28421 .3048 Mtetra
.257 0 .239 r
.28421 .3048 .29426 .27336 .30278 .30281 .2958 .29361 Mtetra
.551 .659 .908 r
.2958 .29361 .30278 .30281 .31376 .3001 .3067 .29211 Mtetra
.615 .721 .922 r
.3067 .29211 .31376 .3001 .32479 .29716 .31777 .28908 Mtetra
.587 .709 .927 r
.31777 .28908 .32479 .29716 .33565 .29811 .32885 .28667 Mtetra
.827 .712 .738 r
.32885 .28667 .33565 .29811 .34736 .28555 .34079 .27093 Mtetra
.332 .42 .802 r
.34079 .27093 .34736 .28555 .35851 .28335 .35157 .27516 Mtetra
.615 .719 .919 r
.35157 .27516 .35851 .28335 .36976 .28003 .36284 .27206 Mtetra
.627 .73 .922 r
.36284 .27206 .36976 .28003 .38107 .2768 .37418 .26866 Mtetra
.6 .716 .926 r
.37418 .26866 .38107 .2768 .39231 .27643 .38554 .26588 Mtetra
.879 .736 .7 r
.38554 .26588 .39231 .27643 .40407 .26455 .39777 .24373 Mtetra
.184 .242 .689 r
.39777 .24373 .40407 .26455 .41548 .26244 .40868 .25409 Mtetra
.619 .72 .918 r
.40868 .25409 .41548 .26244 .427 .25888 .42022 .25084 Mtetra
.638 .737 .92 r
.42022 .25084 .427 .25888 .43858 .25509 .43183 .24709 Mtetra
.64 .74 .921 r
.43183 .24709 .43858 .25509 .45021 .25132 .44349 .24324 Mtetra
.635 .737 .922 r
.44349 .24324 .45021 .25132 .46189 .2479 .4552 .23952 Mtetra
.59 .711 .927 r
.4552 .23952 .46189 .2479 .47351 .2511 .46695 .23688 Mtetra
.783 .671 .74 r
.46695 .23688 .47351 .2511 .48548 .23559 .47892 .22348 Mtetra
.465 .553 .861 r
.47892 .22348 .48548 .23559 .49731 .23266 .49072 .22426 Mtetra
.631 .729 .918 r
.49072 .22426 .49731 .23266 .5092 .22873 .50263 .22057 Mtetra
.647 .744 .92 r
.50263 .22057 .5092 .22873 .52114 .22456 .51461 .21645 Mtetra
.652 .748 .92 r
.51461 .21645 .52114 .22456 .53314 .22026 .52664 .21216 Mtetra
.655 .751 .92 r
.52664 .21216 .53314 .22026 .54519 .21589 .53873 .20778 Mtetra
.657 .752 .92 r
.53873 .20778 .54519 .21589 .5573 .21145 .55087 .20332 Mtetra
.658 .753 .92 r
.55087 .20332 .5573 .21145 .56945 .20696 .56306 .19881 Mtetra
.659 .754 .92 r
.56306 .19881 .56945 .20696 .58166 .20245 .5753 .19427 Mtetra
.5753 .19427 .58166 .20245 .59392 .19791 .5876 .18969 Mtetra
.5876 .18969 .59392 .19791 .60624 .19337 .59995 .18511 Mtetra
.59995 .18511 .60624 .19337 .6186 .1888 .61236 .1805 Mtetra
.658 .753 .92 r
.61236 .1805 .6186 .1888 .63103 .18423 .62482 .17589 Mtetra
.62482 .17589 .63103 .18423 .64351 .17964 .63734 .17126 Mtetra
.63734 .17126 .64351 .17964 .65604 .17504 .64991 .16661 Mtetra
.64991 .16661 .65604 .17504 .66863 .17041 .66254 .16195 Mtetra
.66254 .16195 .66863 .17041 .68128 .16578 .67522 .15728 Mtetra
.67522 .15728 .68128 .16578 .69398 .16112 .68797 .15258 Mtetra
.657 .753 .92 r
.68797 .15258 .69398 .16112 .70674 .15644 .70077 .14786 Mtetra
.70077 .14786 .70674 .15644 .71956 .15175 .71362 .14313 Mtetra
.834 .706 .723 r
.03468 .38361 .04194 .39383 .05306 .38296 .04684 .36609 Mtetra
.095 .219 .703 r
.04684 .36609 .05306 .38296 .06274 .38211 .05518 .37415 Mtetra
.527 .673 .931 r
.05518 .37415 .06274 .38211 .07173 .38649 .06495 .3731 Mtetra
.765 .653 .738 r
.06495 .3731 .07173 .38649 .08336 .37247 .0763 .36122 Mtetra
.38 .511 .864 r
.0763 .36122 .08336 .37247 .09324 .37116 .08573 .36319 Mtetra
.529 .676 .931 r
.08573 .36319 .09324 .37116 .10218 .37741 .09565 .36208 Mtetra
.745 .626 .728 r
.09565 .36208 .10218 .37741 .1141 .36135 .10699 .35067 Mtetra
.424 .55 .879 r
.10699 .35067 .1141 .36135 .12415 .35981 .11669 .35183 Mtetra
.548 .685 .929 r
.11669 .35183 .12415 .35981 .13374 .36255 .1268 .35037 Mtetra
.789 .679 .743 r
.1268 .35037 .13374 .36255 .14527 .34964 .13839 .33727 Mtetra
.35 .47 .841 r
.13839 .33727 .14527 .34964 .15547 .34808 .14806 .34009 Mtetra
.57 .696 .926 r
.14806 .34009 .15547 .34808 .16561 .34755 .15837 .33817 Mtetra
.937 .704 .56 r
.15837 .33817 .16561 .34755 .17692 .33688 .18034 .23329 Mtetra
0 0 .185 r
.18034 .23329 .17692 .33688 .18719 .33601 .17985 .32789 Mtetra
.581 .697 .922 r
.17985 .32789 .18719 .33601 .19763 .33402 .19033 .32574 Mtetra
.45 .637 .936 r
.19033 .32574 .19763 .33402 .21013 .31215 .20062 .32587 Mtetra
0 0 0 r
.20062 .32587 .21013 .31215 .21932 .32351 .21212 .31462 Mtetra
.551 .665 .913 r
.21212 .31462 .21932 .32351 .22994 .32112 .22267 .31313 Mtetra
.588 .707 .926 r
.22267 .31313 .22994 .32112 .2405 .32008 .23337 .31076 Mtetra
.961 .655 .4 r
.23337 .31076 .2405 .32008 .25198 .30913 .23499 .41008 Mtetra
0 0 .003 r
.23499 .41008 .25198 .30913 .26262 .30823 .25544 .29995 Mtetra
.594 .703 .92 r
.25544 .29995 .26262 .30823 .27347 .30549 .26629 .29745 Mtetra
.592 .71 .926 r
.26629 .29745 .27347 .30549 .28421 .3048 .27719 .29495 Mtetra
.921 .728 .624 r
.27719 .29495 .28421 .3048 .2958 .29361 .29105 .25435 Mtetra
0 0 .45 r
.29105 .25435 .2958 .29361 .3067 .29211 .29962 .28383 Mtetra
.604 .71 .919 r
.29962 .28383 .3067 .29211 .31777 .28908 .31069 .28105 Mtetra
.612 .721 .923 r
.31069 .28105 .31777 .28908 .32885 .28667 .32183 .27804 Mtetra
.405 .61 .932 r
.32183 .27804 .32885 .28667 .34079 .27093 .33279 .27892 Mtetra
.559 .849 .523 r
.33279 .27892 .34079 .27093 .35157 .27516 .34461 .26625 Mtetra
.581 .686 .913 r
.34461 .26625 .35157 .27516 .36284 .27206 .35586 .26397 Mtetra
.625 .728 .921 r
.35586 .26397 .36284 .27206 .37418 .26866 .36723 .26057 Mtetra
.621 .728 .923 r
.36723 .26057 .37418 .26866 .38554 .26588 .37864 .25726 Mtetra
.485 .653 .934 r
.37864 .25726 .38554 .26588 .39777 .24373 .38998 .25682 Mtetra
0 0 0 r
.38998 .25682 .39777 .24373 .40868 .25409 .40187 .24483 Mtetra
.576 .678 .909 r
.40187 .24483 .40868 .25409 .42022 .25084 .41339 .24264 Mtetra
.632 .732 .92 r
.41339 .24264 .42022 .25084 .43183 .24709 .42502 .239 Mtetra
.64 .739 .921 r
.42502 .239 .43183 .24709 .44349 .24324 .43671 .23513 Mtetra
.639 .739 .921 r
.43671 .23513 .44349 .24324 .4552 .23952 .44846 .23127 Mtetra
.624 .73 .923 r
.44846 .23127 .4552 .23952 .46695 .23688 .46025 .22777 Mtetra
.268 .522 .909 r
.46025 .22777 .46695 .23688 .47892 .22348 .47198 .2309 Mtetra
.657 .882 .523 r
.47198 .2309 .47892 .22348 .49072 .22426 .48408 .21526 Mtetra
.604 .703 .914 r
.48408 .21526 .49072 .22426 .50263 .22057 .49602 .21225 Mtetra
.641 .739 .919 r
.49602 .21225 .50263 .22057 .51461 .21645 .50803 .20824 Mtetra
.65 .746 .92 r
.50803 .20824 .51461 .21645 .52664 .21216 .5201 .20398 Mtetra
.654 .75 .92 r
.5201 .20398 .52664 .21216 .53873 .20778 .53222 .19959 Mtetra
.656 .751 .92 r
.53222 .19959 .53873 .20778 .55087 .20332 .54439 .19512 Mtetra
.658 .753 .92 r
.54439 .19512 .55087 .20332 .56306 .19881 .55662 .19059 Mtetra
.659 .753 .92 r
.55662 .19059 .56306 .19881 .5753 .19427 .5689 .18601 Mtetra
.659 .754 .92 r
.5689 .18601 .5753 .19427 .5876 .18969 .58123 .18141 Mtetra
.58123 .18141 .5876 .18969 .59995 .18511 .59362 .17678 Mtetra
.59362 .17678 .59995 .18511 .61236 .1805 .60606 .17214 Mtetra
.658 .754 .92 r
.60606 .17214 .61236 .1805 .62482 .17589 .61856 .16748 Mtetra
.658 .753 .92 r
.61856 .16748 .62482 .17589 .63734 .17126 .63112 .16281 Mtetra
.63112 .16281 .63734 .17126 .64991 .16661 .64373 .15812 Mtetra
.64373 .15812 .64991 .16661 .66254 .16195 .6564 .15342 Mtetra
.6564 .15342 .66254 .16195 .67522 .15728 .66912 .1487 Mtetra
.66912 .1487 .67522 .15728 .68797 .15258 .6819 .14397 Mtetra
.6819 .14397 .68797 .15258 .70077 .14786 .69474 .13921 Mtetra
.657 .753 .92 r
.69474 .13921 .70077 .14786 .71362 .14313 .70764 .13444 Mtetra
.37 .597 .934 r
.02707 .37543 .03468 .38361 .04684 .36609 .03643 .37653 Mtetra
0 0 0 r
.03643 .37653 .04684 .36609 .05518 .37415 .04766 .36556 Mtetra
.522 .655 .918 r
.04766 .36556 .05518 .37415 .06495 .3731 .05742 .36466 Mtetra
.04 .396 .853 r
.05742 .36466 .06495 .3731 .0763 .36122 .06647 .369 Mtetra
.798 .978 .694 r
.06647 .369 .0763 .36122 .08573 .36319 .07821 .35486 Mtetra
.545 .673 .922 r
.07821 .35486 .08573 .36319 .09565 .36208 .08818 .35349 Mtetra
0 .248 .751 r
.08818 .35349 .09565 .36208 .10699 .35067 .09718 .35971 Mtetra
.812 .967 .652 r
.09718 .35971 .10699 .35067 .11669 .35183 .10922 .34352 Mtetra
.556 .68 .922 r
.10922 .34352 .11669 .35183 .1268 .35037 .11936 .34192 Mtetra
.236 .518 .912 r
.11936 .34192 .1268 .35037 .13839 .33727 .12901 .34461 Mtetra
.739 .961 .674 r
.12901 .34461 .13839 .33727 .14806 .34009 .14066 .3316 Mtetra
.557 .677 .919 r
.14066 .3316 .14806 .34009 .15837 .33817 .15095 .32997 Mtetra
.494 .66 .935 r
.15095 .32997 .15837 .33817 .18034 .23329 .16117 .32938 Mtetra
.429 .166 .411 r
.16117 .32938 .18034 .23329 .17985 .32789 .17259 .3186 Mtetra
.524 .642 .908 r
.17259 .3186 .17985 .32789 .19033 .32574 .18294 .31768 Mtetra
.574 .699 .927 r
.18294 .31768 .19033 .32574 .20062 .32587 .19348 .31561 Mtetra
.867 .723 .701 r
.19348 .31561 .20062 .32587 .21212 .31462 .20611 .2936 Mtetra
.076 .159 .648 r
.20611 .2936 .21212 .31462 .22267 .31313 .21536 .30494 Mtetra
.591 .705 .922 r
.21536 .30494 .22267 .31313 .23337 .31076 .22608 .30248 Mtetra
.522 .675 .933 r
.22608 .30248 .23337 .31076 .23499 .41008 .23673 .30138 Mtetra
.555 .339 .542 r
.23673 .30138 .23499 .41008 .25544 .29995 .24833 .29032 Mtetra
.526 .638 .903 r
.24833 .29032 .25544 .29995 .26629 .29745 .25906 .28935 Mtetra
.604 .715 .923 r
.25906 .28935 .26629 .29745 .27719 .29495 .27001 .28653 Mtetra
.502 .664 .934 r
.27001 .28653 .27719 .29495 .29105 .25435 .28085 .28577 Mtetra
.246 0 .228 r
.28085 .28577 .29105 .25435 .29962 .28383 .29255 .27448 Mtetra
.551 .659 .908 r
.29255 .27448 .29962 .28383 .31069 .28105 .30355 .27291 Mtetra
.615 .721 .922 r
.30355 .27291 .31069 .28105 .32183 .27804 .31472 .2698 Mtetra
.587 .709 .927 r
.31472 .2698 .32183 .27804 .33279 .27892 .32591 .26731 Mtetra
.827 .713 .738 r
.32591 .26731 .33279 .27892 .34461 .26625 .33797 .25145 Mtetra
.33 .419 .802 r
.33797 .25145 .34461 .26625 .35586 .26397 .34884 .25562 Mtetra
.615 .719 .919 r
.34884 .25562 .35586 .26397 .36723 .26057 .36022 .25245 Mtetra
.627 .73 .922 r
.36022 .25245 .36723 .26057 .37864 .25726 .37167 .24896 Mtetra
.6 .716 .926 r
.37167 .24896 .37864 .25726 .38998 .25682 .38314 .24611 Mtetra
.881 .737 .699 r
.38314 .24611 .38998 .25682 .40187 .24483 .3955 .22381 Mtetra
.181 .24 .688 r
.3955 .22381 .40187 .24483 .41339 .24264 .40651 .23413 Mtetra
.619 .72 .918 r
.40651 .23413 .41339 .24264 .42502 .239 .41816 .2308 Mtetra
.638 .737 .92 r
.41816 .2308 .42502 .239 .43671 .23513 .42988 .22696 Mtetra
.64 .74 .921 r
.42988 .22696 .43671 .23513 .44846 .23127 .44165 .22303 Mtetra
.635 .737 .922 r
.44165 .22303 .44846 .23127 .46025 .22777 .45348 .21922 Mtetra
.591 .711 .927 r
.45348 .21922 .46025 .22777 .47198 .2309 .46535 .2165 Mtetra
.784 .672 .741 r
.46535 .2165 .47198 .2309 .48408 .21526 .47744 .20298 Mtetra
.464 .553 .862 r
.47744 .20298 .48408 .21526 .49602 .21225 .48936 .20369 Mtetra
.631 .729 .918 r
.48936 .20369 .49602 .21225 .50803 .20824 .50139 .19991 Mtetra
.647 .744 .92 r
.50139 .19991 .50803 .20824 .5201 .20398 .51349 .1957 Mtetra
.652 .748 .92 r
.51349 .1957 .5201 .20398 .53222 .19959 .52565 .19132 Mtetra
.655 .751 .92 r
.52565 .19132 .53222 .19959 .54439 .19512 .53786 .18684 Mtetra
.657 .752 .92 r
.53786 .18684 .54439 .19512 .55662 .19059 .55012 .1823 Mtetra
.658 .753 .92 r
.55012 .1823 .55662 .19059 .5689 .18601 .56244 .17769 Mtetra
.659 .754 .92 r
.56244 .17769 .5689 .18601 .58123 .18141 .57481 .17305 Mtetra
.57481 .17305 .58123 .18141 .59362 .17678 .58724 .16838 Mtetra
.58724 .16838 .59362 .17678 .60606 .17214 .59972 .1637 Mtetra
.59972 .1637 .60606 .17214 .61856 .16748 .61225 .159 Mtetra
.658 .753 .92 r
.61225 .159 .61856 .16748 .63112 .16281 .62485 .15429 Mtetra
.62485 .15429 .63112 .16281 .64373 .15812 .6375 .14956 Mtetra
.6375 .14956 .64373 .15812 .6564 .15342 .6502 .14482 Mtetra
.6502 .14482 .6564 .15342 .66912 .1487 .66297 .14006 Mtetra
.66297 .14006 .66912 .1487 .6819 .14397 .67579 .13528 Mtetra
.67579 .13528 .6819 .14397 .69474 .13921 .68867 .13049 Mtetra
.657 .753 .92 r
.68867 .13049 .69474 .13921 .70764 .13444 .7016 .12567 Mtetra
.528 .669 .927 r
.01939 .36725 .02707 .37543 .03643 .37653 .02909 .36616 Mtetra
.835 .707 .723 r
.02909 .36616 .03643 .37653 .04766 .36556 .04137 .34852 Mtetra
.091 .216 .702 r
.04137 .34852 .04766 .36556 .05742 .36466 .04977 .35655 Mtetra
.527 .673 .93 r
.04977 .35655 .05742 .36466 .06647 .369 .05962 .35545 Mtetra
.765 .653 .739 r
.05962 .35545 .06647 .369 .07821 .35486 .07108 .34346 Mtetra
.379 .511 .865 r
.07108 .34346 .07821 .35486 .08818 .35349 .08058 .34538 Mtetra
.529 .676 .931 r
.08058 .34538 .08818 .35349 .09718 .35971 .09058 .34421 Mtetra
.745 .626 .728 r
.09058 .34421 .09718 .35971 .10922 .34352 .10202 .3327 Mtetra
.423 .55 .879 r
.10202 .3327 .10922 .34352 .11936 .34192 .11181 .3338 Mtetra
.548 .685 .929 r
.11181 .3338 .11936 .34192 .12901 .34461 .122 .33228 Mtetra
.789 .68 .743 r
.122 .33228 .12901 .34461 .14066 .3316 .1337 .31907 Mtetra
.348 .47 .841 r
.1337 .31907 .14066 .3316 .15095 .32997 .14345 .32184 Mtetra
.57 .696 .926 r
.14345 .32184 .15095 .32997 .16117 .32938 .15385 .31985 Mtetra
.938 .704 .559 r
.15385 .31985 .16117 .32938 .17259 .3186 .17616 .21453 Mtetra
0 0 .178 r
.17616 .21453 .17259 .3186 .18294 .31768 .17553 .3094 Mtetra
.581 .697 .922 r
.17553 .3094 .18294 .31768 .19348 .31561 .18609 .30719 Mtetra
.451 .638 .936 r
.18609 .30719 .19348 .31561 .20611 .2936 .19647 .30725 Mtetra
0 0 0 r
.19647 .30725 .20611 .2936 .21536 .30494 .20808 .2959 Mtetra
.551 .665 .913 r
.20808 .2959 .21536 .30494 .22608 .30248 .21873 .29434 Mtetra
.588 .707 .926 r
.21873 .29434 .22608 .30248 .23673 .30138 .22952 .2919 Mtetra
.962 .654 .396 r
.22952 .2919 .23673 .30138 .24833 .29032 .23102 .39156 Mtetra
0 0 0 r
.23102 .39156 .24833 .29032 .25906 .28935 .2518 .28092 Mtetra
.594 .703 .92 r
.2518 .28092 .25906 .28935 .27001 .28653 .26275 .27834 Mtetra
.592 .71 .926 r
.26275 .27834 .27001 .28653 .28085 .28577 .27375 .27577 Mtetra
.922 .728 .623 r
.27375 .27577 .28085 .28577 .29255 .27448 .28778 .23495 Mtetra
0 0 .446 r
.28778 .23495 .29255 .27448 .30355 .27291 .29638 .26448 Mtetra
.604 .71 .919 r
.29638 .26448 .30355 .27291 .31472 .2698 .30756 .26161 Mtetra
.612 .721 .923 r
.30756 .26161 .31472 .2698 .32591 .26731 .3188 .25852 Mtetra
.406 .61 .932 r
.3188 .25852 .32591 .26731 .33797 .25145 .32986 .25934 Mtetra
.571 .858 .535 r
.32986 .25934 .33797 .25145 .34884 .25562 .34181 .24656 Mtetra
.581 .686 .913 r
.34181 .24656 .34884 .25562 .36022 .25245 .35316 .2442 Mtetra
.625 .728 .921 r
.35316 .2442 .36022 .25245 .37167 .24896 .36464 .24072 Mtetra
.621 .728 .923 r
.36464 .24072 .37167 .24896 .38314 .24611 .37616 .23733 Mtetra
.486 .653 .934 r
.37616 .23733 .38314 .24611 .3955 .22381 .38761 .23681 Mtetra
0 0 0 r
.38761 .23681 .3955 .22381 .40651 .23413 .39962 .22471 Mtetra
.575 .678 .909 r
.39962 .22471 .40651 .23413 .41816 .2308 .41125 .22244 Mtetra
.632 .732 .92 r
.41125 .22244 .41816 .2308 .42988 .22696 .42299 .21871 Mtetra
.64 .739 .921 r
.42299 .21871 .42988 .22696 .44165 .22303 .4348 .21475 Mtetra
.639 .739 .921 r
.4348 .21475 .44165 .22303 .45348 .21922 .44666 .21081 Mtetra
.624 .73 .923 r
.44666 .21081 .45348 .21922 .46535 .2165 .45857 .20722 Mtetra
.27 .522 .909 r
.45857 .20722 .46535 .2165 .47744 .20298 .47042 .21029 Mtetra
.666 .889 .532 r
.47042 .21029 .47744 .20298 .48936 .20369 .48265 .19452 Mtetra
.604 .703 .914 r
.48265 .19452 .48936 .20369 .50139 .19991 .49471 .19142 Mtetra
.641 .739 .92 r
.49471 .19142 .50139 .19991 .51349 .1957 .50684 .18732 Mtetra
.65 .746 .92 r
.50684 .18732 .51349 .1957 .52565 .19132 .51903 .18296 Mtetra
.654 .75 .92 r
.51903 .18296 .52565 .19132 .53786 .18684 .53127 .17849 Mtetra
.656 .751 .92 r
.53127 .17849 .53786 .18684 .55012 .1823 .54357 .17392 Mtetra
.658 .753 .92 r
.54357 .17392 .55012 .1823 .56244 .17769 .55592 .1693 Mtetra
.659 .753 .92 r
.55592 .1693 .56244 .17769 .57481 .17305 .56833 .16463 Mtetra
.659 .754 .92 r
.56833 .16463 .57481 .17305 .58724 .16838 .5808 .15992 Mtetra
.5808 .15992 .58724 .16838 .59972 .1637 .59331 .1552 Mtetra
.59331 .1552 .59972 .1637 .61225 .159 .60589 .15046 Mtetra
.658 .754 .92 r
.60589 .15046 .61225 .159 .62485 .15429 .61852 .1457 Mtetra
.658 .753 .92 r
.61852 .1457 .62485 .15429 .6375 .14956 .63121 .14093 Mtetra
.63121 .14093 .6375 .14956 .6502 .14482 .64395 .13615 Mtetra
.64395 .13615 .6502 .14482 .66297 .14006 .65676 .13135 Mtetra
.65676 .13135 .66297 .14006 .67579 .13528 .66962 .12653 Mtetra
.66962 .12653 .67579 .13528 .68867 .13049 .68254 .12169 Mtetra
.68254 .12169 .68867 .13049 .7016 .12567 .69552 .11683 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`8006Aoo`03D_aBoE;l009Bo008D_eB
o5;lD_aBoE;l001Bo1Moo`03001oogoo04Uoo`00Sgoo0`00I7oo00mBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_d05Woo00<007oo0000BWoo002=Ool3001ROol00e;lD_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo000009Bo1Moo`03001oogoo04Qoo`00RWoo0`000goo00<007ooOol0GGoo
01MBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m01Moo`03001oogoo
04Moo`00Qgoo0`00Hgoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eB
o000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069oo`0PD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoAIoo`03001oogoo04Ioo`00
PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eoo`00P7oo0P00Hgoo02EBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00=BoE;lOol0
5Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1MOol0;5;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EB
oE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00HGoo03ABo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001oogoo049oo`00Lgoo0`00HGoo0U;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00ABoE;lD_aBo1Moo`03001oogoo045oo`00LGoo0P00
HWoo03UBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_`0
5Goo00<007oo0000@Woo001^Ool3001ROol01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;m001Bo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001oogoo041oo`00Jgoo0`00Hgoo03iBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
5goo00<007ooOol0?goo001YOol20003Ool00`00Oomoo`1KOol00e;lD_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m009Bo1Io
o`03001oogoo03moo`00IWoo0`00HGoo04MBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Ioo`03001oogoo
03ioo`00I7oo0P00HWoo0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol0?Goo001Q
Ool3001POol0Ce;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Eoo`03001oogoo
02Eoo`<001Eoo`00=Goo10009Woo0P00Ggoo00I>o5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aoo`0EOol00`00Oomoo`0VOol00`00Oomoo`0COol003Aoo`03001oogoo009o
o`03001oogoo021oo`<005ioo`1GB[a>g4ZlC]e>g5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l01Ioo`03001oogoo02Eoo`03001oogoo01=oo`00>Goo00<007ooOol07Woo
0P000Woo00<007ooOol0Fgoo0U=`00Y:_4[LB[a:_4klD_e>g5;lC_aBo@=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo01Aoo`03001oogoo02Aoo`03001oo`0001Aoo`00;7oo1P001goo00<0
07ooOol06goo0`00HGoo05YCL5N@Dg1>gDZlC]a:_4kMC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`0SOol00`00Ool0000DOol003Eoo`@001aoo`8006=o
o`=CL005Di1CL4kLC]a>g@02C]`00e;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d05Woo00<007ooOol08Goo00D007ooOomoo`0001=oo`00=Goo00<007ooOol06Woo0`00
I7oo05iCL6:gHYHj>cHJ>S/f6U;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoAAoo`8002=oo`05001oogooOol0000COol003Eoo`03001oogoo01Moo`<0065o
o`03C]e>g4kM008R70087OaR]f:GH[Lj6SXk>SXj>`=>g005C]e>g5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol07goo0`0000Aoo`000000019oo`00
=Goo1@004goo0P00HWoo06M:g4kmC]a>oD[L8Q`Mo28LHYIR]f:FH[Lf6SXk=QXj>dkLD_e>g5;mC]aB
oDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0gOol0
04Yoo`<00003Ool007oo05eoo`0AD_e>g4klC_aBoDkLC]e>g4kMC]`R76:GH[MRUV:gHYM:g003B[`0
1D[LC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo1Eoo`03
001oogoo00Qoo`@002]oo`00B7oo0P00Ggoo071>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e>g4kmHYIR
]f:FH[MRUU>@Dfm>g4ZlC]e:_5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoAIoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo02Qoo`00AGoo0`00
GGoo0TkL00I>oDkLC]a>o5;mC]`2C_`01U;mC]a>oDkLC_e:g0=:g@08HYIR]f:GDg1CKe=`B[a:g0=:
_005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Woo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0:7oo0013Ool2000BOol00gJaOomoo`17Ool0
NDJLB[a6W4ZlAYaBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MB[aR]f:FH[MCKe=`DfmC
T4kLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l01Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo02Qoo`00@7oo0`0057oo00=fdGoo
Ool0AGoo00@001Ce0016W096_006B[a>g4kLC]a>oDkL0Tkl00YBoDkLC_a>g4kmC]a>oDkLB]e:g09:
g@09H[MRUV:G>SXj>cXJ>S]>g4kM009>g003D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0EOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`0XOol003ioo`8001Moo`03M[1oogoo04Eoo`1mK]EbmQ3EB[a6W4ZlAYa:_4kLD_e>g5;mC]aBoDkL
D_e>g5;mC]a>oD[LC_e>g28L7O`R76:FH[MRUSXk>QXj>cHJD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`0XOol003]oo`@001Qoo`03M]5oogoo04Aoo`03K]E^mFkE008Dm@0:C]e>
g4kLC]a>gDkLC_a>g5;mC]`2C_`02U;mC]a>o4kLC]e>g4kM7Q`R76:F0V:G00YR]f:F>S/j>SXk>QYB
o4klD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003
D_eBo7oo01Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00>Goo0P0017oo00<0
07ooOol057oo00=fdGJaOol0A7oo084jO7;fK]E^mQ3E5?D@eDkMB]a>gD[LC]e>g5;mC]aBoDkLD_e>
g5;mC]a>oDkLC_e:g4kmHYIR]f:FH[MRUV:gB[a>gDZlC]a:_5;mC]aBoDkLD_e>o5;mC]aBoDklD_e>
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol00goo1000
:goo000fOol3000MOol00gJaM]5oo`0mOol03DkLC]e>g4kMC]`nWCZMK_E^eFkeK]DDmACE008Dm@06
C]e>g4kLC]a>gDkL0Tkl00IBoDkLC_a>o5;mC]`3B]d024[LB]eRUf:gHYIRUe=_Dg03B[`01T[LC]aB
o4klD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d04goo0P0000=oo`00Ool0<Woo000cOol3000POol00gKAM[0d[@0ROol00g;B00ioo`0FOol0;Tkm
C]a>oD[LC_e:g4km>W`nWFkEK_I^eG;fK]DDmA3E5?D@eDkmC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;m
C]a:gDZlB]e6_6:gHYIR]f:FDg1?Ke=`B[a>gDZl0TkL05]BoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0aOol0035oo`80
02=oo`03M[5fdC2<029oo`03M]<03Goo01Aoo`03C]a>gDkL009>g00>C]e>g4kMC]a>gFkEK_E^eFke
K]E^mDJlB[a6W096_006C_e>g4kLC]aBoDkL0Tkl00IBoDkLC_e>g4kmC]`3B]d024[LHYMRUf:gHYHj
>cXj>S/3C]`01TkMC_aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;m000005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol0<7oo000^Ool3000TOol017J`M]5f/CB/8Woo00=b
dgKcOol03goo07A7D4]`A[a:_4JLB[e>g4kmB]a>oDkLB]e:_4kMB]a:gFkEL_I^eFkfK]DDmDJLB[a6
W4ZlC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e:_4[MHYIR]f:FH[Lf6SXk>QXj>dkLD_e>
g4kmC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m0`0001eBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;m01Eoo`03001oogoo02moo`00;7oo10009Goo00AfdGJaM]4dS25oo`04L]=fdg;C00d>Ool0
3dM@Ag17D4M@A[a:_4JlB[a>g4kMC]a>gDkLB]e:g002B]d01VkeK]E^mFkEK_HDe@96_00:B[a6W4Jl
C]aBoDkLC_a>g5;mC]`2C_`01U;mC]a>gDkLC]e>g08N700>8QaRUV:GHYMR]cXJ>S/j>SXkC]aBo4kl
D_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@030000
1U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo1Eoo`03001oogoo02moo`00:Woo0P00:Goo00Af/GKAM[0d[B5oo`04M_=bdWKc00d>Ool0=V[G
9IPY^BFH:KU:g4kMB]a>gDkLC_e>g4kmB]a:gDZlC]e:g6kfK]EbmVkE5?D@eDkMB]a>gD[LC]e>g5;m
C]aBoDkLD_e>g5;mC]aBoD[LC_e>g4km7O`R76:FH[MRUV:gHYI>g4ZlC]e:_09>g00gD_e>g5;mC]aB
oDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d00`0002ABoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`E
Ool00`00Oomoo`0^Ool002Yoo`8002Uoo`04M]5f/GKA<8`QOol017;CM]=bd`0=3Goo00YZefKFI]LU
VBVi9IPYVDkLC]e:g09>g003C]e>g4kM009:g@06B]a:gCZMK_I^eFke0QCe00@DeDkLC]a>g@9>g003
C_aBoDkL009>o00:D_e>g4klC_a>gDkLC]e>g4kMHYH2HYL01F:gHYI?Kdm_B]`00dZl00EBoDkLD_a>
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`200001E;mD_aBo5;lD_d00e;l
00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@02D_`EOol00`00Oomoo`0^Ool0011oo`D000=oo`@000Aoo`@000Ioo`03001oo`0002Moo`07M]5f
/7KAM[4d[7oo=:d07goo00Eflg;CM_<03@0>00Aoo`1cB]a>gD[LC]e:g39m;U`bOFJfJ]MV]RVi9IPY
^BFHC]e:g4kMB]a>gD[LC_e:g4km>YdnWCYlL_I^eFkfK]EbmQCE5?E:g4kMB]a>oDkLD_e>g5;mC]aB
oDkLD_e>g5;mC]a:gDJlB]e:_4[MHYIR]f:FDfm?Ce=_B[a>g4ZlC]e:_5;mC]aBoDkLD_e>g5;mC_aB
oDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`0002YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00
Oomoo`0]Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03
Ool200000goo001oo`0UOol01gJaM]5f/GKA=8aoocB<01ioo`04M]=bdgKCL]<200d2B]`04T[MB[a:
g4[LC]e:g4kM<UdbOFKFI]MVeV[GI]HYVBFI:KTUV09>g00>C]e>g4kLC]a>gDkLC]djWCjMK]E^mFkE
K_I^e@<Dm@=>g00>C_e>g4klC_aBoDkLC_a>g4kmC]a>oDkLB]e:g09:g@05H[MRUV:GCfmCK`02Cfl0
0dkLC]e>g002C]`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l0`000e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`00e;mD_aoo`0EOol00`00Oomoo`0/Ool0019oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0SOol01gKAM[5fdGJ`=:eo
ocB]01ioo`0YL]=flg;BM_=bd`0>00e>gDZlC]e:_4kMB]a>gD[LC]eV]V[GI[IZefJfJ]M6W4ZmA[a:
_4JLC_e>g4kmB]a>oD[LC_e:g4kmK]E^mVkEL_I^e@020000C4ZlAYa:_4kLD_e>g4kmC]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4[MA[a:gDZlH[MRUV:g>QXj>cHJ>S]>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_eB
o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l0`00035Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00EOol00`00
Oomoo`0/Ool000Moo`H000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0ROol01gJaM]5f/@05<8aoocB<01ioo`05M]=bdgKC
L]=fd`0300d2B]`00d[MB[a:g@02B]d01TZlB]eVeV[GI]IVe`97D004A[a:_4JlB[`3C]`00dkMC]a:
g@02B]d01T[LB]e^eFkfK]E^m@8Dm@09AYa6_4JlB[a6W4klC]aBoDkL009>o00BD_e>g4klC]a>gDkL
C]e>g28L7O`N76:GH[MRUSXk>SXj>cXJ0TkL00E>gDkLC]aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_`000020003
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0DOol00`00Oomoo`0[
Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`0QOol01gKAM[1fd@04=:``S3B]01eoo`1bM_=bdWKcL]=flg;B00h03@0>
00e>gD[LC]e:g4[MA[a:gDJlJ]MV]V[GI[HY^DM?B[a6W4ZmA[a:_4kLC_e>g4kmC]a>gD[LB]e:_7;f
K]E^mVkE5?DDeACeB]a>gD[LC]e:g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4km7O`R76:FH[MRUV:g
HYHj>cXJ>S/f6U;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l0`0003UBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007oo0000;7oo000BOol00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo0P001Woo0P0087oo00QfdGJaM]5f
/@05=8`d[3B<7Goo00MbdgKCL]=fdg;CM]=2W003AY`01D:LC]e>g4kMB]`00d[M00U:_6KG<UeZefKF
:ITUVDkMB]`00TkL00I>gDkLC]e>g4kMC]`3B]d014[LK_E^eFkf11Ce0dkL00I>gDkLC_a>g5;mC]`2
C_`02U;mC]a>o4kLC]e>g4kMHYMR]f:F0V:G00YR]dZlB[a:_4[LB[aBo4klD_e>g09Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l0`000e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
01Eoo`03001oogoo02Yoo`0047oo0`0017oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo01eoo`09M[1fdGJaM]4013B]=8`d[CB<01Qoo`1`B]e:_4[M
A[a:gG;CM_=bdWKcL]=fld:LAYa2W4JLB]a>gD[LC]e:g4[MA[a:gBiLJ]MV]V[G9IPY^BFHC]e:g4kM
B]a>gD[LC_e:g4kmB]`nWCZMK_I^eFkfK]DDmA3E5?DDeDkMB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;m
C]aBoDZlB]e6_6:gHYIR]f:FH[M?CTm_B[a>gDZlC]a:_5;mC]aBoDkLD_e>o5;mC]aBoDklD_e>o5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_`30000@5;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<007oo
Ool0:Goo000BOol00`00Oomoo`03Ool40004Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`0LOol0
2GKAM[5fdGJa00D`S3B/=8`d[@0EOol2B[`00d[MB[a:g@02B]d014ZlM]=bdgKC0g;C00=6W4:LAY`0
0TJL011:g4kMB]a>gD[L<WdbGF[GI]IVefKFJ]LUV2VI9ITY^@=>g00<C]e>g4kMC]a>gCZM?Ye^eFkf
K]E^mFkE11Ce00I>oDkLC]a>g4kmC]`2C_`01e;mC]a>oDkLC_e>g4km009:g@08B]aRUf:GH[M?Cdm_
Cdm:g09:_003C]a>gDkL009Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eBo000008000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Woo00<007ooOol0:7oo000XOol00`00
Oomoo`0:Ool00`00Oomoo`0KOol02GJaM]5f/7KA00@d[32<=:ddS00EOol0KP00B]e:_4[MB[a:gDZl
B]e6_7KcL]=flg;BM_<03DkMB[a>gDZlC]e:g4kMB]a>gBiL<WeV]V[GI[IZefJfB[a6W4ZmA[a:_4[L
C_e>g4kmB]a>oD[LC_e^eFkfK]E^mVkEK_I6W4ZlAYa:_4JLC_e>g5;mC]a>oDkLD_e>g5;mC]aBoDkL
D_e>g4[MB[a:gF:FH[MRUV:gGYHj>cXJC_e>g5;mC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDad20000Ae;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<0
07ooOol0:7oo000XOol3000;Ool00`00Oomoo`0IOol02WJaM]5f/GKAM[401CB<=:`dS3B]5Goo0P00
0TZl00=:gDZl?Yd00SjM0g;C00Ifdg;C00d03D[MB[`2B]`02T[MB]a>gD[LC]eVeVKGI]IZefKF0T=?
00E:_4JlB[a6_4kM00=>g003C]e:g4[M009:g@0AK]E^mFkEK_I^eACeA[a:_4JLA[a>g4kmC]a>o4kL
D_e>g002C_`01U;mC]a>oDkLC_e>g0=:g@08HYIRUf:GH[Lj6SXk>SY>g@=>g005C]eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo0<0009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;m
D_aBo5;l5Goo00<007ooOol09goo000XOol00`00Oomoo`0<Ool00`00Oomoo`0HOol02WKAM[1fdGJa
M]4013B]=8`d[CB<57oo06U2W3il@Y`nNdkMB]a>gDZl?[ebdgKcL]9flg;CM_<03@0>00d03T[LC]e:
g4kMA[a:gDJlB]eV]V[GI[I7D4<_Ae16_4ZlAYa:_DJlC_e>g4kmC]a>oDZlC]e:g4[MK]E^mVkEK_HD
eACeAYa:_4JLB[a>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e>g4kmB]`R71gl8QaNUV:gHYIR]cHJ>S/j
6SXkC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_d00`0004iC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0VOol002Qoo`03001oogoo00eo
o`03001oogoo01Moo`0:M[5fdGJaM]5f/@05<8`d[3B<=:d:Ool014ZmB]e:_7Z<1Goo00YjS4E@@Wa2
O4:LB]a:gD[LB]e:g09bd`06M]=bdg;CL]=6W4:L0dJL00E:g4kMC]a>gDZl009:g@0:J]MVeT=?I]IZ
ebFH:IU>g4kMB]`2C]`01TkMC]a>gDkLB]e:g09:g@04K_I^eFkEK]D35?D00dkLC]e>g002C]`01U;m
C]a>o4kLD_e>g09>o00:D_e>g4kMC]a>gAgl7QaRUf:gHYH2HYL02D[LB[a:_4ZlB]a>g5;lC_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`00`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`015;mD_aBo5;l57oo00<007ooOol09Woo000XOol2000?Ool00`00Oomoo`0FOol02gKAM[5f
dGJ`M]4013B/<8`d[CB<=:d017oo00X004Jm@Ya6_4:LA[e6_4[MMV]jS09oo`1VMV]jS7J;AE4nNd:L
?Wa2W4JlB]e:_4[MA[aflg;CM_=bdWKcL]=6W4:LAYa2W4kMB]a>gD[LC]e6_4[MA[`bOFJfJ]MV]RVi
9IPY^D[LC]e:g4kMC]a>oDkLC_e>g4[MB[a>gD[LK_I^eFkf5=DDmACE5?E:g4kMB]a>gDkLD_e>g5;m
C]aBoDkLD_e>g5;mB]a>oDkLC_eNUV:gHYIR]ejFCfm;CTkLB[a>gDZlD_e>g5;mC]aBoDkLD_e>o5;m
C_aBoE;lD_e>o5;m0`0005IBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l57oo00<007ooOol09Goo000XOol00`00Oomoo`0?Ool00`00Oomoo`0DOol027KAM[5f
dGJaM]5f/@05=8`2=:`2=:d3Ool00`00K]IZe@03AY`01D:LB]e:_GZ<NX/00gZ<00AjR`00AE15D0=:
_003B]e:_4[M009:g@=bd`03M]=bdg;C0096W008@Ya6W4JLC]e:g4kMB]a>g@<bG@0:J]MVeVKGI]HY
^BFH:IU>g4kMB]`2C]`01TkMC]a>gDkL?YdjW@9^e@03K_I^eFkE00@Dm@07C]a>oDkLC]a>o5;mC]`0
0Tkl00I>oDkLC_e>g4kmB]`3B]d016:FHYMRUdm?0Tm>00=:_4[LB[`00TZl00EBoDklD_aBo5;m00=B
o003D_eBo5;l00<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m009Bo1Eoo`03001oogoo02Aoo`00:7oo00<007ooOol047oo00<007ooOol04goo00af
/GKAM[1fdGJaM]4013B]=8`d[CB<>:d2Ool0KSIlK_IZeFkF19=6_D:LA[a2W4:mMX]jS7I[NXafRgZ<
0015DD4`001:_4[MB[a:gDJlB]e:_4[ML]9flg;CM_=bdP0>B[a>gDZlC]e:_4kMB]a>gD[L<Wd^G6[G
I[IZefJfJ]LUV2Vi9IPY^DkLC_e:g4kmB]a>oD[LC_e:g6kfK]E^mVkEK_I^eDZlAYa:_4JLB[a>g4km
C]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gDZlH[MNUV:gHYHj>cHJ>S]>g4kmC]aBoDkLD_e>g5;m
C]aBoDkLD_d30000GE;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBo@0COol2000VOol002Moo`03001oogoo019oo`03001oogoo019oo`08
M]5f/GKAM[5fdGJa00D`S08d[006=:dd[7oo=WdjWF[E0VkE00H8U0BCB]e:_4[MB[`3NX`00gZ;NXaj
S003AE000`00B]e:_002B[`01D[MB[a:gD[MM]<00g;C00Ifd`0=00i:g4[MB[`2B]`02DkMB]a>gD[L
J]MVeVKGI]IZe`02@bl01TJlB[a6_4ZlC]a>g@9>g09:g@04B]a:gD[MK_H3K]D01Vkf5?E6_4JlB[a6
W09>g006C_e>g4kLC_aBoDkL0Tkl00I>oDkLC_e>g4[MB]`2B]d02F:gHYIRUcXj>S/j6SXkC]a>g@03
C]`00e;mD_aBo0030002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l57oo00<007ooOol08goo000WOol3000COol00`00
Oomoo`0AOol087J`M]5f/GKAM[1fd@04B]e6_4[MA[`jWCIl>YeZeFkFJ]E^mPBC29@4Td[MB[a:gGI[
NXafRgZ<MV]jS44`AE430000DdkMB[a>gD[LC]dnW7KcL]=flg;BM_=bd`0>00d03TZlC]e:_4kMA[a:
gDJlB]e6_6[GI[IZed<_@dm3;TZmA[a:_4JLB[e>g4kmC]a>oD[LB]e:_4kMK]E^mVkEK_I^eACeAYa:
_4JLB[a6W5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmC]`R71gl8QaRUV:gGYIR]cXJ>S/f6SXkC]aB
oDkLD_d00`0006ABoDkLD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo029oo`009goo00<007ooOol0
57oo00<007ooOol03goo00Mf/GKAM[5fdGJaM]5f/@0200D01TZmA[a:_DJl>YdfO@9^e@0:K]IZeFkE
19@8U0BCB]e:_GZ<NX/3NX`017Z;AE15D4EA0d9l00E:gD[LB]e:g4[M00=bd`0;M]=bdg;C00d03P0=
00i>g4kMB]a>g@02B]d02DZlB]eVeV[GI]IVebVI:KTUV002C]`01dkMB]a>g4kLC]e>g4kM009:g@04
B]a:gFkEK_H2K]D25?D3C]`01TkMC]a>o4kLD_e>g09>o00:D_e>g4klC_a>gDkLC]dMo1hLHYH2HYL0
1F:gHYI:_4ZlB]`00TZl00=>o00000000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`DOol00`00
Oomoo`0ROol001Eoo`@000Aoo`@000Ioo`03001oogoo01Eoo`03001oogoo00ioo`1EM]5f/GKAM[1f
dGJaM]401005A[a:gDJlB]e6_6kFJ]E^mV[EK]IZeDJm@Ya6_4:LB]efRgZ<MV]jS7J;NXa1<4EA@E12
W3ik@Y`nO4:LA[a:gDZlB]ebdWKcL]=flg;CM_=2W4JL@Ya6W4[LC]e:g4kMB]a:gDJlB]eV]V[GI[IZ
ebFH:KTUV4kMB]a>gD[LC_e>g4kmC]a>oD[LB]e:_6kfK]E^mVkE6?D00QCe01]:g4kMB]a>gD[LD_e>
g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_eRUV:gGYIR]f:FCdi;CTkMB[`00`0006Y>g5;mC]aBoDklD_e>
g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo025oo`0057oo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo00=oo`03001oogoo01Ioo`8000ioo`0:M[5fdGJaM]5f/GKAM[401@0400D2A[d0
1DJlA[e6_FkFJ]D00VkE00=^ePBDAY`00TJL00M:_7Z<NXajS7Z;NX`00004AE001T[MB[a:_4ZlB]e:
_09:g@06M]=bdg;CL]=fdg;C0dJL00Q2W4JLB]a>gD[LC]e:g39m0S9M00MVeV[GI[HY^BVI:KU:g002
C]`02DkMB]a>gDkLC]e>g4kM>YdnW@03K]D00fkfK]DDm@025?D3C]`01TkmC]a>o4klD_e>g09>o00:
D_e>g4kmC]a:gD[LB]eRUf:gHYH2Bdh300000dZlB]a:_002D_`01E;mC_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoGooOol04goo00<007ooOol087oo000IOol01000Oomoo`0017oo00<007ooOol00goo
0P006Goo00<007ooOol017oo07=RUVJg:MXYfTJlB]e6_4KMM[1fdGJaM]5f/7KAM[52W3il@Ya6_4[M
A[a:gF[EK]IZeFkfJ]D8U4:LA[e2W4JlMV]jS7J;NXafJdEA@C15DD4`AE4004[MB[a:gDZlB]e6_4[M
B[aflg;CM_=bdgKC00e>gDZlC]e:_4kMB]a>gD[LC]dbG39mI[IZefJfJ]MV]RVi9IPY^D[LC_e>g4km
B]a>oD[LC_e:g4kmK]E^mVkEK_I^eFkfAYa:_4JLB[a>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;m
B[a:gDJlH[MRUP030000LT]>Cdi>g5;mC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoAAoo`03001oogoo021oo`0037oo1P001goo00@007ooOol000Aoo`03001oogoo009oo`03001o
ogoo01Yoo`03001oogoo009oo`=R]`<YfP0>A[a6_DJmA[ef/GKAM[5fdGJaM]52O4:L@Wa2W096_@0=
A[a6_CImK]IZeFkE19@8U4ZlB]e:_7Z<NX/00gZ<0dE@00E5DDE@001:_4[M00=:_005B]e:_4[ML]=f
d`03L]<05@0>00e:g4[LB]e:_4kMB]a>gD[LC]eVeV[GI[IVefKFJ]M6_4ZlA[a:_003C]`00dkMC]a:
g@02B]d014[LB]e^eFkf0VkE00<Dm@00AY`00TJl00I:_4kLC]a>g4kmC]`2C_`025;mC]a>oDkLC_e>
g4kmB]d300001T]>H[MRUSXk>SXj>`=>g005C]e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aB
o5;l5Goo00<007ooOol07goo000EOol40003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0KOol02@00OomoogooI[MRUV:gHYH]fP02:MX08dJlB]e6_7KAM[1fdGJaM]5b/005A[a:gDJlB]df
OCZM=Wa^mV[EK]IZe@Rd19<8U4JlB]efRgZ<MV]jS7J;AE51<4EA@E000`00045:g4kMB[a>gD[L?Ydn
W7KcL]=fdg;CM_<03@0>00e>gDZlC]e:_4[MA[a:gDJlB]eV]V[GI[IZecl^@bm6W4ZmA[a:_4JLC_e>
g4kmC]a>gD[LB]e:_6kfK]E^mV[E6?HDmDZlAYa:_4JLB[a>g5;mC]aBoDkLD_e>g5;mC]a>oDkL00<0
001i7O`N71glH[MRUV:g=QXj>cXJ>S]>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`057oo00<007ooOol07goo000EOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool2000MOol00`00OomR]`04H[L4:MX024JlA[e6_GKAM[5fdGJaM]4200D01dJlB[e6_4Zm=WdjWF[E
009^e@06K]IZe@RD19@8U4Zl0gZ<00=jRgZ<AE0014E@00U2W49l@Wa:g4[MB]a:gCjMM]<00g;C00=f
dg;C00h00P0>00D03DkMC]a>gD[L00=:g@09B[aVefKFJ]MV]RVi:ITY^D[L009>g006C]e:g4kMC]a>
gD[L0d[M00A:g6kEK]E^mP<Dm@0:C]e>g4kLC]a>gDkLC_a>g5;mC]`2C_`300001dkLC]e>g1hL7OaR
]f:F009RU`09H[M:_4ZlB[a:g4kLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eB
o5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aB
o1Aoo`03001oogoo01ioo`005Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol07Goo06YV]f:FH[MRUVJgFkAOeD:LA[e2W4Jm>YafdGJaM]5b/7KAM[401@04B]e6_4[MA[a:
gF[EK]IZeFkfJ]E^eT:LA[e2W4JlMV]jS7J;NX`004EA@C15DD4`AE4nO4:L?W]2W3ilC]e:_4kML]=f
dg;CM_=bdgKCL]=6W4:LAYa2W4kMB]a>gD[LC]e6_4[MA[aZefJfJ]MV]RVi9IPY^D[LC]e:g4kMC]a>
oDkLC_e:_4kMB]a:gF[EK_I^eASe5=DHmQCeC]e:g4kMB]a>gDkLD_e>g0<00021C]aBoD[LC_e>g4km
B]aR]f:FH[MNUV:gBbe;CTZlC]e:_5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l01Aoo`03001oogoo01eoo`005Goo1@000goo10001Goo00<007ooOol05Goo0Uif00Lb6cHk
<Q/f>d:mA[e2_003H[L01E_DGmEOe5oEAY`00TJl00LnWGJaM]5f/GKAM[5fd@0300D3A[d01DJlA[e^
eFkFJ]D00VkE00H8U4:LAYa6W7Z<NX/2NX`02@00AE15D4E@AE55D4EAB[a:g@03B[`01D[MB[a:gG;C
M]<017;C01E2W4JLAYa6W4:LC]e:g4kMB]a>gC9M<WdbGFKGI]IVebVH:KTYVDkMB]`00TkL00E>gDkL
C]e>g4kM008jW@03K]E^mVkE009^e@@Dm@04C_e>g4kLC]`300000dklD_e>g002C_`00e;mB]a:g@02
B]d014[LHYMRUf:g0d]>00I:g4ZlB[a:_5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoE;lD_`04goo0P007goo000VOol00`00Oomoo`0DOol045YfGWMJMUig<Q/f>c8KA[e2_4JmHYIV
]f:FH[MRURgJ0RWJ05a2W4Jm@YafdG:`M]5f/GKAL[1fdCil@Y`nO4[MA[a:gDJlK_IZeFkFJ]E^ePBC
A[a2W4JmMX]jS7I[NXa1<4EA@C15DD5@AE51D000B[a:gDZlB]e:_4[MA[aflg;CM]=bdgKcL]<03TZl
C]e:_4kMB[a>gD[LC]e:g39m;UaZefJfJ]MV]V[G9IPY^BFHC_e:g4kmC]a>oD[LC_e:g4kmB]a^mVkE
K_IZeFkfAYa:_4JLB[a6W4km0P0008Q>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]e:_4[MGYIR]f:FBdi;
;D]>Bbe>oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03
001oogoo01aoo`009Goo00<007oo000057oo1Uif00Pb6cHk<Q]6_D:mA[eR]ahL0V:g00ERUbWJ:MXY
fTJl0096_@0;M]5f/GKAM[5fdGJa@Ya2O4:L@Wa2W002A[d01DJl=We^eFkFJ]D00PRD00=:gDZlB]d0
0WZ<00UjRdE@AE15DDE@AE55D4EA00000TZl00=:gDZlB[`00T[M00=:_7;CL]<00g;C0P0>01A:_4[L
B]a:gD[LC]e:g4kMB]aVefKFI]MV]VKGI]I:_4JlB[a6_4kM0dkL00=>gD[LB]d00T[M00Q:g6kEK]E^
mVkE5?E6_4Zl0`0000I>oDkLC]a>g5;mC]`2C_`01TkmC]a>oDkLC_e:g0=:g@08HYIRUf:G>S/j6SXk
>SY>g@=>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Aoo`03001o
ogoo00Moo`D000moo`009Goo0P003Goo041RUeif<Q/]nT:m?Ya2_D:LGWMJMUigFWINMf>cImA2W4Jm
@Y`N7AWl7QaRUVJgHYIR]bWI;MXYfTKMA[a:gGJaM]5b/7KAM[5fd@05B]e6_4[MA[a:gCIm>YeZeFkF
J]E^ePBC2;@4Td[MA[ajS7J;NXa1<4EA@E15DD5@AE55D080000LC]e:g4kMB[a>gCjMM]=bdgKcL]=f
dg;C00h03@0>B[a>gDZlC]e6_4[MA[a:gDJlJ]MV]V[GI[H200004DZlAYa:_DJlC_e>g4kmC]a>oDZl
C]e:g4[MJ]E^mVkEK_H00`0008i:_4JLB[a>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e>g4km7O`N71gl
H[MNUV:g>QXj>cXJ>S/j6U;mC]aBoDkLD_e>g5;mC]aBoDklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo1Aoo`03001oogoo00Moo`05001oogooOol0000?Ool002Eoo`03001oogoo00aoo`03GYMRUejF
008]n`04@[e2WD:m@[d4GWH2Im@024JmA[a6_DJl7Q`Io6:gHYL3H[L3:MX01DJmA[a6_GJaM]400gJa
0P0500A:_DJlB[e6_08fO@06K]IZeFkEK]E^ePBD0`RD00=jRgZ<NX`014E@00]5DDE@AE52O4:L@Wa:
gD[LB]e:g4[M00Ibd`@03P05B]a>gDkLC]e:_003B]d02FJfI]MVeVKG:IPY^BVIC]e:g002C]`01TkM
C]a>gDkLB]e:g0=:g@<000056?DDmACeC]a>g@03C]`01U;mC]a>o4kLD_e>g09>o006D_e>g4kMC]`N
71gl0f:G00ARUV:GB[a:g0=:_005D_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00=BoE;lOol04goo00<007ooOol01goo00<007ooOol047oo000UOol00`00Oomoo`03Ool00fJf
2=Ioo`05Ool09UifHYMNUV:G;OXb6bgj@[dnW4:mFWINMeYfImAWdfODHk=6_D:LA[e2W6JgHYIR]f:F
I[MK]5oE@Ya6_D:L?Yeb/7KAM[5fdG:`M]4300D0@d[MA[a:gDJlK]IZeFkFJ]E^eV[EA[a2W4Jm@Yaj
S7I[0011<4EA@C15DDE@AE51D4:L?Wa2W3ik@Ya:_4[MA[a:gG;CM]=bdgKcL]=fdd:LAYa2W4JLB]a>
gD[LC]e6_4[MA[a:gFJfJ]MV]V[G9IPY^BFHC]e:g4kMB]a>oDkLC_e>g4[M00<0002FK_IZeFkf5?DH
mACe6?I:g4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>oDkLH[MNUV:gHYIR]dL]Bdi:_4kLB[a>
gDkLD_e>g5;mC_aBoDkLD_e>o5;mC_aBoE;lD_e>o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007oo
Ool01goo00<007ooOol03goo000UOol20003Ool00fZfJ]IV]P05Ool00ejGHYMNUP02GYL01V:G;OX]
nbgk@[e2W@9NMP0:ImANMUif<Q/f>c8KA[e2_DJm@[`3H[L01E^dFmAK]4JmAY`00TJl00IfdGJaM[5f
/GKAM[4400D3A[d02TJlK]E^eFkFJ]E^e@RDAYa2W4JL0WZ<0dE@00I5DDE@AE55D4EAAE02B[`00d[M
B[a:_002B]d00dZlB]ebd`04L]<00dJL@Ya6W002AY`014[LC]e:g4kM0c9M00YVefJfI]MVeRVi:IPY
^DkLC]e:g09>g006C]d00000000nWCZM0VkE00E^mVkEK]DDmASe008Dm@07C]a>oDkLC]a>o5;mC]`0
0Tkl00I>oDkLC_e>g4kmB]`2B]d01V:GHYIRUd/]Bdi;;@9:_006B]a:_4ZlD_aBoDkl0U;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0DOol00`00Oomoo`08Ool00`00Oomoo`0>
Ool002Eoo`03001oogoo009oo`1_J]MV]V[F1;E2_CjL@[dnW6:GGYIRUeifHYMSeFOe@Ya6_D:L@[dn
W5igFWINMeYf=S`b6cHk<Q]6_D:lA[eRUVJgHYIR]f:F;MXYfTKMA[a:gDJlM]5b/7KAM[5fdG:a@Y`n
O4:L?Wa:gDJlB]e6_6kFJ]E^eV[E2;@4U4Jl@YajS7J;AE51<4EA@E15DD5@AE55D4EA001:gDZlB]e:
_4[MB[a:gDJlM_=bdgKCL]=fm00>C]e:_4kMB[a>gD[LC]e:g4kM;U`bOFJfJ]MV]V[GI[HY^BFH:KU>
g4km00<0002MC_e:g4kmB]a^mV[EK_I^eFkfJ]E:_4JLB[a6W4ZlC]a>oDkLD_e>g5;mC]aBoDkLD_e>
g5;mC]a:gDJlB]eRUV:gGYIR]cXJ>S/j6U;mC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d057oo00<007ooOol027oo00<007ooOol03Goo000UOol03P00
OomoogooJ]IV]V[FJ[H8ePSE@[e2WD:m@Yd2GYL026:GHmEWeF?EA[e2W4:m@Y`6GWH023Hk<Q/f>c8K
A[e2_DJmHYL3H[L3:MX01DJmA[a6_DJmM]400gJa00IfdGJa@Ya2O4:L@W`3A[d01DJl=We^eFkFJ]D0
0PRD00=:gGZ;NX`01DE@00A5DDE@AE55D080009:_003B]e:_4[M009:g@03B[abdg;C009bd`803P0>
B]e:_4[LB]a>gD[LC]e:g4kMI[IVefKFI]MV]P800005B[`00000001>g@03C]`01D[MB]a:gD[MK_H0
0fkE00I^mQCeA[a6_4ZlAY`2C]`03dkmC]a>o4klD_e>g4klC]a>oDkLC_e>g4[MB]a:g@02HYL01F:F
>S/j>SXk>QX00TkL00E>gDkLC]aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;m
D_aBo5;l5Goo00<007ooOol00goo00D007ooOomoo`0000moo`0097oo054007ooOomoof[GI[IZeVJf
J]MV]PSF1;D8eSjL@[eNMV:GGYIRUeif<Q/]nT:m?Ya2_D:LGWMJMUigFWIWe6>cA[e2W4Jm@Y`N7AWl
H[MRUVJgHYIR]bWI;MY6_4KMA[a:gDJlM]5b/GKAM[5fd@05B]e6_4[MA[`jWCIm>YeZeFkFJ]E^ePBC
2;@4U7Z<MV]5DD4`AE51<4EAAE15DD5@AG400`0000a>gD[LC]e:_3jmL]=fdg;CM_AbdgKC00d300h0
2dZlC]e:_4[MA[a:gDJlB]eV]V[GI[H010000:A:_4JLB[e>g4kmC]a>oDkLB]e:_4kMK]E^mV[EK_I^
eASeAYa:_4JLB[a6W5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmC]`N71glH[MRUV:gGYHj>cXJ>S/j
6U;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo
00<007ooOol017oo0`0047oo000TOol300004V[FI[IZeVZfJ]IV]V[F@Ya2WCjL@Ya2WD:mGYINUejF
HYL]nP8]n`03@[e2WD:m00ANMP9We005Im=6_DJlA[e6_003H[L00f:GH[MR]`03:MX3?Yd2M[4017KA
M[5f/GJa0P0500A:_DJlB[e6_08fO@05K]IZeFkEK]D8]00229@00gZ<0015D002AE001TEAAE15DDE@
AE55D092O006@Ya2O4[MB]a:gD[L1W;C00=6W4:LAY`00TJL00E:g4kMC]a:gDZl009:g@0:I]MV]P00
000Y^BVH:KU>g4kMB]`2C]`00dkMC]a>g@02B]d014[LB]e^eFkf0VkE00<DmASeC]`00TkL00I>gDkL
C_a>g5;mC]`2C_`02U;mC]a>o4kLC]e>g4kM7O`N76:F0f:G0dZl00I:g4ZlD_a>o5;mC]`2D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo15oo`800003Ool007oo
01Moo`0097oo06X003jL@[e2W6[FI[IZefJfJ]H8e@00?Ya2WCil1I/5NV:GGWIRUejFHYL]nS8K;OX^
6cjL@[eJMUigHk=NMeYf=S/b6dJm@[a6_D:LI[MRUV:gHYIOe5^dA[e2W4Jm>YdnWG:aM]5f/GKAL[5f
d@0500I6_4[MA[a:gDJlK]IZeFkFJ]E^eT:LA[a2W7Z<@C15DD4`AE51D4EA@E15LDE@AG4nNd:L?Wa2
W3ikB]e:_4[MA[afm7;CM]=bdgKdL]=6W4:LAYa2W4kMB]a>gD[LB]e6_0<0000cI[IZebVH:KTUV2Vi
B]a>gD[LC_e>g4kmC]a>oD[LB]e:_6kfK]E^mV[E6AHDmASeB]a>gD[LC]e:g5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e:g4kmHYIR]ejFH[M7;D/]B[a>gDZl009>g01fD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`0EOol001Yoo`@000Ioo`03
001ood:L0092W@05J]IV]V[FJ[IZeP022=D03d:L@YdnW5jGGYIRUejFGYMNUTJm@Ya2_D:LA[e2W@05
GWH01c8k=S/b6dJm@[e6_F:G009R]`06FmAK]5^dFkA6_DJL0TJl00IfdGJaM[5f/GKAM[4300D01DJl
A[e6_DJmA[`00VkE00=^eV[EK]D00TJL00AjRdE@AE15D@=5D003AE55D4EA0095D@=:_003B]e:_4[M
009:g@03B[abdg;C00=bd`96W005@Ya6W4JLC]e:g0030002<Ud01fJfI]MV]VKG:ITY^BVH009>g009
C]e:g4kMC]a>gDkLC]djWCjM00=^e@05K_I^eACe5?DHm@03C]`02dkmC]a>o4klD_e>g4klC]a>oDkL
C_d00T[M00E:g4[MHYMRUf:F0097;@06B]a:_4ZlB[a:g4kl0U;l00EBoDklD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4goo00<007ooOol05Goo000IOol00`00Oomo
o`02Ool00`00Oomoo`03Ool0I000OomoocjL@[e2W2iMI[IZefJf2=H8e@SF?Ya2_CjLHYMNUV:GGWIW
mF?EA[e2W4Jm@Y`0m`3FGWMJMUigFWINMc8K=S/b6dJm@[a6_F:FGmARUV:g:MT]fRWJA]e6_4[MA[af
dG:aM]5f/GKAL[52W3il@Ya6_4[MA[a:gF[EK]IZeFkFJ]D8]0RDNXa1<4EA@E15DD5@AE55D4EA@E15
LDE@001:_4[MB[a:gDJlB]e:_4[MA[afm7;CM]=bd`0>B[a>gDZl0`000;=:g4kMB]`bOBiLJ]MV]V[G
I[HY^BVH:KTUV4kmC]a>oD[LC_e:g4kmB]a>oFkEK_IZeFkfK]E^mTJLB[a6W4ZlC]aBoDkLC_e>g5;m
C]aBoDkLD_e>g5;mC]a:gDZlB]e6_6:gHYIR]ejF>S/j6TkmC]aBoDkLC_e>g5;mC]aBoDkLD_eBo5;m
C]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03001oogoo01Aoo`00
6Goo00<007ooOol00Woo00<007ooOol00goo0P000Woo0RiM00IZ]V[FI[IZeVZf2=H22=D01T:M@[e2
WEjGGYIRU`=Se@04ImE2W4:m@Y`6GWH024JmA[a6_DJl6Q`Io1hL6O`3H[L3:MX01DJmA[a6_GJaM]40
0gJa00IfdD9l@Ya2O4:LA[`3A[d013ImK]E^eFkF0PRD00=jS4E@AE000TE@00M5DDE@AE55D4EAAE15
D@030002B[`014[M?YdnWCjM1G;C00D03P00000004Zl009:g008C]e:g4kMB]aVefJfI]MV]P800004
B[a6_4ZlA[`2C]`00dkMC]a:g@02B]d014[LB]e^eFkf0VkE00<DmASeAY`00TJl00I:_4kLC_a>g5;m
C]`2C_`01U;mC]a>oDkLC_e>g0=:g@08B]aRUf:GHYLj6SXk>SY>g@=>g005C]eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00DOol00`00Oomoo`0COol0
01Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`1II[IZefJfJ]IV]V[G2=D8ePSE
2=HnW4:mGWIRUf?EHYMNMS8K;OX^6cjL@[eJMUigFWINMeYfImAS/dJm@Ya6_D:L7QdIo6:gHYIV]f:F
;MXYfBgJ:MY6gDJlB]eb/GKAL[5fdG:a00I6_4[MA[a:gCIl>YdfOFkFJ]E^eV[EK]H4TgZ<@C15DD4`
AE55D4EA@E15LDE@AG4nNd:L?Wa2W3ikC]e:g4kM>Yafm7;CM]=bd`03000300h0]dkMB]a>gD[LB]e6
_4[MA[aZefJfJ]LYV000AYa:_DJlB[a6W4kmC]a>oDkLC]e:g4[MB[a^mVkEK_IZeATF5?DHmD[LC]e:
g4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e>g4kmB]`N71glH[MNUV:gHYIR]cXJ>S/j6U;mC]aBoDkLD_e>
g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol0
0`00Oomoo`0COol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`0AI[IZeVZf
J]Ioo`SF@Ya2WCjL@Y`5NPFJ1GYNUejFHYL]nP02;O/00d:m@Ye2_@03GWH2Im<01VODA[a6_DJlA[e6
_0=R]`05HYMR]f:gA[e6W002A[`01CjMM[5f/GJaM]400WJa00H01@06A[a:_DJlB[d2=Wd00fkEK]IZ
e@02K]D02PRd29A5D4E@AE55D4EAAE15DDE@0TEA00Y5LD9l@Wa2O4:LB]a:gD[LB]ebd`<0009bd`96
W006@Ya6W4JLC]e:g4kM0T[M00U:_4[MI[IVefJfI]LYVBViB]`00TkL00M>gD[LC]e>g4kMC]a>g@02
B]d024[LK]E^eFkF5?DHmACe6?D3C]`01U;mC]a>o4kLD_e>g09>o006D_e>g4kMC]a>gDkL0f:G00AR
UV:GHYM:g0=:_005D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo01=oo`03001oogoo019oo`006Goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol01Goo00=V]V[GI[H00Woo04`<eSjL@YdnO0FK1GYRUeifHYMNMV:G;OXb6bgj@[dn
W5igFWINMeYFGWLb6cHk@Ya6_D:lA[e2W6JgHYIR]f:FFmAK/dJm@Ya6_CZMM]5b/GKAL[5fdG:a00H0
1@06A[a:gDJlB]eZeFkFJ]E^eV[EK]H8U4Jl@C15DD5@AE51D4EAAE15DDE@AG55D4EaAE12W3il@Ya6
_0<00031L]=fm7;CM]=bdgKd@Ya6W4:LAYa:g4kMB]a>gDJlB]e6_4[MI[IZefJf:KTYV2ViB]a>gD[L
C]e:g4kmB]a>oD[LC_djWCjMJ]E^mVkEK_HDmATF5?E>gD[LC]e:g5;mC]aBoDkLD_e>g5;mC]aBoDkL
B]e:_4[MA[aR]f:FH[MNUTL]Aba>g4ZlC]e:_5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol04Goo000IOol00`00Oomo
o`02Ool00`00Oomoo`02Ool20006Ool00f[FI[Ioo`02Ool02PSE2=I2W4:M?YaNUejFHYMNUUjG0V?E
00M2W4:m@Ya2_D:MGWH0m`03GWH01c8k=S]2_DJm@[e6_F:G00=R]`08HYHYfRWJA[e6W4JlM[5fd@=f
/@06M]5f/D:L@Wa2W4Jl0TJm00Q6gF[EK]E^eFkFJ]D8]4JL14E@00I5DDE@AE55D4EAAE02AE400dEa
00000002000014ZlB]e:gD[M1G;C01@03TJLAYa2W4JLB]a>gD[LC]dbGC9mI[IVefJfI]MV]RVi:ITY
^BVH0TkL00U>gDkLC]e>g4kMC]`jWFkEK]H00fkE00DHmACe6?DDmDkm00=>g00:D_e>g4klC_aBoDkL
C_e>g4kmC]`3B]d00f:FHYMRU`04Abd01TkMC]a>g4kLD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBoE;l4goo00<007ooOol04Goo000JOol4
0005Ool00`00Oomoo`0:Ool0A`SF2=D<eSjL@[dnW6:GGWIRUf?DIoESe4Jm@Ya6_D:L0?L0eUigFWIN
MeYF=S`b6cHk<Q]6_D:lA[eRUVJgHYIR]bWI;MXYfTKMA[a:gG:aM]5b/GKAL[5fdCil@Y`nO4:LA[a:
gDJlK]IZeFkFJ]E^ePRC2;A1<4EA@C15DDE@AE51D4EaAE15LDE@BG400P0000Y:_4[MB[a:gDJlB]e:
_4[ML]=fm09bd`803P2jB[a>gDZlC]e:g4kMB]a>gFJfJ]MV]V[GI[IZedJLB[e6_4ZlAYa>oDkLC_e:
g4kmB]a>oD[LK_I^eFkfJ]E^mQCeB[a6W4ZlAYa>oDkLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLB]e:
_4[MGYIR]f:F>S/j6SXk>QY>oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m4Woo0`004Woo0005Ool200000goo0000000IOol00`00
Oomoo`0;Ool02PSF2=E2_D:M@[eNUUjGGYIRUejF0Rgk00A6_D:L@[e2W0INMP08A[e6_4JmA[`J71Wl
6QaRUP=R]`8YfP96_@04A[a6_GJaM]43M[401P06@Wa2W49l@Ya6_096_@06K]IZeFkEJ]D8]0RD0TE@
00M5DDE@AE55D4EAAE15D@06000014[LB]e:g4[M0SjM1G;C0`0>00A:g4[MB[a:g09:g@06B[a:gFJf
I]MV]VKG0P0000A6_4ZlA[a:_0=>g003C]e:g4[M009:g@09B]a^eFkEK]I^eASeA[a:_4JL0096_006
D_e>g4klC]aBoDkL0Tkl00IBoDkLC]e>g4kMC]`27O`03AhLHYIRUcXj>S/j>SXkC]a>gDkLD_a>o5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@0COol00`00Oomoo`0@Ool000Aoo`03001oogoo008001Yoo`03001oogoo00]oo`102=D8ePSE@[dn
W4:mGWH5VeifHYMNMS8K;OY2_CjL@[eJMUigFUINMeYfImAS/dJm@Ya6_AWl7QeRUV:gHYIV]f:F;MXY
fBgJA[a6gDJlB]eb/GKAL[5fdP0500I6_4[MA[a:gCIl>YeZeFkFJ]E^eV[E2;A1<4EA@E15DD5@AE43
00003DUaAE15LCik@Ya2O4:LB[a>gD[L?YebdgKd00=bd`03M_@03P0>00803P2jB]a>gD[LC]e6_4[M
A[a:gFJfJ]MV]V[G:IPY^DJLB[e6_4ZlC]a>oDkLC_e:_4kMB]a:gF[EK_IZeFkf5?DI5T[LC]e:g4kM
B]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kmC]a>oAWl7QaRUV:gGYIR]cXJ>S/j6SXkC]aBoDkLD_e>g5;m
C]aBoDkLD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
4goo00<007ooOol03goo0004Ool01@00Oomoogoo00006Goo0`003Goo00]2W4:M?Y`5VPEj1IYNUUjG
GYIRUbgj008]n`03@[e2WD:m00=NMP9Sd`06Im=S/dJmA[a6_F:F0f:g00IRUU^dEk=6_DJLA[`2?Yd3
M[400gKAM[401P0200H02TJlB[e6_4ZmJ]E^eF[EK]IZeFkE0TJL0TE@0`001TEA00Q5LD9l@Wa2O4:L
B]a:gD[L1g;C0TJL00I2W4JLC]a>gD[LC]d2B]d02DZlI]MV]VKGI[HY^BVI:KU:g002C]`01TkMC]a>
gDkLC]e:g0=:g@=^e@056?DDmASeC]a>g@03C]`01U;mC]a>o4klD_e>g09>o009C]e>g4kMC]a>gF:F
HYMRUV:G00800007B[a:g4ZlB[a>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04Goo00<007ooOol03Woo0004Ool0
1@00Oomoogoo00006Goo00<007ooOol03Woo03PnW4:M?Wa2WEifHYMNMV:GGWIRUbgj<Q/]nT:m?YaN
MeYfGWMJEUig<Q/f>c8KA[e2_4JmHYIV]f:FFkAG/e_D@Ya6_D:LA[e2W7KAL[5fdW:aM]401@0600D0
1TJlB]e6_4[MJ]E^eV[EK]IZ]@bd0`000195DDE@AE51D4EaAE15LDE@BG55D4EaB[a:gDZlB]e6_4[M
B[`2L]<0?WKdL]=bdg;CAYa2W4JL@Ya6W4[LC]e:g4kM;UdbOBiLJ]MV]V[GI[HY^BVHC]e:g4kMB]a>
gD[LC_e:g4km>W`nWF[EK_IZeFkfJ]DI5ACe6AI>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:
gDZlB]eNUV:gHYH20000PTkMB[a>g4ZlC]e>g5;mC]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l4goo00<007ooOol03Woo0004Ool01@00
Oomoogoo00006Goo00<007ooOol03goo00m2WD:m@YeNUejFHYMNUUjGHmASeD:L@[e2W4:m@Yd015if
0cHk00E2_DJm@[eR]f:F00=R]`8YfP96_@04A[a6_DJmM]43M[401WKA@Wa2W49l@Ya6_096_@03K]IZ
eFkE00<000082;A5D4JLAE15DDE@AE55D095D@05AG55DDEaAE400@03B[`014[MB[a:gD[M1G;C00D0
3T[LB]a:gDZl009:g00=C]e:g39M<UeVefJfI]MV]VKG:IPY^BVIC]d00dkL00E>gDkLC]e>g4kM00=^
e@09K]I^eFkEA[a:_4JLA[a>g4km009>g003C_aBoDkL009>o006C_e>g4kmC]a:gD[L0T[M00IRUf:F
HYMRUSXk>SX2C]`01TkMC]a>g5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001oogoo00eoo`000goo0P000Woo
0P006Goo00<007ooOol047oo030nW4:m?YaRUeifHYMOe6?EHmA6_D:LA[e2W5igFUINMeYfGWMJESHl
<Q/f>d:LA[e2_6:g6OaV]f:F;MXYfBgJA[a6gDJlB]eb/GKAL[5fdW:aM]4nO4:L?Wa2W4JlB]d30000
4FkFJ]D8]0RDAE5:_4EA@E15LDE@AG55D4UaAE15LDE@BG400P0100M:_4[MB[a:gDJlB]e:_002L]<0
4GKDL]<03P0>C]e:_4kMB[a>gD[LC]e:g6[GI[IZefJfJ]L00P000:m6W4ZmA[a>oD[LC_e>g4kmB[a>
gD[LB]eZeFkfJ]E^mV[E6AI6W4ZlAYa:_4kLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MB[aR
]ejFH[Lj6SXk>QYBoDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Oomoo`0<Ool0029oo`80019oo`07
@Ye2_EjFGYMNUV:GGYH00Rgk00=2_D:M@[d01Eif00ESdf>cA[a6_4Jm00<Io004H[MRUV:gH[L4:MX0
1DJmA[a6_GJaM]400gJa00<01TJlB[d00`0000`fOF[EK]IZeFkEJ]D8]4E@B]e5D4EAAE06AE402DEa
@Wa2O49l@Ya:g4[MB]`nW@06L]<300h01DkMC]a>gD[LC]d00T[M015:_6KGI[IVefJf:KT004ZlA[a:
_4JlC]e>g4kMC]a>gD[L009:g@05K]I^eFkEK]E^eP026?D01dJlB[a6W4JlC]aBoDkL009>o00FD_e>
g4klC_a>gDkLC]e>g1hL7OaRUf:FHYMRUV:G>SXj>cXjD_a>o5;mC]`2D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00COol00`00
Oomoo`0<Ool0029oo`03001oogoo019oo`0X?Ya2_EifHYMNMV:G;OXb6bgj@[dnW4:mFWINMeYFIm=S
/fOC@Ya6_D:LA[e2W6JgHYIR]f:FI[M2W4Jm@Ya6_D:L?Yeb/GKBL[5fdG:aM]8300007T[MA[`jWCIl
K]IZeFkFJ[E^ePRDAE48U4EAAE15DD5@AG55D4EaAE19LDE@@Y`nNd:L@W]>gDZlC]e:g09bd`35M]Ab
dg;CL]=6W4:LAYa2W4kMB]a>gD[LB]e6_4[MI[IZefJfJ]MV]RVi:IQ>gD[LC]e:g4kmC]a>oDkLC_e:
_4kMB]`nWF[EK_IZeATF5?DI5T[LC]e:g4kMC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4kmC]aRUejFH[MN
UV:GGYI>gDZlC]a:_5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol00`00Oomoo`0;Ool0025oo`03001oogoo
01=oo`85NP06HYMNUUjGGYIRUbgj0Rgk00=2_D:MGWH015if0SHk00E2_DJm@[e6_D:m00=R]`9G/`06
A[a6_DJLA[`nWGKA0gJa0P000`0600Y6_4ZmA[a^eV[EK]EZeFkFJ]D8]096W005AE15DDE@AE55D002
AE401DEaAE55LDEAAG400d9l00A:gDZlB]e:g@Ebd`0900i6W4JLAYa2W4kMC]a>gD[L00=:g@05;UeV
efJfI]LYV002:KT02DkMB]a>g4kLC]e>g4kMC]a>g@02>Yd00fkEK]I^e@02K]D26?D2C]`01TkMC]a>
g4klD_e>g09>o00<D_e>g4klC_a:gD[LB]eRUV:GHYIRUf:F0P000TZl00I:g4ZlD_aBo5;mC_`2D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
0e;mD_aoo`0BOol2000<Ool0025oo`03001oo`0001Aoo`0RHYMNMV:GGWIRUeoDHmE2W4Jm@Ya2_CjL
GWL0eUigFUINMc8K=S]2W4Jm@[a6_F:FI[MRUV:gHYH]nRWJA[e2W4JmL[43000097:aM]5b/D:L?Wa2
W4JlB]e6_6kFJ[E^eV[EK]H8U4Jm@Ya5DD5@AG55D4EaAE19LDE@AG55D4UaAE400DZlB]e:_4[MA[a:
g@=bd`0lM]Abdg;C00i6W4:LAYa2W4kMB]a>gD[L<Wd^GF[GI[IZefJfJ]LYV2Vi:IQ>oD[LC_e>g4km
B]a>oD[L?YdjO6kfJ]E^mV[EK_HDmATF5?EBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[M
GYIRUejF100008ABoDkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`COol00`00Oomoo`0:Ool0025oo`8001Io
o`03GYMNUV:G00=Se006HmE2W4:m@Y`0m`3F1Eif0SHk00Db6dJm@[e6_F:F00=R]`<YfP<00003M[5f
dGJa009f/@06M]52O4:L@Wa6gDJl0TJm00Y^eV[EK]EZe@Rd29A:gDE@AE55D095D@09AG55DDEaAE55
LDEAAG400D[M00=:_003B]e:_4[M00Ebd`803P9:g00AB]e:_4kMB]a>gD[LI]MV]VKGI[IVefJfB[a6
_4ZlA[a>g@03C]`01DkMC]a>gDkLK]H00fkE00I^eQSe0016_4ZlAY`2C]`04TkmC]a>g4klD_e>g4kl
C]a>oDkLC_e>g4[MB]aRUf:FHYMRUP8j>P06>S/j>TkLC]a>gDkL0U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;l
D_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0A
Ool2000;Ool000moo`@000Aoo`@000Ioo`03001oogoo01Eoo`04GWIRUeifHmD2Ool05Bgj<Q]2W4Jm
@YaNMeYFGWMJMUigHk9Sdd:LA[e2W1hM6O`J76:FI[MRUP0300008TJlA]e6_7KBL[5fdG:aM]9b/@07
?Wa2W3ilB]e6_4[MA[a^eVZeK]H8U0bd29A5DDE@AE55D4EaAE15LDE@BG55DDUa0`0100M>gDZlC]e:
g3jM>Yafe003L]<047KD00h03dZlC]e:_4kMB[a:gDJlB]e6_6[GI[IZefJf0P000;9:_4JLB[e6_4km
B]a>oDkLB]e:_4kMB]a^mV[EK_IZeATF5?E:_4JLB[a6W5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e:g4km
C]a:gDJlH[MNUV:G>QXj>cXJ>S]>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0ioo`<00003Ool007oo
00Yoo`003Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo01Ioo`03
GYIoogoo009oo`8]n`03;Q]2WD:m00ENMP05Hm=S/dJlA[a6_@026O`01V:g00000000H[L]fP8YfP96
_@04A[af/GJaM]42M[4200H02TJlB[e6_3JM=We^eF[EK]IZeFkE0PRd00E5D4EAAE15DDE@0095D@05
AG55DDEaAE55L@03@W`014[MB]a:gCjM1W;C0`0>00E:g4kMC]a>gD[L00=:g@05I[IVefJfI]LYV002
:KT03DkMB]a>g4kLC]e>g4kMC]a:gD[LB]e^eFkF009^e@036?DI5ASe009>g006C]e>g4klC]aBoDkL
0Tkl00eBoDkLC_a>g4kMC]a>gAgl7QaRUV:GHYIRU`03B[`01D[LC]aBo4klD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@0:Ool40004Ool00`00Oomoo`09Ool001=oo`04001oogoo0004Ool00`00Oomoo`03Ool2000M
Ool03S8K;OY2_CjL@[eJMUigFUISdf>bHm=S/TJm@Y`30000<6:FH[MRUUNcEi=6_D:LA[djWGKAL[5f
dW:aM]5b/@0700I:gDJlB]e6_4[MJ[E^eV[EK]IZ]DJm@Ya5DD5@AG55D4EaAE19LDE@AG55D4UaAE52
W3ik@Ya2NdkMB[a>g@=bd`0mM]Abdg;D00i6W4:LAYa:g4kMB]a>gD[LB]e6_4[MI[IZefJf:KTYV2Vi
:IQ>gD[LC]e>g4kmC]a>oDkLB]e:_4kMJ]E^mV[E6AHHmATF5?E>gD[LC]e:g5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e:g4kmGYIRUejFH[L00P0008Q:_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aBoDkl
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@Io
o`<000Qoo`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03001oogoo009oo`8001ioo`05;OX]
nbgk@[e2W@02GWH016?CGWINMSHk0`0000=2_DJmHYH00V:g0eNc00I6_4JmAYa6_7JaM]43M[401WKA
00H01P06A]e6_096_@06A]eZeFkEJ]E^ePRd0TJL00Y5DDE@AE55DDEaAE55LDEAAG55D@95L@07B]e:
_4ZlB[a:gDZlB]d01W;C00U2W4JLAYa6W4[LC]e:g4kMB]`00S9M00YVefJfI]MV]RVi:IPY^DkLC]e:
g09>g005C]e>g4kMC]`jW@03K]D01VkFK]DHmASe6ADHm@9>g00;C_e>g4klC_aBoDkLC_a>g4kmC]a>
o@02B]d014[LHYMRUV:G0`0000I:g4ZlB[a:_5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l0goo0`0037oo
00<007ooOol027oo000?Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0NOol0
1d:LA[e2W4:m?YaNMeYf00<0003o<Q/f>c8KA[e2_6:gHYIG/f:FH[LYfBgjA[a6gDJlB]eb/GKAL[5f
dW:aM]8nO4:L?Wa:gDJlB]e6_6kFJ[E^eV[EK]H8U4JmAE15LDE@BG55D4EaAE19LDEABG55D4Ua005:
gDZlB]e:_4[MA[a:gG;CL]Abdg;DL]<03dZlC]e:_4kMB]a>gD[LC]d^G39mI[IVefJfJ]LYV2Vi:IPY
^DkLC_e:g4kmB]a>oD[LC_e:g6kfJ]E^mV[EK_I6W4ZlAYa:_4JLD_e>g4kmC]aBoDkLD_e>g5;mC]aB
oDkLB]e:_4[MA[aR]ejFHYLj6SXk>QY>oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l005Bo@5Bo080
00moo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol07goo00=2W4:m@Y`00`000eif0TJl00U6_DJl6O`Io1XLHYIR]f:G;MX00RWJ0TJm00E6_4Jm
M[5fdG:a009f/@06@Ya2O4:L@Wa2W4Jl0TJm00I^eV[EK]EZe@bd2;@6AE401TEaAE55LDEAAG55D@80
0@03B]e:_4Zl00<nW@Ebd`0300h03dZl009:g009B]e:_4kMB]a>gFJfI]MV]VKG00800006A[a:_4Jl
B[a>g4kM0TkL0T[M00A:g4[MB]e^eP=^e@0:6AE6W4JlA[a:_4JLC_a>g5;mC]`2C_`01U;mC]a>oDkL
C_e>g0=:g@04HYIRUf:F>S/3>SX01DkMC]a>g4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo11oo`03001o
ogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol087oo
0P000?mJMUigFUINMeYfHm=O/TJm@Ya6_AWl7QeRUV:gHYIV]f:F;MXYfBgjA[a6gDJlB]eb/GKBL[5f
dP06B]e6_4[MA[a:gCIl>YeZeFkFJ[E^ePRD3;A1D4EaAE15LDE@BG55D4UaAE19LDEABG4nNd:L@W]>
gDZlC]dnWG;DL]=be7;CL]Abd`0?00h03d[LC]e:g4kMB]a:gDJlB]eV]V[GI[IVebVH0016_4ZlAYa:
_DkLC_e>g4kmB]a:gDZlC]eZeFkfJ]E^mQSe6AI:g4kMB]a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmC]a>
oD[L7Q`Io6:GGYIR]ejF>S/j6SXk>QYBoDkLD_e>g5;mC]aBoDkLD_e>o5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`000YBoE;lD_eBo5;mD_aBoE;lD_eBo0mo
o`03001oogoo00Qoo`003goo1@000goo10001Goo0P007Woo0`0000=2_D:M@[d00eif00AS/f>bHk=S
/P96_00;A[eRUV:gHYMR]f:FH[M6_4JmAYa6_002?Yd01G:aM[5f/GKAL[400P0600Y:_DJlB[e6_4Zm
J]E^eF[EK]IZe@88]00:AE55D4EAAE55LDEAAG55DDEaAE42AG401d:L@Wa2O4[LB]e:g4[M00Ibd`09
00i6W4JLAYa:g4kMC]a>gD[L009:g@0:I]MV]VJgI[HY^BVH:KU>g4kMB]`2C]`00dkMC]a>g@02B]d0
1D[LB]e^eFkFK]D00QSe00XI5DkLC]a>g4kMC]a>o4kLD_e>g09>o00=D_e>g4kMC]a>gDkLHYMRUV:G
HYIRUdZlB]`00dZl00EBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`?Ool00`00Oomoo`08Ool0
021oo`03001oogoo01Yoo`<000Aoo`1m@[dnW5igFWINMeYFGWLb6cHk<Q]6_D:lA[eRUVJgHYIR]e>B
Ek=2W4Jm@Ya6_CZMM]9b/GKBL[5fdP0600L01T[MA[a:gDJlB]eZ]FkFJ]E^ePRDA[e5D4EaAE19LDE@
AG55D4UaAE59LDE@BG55DD:L?W]2W4ZlB]e6_4[ML]=be7;CL]Abd`0?@Ya6W4:LAYa:g4kMB]a>gD[L
<Wd^GFKGI[IZefJf:KTYV2ViB]a>gD[LC]e:g4kmB]a>oCZM?YeZeFkfJ]E^eV[E6AHHmATFC]aBoDkL
C_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlB]e6_6:gGYIRU`020000S4ZlC]a:_4kMB[aBoDkLD_e>g5;m
C]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d>Ool00`00Oomoo`08Ool0021oo`03001oogoo01Moo`<000Qoo`03
@[e2WEif00=NMP<f>`08<Q]6_D:mA[eRUV:gHYMR]`8YfP07A[a6_DJLA[af/GKAL[400WJa00IfdD9l
@Ya2O4KMA[`2A[d02FkFJ]EZeF[EK]H8]4JLAE55L@03AE400dEaAE55L@04AG401001B]e:_4Zl0T[M
00=:_7;CL]<017;C00l03dZlB]a:g4[MB]a>gD[LC]d^GC9MI[IVefJfI[L00RVi00@YV2ViC]a>g@=>
g005C]e>g4kMK]E^eP03K]D01FkFAYa6_4JlB[`00dkL00Y>oDkLC_a>o5;mC]a>oDkLC_e:g0=:g@04
HYIRUf:FHYL2>SX00dkLC]e>g002C]`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0
3Goo00<007ooOol027oo000OOol00`00Oomoo`0EOol3000=Ool0D5YFGWMJMUigFUHf>c8K=S/b6dJm
@[aR]f:FH[MRUV:g:MT]nTJlA]e6_4[ML[5fdW:aM]9b/D:L?Wa2W3il@Ya6_4[MA[`jWFZeK]IZe@bd
29A5LDE@AG55D4UaAE59LDE@BG55DDUaAE400P01B]e:_4[MB[a:gDJlL]Abdg;DL]=be00>00m:_4kM
B[a>gD[LC]e:g4kMI[IZefJfI]L20000^4JlB[a6W4ZmC]a>oD[LC_e:g4[MB[a>gF[EK]IZeFkf6?DI
5TJLB[a6W4kmC]aBoDkLC_e>g5;mC]aBoDkLD_e>g5;mA[a:gDJlB]eNUV:gGYHj>cXJ?S]>g4kmC]aB
oDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m3Goo00<007ooOol01goo000OOol2000COol3
000@Ool4GWH01V>bGk96_4JlA[e6_08Io005H[MRUV:gHYL]fP03:MX01TJmA[a6_GJaM]5b/@9f/@05
B[e6_4ZmA[a:_@02=Wd01f[EK]IZeF[E2;@<]4E@0095D@06AG55DDEaAE55LDEA0TEa00Q2W49l@Wa2
O4[MB]a:gCjM1W;C00P03`0>00m:g4kMC]a>gDZl0d[M00iV]VJgI[HY^@00B[a6_4ZlA[a:_4kLC]e>
g4kM0T[M00U:g6kEK]E^eV[EK]DHmATEAY`00TJl00IBoDkLC_a>g5;mC]`2C_`03E;mC]a>gDkLC]dI
o1glHYIRUf:FHYMRUSXk008j>P06C_aBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo
00aoo`03001oogoo00Moo`007goo00<007ooOol03goo0`0057oo0?mNMeYFGWMO/V>cGk9Sdd:LA[e2
W6:gHYIR]f:FH[MRUTJm@Ya6_D:L?Yeb/GKBL[5fdW:aM]801T[MA[a:gDJl>YdfO6kFJ]E^eVZe3;@8
]4EaAE19LDE@AG55D4UaAE59LDEABG55LD:L?W]2W4[LC]e:_4kML]=be7;CL]Abdg;D@Ya6W4:LAYa:
g4kMB]a:gDJlB]e6_6KGI[IZefJf:KTYV4kMB]a>gD[LC]e>g4kmC]a>oD[LB]e:_3jMJ]E^eV[E6AHH
mATFB]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mB]a>oDkLC_eNUV:gGYIRUejFH[M:_4kLB[a>gDkLD_e>
g5;mC_aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d000]Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l00aoo`03001oogoo00Moo`007goo00<0
07ooOol037oo0`005goo0Uif01EO/WooOolf>c8K=S]2_DJm@[eR]f:GH[MRUUNBDi96_DJLA[`nWGKA
L[400WJa00=fdG:a00L00P0700A6_4ZmA[a^eP=Ze@0:K]IZeDJLAE55LDEAAG55DDEaAE42AG401DUa
AG55LDEa@Y`00T9l0T[M00=:_4[ML]<017;C00<03d:LAY`00TJL00E:g4kMC]a:gDZl009:g@03I]MV
]VJg008Y^@05:IQ>g4kLC]e:g002C]`00dkMC]a>g@02>Yd026[EK]E^eFkF6?DI5ASeC]d3C]`01U;m
C]a>o4klD_e>g09>o003D_e:g4[M009:g@04HYIRUf:FHYL200001dZlB]a:_4ZlD_aBoDkl009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Yoo`03001oogoo00Moo`007goo00<007ooOol0
2Goo0`006goo07QJMWooOomooc8K=S/b6dJm@[a6_F:FH[MRUV:gHYH]nRWJA[e2W4JmL[5fdW:aM]9b
/GKBL[52W3il@Ya6_4[MA[a^eVZeK]IZeFkF2;A6_DE@AG55D4UaAE59LDE@BG55DDUaAE59L@01B]e:
_4[MB[a:gDJlL]Abdg;DL]=be7;C00m:_4kMB[a>gD[LC]e:g39m;UaZefJfI]MV]V[G:IPY^BVHC_e>
g4kmB]a>oD[LC_e:g3jM>Ye^eV[EK_IZeATF6?DI5QSeC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6
_4[MA[aRUejFH[L40000SdkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`02Woo00<007ooOol01goo000OOol20008Ool2000SOol2=S/0238KA[e2_DJmHYIR]f:GH[L3:MX0
1TJmA[a6_GJaM]5b/@9f/@09M[92O4:L@Wa2W4JlA[eZeFkF00=Ze@0:3;@8]4EAAE55LDEAAG55DDEa
AE42AG401DUaAG400TZlB]d00TZl0T[M00=:_7;CL]<00g;C0P0?015:_4[LB]a>gD[LC]e:g6KGI[IV
]fJfI]MV]TZlA[a:_4Jl009>g006C]e>g4kLC]a>gDkL0VkE00I^eV[EK]DHmDZlAY`2A[`01TkmC]a>
g4kLD_e>g09>o006C_e>g4kmC]a>oD[L0T[M00ERUf:FHYLj>SXk008j>P06C]a>gDkLC]aBo5;m0e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol027oo00<007ooOol01goo000NOol00`00Oomo
o`05Ool3000VOol0od:LA[e2W1XM6OaR]f:FH[MRUV:g:MT]nTJlA]e6_7KBL[5fdW:aM]9b/@07A[a:
gDJlB]dfO3ZMJ]E^eVZeK]IZe@bdAE19LDE@BG55D4UaAE59LDEABG55L@0200400T[LC]e:_4kM?Yeb
e7;CL]Abdg;DL]<03`0>00m:_4kMB[a:gDJlB]e6_6KGI[IZefJf:KT004ZmA[a:_4JLC_e>g4kmC]a>
oD[LB]e:_6kfJ]E^eV[E7AI6W4ZlAYa:_4JLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oDkLC_dIo1hLGYIR
UejF?S/j6SXk>QYBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0001e;mD_aBoE;lD_eBo5;m
00Yoo`03001oogoo00Ioo`007Woo00<007ooOol00Woo0`00:Goo0TJl00U6_DJlH[MRUf:gHYIR]f:G
;MX00RWJ0TJm00I6_7JaM[5f/W:aM[4200L01DJlB[e6_3JM=Wd00V[E00Y^eV[EJ]D<]4EaAE55LDEA
AG55D@95L@05BG55LDEaAG52W002@W`014[LB]e:g4[M1W;C0152W4JLAYa6W4[LC]e>g4[MB[a:gFJf
I]MV]VJgI[HY^BVH009>g007C]e:g4kMC]a>gDkLC]d00T[M00QZeFkEK]E^eQSe6AE>g4kM0dkL00IB
oDkLC_a>g5;mC]`2C_`02TkMC]a>gDkLC]eRUV:GHYIRUf:F0TZl00I:g4ZlD_a>o5;mC]`2D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0Yoo`03001oogoo00Ioo`007Woo00<007oo00000P00
;Goo0796_D:lA[e2W6:gHYIR]f:FEk9CTTJm@Ya6_CZMM]9b/GKBL[5fdW:a00L01P07A[a:gDJlK]IZ
]FkFJ]E^eVZe3;E5D4EaAE19LDEABG55D4UaAE59LDEABG95LD:L?W]2W4ZlB]e6_4[ML]=be7;CL]Ab
d`0?@Ya6W4:LC]e:g4kMB]a:gDJlB]d^GFKGI[IZebVH:KTYV4kMB]a>gD[LC_e:g4kmB]a>oCZM?YeZ
eFkfJ]E^eQSe7AI:g4kMB]a>gD[LD_e>g5;mC]aBoDkLD_e>g4[MA[a:gDJlB]eNUV:gGYH20000TTkM
B[a>g4ZlD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`9Ool00`00Oomo
o`06Ool001ioo`<0031oo`0@A[e2_DJmHYIR]f:GH[MRURgJ:MY6_DJLA[af/GJbL[42M[401WJbL[52
W49l@Ya6_096_@06K]IZeF[EJ]E^ePbd0TEA00=5LDEAAG401DEa00E9LDEaBG400T[M009:_09:g@03
B[abdg;C00=bd`803`0>@Ya6W4JLC]e:g4kMB]`bOBiMI[MV]VKGI[IV]`8Y^@0=:IQ>g4kLC]e>g4kM
C]a>gDkL>Ye^eFkFJ]D00VkE00DI5ASe6AE>g4km00=>g00:D_e>g4klC_a>oDkLC_e>g4[MB]`2B]d0
0f:GHYIRU`030002C]`01TkMC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l27oo00<007ooOol01Woo0004Ool50003Ool40004Ool40007Ool00`00Oomoo`0`Ool0odJm@[a6
_F:F6QeRUV:g:MT]nRWJA]e6_4[ML[5fdW:aM]9b/GKB?Wa2W3il@Ya6_4[MJ]E^eVZeK]IZ]@bd2;A9
LDZlBG55D4UaAE59LDEABG55LDUaAE400TZlB]e:_4[MB[a:gDJlL]Abdg;DL[<03`0>00m:_4kMB[a>
gD[LC]e:g6KGI[IZefJfI]MV]TZmA[a:_4JLC_e>g4kmB]a>oD[LC_e:g6kfJ]E^eV[EK_HHmDZlAYa:
_4kLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MA[aRUejF?S/j6SXk>QYBoDkLC_e>g5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@001e;lD_eBo5;mD_aBoE;l00Moo`03001oogoo00Ioo`00
1Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`80035oo`<I
o006HYIR]f:GH[LYfRgJ0TJm00a6_7JaM[5f/W:aM[5b/@07A[a:_DJlB[d2=Wd00f[EK]IZe@02J]D0
1PbdAE5:gDEAAG55D@95L@04BG55LDEaAG4300801D[LB]e:g4[M?Yd01G;C00D03P0?00l03dZl009:
g00BB]e:_4[MB]eVefJfI[MV]RVi001:_4JlB[a6_4kMC]a>gDkL0d[M015:g6kEK]E^eV[E6AE6_4Zl
AYa6_4kLD_e>g4klC]aBoDkL009>o004C]e>g4kMC]`26O`016:GHYIRUf:F0SXj00Hj>cXjD_a>o5;m
C]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`0
0003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00Moo`03001oogoo00Io
o`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Moo`03001o
ogoo031oo`0@HYIR]f:FH[MRURgJ:MT]nTJlA]e6_7KBL[5fdW:aM]8200L0lTJlB]e6_3JM=We^eVZe
K]IZ]FkF2;A5L@RdBG55DDUaAE19LDEABG55DDUbAG52W3ik@Ya:g4kMB[a>gG;CL]Ab/g;DL]=6W4:L
AYa2W4JLB]a>gD[LB]e6_4[MI[IVefJfJ]LYV2Vi:IQ>gD[LC]e:g4kmC]a>oDkLC]e:g4[MJ]E^mV[E
K]HHmAdFB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e>g6:GGYIR]ejFHYM:_4kMB[a>g4Zl
D_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d6Ool00`00Oomo
o`06Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`08Ool0
0`00Oomoo`0`Ool00f:GH[MRUP02Di802TJmAYa6_3jMM[9b/GJaL[5f/W:a0`0700A6_4ZmA[a^eP=Z
e@06K]IZe@bdAE56W4EA1TEa00E9LDEaBG55LD:L0092O09:g@03B[a:gG;C00Abd`0>AYa2W4JLAYa>
gD[LC]e>g4[MB[a:gFJfI]MV]P<Y^@09:KQ>g4kLC]e:g4kMC]a>gDkL008jW@09K]IZeFkEK]E^eQSe
6AE>g4kM009>g003C_aBoDkL009>o006D_e>g4klC_a:gD[L0T[M00=RUf:FHYL00P000dZl00I:g4Zl
D_aBo5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo00Ioo`03001o
ogoo00Eoo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Uo
o`03001oogoo02moo`1/H[MRUV:gOol]nRWJA[e2W4JmL[5fdW:aM]9b/GKBL[52W3il@Ya6_4[MA[a^
eVZeK]IZ]FkF2;A9LD:LBG55D4UaAE59LDEABG55LDUaAG59LP02B]e:_4[MB[a:gDJlL]Abdg;DK[=b
e00>AYa2W4JL@Ya>gD[LC]e:g39m;UaZefJfI]MV]Rfi:IPY^BVHC_e>g4kmB]a>oD[LC_djO3jMJ]E^
eV[EK_IZeATF6?DM5TkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MGYIRUejF0`0009E>g5;m
C]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Ioo`03
001oogoo00Eoo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
00Yoo`80031oo`0GH[Moogoo:MX]fRWJA[e6_4JmL[5f/W:aM[5b/GJb@Wa2W49l@Ya6_4JmJ]E^eP03
J]D23;@014[MAE55LDEA0TEa00U9LDEaBG55LDUaAG400TZlB]d00TZl0T[M00E:_7;CL]=be7;C0080
3`0BB]e:_4[LB]a>gD[LC]e:g6KGI[IV]fJfI]M6_4ZlA[a:_4Jl0TkL00I>gDkLC]e>g4kMJ]D2K]D0
2FkFJ]DI5@@1B[a6W4JlC]a>o@02C]`03dklD_e>g4klC]a>oDkLC_e>g4[MB]a:gF:FHYMRUP02>SX0
1CXkC]a>g4kLC]d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
0e;mD_aoo`04Ool00`00Oomoo`05Ool000Aoo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool0
0`00Oomoo`0<Ool00`00Oomoo`0aOol0obWI;OY6_4KMA[a:gG:aM]9b/GKBL[4024JlB]e6_4[M=Wdj
WFZeK]IZ]FkFJ[D<]0RdBG55DDUaAE59LDEaBG55DDUbAG400`0200=:g4kMB[a>gCjML]A^/g;DL]=b
e00>00l03P0?B[a>gDZlB]e6_4[MA[aVefJfJ]MV]P00AYa:_DJlB[a6W4kmC]a>oDkLC]e:g4[MJ]E^
mV[EK]HHmAdFAYa:_4JLB[a>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e>g1gl6O]R]ejFHYLj6Shk>QXj
>dkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo001D_d1
D_`4Ool00`00Oomoo`05Ool000Ioo`03001oogoo00=oo`@000Aoo`@0011oo`03001oogoo031oo`03
;MXYfRgJ0096_@06A[a6_G:aM[9b/GJa0P0700E6_4ZmA[`fWCIm009Ze@03K]IZeF[E008<]004AE55
LDEaBG43AG401DUaAG59LD9l@Y`00T9l00I:g4[MB]a:gG;CL]@3L]<00dJL@Ya6W002AY`02T[LC]e>
g4[MB[a:gFJfI]MV]VJg0RVi00U:g4kLC]a>gD[LC]e>g4kMC]`00T[M00U^eV[EK]E^eATF6?DI5DkL
C]d00dkL015BoDkLC_a>o5;mC]a>o4kLC_e>g4kMC]aRUf:FHYMRUV:G00=:_005B]a>g5;lC_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l
001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol00Woo00<007oo
Ool01Goo000YOol00`00Oomoo`0`Ool0IdJm@Ya6_CZM?Yeb/GKBL[5fdW:a00P01`08A[a:gDJlK]IZ
]FkFJ[E^eVZe3=E2W4UaAE19LDEABG55DDUbAG59LDEaBI95LD:L?W]2W4ZlB]e6_4[ML]=be6jcL]Ab
ddJL@Y]6W4:LAYa:g4kMB]a:gDJlB]eV]VKGI[IZebVH;KU:g4kMB]a>gD[LC_e:g4kmB]`nWCZMK]IZ
eFkFJ]DM5QSeC]e:g4kMB]a>gDkLD_e>g5;mC]aBoDkLD_e6_4[MA[a:gEjFHYMNUV:g00800003B[a>
gDZl009>g02CD_e>g5;mC]aBoDklD_e>o5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m00=oo`03001oogoo00Eoo`00:Woo00<007ooOol0<Goo00e6W4JlA[af/W:aM[5b/GJbL[52W49l
@Ya6_002A[d02VkFJ]EZeF[EK]H<]4JLAE55LDEA0TEa00U9LDEaBG55LDUaAG59L@02B]d00TZl0T[M
00A:_7;CL]=be09bd`0300m:gDZl009:g00:B]e:g4kMB]`bOBiMI[MV]VKGI[H3:KT3C]`01TkMC]a>
gDkLC]djW@9^e@06K]IZeFkE6ADI5QSe0TkL00]>oDkLC]a>o5;mC]a>o4kLC_e>g4km009:g@05B]a:
gF:FHYMRUP02>SX01SXkC]a>g4kLC]e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo0=oo`03001oogoo00Eoo`00:goo0P00<Woo02e6_4[MA[afdW:aM]9b/GKB
?Wa2W3il@Ya6_4[MJ[E^eVZeK]IZ]@cE3;A:gDEABG55DDUaAG59LDEABG95LDUbAG400dZlB]e:_4[M
B[a:gDJlL]Abdg;DK[<00P0?00a>gDZlC]e:_4kMB]a>gD[LI]MV]V[GI[H20000`TZmA[a:_4[LC_e>
g4kmB]a>oD[LC_eZeFkFJ]E^eV[E7AI6W4ZlAYaBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]e6
_6:gGYIRUcXJ?S/j6SXkC]aBoDkLC_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`3Ool00`00Oomoo`04Ool002eoo`03001oogoo031oo`0<A[a6_DJmM[9b
/GJbL[4024JlB[e6_4Zm0SIm00=ZeFkFJ]D00V[E0Pbd0TEa00I9LDEaAG55LDUaAG42BG402@030080
0d[LB]e:g4[M?Yebe003L]<02W;D00l03`0?C]e:g4kMC]a>gDZl0T[M00iVefJfI[MV]P00A[a:_4Jl
B[a>g4kMC]a>gDkL0d[M00AZeFkEK]E^eP8I5@07A[a:_4JLC_a>g5;mC]`00Tkl00MBoDkLC_a>g4km
C]a>g@026O`016:FHYMRUV:G0cXj00EBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo09oo`03001oogoo00Aoo`00;Woo00<007ooOol0<7oo0?lj
W7KBL[5fdW:aM]801`08A[a:gDJl=YdfOFkFJ[E^eVZeK]H<]0cEAE19LDEABG55DDUbAG59LDEaBI92
Nd:L?W]2W4[LC]e:_4kML]=be6jcL]Abdg;D@Y]6W4:LC]e:g4kMB]a:gDJlB]eV]VKGI[IVebVH;KU:
g4kMB]a>gDkLC_e>g4kmB[a>gD[LB]eZeFkFJ]DM5QSe7AI:g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e>
g4kmB]a>oEjFHYMNUV:GGYI>g4ZlC]e:_5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00Goo0@001Woo000_Ool00`00Oomoo`0_Ool01SjM
L[5f/W:aM[9b/@801`0500Q6_4ZmA[a^eP03J]D016kFJ]D<]4JL14Ea00U9LDEaBG55LDUaAG59LD9l
@Y`00T9l0T[M00A:_4[ML]=be0=bd`0?AYa2W4JLAYa>gD[LC]e>g4[MB[a:gFJfI[MV]VJg008Y^@08
B]a>g4kLC]e>g4kMC]a>g@8jW@06K]E^eV[EK]I^eAdF0QTE00=>g4kMC]`00Tkl00MBoDkLC_a>o5;m
C]a>o002B]d01D[LB]eRUV:GHYH00P0000I:g4ZlB[a:_5;mC_`2D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aoo`0000Ioo`00<7oo0P00<7oo00Af
dW:aM]9b/@9oo`3j@Y`nO4:LA[a:gDJlK]IZ]FkFJ[E^ePbd4=E5DDUaAE59LDEaBG55LDUbAG59LTEa
00=:_4[MB[a:gDZlB]e6_7;DL]=be6jcL]@03dkMB[a>gDZlC]e:g4kMB]`bOFJfI]MV]VKGI[H]^BVH
;KU:g4kmC]a>oD[LC_e:g4kmJ]E^eV[EK]IZeFkFAYa:_4JLB[a>g4kmC]aBoDkLD_e>g5;mC]aBoDkL
D_e6_4[MA[aRUejFHYLj6Shk>QY>oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0006Ool0039oo`03001oogoo02ioo`03M[9b/Goo
009oo`05@Wa2W49l@Ya6_002A[d016[FJ]EZeF[E0Pbd0TEa00I9LDEaBG55LDUaAG43BG4200<014Zl
B]e:_4Zl0T[M00E:_7;CL]=be7;C00803`0<B]e:_4[LB]a>gD[LC]eV]VJgI[IV]fJf0P0000=:_4Jl
B[`00dkL00=>gD[LB]d00T[M00eZeFkFK]E^eQTE2096_4ZlAYa6_4kLC_e>g002C_`01U;mC]a>oDkL
C_e>g0=:g@04B]aRUf:FHYL3>SX01DkMC]a>g4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l00001Woo000cOol00`00Oomoo`0bOol09@08A[a:
gDJlB]dfOCZMJ[E^eVZeK]IZ]@cE3;A9LDEaBG55DDUbAG59LDEaBI95LD:L?W]2W4[LC]e:_4kM?Yeb
e6jcL]Abdg;D00<03`3>C]e:g4kMB]a:gDJlB]eV]VKGI[IVebVH;KTYV4ZmA[a:_4kLC_e>g4kmB[a>
gD[LK]IZeFkFJ]DM5QSeC]e:g4kMB]a>gDkLD_e>g5;mC]aBoDkLC_e>g4kmB]`J71WlHYMNUV:GGYHj
>cXJ?S/j6U;mC]aBoDkLD_e>g5;mC]aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo0Aoo`03001oogoo00=oo`00=7oo00<007ooOol0<Goo0P0800A6_4ZmA[a:_@=Ze@03J]IZ
eF[E008<]0=5L@09BG55LDUaAG59LDEaBG52O4:L0092O006B]a:gD[LB]ebdg;D0g;C00l03d:LAYa6
W4kMB]a>gDkLB]e:_6JgI[IV]fJfI[L00RVi00TY^4kLC]a>gDkLC]e>g4kMB]`00T[M00I^eV[EK]HI
5AdF6AD2C]`01TkMC]a>g4klD_e>g09>o00:D_e>g4kMC]a>oDkLHYMRUV:GHYH200002D[LB[a:_4Zl
D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo00Ioo`03
001oogoo00=oo`00=Goo0P00<Goo05/0200700Q6_4[MA[a:gFZeK]IZ]FkFJ[D@eD:LBG55DDUaAG59
LDEaBI95LDVBAG59TTZlB]e:_4[MB[a:gDJlB]ebdg;DK[=be6kCAYa2VdJL@Ya>gD[LC]e:g39m;U`b
OFJfI]MV]Rfi:IP]^D[LC]e:g4kMB]a>oD[LC_djO3jMJ]E^eV[EK]HHmAdF6?EBoDkLC_e>g5;mC]aB
oDkLD_e>g5;mC]a:gDJlB]e6_6:GGYIRU`020000TTZlC]a:_4kMB[aBoDkLD_e>g5;mC]aBoDklD_e>
o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;m001BoE;lD_eBo5;mD_aBoE;lD_d;Ool00`00Oomoo`03Ool003Moo`03001oogoo02moo`04@Ya2
O4:LA[`2A[d01F[FJ]EZeV[EJ]H00Pbd00M5LDUaAG59LDEaBG55L@02BG401DUbBG400dZlB]d00dZl
00E:gDZlB]ebdg;D009bd`0300m:gDZl009:g00:C]e:g4kM;UdbOFJfI[MV]VJg:KP3:KT3C]`02TkM
C]a>gDkLC]eZeFkFJ]E^eV[E0TJl00I:_4JLC]a>g4kmC]`2C_`01U;mC]a>o4kLC_e>g0=:g@04HYIR
Uf:FHYL2>SX00dkLC]e>g002C]`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo0moo`03001o
ogoo00=oo`00>7oo00<007ooOol0;goo01M2W3il@Ya6_4[MA[`fWFZeK]IZ]FkF3;A9LDEaBG55DDUb
AG59LTEaBI95LDVB00800`04B]a>gDZlC]d2?Yd04VjcL]A^dg;DK[<0400?C]e:_4kMB[a>gD[LC]eV
]VKGI[IVe`80002cAYa:_DJlB[a:g4kmC]a>oDZlC]e:g4[MJ]E^eV[EK]HHmDZlAYa:_4JLD_e>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MGYIRUejF>S/j6ShkC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d0000BOol00`00Oomoo`03Ool003Uoo`03001oogoo02moo`03B[e6_4Zm008fO@07J]EZ
eV[EJ]IZe@cD3;@00TEa00=9LDEaBG400TUa00A5LDUaBG52W092O006B]a:gD[LB]ebdg;D0g;C01Yb
e00?00l03dkMB]a>gDkLB]e:_4[MI[IV]fJfI[LY^BfiA[a:_4JlB[a>g4kMC]a>gD[L0T[M00I^eV[E
K]IZeAdF6AD2C]`01TkMC]a>o4kLD_e>g09>o006D_e>g4klC]a>oDkL0QWl00ERUejFHYMRUSXk008j
>P06C_aBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`017oo00<007ooOol03goo00<007ooOol00goo000jOol2
000`Ool0F4[MA[a:gDJlK]IZ]FkFJ[E^ePbdA[a5DDUbAG59LDEaBI95LDVBAG59TT9k@Y`nNd:LB]a>
gDZlL]A^dg;DK[=be6jc00m2VdJL@Ya>gD[LC]e:g4[MA[aVefJfI]MV]Rfi:IP]^D[LC]e:g4kMC]a>
oDkLC_e:_4kMB]a^eV[EK]IZeAdF6?E>gD[LC]e:g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e:g6:GGYIR
UejF0P00089>g4ZlC]e:_5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Qoo`03001oogoo00moo`03001oogoo00=oo`00?7oo
00<007ooOol0;Woo0TJm00i6gDJlJ]IZeF[FJ[D<]4JLBG55LDUaAG59LDEa0TUa00E9LTUaBG5:_4[M
009:_09:g@04B]abdg;CL]@3L]<03P0?@Ya6W4JLC]e:g4kMB]`bOBiMI[MV]VJgI[H2:KT04RfiC]a>
g4kLC]e>g4kMC]a>gCZMK]IZeFkFJ]E^eQTE7AHI5@9>g00:C_e>g4klC_aBoDkLC_e>g4kmC]`3B]d0
0ejFHYMRUP0400001TkMC]a>g4kLD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`<Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool003eoo`03
001oogoo02moo`0PA[a:gFZeK]IZ]FkF3;@@eDEaBG55DDUbAG59LTEaBI95LDVBAG4014ZlB]e:_4[M
B[a:gDJlL]A^/g;DK[=be0803`2`B[a>gDZlC]e:g4kMB]aVefJfI]MV]VKGAYa:_DJlB[a:g4kmC]a>
oD[LC_e:g4kmJ]E^eV[EK]HHm@`3AYa:_4JLD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MGYIR
UejF?S/j6Shk>QY>oDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoA5oo`03001oogoo00ioo`03001oogoo009oo`00?Woo00<007ooOol0;goo00Lf
OCJMJ[EZeV[EJ]H<]002AG400dUaAG59L@05BG402DVB00<00d[LB]e:g4[M?Yebe003L]<00g;DL]<0
3`0200l01DZlB]a:g4[MB[`00T[M00IV]fJfI[MV]P00A[`3B[`01DkLC]e>g4kMB]`00T[M00I^eV[E
K]IZeAdF6AD2A[`01TZlAYa>o4kLD_e>g09>o006D_e>g4kMC]a>oDkL0QWl00ERUejFHYLj>SXk008j
>P06C_aBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0E
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool003moo`03001oogoo02ioo`3:>YeZ]FkFJ[E^eVZe4=D<
]4UbAG59LDEaBI95LDVBAG59TTEa@Y`nNd:LB]a>gDZlC]e^/g;DK[=be6jcL]A2VdJL@Ya6W4[LC]e:
g4[MA[a:gFJfI]MV]VKG:IP]^D[LC]e:g4kMC]a>oDkLC_e:_4kMB]a^eV[EK]HI5AdF6?E>gD[LC]e:
g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_e:g6:GGYIRUejFHYM:_4kLB[a>gDkLD_e>g5;mC_aBoDkLD_e>
o5;mC_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`IOol00`00Oomoo`0=Ool00`00Oomoo`02Ool0041o
o`8002moo`0<J]IZeF[FJ[Eoo`bdAYa5LDUaAG59LDEa0TUa00E9LTUaBG99LD:L0092O09:g@09B]a:
gG;CL]Abdg;DL]<03d:L00=6W00=B]a>gDkLB]e:_4[MI[IV]fJfI[LY^BfiB]`00TkL00E>gDkLC]e>
g4kM008jW@07J]E^eV[EK]HM5AdF6AD00TkL00I>gDkLC_a>o5;mC]`2C_`00e;mC]a:g@02B]d014[L
HYMRUV:G0P0000M:_4[LB[a:_5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l7Goo
00<007ooOol037oo00<007ooOol00Woo0012Ool00`00Oomoo`0]Ool0`VkFJ[Eoogoo4=D<]4UaAG59
LTEaBI95LDVBAG59TTEaBI800d[MB[a:gDZlB]e6_7;DK[=be6jcL]@03dkMB[a>gDZlC]e:g4kMB]`b
OBiLI]MV]VKGI[H]^BVH;KU:g4kmC]a>oD[LC_e:g4kmJ]E^eV[EK]IZeDZlAYa:_4JLD_e>g4kmC]aB
oDkLD_e>g5;mC]aBoDkLB]e6_4[MGYIRUejF?S/j6ShkC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`QOol00`00Oomoo`0;Ool00`00Oomoo`02Ool004=oo`03001oogoo031oo`053;@@
e4EaBG55L@06BG401DVBBG401003B]d00TZl0T[M00E:g7;DL]=be7;C00803`0<B]e:_4[LB]a>gD[L
C]e:g6JgI[IV]fJf0P000dZl0dkL00=>gD[LB]d00T[M00EZeFkFJ]E^eQTE0096_006B[a6W4klC]aB
oDkL0Tkl00IBoDkLC_e>g4kmC]`3B]d015jFHYMRUSXk0SXj00I>g4kMC]a>g5;lD_d3D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`X
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool004Aoo`03001oogoo031oo`2b3;A9LTEaBG95LDVBAG59
TTEaBI99LDVB?W]2W49kC]e:_4kM>Yebe6jcL]A^/g;D00l0<00?C]e:g4kMB]a:gDJlB]eV]VKGI[IV
ebVh;KTYV4ZmA[a:_4kLC_e>g4kmB[a>gD[LK]IZeFkFJ]DM5QSeC]e:g4kMB]aBoDkLD_e>g5;mC]aB
oDkLC_e>g4kmB]`Io5jFHYMNUV:G>QXn>cXJ?S]>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d]Ool00`00Oomoo`0;Ool00`00
Oomoo`01Ool004Eoo`80031oo`03AYa2W4Ua0099L@08AG59LDUaBI99LDUbBG52W0=2O00:B]e:g4[M
L]=be7;CL]Abdg;D@Y`2AY`03TkMB]a>gDkLB]e:_4[MI[IV]fJfI[LY^Bfi:KP2C]`01TkMC]a>gDkL
C]e:g09:g@06K]IZeFkFJ]DM5QTE0TkL00I>gDkLC_a>o5;mC]`2C_`02E;mC]a>gDkLC_eNUV:GHYIR
U`0200001dZlB]a:_4ZlC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00U;l<Goo00<007ooOol02Woo00<007ooOol00Goo0017Ool00`00Oomo
o`0^Ool0C4JlAG59TTEaBI95LDVBAG59TTEaBI99LD[MB[a:gDZlB]e6_4[MK[=be6jcL]A^/`0`@Y]6
W4:LC]e:g4kMB]`bOBiLI]MV]VKGI[H]^BVh;KU:g4kMB]a>gD[LC_e:g4km>W`nWF[EK]IZ]FkF6ADM
5QSeD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MGYIRUejF0`0005a:_4kLB[aBoDkLD_e>g5;m
D_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m=Goo00<007ooOol0
2Goo00<007ooOol00Goo0018Ool00`00Oomoo`0^Ool01DUaAG59LDUaBG800dUa00E9TTUaBI8014[M
00=:_00:B]e:g4[ML]=be7;CL]@03`0@B[`2B]`02TkMB]a>gD[LI[MV]VJgI[IV]dJl0dZl0dkL00i>
gDkLC]e>g4kMJ]E^eV[EK]HM5@`3A[a:_4JL0TkL00Y>oDkLC_a>o5;mC]a>oDkLC_e>g09:g@05HYMN
UV:GHYHj>`02>SX01TkLC]e>g4kLD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;l
D_aBoE;l>Goo00<007ooOol02Goo00<007ooOol00Goo0019Ool00`00Oomoo`0]Ool0XdEaBG95LDVB
AG59TTEaBI99LDVBAG401003C]e:_4kMB]`nWFjcL]A^/g;DK[<0<00?031:_4kMB[a:gDJlB]e6_6KG
I[IVefJf0016W4ZmA[a:_4kLC_e>g4kmB[a>gD[LK]IZ]FkFJ]DM5QTEB[a6W4ZlAYaBoDkLD_e>g5;m
C]aBoDkLC_e>g4kmB]a:gDJlHYMNUV:G>QXn>cXJ?S]>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l03eoo`03001oogoo00Qoo`03001oogoo005oo`00BWoo0P00;Goo0dUa
00Q5LDUaBG59TTUaBG99LDVB0d9l00Y:gD[LB]e:g7;DL]=be7;CL]@03`=6W00=B]a>gDkLB]e:_4[M
I[IV]fJfI[LY^BfiB]`00TkL00I>gDkLC]e>g4kMB]`2B]d01VkFJ]EZeQdE7AHM5@9>g006C]e>g4kl
C]aBoDkL0Tkl00eBoDkLC]e>g4kmC]aRUf:FHYMNUV:GB[a>g002B[`00dklD_e>g002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mD_aoo`10Ool00`00Oomoo`07Ool00`00Oomoo`01Ool004aoo`03
001oogoo02]oo`1;BI95LDVBAG59TTEaBI95LDVBBG59TSik@Ya2Nd[MA[a:gDZlL]A^/g;DK[<4<4:K
AYa2W4JLB]a>gD[LB]e6_4[MI[IVefJfI]LY^2fiB]a>gD[LC]e:g4kmB]a>oCYm?YeZeFkFJ[E^eQTE
7AHI5DkMB]a>gDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gEjFHYMNUV:G0080001>B[a>g4ZlC]e>g5;m
C]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mAWoo00<007ooOol01Woo00<007ooOol00Goo001=Ool00`00
Oomoo`0ZOol014EaBG59LDUb0dUa00E9TTUaBI99T@0400=:_00:B]e:g4[ML]=be6kCL]Abd`0`B[`2
B]`03D[MB]a>gD[L;Wd^GFJgI[IV]fJf;KTY^Bfi00=>g00:C]e>g4kMC]a>gF[EJ]IZeFkFJ]D2A[`0
1TZlAYa>g4kLC_e>g09>o006D_e>g4kmC]a>oDkL0d[M00ENUV:GHYHj>cXj009>g006C]e>g4kLD_aB
oDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`00e;mOomoo`17Ool00`00Oomoo`07Ool10001Ool1Ool004ioo`03001oogoo
02Uoo`0;BG95LDVBAG59TTEaBI99LDVBAG59TP0200@05dZlB]e:_4[MA[a:gFjcL]A^/g;D00l4<4Zl
C]e:_4kMB]a>gD[LI]MV]VKGI[H00P0006m:_DJlB[a:g4kmC]a>oDZlC]e:g4[MJ[E^eV[EK]HI5DZl
AYa:_4JLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJlB]e6_6:GGYIRUcXJ?S/j6U;mC]a>oDkLD_e>g5;m
C]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_d0CGoo00<007ooOol01Woo0@000Goo0Goo001?Ool2000YOol5BG401TVBBG59TTUaBI99
L@92O00B@Ya:g4[MB]`nWFkCL]Abdg;DK]<0;`0?031:g4kMC]a>gDZl0T[M00IV]fJfI[MV]Rfi:KP3
B[`01DkLC]e>g4kMB]`00T[M00I^eV[EJ]IZeAdF7AD2C]`01TkMC]a>o4kLD_e>g09>o00BD_e>g4kM
C]a>oAGl6OaRUV:GGYIRUcXj>S/j>U;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_aBOol00`00Oomoo`05Ool10001Ool1Ool0
055oo`03001oogoo02Moo`1:AG59TTEaBI99LDVBAG59TTUaBI99LD:L@W]2W4ZlC]e:g7;DK[=be6jc
L]@03dJL@Ya6W4[LC]e:g4kMA[a:gFJfI]MR]VKG:KP]^BVHC]e:g4kMB[a>oDkLC_e:_4kMB]a^eVZe
K]IZeAdF6AE>gD[LC]e:g5;mC]aBoDkLD_e>g5;mC]a>oDkLC_eNUV:GGYIRU`800011B[a>g4ZlC]e>
g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o01EOol00`00Oomoo`05Ool10001Ool1Ool0059oo`03001oogoo02Ioo`99L@06BG99LDUbBG59TTUa
0dVB00D014ZlB[a:gD[L009:g@06L]A^dg;DL]=be00?0dJL00A:g4kMB]a>g@8^G@07I[IV]fJfI[LY
^Bfi:KP00TkL00i>gDkLC]e>g4kM>YeZeV[EK]IZeF[F7ADM5QdE0TkL00Y>oDkLC_a>o5;mC]a>oDkL
C_e>g0=:g@04GYIRUf:F>S/2>SX01dkLC]e>g4kLD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_aIOol00`00Oomoo`04Ool10001Ool1Ool005=oo`03001o
ogoo02Eoo`0;AG59TTEaBI95LDVBBG59TTEaBI99L@0200@05d[MB[a:gDJlB]e:_7;DK[=be6jc1300
3dkMB[a>gDZlC]e:g4kMH[IVefJfI[L00P000656_4ZlAYa>oDkLC_e:g4kmB]a>oFZeK]IZeFkF6AD@
14JLB[a6W4ZlC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4[MA[aRUejFHYMNUShk>QXn>dkLC_e>g5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo01MOol00`00Oomoo`03Ool1
0001Ool1Ool005Aoo`03001oogoo02Aoo`A9L@0JBI99LDVBBI59TTUaBI92O4:L@Wa:gD[LB]dnWG;D
L]=be6kCL]@0;`@`00m>gDkLC]e:g09:g@06I[MV]VJgI[H]^BVh0dZl00E6_4kMC]a>gDkL00=:g@05
J]EZeV[E7AHM5@02C]`01TkMC]a>g4kLD_e>g09>o00BD_e>g4kMC]a>oDkL6OaRUV:GGYIRUcXj>S/j
>U;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lHWoo00<007ooOol0
0goo0@000Goo001EOol2000UOol0BDVBAG59TTUaBI95LDVBBG59TWoo@Ya2Nd:LB[a>gD[LC]e^/g;D
K[=be6jc1312W4JL@Y]>gD[LC]e6_4[MA[aV]f:fI]LY^2fi:IQ>gD[LC]e:_4kmC]a>oDZlC]e:g6kF
J[E^eV[E7AHI5DkMB]a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmC]a>oEifHYMNUV:G0080000dB[a>g4Zl
D_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eUOol00`00Oomoo`03Ool10001Ool0
05Moo`03001oogoo029oo`07BG59TTUaBG99LDVBBG400TVB00IoodZlB[a:_4[MB]`3B]d01FkCL]Ab
dg;D02l00dJL00A:g4kMB]a>g@8^G@04I[IV]fJfI[L2;KT022VhC]a>g4kMC]a>gDkLC]d2>Yd01f[E
K]IZeF[F7ADM5QdE009>g00:C_e>g4klC_aBoDkLC_e>g4kmC]`3B]d00ejFHYMRUP0300000dZlC]a:
_002D_`01E;mC_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l06Uoo`03001oogoo009oo`40005oo`00F7oo
00<007ooOol08Goo00U9TTEaBI95LDVBBG59TTUaBI800Woo06Y:_4[MB[a:gDJlB]e:_7;DK[=be6jc
13003dkMB[a>gD[LC]e:g4kMH[IVefJfI[MR]TZmA[a:_4JLC_e>g4kmB]a>oD[LC_eZ]FkFJ]E^eVZe
7CI6W4ZlAYaBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a:gDJlHYMNMV:GGYHn>cXJ?S]>g4kmC]aBoDkL
D_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoG5oo`05001oogooOol00001Ool005Uoo`03001oogoo021oo`=9L@06BI99LDVBBI59
TTUa0goo00Y:g4[MB]a:gCjML]Abdg;DK]=be084<00502m:g4[LB]e:_003B]d01FJfI[MV]VJg0000
0dZl00E6_4kMC]a>gDkL00=:g@0=J]EZeV[EK]HM5AdFA[a:_4JLC_a>g5;mC]`00Tkl00IBoDkLC]e>
g4kmC]`2B]d01F:GGYIRUcXj>S/00SXj00=>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo7Eoo`04001oogoo0001Ool005Yo
o`80021oo`09BI95LDVBBG59TTEaBI99LDVB00Aoo`1RB[a>gD[LC]e^/g;DK[=be6jcL]A2W4JL@Y]>
gD[LC]e6_4[MA[aV]f:fI]MV]Rfi:IQ>gD[LC]e:_4kmC]a>oDkLC]e:g4[MJ[E^eV[EK]HM5AdfB]a>
gD[LC]e>g5;mC]aBoDkLD_e>g4kmC]a>oD[LHYMNUV:GGWIRUdZlC]a:_4kMC]aBoDkLD_e>o5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7GQoo`04001oogoo
0001Ool005aoo`03001oogoo01ioo`06BI99LDUbBG59TTUa0TVB1Goo00E:g4[MB]e:gFkC00=be003
K[=6W4JL0096W004C]e>g4kMB[`2B]d01VJgI[IV]fJf;KTY^09>g006C]e:g4kMC]a>gDkL0SZM00U^
eV[EJ]IZeAdF7ADM5TkLC_d00TkL00=>o5;mC]`00Tkl00=BoDkLB]d00T[M00ANUV:GHYIRU`800003
B[a>g4Zl009Bo005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003
D_eBo5;l07aoo`03001oo`00005oo`00GGoo00<007ooOol07Goo00M5LDVBAG59TTUaBI99L@08Ool0
FD[MB[a:gFjcL]A^/g;D00m>gDZlC]e:_4kMB]a>gD[LI]MV]VJgH[IVebVh;KTYV4kmC]a>oD[LC_e:
g4kmB]a^eV[EK]IZ]B4fAYa:_4JLB[a>g4kmC]aBoDkLD_e>g5;mC]aBoDkLB]e6_4[MGWIRUejF?S/j
6U;mC]a>oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDad0
P7oo0@000Goo0@00001NOol00`00Oomoo`0LOol2BG401DVBBG59TTVABI802Goo00@nWG;DL]A^/`9b
e0061304;`@`B]a:gDZl0d[M00I:_6JgI[IV]bVh0002B[`01DJlB[a>g4kMC]`00d[M00eZeF[FJ]E^
eQdE40A6_4ZlAYa>o4kLD_e>g002C_`01U;mC]a>gDkLC_e>g09:g@05HYMNUV:G>SXj>`02>SX00dkL
C]e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Aoo`800000Ggoo
0P0077oo00M5LDVBBG59TTEaBI99L@0:Ool0D7;DK[=be6jcL]A2W4JL@Y]6W4[LC]e:g4[MA[a:gF:f
I]MV]VJg:IP]^D[LC]e:_4kMC]a>oDkLC]e:g4[MJ[E^eVZe7CHM5DkMB]a>gD[LD_e>g5;mC]aBoDkL
D_e>g4kmC]a>oD[LHYMNUV:GGWIRUdZlC]a:_4kMC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;l
D_eBo5;mD_b8Ool20000065oo`03001oogoo01Yoo`06BG59TTUaBI99LDVB2goo0g;D00=oo`@`AY`0
0dJL00=>g4kMB]`00d[M00eV]VJgI[H]^BVh;KU>g4kMB]a>gDkLC]e>g002>Yd02VkFJ]EZeV[E7AHM
5AdFC]a>gDkL0Tkl00IBoDkLC_a>o5;mC]`3B]d014[LHYMRUV:G0P0000M:_4kLB[a:_5;lD_e>o002
D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0RWoo0P00001ROol00`00Oomoo`0IOol01TVBAG59TTUa
BI99L@]oo`03K[=be7oo009oo`14131:_4kMB[a>gD[LC]e:g39m;UeV]f:fI]LY^2fi:IQ>oDkLC_e:
g4kmB]a>oD[LK]IZ]FkFJ[E^eTJLB[a6W4ZlC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4[MA[a:gEifHYMN
UShk>QXn>dkLC_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o8Yoo`@0009oo`00Hgoo00<007ooOol0
67oo00=9LDVBBG400dVB47oo0P@`00=:g4[MB[`00T[L00M>gD[LI[MV]VJgI[H00002B[`01DJlB[a>
g4kMC]`00d[M00e:g6[FJ]E^eV[E7AI6_4ZlAYa6_4kLD_e>g002C_`01U;mC]a>o4kLC_e>g0=:g@04
GYIRUcXj?S/2>SX00dkLC]e>g002D_`01U;mD_aBo5;lD_eBo8Uoo`@000Ioo`00I7oo0P0067oo00I9
TTUaBI95LDVBBG4@Ool0>`@`02l4<4[LC]e:g4kMA[a:gDJlI]MV]VJg:KP]^D[LC]e:_4kMC]a>oDkL
C]e:g4[MJ[E^eVZeK]HM5B4fB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[L6OaNUV:GGWIRUdZl
C]a:_4kMC]aBoDkLD_d0Rgoo10002Woo001VOol00`00Oomoo`0FOol014VBBI59TTUa4Woo0dJL00=>
g4kMB]`00d[M00UV]VJgI[IV]bfh;KU>g4kMB]`00TkL00=>gDkLB]d00T[M00QZeF[FJ]EZeQdE7AHM
5DkM0TkL00=>o5;mC]`00Tkl00UBoDkLC]e>g4kmGYIRUf:FHYL00P0000A:_4kLB[a:_8Yoo`@000io
o`00Igoo00<007ooOol05Goo00A5LDVBBG59TQ9oo`0aB[a>gDZlC]e:g4kMB]`bOBiMI[MR]VKGI[H]
^BVh;KU>g4kmB]a>oD[LC_e:g4kmJ[E^eVZeK]IZ]DZlAYa:_4JLC_e>g5;mC]aBoDkLD_e>g5;mC]a:
gDJlB]eNMV:GGYH0SGoo0`004Woo001XOol00`00Oomoo`0DOol014VBBG59TTVB4goo00=:g4[MB[`0
0T[L00Y>gD[LI[MV]VJgI[IV]`00B[a6_09:_003C]e>g4kL009:g@0=B]aZeV[EJ]IZeAdF50E:_4JL
B[a>g5;mC]`00Tkl00IBoDkLC_a>g4kmC]`2B]d00f:GGYIoo`29Ool4000EOol006Uoo`8001Aoo`04
BG59TTUaBI8DOol0;D[LC]e:g4kMA[a:gDJlI]MV]VJgH[H]^BVhC]e:_4kMB]a>oDkLC_e:g4[MB[a^
eVZeK]HM5B4fB]a>gD[LC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[L6O`Eg027Ool4000IOol006]oo`03
001oogoo015oo`04BI99TDVBBG4FOol00dkMB]a>g@02B]d01DJlI[MV]VJgI[H00Rfi00I>gD[LC]a>
g4kMC]`3B]d01f[EJ]IZeF[F7ADM5QdE00=>g003C_aBoDkL009>o006D_e>g4klC]a>oDkLQ7oo1000
7Goo001/Ool00`00Oomoo`0AOol00dVBBG59TP0GOol08dkMB]a>gBiM;WeR]VKGI[IV]bVh;KTY^4km
B]a>oD[LC_e:g4kmJ[E^eVZeK]IZ]DZlAYa:_4JLC_e>g5;mC]aBoDkLD_d0QWoo10008Goo001]Ool0
0`00Oomoo`0@Ool00dUaBI99TP0HOol01dkMB]a>gFJfI[MV]VJg00800004A[a:_4ZlC]d2C]`2B]d0
1D[LB]eZeF[FJ]D00Woo00A:_4JLB[a6_8Uoo`<002Eoo`00KWoo00<007ooOol03goo00=9TTUaOol0
6Goo01A:gDJlB]eV]VJgH[H]^BVhC]e:_4kMB]a>oDkLC_e:g4[MB[a^eVZeS7oo1000:7oo001_Ool2
000?Ool00dVABI9oo`0JOol01T[MA[a:gFJfI[MV]P8]^@07C]e:g4kLC]a>gDkLC]d00T[M00=:g7oo
Ool0Qgoo1000;7oo001aOol00`00Oomoo`0=Ool00dUaOomoo`0JOol042imH[IV]fJfI[LY^2fi:KQ>
oD[LC_e>g4kmB]a>oD[LQWoo1000<7oo001bOol00`00Oomoo`0<Ool00dVBOomoo`0JOol016JfI[MV
]VJg0P0000A6_4ZlB[a:_0=>g8Eoo`@003Aoo`00Lgoo00<007ooOol02goo00=9LGooOol06goo00AV
]VJgOol008Uoo`@003Qoo`00M7oo0P002goo00=9TWooOol07Woo00<007ooOol0Q7oo0`00?7oo001f
Ool00`00Oomoo`0YOol00`00Oomoo`20Ool4000oOol007Moo`03001oogoo02Qoo`03001oogoo07ao
o`@004=oo`00N7oo00<007ooOol09goo00<007ooOol0N7oo1000Agoo001iOol2000WOol00`00Oomo
o`1dOol4001;Ool007]oo`03001oogoo02Aoo`03001oogoo075oo`<004moo`00O7oo00<007ooOol0
8goo00<007ooOol0KGoo1000DWoo001mOol00`00Oomoo`0ROol00`00Oomoo`1YOol4001FOol007io
o`80029oo`03001oogoo06Eoo`@005Yoo`00P7oo00<007ooOol07goo00<007ooOol0HGoo1000GWoo
0021Ool00`00Oomoo`0NOol00`00Oomoo`1NOol3001ROol0089oo`03001oogoo01eoo`03001oogoo
05Yoo`@006Eoo`00Pgoo00<007ooOol077oo00<007ooOol0EWoo1000JGoo0024Ool2000LOol00`00
Oomoo`1BOol4001]Ool008Ioo`03001oogoo01Uoo`03001oogoo04ioo`@0075oo`00Qgoo00<007oo
Ool067oo00<007ooOol0Bgoo0`00MGoo0028Ool00`00Oomoo`0GOol00`00Oomoo`17Ool4001hOol0
08Uoo`8001Moo`03001oogoo04=oo`@007aoo`00Rgoo00<007ooOol057oo00<007ooOol0?goo1000
P7oo002<Ool00`00Oomoo`0BOol00`00Oomoo`0lOol40024Ool008eoo`03001oogoo015oo`03001o
ogoo03Uoo`<008Qoo`00SWoo0P004Goo00<007ooOol0=Goo1000Rgoo002@Ool00`00Oomoo`0>Ool0
0`00Oomoo`0aOol4002?Ool0095oo`03001oogoo00eoo`03001oogoo02eoo`@009=oo`00TWoo00<0
07ooOol037oo00<007ooOol0:Goo1000Ugoo002COol2000<Ool00`00Oomoo`0UOol4002KOol009Eo
o`03001oogoo00Uoo`03001oogoo029oo`<009moo`00UWoo00<007ooOol027oo00<007ooOol07Woo
1000XWoo002GOol00`00Oomoo`07Ool00`00Oomoo`0JOol4002VOol009Qoo`03001oogoo00Ioo`03
001oogoo01Ioo`@00:Yoo`00VGoo0P001Woo00<007ooOol04Woo1000[Woo002KOol00`00Oomoo`03
Ool00`00Oomoo`0?Ool3002bOol009aoo`03001oogoo009oo`03001oogoo00]oo`@00;Eoo`00WGoo
00D007ooOomoo`0000Uoo`@00;Uoo`00WWoo0P0000=oo`00Ool017oo1000_Goo002POol200000goo
000000020031Ool00:5oo`800<Eoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.517 .676 .936 r
.39632 .69825 .40163 .70363 .41329 .61699 .40518 .69837 Mtetra
.532 .309 .521 r
.40518 .69837 .41329 .61699 .4196 .69579 .41436 .68941 Mtetra
.555 .654 .901 r
.41436 .68941 .4196 .69579 .42855 .69434 .42329 .68922 Mtetra
.623 .726 .92 r
.42329 .68922 .42855 .69434 .43754 .69246 .4323 .68742 Mtetra
.624 .729 .922 r
.4323 .68742 .43754 .69246 .44656 .69092 .44134 .68558 Mtetra
.55 .692 .933 r
.44134 .68558 .44656 .69092 .45509 .71617 .45039 .68514 Mtetra
.659 .493 .649 r
.45039 .68514 .45509 .71617 .4648 .6828 .45964 .67596 Mtetra
.541 .634 .892 r
.45964 .67596 .4648 .6828 .47391 .6813 .46874 .67614 Mtetra
.629 .729 .919 r
.46874 .67614 .47391 .6813 .48307 .67918 .47791 .67418 Mtetra
.64 .739 .92 r
.47791 .67418 .48307 .67918 .49226 .67695 .48713 .67196 Mtetra
.64 .74 .921 r
.48713 .67196 .49226 .67695 .50148 .6748 .49637 .66972 Mtetra
.629 .733 .923 r
.49637 .66972 .50148 .6748 .51074 .67329 .50565 .66772 Mtetra
.486 .659 .937 r
.50565 .66772 .51074 .67329 .52006 .65426 .51495 .66833 Mtetra
.218 0 .218 r
.51495 .66833 .52006 .65426 .52936 .66476 .5243 .65864 Mtetra
.586 .68 .906 r
.5243 .65864 .52936 .66476 .53871 .66286 .53367 .65772 Mtetra
.639 .736 .919 r
.53367 .65772 .53871 .66286 .54809 .66047 .54308 .65546 Mtetra
.649 .745 .92 r
.54308 .65546 .54809 .66047 .55751 .65792 .55251 .65296 Mtetra
.653 .749 .92 r
.55251 .65296 .55751 .65792 .56695 .65529 .56198 .65034 Mtetra
.656 .751 .92 r
.56198 .65034 .56695 .65529 .57643 .6526 .57148 .64765 Mtetra
.657 .753 .92 r
.57148 .64765 .57643 .6526 .58594 .64986 .58102 .64492 Mtetra
.658 .753 .92 r
.58102 .64492 .58594 .64986 .59549 .6471 .59058 .64214 Mtetra
.659 .754 .92 r
.59058 .64214 .59549 .6471 .60506 .64432 .60018 .63935 Mtetra
.60018 .63935 .60506 .64432 .61467 .64153 .60981 .63654 Mtetra
.60981 .63654 .61467 .64153 .62431 .63874 .61947 .63373 Mtetra
.658 .754 .92 r
.61947 .63373 .62431 .63874 .63399 .63595 .62917 .63092 Mtetra
.658 .753 .92 r
.62917 .63092 .63399 .63595 .64369 .63315 .6389 .6281 Mtetra
.6389 .6281 .64369 .63315 .65343 .63035 .64867 .62528 Mtetra
.64867 .62528 .65343 .63035 .66321 .62755 .65846 .62245 Mtetra
.65846 .62245 .66321 .62755 .67302 .62473 .6683 .61962 Mtetra
.6683 .61962 .67302 .62473 .68286 .62191 .67816 .61678 Mtetra
.67816 .61678 .68286 .62191 .69274 .61908 .68806 .61393 Mtetra
.657 .753 .92 r
.68806 .61393 .69274 .61908 .70265 .61625 .698 .61108 Mtetra
.698 .61108 .70265 .61625 .71259 .6134 .70797 .60821 Mtetra
.70797 .60821 .71259 .6134 .72257 .61055 .71797 .60534 Mtetra
.71797 .60534 .72257 .61055 .73259 .60769 .72801 .60246 Mtetra
.657 .752 .92 r
.72801 .60246 .73259 .60769 .74264 .60482 .73809 .59957 Mtetra
.73809 .59957 .74264 .60482 .75273 .60194 .7482 .59667 Mtetra
.7482 .59667 .75273 .60194 .76285 .59905 .75834 .59376 Mtetra
.75834 .59376 .76285 .59905 .773 .59615 .76853 .59085 Mtetra
.76853 .59085 .773 .59615 .7832 .59324 .77875 .58792 Mtetra
.77875 .58792 .7832 .59324 .79343 .59032 .789 .58498 Mtetra
.789 .58498 .79343 .59032 .80369 .5874 .79929 .58204 Mtetra
.79929 .58204 .80369 .5874 .81399 .58446 .80962 .57908 Mtetra
.80962 .57908 .81399 .58446 .82433 .58151 .81999 .57611 Mtetra
.81999 .57611 .82433 .58151 .83471 .57856 .83039 .57314 Mtetra
.83039 .57314 .83471 .57856 .84512 .57559 .84083 .57015 Mtetra
.84083 .57015 .84512 .57559 .85557 .57261 .8513 .56715 Mtetra
.8513 .56715 .85557 .57261 .86606 .56963 .86182 .56415 Mtetra
.86182 .56415 .86606 .56963 .87658 .56663 .87237 .56113 Mtetra
.87237 .56113 .87658 .56663 .88715 .56362 .88296 .5581 Mtetra
.88296 .5581 .88715 .56362 .89775 .5606 .89359 .55506 Mtetra
.89359 .55506 .89775 .5606 .90839 .55757 .90426 .55201 Mtetra
.90426 .55201 .90839 .55757 .91906 .55454 .91496 .54896 Mtetra
.91496 .54896 .91906 .55454 .92978 .55149 .92571 .54588 Mtetra
.92571 .54588 .92978 .55149 .94053 .54843 .93649 .5428 Mtetra
.93649 .5428 .94053 .54843 .95133 .54535 .94732 .53971 Mtetra
.94732 .53971 .95133 .54535 .96216 .54227 .95818 .53661 Mtetra
.95818 .53661 .96216 .54227 .97304 .53918 .96908 .53349 Mtetra
.96908 .53349 .97304 .53918 .98395 .53608 .98003 .53037 Mtetra
.599 .716 .926 r
.39098 .69308 .39632 .69825 .40518 .69837 .3999 .69176 Mtetra
.923 .7 .583 r
.3999 .69176 .40518 .69837 .41436 .68941 .41168 .60472 Mtetra
0 0 .431 r
.41168 .60472 .41436 .68941 .42329 .68922 .418 .68383 Mtetra
.609 .711 .917 r
.418 .68383 .42329 .68922 .4323 .68742 .42702 .68234 Mtetra
.627 .73 .921 r
.42702 .68234 .4323 .68742 .44134 .68558 .43608 .68042 Mtetra
.61 .722 .925 r
.43608 .68042 .44134 .68558 .45039 .68514 .44517 .67885 Mtetra
.926 .538 .191 r
.44517 .67885 .45039 .68514 .45964 .67596 .45375 .70419 Mtetra
0 0 .123 r
.45375 .70419 .45964 .67596 .46874 .67614 .46355 .67064 Mtetra
.611 .71 .916 r
.46355 .67064 .46874 .67614 .47791 .67418 .47273 .6691 Mtetra
.636 .736 .92 r
.47273 .6691 .47791 .67418 .48713 .67196 .48196 .66694 Mtetra
.641 .74 .921 r
.48196 .66694 .48713 .67196 .49637 .66972 .49122 .66467 Mtetra
.637 .738 .922 r
.49122 .66467 .49637 .66972 .50565 .66772 .50052 .66248 Mtetra
.606 .721 .926 r
.50052 .66248 .50565 .66772 .51495 .66833 .50985 .66094 Mtetra
.862 .719 .703 r
.50985 .66094 .51495 .66833 .5243 .65864 .51924 .64179 Mtetra
.284 .308 .71 r
.51924 .64179 .5243 .65864 .53367 .65772 .52861 .65231 Mtetra
.626 .723 .917 r
.52861 .65231 .53367 .65772 .54308 .65546 .53803 .65037 Mtetra
.645 .742 .92 r
.53803 .65037 .54308 .65546 .55251 .65296 .54749 .64794 Mtetra
.652 .747 .92 r
.54749 .64794 .55251 .65296 .56198 .65034 .55698 .64535 Mtetra
.655 .75 .92 r
.55698 .64535 .56198 .65034 .57148 .64765 .5665 .64267 Mtetra
.657 .752 .92 r
.5665 .64267 .57148 .64765 .58102 .64492 .57606 .63993 Mtetra
.658 .753 .92 r
.57606 .63993 .58102 .64492 .59058 .64214 .58565 .63715 Mtetra
.659 .754 .92 r
.58565 .63715 .59058 .64214 .60018 .63935 .59527 .63435 Mtetra
.59527 .63435 .60018 .63935 .60981 .63654 .60492 .63152 Mtetra
.60492 .63152 .60981 .63654 .61947 .63373 .61461 .62869 Mtetra
.61461 .62869 .61947 .63373 .62917 .63092 .62433 .62586 Mtetra
.658 .753 .92 r
.62433 .62586 .62917 .63092 .6389 .6281 .63408 .62302 Mtetra
.63408 .62302 .6389 .6281 .64867 .62528 .64387 .62018 Mtetra
.64387 .62018 .64867 .62528 .65846 .62245 .65369 .61733 Mtetra
.65369 .61733 .65846 .62245 .6683 .61962 .66354 .61448 Mtetra
.66354 .61448 .6683 .61962 .67816 .61678 .67343 .61162 Mtetra
.67343 .61162 .67816 .61678 .68806 .61393 .68336 .60875 Mtetra
.657 .753 .92 r
.68336 .60875 .68806 .61393 .698 .61108 .69332 .60588 Mtetra
.69332 .60588 .698 .61108 .70797 .60821 .70331 .60299 Mtetra
.70331 .60299 .70797 .60821 .71797 .60534 .71334 .6001 Mtetra
.71334 .6001 .71797 .60534 .72801 .60246 .7234 .5972 Mtetra
.7234 .5972 .72801 .60246 .73809 .59957 .7335 .59429 Mtetra
.657 .752 .92 r
.7335 .59429 .73809 .59957 .7482 .59667 .74364 .59137 Mtetra
.74364 .59137 .7482 .59667 .75834 .59376 .75381 .58845 Mtetra
.75381 .58845 .75834 .59376 .76853 .59085 .76402 .58551 Mtetra
.76402 .58551 .76853 .59085 .77875 .58792 .77426 .58256 Mtetra
.77426 .58256 .77875 .58792 .789 .58498 .78455 .57961 Mtetra
.78455 .57961 .789 .58498 .79929 .58204 .79486 .57664 Mtetra
.79486 .57664 .79929 .58204 .80962 .57908 .80522 .57366 Mtetra
.80522 .57366 .80962 .57908 .81999 .57611 .81561 .57068 Mtetra
.81561 .57068 .81999 .57611 .83039 .57314 .82604 .56768 Mtetra
.82604 .56768 .83039 .57314 .84083 .57015 .8365 .56468 Mtetra
.8365 .56468 .84083 .57015 .8513 .56715 .84701 .56166 Mtetra
.84701 .56166 .8513 .56715 .86182 .56415 .85755 .55863 Mtetra
.85755 .55863 .86182 .56415 .87237 .56113 .86813 .55559 Mtetra
.86813 .55559 .87237 .56113 .88296 .5581 .87875 .55255 Mtetra
.87875 .55255 .88296 .5581 .89359 .55506 .88941 .54949 Mtetra
.88941 .54949 .89359 .55506 .90426 .55201 .9001 .54642 Mtetra
.9001 .54642 .90426 .55201 .91496 .54896 .91084 .54334 Mtetra
.91084 .54334 .91496 .54896 .92571 .54588 .92161 .54025 Mtetra
.92161 .54025 .92571 .54588 .93649 .5428 .93242 .53714 Mtetra
.93242 .53714 .93649 .5428 .94732 .53971 .94328 .53403 Mtetra
.94328 .53403 .94732 .53971 .95818 .53661 .95417 .53091 Mtetra
.95417 .53091 .95818 .53661 .96908 .53349 .9651 .52777 Mtetra
.9651 .52777 .96908 .53349 .98003 .53037 .97608 .52463 Mtetra
.614 .723 .923 r
.3856 .68794 .39098 .69308 .3999 .69176 .39455 .6863 Mtetra
.517 .676 .936 r
.39455 .6863 .3999 .69176 .41168 .60472 .40347 .68639 Mtetra
.53 .305 .519 r
.40347 .68639 .41168 .60472 .418 .68383 .41272 .67737 Mtetra
.555 .654 .901 r
.41272 .67737 .418 .68383 .42702 .68234 .42171 .67715 Mtetra
.623 .726 .92 r
.42171 .67715 .42702 .68234 .43608 .68042 .43079 .67531 Mtetra
.624 .729 .922 r
.43079 .67531 .43608 .68042 .44517 .67885 .4399 .67343 Mtetra
.551 .692 .933 r
.4399 .67343 .44517 .67885 .45375 .70419 .44902 .67297 Mtetra
.658 .493 .648 r
.44902 .67297 .45375 .70419 .46355 .67064 .45835 .66371 Mtetra
.541 .634 .892 r
.45835 .66371 .46355 .67064 .47273 .6691 .46752 .66387 Mtetra
.629 .729 .919 r
.46752 .66387 .47273 .6691 .48196 .66694 .47676 .66186 Mtetra
.64 .739 .92 r
.47676 .66186 .48196 .66694 .49122 .66467 .48604 .6596 Mtetra
.64 .74 .921 r
.48604 .6596 .49122 .66467 .50052 .66248 .49536 .65732 Mtetra
.629 .733 .923 r
.49536 .65732 .50052 .66248 .50985 .66094 .50471 .65529 Mtetra
.487 .659 .937 r
.50471 .65529 .50985 .66094 .51924 .64179 .51408 .65587 Mtetra
.209 0 .209 r
.51408 .65587 .51924 .64179 .52861 .65231 .52351 .6461 Mtetra
.586 .68 .906 r
.52351 .6461 .52861 .65231 .53803 .65037 .53296 .64514 Mtetra
.639 .736 .919 r
.53296 .64514 .53803 .65037 .54749 .64794 .54244 .64285 Mtetra
.649 .745 .92 r
.54244 .64285 .54749 .64794 .55698 .64535 .55195 .6403 Mtetra
.653 .749 .92 r
.55195 .6403 .55698 .64535 .5665 .64267 .56149 .63764 Mtetra
.656 .751 .92 r
.56149 .63764 .5665 .64267 .57606 .63993 .57107 .63491 Mtetra
.657 .753 .92 r
.57107 .63491 .57606 .63993 .58565 .63715 .58068 .63213 Mtetra
.658 .753 .92 r
.58068 .63213 .58565 .63715 .59527 .63435 .59032 .62931 Mtetra
.659 .754 .92 r
.59032 .62931 .59527 .63435 .60492 .63152 .6 .62647 Mtetra
.6 .62647 .60492 .63152 .61461 .62869 .60971 .62362 Mtetra
.60971 .62362 .61461 .62869 .62433 .62586 .61945 .62076 Mtetra
.658 .754 .92 r
.61945 .62076 .62433 .62586 .63408 .62302 .62923 .6179 Mtetra
.658 .753 .92 r
.62923 .6179 .63408 .62302 .64387 .62018 .63904 .61504 Mtetra
.63904 .61504 .64387 .62018 .65369 .61733 .64888 .61217 Mtetra
.64888 .61217 .65369 .61733 .66354 .61448 .65876 .6093 Mtetra
.65876 .6093 .66354 .61448 .67343 .61162 .66867 .60642 Mtetra
.66867 .60642 .67343 .61162 .68336 .60875 .67862 .60354 Mtetra
.67862 .60354 .68336 .60875 .69332 .60588 .6886 .60064 Mtetra
.657 .753 .92 r
.6886 .60064 .69332 .60588 .70331 .60299 .69862 .59774 Mtetra
.69862 .59774 .70331 .60299 .71334 .6001 .70868 .59483 Mtetra
.70868 .59483 .71334 .6001 .7234 .5972 .71877 .59191 Mtetra
.71877 .59191 .7234 .5972 .7335 .59429 .72889 .58898 Mtetra
.657 .752 .92 r
.72889 .58898 .7335 .59429 .74364 .59137 .73905 .58604 Mtetra
.73905 .58604 .74364 .59137 .75381 .58845 .74925 .58309 Mtetra
.74925 .58309 .75381 .58845 .76402 .58551 .75948 .58014 Mtetra
.75948 .58014 .76402 .58551 .77426 .58256 .76975 .57717 Mtetra
.76975 .57717 .77426 .58256 .78455 .57961 .78006 .5742 Mtetra
.78006 .5742 .78455 .57961 .79486 .57664 .7904 .57121 Mtetra
.7904 .57121 .79486 .57664 .80522 .57366 .80079 .56821 Mtetra
.80079 .56821 .80522 .57366 .81561 .57068 .8112 .56521 Mtetra
.8112 .56521 .81561 .57068 .82604 .56768 .82166 .56219 Mtetra
.82166 .56219 .82604 .56768 .8365 .56468 .83215 .55916 Mtetra
.83215 .55916 .8365 .56468 .84701 .56166 .84268 .55613 Mtetra
.84268 .55613 .84701 .56166 .85755 .55863 .85325 .55308 Mtetra
.85325 .55308 .85755 .55863 .86813 .55559 .86386 .55002 Mtetra
.86386 .55002 .86813 .55559 .87875 .55255 .87451 .54695 Mtetra
.87451 .54695 .87875 .55255 .88941 .54949 .88519 .54387 Mtetra
.88519 .54387 .88941 .54949 .9001 .54642 .89592 .54078 Mtetra
.89592 .54078 .9001 .54642 .91084 .54334 .90668 .53768 Mtetra
.90668 .53768 .91084 .54334 .92161 .54025 .91748 .53457 Mtetra
.91748 .53457 .92161 .54025 .93242 .53714 .92833 .53145 Mtetra
.92833 .53145 .93242 .53714 .94328 .53403 .93921 .52831 Mtetra
.93921 .52831 .94328 .53403 .95417 .53091 .95013 .52517 Mtetra
.95013 .52517 .95417 .53091 .9651 .52777 .96109 .52201 Mtetra
.96109 .52201 .9651 .52777 .97608 .52463 .9721 .51884 Mtetra
.613 .719 .921 r
.3802 .68268 .3856 .68794 .39455 .6863 .38915 .68106 Mtetra
.599 .716 .926 r
.38915 .68106 .39455 .6863 .40347 .68639 .39814 .67971 Mtetra
.924 .7 .581 r
.39814 .67971 .40347 .68639 .41272 .67737 .41005 .59227 Mtetra
0 0 .428 r
.41005 .59227 .41272 .67737 .42171 .67715 .41638 .67168 Mtetra
.609 .711 .917 r
.41638 .67168 .42171 .67715 .43079 .67531 .42547 .67016 Mtetra
.627 .73 .921 r
.42547 .67016 .43079 .67531 .4399 .67343 .4346 .6682 Mtetra
.61 .722 .925 r
.4346 .6682 .4399 .67343 .44902 .67297 .44376 .66659 Mtetra
.925 .535 .184 r
.44376 .66659 .44902 .67297 .45835 .66371 .4524 .69201 Mtetra
0 0 .115 r
.4524 .69201 .45835 .66371 .46752 .66387 .46228 .65828 Mtetra
.611 .71 .916 r
.46228 .65828 .46752 .66387 .47676 .66186 .47153 .6567 Mtetra
.636 .736 .92 r
.47153 .6567 .47676 .66186 .48604 .6596 .48083 .6545 Mtetra
.641 .74 .921 r
.48083 .6545 .48604 .6596 .49536 .65732 .49017 .65219 Mtetra
.637 .738 .922 r
.49017 .65219 .49536 .65732 .50471 .65529 .49954 .64996 Mtetra
.607 .721 .926 r
.49954 .64996 .50471 .65529 .51408 .65587 .50894 .64838 Mtetra
.862 .719 .703 r
.50894 .64838 .51408 .65587 .52351 .6461 .51841 .62912 Mtetra
.282 .306 .71 r
.51841 .62912 .52351 .6461 .53296 .64514 .52785 .63965 Mtetra
.626 .723 .917 r
.52785 .63965 .53296 .64514 .54244 .64285 .53735 .63767 Mtetra
.645 .742 .92 r
.53735 .63767 .54244 .64285 .55195 .6403 .54688 .6352 Mtetra
.651 .748 .92 r
.54688 .6352 .55195 .6403 .56149 .63764 .55645 .63257 Mtetra
.655 .75 .92 r
.55645 .63257 .56149 .63764 .57107 .63491 .56605 .62984 Mtetra
.657 .752 .92 r
.56605 .62984 .57107 .63491 .58068 .63213 .57568 .62706 Mtetra
.658 .753 .92 r
.57568 .62706 .58068 .63213 .59032 .62931 .58535 .62424 Mtetra
.659 .754 .92 r
.58535 .62424 .59032 .62931 .6 .62647 .59504 .62138 Mtetra
.59504 .62138 .6 .62647 .60971 .62362 .60478 .61852 Mtetra
.60478 .61852 .60971 .62362 .61945 .62076 .61454 .61564 Mtetra
.61454 .61564 .61945 .62076 .62923 .6179 .62434 .61276 Mtetra
.658 .753 .92 r
.62434 .61276 .62923 .6179 .63904 .61504 .63417 .60987 Mtetra
.63417 .60987 .63904 .61504 .64888 .61217 .64404 .60699 Mtetra
.64404 .60699 .64888 .61217 .65876 .6093 .65394 .60409 Mtetra
.65394 .60409 .65876 .6093 .66867 .60642 .66388 .60119 Mtetra
.66388 .60119 .66867 .60642 .67862 .60354 .67385 .59829 Mtetra
.67385 .59829 .67862 .60354 .6886 .60064 .68386 .59537 Mtetra
.657 .753 .92 r
.68386 .59537 .6886 .60064 .69862 .59774 .69391 .59245 Mtetra
.69391 .59245 .69862 .59774 .70868 .59483 .70398 .58952 Mtetra
.70398 .58952 .70868 .59483 .71877 .59191 .7141 .58658 Mtetra
.7141 .58658 .71877 .59191 .72889 .58898 .72425 .58363 Mtetra
.72425 .58363 .72889 .58898 .73905 .58604 .73444 .58067 Mtetra
.657 .752 .92 r
.73444 .58067 .73905 .58604 .74925 .58309 .74466 .57771 Mtetra
.74466 .57771 .74925 .58309 .75948 .58014 .75492 .57473 Mtetra
.75492 .57473 .75948 .58014 .76975 .57717 .76521 .57174 Mtetra
.76521 .57174 .76975 .57717 .78006 .5742 .77555 .56875 Mtetra
.77555 .56875 .78006 .5742 .7904 .57121 .78592 .56574 Mtetra
.78592 .56574 .7904 .57121 .80079 .56821 .79632 .56273 Mtetra
.79632 .56273 .80079 .56821 .8112 .56521 .80677 .5597 Mtetra
.80677 .5597 .8112 .56521 .82166 .56219 .81725 .55666 Mtetra
.81725 .55666 .82166 .56219 .83215 .55916 .82777 .55361 Mtetra
.82777 .55361 .83215 .55916 .84268 .55613 .83833 .55056 Mtetra
.83833 .55056 .84268 .55613 .85325 .55308 .84893 .54749 Mtetra
.84893 .54749 .85325 .55308 .86386 .55002 .85956 .54441 Mtetra
.85956 .54441 .86386 .55002 .87451 .54695 .87024 .54132 Mtetra
.87024 .54132 .87451 .54695 .88519 .54387 .88095 .53822 Mtetra
.88095 .53822 .88519 .54387 .89592 .54078 .89171 .53511 Mtetra
.89171 .53511 .89592 .54078 .90668 .53768 .9025 .53199 Mtetra
.9025 .53199 .90668 .53768 .91748 .53457 .91333 .52885 Mtetra
.91333 .52885 .91748 .53457 .92833 .53145 .9242 .52571 Mtetra
.9242 .52571 .92833 .53145 .93921 .52831 .93511 .52255 Mtetra
.93511 .52255 .93921 .52831 .95013 .52517 .94607 .51939 Mtetra
.94607 .51939 .95013 .52517 .96109 .52201 .95706 .51621 Mtetra
.95706 .51621 .96109 .52201 .9721 .51884 .96809 .51302 Mtetra
.595 .7 .916 r
.37477 .67705 .3802 .68268 .38915 .68106 .38373 .67584 Mtetra
.614 .723 .923 r
.38373 .67584 .38915 .68106 .39814 .67971 .39274 .67417 Mtetra
.517 .676 .936 r
.39274 .67417 .39814 .67971 .41005 .59227 .40172 .67423 Mtetra
.527 .302 .516 r
.40172 .67423 .41005 .59227 .41638 .67168 .41105 .66514 Mtetra
.554 .654 .901 r
.41105 .66514 .41638 .67168 .42547 .67016 .42011 .66489 Mtetra
.623 .726 .92 r
.42011 .66489 .42547 .67016 .4346 .6682 .42926 .66301 Mtetra
.624 .729 .922 r
.42926 .66301 .4346 .6682 .44376 .66659 .43844 .66109 Mtetra
.551 .692 .933 r
.43844 .66109 .44376 .66659 .4524 .69201 .44763 .66059 Mtetra
.658 .492 .648 r
.44763 .66059 .4524 .69201 .46228 .65828 .45703 .65126 Mtetra
.54 .634 .893 r
.45703 .65126 .46228 .65828 .47153 .6567 .46627 .65139 Mtetra
.629 .729 .919 r
.46627 .65139 .47153 .6567 .48083 .6545 .47559 .64935 Mtetra
.639 .739 .92 r
.47559 .64935 .48083 .6545 .49017 .65219 .48494 .64705 Mtetra
.64 .74 .921 r
.48494 .64705 .49017 .65219 .49954 .64996 .49433 .64473 Mtetra
.629 .733 .923 r
.49433 .64473 .49954 .64996 .50894 .64838 .50375 .64265 Mtetra
.487 .659 .937 r
.50375 .64265 .50894 .64838 .51841 .62912 .5132 .6432 Mtetra
.2 0 .2 r
.5132 .6432 .51841 .62912 .52785 .63965 .52271 .63336 Mtetra
.586 .68 .906 r
.52271 .63336 .52785 .63965 .53735 .63767 .53223 .63236 Mtetra
.639 .736 .919 r
.53223 .63236 .53735 .63767 .54688 .6352 .54178 .63003 Mtetra
.649 .745 .92 r
.54178 .63003 .54688 .6352 .55645 .63257 .55137 .62744 Mtetra
.653 .749 .92 r
.55137 .62744 .55645 .63257 .56605 .62984 .56099 .62473 Mtetra
.656 .751 .92 r
.56099 .62473 .56605 .62984 .57568 .62706 .57065 .62196 Mtetra
.657 .753 .92 r
.57065 .62196 .57568 .62706 .58535 .62424 .58034 .61913 Mtetra
.658 .753 .92 r
.58034 .61913 .58535 .62424 .59504 .62138 .59006 .61626 Mtetra
.659 .754 .92 r
.59006 .61626 .59504 .62138 .60478 .61852 .59981 .61338 Mtetra
.59981 .61338 .60478 .61852 .61454 .61564 .6096 .61048 Mtetra
.6096 .61048 .61454 .61564 .62434 .61276 .61942 .60758 Mtetra
.658 .754 .92 r
.61942 .60758 .62434 .61276 .63417 .60987 .62928 .60468 Mtetra
.658 .753 .92 r
.62928 .60468 .63417 .60987 .64404 .60699 .63917 .60177 Mtetra
.63917 .60177 .64404 .60699 .65394 .60409 .6491 .59885 Mtetra
.6491 .59885 .65394 .60409 .66388 .60119 .65906 .59593 Mtetra
.65906 .59593 .66388 .60119 .67385 .59829 .66906 .59301 Mtetra
.66906 .59301 .67385 .59829 .68386 .59537 .67909 .59007 Mtetra
.67909 .59007 .68386 .59537 .69391 .59245 .68916 .58713 Mtetra
.657 .753 .92 r
.68916 .58713 .69391 .59245 .70398 .58952 .69926 .58418 Mtetra
.69926 .58418 .70398 .58952 .7141 .58658 .7094 .58122 Mtetra
.7094 .58122 .7141 .58658 .72425 .58363 .71957 .57825 Mtetra
.71957 .57825 .72425 .58363 .73444 .58067 .72979 .57527 Mtetra
.657 .752 .92 r
.72979 .57527 .73444 .58067 .74466 .57771 .74004 .57228 Mtetra
.74004 .57228 .74466 .57771 .75492 .57473 .75032 .56929 Mtetra
.75032 .56929 .75492 .57473 .76521 .57174 .76064 .56628 Mtetra
.76064 .56628 .76521 .57174 .77555 .56875 .771 .56326 Mtetra
.771 .56326 .77555 .56875 .78592 .56574 .7814 .56024 Mtetra
.7814 .56024 .78592 .56574 .79632 .56273 .79183 .5572 Mtetra
.79183 .5572 .79632 .56273 .80677 .5597 .8023 .55415 Mtetra
.8023 .55415 .80677 .5597 .81725 .55666 .81281 .5511 Mtetra
.81281 .5511 .81725 .55666 .82777 .55361 .82336 .54803 Mtetra
.82336 .54803 .82777 .55361 .83833 .55056 .83395 .54495 Mtetra
.83395 .54495 .83833 .55056 .84893 .54749 .84457 .54186 Mtetra
.84457 .54186 .84893 .54749 .85956 .54441 .85524 .53876 Mtetra
.85524 .53876 .85956 .54441 .87024 .54132 .86594 .53565 Mtetra
.86594 .53565 .87024 .54132 .88095 .53822 .87668 .53253 Mtetra
.87668 .53253 .88095 .53822 .89171 .53511 .88746 .5294 Mtetra
.88746 .5294 .89171 .53511 .9025 .53199 .89829 .52625 Mtetra
.89829 .52625 .9025 .53199 .91333 .52885 .90915 .5231 Mtetra
.90915 .5231 .91333 .52885 .9242 .52571 .92005 .51993 Mtetra
.92005 .51993 .9242 .52571 .93511 .52255 .93099 .51676 Mtetra
.93099 .51676 .93511 .52255 .94607 .51939 .94197 .51357 Mtetra
.94197 .51357 .94607 .51939 .95706 .51621 .953 .51037 Mtetra
.953 .51037 .95706 .51621 .96809 .51302 .96406 .50715 Mtetra
.503 .601 .884 r
.3694 .66957 .37477 .67705 .38373 .67584 .37827 .6705 Mtetra
.613 .719 .921 r
.37827 .6705 .38373 .67584 .39274 .67417 .3873 .66885 Mtetra
.599 .716 .926 r
.3873 .66885 .39274 .67417 .40172 .67423 .39635 .66746 Mtetra
.925 .701 .58 r
.39635 .66746 .40172 .67423 .41105 .66514 .4084 .57962 Mtetra
0 0 .424 r
.4084 .57962 .41105 .66514 .42011 .66489 .41473 .65934 Mtetra
.609 .711 .917 r
.41473 .65934 .42011 .66489 .42926 .66301 .42389 .65777 Mtetra
.627 .73 .921 r
.42389 .65777 .42926 .66301 .43844 .66109 .43309 .65578 Mtetra
.61 .722 .925 r
.43309 .65578 .43844 .66109 .44763 .66059 .44232 .65413 Mtetra
.923 .532 .178 r
.44232 .65413 .44763 .66059 .45703 .65126 .45102 .67964 Mtetra
0 0 .108 r
.45102 .67964 .45703 .65126 .46627 .65139 .46099 .64573 Mtetra
.611 .71 .916 r
.46099 .64573 .46627 .65139 .47559 .64935 .47031 .64411 Mtetra
.636 .736 .92 r
.47031 .64411 .47559 .64935 .48494 .64705 .47969 .64187 Mtetra
.641 .74 .921 r
.47969 .64187 .48494 .64705 .49433 .64473 .48909 .63951 Mtetra
.637 .738 .922 r
.48909 .63951 .49433 .64473 .50375 .64265 .49854 .63724 Mtetra
.607 .721 .926 r
.49854 .63724 .50375 .64265 .5132 .6432 .50801 .63563 Mtetra
.863 .72 .703 r
.50801 .63563 .5132 .6432 .52271 .63336 .51756 .61624 Mtetra
.28 .305 .709 r
.51756 .61624 .52271 .63336 .53223 .63236 .52708 .62679 Mtetra
.626 .723 .917 r
.52708 .62679 .53223 .63236 .54178 .63003 .53665 .62477 Mtetra
.645 .742 .92 r
.53665 .62477 .54178 .63003 .55137 .62744 .54626 .62225 Mtetra
.651 .748 .92 r
.54626 .62225 .55137 .62744 .56099 .62473 .55591 .61957 Mtetra
.655 .75 .92 r
.55591 .61957 .56099 .62473 .57065 .62196 .56558 .61681 Mtetra
.657 .752 .92 r
.56558 .61681 .57065 .62196 .58034 .61913 .57529 .61398 Mtetra
.658 .753 .92 r
.57529 .61398 .58034 .61913 .59006 .61626 .58504 .61111 Mtetra
.659 .754 .92 r
.58504 .61111 .59006 .61626 .59981 .61338 .59482 .60821 Mtetra
.59482 .60821 .59981 .61338 .6096 .61048 .60463 .60529 Mtetra
.60463 .60529 .6096 .61048 .61942 .60758 .61447 .60237 Mtetra
.61447 .60237 .61942 .60758 .62928 .60468 .62436 .59944 Mtetra
.658 .753 .92 r
.62436 .59944 .62928 .60468 .63917 .60177 .63427 .59651 Mtetra
.63427 .59651 .63917 .60177 .6491 .59885 .64422 .59358 Mtetra
.64422 .59358 .6491 .59885 .65906 .59593 .65421 .59064 Mtetra
.65421 .59064 .65906 .59593 .66906 .59301 .66423 .58769 Mtetra
.66423 .58769 .66906 .59301 .67909 .59007 .67428 .58473 Mtetra
.67428 .58473 .67909 .59007 .68916 .58713 .68438 .58177 Mtetra
.657 .753 .92 r
.68438 .58177 .68916 .58713 .69926 .58418 .6945 .5788 Mtetra
.6945 .5788 .69926 .58418 .7094 .58122 .70467 .57582 Mtetra
.70467 .57582 .7094 .58122 .71957 .57825 .71487 .57283 Mtetra
.71487 .57283 .71957 .57825 .72979 .57527 .72511 .56983 Mtetra
.72511 .56983 .72979 .57527 .74004 .57228 .73538 .56683 Mtetra
.657 .752 .92 r
.73538 .56683 .74004 .57228 .75032 .56929 .74569 .56381 Mtetra
.74569 .56381 .75032 .56929 .76064 .56628 .75604 .56078 Mtetra
.75604 .56078 .76064 .56628 .771 .56326 .76643 .55774 Mtetra
.76643 .55774 .771 .56326 .7814 .56024 .77685 .5547 Mtetra
.77685 .5547 .7814 .56024 .79183 .5572 .78731 .55164 Mtetra
.78731 .55164 .79183 .5572 .8023 .55415 .79781 .54857 Mtetra
.79781 .54857 .8023 .55415 .81281 .5511 .80835 .54549 Mtetra
.80835 .54549 .81281 .5511 .82336 .54803 .81892 .54241 Mtetra
.81892 .54241 .82336 .54803 .83395 .54495 .82954 .53931 Mtetra
.82954 .53931 .83395 .54495 .84457 .54186 .84019 .5362 Mtetra
.84019 .5362 .84457 .54186 .85524 .53876 .85088 .53308 Mtetra
.85088 .53308 .85524 .53876 .86594 .53565 .86161 .52994 Mtetra
.86161 .52994 .86594 .53565 .87668 .53253 .87238 .5268 Mtetra
.87238 .5268 .87668 .53253 .88746 .5294 .88319 .52365 Mtetra
.88319 .52365 .88746 .5294 .89829 .52625 .89405 .52048 Mtetra
.89405 .52048 .89829 .52625 .90915 .5231 .90494 .5173 Mtetra
.90494 .5173 .90915 .5231 .92005 .51993 .91587 .51412 Mtetra
.91587 .51412 .92005 .51993 .93099 .51676 .92684 .51092 Mtetra
.92684 .51092 .93099 .51676 .94197 .51357 .93785 .50771 Mtetra
.93785 .50771 .94197 .51357 .953 .51037 .9489 .50448 Mtetra
.9489 .50448 .953 .51037 .96406 .50715 .96 .50125 Mtetra
0 0 0 r
.36303 .68293 .3694 .66957 .37827 .6705 .3728 .66479 Mtetra
.595 .7 .916 r
.3728 .66479 .37827 .6705 .3873 .66885 .38182 .66355 Mtetra
.614 .723 .923 r
.38182 .66355 .3873 .66885 .39635 .66746 .3909 .66184 Mtetra
.518 .675 .936 r
.3909 .66184 .39635 .66746 .4084 .57962 .39996 .66187 Mtetra
.525 .298 .513 r
.39996 .66187 .4084 .57962 .41473 .65934 .40936 .65271 Mtetra
.554 .654 .902 r
.40936 .65271 .41473 .65934 .42389 .65777 .41849 .65243 Mtetra
.623 .726 .92 r
.41849 .65243 .42389 .65777 .43309 .65578 .42771 .65051 Mtetra
.624 .729 .922 r
.42771 .65051 .43309 .65578 .44232 .65413 .43696 .64855 Mtetra
.551 .692 .933 r
.43696 .64855 .44232 .65413 .45102 .67964 .44622 .64802 Mtetra
.657 .491 .647 r
.44622 .64802 .45102 .67964 .46099 .64573 .4557 .63862 Mtetra
.54 .634 .893 r
.4557 .63862 .46099 .64573 .47031 .64411 .46501 .63871 Mtetra
.629 .729 .919 r
.46501 .63871 .47031 .64411 .47969 .64187 .4744 .63663 Mtetra
.639 .739 .92 r
.4744 .63663 .47969 .64187 .48909 .63951 .48382 .63429 Mtetra
.64 .74 .921 r
.48382 .63429 .48909 .63951 .49854 .63724 .49329 .63193 Mtetra
.629 .733 .923 r
.49329 .63193 .49854 .63724 .50801 .63563 .50279 .62981 Mtetra
.488 .659 .937 r
.50279 .62981 .50801 .63563 .51756 .61624 .51231 .63033 Mtetra
.191 0 .191 r
.51231 .63033 .51756 .61624 .52708 .62679 .52189 .62041 Mtetra
.585 .68 .906 r
.52189 .62041 .52708 .62679 .53665 .62477 .53149 .61938 Mtetra
.639 .736 .919 r
.53149 .61938 .53665 .62477 .54626 .62225 .54112 .617 Mtetra
.649 .745 .92 r
.54112 .617 .54626 .62225 .55591 .61957 .55079 .61436 Mtetra
.653 .749 .92 r
.55079 .61436 .55591 .61957 .56558 .61681 .56049 .61161 Mtetra
.656 .751 .92 r
.56049 .61161 .56558 .61681 .57529 .61398 .57022 .60879 Mtetra
.657 .753 .92 r
.57022 .60879 .57529 .61398 .58504 .61111 .57999 .60591 Mtetra
.658 .753 .92 r
.57999 .60591 .58504 .61111 .59482 .60821 .58979 .603 Mtetra
.659 .754 .92 r
.58979 .603 .59482 .60821 .60463 .60529 .59962 .60007 Mtetra
.59962 .60007 .60463 .60529 .61447 .60237 .60949 .59713 Mtetra
.60949 .59713 .61447 .60237 .62436 .59944 .6194 .59418 Mtetra
.658 .754 .92 r
.6194 .59418 .62436 .59944 .63427 .59651 .62934 .59123 Mtetra
.658 .753 .92 r
.62934 .59123 .63427 .59651 .64422 .59358 .63931 .58827 Mtetra
.63931 .58827 .64422 .59358 .65421 .59064 .64932 .58531 Mtetra
.64932 .58531 .65421 .59064 .66423 .58769 .65937 .58234 Mtetra
.65937 .58234 .66423 .58769 .67428 .58473 .66945 .57936 Mtetra
.66945 .57936 .67428 .58473 .68438 .58177 .67956 .57638 Mtetra
.67956 .57638 .68438 .58177 .6945 .5788 .68972 .57339 Mtetra
.657 .753 .92 r
.68972 .57339 .6945 .5788 .70467 .57582 .69991 .57039 Mtetra
.69991 .57039 .70467 .57582 .71487 .57283 .71013 .56738 Mtetra
.71013 .56738 .71487 .57283 .72511 .56983 .7204 .56436 Mtetra
.7204 .56436 .72511 .56983 .73538 .56683 .7307 .56133 Mtetra
.657 .752 .92 r
.7307 .56133 .73538 .56683 .74569 .56381 .74103 .55829 Mtetra
.74103 .55829 .74569 .56381 .75604 .56078 .75141 .55525 Mtetra
.75141 .55525 .75604 .56078 .76643 .55774 .76182 .55219 Mtetra
.76182 .55219 .76643 .55774 .77685 .5547 .77227 .54912 Mtetra
.77227 .54912 .77685 .5547 .78731 .55164 .78276 .54604 Mtetra
.78276 .54604 .78731 .55164 .79781 .54857 .79328 .54295 Mtetra
.79328 .54295 .79781 .54857 .80835 .54549 .80385 .53985 Mtetra
.80385 .53985 .80835 .54549 .81892 .54241 .81445 .53674 Mtetra
.81445 .53674 .81892 .54241 .82954 .53931 .82509 .53362 Mtetra
.82509 .53362 .82954 .53931 .84019 .5362 .83578 .53049 Mtetra
.83578 .53049 .84019 .5362 .85088 .53308 .8465 .52735 Mtetra
.8465 .52735 .85088 .53308 .86161 .52994 .85726 .5242 Mtetra
.85726 .5242 .86161 .52994 .87238 .5268 .86806 .52103 Mtetra
.86806 .52103 .87238 .5268 .88319 .52365 .8789 .51786 Mtetra
.8789 .51786 .88319 .52365 .89405 .52048 .88978 .51467 Mtetra
.88978 .51467 .89405 .52048 .90494 .5173 .9007 .51147 Mtetra
.9007 .51147 .90494 .5173 .91587 .51412 .91166 .50826 Mtetra
.91166 .50826 .91587 .51412 .92684 .51092 .92266 .50504 Mtetra
.92266 .50504 .92684 .51092 .93785 .50771 .9337 .50181 Mtetra
.9337 .50181 .93785 .50771 .9489 .50448 .94479 .49856 Mtetra
.94479 .49856 .9489 .50448 .96 .50125 .95591 .49531 Mtetra
.714 .578 .702 r
.35799 .66669 .36303 .68293 .3728 .66479 .36738 .65723 Mtetra
.503 .601 .884 r
.36738 .65723 .3728 .66479 .38182 .66355 .37632 .65813 Mtetra
.613 .719 .921 r
.37632 .65813 .38182 .66355 .3909 .66184 .38541 .65644 Mtetra
.599 .716 .926 r
.38541 .65644 .3909 .66184 .39996 .66187 .39454 .65501 Mtetra
.926 .701 .578 r
.39454 .65501 .39996 .66187 .40936 .65271 .40672 .56677 Mtetra
0 0 .42 r
.40672 .56677 .40936 .65271 .41849 .65243 .41306 .64679 Mtetra
.609 .711 .917 r
.41306 .64679 .41849 .65243 .42771 .65051 .42229 .64519 Mtetra
.627 .73 .921 r
.42229 .64519 .42771 .65051 .43696 .64855 .43156 .64316 Mtetra
.61 .722 .925 r
.43156 .64316 .43696 .64855 .44622 .64802 .44086 .64148 Mtetra
.922 .53 .171 r
.44086 .64148 .44622 .64802 .4557 .63862 .44961 .66706 Mtetra
0 0 .1 r
.44961 .66706 .4557 .63862 .46501 .63871 .45967 .63297 Mtetra
.611 .71 .916 r
.45967 .63297 .46501 .63871 .4744 .63663 .46907 .63131 Mtetra
.636 .736 .92 r
.46907 .63131 .4744 .63663 .48382 .63429 .47852 .62902 Mtetra
.641 .74 .921 r
.47852 .62902 .48382 .63429 .49329 .63193 .48801 .62663 Mtetra
.637 .738 .922 r
.48801 .62663 .49329 .63193 .50279 .62981 .49752 .62431 Mtetra
.607 .721 .926 r
.49752 .62431 .50279 .62981 .51231 .63033 .50707 .62266 Mtetra
.864 .721 .702 r
.50707 .62266 .51231 .63033 .52189 .62041 .51671 .60315 Mtetra
.277 .303 .709 r
.51671 .60315 .52189 .62041 .53149 .61938 .52629 .61372 Mtetra
.626 .723 .917 r
.52629 .61372 .53149 .61938 .54112 .617 .53594 .61166 Mtetra
.645 .742 .92 r
.53594 .61166 .54112 .617 .55079 .61436 .54563 .60909 Mtetra
.651 .748 .92 r
.54563 .60909 .55079 .61436 .56049 .61161 .55536 .60637 Mtetra
.655 .75 .92 r
.55536 .60637 .56049 .61161 .57022 .60879 .56511 .60355 Mtetra
.657 .752 .92 r
.56511 .60355 .57022 .60879 .57999 .60591 .5749 .60068 Mtetra
.658 .753 .92 r
.5749 .60068 .57999 .60591 .58979 .603 .58473 .59776 Mtetra
.659 .754 .92 r
.58473 .59776 .58979 .603 .59962 .60007 .59459 .59482 Mtetra
.59459 .59482 .59962 .60007 .60949 .59713 .60448 .59185 Mtetra
.60448 .59185 .60949 .59713 .6194 .59418 .61441 .58888 Mtetra
.61441 .58888 .6194 .59418 .62934 .59123 .62437 .58591 Mtetra
.658 .753 .92 r
.62437 .58591 .62934 .59123 .63931 .58827 .63437 .58293 Mtetra
.63437 .58293 .63931 .58827 .64932 .58531 .6444 .57994 Mtetra
.6444 .57994 .64932 .58531 .65937 .58234 .65447 .57695 Mtetra
.65447 .57695 .65937 .58234 .66945 .57936 .66458 .57396 Mtetra
.66458 .57396 .66945 .57936 .67956 .57638 .67472 .57095 Mtetra
.67472 .57095 .67956 .57638 .68972 .57339 .6849 .56794 Mtetra
.657 .753 .92 r
.6849 .56794 .68972 .57339 .69991 .57039 .69511 .56492 Mtetra
.69511 .56492 .69991 .57039 .71013 .56738 .70537 .56189 Mtetra
.70537 .56189 .71013 .56738 .7204 .56436 .71565 .55885 Mtetra
.71565 .55885 .7204 .56436 .7307 .56133 .72598 .5558 Mtetra
.72598 .5558 .7307 .56133 .74103 .55829 .73634 .55274 Mtetra
.657 .752 .92 r
.73634 .55274 .74103 .55829 .75141 .55525 .74675 .54967 Mtetra
.74675 .54967 .75141 .55525 .76182 .55219 .75718 .54659 Mtetra
.75718 .54659 .76182 .55219 .77227 .54912 .76766 .54351 Mtetra
.76766 .54351 .77227 .54912 .78276 .54604 .77818 .54041 Mtetra
.77818 .54041 .78276 .54604 .79328 .54295 .78873 .5373 Mtetra
.78873 .5373 .79328 .54295 .80385 .53985 .79932 .53418 Mtetra
.79932 .53418 .80385 .53985 .81445 .53674 .80995 .53104 Mtetra
.80995 .53104 .81445 .53674 .82509 .53362 .82062 .5279 Mtetra
.82062 .5279 .82509 .53362 .83578 .53049 .83133 .52475 Mtetra
.83133 .52475 .83578 .53049 .8465 .52735 .84208 .52159 Mtetra
.84208 .52159 .8465 .52735 .85726 .5242 .85287 .51841 Mtetra
.85287 .51841 .85726 .5242 .86806 .52103 .8637 .51522 Mtetra
.8637 .51522 .86806 .52103 .8789 .51786 .87457 .51203 Mtetra
.87457 .51203 .8789 .51786 .88978 .51467 .88548 .50882 Mtetra
.88548 .50882 .88978 .51467 .9007 .51147 .89643 .5056 Mtetra
.89643 .5056 .9007 .51147 .91166 .50826 .90742 .50236 Mtetra
.90742 .50236 .91166 .50826 .92266 .50504 .91845 .49912 Mtetra
.91845 .49912 .92266 .50504 .9337 .50181 .92952 .49587 Mtetra
.92952 .49587 .9337 .50181 .94479 .49856 .94064 .4926 Mtetra
.94064 .4926 .94479 .49856 .95591 .49531 .95179 .48932 Mtetra
.577 .095 0 r
.35246 .6604 .35799 .66669 .36738 .65723 .36095 .67059 Mtetra
0 0 0 r
.36095 .67059 .36738 .65723 .37632 .65813 .3708 .65234 Mtetra
.595 .7 .916 r
.3708 .65234 .37632 .65813 .38541 .65644 .37989 .65106 Mtetra
.614 .723 .923 r
.37989 .65106 .38541 .65644 .39454 .65501 .38904 .64931 Mtetra
.518 .675 .936 r
.38904 .64931 .39454 .65501 .40672 .56677 .39816 .64931 Mtetra
.522 .294 .51 r
.39816 .64931 .40672 .56677 .41306 .64679 .40764 .64008 Mtetra
.554 .654 .902 r
.40764 .64008 .41306 .64679 .42229 .64519 .41684 .63977 Mtetra
.623 .726 .92 r
.41684 .63977 .42229 .64519 .43156 .64316 .42613 .6378 Mtetra
.624 .729 .922 r
.42613 .6378 .43156 .64316 .44086 .64148 .43545 .63581 Mtetra
.551 .692 .933 r
.43545 .63581 .44086 .64148 .44961 .66706 .44478 .63524 Mtetra
.657 .49 .646 r
.44478 .63524 .44961 .66706 .45967 .63297 .45434 .62577 Mtetra
.54 .634 .893 r
.45434 .62577 .45967 .63297 .46907 .63131 .46372 .62583 Mtetra
.629 .729 .919 r
.46372 .62583 .46907 .63131 .47852 .62902 .47319 .62371 Mtetra
.639 .739 .92 r
.47319 .62371 .47852 .62902 .48801 .62663 .48269 .62132 Mtetra
.64 .74 .921 r
.48269 .62132 .48801 .62663 .49752 .62431 .49223 .61891 Mtetra
.629 .733 .923 r
.49223 .61891 .49752 .62431 .50707 .62266 .5018 .61675 Mtetra
.488 .659 .937 r
.5018 .61675 .50707 .62266 .51671 .60315 .5114 .61724 Mtetra
.182 0 .182 r
.5114 .61724 .51671 .60315 .52629 .61372 .52106 .60725 Mtetra
.585 .68 .906 r
.52106 .60725 .52629 .61372 .53594 .61166 .53074 .60618 Mtetra
.639 .736 .919 r
.53074 .60618 .53594 .61166 .54563 .60909 .54045 .60375 Mtetra
.649 .745 .92 r
.54045 .60375 .54563 .60909 .55536 .60637 .55019 .60107 Mtetra
.653 .749 .92 r
.55019 .60107 .55536 .60637 .56511 .60355 .55997 .59827 Mtetra
.656 .751 .92 r
.55997 .59827 .56511 .60355 .5749 .60068 .56978 .5954 Mtetra
.657 .753 .92 r
.56978 .5954 .5749 .60068 .58473 .59776 .57963 .59248 Mtetra
.658 .753 .92 r
.57963 .59248 .58473 .59776 .59459 .59482 .58952 .58952 Mtetra
.659 .754 .92 r
.58952 .58952 .59459 .59482 .60448 .59185 .59943 .58654 Mtetra
.59943 .58654 .60448 .59185 .61441 .58888 .60938 .58355 Mtetra
.60938 .58355 .61441 .58888 .62437 .58591 .61937 .58055 Mtetra
.658 .754 .92 r
.61937 .58055 .62437 .58591 .63437 .58293 .62939 .57755 Mtetra
.658 .753 .92 r
.62939 .57755 .63437 .58293 .6444 .57994 .63945 .57454 Mtetra
.63945 .57454 .6444 .57994 .65447 .57695 .64955 .57153 Mtetra
.64955 .57153 .65447 .57695 .66458 .57396 .65968 .56851 Mtetra
.65968 .56851 .66458 .57396 .67472 .57095 .66984 .56549 Mtetra
.66984 .56549 .67472 .57095 .6849 .56794 .68005 .56245 Mtetra
.68005 .56245 .6849 .56794 .69511 .56492 .69029 .55941 Mtetra
.657 .753 .92 r
.69029 .55941 .69511 .56492 .70537 .56189 .70057 .55636 Mtetra
.70057 .55636 .70537 .56189 .71565 .55885 .71088 .5533 Mtetra
.71088 .5533 .71565 .55885 .72598 .5558 .72123 .55023 Mtetra
.72123 .55023 .72598 .5558 .73634 .55274 .73162 .54715 Mtetra
.657 .752 .92 r
.73162 .54715 .73634 .55274 .74675 .54967 .74205 .54406 Mtetra
.74205 .54406 .74675 .54967 .75718 .54659 .75252 .54096 Mtetra
.75252 .54096 .75718 .54659 .76766 .54351 .76302 .53785 Mtetra
.76302 .53785 .76766 .54351 .77818 .54041 .77356 .53473 Mtetra
.77356 .53473 .77818 .54041 .78873 .5373 .78414 .5316 Mtetra
.78414 .5316 .78873 .5373 .79932 .53418 .79476 .52846 Mtetra
.79476 .52846 .79932 .53418 .80995 .53104 .80542 .52531 Mtetra
.80542 .52531 .80995 .53104 .82062 .5279 .81612 .52214 Mtetra
.81612 .52214 .82062 .5279 .83133 .52475 .82686 .51897 Mtetra
.82686 .51897 .83133 .52475 .84208 .52159 .83763 .51578 Mtetra
.83763 .51578 .84208 .52159 .85287 .51841 .84845 .51258 Mtetra
.84845 .51258 .85287 .51841 .8637 .51522 .85931 .50938 Mtetra
.85931 .50938 .8637 .51522 .87457 .51203 .87021 .50616 Mtetra
.87021 .50616 .87457 .51203 .88548 .50882 .88115 .50293 Mtetra
.88115 .50293 .88548 .50882 .89643 .5056 .89213 .49968 Mtetra
.89213 .49968 .89643 .5056 .90742 .50236 .90315 .49643 Mtetra
.90315 .49643 .90742 .50236 .91845 .49912 .91421 .49316 Mtetra
.91421 .49316 .91845 .49912 .92952 .49587 .92531 .48988 Mtetra
.92531 .48988 .92952 .49587 .94064 .4926 .93646 .48659 Mtetra
.93646 .48659 .94064 .4926 .95179 .48932 .94765 .48329 Mtetra
.552 .692 .932 r
.34685 .65479 .35246 .6604 .36095 .67059 .35586 .65422 Mtetra
.714 .578 .702 r
.35586 .65422 .36095 .67059 .3708 .65234 .36533 .64469 Mtetra
.502 .601 .884 r
.36533 .64469 .3708 .65234 .37989 .65106 .37434 .64556 Mtetra
.613 .719 .921 r
.37434 .64556 .37989 .65106 .38904 .64931 .3835 .64384 Mtetra
.599 .716 .926 r
.3835 .64384 .38904 .64931 .39816 .64931 .39269 .64237 Mtetra
.927 .702 .577 r
.39269 .64237 .39816 .64931 .40764 .64008 .40501 .55372 Mtetra
0 0 .417 r
.40501 .55372 .40764 .64008 .41684 .63977 .41136 .63405 Mtetra
.609 .711 .917 r
.41136 .63405 .41684 .63977 .42613 .6378 .42066 .63241 Mtetra
.627 .73 .921 r
.42066 .63241 .42613 .6378 .43545 .63581 .43001 .63033 Mtetra
.61 .722 .925 r
.43001 .63033 .43545 .63581 .44478 .63524 .43938 .62861 Mtetra
.92 .527 .164 r
.43938 .62861 .44478 .63524 .45434 .62577 .44819 .65428 Mtetra
0 0 .093 r
.44819 .65428 .45434 .62577 .46372 .62583 .45834 .62 Mtetra
.611 .71 .916 r
.45834 .62 .46372 .62583 .47319 .62371 .46782 .6183 Mtetra
.636 .736 .92 r
.46782 .6183 .47319 .62371 .48269 .62132 .47734 .61597 Mtetra
.641 .74 .921 r
.47734 .61597 .48269 .62132 .49223 .61891 .4869 .61353 Mtetra
.637 .738 .922 r
.4869 .61353 .49223 .61891 .5018 .61675 .49649 .61117 Mtetra
.607 .721 .926 r
.49649 .61117 .5018 .61675 .5114 .61724 .50612 .60948 Mtetra
.865 .722 .702 r
.50612 .60948 .5114 .61724 .52106 .60725 .51583 .58985 Mtetra
.275 .302 .708 r
.51583 .58985 .52106 .60725 .53074 .60618 .52549 .60043 Mtetra
.626 .723 .917 r
.52549 .60043 .53074 .60618 .54045 .60375 .53523 .59832 Mtetra
.645 .742 .92 r
.53523 .59832 .54045 .60375 .55019 .60107 .54499 .59571 Mtetra
.651 .748 .92 r
.54499 .59571 .55019 .60107 .55997 .59827 .5548 .59294 Mtetra
.655 .75 .92 r
.5548 .59294 .55997 .59827 .56978 .5954 .56463 .59008 Mtetra
.657 .752 .92 r
.56463 .59008 .56978 .5954 .57963 .59248 .5745 .58716 Mtetra
.658 .753 .92 r
.5745 .58716 .57963 .59248 .58952 .58952 .58441 .58419 Mtetra
.659 .754 .92 r
.58441 .58419 .58952 .58952 .59943 .58654 .59435 .5812 Mtetra
.59435 .5812 .59943 .58654 .60938 .58355 .60433 .57819 Mtetra
.60433 .57819 .60938 .58355 .61937 .58055 .61434 .57516 Mtetra
.61434 .57516 .61937 .58055 .62939 .57755 .62439 .57214 Mtetra
.658 .753 .92 r
.62439 .57214 .62939 .57755 .63945 .57454 .63447 .56911 Mtetra
.63447 .56911 .63945 .57454 .64955 .57153 .64459 .56608 Mtetra
.64459 .56608 .64955 .57153 .65968 .56851 .65474 .56304 Mtetra
.65474 .56304 .65968 .56851 .66984 .56549 .66494 .55999 Mtetra
.66494 .55999 .66984 .56549 .68005 .56245 .67516 .55693 Mtetra
.67516 .55693 .68005 .56245 .69029 .55941 .68543 .55387 Mtetra
.657 .753 .92 r
.68543 .55387 .69029 .55941 .70057 .55636 .69573 .5508 Mtetra
.69573 .5508 .70057 .55636 .71088 .5533 .70607 .54772 Mtetra
.70607 .54772 .71088 .5533 .72123 .55023 .71645 .54463 Mtetra
.71645 .54463 .72123 .55023 .73162 .54715 .72687 .54152 Mtetra
.72687 .54152 .73162 .54715 .74205 .54406 .73732 .53841 Mtetra
.657 .752 .92 r
.73732 .53841 .74205 .54406 .75252 .54096 .74782 .53529 Mtetra
.74782 .53529 .75252 .54096 .76302 .53785 .75835 .53216 Mtetra
.75835 .53216 .76302 .53785 .77356 .53473 .76892 .52902 Mtetra
.76892 .52902 .77356 .53473 .78414 .5316 .77952 .52587 Mtetra
.77952 .52587 .78414 .5316 .79476 .52846 .79017 .5227 Mtetra
.79017 .5227 .79476 .52846 .80542 .52531 .80086 .51953 Mtetra
.80086 .51953 .80542 .52531 .81612 .52214 .81159 .51634 Mtetra
.81159 .51634 .81612 .52214 .82686 .51897 .82235 .51315 Mtetra
.82235 .51315 .82686 .51897 .83763 .51578 .83316 .50994 Mtetra
.83316 .50994 .83763 .51578 .84845 .51258 .844 .50672 Mtetra
.844 .50672 .84845 .51258 .85931 .50938 .85489 .50349 Mtetra
.85489 .50349 .85931 .50938 .87021 .50616 .86582 .50025 Mtetra
.86582 .50025 .87021 .50616 .88115 .50293 .87679 .49699 Mtetra
.87679 .49699 .88115 .50293 .89213 .49968 .8878 .49373 Mtetra
.8878 .49373 .89213 .49968 .90315 .49643 .89885 .49045 Mtetra
.89885 .49045 .90315 .49643 .91421 .49316 .90994 .48716 Mtetra
.90994 .48716 .91421 .49316 .92531 .48988 .92108 .48386 Mtetra
.92108 .48386 .92531 .48988 .93646 .48659 .93225 .48055 Mtetra
.93225 .48055 .93646 .48659 .94765 .48329 .94347 .47722 Mtetra
.599 .714 .925 r
.34121 .64929 .34685 .65479 .35586 .65422 .35028 .64785 Mtetra
.57 .089 0 r
.35028 .64785 .35586 .65422 .36533 .64469 .35883 .65805 Mtetra
0 0 0 r
.35883 .65805 .36533 .64469 .37434 .64556 .36876 .63969 Mtetra
.595 .7 .916 r
.36876 .63969 .37434 .64556 .3835 .64384 .37792 .63837 Mtetra
.614 .723 .923 r
.37792 .63837 .3835 .64384 .39269 .64237 .38714 .63658 Mtetra
.518 .675 .936 r
.38714 .63658 .39269 .64237 .40501 .55372 .39633 .63655 Mtetra
.519 .29 .507 r
.39633 .63655 .40501 .55372 .41136 .63405 .40589 .62724 Mtetra
.554 .654 .902 r
.40589 .62724 .41136 .63405 .42066 .63241 .41516 .6269 Mtetra
.623 .726 .92 r
.41516 .6269 .42066 .63241 .43001 .63033 .42452 .62489 Mtetra
.624 .729 .922 r
.42452 .62489 .43001 .63033 .43938 .62861 .43392 .62285 Mtetra
.551 .692 .933 r
.43392 .62285 .43938 .62861 .44819 .65428 .44332 .62226 Mtetra
.656 .489 .646 r
.44332 .62226 .44819 .65428 .45834 .62 .45296 .61271 Mtetra
.54 .634 .893 r
.45296 .61271 .45834 .62 .46782 .6183 .46241 .61274 Mtetra
.629 .729 .919 r
.46241 .61274 .46782 .6183 .47734 .61597 .47195 .61057 Mtetra
.639 .739 .92 r
.47195 .61057 .47734 .61597 .4869 .61353 .48153 .60814 Mtetra
.64 .74 .921 r
.48153 .60814 .4869 .61353 .49649 .61117 .49115 .60569 Mtetra
.629 .733 .923 r
.49115 .60569 .49649 .61117 .50612 .60948 .5008 .60348 Mtetra
.489 .659 .936 r
.5008 .60348 .50612 .60948 .51583 .58985 .51048 .60394 Mtetra
.172 0 .172 r
.51048 .60394 .51583 .58985 .52549 .60043 .52022 .59386 Mtetra
.585 .68 .906 r
.52022 .59386 .52549 .60043 .53523 .59832 .52997 .59275 Mtetra
.639 .736 .919 r
.52997 .59275 .53523 .59832 .54499 .59571 .53976 .59029 Mtetra
.649 .745 .92 r
.53976 .59029 .54499 .59571 .5548 .59294 .54959 .58756 Mtetra
.653 .749 .92 r
.54959 .58756 .5548 .59294 .56463 .59008 .55945 .58471 Mtetra
.656 .751 .92 r
.55945 .58471 .56463 .59008 .5745 .58716 .56934 .58179 Mtetra
.657 .753 .92 r
.56934 .58179 .5745 .58716 .58441 .58419 .57927 .57882 Mtetra
.658 .753 .92 r
.57927 .57882 .58441 .58419 .59435 .5812 .58924 .57581 Mtetra
.659 .754 .92 r
.58924 .57581 .59435 .5812 .60433 .57819 .59924 .57279 Mtetra
.59924 .57279 .60433 .57819 .61434 .57516 .60927 .56974 Mtetra
.60927 .56974 .61434 .57516 .62439 .57214 .61934 .56669 Mtetra
.658 .754 .92 r
.61934 .56669 .62439 .57214 .63447 .56911 .62945 .56364 Mtetra
.658 .753 .92 r
.62945 .56364 .63447 .56911 .64459 .56608 .6396 .56058 Mtetra
.6396 .56058 .64459 .56608 .65474 .56304 .64978 .55752 Mtetra
.64978 .55752 .65474 .56304 .66494 .55999 .65999 .55445 Mtetra
.65999 .55445 .66494 .55999 .67516 .55693 .67025 .55138 Mtetra
.67025 .55138 .67516 .55693 .68543 .55387 .68054 .54829 Mtetra
.68054 .54829 .68543 .55387 .69573 .5508 .69087 .5452 Mtetra
.657 .753 .92 r
.69087 .5452 .69573 .5508 .70607 .54772 .70124 .54209 Mtetra
.70124 .54209 .70607 .54772 .71645 .54463 .71164 .53898 Mtetra
.71164 .53898 .71645 .54463 .72687 .54152 .72208 .53586 Mtetra
.72208 .53586 .72687 .54152 .73732 .53841 .73256 .53273 Mtetra
.657 .752 .92 r
.73256 .53273 .73732 .53841 .74782 .53529 .74308 .52958 Mtetra
.74308 .52958 .74782 .53529 .75835 .53216 .75364 .52643 Mtetra
.75364 .52643 .75835 .53216 .76892 .52902 .76424 .52327 Mtetra
.76424 .52327 .76892 .52902 .77952 .52587 .77488 .52009 Mtetra
.77488 .52009 .77952 .52587 .79017 .5227 .78555 .51691 Mtetra
.78555 .51691 .79017 .5227 .80086 .51953 .79627 .51371 Mtetra
.79627 .51371 .80086 .51953 .81159 .51634 .80702 .5105 Mtetra
.80702 .5105 .81159 .51634 .82235 .51315 .81782 .50728 Mtetra
.81782 .50728 .82235 .51315 .83316 .50994 .82865 .50405 Mtetra
.82865 .50405 .83316 .50994 .844 .50672 .83953 .50081 Mtetra
.83953 .50081 .844 .50672 .85489 .50349 .85044 .49756 Mtetra
.85044 .49756 .85489 .50349 .86582 .50025 .8614 .49429 Mtetra
.8614 .49429 .86582 .50025 .87679 .49699 .8724 .49102 Mtetra
.8724 .49102 .87679 .49699 .8878 .49373 .88344 .48773 Mtetra
.88344 .48773 .8878 .49373 .89885 .49045 .89452 .48443 Mtetra
.89452 .48443 .89885 .49045 .90994 .48716 .90564 .48112 Mtetra
.90564 .48112 .90994 .48716 .92108 .48386 .91681 .47779 Mtetra
.91681 .47779 .92108 .48386 .93225 .48055 .92802 .47446 Mtetra
.92802 .47446 .93225 .48055 .94347 .47722 .93927 .47111 Mtetra
.604 .713 .922 r
.33554 .6437 .34121 .64929 .35028 .64785 .34463 .64216 Mtetra
.552 .692 .932 r
.34463 .64216 .35028 .64785 .35883 .65805 .3537 .64155 Mtetra
.714 .578 .702 r
.3537 .64155 .35883 .65805 .36876 .63969 .36324 .63194 Mtetra
.502 .601 .885 r
.36324 .63194 .36876 .63969 .37792 .63837 .37232 .63279 Mtetra
.613 .719 .921 r
.37232 .63279 .37792 .63837 .38714 .63658 .38155 .63102 Mtetra
.599 .716 .926 r
.38155 .63102 .38714 .63658 .39633 .63655 .39081 .62952 Mtetra
.928 .702 .575 r
.39081 .62952 .39633 .63655 .40589 .62724 .40328 .54046 Mtetra
0 0 .413 r
.40328 .54046 .40589 .62724 .41516 .6269 .40963 .62109 Mtetra
.609 .711 .917 r
.40963 .62109 .41516 .6269 .42452 .62489 .419 .61941 Mtetra
.627 .73 .921 r
.419 .61941 .42452 .62489 .43392 .62285 .42842 .61729 Mtetra
.61 .722 .925 r
.42842 .61729 .43392 .62285 .44332 .62226 .43787 .61553 Mtetra
.919 .524 .157 r
.43787 .61553 .44332 .62226 .45296 .61271 .44674 .64128 Mtetra
0 0 .085 r
.44674 .64128 .45296 .61271 .46241 .61274 .45699 .60681 Mtetra
.611 .711 .916 r
.45699 .60681 .46241 .61274 .47195 .61057 .46654 .60507 Mtetra
.636 .736 .92 r
.46654 .60507 .47195 .61057 .48153 .60814 .47613 .6027 Mtetra
.641 .74 .921 r
.47613 .6027 .48153 .60814 .49115 .60569 .48577 .60022 Mtetra
.637 .738 .922 r
.48577 .60022 .49115 .60569 .5008 .60348 .49544 .59781 Mtetra
.607 .721 .926 r
.49544 .59781 .5008 .60348 .51048 .60394 .50515 .59607 Mtetra
.866 .723 .702 r
.50515 .59607 .51048 .60394 .52022 .59386 .51495 .57633 Mtetra
.272 .3 .708 r
.51495 .57633 .52022 .59386 .52997 .59275 .52468 .58692 Mtetra
.626 .723 .917 r
.52468 .58692 .52997 .59275 .53976 .59029 .53449 .58477 Mtetra
.645 .742 .92 r
.53449 .58477 .53976 .59029 .54959 .58756 .54434 .58211 Mtetra
.651 .748 .92 r
.54434 .58211 .54959 .58756 .55945 .58471 .55423 .57929 Mtetra
.655 .75 .92 r
.55423 .57929 .55945 .58471 .56934 .58179 .56415 .57638 Mtetra
.657 .752 .92 r
.56415 .57638 .56934 .58179 .57927 .57882 .5741 .57341 Mtetra
.658 .753 .92 r
.5741 .57341 .57927 .57882 .58924 .57581 .58409 .57039 Mtetra
.659 .754 .92 r
.58409 .57039 .58924 .57581 .59924 .57279 .59411 .56735 Mtetra
.59411 .56735 .59924 .57279 .60927 .56974 .60417 .56429 Mtetra
.60417 .56429 .60927 .56974 .61934 .56669 .61427 .56121 Mtetra
.61427 .56121 .61934 .56669 .62945 .56364 .6244 .55814 Mtetra
.658 .753 .92 r
.6244 .55814 .62945 .56364 .6396 .56058 .63457 .55506 Mtetra
.63457 .55506 .6396 .56058 .64978 .55752 .64478 .55197 Mtetra
.64478 .55197 .64978 .55752 .65999 .55445 .65502 .54888 Mtetra
.65502 .54888 .65999 .55445 .67025 .55138 .6653 .54578 Mtetra
.6653 .54578 .67025 .55138 .68054 .54829 .67562 .54268 Mtetra
.67562 .54268 .68054 .54829 .69087 .5452 .68597 .53956 Mtetra
.657 .753 .92 r
.68597 .53956 .69087 .5452 .70124 .54209 .69636 .53644 Mtetra
.69636 .53644 .70124 .54209 .71164 .53898 .7068 .5333 Mtetra
.7068 .5333 .71164 .53898 .72208 .53586 .71726 .53016 Mtetra
.71726 .53016 .72208 .53586 .73256 .53273 .72777 .527 Mtetra
.72777 .527 .73256 .53273 .74308 .52958 .73832 .52384 Mtetra
.657 .752 .92 r
.73832 .52384 .74308 .52958 .75364 .52643 .7489 .52066 Mtetra
.7489 .52066 .75364 .52643 .76424 .52327 .75953 .51748 Mtetra
.75953 .51748 .76424 .52327 .77488 .52009 .77019 .51428 Mtetra
.77019 .51428 .77488 .52009 .78555 .51691 .7809 .51107 Mtetra
.7809 .51107 .78555 .51691 .79627 .51371 .79164 .50785 Mtetra
.79164 .50785 .79627 .51371 .80702 .5105 .80242 .50462 Mtetra
.80242 .50462 .80702 .5105 .81782 .50728 .81325 .50138 Mtetra
.81325 .50138 .81782 .50728 .82865 .50405 .82411 .49813 Mtetra
.82411 .49813 .82865 .50405 .83953 .50081 .83502 .49487 Mtetra
.83502 .49487 .83953 .50081 .85044 .49756 .84596 .49159 Mtetra
.84596 .49159 .85044 .49756 .8614 .49429 .85695 .4883 Mtetra
.85695 .4883 .8614 .49429 .8724 .49102 .86798 .485 Mtetra
.86798 .485 .8724 .49102 .88344 .48773 .87905 .48169 Mtetra
.87905 .48169 .88344 .48773 .89452 .48443 .89016 .47837 Mtetra
.89016 .47837 .89452 .48443 .90564 .48112 .90132 .47503 Mtetra
.90132 .47503 .90564 .48112 .91681 .47779 .91251 .47168 Mtetra
.91251 .47168 .91681 .47779 .92802 .47446 .92375 .46832 Mtetra
.92375 .46832 .92802 .47446 .93927 .47111 .93503 .46495 Mtetra
.583 .691 .916 r
.32985 .63767 .33554 .6437 .34463 .64216 .33893 .63657 Mtetra
.599 .714 .925 r
.33893 .63657 .34463 .64216 .3537 .64155 .34807 .63509 Mtetra
.562 .083 0 r
.34807 .63509 .3537 .64155 .36324 .63194 .35667 .64531 Mtetra
0 0 0 r
.35667 .64531 .36324 .63194 .37232 .63279 .3667 .62683 Mtetra
.595 .7 .916 r
.3667 .62683 .37232 .63279 .38155 .63102 .37593 .62547 Mtetra
.614 .723 .923 r
.37593 .62547 .38155 .63102 .39081 .62952 .38522 .62365 Mtetra
.518 .675 .936 r
.38522 .62365 .39081 .62952 .40328 .54046 .39448 .62358 Mtetra
.516 .286 .504 r
.39448 .62358 .40328 .54046 .40963 .62109 .40411 .6142 Mtetra
.554 .654 .902 r
.40411 .6142 .40963 .62109 .419 .61941 .41345 .61382 Mtetra
.623 .726 .92 r
.41345 .61382 .419 .61941 .42842 .61729 .42289 .61177 Mtetra
.624 .729 .922 r
.42289 .61177 .42842 .61729 .43787 .61553 .43236 .60969 Mtetra
.552 .692 .933 r
.43236 .60969 .43787 .61553 .44674 .64128 .44184 .60905 Mtetra
.656 .488 .645 r
.44184 .60905 .44674 .64128 .45699 .60681 .45156 .59943 Mtetra
.539 .634 .893 r
.45156 .59943 .45699 .60681 .46654 .60507 .46109 .59942 Mtetra
.629 .729 .919 r
.46109 .59942 .46654 .60507 .47613 .6027 .4707 .59721 Mtetra
.639 .739 .92 r
.4707 .59721 .47613 .6027 .48577 .60022 .48036 .59473 Mtetra
.64 .74 .921 r
.48036 .59473 .48577 .60022 .49544 .59781 .49005 .59224 Mtetra
.629 .733 .923 r
.49005 .59224 .49544 .59781 .50515 .59607 .49978 .58999 Mtetra
.489 .659 .936 r
.49978 .58999 .50515 .59607 .51495 .57633 .50954 .59041 Mtetra
.163 0 .163 r
.50954 .59041 .51495 .57633 .52468 .58692 .51936 .58026 Mtetra
.585 .68 .906 r
.51936 .58026 .52468 .58692 .53449 .58477 .52919 .57911 Mtetra
.639 .736 .919 r
.52919 .57911 .53449 .58477 .54434 .58211 .53906 .57659 Mtetra
.649 .745 .92 r
.53906 .57659 .54434 .58211 .55423 .57929 .54897 .57381 Mtetra
.653 .749 .92 r
.54897 .57381 .55423 .57929 .56415 .57638 .55891 .57092 Mtetra
.656 .751 .92 r
.55891 .57092 .56415 .57638 .5741 .57341 .56889 .56795 Mtetra
.657 .753 .92 r
.56889 .56795 .5741 .57341 .58409 .57039 .57891 .56493 Mtetra
.658 .753 .92 r
.57891 .56493 .58409 .57039 .59411 .56735 .58895 .56187 Mtetra
.659 .754 .92 r
.58895 .56187 .59411 .56735 .60417 .56429 .59904 .55879 Mtetra
.59904 .55879 .60417 .56429 .61427 .56121 .60916 .5557 Mtetra
.60916 .5557 .61427 .56121 .6244 .55814 .61932 .5526 Mtetra
.658 .754 .92 r
.61932 .5526 .6244 .55814 .63457 .55506 .62951 .5495 Mtetra
.658 .753 .92 r
.62951 .5495 .63457 .55506 .64478 .55197 .63974 .54639 Mtetra
.63974 .54639 .64478 .55197 .65502 .54888 .65001 .54327 Mtetra
.65001 .54327 .65502 .54888 .6653 .54578 .66032 .54015 Mtetra
.66032 .54015 .6653 .54578 .67562 .54268 .67066 .53702 Mtetra
.67066 .53702 .67562 .54268 .68597 .53956 .68104 .53388 Mtetra
.68104 .53388 .68597 .53956 .69636 .53644 .69146 .53074 Mtetra
.657 .753 .92 r
.69146 .53074 .69636 .53644 .7068 .5333 .70192 .52758 Mtetra
.70192 .52758 .7068 .5333 .71726 .53016 .71241 .52441 Mtetra
.71241 .52441 .71726 .53016 .72777 .527 .72295 .52124 Mtetra
.72295 .52124 .72777 .527 .73832 .52384 .73352 .51805 Mtetra
.657 .752 .92 r
.73352 .51805 .73832 .52384 .7489 .52066 .74414 .51485 Mtetra
.74414 .51485 .7489 .52066 .75953 .51748 .75479 .51165 Mtetra
.75479 .51165 .75953 .51748 .77019 .51428 .76548 .50843 Mtetra
.76548 .50843 .77019 .51428 .7809 .51107 .77621 .5052 Mtetra
.77621 .5052 .7809 .51107 .79164 .50785 .78698 .50196 Mtetra
.78698 .50196 .79164 .50785 .80242 .50462 .7978 .4987 Mtetra
.7978 .4987 .80242 .50462 .81325 .50138 .80865 .49544 Mtetra
.80865 .49544 .81325 .50138 .82411 .49813 .81954 .49216 Mtetra
.81954 .49216 .82411 .49813 .83502 .49487 .83048 .48888 Mtetra
.83048 .48888 .83502 .49487 .84596 .49159 .84145 .48558 Mtetra
.84145 .48558 .84596 .49159 .85695 .4883 .85247 .48227 Mtetra
.85247 .48227 .85695 .4883 .86798 .485 .86353 .47894 Mtetra
.86353 .47894 .86798 .485 .87905 .48169 .87463 .47561 Mtetra
.87463 .47561 .87905 .48169 .89016 .47837 .88577 .47226 Mtetra
.88577 .47226 .89016 .47837 .90132 .47503 .89696 .4689 Mtetra
.89696 .4689 .90132 .47503 .91251 .47168 .90818 .46553 Mtetra
.90818 .46553 .91251 .47168 .92375 .46832 .91946 .46215 Mtetra
.91946 .46215 .92375 .46832 .93503 .46495 .93077 .45875 Mtetra
.455 .554 .867 r
.32429 .62901 .32985 .63767 .33893 .63657 .3332 .63089 Mtetra
.604 .713 .922 r
.3332 .63089 .33893 .63657 .34807 .63509 .34236 .62931 Mtetra
.553 .692 .932 r
.34236 .62931 .34807 .63509 .35667 .64531 .35151 .62867 Mtetra
.714 .578 .702 r
.35151 .62867 .35667 .64531 .3667 .62683 .36113 .61899 Mtetra
.502 .601 .885 r
.36113 .61899 .3667 .62683 .37593 .62547 .37027 .61981 Mtetra
.613 .719 .921 r
.37027 .61981 .37593 .62547 .38522 .62365 .37958 .618 Mtetra
.599 .716 .926 r
.37958 .618 .38522 .62365 .39448 .62358 .38891 .61645 Mtetra
.929 .703 .574 r
.38891 .61645 .39448 .62358 .40411 .6142 .40152 .52699 Mtetra
0 0 .409 r
.40152 .52699 .40411 .6142 .41345 .61382 .40788 .60793 Mtetra
.609 .711 .917 r
.40788 .60793 .41345 .61382 .42289 .61177 .41732 .6062 Mtetra
.627 .73 .921 r
.41732 .6062 .42289 .61177 .43236 .60969 .42682 .60404 Mtetra
.61 .722 .925 r
.42682 .60404 .43236 .60969 .44184 .60905 .43634 .60224 Mtetra
.917 .521 .15 r
.43634 .60224 .44184 .60905 .45156 .59943 .44526 .62807 Mtetra
0 0 .077 r
.44526 .62807 .45156 .59943 .46109 .59942 .45561 .59341 Mtetra
.611 .711 .916 r
.45561 .59341 .46109 .59942 .4707 .59721 .46524 .59163 Mtetra
.636 .736 .92 r
.46524 .59163 .4707 .59721 .48036 .59473 .47491 .58921 Mtetra
.641 .74 .921 r
.47491 .58921 .48036 .59473 .49005 .59224 .48463 .58668 Mtetra
.637 .738 .922 r
.48463 .58668 .49005 .59224 .49978 .58999 .49438 .58423 Mtetra
.607 .721 .926 r
.49438 .58423 .49978 .58999 .50954 .59041 .50416 .58245 Mtetra
.867 .724 .702 r
.50416 .58245 .50954 .59041 .51936 .58026 .51405 .56258 Mtetra
.27 .299 .707 r
.51405 .56258 .51936 .58026 .52919 .57911 .52386 .57318 Mtetra
.626 .723 .917 r
.52386 .57318 .52919 .57911 .53906 .57659 .53375 .57098 Mtetra
.645 .742 .92 r
.53375 .57098 .53906 .57659 .54897 .57381 .54368 .56828 Mtetra
.651 .748 .92 r
.54368 .56828 .54897 .57381 .55891 .57092 .55365 .56541 Mtetra
.655 .75 .92 r
.55365 .56541 .55891 .57092 .56889 .56795 .56365 .56245 Mtetra
.657 .752 .92 r
.56365 .56245 .56889 .56795 .57891 .56493 .57369 .55943 Mtetra
.658 .753 .92 r
.57369 .55943 .57891 .56493 .58895 .56187 .58376 .55636 Mtetra
.659 .754 .92 r
.58376 .55636 .58895 .56187 .59904 .55879 .59387 .55326 Mtetra
.59387 .55326 .59904 .55879 .60916 .5557 .60402 .55015 Mtetra
.60402 .55015 .60916 .5557 .61932 .5526 .6142 .54703 Mtetra
.6142 .54703 .61932 .5526 .62951 .5495 .62442 .5439 Mtetra
.658 .753 .92 r
.62442 .5439 .62951 .5495 .63974 .54639 .63467 .54076 Mtetra
.63467 .54076 .63974 .54639 .65001 .54327 .64497 .53763 Mtetra
.64497 .53763 .65001 .54327 .66032 .54015 .6553 .53448 Mtetra
.6553 .53448 .66032 .54015 .67066 .53702 .66567 .53133 Mtetra
.66567 .53133 .67066 .53702 .68104 .53388 .67608 .52817 Mtetra
.67608 .52817 .68104 .53388 .69146 .53074 .68652 .525 Mtetra
.657 .753 .92 r
.68652 .525 .69146 .53074 .70192 .52758 .69701 .52182 Mtetra
.69701 .52182 .70192 .52758 .71241 .52441 .70753 .51863 Mtetra
.70753 .51863 .71241 .52441 .72295 .52124 .71809 .51544 Mtetra
.71809 .51544 .72295 .52124 .73352 .51805 .72869 .51223 Mtetra
.72869 .51223 .73352 .51805 .74414 .51485 .73933 .50901 Mtetra
.657 .752 .92 r
.73933 .50901 .74414 .51485 .75479 .51165 .75001 .50578 Mtetra
.75001 .50578 .75479 .51165 .76548 .50843 .76073 .50253 Mtetra
.76073 .50253 .76548 .50843 .77621 .5052 .77149 .49928 Mtetra
.77149 .49928 .77621 .5052 .78698 .50196 .78229 .49602 Mtetra
.78229 .49602 .78698 .50196 .7978 .4987 .79313 .49274 Mtetra
.79313 .49274 .7978 .4987 .80865 .49544 .80402 .48946 Mtetra
.80402 .48946 .80865 .49544 .81954 .49216 .81494 .48616 Mtetra
.81494 .48616 .81954 .49216 .83048 .48888 .8259 .48285 Mtetra
.8259 .48285 .83048 .48888 .84145 .48558 .83691 .47952 Mtetra
.83691 .47952 .84145 .48558 .85247 .48227 .84796 .47619 Mtetra
.84796 .47619 .85247 .48227 .86353 .47894 .85905 .47284 Mtetra
.85905 .47284 .86353 .47894 .87463 .47561 .87018 .46949 Mtetra
.87018 .46949 .87463 .47561 .88577 .47226 .88135 .46611 Mtetra
.88135 .46611 .88577 .47226 .89696 .4689 .89257 .46273 Mtetra
.89257 .46273 .89696 .4689 .90818 .46553 .90383 .45934 Mtetra
.90383 .45934 .90818 .46553 .91946 .46215 .91513 .45593 Mtetra
.91513 .45593 .91946 .46215 .93077 .45875 .92647 .45251 Mtetra
0 0 0 r
.31763 .63814 .32429 .62901 .3332 .63089 .32747 .62477 Mtetra
.583 .692 .916 r
.32747 .62477 .3332 .63089 .34236 .62931 .33661 .62365 Mtetra
.599 .714 .925 r
.33661 .62365 .34236 .62931 .35151 .62867 .34582 .62212 Mtetra
.555 .077 0 r
.34582 .62212 .35151 .62867 .36113 .61899 .35448 .63235 Mtetra
0 0 0 r
.35448 .63235 .36113 .61899 .37027 .61981 .36459 .61376 Mtetra
.595 .7 .916 r
.36459 .61376 .37027 .61981 .37958 .618 .3739 .61236 Mtetra
.614 .723 .923 r
.3739 .61236 .37958 .618 .38891 .61645 .38326 .61049 Mtetra
.519 .675 .935 r
.38326 .61049 .38891 .61645 .40152 .52699 .39259 .61039 Mtetra
.513 .282 .501 r
.39259 .61039 .40152 .52699 .40788 .60793 .40231 .60094 Mtetra
.554 .654 .902 r
.40231 .60094 .40788 .60793 .41732 .6062 .41172 .60052 Mtetra
.623 .726 .92 r
.41172 .60052 .41732 .6062 .42682 .60404 .42123 .59843 Mtetra
.624 .729 .922 r
.42123 .59843 .42682 .60404 .43634 .60224 .43078 .5963 Mtetra
.552 .692 .932 r
.43078 .5963 .43634 .60224 .44526 .62807 .44033 .59563 Mtetra
.655 .487 .645 r
.44033 .59563 .44526 .62807 .45561 .59341 .45013 .58593 Mtetra
.539 .634 .893 r
.45013 .58593 .45561 .59341 .46524 .59163 .45974 .58589 Mtetra
.629 .729 .919 r
.45974 .58589 .46524 .59163 .47491 .58921 .46943 .58363 Mtetra
.639 .739 .92 r
.46943 .58363 .47491 .58921 .48463 .58668 .47917 .58111 Mtetra
.64 .74 .921 r
.47917 .58111 .48463 .58668 .49438 .58423 .48894 .57856 Mtetra
.629 .733 .923 r
.48894 .57856 .49438 .58423 .50416 .58245 .49875 .57627 Mtetra
.49 .659 .936 r
.49875 .57627 .50416 .58245 .51405 .56258 .50858 .57666 Mtetra
.152 0 .153 r
.50858 .57666 .51405 .56258 .52386 .57318 .51849 .56642 Mtetra
.585 .68 .906 r
.51849 .56642 .52386 .57318 .53375 .57098 .5284 .56523 Mtetra
.639 .736 .919 r
.5284 .56523 .53375 .57098 .54368 .56828 .53836 .56267 Mtetra
.649 .745 .92 r
.53836 .56267 .54368 .56828 .55365 .56541 .54835 .55984 Mtetra
.653 .749 .92 r
.54835 .55984 .55365 .56541 .56365 .56245 .55837 .55689 Mtetra
.656 .751 .92 r
.55837 .55689 .56365 .56245 .57369 .55943 .56843 .55387 Mtetra
.657 .753 .92 r
.56843 .55387 .57369 .55943 .58376 .55636 .57853 .5508 Mtetra
.658 .753 .92 r
.57853 .5508 .58376 .55636 .59387 .55326 .58867 .54769 Mtetra
.659 .754 .92 r
.58867 .54769 .59387 .55326 .60402 .55015 .59884 .54456 Mtetra
.59884 .54456 .60402 .55015 .6142 .54703 .60904 .54142 Mtetra
.60904 .54142 .6142 .54703 .62442 .5439 .61929 .53826 Mtetra
.658 .754 .92 r
.61929 .53826 .62442 .5439 .63467 .54076 .62957 .53511 Mtetra
.658 .753 .92 r
.62957 .53511 .63467 .54076 .64497 .53763 .63989 .53194 Mtetra
.63989 .53194 .64497 .53763 .6553 .53448 .65025 .52878 Mtetra
.65025 .52878 .6553 .53448 .66567 .53133 .66064 .5256 Mtetra
.66064 .5256 .66567 .53133 .67608 .52817 .67108 .52242 Mtetra
.67108 .52242 .67608 .52817 .68652 .525 .68155 .51923 Mtetra
.68155 .51923 .68652 .525 .69701 .52182 .69206 .51602 Mtetra
.657 .753 .92 r
.69206 .51602 .69701 .52182 .70753 .51863 .70261 .51281 Mtetra
.70261 .51281 .70753 .51863 .71809 .51544 .7132 .50959 Mtetra
.7132 .50959 .71809 .51544 .72869 .51223 .72383 .50636 Mtetra
.72383 .50636 .72869 .51223 .73933 .50901 .7345 .50312 Mtetra
.657 .752 .92 r
.7345 .50312 .73933 .50901 .75001 .50578 .74521 .49986 Mtetra
.74521 .49986 .75001 .50578 .76073 .50253 .75595 .4966 Mtetra
.75595 .4966 .76073 .50253 .77149 .49928 .76674 .49333 Mtetra
.76674 .49333 .77149 .49928 .78229 .49602 .77757 .49004 Mtetra
.77757 .49004 .78229 .49602 .79313 .49274 .78844 .48674 Mtetra
.78844 .48674 .79313 .49274 .80402 .48946 .79935 .48343 Mtetra
.79935 .48343 .80402 .48946 .81494 .48616 .8103 .48011 Mtetra
.8103 .48011 .81494 .48616 .8259 .48285 .8213 .47677 Mtetra
.8213 .47677 .8259 .48285 .83691 .47952 .83233 .47343 Mtetra
.83233 .47343 .83691 .47952 .84796 .47619 .84341 .47007 Mtetra
.84341 .47007 .84796 .47619 .85905 .47284 .85453 .4667 Mtetra
.85453 .4667 .85905 .47284 .87018 .46949 .86569 .46332 Mtetra
.86569 .46332 .87018 .46949 .88135 .46611 .8769 .45992 Mtetra
.8769 .45992 .88135 .46611 .89257 .46273 .88815 .45652 Mtetra
.88815 .45652 .89257 .46273 .90383 .45934 .89944 .4531 Mtetra
.89944 .4531 .90383 .45934 .91513 .45593 .91077 .44966 Mtetra
.91077 .44966 .91513 .45593 .92647 .45251 .92215 .44622 Mtetra
.755 .638 .731 r
.31217 .6264 .31763 .63814 .32747 .62477 .32185 .61602 Mtetra
.454 .553 .867 r
.32185 .61602 .32747 .62477 .33661 .62365 .33083 .61788 Mtetra
.604 .713 .922 r
.33083 .61788 .33661 .62365 .34582 .62212 .34006 .61626 Mtetra
.553 .692 .932 r
.34006 .61626 .34582 .62212 .35448 .63235 .34927 .61558 Mtetra
.714 .578 .701 r
.34927 .61558 .35448 .63235 .36459 .61376 .35897 .60582 Mtetra
.501 .601 .885 r
.35897 .60582 .36459 .61376 .3739 .61236 .36819 .60661 Mtetra
.613 .719 .921 r
.36819 .60661 .3739 .61236 .38326 .61049 .37756 .60476 Mtetra
.6 .716 .926 r
.37756 .60476 .38326 .61049 .39259 .61039 .38697 .60317 Mtetra
.93 .703 .572 r
.38697 .60317 .39259 .61039 .40231 .60094 .39973 .5133 Mtetra
0 0 .405 r
.39973 .5133 .40231 .60094 .41172 .60052 .40609 .59454 Mtetra
.609 .712 .917 r
.40609 .59454 .41172 .60052 .42123 .59843 .41561 .59278 Mtetra
.627 .73 .921 r
.41561 .59278 .42123 .59843 .43078 .5963 .42518 .59057 Mtetra
.61 .722 .925 r
.42518 .59057 .43078 .5963 .44033 .59563 .43478 .58872 Mtetra
.915 .518 .143 r
.43478 .58872 .44033 .59563 .45013 .58593 .44376 .61463 Mtetra
0 0 .069 r
.44376 .61463 .45013 .58593 .45974 .58589 .45421 .57978 Mtetra
.61 .711 .916 r
.45421 .57978 .45974 .58589 .46943 .58363 .46391 .57796 Mtetra
.636 .736 .92 r
.46391 .57796 .46943 .58363 .47917 .58111 .47367 .57549 Mtetra
.641 .74 .921 r
.47367 .57549 .47917 .58111 .48894 .57856 .48346 .57291 Mtetra
.637 .738 .922 r
.48346 .57291 .48894 .57856 .49875 .57627 .49329 .57042 Mtetra
.607 .721 .926 r
.49329 .57042 .49875 .57627 .50858 .57666 .50316 .56859 Mtetra
.868 .725 .701 r
.50316 .56859 .50858 .57666 .51849 .56642 .51313 .5486 Mtetra
.268 .297 .707 r
.51313 .5486 .51849 .56642 .5284 .56523 .52302 .5592 Mtetra
.626 .723 .917 r
.52302 .5592 .5284 .56523 .53836 .56267 .53299 .55696 Mtetra
.645 .742 .92 r
.53299 .55696 .53836 .56267 .54835 .55984 .54301 .55421 Mtetra
.651 .748 .92 r
.54301 .55421 .54835 .55984 .55837 .55689 .55306 .55129 Mtetra
.655 .75 .92 r
.55306 .55129 .55837 .55689 .56843 .55387 .56315 .54828 Mtetra
.657 .752 .92 r
.56315 .54828 .56843 .55387 .57853 .5508 .57327 .5452 Mtetra
.658 .753 .92 r
.57327 .5452 .57853 .5508 .58867 .54769 .58343 .54208 Mtetra
.659 .754 .92 r
.58343 .54208 .58867 .54769 .59884 .54456 .59362 .53893 Mtetra
.59362 .53893 .59884 .54456 .60904 .54142 .60386 .53577 Mtetra
.60386 .53577 .60904 .54142 .61929 .53826 .61413 .53259 Mtetra
.61413 .53259 .61929 .53826 .62957 .53511 .62443 .52941 Mtetra
.658 .753 .92 r
.62443 .52941 .62957 .53511 .63989 .53194 .63478 .52622 Mtetra
.63478 .52622 .63989 .53194 .65025 .52878 .64516 .52303 Mtetra
.64516 .52303 .65025 .52878 .66064 .5256 .65558 .51983 Mtetra
.65558 .51983 .66064 .5256 .67108 .52242 .66604 .51663 Mtetra
.66604 .51663 .67108 .52242 .68155 .51923 .67654 .51341 Mtetra
.67654 .51341 .68155 .51923 .69206 .51602 .68708 .51019 Mtetra
.657 .753 .92 r
.68708 .51019 .69206 .51602 .70261 .51281 .69766 .50695 Mtetra
.69766 .50695 .70261 .51281 .7132 .50959 .70828 .50371 Mtetra
.70828 .50371 .7132 .50959 .72383 .50636 .71893 .50045 Mtetra
.71893 .50045 .72383 .50636 .7345 .50312 .72963 .49719 Mtetra
.72963 .49719 .7345 .50312 .74521 .49986 .74036 .49391 Mtetra
.657 .752 .92 r
.74036 .49391 .74521 .49986 .75595 .4966 .75114 .49063 Mtetra
.75114 .49063 .75595 .4966 .76674 .49333 .76196 .48733 Mtetra
.76196 .48733 .76674 .49333 .77757 .49004 .77282 .48402 Mtetra
.77282 .48402 .77757 .49004 .78844 .48674 .78372 .48069 Mtetra
.78372 .48069 .78844 .48674 .79935 .48343 .79466 .47736 Mtetra
.79466 .47736 .79935 .48343 .8103 .48011 .80564 .47402 Mtetra
.80564 .47402 .8103 .48011 .8213 .47677 .81666 .47066 Mtetra
.81666 .47066 .8213 .47677 .83233 .47343 .82773 .46729 Mtetra
.82773 .46729 .83233 .47343 .84341 .47007 .83883 .46391 Mtetra
.83883 .46391 .84341 .47007 .85453 .4667 .84998 .46051 Mtetra
.84998 .46051 .85453 .4667 .86569 .46332 .86118 .45711 Mtetra
.86118 .45711 .86569 .46332 .8769 .45992 .87241 .45369 Mtetra
.87241 .45369 .8769 .45992 .88815 .45652 .88369 .45026 Mtetra
.88369 .45026 .88815 .45652 .89944 .4531 .89502 .44681 Mtetra
.89502 .44681 .89944 .4531 .91077 .44966 .90638 .44335 Mtetra
.90638 .44335 .91077 .44966 .92215 .44622 .91779 .43988 Mtetra
.001 .373 .838 r
.30635 .61998 .31217 .6264 .32185 .61602 .31512 .62513 Mtetra
.571 .809 .422 r
.31512 .62513 .32185 .61602 .33083 .61788 .32504 .61167 Mtetra
.583 .692 .916 r
.32504 .61167 .33083 .61788 .34006 .61626 .33425 .61051 Mtetra
.599 .714 .925 r
.33425 .61051 .34006 .61626 .34927 .61558 .34353 .60894 Mtetra
.547 .071 0 r
.34353 .60894 .34927 .61558 .35897 .60582 .35225 .61918 Mtetra
0 0 0 r
.35225 .61918 .35897 .60582 .36819 .60661 .36246 .60047 Mtetra
.595 .7 .917 r
.36246 .60047 .36819 .60661 .37756 .60476 .37183 .59904 Mtetra
.614 .723 .923 r
.37183 .59904 .37756 .60476 .38697 .60317 .38127 .59712 Mtetra
.519 .675 .935 r
.38127 .59712 .38697 .60317 .39973 .5133 .39067 .59699 Mtetra
.51 .278 .498 r
.39067 .59699 .39973 .5133 .40609 .59454 .40047 .58746 Mtetra
.553 .654 .902 r
.40047 .58746 .40609 .59454 .41561 .59278 .40996 .587 Mtetra
.623 .726 .92 r
.40996 .587 .41561 .59278 .42518 .59057 .41954 .58486 Mtetra
.624 .729 .922 r
.41954 .58486 .42518 .59057 .43478 .58872 .42917 .58269 Mtetra
.552 .692 .932 r
.42917 .58269 .43478 .58872 .44376 .61463 .4388 .58198 Mtetra
.655 .486 .644 r
.4388 .58198 .44376 .61463 .45421 .57978 .44868 .5722 Mtetra
.539 .634 .893 r
.44868 .5722 .45421 .57978 .46391 .57796 .45836 .57212 Mtetra
.629 .729 .919 r
.45836 .57212 .46391 .57796 .47367 .57549 .46814 .56982 Mtetra
.639 .739 .92 r
.46814 .56982 .47367 .57549 .48346 .57291 .47795 .56725 Mtetra
.64 .74 .921 r
.47795 .56725 .48346 .57291 .49329 .57042 .4878 .56466 Mtetra
.629 .733 .923 r
.4878 .56466 .49329 .57042 .50316 .56859 .49769 .56231 Mtetra
.49 .659 .936 r
.49769 .56231 .50316 .56859 .51313 .5486 .50761 .56267 Mtetra
.142 0 .142 r
.50761 .56267 .51313 .5486 .52302 .5592 .5176 .55235 Mtetra
.585 .68 .906 r
.5176 .55235 .52302 .5592 .53299 .55696 .5276 .55111 Mtetra
.639 .736 .919 r
.5276 .55111 .53299 .55696 .54301 .55421 .53764 .5485 Mtetra
.649 .745 .92 r
.53764 .5485 .54301 .55421 .55306 .55129 .54771 .54562 Mtetra
.653 .749 .92 r
.54771 .54562 .55306 .55129 .56315 .54828 .55782 .54263 Mtetra
.656 .751 .92 r
.55782 .54263 .56315 .54828 .57327 .5452 .56797 .53955 Mtetra
.657 .753 .92 r
.56797 .53955 .57327 .5452 .58343 .54208 .57815 .53643 Mtetra
.658 .753 .92 r
.57815 .53643 .58343 .54208 .59362 .53893 .58837 .53327 Mtetra
.659 .754 .92 r
.58837 .53327 .59362 .53893 .60386 .53577 .59863 .53008 Mtetra
.59863 .53008 .60386 .53577 .61413 .53259 .60893 .52688 Mtetra
.60893 .52688 .61413 .53259 .62443 .52941 .61926 .52368 Mtetra
.658 .754 .92 r
.61926 .52368 .62443 .52941 .63478 .52622 .62963 .52047 Mtetra
.658 .753 .92 r
.62963 .52047 .63478 .52622 .64516 .52303 .64004 .51725 Mtetra
.64004 .51725 .64516 .52303 .65558 .51983 .65049 .51403 Mtetra
.65049 .51403 .65558 .51983 .66604 .51663 .66098 .5108 Mtetra
.66098 .5108 .66604 .51663 .67654 .51341 .6715 .50756 Mtetra
.6715 .50756 .67654 .51341 .68708 .51019 .68207 .50431 Mtetra
.68207 .50431 .68708 .51019 .69766 .50695 .69267 .50105 Mtetra
.657 .753 .92 r
.69267 .50105 .69766 .50695 .70828 .50371 .70332 .49779 Mtetra
.70332 .49779 .70828 .50371 .71893 .50045 .714 .49451 Mtetra
.714 .49451 .71893 .50045 .72963 .49719 .72472 .49122 Mtetra
.72472 .49122 .72963 .49719 .74036 .49391 .73549 .48792 Mtetra
.657 .752 .92 r
.73549 .48792 .74036 .49391 .75114 .49063 .74629 .48461 Mtetra
.74629 .48461 .75114 .49063 .76196 .48733 .75714 .48129 Mtetra
.75714 .48129 .76196 .48733 .77282 .48402 .76803 .47795 Mtetra
.76803 .47795 .77282 .48402 .78372 .48069 .77896 .47461 Mtetra
.77896 .47461 .78372 .48069 .79466 .47736 .78993 .47125 Mtetra
.78993 .47125 .79466 .47736 .80564 .47402 .80094 .46788 Mtetra
.80094 .46788 .80564 .47402 .81666 .47066 .81199 .4645 Mtetra
.81199 .4645 .81666 .47066 .82773 .46729 .82309 .46111 Mtetra
.82309 .46111 .82773 .46729 .83883 .46391 .83423 .4577 Mtetra
.83423 .4577 .83883 .46391 .84998 .46051 .84541 .45428 Mtetra
.84541 .45428 .84998 .46051 .86118 .45711 .85663 .45085 Mtetra
.85663 .45085 .86118 .45711 .87241 .45369 .8679 .44741 Mtetra
.8679 .44741 .87241 .45369 .88369 .45026 .87921 .44395 Mtetra
.87921 .44395 .88369 .45026 .89502 .44681 .89056 .44048 Mtetra
.89056 .44048 .89502 .44681 .90638 .44335 .90196 .437 Mtetra
.90196 .437 .90638 .44335 .91779 .43988 .9134 .43351 Mtetra
.559 .694 .931 r
.30047 .61408 .30635 .61998 .31512 .62513 .30961 .61327 Mtetra
.755 .639 .732 r
.30961 .61327 .31512 .62513 .32504 .61167 .31937 .60282 Mtetra
.454 .553 .867 r
.31937 .60282 .32504 .61167 .33425 .61051 .32842 .60465 Mtetra
.604 .713 .922 r
.32842 .60465 .33425 .61051 .34353 .60894 .33772 .60299 Mtetra
.553 .692 .932 r
.33772 .60299 .34353 .60894 .35225 .61918 .347 .60227 Mtetra
.714 .578 .701 r
.347 .60227 .35225 .61918 .36246 .60047 .35678 .59244 Mtetra
.501 .601 .885 r
.35678 .59244 .36246 .60047 .37183 .59904 .36607 .59319 Mtetra
.613 .719 .921 r
.36607 .59319 .37183 .59904 .38127 .59712 .37552 .5913 Mtetra
.6 .716 .926 r
.37552 .5913 .38127 .59712 .39067 .59699 .385 .58967 Mtetra
.932 .704 .571 r
.385 .58967 .39067 .59699 .40047 .58746 .39791 .49938 Mtetra
0 0 .401 r
.39791 .49938 .40047 .58746 .40996 .587 .40428 .58093 Mtetra
.609 .712 .917 r
.40428 .58093 .40996 .587 .41954 .58486 .41387 .57912 Mtetra
.627 .73 .921 r
.41387 .57912 .41954 .58486 .42917 .58269 .42352 .57687 Mtetra
.61 .722 .925 r
.42352 .57687 .42917 .58269 .4388 .58198 .4332 .57497 Mtetra
.913 .515 .136 r
.4332 .57497 .4388 .58198 .44868 .5722 .44224 .60096 Mtetra
0 0 .061 r
.44224 .60096 .44868 .5722 .45836 .57212 .45278 .56593 Mtetra
.61 .711 .916 r
.45278 .56593 .45836 .57212 .46814 .56982 .46257 .56405 Mtetra
.636 .736 .92 r
.46257 .56405 .46814 .56982 .47795 .56725 .4724 .56154 Mtetra
.641 .74 .921 r
.4724 .56154 .47795 .56725 .4878 .56466 .48228 .55891 Mtetra
.637 .738 .922 r
.48228 .55891 .4878 .56466 .49769 .56231 .49219 .55637 Mtetra
.607 .721 .926 r
.49219 .55637 .49769 .56231 .50761 .56267 .50214 .55449 Mtetra
.869 .725 .701 r
.50214 .55449 .50761 .56267 .5176 .55235 .5122 .53438 Mtetra
.265 .295 .706 r
.5122 .53438 .5176 .55235 .5276 .55111 .52217 .54499 Mtetra
.626 .723 .917 r
.52217 .54499 .5276 .55111 .53764 .5485 .53223 .5427 Mtetra
.645 .742 .92 r
.53223 .5427 .53764 .5485 .54771 .54562 .54232 .53989 Mtetra
.651 .748 .92 r
.54232 .53989 .54771 .54562 .55782 .54263 .55246 .53692 Mtetra
.655 .75 .92 r
.55246 .53692 .55782 .54263 .56797 .53955 .56263 .53386 Mtetra
.657 .752 .92 r
.56263 .53386 .56797 .53955 .57815 .53643 .57284 .53073 Mtetra
.658 .753 .92 r
.57284 .53073 .57815 .53643 .58837 .53327 .58309 .52756 Mtetra
.659 .754 .92 r
.58309 .52756 .58837 .53327 .59863 .53008 .59337 .52436 Mtetra
.59337 .52436 .59863 .53008 .60893 .52688 .60369 .52114 Mtetra
.60369 .52114 .60893 .52688 .61926 .52368 .61405 .51791 Mtetra
.61405 .51791 .61926 .52368 .62963 .52047 .62445 .51467 Mtetra
.658 .753 .92 r
.62445 .51467 .62963 .52047 .64004 .51725 .63489 .51143 Mtetra
.63489 .51143 .64004 .51725 .65049 .51403 .64536 .50818 Mtetra
.64536 .50818 .65049 .51403 .66098 .5108 .65587 .50493 Mtetra
.65587 .50493 .66098 .5108 .6715 .50756 .66643 .50166 Mtetra
.66643 .50166 .6715 .50756 .68207 .50431 .67702 .49839 Mtetra
.67702 .49839 .68207 .50431 .69267 .50105 .68765 .49511 Mtetra
.657 .753 .92 r
.68765 .49511 .69267 .50105 .70332 .49779 .69832 .49182 Mtetra
.69832 .49182 .70332 .49779 .714 .49451 .70903 .48852 Mtetra
.70903 .48852 .714 .49451 .72472 .49122 .71979 .48521 Mtetra
.71979 .48521 .72472 .49122 .73549 .48792 .73058 .48189 Mtetra
.73058 .48189 .73549 .48792 .74629 .48461 .74141 .47855 Mtetra
.657 .752 .92 r
.74141 .47855 .74629 .48461 .75714 .48129 .75229 .4752 Mtetra
.75229 .4752 .75714 .48129 .76803 .47795 .76321 .47185 Mtetra
.76321 .47185 .76803 .47795 .77896 .47461 .77416 .46848 Mtetra
.77416 .46848 .77896 .47461 .78993 .47125 .78516 .4651 Mtetra
.78516 .4651 .78993 .47125 .80094 .46788 .7962 .4617 Mtetra
.7962 .4617 .80094 .46788 .81199 .4645 .80729 .4583 Mtetra
.80729 .4583 .81199 .4645 .82309 .46111 .81841 .45488 Mtetra
.81841 .45488 .82309 .46111 .83423 .4577 .82958 .45145 Mtetra
.82958 .45145 .83423 .4577 .84541 .45428 .8408 .44801 Mtetra
.8408 .44801 .84541 .45428 .85663 .45085 .85205 .44455 Mtetra
.85205 .44455 .85663 .45085 .8679 .44741 .86335 .44108 Mtetra
.86335 .44108 .8679 .44741 .87921 .44395 .87469 .4376 Mtetra
.87469 .4376 .87921 .44395 .89056 .44048 .88608 .43411 Mtetra
.88608 .43411 .89056 .44048 .90196 .437 .89751 .4306 Mtetra
.89751 .4306 .90196 .437 .9134 .43351 .90899 .42708 Mtetra
.593 .709 .924 r
.29454 .60821 .30047 .61408 .30961 .61327 .30374 .60677 Mtetra
.005 .375 .84 r
.30374 .60677 .30961 .61327 .31937 .60282 .31256 .6119 Mtetra
.582 .818 .432 r
.31256 .6119 .31937 .60282 .32842 .60465 .32257 .59835 Mtetra
.583 .692 .916 r
.32257 .59835 .32842 .60465 .33772 .60299 .33186 .59715 Mtetra
.599 .714 .925 r
.33186 .59715 .33772 .60299 .347 .60227 .34121 .59554 Mtetra
.54 .065 0 r
.34121 .59554 .347 .60227 .35678 .59244 .34999 .60579 Mtetra
0 0 0 r
.34999 .60579 .35678 .59244 .36607 .59319 .36028 .58696 Mtetra
.595 .7 .917 r
.36028 .58696 .36607 .59319 .37552 .5913 .36973 .58549 Mtetra
.615 .723 .923 r
.36973 .58549 .37552 .5913 .385 .58967 .37924 .58353 Mtetra
.519 .675 .935 r
.37924 .58353 .385 .58967 .39791 .49938 .38872 .58336 Mtetra
.507 .274 .495 r
.38872 .58336 .39791 .49938 .40428 .58093 .3986 .57375 Mtetra
.553 .654 .902 r
.3986 .57375 .40428 .58093 .41387 .57912 .40817 .57325 Mtetra
.623 .726 .92 r
.40817 .57325 .41387 .57912 .42352 .57687 .41783 .57107 Mtetra
.624 .729 .922 r
.41783 .57107 .42352 .57687 .4332 .57497 .42753 .56885 Mtetra
.552 .692 .932 r
.42753 .56885 .4332 .57497 .44224 .60096 .43724 .5681 Mtetra
.654 .485 .643 r
.43724 .5681 .44224 .60096 .45278 .56593 .4472 .55824 Mtetra
.539 .634 .893 r
.4472 .55824 .45278 .56593 .46257 .56405 .45697 .55813 Mtetra
.629 .729 .919 r
.45697 .55813 .46257 .56405 .4724 .56154 .46682 .55577 Mtetra
.639 .739 .92 r
.46682 .55577 .4724 .56154 .48228 .55891 .47672 .55315 Mtetra
.64 .74 .921 r
.47672 .55315 .48228 .55891 .49219 .55637 .48665 .55051 Mtetra
.629 .733 .923 r
.48665 .55051 .49219 .55637 .50214 .55449 .49662 .54812 Mtetra
.491 .659 .936 r
.49662 .54812 .50214 .55449 .5122 .53438 .50662 .54844 Mtetra
.131 0 .132 r
.50662 .54844 .5122 .53438 .52217 .54499 .5167 .53803 Mtetra
.585 .68 .906 r
.5167 .53803 .52217 .54499 .53223 .5427 .52678 .53675 Mtetra
.639 .736 .919 r
.52678 .53675 .53223 .5427 .54232 .53989 .5369 .53409 Mtetra
.649 .745 .92 r
.5369 .53409 .54232 .53989 .55246 .53692 .54706 .53116 Mtetra
.653 .749 .92 r
.54706 .53116 .55246 .53692 .56263 .53386 .55726 .52811 Mtetra
.656 .751 .92 r
.55726 .52811 .56263 .53386 .57284 .53073 .56749 .52499 Mtetra
.657 .753 .92 r
.56749 .52499 .57284 .53073 .58309 .52756 .57777 .52181 Mtetra
.658 .753 .92 r
.57777 .52181 .58309 .52756 .59337 .52436 .58808 .51859 Mtetra
.659 .754 .92 r
.58808 .51859 .59337 .52436 .60369 .52114 .59842 .51535 Mtetra
.59842 .51535 .60369 .52114 .61405 .51791 .60881 .5121 Mtetra
.60881 .5121 .61405 .51791 .62445 .51467 .61923 .50884 Mtetra
.658 .754 .92 r
.61923 .50884 .62445 .51467 .63489 .51143 .62969 .50557 Mtetra
.658 .753 .92 r
.62969 .50557 .63489 .51143 .64536 .50818 .64019 .5023 Mtetra
.64019 .5023 .64536 .50818 .65587 .50493 .65074 .49902 Mtetra
.65074 .49902 .65587 .50493 .66643 .50166 .66132 .49573 Mtetra
.66132 .49573 .66643 .50166 .67702 .49839 .67193 .49244 Mtetra
.67193 .49244 .67702 .49839 .68765 .49511 .68259 .48913 Mtetra
.68259 .48913 .68765 .49511 .69832 .49182 .69329 .48582 Mtetra
.657 .753 .92 r
.69329 .48582 .69832 .49182 .70903 .48852 .70403 .48249 Mtetra
.70403 .48249 .70903 .48852 .71979 .48521 .71482 .47916 Mtetra
.71482 .47916 .71979 .48521 .73058 .48189 .72564 .47581 Mtetra
.72564 .47581 .73058 .48189 .74141 .47855 .7365 .47245 Mtetra
.657 .752 .92 r
.7365 .47245 .74141 .47855 .75229 .4752 .7474 .46908 Mtetra
.7474 .46908 .75229 .4752 .76321 .47185 .75835 .4657 Mtetra
.75835 .4657 .76321 .47185 .77416 .46848 .76934 .46231 Mtetra
.76934 .46231 .77416 .46848 .78516 .4651 .78037 .4589 Mtetra
.78037 .4589 .78516 .4651 .7962 .4617 .79144 .45548 Mtetra
.79144 .45548 .7962 .4617 .80729 .4583 .80255 .45205 Mtetra
.80255 .45205 .80729 .4583 .81841 .45488 .81371 .44861 Mtetra
.81371 .44861 .81841 .45488 .82958 .45145 .82491 .44515 Mtetra
.82491 .44515 .82958 .45145 .8408 .44801 .83615 .44169 Mtetra
.83615 .44169 .8408 .44801 .85205 .44455 .84744 .43821 Mtetra
.84744 .43821 .85205 .44455 .86335 .44108 .85877 .43471 Mtetra
.85877 .43471 .86335 .44108 .87469 .4376 .87014 .43121 Mtetra
.87014 .43121 .87469 .4376 .88608 .43411 .88156 .42769 Mtetra
.88156 .42769 .88608 .43411 .89751 .4306 .89303 .42415 Mtetra
.89303 .42415 .89751 .4306 .90899 .42708 .90453 .42061 Mtetra
.586 .697 .919 r
.2886 .60206 .29454 .60821 .30374 .60677 .29779 .60078 Mtetra
.559 .694 .931 r
.29779 .60078 .30374 .60677 .31256 .6119 .307 .59993 Mtetra
.756 .639 .732 r
.307 .59993 .31256 .6119 .32257 .59835 .31685 .58939 Mtetra
.453 .553 .867 r
.31685 .58939 .32257 .59835 .33186 .59715 .32597 .5912 Mtetra
.604 .713 .922 r
.32597 .5912 .33186 .59715 .34121 .59554 .33534 .5895 Mtetra
.553 .692 .932 r
.33534 .5895 .34121 .59554 .34999 .60579 .3447 .58874 Mtetra
.714 .578 .701 r
.3447 .58874 .34999 .60579 .36028 .58696 .35456 .57883 Mtetra
.501 .601 .885 r
.35456 .57883 .36028 .58696 .36973 .58549 .36391 .57955 Mtetra
.613 .719 .921 r
.36391 .57955 .36973 .58549 .37924 .58353 .37344 .57761 Mtetra
.6 .716 .926 r
.37344 .57761 .37924 .58353 .38872 .58336 .383 .57594 Mtetra
.933 .704 .569 r
.383 .57594 .38872 .58336 .3986 .57375 .39606 .48524 Mtetra
0 0 .396 r
.39606 .48524 .3986 .57375 .40817 .57325 .40243 .56708 Mtetra
.609 .712 .918 r
.40243 .56708 .40817 .57325 .41783 .57107 .4121 .56523 Mtetra
.627 .73 .921 r
.4121 .56523 .41783 .57107 .42753 .56885 .42183 .56293 Mtetra
.61 .722 .925 r
.42183 .56293 .42753 .56885 .43724 .5681 .43158 .56099 Mtetra
.911 .512 .128 r
.43158 .56099 .43724 .5681 .4472 .55824 .44069 .58706 Mtetra
0 0 .053 r
.44069 .58706 .4472 .55824 .45697 .55813 .45133 .55183 Mtetra
.61 .711 .916 r
.45133 .55183 .45697 .55813 .46682 .55577 .4612 .54991 Mtetra
.636 .736 .92 r
.4612 .54991 .46682 .55577 .47672 .55315 .47112 .54735 Mtetra
.641 .74 .921 r
.47112 .54735 .47672 .55315 .48665 .55051 .48107 .54467 Mtetra
.637 .738 .922 r
.48107 .54467 .48665 .55051 .49662 .54812 .49107 .54208 Mtetra
.607 .721 .926 r
.49107 .54208 .49662 .54812 .50662 .54844 .5011 .54016 Mtetra
.87 .726 .701 r
.5011 .54016 .50662 .54844 .5167 .53803 .51125 .51992 Mtetra
.263 .294 .706 r
.51125 .51992 .5167 .53803 .52678 .53675 .5213 .53053 Mtetra
.625 .723 .917 r
.5213 .53053 .52678 .53675 .5369 .53409 .53144 .52819 Mtetra
.645 .742 .92 r
.53144 .52819 .5369 .53409 .54706 .53116 .54163 .52533 Mtetra
.651 .748 .92 r
.54163 .52533 .54706 .53116 .55726 .52811 .55185 .52231 Mtetra
.655 .75 .92 r
.55185 .52231 .55726 .52811 .56749 .52499 .56211 .51919 Mtetra
.657 .752 .92 r
.56211 .51919 .56749 .52499 .57777 .52181 .57241 .51601 Mtetra
.658 .753 .92 r
.57241 .51601 .57777 .52181 .58808 .51859 .58274 .51278 Mtetra
.659 .754 .92 r
.58274 .51278 .58808 .51859 .59842 .51535 .59312 .50953 Mtetra
.59312 .50953 .59842 .51535 .60881 .5121 .60353 .50625 Mtetra
.60353 .50625 .60881 .5121 .61923 .50884 .61398 .50296 Mtetra
.61398 .50296 .61923 .50884 .62969 .50557 .62447 .49967 Mtetra
.658 .753 .92 r
.62447 .49967 .62969 .50557 .64019 .5023 .63499 .49637 Mtetra
.63499 .49637 .64019 .5023 .65074 .49902 .64556 .49307 Mtetra
.64556 .49307 .65074 .49902 .66132 .49573 .65617 .48976 Mtetra
.65617 .48976 .66132 .49573 .67193 .49244 .66682 .48644 Mtetra
.66682 .48644 .67193 .49244 .68259 .48913 .6775 .48311 Mtetra
.6775 .48311 .68259 .48913 .69329 .48582 .68823 .47977 Mtetra
.657 .753 .92 r
.68823 .47977 .69329 .48582 .70403 .48249 .699 .47642 Mtetra
.699 .47642 .70403 .48249 .71482 .47916 .70981 .47306 Mtetra
.70981 .47306 .71482 .47916 .72564 .47581 .72066 .46969 Mtetra
.72066 .46969 .72564 .47581 .7365 .47245 .73155 .46631 Mtetra
.73155 .46631 .7365 .47245 .7474 .46908 .74248 .46291 Mtetra
.657 .752 .92 r
.74248 .46291 .7474 .46908 .75835 .4657 .75346 .45951 Mtetra
.75346 .45951 .75835 .4657 .76934 .46231 .76447 .45609 Mtetra
.76447 .45609 .76934 .46231 .78037 .4589 .77553 .45266 Mtetra
.77553 .45266 .78037 .4589 .79144 .45548 .78664 .44922 Mtetra
.78664 .44922 .79144 .45548 .80255 .45205 .79778 .44576 Mtetra
.79778 .44576 .80255 .45205 .81371 .44861 .80897 .44229 Mtetra
.80897 .44229 .81371 .44861 .82491 .44515 .8202 .43881 Mtetra
.8202 .43881 .82491 .44515 .83615 .44169 .83147 .43532 Mtetra
.83147 .43532 .83615 .44169 .84744 .43821 .84279 .43182 Mtetra
.84279 .43182 .84744 .43821 .85877 .43471 .85415 .4283 Mtetra
.85415 .4283 .85877 .43471 .87014 .43121 .86556 .42477 Mtetra
.86556 .42477 .87014 .43121 .88156 .42769 .87701 .42122 Mtetra
.87701 .42122 .88156 .42769 .89303 .42415 .88851 .41766 Mtetra
.88851 .41766 .89303 .42415 .90453 .42061 .90005 .41409 Mtetra
.511 .62 .896 r
.28272 .59445 .2886 .60206 .29779 .60078 .29181 .59482 Mtetra
.593 .709 .924 r
.29181 .59482 .29779 .60078 .307 .59993 .30108 .59333 Mtetra
.01 .378 .842 r
.30108 .59333 .307 .59993 .31685 .58939 .30997 .59845 Mtetra
.592 .826 .443 r
.30997 .59845 .31685 .58939 .32597 .5912 .32006 .58481 Mtetra
.583 .692 .916 r
.32006 .58481 .32597 .5912 .33534 .5895 .32942 .58356 Mtetra
.599 .714 .925 r
.32942 .58356 .33534 .5895 .3447 .58874 .33884 .58191 Mtetra
0 0 .465 r
.33884 .58191 .3447 .58874 .35456 .57883 .34769 .59217 Mtetra
0 0 0 r
.34769 .59217 .35456 .57883 .36391 .57955 .35807 .57323 Mtetra
.595 .7 .917 r
.35807 .57323 .36391 .57955 .37344 .57761 .3676 .57171 Mtetra
.615 .723 .923 r
.3676 .57171 .37344 .57761 .383 .57594 .37719 .5697 Mtetra
.52 .675 .935 r
.37719 .5697 .383 .57594 .39606 .48524 .38674 .5695 Mtetra
.504 .269 .492 r
.38674 .5695 .39606 .48524 .40243 .56708 .3967 .5598 Mtetra
.553 .654 .902 r
.3967 .5598 .40243 .56708 .4121 .56523 .40634 .55927 Mtetra
.623 .726 .92 r
.40634 .55927 .4121 .56523 .42183 .56293 .41609 .55704 Mtetra
.624 .729 .922 r
.41609 .55704 .42183 .56293 .43158 .56099 .42587 .55478 Mtetra
.552 .692 .932 r
.42587 .55478 .43158 .56099 .44069 .58706 .43565 .55398 Mtetra
.654 .484 .642 r
.43565 .55398 .44069 .58706 .45133 .55183 .4457 .54404 Mtetra
.539 .634 .894 r
.4457 .54404 .45133 .55183 .4612 .54991 .45554 .54389 Mtetra
.629 .729 .919 r
.45554 .54389 .4612 .54991 .47112 .54735 .46548 .54149 Mtetra
.639 .739 .92 r
.46548 .54149 .47112 .54735 .48107 .54467 .47546 .53882 Mtetra
.64 .74 .921 r
.47546 .53882 .48107 .54467 .49107 .54208 .48548 .53612 Mtetra
.629 .733 .923 r
.48548 .53612 .49107 .54208 .5011 .54016 .49553 .53368 Mtetra
.491 .659 .935 r
.49553 .53368 .5011 .54016 .51125 .51992 .50562 .53396 Mtetra
.121 0 .121 r
.50562 .53396 .51125 .51992 .5213 .53053 .51578 .52347 Mtetra
.585 .68 .906 r
.51578 .52347 .5213 .53053 .53144 .52819 .52595 .52215 Mtetra
.639 .736 .919 r
.52595 .52215 .53144 .52819 .54163 .52533 .53616 .51943 Mtetra
.649 .745 .92 r
.53616 .51943 .54163 .52533 .55185 .52231 .5464 .51645 Mtetra
.653 .749 .92 r
.5464 .51645 .55185 .52231 .56211 .51919 .55669 .51334 Mtetra
.656 .751 .92 r
.55669 .51334 .56211 .51919 .57241 .51601 .56701 .51016 Mtetra
.657 .753 .92 r
.56701 .51016 .57241 .51601 .58274 .51278 .57737 .50693 Mtetra
.658 .753 .92 r
.57737 .50693 .58274 .51278 .59312 .50953 .58777 .50366 Mtetra
.659 .754 .92 r
.58777 .50366 .59312 .50953 .60353 .50625 .59821 .50036 Mtetra
.59821 .50036 .60353 .50625 .61398 .50296 .60869 .49705 Mtetra
.60869 .49705 .61398 .50296 .62447 .49967 .6192 .49373 Mtetra
.658 .754 .92 r
.6192 .49373 .62447 .49967 .63499 .49637 .62976 .49041 Mtetra
.658 .753 .92 r
.62976 .49041 .63499 .49637 .64556 .49307 .64035 .48708 Mtetra
.64035 .48708 .64556 .49307 .65617 .48976 .65099 .48374 Mtetra
.65099 .48374 .65617 .48976 .66682 .48644 .66166 .4804 Mtetra
.66166 .4804 .66682 .48644 .6775 .48311 .67238 .47704 Mtetra
.67238 .47704 .6775 .48311 .68823 .47977 .68313 .47368 Mtetra
.68313 .47368 .68823 .47977 .699 .47642 .69393 .47031 Mtetra
.657 .753 .92 r
.69393 .47031 .699 .47642 .70981 .47306 .70477 .46692 Mtetra
.70477 .46692 .70981 .47306 .72066 .46969 .71564 .46353 Mtetra
.71564 .46353 .72066 .46969 .73155 .46631 .72656 .46012 Mtetra
.72656 .46012 .73155 .46631 .74248 .46291 .73753 .4567 Mtetra
.657 .752 .92 r
.73753 .4567 .74248 .46291 .75346 .45951 .74853 .45327 Mtetra
.74853 .45327 .75346 .45951 .76447 .45609 .75958 .44983 Mtetra
.75958 .44983 .76447 .45609 .77553 .45266 .77067 .44637 Mtetra
.77067 .44637 .77553 .45266 .78664 .44922 .7818 .44291 Mtetra
.7818 .44291 .78664 .44922 .79778 .44576 .79298 .43943 Mtetra
.79298 .43943 .79778 .44576 .80897 .44229 .80419 .43593 Mtetra
.80419 .43593 .80897 .44229 .8202 .43881 .81546 .43243 Mtetra
.81546 .43243 .8202 .43881 .83147 .43532 .82676 .42891 Mtetra
.82676 .42891 .83147 .43532 .84279 .43182 .83811 .42538 Mtetra
.83811 .42538 .84279 .43182 .85415 .4283 .84951 .42184 Mtetra
.84951 .42184 .85415 .4283 .86556 .42477 .86095 .41828 Mtetra
.86095 .41828 .86556 .42477 .87701 .42122 .87243 .41471 Mtetra
.87243 .41471 .87701 .42122 .88851 .41766 .88396 .41112 Mtetra
.88396 .41112 .88851 .41766 .90005 .41409 .89553 .40752 Mtetra
0 0 0 r
.27432 .62097 .28272 .59445 .29181 .59482 .28581 .58857 Mtetra
.586 .697 .919 r
.28581 .58857 .29181 .59482 .30108 .59333 .29508 .58725 Mtetra
.559 .694 .931 r
.29508 .58725 .30108 .59333 .30997 .59845 .30436 .58636 Mtetra
.756 .639 .732 r
.30436 .58636 .30997 .59845 .32006 .58481 .31429 .57575 Mtetra
.453 .553 .868 r
.31429 .57575 .32006 .58481 .32942 .58356 .32347 .57752 Mtetra
.604 .713 .922 r
.32347 .57752 .32942 .58356 .33884 .58191 .33292 .57578 Mtetra
.553 .692 .932 r
.33292 .57578 .33884 .58191 .34769 .59217 .34235 .57498 Mtetra
.714 .578 .701 r
.34235 .57498 .34769 .59217 .35807 .57323 .3523 .56499 Mtetra
.5 .601 .885 r
.3523 .56499 .35807 .57323 .3676 .57171 .36172 .56568 Mtetra
.613 .719 .921 r
.36172 .56568 .3676 .57171 .37719 .5697 .37133 .56369 Mtetra
.6 .716 .926 r
.37133 .56369 .37719 .5697 .38674 .5695 .38096 .56198 Mtetra
.934 .705 .568 r
.38096 .56198 .38674 .5695 .3967 .5598 .39418 .47086 Mtetra
0 0 .392 r
.39418 .47086 .3967 .5598 .40634 .55927 .40055 .55301 Mtetra
.609 .712 .918 r
.40055 .55301 .40634 .55927 .41609 .55704 .4103 .55111 Mtetra
.627 .73 .921 r
.4103 .55111 .41609 .55704 .42587 .55478 .42011 .54876 Mtetra
.61 .722 .925 r
.42011 .54876 .42587 .55478 .43565 .55398 .42995 .54677 Mtetra
.909 .508 .121 r
.42995 .54677 .43565 .55398 .4457 .54404 .43911 .57292 Mtetra
0 0 .044 r
.43911 .57292 .4457 .54404 .45554 .54389 .44986 .53749 Mtetra
.61 .711 .916 r
.44986 .53749 .45554 .54389 .46548 .54149 .45981 .53553 Mtetra
.636 .736 .92 r
.45981 .53553 .46548 .54149 .47546 .53882 .46981 .53292 Mtetra
.641 .74 .921 r
.46981 .53292 .47546 .53882 .48548 .53612 .47985 .53019 Mtetra
.637 .738 .922 r
.47985 .53019 .48548 .53612 .49553 .53368 .48993 .52754 Mtetra
.607 .721 .926 r
.48993 .52754 .49553 .53368 .50562 .53396 .50004 .52557 Mtetra
.871 .727 .701 r
.50004 .52557 .50562 .53396 .51578 .52347 .51028 .5052 Mtetra
.26 .292 .705 r
.51028 .5052 .51578 .52347 .52595 .52215 .52042 .51582 Mtetra
.625 .723 .917 r
.52042 .51582 .52595 .52215 .53616 .51943 .53065 .51343 Mtetra
.645 .742 .92 r
.53065 .51343 .53616 .51943 .5464 .51645 .54092 .51052 Mtetra
.651 .748 .92 r
.54092 .51052 .5464 .51645 .55669 .51334 .55123 .50744 Mtetra
.655 .75 .92 r
.55123 .50744 .55669 .51334 .56701 .51016 .56158 .50427 Mtetra
.657 .752 .92 r
.56158 .50427 .56701 .51016 .57737 .50693 .57197 .50103 Mtetra
.658 .753 .92 r
.57197 .50103 .57737 .50693 .58777 .50366 .58239 .49775 Mtetra
.659 .754 .92 r
.58239 .49775 .58777 .50366 .59821 .50036 .59286 .49443 Mtetra
.59286 .49443 .59821 .50036 .60869 .49705 .60336 .4911 Mtetra
.60336 .4911 .60869 .49705 .6192 .49373 .6139 .48775 Mtetra
.6139 .48775 .6192 .49373 .62976 .49041 .62448 .4844 Mtetra
.658 .753 .92 r
.62448 .4844 .62976 .49041 .64035 .48708 .6351 .48105 Mtetra
.6351 .48105 .64035 .48708 .65099 .48374 .64577 .47768 Mtetra
.64577 .47768 .65099 .48374 .66166 .4804 .65647 .47431 Mtetra
.65647 .47431 .66166 .4804 .67238 .47704 .66721 .47094 Mtetra
.66721 .47094 .67238 .47704 .68313 .47368 .678 .46755 Mtetra
.678 .46755 .68313 .47368 .69393 .47031 .68882 .46415 Mtetra
.657 .753 .92 r
.68882 .46415 .69393 .47031 .70477 .46692 .69969 .46074 Mtetra
.69969 .46074 .70477 .46692 .71564 .46353 .71059 .45732 Mtetra
.71059 .45732 .71564 .46353 .72656 .46012 .72154 .45389 Mtetra
.72154 .45389 .72656 .46012 .73753 .4567 .73254 .45045 Mtetra
.73254 .45045 .73753 .4567 .74853 .45327 .74357 .44699 Mtetra
.657 .752 .92 r
.74357 .44699 .74853 .45327 .75958 .44983 .75465 .44352 Mtetra
.75465 .44352 .75958 .44983 .77067 .44637 .76577 .44004 Mtetra
.76577 .44004 .77067 .44637 .7818 .44291 .77693 .43655 Mtetra
.77693 .43655 .7818 .44291 .79298 .43943 .78814 .43305 Mtetra
.78814 .43305 .79298 .43943 .80419 .43593 .79939 .42953 Mtetra
.79939 .42953 .80419 .43593 .81546 .43243 .81068 .426 Mtetra
.81068 .426 .81546 .43243 .82676 .42891 .82202 .42245 Mtetra
.82202 .42245 .82676 .42891 .83811 .42538 .8334 .4189 Mtetra
.8334 .4189 .83811 .42538 .84951 .42184 .84483 .41533 Mtetra
.84483 .41533 .84951 .42184 .86095 .41828 .8563 .41174 Mtetra
.8563 .41174 .86095 .41828 .87243 .41471 .86781 .40815 Mtetra
.86781 .40815 .87243 .41471 .88396 .41112 .87938 .40453 Mtetra
.87938 .40453 .88396 .41112 .89553 .40752 .89098 .40091 Mtetra
.657 .491 .648 r
.27003 .59032 .27432 .62097 .28581 .58857 .27987 .58087 Mtetra
.511 .62 .897 r
.27987 .58087 .28581 .58857 .29508 .58725 .28903 .5812 Mtetra
.593 .709 .924 r
.28903 .5812 .29508 .58725 .30436 .58636 .29837 .57967 Mtetra
.014 .38 .843 r
.29837 .57967 .30436 .58636 .31429 .57575 .30733 .58478 Mtetra
.603 .834 .453 r
.30733 .58478 .31429 .57575 .32347 .57752 .31751 .57104 Mtetra
.583 .692 .916 r
.31751 .57104 .32347 .57752 .33292 .57578 .32694 .56975 Mtetra
.599 .714 .925 r
.32694 .56975 .33292 .57578 .34235 .57498 .33644 .56806 Mtetra
0 0 .472 r
.33644 .56806 .34235 .57498 .3523 .56499 .34535 .57832 Mtetra
0 0 0 r
.34535 .57832 .3523 .56499 .36172 .56568 .35583 .55926 Mtetra
.595 .7 .917 r
.35583 .55926 .36172 .56568 .37133 .56369 .36543 .55769 Mtetra
.615 .722 .923 r
.36543 .55769 .37133 .56369 .38096 .56198 .37509 .55564 Mtetra
.52 .675 .935 r
.37509 .55564 .38096 .56198 .39418 .47086 .38472 .5554 Mtetra
.501 .265 .488 r
.38472 .5554 .39418 .47086 .40055 .55301 .39477 .54562 Mtetra
.553 .654 .902 r
.39477 .54562 .40055 .55301 .4103 .55111 .40449 .54505 Mtetra
.623 .726 .92 r
.40449 .54505 .4103 .55111 .42011 .54876 .41431 .54277 Mtetra
.624 .729 .922 r
.41431 .54277 .42011 .54876 .42995 .54677 .42418 .54046 Mtetra
.552 .692 .932 r
.42418 .54046 .42995 .54677 .43911 .57292 .43404 .53962 Mtetra
.653 .483 .642 r
.43404 .53962 .43911 .57292 .44986 .53749 .44418 .5296 Mtetra
.538 .634 .894 r
.44418 .5296 .44986 .53749 .45981 .53553 .4541 .5294 Mtetra
.629 .729 .919 r
.4541 .5294 .45981 .53553 .46981 .53292 .46412 .52695 Mtetra
.639 .739 .92 r
.46412 .52695 .46981 .53292 .47985 .53019 .47418 .52423 Mtetra
.64 .74 .921 r
.47418 .52423 .47985 .53019 .48993 .52754 .48429 .52148 Mtetra
.629 .733 .923 r
.48429 .52148 .48993 .52754 .50004 .52557 .49443 .51899 Mtetra
.492 .659 .935 r
.49443 .51899 .50004 .52557 .51028 .5052 .50459 .51923 Mtetra
.109 0 .109 r
.50459 .51923 .51028 .5052 .52042 .51582 .51485 .50866 Mtetra
.585 .68 .907 r
.51485 .50866 .52042 .51582 .53065 .51343 .5251 .50728 Mtetra
.639 .736 .919 r
.5251 .50728 .53065 .51343 .54092 .51052 .5354 .50451 Mtetra
.649 .745 .92 r
.5354 .50451 .54092 .51052 .55123 .50744 .54573 .50147 Mtetra
.653 .749 .92 r
.54573 .50147 .55123 .50744 .56158 .50427 .55611 .49831 Mtetra
.656 .751 .92 r
.55611 .49831 .56158 .50427 .57197 .50103 .56652 .49508 Mtetra
.657 .753 .92 r
.56652 .49508 .57197 .50103 .58239 .49775 .57697 .49179 Mtetra
.658 .753 .92 r
.57697 .49179 .58239 .49775 .59286 .49443 .58746 .48846 Mtetra
.659 .754 .92 r
.58746 .48846 .59286 .49443 .60336 .4911 .59799 .4851 Mtetra
.59799 .4851 .60336 .4911 .6139 .48775 .60856 .48174 Mtetra
.60856 .48174 .6139 .48775 .62448 .4844 .61917 .47836 Mtetra
.658 .754 .92 r
.61917 .47836 .62448 .4844 .6351 .48105 .62982 .47498 Mtetra
.658 .753 .92 r
.62982 .47498 .6351 .48105 .64577 .47768 .64051 .47159 Mtetra
.64051 .47159 .64577 .47768 .65647 .47431 .65124 .46819 Mtetra
.65124 .46819 .65647 .47431 .66721 .47094 .66201 .46479 Mtetra
.66201 .46479 .66721 .47094 .678 .46755 .67282 .46137 Mtetra
.67282 .46137 .678 .46755 .68882 .46415 .68368 .45795 Mtetra
.68368 .45795 .68882 .46415 .69969 .46074 .69457 .45452 Mtetra
.657 .753 .92 r
.69457 .45452 .69969 .46074 .71059 .45732 .70551 .45107 Mtetra
.70551 .45107 .71059 .45732 .72154 .45389 .71649 .44761 Mtetra
.71649 .44761 .72154 .45389 .73254 .45045 .72751 .44415 Mtetra
.72751 .44415 .73254 .45045 .74357 .44699 .73857 .44066 Mtetra
.657 .752 .92 r
.73857 .44066 .74357 .44699 .75465 .44352 .74968 .43717 Mtetra
.74968 .43717 .75465 .44352 .76577 .44004 .76083 .43367 Mtetra
.76083 .43367 .76577 .44004 .77693 .43655 .77202 .43015 Mtetra
.77202 .43015 .77693 .43655 .78814 .43305 .78326 .42662 Mtetra
.78326 .42662 .78814 .43305 .79939 .42953 .79454 .42308 Mtetra
.79454 .42308 .79939 .42953 .81068 .426 .80587 .41952 Mtetra
.80587 .41952 .81068 .426 .82202 .42245 .81724 .41595 Mtetra
.81724 .41595 .82202 .42245 .8334 .4189 .82865 .41237 Mtetra
.82865 .41237 .8334 .4189 .84483 .41533 .84011 .40877 Mtetra
.84011 .40877 .84483 .41533 .8563 .41174 .85161 .40516 Mtetra
.85161 .40516 .8563 .41174 .86781 .40815 .86316 .40154 Mtetra
.86316 .40154 .86781 .40815 .87938 .40453 .87476 .3979 Mtetra
.87476 .3979 .87938 .40453 .89098 .40091 .8864 .39425 Mtetra
.927 .541 .208 r
.26399 .58322 .27003 .59032 .27987 .58087 .27137 .60744 Mtetra
0 0 0 r
.27137 .60744 .27987 .58087 .28903 .5812 .28297 .57486 Mtetra
.586 .697 .919 r
.28297 .57486 .28903 .5812 .29837 .57967 .29231 .5735 Mtetra
.559 .694 .931 r
.29231 .5735 .29837 .57967 .30733 .58478 .30167 .57257 Mtetra
.756 .64 .732 r
.30167 .57257 .30733 .58478 .31751 .57104 .31168 .56187 Mtetra
.452 .553 .868 r
.31168 .56187 .31751 .57104 .32694 .56975 .32094 .56362 Mtetra
.604 .713 .922 r
.32094 .56362 .32694 .56975 .33644 .56806 .33045 .56182 Mtetra
.553 .692 .932 r
.33045 .56182 .33644 .56806 .34535 .57832 .33996 .56099 Mtetra
.714 .578 .701 r
.33996 .56099 .34535 .57832 .35583 .55926 .34999 .55091 Mtetra
.5 .601 .886 r
.34999 .55091 .35583 .55926 .36543 .55769 .3595 .55157 Mtetra
.613 .719 .921 r
.3595 .55157 .36543 .55769 .37509 .55564 .36918 .54954 Mtetra
.6 .716 .926 r
.36918 .54954 .37509 .55564 .38472 .5554 .37889 .54777 Mtetra
.935 .705 .566 r
.37889 .54777 .38472 .5554 .39477 .54562 .39227 .45625 Mtetra
0 0 .388 r
.39227 .45625 .39477 .54562 .40449 .54505 .39864 .53869 Mtetra
.609 .712 .918 r
.39864 .53869 .40449 .54505 .41431 .54277 .40847 .53674 Mtetra
.627 .73 .921 r
.40847 .53674 .41431 .54277 .42418 .54046 .41836 .53434 Mtetra
.61 .722 .925 r
.41836 .53434 .42418 .54046 .43404 .53962 .42828 .53231 Mtetra
.907 .505 .113 r
.42828 .53231 .43404 .53962 .44418 .5296 .43751 .55853 Mtetra
0 0 .036 r
.43751 .55853 .44418 .5296 .4541 .5294 .44836 .52291 Mtetra
.61 .711 .916 r
.44836 .52291 .4541 .5294 .46412 .52695 .45839 .52089 Mtetra
.636 .736 .92 r
.45839 .52089 .46412 .52695 .47418 .52423 .46848 .51823 Mtetra
.641 .74 .921 r
.46848 .51823 .47418 .52423 .48429 .52148 .4786 .51545 Mtetra
.637 .738 .922 r
.4786 .51545 .48429 .52148 .49443 .51899 .48877 .51275 Mtetra
.607 .721 .926 r
.48877 .51275 .49443 .51899 .50459 .51923 .49897 .51073 Mtetra
.872 .728 .701 r
.49897 .51073 .50459 .51923 .51485 .50866 .5093 .49023 Mtetra
.258 .29 .705 r
.5093 .49023 .51485 .50866 .5251 .50728 .51952 .50085 Mtetra
.625 .723 .917 r
.51952 .50085 .5251 .50728 .5354 .50451 .52984 .49841 Mtetra
.645 .742 .92 r
.52984 .49841 .5354 .50451 .54573 .50147 .5402 .49544 Mtetra
.651 .748 .92 r
.5402 .49544 .54573 .50147 .55611 .49831 .5506 .49231 Mtetra
.655 .75 .92 r
.5506 .49231 .55611 .49831 .56652 .49508 .56104 .48908 Mtetra
.657 .752 .92 r
.56104 .48908 .56652 .49508 .57697 .49179 .57152 .48578 Mtetra
.658 .753 .92 r
.57152 .48578 .57697 .49179 .58746 .48846 .58203 .48244 Mtetra
.659 .754 .92 r
.58203 .48244 .58746 .48846 .59799 .4851 .59259 .47907 Mtetra
.59259 .47907 .59799 .4851 .60856 .48174 .60319 .47568 Mtetra
.60319 .47568 .60856 .48174 .61917 .47836 .61382 .47227 Mtetra
.61382 .47227 .61917 .47836 .62982 .47498 .6245 .46886 Mtetra
.658 .753 .92 r
.6245 .46886 .62982 .47498 .64051 .47159 .63522 .46545 Mtetra
.63522 .46545 .64051 .47159 .65124 .46819 .64598 .46202 Mtetra
.64598 .46202 .65124 .46819 .66201 .46479 .65677 .45859 Mtetra
.65677 .45859 .66201 .46479 .67282 .46137 .66762 .45516 Mtetra
.66762 .45516 .67282 .46137 .68368 .45795 .6785 .45171 Mtetra
.6785 .45171 .68368 .45795 .69457 .45452 .68942 .44825 Mtetra
.657 .753 .92 r
.68942 .44825 .69457 .45452 .70551 .45107 .70039 .44478 Mtetra
.70039 .44478 .70551 .45107 .71649 .44761 .7114 .44129 Mtetra
.7114 .44129 .71649 .44761 .72751 .44415 .72245 .4378 Mtetra
.72245 .4378 .72751 .44415 .73857 .44066 .73354 .43429 Mtetra
.73354 .43429 .73857 .44066 .74968 .43717 .74468 .43078 Mtetra
.657 .752 .92 r
.74468 .43078 .74968 .43717 .76083 .43367 .75586 .42725 Mtetra
.75586 .42725 .76083 .43367 .77202 .43015 .76708 .4237 Mtetra
.76708 .4237 .77202 .43015 .78326 .42662 .77835 .42015 Mtetra
.77835 .42015 .78326 .42662 .79454 .42308 .78966 .41658 Mtetra
.78966 .41658 .79454 .42308 .80587 .41952 .80102 .41299 Mtetra
.80102 .41299 .80587 .41952 .81724 .41595 .81242 .4094 Mtetra
.81242 .4094 .81724 .41595 .82865 .41237 .82387 .40579 Mtetra
.82387 .40579 .82865 .41237 .84011 .40877 .83536 .40217 Mtetra
.83536 .40217 .84011 .40877 .85161 .40516 .8469 .39853 Mtetra
.8469 .39853 .85161 .40516 .86316 .40154 .85848 .39488 Mtetra
.85848 .39488 .86316 .40154 .87476 .3979 .87011 .39121 Mtetra
.87011 .39121 .87476 .3979 .8864 .39425 .88178 .38754 Mtetra
.526 .678 .934 r
.25784 .57695 .26399 .58322 .27137 .60744 .26705 .57659 Mtetra
.656 .49 .647 r
.26705 .57659 .27137 .60744 .28297 .57486 .27698 .56705 Mtetra
.51 .62 .897 r
.27698 .56705 .28297 .57486 .29231 .5735 .28621 .56735 Mtetra
.593 .709 .924 r
.28621 .56735 .29231 .5735 .30167 .57257 .29562 .56578 Mtetra
.019 .382 .845 r
.29562 .56578 .30167 .57257 .31168 .56187 .30464 .57087 Mtetra
.613 .842 .464 r
.30464 .57087 .31168 .56187 .32094 .56362 .31492 .55703 Mtetra
.583 .692 .916 r
.31492 .55703 .32094 .56362 .33045 .56182 .32442 .5557 Mtetra
.599 .714 .925 r
.32442 .5557 .33045 .56182 .33996 .56099 .33399 .55396 Mtetra
0 0 .48 r
.33399 .55396 .33996 .56099 .34999 .55091 .34296 .56424 Mtetra
0 0 0 r
.34296 .56424 .34999 .55091 .3595 .55157 .35354 .54505 Mtetra
.595 .7 .917 r
.35354 .54505 .3595 .55157 .36918 .54954 .36322 .54344 Mtetra
.615 .722 .923 r
.36322 .54344 .36918 .54954 .37889 .54777 .37296 .54134 Mtetra
.52 .675 .935 r
.37296 .54134 .37889 .54777 .39227 .45625 .38267 .54105 Mtetra
.497 .26 .485 r
.38267 .54105 .39227 .45625 .39864 .53869 .39281 .5312 Mtetra
.553 .654 .903 r
.39281 .5312 .39864 .53869 .40847 .53674 .4026 .53058 Mtetra
.623 .726 .92 r
.4026 .53058 .40847 .53674 .41836 .53434 .41251 .52826 Mtetra
.624 .729 .922 r
.41251 .52826 .41836 .53434 .42828 .53231 .42245 .52589 Mtetra
.553 .692 .932 r
.42245 .52589 .42828 .53231 .43751 .55853 .4324 .52501 Mtetra
.652 .482 .641 r
.4324 .52501 .43751 .55853 .44836 .52291 .44262 .5149 Mtetra
.538 .634 .894 r
.44262 .5149 .44836 .52291 .45839 .52089 .45263 .51467 Mtetra
.629 .729 .919 r
.45263 .51467 .45839 .52089 .46848 .51823 .46273 .51216 Mtetra
.639 .739 .92 r
.46273 .51216 .46848 .51823 .4786 .51545 .47288 .50939 Mtetra
.64 .74 .921 r
.47288 .50939 .4786 .51545 .48877 .51275 .48307 .50659 Mtetra
.629 .733 .923 r
.48307 .50659 .48877 .51275 .49897 .51073 .4933 .50404 Mtetra
.492 .659 .935 r
.4933 .50404 .49897 .51073 .5093 .49023 .50355 .50424 Mtetra
.098 0 .098 r
.50355 .50424 .5093 .49023 .51952 .50085 .5139 .49358 Mtetra
.585 .68 .907 r
.5139 .49358 .51952 .50085 .52984 .49841 .52424 .49215 Mtetra
.639 .736 .919 r
.52424 .49215 .52984 .49841 .5402 .49544 .53462 .48933 Mtetra
.649 .745 .92 r
.53462 .48933 .5402 .49544 .5506 .49231 .54505 .48623 Mtetra
.653 .749 .92 r
.54505 .48623 .5506 .49231 .56104 .48908 .55552 .48302 Mtetra
.656 .751 .92 r
.55552 .48302 .56104 .48908 .57152 .48578 .56602 .47972 Mtetra
.657 .753 .92 r
.56602 .47972 .57152 .48578 .58203 .48244 .57657 .47638 Mtetra
.658 .753 .92 r
.57657 .47638 .58203 .48244 .59259 .47907 .58715 .47299 Mtetra
.659 .754 .92 r
.58715 .47299 .59259 .47907 .60319 .47568 .59777 .46957 Mtetra
.59777 .46957 .60319 .47568 .61382 .47227 .60844 .46615 Mtetra
.60844 .46615 .61382 .47227 .6245 .46886 .61914 .46271 Mtetra
.658 .754 .92 r
.61914 .46271 .6245 .46886 .63522 .46545 .62989 .45927 Mtetra
.658 .753 .92 r
.62989 .45927 .63522 .46545 .64598 .46202 .64067 .45582 Mtetra
.64067 .45582 .64598 .46202 .65677 .45859 .6515 .45236 Mtetra
.6515 .45236 .65677 .45859 .66762 .45516 .66237 .44889 Mtetra
.66237 .44889 .66762 .45516 .6785 .45171 .67328 .44542 Mtetra
.67328 .44542 .6785 .45171 .68942 .44825 .68423 .44193 Mtetra
.68423 .44193 .68942 .44825 .70039 .44478 .69523 .43844 Mtetra
.657 .753 .92 r
.69523 .43844 .70039 .44478 .7114 .44129 .70627 .43493 Mtetra
.70627 .43493 .7114 .44129 .72245 .4378 .71735 .43141 Mtetra
.71735 .43141 .72245 .4378 .73354 .43429 .72847 .42788 Mtetra
.72847 .42788 .73354 .43429 .74468 .43078 .73964 .42433 Mtetra
.657 .752 .92 r
.73964 .42433 .74468 .43078 .75586 .42725 .75085 .42078 Mtetra
.75085 .42078 .75586 .42725 .76708 .4237 .76211 .41721 Mtetra
.76211 .41721 .76708 .4237 .77835 .42015 .77341 .41362 Mtetra
.77341 .41362 .77835 .42015 .78966 .41658 .78475 .41003 Mtetra
.78475 .41003 .78966 .41658 .80102 .41299 .79614 .40642 Mtetra
.79614 .40642 .80102 .41299 .81242 .4094 .80757 .4028 Mtetra
.80757 .4028 .81242 .4094 .82387 .40579 .81905 .39916 Mtetra
.81905 .39916 .82387 .40579 .83536 .40217 .83057 .39551 Mtetra
.83057 .39551 .83536 .40217 .8469 .39853 .84214 .39185 Mtetra
.84214 .39185 .8469 .39853 .85848 .39488 .85376 .38817 Mtetra
.85376 .38817 .85848 .39488 .87011 .39121 .86542 .38448 Mtetra
.86542 .38448 .87011 .39121 .88178 .38754 .87713 .38077 Mtetra
.581 .702 .925 r
.25166 .57073 .25784 .57695 .26705 .57659 .26095 .56939 Mtetra
.926 .539 .202 r
.26095 .56939 .26705 .57659 .27698 .56705 .26837 .59368 Mtetra
0 0 0 r
.26837 .59368 .27698 .56705 .28621 .56735 .28009 .56092 Mtetra
.586 .697 .919 r
.28009 .56092 .28621 .56735 .29562 .56578 .2895 .55951 Mtetra
.559 .694 .93 r
.2895 .55951 .29562 .56578 .30464 .57087 .29893 .55854 Mtetra
.757 .64 .732 r
.29893 .55854 .30464 .57087 .31492 .55703 .30903 .54775 Mtetra
.451 .553 .868 r
.30903 .54775 .31492 .55703 .32442 .5557 .31836 .54947 Mtetra
.604 .713 .922 r
.31836 .54947 .32442 .5557 .33399 .55396 .32795 .54763 Mtetra
.553 .692 .932 r
.32795 .54763 .33399 .55396 .34296 .56424 .33753 .54675 Mtetra
.714 .578 .701 r
.33753 .54675 .34296 .56424 .35354 .54505 .34765 .53659 Mtetra
.499 .601 .886 r
.34765 .53659 .35354 .54505 .36322 .54344 .35723 .53721 Mtetra
.613 .719 .921 r
.35723 .53721 .36322 .54344 .37296 .54134 .36699 .53513 Mtetra
.6 .716 .926 r
.36699 .53513 .37296 .54134 .38267 .54105 .37678 .53332 Mtetra
.936 .706 .564 r
.37678 .53332 .38267 .54105 .39281 .5312 .39033 .44138 Mtetra
0 0 .384 r
.39033 .44138 .39281 .5312 .4026 .53058 .3967 .52412 Mtetra
.609 .712 .918 r
.3967 .52412 .4026 .53058 .41251 .52826 .40661 .52212 Mtetra
.627 .73 .921 r
.40661 .52212 .41251 .52826 .42245 .52589 .41658 .51967 Mtetra
.61 .722 .925 r
.41658 .51967 .42245 .52589 .4324 .52501 .42658 .51759 Mtetra
.905 .501 .106 r
.42658 .51759 .4324 .52501 .44262 .5149 .43587 .54388 Mtetra
0 0 .028 r
.43587 .54388 .44262 .5149 .45263 .51467 .44684 .50807 Mtetra
.61 .711 .916 r
.44684 .50807 .45263 .51467 .46273 .51216 .45695 .506 Mtetra
.636 .736 .92 r
.45695 .506 .46273 .51216 .47288 .50939 .46712 .50328 Mtetra
.641 .74 .921 r
.46712 .50328 .47288 .50939 .48307 .50659 .47733 .50045 Mtetra
.637 .738 .922 r
.47733 .50045 .48307 .50659 .4933 .50404 .48759 .49769 Mtetra
.607 .721 .926 r
.48759 .49769 .4933 .50404 .50355 .50424 .49788 .49562 Mtetra
.873 .729 .7 r
.49788 .49562 .50355 .50424 .5139 .49358 .5083 .475 Mtetra
.255 .289 .704 r
.5083 .475 .5139 .49358 .52424 .49215 .5186 .48562 Mtetra
.625 .723 .917 r
.5186 .48562 .52424 .49215 .53462 .48933 .52901 .48312 Mtetra
.645 .742 .92 r
.52901 .48312 .53462 .48933 .54505 .48623 .53946 .4801 Mtetra
.651 .748 .92 r
.53946 .4801 .54505 .48623 .55552 .48302 .54996 .4769 Mtetra
.655 .75 .92 r
.54996 .4769 .55552 .48302 .56602 .47972 .56049 .47361 Mtetra
.657 .752 .92 r
.56049 .47361 .56602 .47972 .57657 .47638 .57106 .47026 Mtetra
.658 .753 .92 r
.57106 .47026 .57657 .47638 .58715 .47299 .58167 .46686 Mtetra
.659 .754 .92 r
.58167 .46686 .58715 .47299 .59777 .46957 .59232 .46343 Mtetra
.59232 .46343 .59777 .46957 .60844 .46615 .60301 .45998 Mtetra
.60301 .45998 .60844 .46615 .61914 .46271 .61374 .45651 Mtetra
.61374 .45651 .61914 .46271 .62989 .45927 .62452 .45304 Mtetra
.658 .753 .92 r
.62452 .45304 .62989 .45927 .64067 .45582 .63533 .44956 Mtetra
.63533 .44956 .64067 .45582 .6515 .45236 .64619 .44608 Mtetra
.64619 .44608 .6515 .45236 .66237 .44889 .65709 .44259 Mtetra
.65709 .44259 .66237 .44889 .67328 .44542 .66803 .43909 Mtetra
.66803 .43909 .67328 .44542 .68423 .44193 .67901 .43558 Mtetra
.67901 .43558 .68423 .44193 .69523 .43844 .69003 .43205 Mtetra
.657 .753 .92 r
.69003 .43205 .69523 .43844 .70627 .43493 .7011 .42852 Mtetra
.7011 .42852 .70627 .43493 .71735 .43141 .71221 .42497 Mtetra
.71221 .42497 .71735 .43141 .72847 .42788 .72337 .42142 Mtetra
.72337 .42142 .72847 .42788 .73964 .42433 .73457 .41785 Mtetra
.73457 .41785 .73964 .42433 .75085 .42078 .74581 .41426 Mtetra
.657 .752 .92 r
.74581 .41426 .75085 .42078 .76211 .41721 .75709 .41067 Mtetra
.75709 .41067 .76211 .41721 .77341 .41362 .76842 .40706 Mtetra
.76842 .40706 .77341 .41362 .78475 .41003 .7798 .40344 Mtetra
.7798 .40344 .78475 .41003 .79614 .40642 .79122 .3998 Mtetra
.79122 .3998 .79614 .40642 .80757 .4028 .80269 .39615 Mtetra
.80269 .39615 .80757 .4028 .81905 .39916 .8142 .39249 Mtetra
.8142 .39249 .81905 .39916 .83057 .39551 .82575 .38881 Mtetra
.82575 .38881 .83057 .39551 .84214 .39185 .83736 .38512 Mtetra
.83736 .38512 .84214 .39185 .85376 .38817 .84901 .38142 Mtetra
.84901 .38142 .85376 .38817 .86542 .38448 .8607 .3777 Mtetra
.8607 .3777 .86542 .38448 .87713 .38077 .87245 .37396 Mtetra
.573 .688 .919 r
.24545 .56417 .25166 .57073 .26095 .56939 .25475 .56302 Mtetra
.526 .678 .934 r
.25475 .56302 .26095 .56939 .26837 .59368 .26403 .56262 Mtetra
.656 .489 .647 r
.26403 .56262 .26837 .59368 .28009 .56092 .27404 .553 Mtetra
.51 .62 .897 r
.27404 .553 .28009 .56092 .2895 .55951 .28334 .55327 Mtetra
.593 .709 .924 r
.28334 .55327 .2895 .55951 .29893 .55854 .29283 .55165 Mtetra
.023 .385 .846 r
.29283 .55165 .29893 .55854 .30903 .54775 .30191 .55672 Mtetra
.623 .85 .474 r
.30191 .55672 .30903 .54775 .31836 .54947 .31228 .54279 Mtetra
.583 .692 .916 r
.31228 .54279 .31836 .54947 .32795 .54763 .32186 .54141 Mtetra
.599 .714 .925 r
.32186 .54141 .32795 .54763 .33753 .54675 .33151 .53962 Mtetra
0 0 .487 r
.33151 .53962 .33753 .54675 .34765 .53659 .34054 .54991 Mtetra
0 0 0 r
.34054 .54991 .34765 .53659 .35723 .53721 .35122 .53059 Mtetra
.594 .7 .917 r
.35122 .53059 .35723 .53721 .36699 .53513 .36097 .52894 Mtetra
.615 .722 .923 r
.36097 .52894 .36699 .53513 .37678 .53332 .3708 .52679 Mtetra
.52 .675 .935 r
.3708 .52679 .37678 .53332 .39033 .44138 .38058 .52646 Mtetra
.494 .255 .481 r
.38058 .52646 .39033 .44138 .3967 .52412 .39081 .51652 Mtetra
.552 .654 .903 r
.39081 .51652 .3967 .52412 .40661 .52212 .40068 .51586 Mtetra
.623 .726 .92 r
.40068 .51586 .40661 .52212 .41658 .51967 .41067 .51349 Mtetra
.624 .729 .922 r
.41067 .51349 .41658 .51967 .42658 .51759 .4207 .51107 Mtetra
.553 .692 .932 r
.4207 .51107 .42658 .51759 .43587 .54388 .43073 .51014 Mtetra
.652 .481 .64 r
.43073 .51014 .43587 .54388 .44684 .50807 .44104 .49995 Mtetra
.538 .634 .894 r
.44104 .49995 .44684 .50807 .45695 .506 .45113 .49967 Mtetra
.629 .729 .919 r
.45113 .49967 .45695 .506 .46712 .50328 .46132 .49711 Mtetra
.639 .739 .92 r
.46132 .49711 .46712 .50328 .47733 .50045 .47156 .49428 Mtetra
.64 .74 .921 r
.47156 .49428 .47733 .50045 .48759 .49769 .48184 .49143 Mtetra
.629 .733 .923 r
.48184 .49143 .48759 .49769 .49788 .49562 .49215 .48883 Mtetra
.493 .659 .935 r
.49215 .48883 .49788 .49562 .5083 .475 .50249 .48898 Mtetra
.086 0 .086 r
.50249 .48898 .5083 .475 .5186 .48562 .51293 .47823 Mtetra
.584 .68 .907 r
.51293 .47823 .5186 .48562 .52901 .48312 .52336 .47676 Mtetra
.639 .736 .919 r
.52336 .47676 .52901 .48312 .53946 .4801 .53384 .47388 Mtetra
.649 .745 .92 r
.53384 .47388 .53946 .4801 .54996 .4769 .54436 .47072 Mtetra
.653 .749 .92 r
.54436 .47072 .54996 .4769 .56049 .47361 .55491 .46745 Mtetra
.656 .751 .92 r
.55491 .46745 .56049 .47361 .57106 .47026 .56551 .46409 Mtetra
.657 .753 .92 r
.56551 .46409 .57106 .47026 .58167 .46686 .57615 .46069 Mtetra
.658 .753 .92 r
.57615 .46069 .58167 .46686 .59232 .46343 .58683 .45724 Mtetra
.659 .754 .92 r
.58683 .45724 .59232 .46343 .60301 .45998 .59755 .45376 Mtetra
.59755 .45376 .60301 .45998 .61374 .45651 .60831 .45027 Mtetra
.60831 .45027 .61374 .45651 .62452 .45304 .61911 .44677 Mtetra
.658 .754 .92 r
.61911 .44677 .62452 .45304 .63533 .44956 .62995 .44327 Mtetra
.658 .753 .92 r
.62995 .44327 .63533 .44956 .64619 .44608 .64084 .43976 Mtetra
.64084 .43976 .64619 .44608 .65709 .44259 .65176 .43624 Mtetra
.65176 .43624 .65709 .44259 .66803 .43909 .66273 .43271 Mtetra
.66273 .43271 .66803 .43909 .67901 .43558 .67375 .42917 Mtetra
.67375 .42917 .67901 .43558 .69003 .43205 .6848 .42562 Mtetra
.6848 .42562 .69003 .43205 .7011 .42852 .6959 .42206 Mtetra
.657 .753 .92 r
.6959 .42206 .7011 .42852 .71221 .42497 .70704 .41849 Mtetra
.70704 .41849 .71221 .42497 .72337 .42142 .71822 .41491 Mtetra
.71822 .41491 .72337 .42142 .73457 .41785 .72945 .41131 Mtetra
.72945 .41131 .73457 .41785 .74581 .41426 .74073 .4077 Mtetra
.657 .752 .92 r
.74073 .4077 .74581 .41426 .75709 .41067 .75204 .40408 Mtetra
.75204 .40408 .75709 .41067 .76842 .40706 .76341 .40044 Mtetra
.76341 .40044 .76842 .40706 .7798 .40344 .77481 .39679 Mtetra
.77481 .39679 .7798 .40344 .79122 .3998 .78627 .39313 Mtetra
.78627 .39313 .79122 .3998 .80269 .39615 .79776 .38945 Mtetra
.79776 .38945 .80269 .39615 .8142 .39249 .80931 .38576 Mtetra
.80931 .38576 .8142 .39249 .82575 .38881 .8209 .38206 Mtetra
.8209 .38206 .82575 .38881 .83736 .38512 .83253 .37834 Mtetra
.83253 .37834 .83736 .38512 .84901 .38142 .84422 .37461 Mtetra
.84422 .37461 .84901 .38142 .8607 .3777 .85595 .37086 Mtetra
.85595 .37086 .8607 .3777 .87245 .37396 .86773 .3671 Mtetra
.459 .571 .88 r
.2394 .55537 .24545 .56417 .25475 .56302 .2485 .55671 Mtetra
.581 .702 .925 r
.2485 .55671 .25475 .56302 .26403 .56262 .25787 .55532 Mtetra
.925 .536 .196 r
.25787 .55532 .26403 .56262 .27404 .553 .26531 .57968 Mtetra
0 0 0 r
.26531 .57968 .27404 .553 .28334 .55327 .27716 .54673 Mtetra
.585 .697 .919 r
.27716 .54673 .28334 .55327 .29283 .55165 .28665 .54528 Mtetra
.56 .694 .93 r
.28665 .54528 .29283 .55165 .30191 .55672 .29615 .54427 Mtetra
.757 .641 .732 r
.29615 .54427 .30191 .55672 .31228 .54279 .30633 .53339 Mtetra
.451 .553 .868 r
.30633 .53339 .31228 .54279 .32186 .54141 .31573 .53508 Mtetra
.604 .713 .922 r
.31573 .53508 .32186 .54141 .33151 .53962 .3254 .53319 Mtetra
.553 .692 .931 r
.3254 .53319 .33151 .53962 .34054 .54991 .33506 .53227 Mtetra
.714 .578 .701 r
.33506 .53227 .34054 .54991 .35122 .53059 .34527 .52203 Mtetra
.499 .601 .886 r
.34527 .52203 .35122 .53059 .36097 .52894 .35492 .52261 Mtetra
.613 .719 .921 r
.35492 .52261 .36097 .52894 .3708 .52679 .36476 .52048 Mtetra
.6 .716 .926 r
.36476 .52048 .3708 .52679 .38058 .52646 .37463 .51862 Mtetra
.937 .706 .562 r
.37463 .51862 .38058 .52646 .39081 .51652 .38835 .42626 Mtetra
0 0 .379 r
.38835 .42626 .39081 .51652 .40068 .51586 .39473 .50929 Mtetra
.609 .712 .918 r
.39473 .50929 .40068 .51586 .41067 .51349 .40472 .50725 Mtetra
.627 .73 .921 r
.40472 .50725 .41067 .51349 .4207 .51107 .41477 .50475 Mtetra
.61 .722 .925 r
.41477 .50475 .4207 .51107 .43073 .51014 .42485 .50261 Mtetra
.902 .498 .098 r
.42485 .50261 .43073 .51014 .44104 .49995 .43421 .52898 Mtetra
0 0 .019 r
.43421 .52898 .44104 .49995 .45113 .49967 .44528 .49296 Mtetra
.61 .711 .916 r
.44528 .49296 .45113 .49967 .46132 .49711 .45548 .49084 Mtetra
.636 .736 .92 r
.45548 .49084 .46132 .49711 .47156 .49428 .46574 .48807 Mtetra
.641 .74 .921 r
.46574 .48807 .47156 .49428 .48184 .49143 .47604 .48518 Mtetra
.637 .738 .922 r
.47604 .48518 .48184 .49143 .49215 .48883 .48638 .48237 Mtetra
.607 .721 .925 r
.48638 .48237 .49215 .48883 .50249 .48898 .49676 .48024 Mtetra
.874 .73 .7 r
.49676 .48024 .50249 .48898 .51293 .47823 .50729 .45949 Mtetra
.253 .287 .704 r
.50729 .45949 .51293 .47823 .52336 .47676 .51767 .47011 Mtetra
.625 .723 .917 r
.51767 .47011 .52336 .47676 .53384 .47388 .52817 .46756 Mtetra
.645 .742 .92 r
.52817 .46756 .53384 .47388 .54436 .47072 .53872 .46447 Mtetra
.651 .748 .92 r
.53872 .46447 .54436 .47072 .55491 .46745 .5493 .46122 Mtetra
.655 .75 .92 r
.5493 .46122 .55491 .46745 .56551 .46409 .55993 .45787 Mtetra
.657 .752 .92 r
.55993 .45787 .56551 .46409 .57615 .46069 .57059 .45446 Mtetra
.658 .753 .92 r
.57059 .45446 .57615 .46069 .58683 .45724 .5813 .451 Mtetra
.659 .754 .92 r
.5813 .451 .58683 .45724 .59755 .45376 .59205 .4475 Mtetra
.59205 .4475 .59755 .45376 .60831 .45027 .60283 .44399 Mtetra
.60283 .44399 .60831 .45027 .61911 .44677 .61366 .44046 Mtetra
.61366 .44046 .61911 .44677 .62995 .44327 .62454 .43693 Mtetra
.658 .753 .92 r
.62454 .43693 .62995 .44327 .64084 .43976 .63545 .43339 Mtetra
.63545 .43339 .64084 .43976 .65176 .43624 .6464 .42984 Mtetra
.6464 .42984 .65176 .43624 .66273 .43271 .6574 .42629 Mtetra
.6574 .42629 .66273 .43271 .67375 .42917 .66844 .42272 Mtetra
.66844 .42272 .67375 .42917 .6848 .42562 .67953 .41915 Mtetra
.67953 .41915 .6848 .42562 .6959 .42206 .69066 .41556 Mtetra
.657 .753 .92 r
.69066 .41556 .6959 .42206 .70704 .41849 .70183 .41196 Mtetra
.70183 .41196 .70704 .41849 .71822 .41491 .71304 .40835 Mtetra
.71304 .40835 .71822 .41491 .72945 .41131 .7243 .40473 Mtetra
.7243 .40473 .72945 .41131 .74073 .4077 .73561 .40109 Mtetra
.73561 .40109 .74073 .4077 .75204 .40408 .74696 .39744 Mtetra
.657 .752 .92 r
.74696 .39744 .75204 .40408 .76341 .40044 .75835 .39378 Mtetra
.75835 .39378 .76341 .40044 .77481 .39679 .76979 .3901 Mtetra
.76979 .3901 .77481 .39679 .78627 .39313 .78128 .38641 Mtetra
.78128 .38641 .78627 .39313 .79776 .38945 .79281 .38271 Mtetra
.79281 .38271 .79776 .38945 .80931 .38576 .80438 .37899 Mtetra
.80438 .37899 .80931 .38576 .8209 .38206 .81601 .37526 Mtetra
.81601 .37526 .8209 .38206 .83253 .37834 .82768 .37151 Mtetra
.82768 .37151 .83253 .37834 .84422 .37461 .83939 .36775 Mtetra
.83939 .36775 .84422 .37461 .85595 .37086 .85116 .36398 Mtetra
.85116 .36398 .85595 .37086 .86773 .3671 .86297 .36019 Mtetra
.681 .87 .48 r
.23165 .56583 .2394 .55537 .2485 .55671 .24223 .55004 Mtetra
.573 .688 .919 r
.24223 .55004 .2485 .55671 .25787 .55532 .2516 .54885 Mtetra
.526 .678 .934 r
.2516 .54885 .25787 .55532 .26531 .57968 .26095 .54841 Mtetra
.655 .488 .646 r
.26095 .54841 .26531 .57968 .27716 .54673 .27105 .53871 Mtetra
.51 .62 .897 r
.27105 .53871 .27716 .54673 .28665 .54528 .28042 .53894 Mtetra
.593 .709 .924 r
.28042 .53894 .28665 .54528 .29615 .54427 .28998 .53727 Mtetra
.028 .387 .848 r
.28998 .53727 .29615 .54427 .30633 .53339 .29913 .54233 Mtetra
.633 .858 .484 r
.29913 .54233 .30633 .53339 .31573 .53508 .30959 .52829 Mtetra
.583 .692 .916 r
.30959 .52829 .31573 .53508 .3254 .53319 .31925 .52687 Mtetra
.599 .714 .925 r
.31925 .52687 .3254 .53319 .33506 .53227 .32898 .52504 Mtetra
0 0 .495 r
.32898 .52504 .33506 .53227 .34527 .52203 .33807 .53532 Mtetra
0 0 0 r
.33807 .53532 .34527 .52203 .35492 .52261 .34885 .51589 Mtetra
.594 .7 .917 r
.34885 .51589 .35492 .52261 .36476 .52048 .35869 .51418 Mtetra
.615 .722 .923 r
.35869 .51418 .36476 .52048 .37463 .51862 .36859 .51198 Mtetra
.521 .675 .935 r
.36859 .51198 .37463 .51862 .38835 .42626 .37846 .51161 Mtetra
.49 .25 .477 r
.37846 .51161 .38835 .42626 .39473 .50929 .38877 .50159 Mtetra
.552 .654 .903 r
.38877 .50159 .39473 .50929 .40472 .50725 .39873 .50088 Mtetra
.623 .726 .92 r
.39873 .50088 .40472 .50725 .41477 .50475 .4088 .49845 Mtetra
.624 .729 .922 r
.4088 .49845 .41477 .50475 .42485 .50261 .41892 .49599 Mtetra
.553 .692 .932 r
.41892 .49599 .42485 .50261 .43421 .52898 .42903 .49501 Mtetra
.651 .48 .639 r
.42903 .49501 .43421 .52898 .44528 .49296 .43944 .48473 Mtetra
.538 .634 .894 r
.43944 .48473 .44528 .49296 .45548 .49084 .44961 .48441 Mtetra
.629 .729 .919 r
.44961 .48441 .45548 .49084 .46574 .48807 .45989 .48179 Mtetra
.639 .739 .92 r
.45989 .48179 .46574 .48807 .47604 .48518 .47021 .47891 Mtetra
.64 .74 .921 r
.47021 .47891 .47604 .48518 .48638 .48237 .48058 .476 Mtetra
.629 .733 .923 r
.48058 .476 .48638 .48237 .49676 .48024 .49098 .47334 Mtetra
.493 .659 .935 r
.49098 .47334 .49676 .48024 .50729 .45949 .50141 .47345 Mtetra
.074 0 .074 r
.50141 .47345 .50729 .45949 .51767 .47011 .51195 .46261 Mtetra
.584 .68 .907 r
.51195 .46261 .51767 .47011 .52817 .46756 .52247 .46108 Mtetra
.639 .736 .919 r
.52247 .46108 .52817 .46756 .53872 .46447 .53304 .45814 Mtetra
.649 .745 .92 r
.53304 .45814 .53872 .46447 .5493 .46122 .54365 .45493 Mtetra
.653 .749 .92 r
.54365 .45493 .5493 .46122 .55993 .45787 .5543 .45159 Mtetra
.656 .751 .92 r
.5543 .45159 .55993 .45787 .57059 .45446 .565 .44818 Mtetra
.657 .753 .92 r
.565 .44818 .57059 .45446 .5813 .451 .57573 .44471 Mtetra
.658 .753 .92 r
.57573 .44471 .5813 .451 .59205 .4475 .5865 .4412 Mtetra
.659 .754 .92 r
.5865 .4412 .59205 .4475 .60283 .44399 .59732 .43766 Mtetra
.59732 .43766 .60283 .44399 .61366 .44046 .60818 .43411 Mtetra
.60818 .43411 .61366 .44046 .62454 .43693 .61908 .43055 Mtetra
.658 .754 .92 r
.61908 .43055 .62454 .43693 .63545 .43339 .63002 .42698 Mtetra
.658 .753 .92 r
.63002 .42698 .63545 .43339 .6464 .42984 .64101 .4234 Mtetra
.64101 .4234 .6464 .42984 .6574 .42629 .65203 .41982 Mtetra
.65203 .41982 .6574 .42629 .66844 .42272 .6631 .41623 Mtetra
.6631 .41623 .66844 .42272 .67953 .41915 .67422 .41262 Mtetra
.67422 .41262 .67953 .41915 .69066 .41556 .68538 .40901 Mtetra
.68538 .40901 .69066 .41556 .70183 .41196 .69658 .40538 Mtetra
.657 .753 .92 r
.69658 .40538 .70183 .41196 .71304 .40835 .70783 .40175 Mtetra
.70783 .40175 .71304 .40835 .7243 .40473 .71912 .3981 Mtetra
.71912 .3981 .7243 .40473 .73561 .40109 .73045 .39443 Mtetra
.73045 .39443 .73561 .40109 .74696 .39744 .74183 .39075 Mtetra
.657 .752 .92 r
.74183 .39075 .74696 .39744 .75835 .39378 .75326 .38706 Mtetra
.75326 .38706 .75835 .39378 .76979 .3901 .76473 .38336 Mtetra
.76473 .38336 .76979 .3901 .78128 .38641 .77625 .37964 Mtetra
.77625 .37964 .78128 .38641 .79281 .38271 .78781 .37591 Mtetra
.78781 .37591 .79281 .38271 .80438 .37899 .79942 .37217 Mtetra
.79942 .37217 .80438 .37899 .81601 .37526 .81108 .36841 Mtetra
.81108 .36841 .81601 .37526 .82768 .37151 .82278 .36463 Mtetra
.82278 .36463 .82768 .37151 .83939 .36775 .83453 .36084 Mtetra
.83453 .36084 .83939 .36775 .85116 .36398 .84633 .35704 Mtetra
.84633 .35704 .85116 .36398 .86297 .36019 .85818 .35322 Mtetra
.735 .611 .72 r
.22599 .55139 .23165 .56583 .24223 .55004 .23612 .54114 Mtetra
.459 .571 .88 r
.23612 .54114 .24223 .55004 .2516 .54885 .24528 .54244 Mtetra
.581 .702 .925 r
.24528 .54244 .2516 .54885 .26095 .54841 .25473 .54101 Mtetra
.924 .534 .189 r
.25473 .54101 .26095 .54841 .27105 .53871 .26221 .56543 Mtetra
0 0 0 r
.26221 .56543 .27105 .53871 .28042 .53894 .27418 .5323 Mtetra
.585 .697 .919 r
.27418 .5323 .28042 .53894 .28998 .53727 .28374 .5308 Mtetra
.56 .694 .93 r
.28374 .5308 .28998 .53727 .29913 .54233 .29331 .52975 Mtetra
.757 .641 .733 r
.29331 .52975 .29913 .54233 .30959 .52829 .30359 .51879 Mtetra
.45 .552 .868 r
.30359 .51879 .30959 .52829 .31925 .52687 .31306 .52044 Mtetra
.604 .713 .922 r
.31306 .52044 .31925 .52687 .32898 .52504 .32281 .5185 Mtetra
.554 .692 .931 r
.32281 .5185 .32898 .52504 .33807 .53532 .33255 .51754 Mtetra
.714 .578 .701 r
.33255 .51754 .33807 .53532 .34885 .51589 .34285 .50721 Mtetra
.499 .601 .886 r
.34285 .50721 .34885 .51589 .35869 .51418 .35258 .50775 Mtetra
.613 .719 .921 r
.35258 .50775 .35869 .51418 .36859 .51198 .3625 .50557 Mtetra
.6 .716 .926 r
.3625 .50557 .36859 .51198 .37846 .51161 .37245 .50366 Mtetra
.939 .707 .561 r
.37245 .50366 .37846 .51161 .38877 .50159 .38634 .41089 Mtetra
0 0 .375 r
.38634 .41089 .38877 .50159 .39873 .50088 .39271 .49421 Mtetra
.609 .712 .918 r
.39271 .49421 .39873 .50088 .4088 .49845 .40279 .49211 Mtetra
.627 .73 .921 r
.40279 .49211 .4088 .49845 .41892 .49599 .41293 .48956 Mtetra
.61 .722 .925 r
.41293 .48956 .41892 .49599 .42903 .49501 .4231 .48737 Mtetra
.9 .494 .09 r
.4231 .48737 .42903 .49501 .43944 .48473 .43252 .5138 Mtetra
0 0 .01 r
.43252 .5138 .43944 .48473 .44961 .48441 .4437 .47759 Mtetra
.61 .711 .916 r
.4437 .47759 .44961 .48441 .45989 .48179 .45399 .47542 Mtetra
.636 .736 .92 r
.45399 .47542 .45989 .48179 .47021 .47891 .46434 .47259 Mtetra
.641 .74 .921 r
.46434 .47259 .47021 .47891 .48058 .476 .47473 .46964 Mtetra
.637 .738 .922 r
.47473 .46964 .48058 .476 .49098 .47334 .48516 .46677 Mtetra
.607 .721 .925 r
.48516 .46677 .49098 .47334 .50141 .47345 .49563 .46459 Mtetra
.875 .731 .7 r
.49563 .46459 .50141 .47345 .51195 .46261 .50625 .4437 Mtetra
.25 .285 .703 r
.50625 .4437 .51195 .46261 .52247 .46108 .51672 .45432 Mtetra
.625 .723 .917 r
.51672 .45432 .52247 .46108 .53304 .45814 .52732 .45171 Mtetra
.645 .742 .92 r
.52732 .45171 .53304 .45814 .54365 .45493 .53796 .44857 Mtetra
.651 .748 .92 r
.53796 .44857 .54365 .45493 .5543 .45159 .54864 .44526 Mtetra
.655 .75 .92 r
.54864 .44526 .5543 .45159 .565 .44818 .55936 .44185 Mtetra
.657 .752 .92 r
.55936 .44185 .565 .44818 .57573 .44471 .57012 .43837 Mtetra
.658 .753 .92 r
.57012 .43837 .57573 .44471 .5865 .4412 .58092 .43485 Mtetra
.659 .754 .92 r
.58092 .43485 .5865 .4412 .59732 .43766 .59177 .43129 Mtetra
.59177 .43129 .59732 .43766 .60818 .43411 .60265 .42771 Mtetra
.60265 .42771 .60818 .43411 .61908 .43055 .61358 .42412 Mtetra
.61358 .42412 .61908 .43055 .63002 .42698 .62455 .42052 Mtetra
.658 .753 .92 r
.62455 .42052 .63002 .42698 .64101 .4234 .63557 .41692 Mtetra
.63557 .41692 .64101 .4234 .65203 .41982 .64662 .41331 Mtetra
.64662 .41331 .65203 .41982 .6631 .41623 .65773 .40969 Mtetra
.65773 .40969 .6631 .41623 .67422 .41262 .66887 .40606 Mtetra
.66887 .40606 .67422 .41262 .68538 .40901 .68006 .40241 Mtetra
.68006 .40241 .68538 .40901 .69658 .40538 .69129 .39876 Mtetra
.657 .753 .92 r
.69129 .39876 .69658 .40538 .70783 .40175 .70257 .39509 Mtetra
.70257 .39509 .70783 .40175 .71912 .3981 .71389 .39142 Mtetra
.71389 .39142 .71912 .3981 .73045 .39443 .72526 .38772 Mtetra
.72526 .38772 .73045 .39443 .74183 .39075 .73667 .38402 Mtetra
.73667 .38402 .74183 .39075 .75326 .38706 .74813 .3803 Mtetra
.657 .752 .92 r
.74813 .3803 .75326 .38706 .76473 .38336 .75963 .37657 Mtetra
.75963 .37657 .76473 .38336 .77625 .37964 .77118 .37282 Mtetra
.77118 .37282 .77625 .37964 .78781 .37591 .78278 .36907 Mtetra
.78278 .36907 .78781 .37591 .79942 .37217 .79442 .36529 Mtetra
.79442 .36529 .79942 .37217 .81108 .36841 .80611 .3615 Mtetra
.80611 .3615 .81108 .36841 .82278 .36463 .81785 .3577 Mtetra
.81785 .3577 .82278 .36463 .83453 .36084 .82963 .35388 Mtetra
.82963 .35388 .83453 .36084 .84633 .35704 .84147 .35005 Mtetra
.84147 .35005 .84633 .35704 .85818 .35322 .85335 .3462 Mtetra
0 .156 .672 r
.21965 .54428 .22599 .55139 .23612 .54114 .22827 .55157 Mtetra
.69 .877 .489 r
.22827 .55157 .23612 .54114 .24528 .54244 .23896 .53567 Mtetra
.573 .688 .919 r
.23896 .53567 .24528 .54244 .25473 .54101 .24839 .53443 Mtetra
.526 .678 .934 r
.24839 .53443 .25473 .54101 .26221 .56543 .25782 .53395 Mtetra
.654 .487 .645 r
.25782 .53395 .26221 .56543 .27418 .5323 .268 .52418 Mtetra
.51 .62 .897 r
.268 .52418 .27418 .5323 .28374 .5308 .27745 .52436 Mtetra
.593 .709 .924 r
.27745 .52436 .28374 .5308 .29331 .52975 .28709 .52265 Mtetra
.032 .389 .849 r
.28709 .52265 .29331 .52975 .30359 .51879 .29631 .52769 Mtetra
.642 .865 .494 r
.29631 .52769 .30359 .51879 .31306 .52044 .30686 .51355 Mtetra
.583 .692 .916 r
.30686 .51355 .31306 .52044 .32281 .5185 .3166 .51208 Mtetra
.599 .714 .925 r
.3166 .51208 .32281 .5185 .33255 .51754 .3264 .5102 Mtetra
0 0 .502 r
.3264 .5102 .33255 .51754 .34285 .50721 .33557 .52048 Mtetra
0 0 0 r
.33557 .52048 .34285 .50721 .35258 .50775 .34645 .50092 Mtetra
.594 .7 .917 r
.34645 .50092 .35258 .50775 .3625 .50557 .35636 .49917 Mtetra
.615 .722 .923 r
.35636 .49917 .3625 .50557 .37245 .50366 .36635 .49692 Mtetra
.521 .675 .934 r
.36635 .49692 .37245 .50366 .38634 .41089 .3763 .4965 Mtetra
.487 .245 .473 r
.3763 .4965 .38634 .41089 .39271 .49421 .3867 .48639 Mtetra
.552 .654 .903 r
.3867 .48639 .39271 .49421 .40279 .49211 .39674 .48564 Mtetra
.623 .726 .92 r
.39674 .48564 .40279 .49211 .41293 .48956 .4069 .48315 Mtetra
.624 .729 .922 r
.4069 .48315 .41293 .48956 .4231 .48737 .4171 .48063 Mtetra
.553 .692 .932 r
.4171 .48063 .4231 .48737 .43252 .5138 .4273 .47961 Mtetra
.65 .479 .639 r
.4273 .47961 .43252 .5138 .4437 .47759 .4378 .46924 Mtetra
.537 .634 .894 r
.4378 .46924 .4437 .47759 .45399 .47542 .44806 .46887 Mtetra
.629 .729 .919 r
.44806 .46887 .45399 .47542 .46434 .47259 .45843 .4662 Mtetra
.639 .739 .92 r
.45843 .4662 .46434 .47259 .47473 .46964 .46884 .46326 Mtetra
.64 .74 .921 r
.46884 .46326 .47473 .46964 .48516 .46677 .4793 .46029 Mtetra
.629 .733 .923 r
.4793 .46029 .48516 .46677 .49563 .46459 .48979 .45757 Mtetra
.494 .659 .935 r
.48979 .45757 .49563 .46459 .50625 .4437 .50031 .45764 Mtetra
.061 0 .061 r
.50031 .45764 .50625 .4437 .51672 .45432 .51095 .4467 Mtetra
.584 .681 .907 r
.51095 .4467 .51672 .45432 .52732 .45171 .52156 .44512 Mtetra
.639 .736 .919 r
.52156 .44512 .52732 .45171 .53796 .44857 .53222 .44213 Mtetra
.649 .745 .92 r
.53222 .44213 .53796 .44857 .54864 .44526 .54293 .43885 Mtetra
.653 .749 .92 r
.54293 .43885 .54864 .44526 .55936 .44185 .55368 .43545 Mtetra
.656 .751 .92 r
.55368 .43545 .55936 .44185 .57012 .43837 .56447 .43198 Mtetra
.657 .753 .92 r
.56447 .43198 .57012 .43837 .58092 .43485 .5753 .42844 Mtetra
.658 .753 .92 r
.5753 .42844 .58092 .43485 .59177 .43129 .58617 .42487 Mtetra
.659 .754 .92 r
.58617 .42487 .59177 .43129 .60265 .42771 .59709 .42127 Mtetra
.59709 .42127 .60265 .42771 .61358 .42412 .60805 .41765 Mtetra
.60805 .41765 .61358 .42412 .62455 .42052 .61905 .41402 Mtetra
.658 .754 .92 r
.61905 .41402 .62455 .42052 .63557 .41692 .63009 .41039 Mtetra
.658 .753 .92 r
.63009 .41039 .63557 .41692 .64662 .41331 .64118 .40675 Mtetra
.64118 .40675 .64662 .41331 .65773 .40969 .65231 .4031 Mtetra
.65231 .4031 .65773 .40969 .66887 .40606 .66348 .39944 Mtetra
.66348 .39944 .66887 .40606 .68006 .40241 .6747 .39577 Mtetra
.6747 .39577 .68006 .40241 .69129 .39876 .68596 .39209 Mtetra
.68596 .39209 .69129 .39876 .70257 .39509 .69727 .38839 Mtetra
.657 .753 .92 r
.69727 .38839 .70257 .39509 .71389 .39142 .70863 .38469 Mtetra
.70863 .38469 .71389 .39142 .72526 .38772 .72003 .38097 Mtetra
.72003 .38097 .72526 .38772 .73667 .38402 .73147 .37724 Mtetra
.73147 .37724 .73667 .38402 .74813 .3803 .74296 .37349 Mtetra
.657 .752 .92 r
.74296 .37349 .74813 .3803 .75963 .37657 .7545 .36973 Mtetra
.7545 .36973 .75963 .37657 .77118 .37282 .76608 .36596 Mtetra
.76608 .36596 .77118 .37282 .78278 .36907 .77771 .36217 Mtetra
.77771 .36217 .78278 .36907 .79442 .36529 .78939 .35837 Mtetra
.78939 .35837 .79442 .36529 .80611 .3615 .80111 .35455 Mtetra
.80111 .35455 .80611 .3615 .81785 .3577 .81288 .35072 Mtetra
.81288 .35072 .81785 .3577 .82963 .35388 .8247 .34687 Mtetra
.8247 .34687 .82963 .35388 .84147 .35005 .83657 .34301 Mtetra
.83657 .34301 .84147 .35005 .85335 .3462 .84848 .33913 Mtetra
.54 .684 .932 r
.21323 .53772 .21965 .54428 .22827 .55157 .22256 .53699 Mtetra
.735 .611 .72 r
.22256 .53699 .22827 .55157 .23896 .53567 .23278 .52666 Mtetra
.458 .571 .88 r
.23278 .52666 .23896 .53567 .24839 .53443 .24201 .52792 Mtetra
.582 .702 .925 r
.24201 .52792 .24839 .53443 .25782 .53395 .25153 .52644 Mtetra
.923 .531 .183 r
.25153 .52644 .25782 .53395 .268 .52418 .25904 .55094 Mtetra
0 0 0 r
.25904 .55094 .268 .52418 .27745 .52436 .27114 .51762 Mtetra
.585 .697 .92 r
.27114 .51762 .27745 .52436 .28709 .52265 .28078 .51608 Mtetra
.56 .694 .93 r
.28078 .51608 .28709 .52265 .29631 .52769 .29043 .51497 Mtetra
.758 .642 .733 r
.29043 .51497 .29631 .52769 .30686 .51355 .3008 .50392 Mtetra
.45 .552 .868 r
.3008 .50392 .30686 .51355 .3166 .51208 .31035 .50554 Mtetra
.604 .713 .922 r
.31035 .50554 .3166 .51208 .3264 .5102 .32018 .50356 Mtetra
.554 .692 .931 r
.32018 .50356 .3264 .5102 .33557 .52048 .32999 .50254 Mtetra
.714 .578 .701 r
.32999 .50254 .33557 .52048 .34645 .50092 .34038 .49213 Mtetra
.498 .601 .886 r
.34038 .49213 .34645 .50092 .35636 .49917 .35019 .49263 Mtetra
.613 .719 .921 r
.35019 .49263 .35636 .49917 .36635 .49692 .36019 .4904 Mtetra
.6 .716 .926 r
.36019 .4904 .36635 .49692 .3763 .4965 .37023 .48844 Mtetra
.94 .707 .559 r
.37023 .48844 .3763 .4965 .3867 .48639 .3843 .39524 Mtetra
0 0 .37 r
.3843 .39524 .3867 .48639 .39674 .48564 .39067 .47885 Mtetra
.609 .712 .918 r
.39067 .47885 .39674 .48564 .4069 .48315 .40083 .4767 Mtetra
.627 .73 .921 r
.40083 .4767 .4069 .48315 .4171 .48063 .41105 .47409 Mtetra
.61 .722 .925 r
.41105 .47409 .4171 .48063 .4273 .47961 .42131 .47185 Mtetra
.897 .49 .082 r
.42131 .47185 .4273 .47961 .4378 .46924 .4308 .49836 Mtetra
0 0 .002 r
.4308 .49836 .4378 .46924 .44806 .46887 .4421 .46194 Mtetra
.61 .711 .916 r
.4421 .46194 .44806 .46887 .45843 .4662 .45247 .45971 Mtetra
.636 .736 .92 r
.45247 .45971 .45843 .4662 .46884 .46326 .46291 .45683 Mtetra
.641 .74 .921 r
.46291 .45683 .46884 .46326 .4793 .46029 .47339 .45382 Mtetra
.637 .738 .922 r
.47339 .45382 .4793 .46029 .48979 .45757 .48391 .45089 Mtetra
.607 .721 .925 r
.48391 .45089 .48979 .45757 .50031 .45764 .49448 .44865 Mtetra
.876 .732 .7 r
.49448 .44865 .50031 .45764 .51095 .4467 .5052 .42763 Mtetra
.248 .283 .703 r
.5052 .42763 .51095 .4467 .52156 .44512 .51576 .43825 Mtetra
.625 .723 .917 r
.51576 .43825 .52156 .44512 .53222 .44213 .52645 .43558 Mtetra
.645 .742 .92 r
.52645 .43558 .53222 .44213 .54293 .43885 .53718 .43237 Mtetra
.651 .748 .92 r
.53718 .43237 .54293 .43885 .55368 .43545 .54796 .429 Mtetra
.655 .75 .92 r
.54796 .429 .55368 .43545 .56447 .43198 .55878 .42552 Mtetra
.657 .752 .92 r
.55878 .42552 .56447 .43198 .5753 .42844 .56964 .42198 Mtetra
.658 .753 .92 r
.56964 .42198 .5753 .42844 .58617 .42487 .58054 .41839 Mtetra
.659 .754 .92 r
.58054 .41839 .58617 .42487 .59709 .42127 .59148 .41477 Mtetra
.59148 .41477 .59709 .42127 .60805 .41765 .60247 .41113 Mtetra
.60247 .41113 .60805 .41765 .61905 .41402 .6135 .40747 Mtetra
.6135 .40747 .61905 .41402 .63009 .41039 .62457 .40381 Mtetra
.658 .753 .92 r
.62457 .40381 .63009 .41039 .64118 .40675 .63569 .40014 Mtetra
.63569 .40014 .64118 .40675 .65231 .4031 .64685 .39646 Mtetra
.64685 .39646 .65231 .4031 .66348 .39944 .65805 .39277 Mtetra
.65805 .39277 .66348 .39944 .6747 .39577 .6693 .38907 Mtetra
.6693 .38907 .6747 .39577 .68596 .39209 .6806 .38537 Mtetra
.6806 .38537 .68596 .39209 .69727 .38839 .69194 .38164 Mtetra
.657 .753 .92 r
.69194 .38164 .69727 .38839 .70863 .38469 .70332 .37791 Mtetra
.70332 .37791 .70863 .38469 .72003 .38097 .71475 .37416 Mtetra
.71475 .37416 .72003 .38097 .73147 .37724 .72623 .3704 Mtetra
.72623 .3704 .73147 .37724 .74296 .37349 .73775 .36663 Mtetra
.73775 .36663 .74296 .37349 .7545 .36973 .74932 .36284 Mtetra
.657 .752 .92 r
.74932 .36284 .7545 .36973 .76608 .36596 .76094 .35904 Mtetra
.76094 .35904 .76608 .36596 .77771 .36217 .7726 .35522 Mtetra
.7726 .35522 .77771 .36217 .78939 .35837 .78431 .35139 Mtetra
.78431 .35139 .78939 .35837 .80111 .35455 .79607 .34754 Mtetra
.79607 .34754 .80111 .35455 .81288 .35072 .80787 .34368 Mtetra
.80787 .34368 .81288 .35072 .8247 .34687 .81973 .33981 Mtetra
.81973 .33981 .8247 .34687 .83657 .34301 .83163 .33591 Mtetra
.83163 .33591 .83657 .34301 .84848 .33913 .84358 .33201 Mtetra
.573 .694 .924 r
.20677 .53108 .21323 .53772 .22256 .53699 .21616 .52978 Mtetra
0 .161 .677 r
.21616 .52978 .22256 .53699 .23278 .52666 .22484 .53706 Mtetra
.698 .883 .498 r
.22484 .53706 .23278 .52666 .24201 .52792 .23562 .52105 Mtetra
.573 .688 .919 r
.23562 .52105 .24201 .52792 .25153 .52644 .24513 .51977 Mtetra
.526 .678 .934 r
.24513 .51977 .25153 .52644 .25904 .55094 .25463 .51925 Mtetra
.654 .486 .645 r
.25463 .51925 .25904 .55094 .27114 .51762 .26491 .50939 Mtetra
.509 .62 .897 r
.26491 .50939 .27114 .51762 .28078 .51608 .27443 .50953 Mtetra
.593 .709 .924 r
.27443 .50953 .28078 .51608 .29043 .51497 .28414 .50777 Mtetra
.036 .391 .85 r
.28414 .50777 .29043 .51497 .3008 .50392 .29343 .51279 Mtetra
.652 .872 .504 r
.29343 .51279 .3008 .50392 .31035 .50554 .30408 .49854 Mtetra
.583 .692 .916 r
.30408 .49854 .31035 .50554 .32018 .50356 .3139 .49702 Mtetra
.599 .714 .925 r
.3139 .49702 .32018 .50356 .32999 .50254 .32378 .49509 Mtetra
0 0 .509 r
.32378 .49509 .32999 .50254 .34038 .49213 .33301 .50538 Mtetra
0 0 0 r
.33301 .50538 .34038 .49213 .35019 .49263 .344 .48569 Mtetra
.594 .7 .917 r
.344 .48569 .35019 .49263 .36019 .4904 .354 .48388 Mtetra
.615 .722 .923 r
.354 .48388 .36019 .4904 .37023 .48844 .36407 .48158 Mtetra
.521 .675 .934 r
.36407 .48158 .37023 .48844 .3843 .39524 .3741 .48112 Mtetra
.483 .24 .469 r
.3741 .48112 .3843 .39524 .39067 .47885 .3846 .47092 Mtetra
.552 .654 .903 r
.3846 .47092 .39067 .47885 .40083 .4767 .39472 .47012 Mtetra
.623 .726 .92 r
.39472 .47012 .40083 .4767 .41105 .47409 .40496 .46758 Mtetra
.624 .729 .922 r
.40496 .46758 .41105 .47409 .42131 .47185 .41525 .465 Mtetra
.553 .692 .931 r
.41525 .465 .42131 .47185 .4308 .49836 .42554 .46393 Mtetra
.65 .478 .638 r
.42554 .46393 .4308 .49836 .4421 .46194 .43613 .45347 Mtetra
.537 .634 .894 r
.43613 .45347 .4421 .46194 .45247 .45971 .44648 .45305 Mtetra
.629 .729 .919 r
.44648 .45305 .45247 .45971 .46291 .45683 .45694 .45033 Mtetra
.639 .739 .92 r
.45694 .45033 .46291 .45683 .47339 .45382 .46744 .44732 Mtetra
.64 .74 .921 r
.46744 .44732 .47339 .45382 .48391 .45089 .47799 .44429 Mtetra
.629 .733 .923 r
.47799 .44429 .48391 .45089 .49448 .44865 .48858 .44152 Mtetra
.494 .659 .934 r
.48858 .44152 .49448 .44865 .5052 .42763 .4992 .44153 Mtetra
.049 0 .049 r
.4992 .44153 .5052 .42763 .51576 .43825 .50992 .43051 Mtetra
.584 .681 .907 r
.50992 .43051 .51576 .43825 .52645 .43558 .52063 .42887 Mtetra
.639 .736 .919 r
.52063 .42887 .52645 .43558 .53718 .43237 .53139 .42581 Mtetra
.649 .745 .92 r
.53139 .42581 .53718 .43237 .54796 .429 .5422 .42247 Mtetra
.653 .749 .92 r
.5422 .42247 .54796 .429 .55878 .42552 .55304 .41901 Mtetra
.656 .751 .92 r
.55304 .41901 .55878 .42552 .56964 .42198 .56393 .41547 Mtetra
.657 .753 .92 r
.56393 .41547 .56964 .42198 .58054 .41839 .57486 .41187 Mtetra
.658 .753 .92 r
.57486 .41187 .58054 .41839 .59148 .41477 .58584 .40823 Mtetra
.659 .754 .92 r
.58584 .40823 .59148 .41477 .60247 .41113 .59685 .40456 Mtetra
.59685 .40456 .60247 .41113 .6135 .40747 .60791 .40088 Mtetra
.60791 .40088 .6135 .40747 .62457 .40381 .61901 .39719 Mtetra
.658 .754 .92 r
.61901 .39719 .62457 .40381 .63569 .40014 .63016 .39349 Mtetra
.658 .753 .92 r
.63016 .39349 .63569 .40014 .64685 .39646 .64135 .38978 Mtetra
.64135 .38978 .64685 .39646 .65805 .39277 .65259 .38606 Mtetra
.65259 .38606 .65805 .39277 .6693 .38907 .66387 .38233 Mtetra
.66387 .38233 .6693 .38907 .6806 .38537 .67519 .37859 Mtetra
.67519 .37859 .6806 .38537 .69194 .38164 .68656 .37484 Mtetra
.68656 .37484 .69194 .38164 .70332 .37791 .69798 .37108 Mtetra
.657 .753 .92 r
.69798 .37108 .70332 .37791 .71475 .37416 .70944 .3673 Mtetra
.70944 .3673 .71475 .37416 .72623 .3704 .72095 .36351 Mtetra
.72095 .36351 .72623 .3704 .73775 .36663 .73251 .35971 Mtetra
.73251 .35971 .73775 .36663 .74932 .36284 .74411 .35589 Mtetra
.657 .752 .92 r
.74411 .35589 .74932 .36284 .76094 .35904 .75576 .35206 Mtetra
.75576 .35206 .76094 .35904 .7726 .35522 .76745 .34822 Mtetra
.76745 .34822 .7726 .35522 .78431 .35139 .7792 .34436 Mtetra
.7792 .34436 .78431 .35139 .79607 .34754 .79099 .34048 Mtetra
.79099 .34048 .79607 .34754 .80787 .34368 .80283 .33659 Mtetra
.80283 .33659 .80787 .34368 .81973 .33981 .81472 .33269 Mtetra
.81472 .33269 .81973 .33981 .83163 .33591 .82666 .32877 Mtetra
.82666 .32877 .83163 .33591 .84358 .33201 .83864 .32483 Mtetra
.533 .652 .911 r
.20034 .52356 .20677 .53108 .21616 .52978 .20967 .52311 Mtetra
.541 .684 .932 r
.20967 .52311 .21616 .52978 .22484 .53706 .21908 .52235 Mtetra
.735 .612 .72 r
.21908 .52235 .22484 .53706 .23562 .52105 .22938 .51193 Mtetra
.458 .57 .88 r
.22938 .51193 .23562 .52105 .24513 .51977 .23869 .51315 Mtetra
.582 .702 .925 r
.23869 .51315 .24513 .51977 .25463 .51925 .24828 .51163 Mtetra
.922 .529 .177 r
.24828 .51163 .25463 .51925 .26491 .50939 .25583 .53618 Mtetra
0 0 0 r
.25583 .53618 .26491 .50939 .27443 .50953 .26805 .50268 Mtetra
.585 .697 .92 r
.26805 .50268 .27443 .50953 .28414 .50777 .27777 .50109 Mtetra
.56 .694 .93 r
.27777 .50109 .28414 .50777 .29343 .51279 .2875 .49994 Mtetra
.758 .642 .733 r
.2875 .49994 .29343 .51279 .30408 .49854 .29796 .4888 Mtetra
.449 .552 .869 r
.29796 .4888 .30408 .49854 .3139 .49702 .30758 .49038 Mtetra
.604 .713 .922 r
.30758 .49038 .3139 .49702 .32378 .49509 .31749 .48834 Mtetra
.554 .692 .931 r
.31749 .48834 .32378 .49509 .33301 .50538 .32739 .48728 Mtetra
.714 .578 .701 r
.32739 .48728 .33301 .50538 .344 .48569 .33787 .47678 Mtetra
.498 .601 .886 r
.33787 .47678 .344 .48569 .354 .48388 .34776 .47724 Mtetra
.613 .719 .921 r
.34776 .47724 .354 .48388 .36407 .48158 .35785 .47495 Mtetra
.6 .716 .925 r
.35785 .47495 .36407 .48158 .3741 .48112 .36797 .47294 Mtetra
.941 .708 .557 r
.36797 .47294 .3741 .48112 .3846 .47092 .38221 .37933 Mtetra
0 0 .365 r
.38221 .37933 .3846 .47092 .39472 .47012 .38858 .46322 Mtetra
.609 .712 .918 r
.38858 .46322 .39472 .47012 .40496 .46758 .39883 .46102 Mtetra
.627 .73 .921 r
.39883 .46102 .40496 .46758 .41525 .465 .40914 .45835 Mtetra
.61 .722 .925 r
.40914 .45835 .41525 .465 .42554 .46393 .41949 .45605 Mtetra
.894 .486 .074 r
.41949 .45605 .42554 .46393 .43613 .45347 .42904 .48262 Mtetra
0 0 0 r
.42904 .48262 .43613 .45347 .44648 .45305 .44046 .446 Mtetra
.61 .711 .916 r
.44046 .446 .44648 .45305 .45694 .45033 .45093 .44372 Mtetra
.636 .736 .92 r
.45093 .44372 .45694 .45033 .46744 .44732 .46145 .44077 Mtetra
.641 .74 .921 r
.46145 .44077 .46744 .44732 .47799 .44429 .47203 .43771 Mtetra
.637 .738 .922 r
.47203 .43771 .47799 .44429 .48858 .44152 .48265 .43472 Mtetra
.607 .721 .925 r
.48265 .43472 .48858 .44152 .4992 .44153 .4933 .43242 Mtetra
.877 .733 .699 r
.4933 .43242 .4992 .44153 .50992 .43051 .50413 .41127 Mtetra
.245 .282 .702 r
.50413 .41127 .50992 .43051 .52063 .42887 .51478 .42188 Mtetra
.625 .723 .917 r
.51478 .42188 .52063 .42887 .53139 .42581 .52556 .41914 Mtetra
.645 .742 .92 r
.52556 .41914 .53139 .42581 .5422 .42247 .53639 .41588 Mtetra
.651 .748 .92 r
.53639 .41588 .5422 .42247 .55304 .41901 .54727 .41244 Mtetra
.655 .75 .92 r
.54727 .41244 .55304 .41901 .56393 .41547 .55818 .4089 Mtetra
.657 .752 .92 r
.55818 .4089 .56393 .41547 .57486 .41187 .56914 .40529 Mtetra
.658 .753 .92 r
.56914 .40529 .57486 .41187 .58584 .40823 .58015 .40164 Mtetra
.659 .754 .92 r
.58015 .40164 .58584 .40823 .59685 .40456 .59119 .39795 Mtetra
.59119 .39795 .59685 .40456 .60791 .40088 .60228 .39424 Mtetra
.60228 .39424 .60791 .40088 .61901 .39719 .61341 .39052 Mtetra
.61341 .39052 .61901 .39719 .63016 .39349 .62459 .38678 Mtetra
.658 .753 .92 r
.62459 .38678 .63016 .39349 .64135 .38978 .63581 .38305 Mtetra
.63581 .38305 .64135 .38978 .65259 .38606 .64708 .3793 Mtetra
.64708 .3793 .65259 .38606 .66387 .38233 .65839 .37554 Mtetra
.65839 .37554 .66387 .38233 .67519 .37859 .66975 .37177 Mtetra
.66975 .37177 .67519 .37859 .68656 .37484 .68115 .36799 Mtetra
.68115 .36799 .68656 .37484 .69798 .37108 .6926 .3642 Mtetra
.657 .753 .92 r
.6926 .3642 .69798 .37108 .70944 .3673 .70409 .3604 Mtetra
.70409 .3604 .70944 .3673 .72095 .36351 .71563 .35658 Mtetra
.71563 .35658 .72095 .36351 .73251 .35971 .72722 .35275 Mtetra
.72722 .35275 .73251 .35971 .74411 .35589 .73886 .3489 Mtetra
.73886 .3489 .74411 .35589 .75576 .35206 .75054 .34504 Mtetra
.657 .752 .92 r
.75054 .34504 .75576 .35206 .76745 .34822 .76227 .34116 Mtetra
.76227 .34116 .76745 .34822 .7792 .34436 .77405 .33727 Mtetra
.77405 .33727 .7792 .34436 .79099 .34048 .78587 .33337 Mtetra
.78587 .33337 .79099 .34048 .80283 .33659 .79775 .32945 Mtetra
.79775 .32945 .80283 .33659 .81472 .33269 .80967 .32551 Mtetra
.80967 .32551 .81472 .33269 .82666 .32877 .82164 .32156 Mtetra
.82164 .32156 .82666 .32877 .83864 .32483 .83367 .3176 Mtetra
0 0 .521 r
.19582 .49644 .20034 .52356 .20967 .52311 .20314 .51637 Mtetra
.573 .694 .924 r
.20314 .51637 .20967 .52311 .21908 .52235 .21261 .51502 Mtetra
0 .165 .681 r
.21261 .51502 .21908 .52235 .22938 .51193 .22134 .5223 Mtetra
.707 .889 .507 r
.22134 .5223 .22938 .51193 .23869 .51315 .23223 .50618 Mtetra
.573 .688 .919 r
.23223 .50618 .23869 .51315 .24828 .51163 .24182 .50485 Mtetra
.527 .678 .934 r
.24182 .50485 .24828 .51163 .25583 .53618 .25139 .50428 Mtetra
.653 .485 .644 r
.25139 .50428 .25583 .53618 .26805 .50268 .26176 .49433 Mtetra
.509 .62 .897 r
.26176 .49433 .26805 .50268 .27777 .50109 .27135 .49443 Mtetra
.593 .709 .924 r
.27135 .49443 .27777 .50109 .2875 .49994 .28114 .49262 Mtetra
.041 .394 .852 r
.28114 .49262 .2875 .49994 .29796 .4888 .2905 .49762 Mtetra
.661 .879 .513 r
.2905 .49762 .29796 .4888 .30758 .49038 .30125 .48327 Mtetra
.583 .692 .917 r
.30125 .48327 .30758 .49038 .31749 .48834 .31115 .4817 Mtetra
.599 .714 .925 r
.31115 .4817 .31749 .48834 .32739 .48728 .32112 .47972 Mtetra
0 0 .516 r
.32112 .47972 .32739 .48728 .33787 .47678 .33041 .49001 Mtetra
.624 .791 .352 r
.33041 .49001 .33787 .47678 .34776 .47724 .3415 .47019 Mtetra
.594 .7 .917 r
.3415 .47019 .34776 .47724 .35785 .47495 .35159 .46833 Mtetra
.615 .722 .923 r
.35159 .46833 .35785 .47495 .36797 .47294 .36174 .46597 Mtetra
.521 .675 .934 r
.36174 .46597 .36797 .47294 .38221 .37933 .37185 .46546 Mtetra
.479 .235 .465 r
.37185 .46546 .38221 .37933 .38858 .46322 .38245 .45517 Mtetra
.552 .654 .903 r
.38245 .45517 .38858 .46322 .39883 .46102 .39266 .45432 Mtetra
.623 .726 .92 r
.39266 .45432 .39883 .46102 .40914 .45835 .40299 .45173 Mtetra
.624 .729 .922 r
.40299 .45173 .40914 .45835 .41949 .45605 .41337 .44909 Mtetra
.553 .692 .931 r
.41337 .44909 .41949 .45605 .42904 .48262 .42374 .44796 Mtetra
.649 .477 .637 r
.42374 .44796 .42904 .48262 .44046 .446 .43444 .43741 Mtetra
.537 .634 .895 r
.43444 .43741 .44046 .446 .45093 .44372 .44487 .43694 Mtetra
.629 .729 .919 r
.44487 .43694 .45093 .44372 .46145 .44077 .45542 .43416 Mtetra
.639 .739 .92 r
.45542 .43416 .46145 .44077 .47203 .43771 .46602 .43109 Mtetra
.64 .74 .921 r
.46602 .43109 .47203 .43771 .48265 .43472 .47666 .428 Mtetra
.629 .733 .923 r
.47666 .428 .48265 .43472 .4933 .43242 .48735 .42517 Mtetra
.494 .659 .934 r
.48735 .42517 .4933 .43242 .50413 .41127 .49806 .42513 Mtetra
.036 0 .036 r
.49806 .42513 .50413 .41127 .51478 .42188 .50889 .41401 Mtetra
.584 .681 .907 r
.50889 .41401 .51478 .42188 .52556 .41914 .51969 .41232 Mtetra
.639 .736 .919 r
.51969 .41232 .52556 .41914 .53639 .41588 .53055 .4092 Mtetra
.649 .745 .92 r
.53055 .4092 .53639 .41588 .54727 .41244 .54145 .40579 Mtetra
.653 .749 .92 r
.54145 .40579 .54727 .41244 .55818 .4089 .5524 .40227 Mtetra
.656 .751 .92 r
.5524 .40227 .55818 .4089 .56914 .40529 .56338 .39866 Mtetra
.657 .753 .92 r
.56338 .39866 .56914 .40529 .58015 .40164 .57442 .39499 Mtetra
.658 .753 .92 r
.57442 .39499 .58015 .40164 .59119 .39795 .58549 .39128 Mtetra
.659 .754 .92 r
.58549 .39128 .59119 .39795 .60228 .39424 .59661 .38755 Mtetra
.59661 .38755 .60228 .39424 .61341 .39052 .60777 .3838 Mtetra
.60777 .3838 .61341 .39052 .62459 .38678 .61898 .38004 Mtetra
.658 .754 .92 r
.61898 .38004 .62459 .38678 .63581 .38305 .63023 .37627 Mtetra
.658 .753 .92 r
.63023 .37627 .63581 .38305 .64708 .3793 .64153 .37249 Mtetra
.64153 .37249 .64708 .3793 .65839 .37554 .65287 .3687 Mtetra
.65287 .3687 .65839 .37554 .66975 .37177 .66426 .3649 Mtetra
.66426 .3649 .66975 .37177 .68115 .36799 .67569 .36109 Mtetra
.67569 .36109 .68115 .36799 .6926 .3642 .68717 .35727 Mtetra
.68717 .35727 .6926 .3642 .70409 .3604 .6987 .35344 Mtetra
.657 .753 .92 r
.6987 .35344 .70409 .3604 .71563 .35658 .71027 .34959 Mtetra
.71027 .34959 .71563 .35658 .72722 .35275 .7219 .34573 Mtetra
.7219 .34573 .72722 .35275 .73886 .3489 .73356 .34185 Mtetra
.73356 .34185 .73886 .3489 .75054 .34504 .74528 .33796 Mtetra
.657 .752 .92 r
.74528 .33796 .75054 .34504 .76227 .34116 .75704 .33406 Mtetra
.75704 .33406 .76227 .34116 .77405 .33727 .76886 .33014 Mtetra
.76886 .33014 .77405 .33727 .78587 .33337 .78072 .3262 Mtetra
.78072 .3262 .78587 .33337 .79775 .32945 .79263 .32225 Mtetra
.79263 .32225 .79775 .32945 .80967 .32551 .80458 .31828 Mtetra
.80458 .31828 .80967 .32551 .82164 .32156 .81659 .3143 Mtetra
.81659 .3143 .82164 .32156 .83367 .3176 .82865 .31031 Mtetra
.231 0 .211 r
.18636 .51855 .19582 .49644 .20314 .51637 .19665 .50875 Mtetra
.533 .652 .911 r
.19665 .50875 .20314 .51637 .21261 .51502 .20605 .50825 Mtetra
.541 .684 .932 r
.20605 .50825 .21261 .51502 .22134 .5223 .21553 .50744 Mtetra
.735 .612 .72 r
.21553 .50744 .22134 .5223 .23223 .50618 .22593 .49693 Mtetra
.457 .57 .881 r
.22593 .49693 .23223 .50618 .24182 .50485 .2353 .49813 Mtetra
.582 .702 .925 r
.2353 .49813 .24182 .50485 .25139 .50428 .24497 .49655 Mtetra
.92 .526 .17 r
.24497 .49655 .25139 .50428 .26176 .49433 .25255 .52117 Mtetra
0 0 0 r
.25255 .52117 .26176 .49433 .27135 .49443 .26491 .48748 Mtetra
.585 .697 .92 r
.26491 .48748 .27135 .49443 .28114 .49262 .27471 .48583 Mtetra
.56 .694 .93 r
.27471 .48583 .28114 .49262 .2905 .49762 .28451 .48464 Mtetra
.758 .643 .733 r
.28451 .48464 .2905 .49762 .30125 .48327 .29507 .47341 Mtetra
.448 .552 .869 r
.29507 .47341 .30125 .48327 .31115 .4817 .30477 .47495 Mtetra
.604 .713 .922 r
.30477 .47495 .31115 .4817 .32112 .47972 .31476 .47286 Mtetra
.554 .692 .931 r
.31476 .47286 .32112 .47972 .33041 .49001 .32474 .47175 Mtetra
.715 .578 .701 r
.32474 .47175 .33041 .49001 .3415 .47019 .33532 .46115 Mtetra
.498 .601 .887 r
.33532 .46115 .3415 .47019 .35159 .46833 .34529 .46157 Mtetra
.613 .719 .921 r
.34529 .46157 .35159 .46833 .36174 .46597 .35546 .45923 Mtetra
.6 .716 .925 r
.35546 .45923 .36174 .46597 .37185 .46546 .36566 .45716 Mtetra
.942 .708 .555 r
.36566 .45716 .37185 .46546 .38245 .45517 .3801 .36313 Mtetra
0 0 .361 r
.3801 .36313 .38245 .45517 .39266 .45432 .38646 .44731 Mtetra
.609 .712 .918 r
.38646 .44731 .39266 .45432 .40299 .45173 .3968 .44505 Mtetra
.627 .73 .921 r
.3968 .44505 .40299 .45173 .41337 .44909 .4072 .44232 Mtetra
.611 .722 .924 r
.4072 .44232 .41337 .44909 .42374 .44796 .41763 .43997 Mtetra
.891 .482 .065 r
.41763 .43997 .42374 .44796 .43444 .43741 .42725 .4666 Mtetra
0 0 0 r
.42725 .4666 .43444 .43741 .44487 .43694 .43879 .42978 Mtetra
.61 .711 .916 r
.43879 .42978 .44487 .43694 .45542 .43416 .44935 .42744 Mtetra
.636 .736 .92 r
.44935 .42744 .45542 .43416 .46602 .43109 .45997 .42443 Mtetra
.641 .74 .921 r
.45997 .42443 .46602 .43109 .47666 .428 .47064 .4213 Mtetra
.637 .738 .922 r
.47064 .4213 .47666 .428 .48735 .42517 .48135 .41825 Mtetra
.607 .721 .925 r
.48135 .41825 .48735 .42517 .49806 .42513 .4921 .41589 Mtetra
.878 .734 .699 r
.4921 .41589 .49806 .42513 .50889 .41401 .50303 .3946 Mtetra
.242 .28 .701 r
.50303 .3946 .50889 .41401 .51969 .41232 .51378 .4052 Mtetra
.625 .723 .917 r
.51378 .4052 .51969 .41232 .53055 .4092 .52466 .40241 Mtetra
.645 .742 .92 r
.52466 .40241 .53055 .4092 .54145 .40579 .53559 .39907 Mtetra
.651 .748 .92 r
.53559 .39907 .54145 .40579 .5524 .40227 .54656 .39557 Mtetra
.655 .75 .92 r
.54656 .39557 .5524 .40227 .56338 .39866 .55758 .39196 Mtetra
.657 .752 .92 r
.55758 .39196 .56338 .39866 .57442 .39499 .56864 .38829 Mtetra
.658 .753 .92 r
.56864 .38829 .57442 .39499 .58549 .39128 .57975 .38457 Mtetra
.659 .754 .92 r
.57975 .38457 .58549 .39128 .59661 .38755 .5909 .38081 Mtetra
.5909 .38081 .59661 .38755 .60777 .3838 .60209 .37703 Mtetra
.60209 .37703 .60777 .3838 .61898 .38004 .61333 .37324 Mtetra
.61333 .37324 .61898 .38004 .63023 .37627 .62461 .36944 Mtetra
.658 .753 .92 r
.62461 .36944 .63023 .37627 .64153 .37249 .63594 .36563 Mtetra
.63594 .36563 .64153 .37249 .65287 .3687 .64731 .36181 Mtetra
.64731 .36181 .65287 .3687 .66426 .3649 .65873 .35798 Mtetra
.65873 .35798 .66426 .3649 .67569 .36109 .6702 .35414 Mtetra
.6702 .35414 .67569 .36109 .68717 .35727 .68171 .35029 Mtetra
.68171 .35029 .68717 .35727 .6987 .35344 .69327 .34643 Mtetra
.657 .753 .92 r
.69327 .34643 .6987 .35344 .71027 .34959 .70488 .34255 Mtetra
.70488 .34255 .71027 .34959 .7219 .34573 .71653 .33866 Mtetra
.71653 .33866 .7219 .34573 .73356 .34185 .72823 .33475 Mtetra
.72823 .33475 .73356 .34185 .74528 .33796 .73998 .33083 Mtetra
.73998 .33083 .74528 .33796 .75704 .33406 .75178 .32689 Mtetra
.657 .752 .92 r
.75178 .32689 .75704 .33406 .76886 .33014 .76362 .32294 Mtetra
.76362 .32294 .76886 .33014 .78072 .3262 .77552 .31898 Mtetra
.77552 .31898 .78072 .3262 .79263 .32225 .78746 .315 Mtetra
.78746 .315 .79263 .32225 .80458 .31828 .79946 .311 Mtetra
.79946 .311 .80458 .31828 .81659 .3143 .8115 .30699 Mtetra
.8115 .30699 .81659 .3143 .82865 .31031 .8236 .30296 Mtetra
.88 .712 .669 r
.17988 .51011 .18636 .51855 .19665 .50875 .1921 .48143 Mtetra
0 0 .518 r
.1921 .48143 .19665 .50875 .20605 .50825 .19945 .5014 Mtetra
.573 .694 .924 r
.19945 .5014 .20605 .50825 .21553 .50744 .209 .50001 Mtetra
0 .17 .686 r
.209 .50001 .21553 .50744 .22593 .49693 .21779 .50727 Mtetra
.715 .895 .516 r
.21779 .50727 .22593 .49693 .2353 .49813 .22878 .49104 Mtetra
.573 .688 .919 r
.22878 .49104 .2353 .49813 .24497 .49655 .23844 .48966 Mtetra
.527 .678 .933 r
.23844 .48966 .24497 .49655 .25255 .52117 .24809 .48904 Mtetra
.652 .484 .643 r
.24809 .48904 .25255 .52117 .26491 .48748 .25855 .47901 Mtetra
.509 .62 .898 r
.25855 .47901 .26491 .48748 .27471 .48583 .26822 .47907 Mtetra
.593 .709 .924 r
.26822 .47907 .27471 .48583 .28451 .48464 .27809 .47721 Mtetra
.045 .396 .853 r
.27809 .47721 .28451 .48464 .29507 .47341 .28752 .48218 Mtetra
.67 .886 .523 r
.28752 .48218 .29507 .47341 .30477 .47495 .29837 .46773 Mtetra
.583 .692 .917 r
.29837 .46773 .30477 .47495 .31476 .47286 .30835 .46611 Mtetra
.599 .714 .925 r
.30835 .46611 .31476 .47286 .32474 .47175 .3184 .46407 Mtetra
0 0 .524 r
.3184 .46407 .32474 .47175 .33532 .46115 .32776 .47435 Mtetra
.634 .799 .361 r
.32776 .47435 .33532 .46115 .34529 .46157 .33896 .4544 Mtetra
.594 .7 .917 r
.33896 .4544 .34529 .46157 .35546 .45923 .34913 .45249 Mtetra
.615 .722 .923 r
.34913 .45249 .35546 .45923 .36566 .45716 .35937 .45007 Mtetra
.522 .675 .934 r
.35937 .45007 .36566 .45716 .3801 .36313 .36957 .44951 Mtetra
.475 .229 .461 r
.36957 .44951 .3801 .36313 .38646 .44731 .38027 .43914 Mtetra
.552 .654 .903 r
.38027 .43914 .38646 .44731 .3968 .44505 .39056 .43824 Mtetra
.623 .726 .92 r
.39056 .43824 .3968 .44505 .4072 .44232 .40098 .43558 Mtetra
.624 .729 .922 r
.40098 .43558 .4072 .44232 .41763 .43997 .41145 .43288 Mtetra
.554 .692 .931 r
.41145 .43288 .41763 .43997 .42725 .4666 .42192 .43171 Mtetra
.648 .476 .636 r
.42192 .43171 .42725 .4666 .43879 .42978 .43271 .42106 Mtetra
.537 .634 .895 r
.43271 .42106 .43879 .42978 .44935 .42744 .44324 .42054 Mtetra
.629 .729 .919 r
.44324 .42054 .44935 .42744 .45997 .42443 .45388 .41769 Mtetra
.639 .739 .92 r
.45388 .41769 .45997 .42443 .47064 .4213 .46457 .41456 Mtetra
.64 .74 .921 r
.46457 .41456 .47064 .4213 .48135 .41825 .47531 .41141 Mtetra
.629 .733 .923 r
.47531 .41141 .48135 .41825 .4921 .41589 .48609 .40852 Mtetra
.495 .659 .934 r
.48609 .40852 .4921 .41589 .50303 .3946 .4969 .40843 Mtetra
.022 0 .022 r
.4969 .40843 .50303 .3946 .51378 .4052 .50783 .39721 Mtetra
.584 .681 .907 r
.50783 .39721 .51378 .4052 .52466 .40241 .51873 .39546 Mtetra
.639 .736 .919 r
.51873 .39546 .52466 .40241 .53559 .39907 .52969 .39227 Mtetra
.649 .745 .92 r
.52969 .39227 .53559 .39907 .54656 .39557 .54069 .3888 Mtetra
.653 .749 .92 r
.54069 .3888 .54656 .39557 .55758 .39196 .55174 .3852 Mtetra
.656 .751 .92 r
.55174 .3852 .55758 .39196 .56864 .38829 .56283 .38153 Mtetra
.657 .753 .92 r
.56283 .38153 .56864 .38829 .57975 .38457 .57396 .37779 Mtetra
.658 .753 .92 r
.57396 .37779 .57975 .38457 .5909 .38081 .58514 .37402 Mtetra
.659 .754 .92 r
.58514 .37402 .5909 .38081 .60209 .37703 .59636 .37021 Mtetra
.59636 .37021 .60209 .37703 .61333 .37324 .60763 .36639 Mtetra
.60763 .36639 .61333 .37324 .62461 .36944 .61895 .36256 Mtetra
.658 .754 .92 r
.61895 .36256 .62461 .36944 .63594 .36563 .63031 .35872 Mtetra
.658 .753 .92 r
.63031 .35872 .63594 .36563 .64731 .36181 .64171 .35487 Mtetra
.64171 .35487 .64731 .36181 .65873 .35798 .65316 .35101 Mtetra
.65316 .35101 .65873 .35798 .6702 .35414 .66466 .34714 Mtetra
.66466 .34714 .6702 .35414 .68171 .35029 .6762 .34326 Mtetra
.6762 .34326 .68171 .35029 .69327 .34643 .6878 .33936 Mtetra
.6878 .33936 .69327 .34643 .70488 .34255 .69944 .33545 Mtetra
.657 .753 .92 r
.69944 .33545 .70488 .34255 .71653 .33866 .71112 .33153 Mtetra
.71112 .33153 .71653 .33866 .72823 .33475 .72286 .32759 Mtetra
.72286 .32759 .72823 .33475 .73998 .33083 .73464 .32364 Mtetra
.73464 .32364 .73998 .33083 .75178 .32689 .74647 .31968 Mtetra
.657 .752 .92 r
.74647 .31968 .75178 .32689 .76362 .32294 .75835 .3157 Mtetra
.75835 .3157 .76362 .32294 .77552 .31898 .77028 .3117 Mtetra
.77028 .3117 .77552 .31898 .78746 .315 .78226 .30769 Mtetra
.78226 .30769 .78746 .315 .79946 .311 .79429 .30366 Mtetra
.79429 .30366 .79946 .311 .8115 .30699 .80637 .29962 Mtetra
.80637 .29962 .8115 .30699 .8236 .30296 .8185 .29556 Mtetra
.456 .642 .937 r
.17322 .50311 .17988 .51011 .1921 .48143 .18251 .50356 Mtetra
.22 0 .2 r
.18251 .50356 .1921 .48143 .19945 .5014 .19289 .49367 Mtetra
.533 .652 .911 r
.19289 .49367 .19945 .5014 .209 .50001 .20237 .49313 Mtetra
.541 .684 .931 r
.20237 .49313 .209 .50001 .21779 .50727 .21192 .49227 Mtetra
.736 .612 .72 r
.21192 .49227 .21779 .50727 .22878 .49104 .22241 .48167 Mtetra
.457 .57 .881 r
.22241 .48167 .22878 .49104 .23844 .48966 .23186 .48283 Mtetra
.582 .702 .925 r
.23186 .48283 .23844 .48966 .24809 .48904 .24161 .4812 Mtetra
.919 .524 .164 r
.24161 .4812 .24809 .48904 .25855 .47901 .24922 .50588 Mtetra
0 0 0 r
.24922 .50588 .25855 .47901 .26822 .47907 .26171 .472 Mtetra
.585 .697 .92 r
.26171 .472 .26822 .47907 .27809 .47721 .27159 .47031 Mtetra
.56 .694 .93 r
.27159 .47031 .27809 .47721 .28752 .48218 .28148 .46906 Mtetra
.759 .643 .733 r
.28148 .46906 .28752 .48218 .29837 .46773 .29213 .45773 Mtetra
.448 .552 .869 r
.29213 .45773 .29837 .46773 .30835 .46611 .3019 .45924 Mtetra
.604 .713 .922 r
.3019 .45924 .30835 .46611 .3184 .46407 .31198 .45709 Mtetra
.554 .692 .931 r
.31198 .45709 .3184 .46407 .32776 .47435 .32204 .45593 Mtetra
.715 .578 .701 r
.32204 .45593 .32776 .47435 .33896 .4544 .33271 .44525 Mtetra
.497 .601 .887 r
.33271 .44525 .33896 .4544 .34913 .45249 .34277 .44562 Mtetra
.613 .719 .921 r
.34277 .44562 .34913 .45249 .35937 .45007 .35303 .44321 Mtetra
.6 .716 .925 r
.35303 .44321 .35937 .45007 .36957 .44951 .36332 .44109 Mtetra
.943 .708 .553 r
.36332 .44109 .36957 .44951 .38027 .43914 .37794 .34664 Mtetra
0 0 .356 r
.37794 .34664 .38027 .43914 .39056 .43824 .3843 .4311 Mtetra
.609 .712 .918 r
.3843 .4311 .39056 .43824 .40098 .43558 .39473 .42879 Mtetra
.627 .73 .921 r
.39473 .42879 .40098 .43558 .41145 .43288 .40522 .426 Mtetra
.611 .722 .924 r
.40522 .426 .41145 .43288 .42192 .43171 .41574 .42358 Mtetra
.888 .478 .057 r
.41574 .42358 .42192 .43171 .43271 .42106 .42543 .45028 Mtetra
0 0 0 r
.42543 .45028 .43271 .42106 .44324 .42054 .43709 .41325 Mtetra
.61 .711 .916 r
.43709 .41325 .44324 .42054 .45388 .41769 .44775 .41085 Mtetra
.636 .736 .92 r
.44775 .41085 .45388 .41769 .46457 .41456 .45846 .40778 Mtetra
.641 .74 .921 r
.45846 .40778 .46457 .41456 .47531 .41141 .46923 .40458 Mtetra
.637 .738 .922 r
.46923 .40458 .47531 .41141 .48609 .40852 .48004 .40147 Mtetra
.607 .721 .925 r
.48004 .40147 .48609 .40852 .4969 .40843 .49088 .39906 Mtetra
.879 .735 .699 r
.49088 .39906 .4969 .40843 .50783 .39721 .50192 .37762 Mtetra
.24 .278 .701 r
.50192 .37762 .50783 .39721 .51873 .39546 .51276 .38821 Mtetra
.625 .723 .917 r
.51276 .38821 .51873 .39546 .52969 .39227 .52374 .38535 Mtetra
.645 .742 .92 r
.52374 .38535 .52969 .39227 .54069 .3888 .53477 .38196 Mtetra
.651 .748 .92 r
.53477 .38196 .54069 .3888 .55174 .3852 .54585 .37838 Mtetra
.655 .75 .92 r
.54585 .37838 .55174 .3852 .56283 .38153 .55697 .37471 Mtetra
.657 .752 .92 r
.55697 .37471 .56283 .38153 .57396 .37779 .56813 .37096 Mtetra
.658 .753 .92 r
.56813 .37096 .57396 .37779 .58514 .37402 .57934 .36717 Mtetra
.659 .754 .92 r
.57934 .36717 .58514 .37402 .59636 .37021 .5906 .36334 Mtetra
.5906 .36334 .59636 .37021 .60763 .36639 .6019 .35949 Mtetra
.6019 .35949 .60763 .36639 .61895 .36256 .61324 .35563 Mtetra
.61324 .35563 .61895 .36256 .63031 .35872 .62463 .35175 Mtetra
.658 .753 .92 r
.62463 .35175 .63031 .35872 .64171 .35487 .63607 .34787 Mtetra
.63607 .34787 .64171 .35487 .65316 .35101 .64755 .34398 Mtetra
.64755 .34398 .65316 .35101 .66466 .34714 .65908 .34008 Mtetra
.65908 .34008 .66466 .34714 .6762 .34326 .67066 .33617 Mtetra
.67066 .33617 .6762 .34326 .6878 .33936 .68228 .33224 Mtetra
.68228 .33224 .6878 .33936 .69944 .33545 .69395 .3283 Mtetra
.657 .753 .92 r
.69395 .3283 .69944 .33545 .71112 .33153 .70567 .32435 Mtetra
.70567 .32435 .71112 .33153 .72286 .32759 .71744 .32038 Mtetra
.71744 .32038 .72286 .32759 .73464 .32364 .72926 .3164 Mtetra
.72926 .3164 .73464 .32364 .74647 .31968 .74113 .31241 Mtetra
.74113 .31241 .74647 .31968 .75835 .3157 .75304 .30839 Mtetra
.657 .752 .92 r
.75304 .30839 .75835 .3157 .77028 .3117 .76501 .30437 Mtetra
.76501 .30437 .77028 .3117 .78226 .30769 .77702 .30032 Mtetra
.77702 .30032 .78226 .30769 .79429 .30366 .78909 .29627 Mtetra
.78909 .29627 .79429 .30366 .80637 .29962 .8012 .29219 Mtetra
.8012 .29219 .80637 .29962 .8185 .29556 .81337 .2881 Mtetra
.56 .689 .927 r
.16649 .49619 .17322 .50311 .18251 .50356 .17597 .49501 Mtetra
.881 .713 .669 r
.17597 .49501 .18251 .50356 .19289 .49367 .18832 .46616 Mtetra
0 0 .515 r
.18832 .46616 .19289 .49367 .20237 .49313 .1957 .48617 Mtetra
.573 .694 .924 r
.1957 .48617 .20237 .49313 .21192 .49227 .20532 .48472 Mtetra
0 .174 .69 r
.20532 .48472 .21192 .49227 .22241 .48167 .21417 .49198 Mtetra
.723 .901 .525 r
.21417 .49198 .22241 .48167 .23186 .48283 .22526 .47563 Mtetra
.573 .688 .919 r
.22526 .47563 .23186 .48283 .24161 .4812 .235 .4742 Mtetra
.527 .678 .933 r
.235 .4742 .24161 .4812 .24922 .50588 .24473 .47354 Mtetra
.652 .483 .642 r
.24473 .47354 .24922 .50588 .26171 .472 .25528 .46342 Mtetra
.508 .62 .898 r
.25528 .46342 .26171 .472 .27159 .47031 .26503 .46343 Mtetra
.593 .709 .924 r
.26503 .46343 .27159 .47031 .28148 .46906 .27499 .46151 Mtetra
.049 .398 .854 r
.27499 .46151 .28148 .46906 .29213 .45773 .28449 .46646 Mtetra
.679 .892 .532 r
.28449 .46646 .29213 .45773 .3019 .45924 .29544 .4519 Mtetra
.583 .692 .917 r
.29544 .4519 .3019 .45924 .31198 .45709 .3055 .45023 Mtetra
.599 .714 .925 r
.3055 .45023 .31198 .45709 .32204 .45593 .31564 .44813 Mtetra
0 0 .531 r
.31564 .44813 .32204 .45593 .33271 .44525 .32507 .45841 Mtetra
.644 .807 .371 r
.32507 .45841 .33271 .44525 .34277 .44562 .33638 .43833 Mtetra
.594 .7 .917 r
.33638 .43833 .34277 .44562 .35303 .44321 .34663 .43636 Mtetra
.615 .722 .923 r
.34663 .43636 .35303 .44321 .36332 .44109 .35696 .43389 Mtetra
.522 .675 .934 r
.35696 .43389 .36332 .44109 .37794 .34664 .36725 .43328 Mtetra
.471 .223 .457 r
.36725 .43328 .37794 .34664 .3843 .4311 .37804 .42281 Mtetra
.551 .654 .903 r
.37804 .42281 .3843 .4311 .39473 .42879 .38843 .42185 Mtetra
.623 .726 .92 r
.38843 .42185 .39473 .42879 .40522 .426 .39894 .41914 Mtetra
.624 .729 .922 r
.39894 .41914 .40522 .426 .41574 .42358 .4095 .41638 Mtetra
.554 .692 .931 r
.4095 .41638 .41574 .42358 .42543 .45028 .42006 .41515 Mtetra
.648 .474 .635 r
.42006 .41515 .42543 .45028 .43709 .41325 .43095 .40441 Mtetra
.536 .634 .895 r
.43095 .40441 .43709 .41325 .44775 .41085 .44157 .40383 Mtetra
.629 .729 .919 r
.44157 .40383 .44775 .41085 .45846 .40778 .45231 .40092 Mtetra
.639 .739 .92 r
.45231 .40092 .45846 .40778 .46923 .40458 .4631 .39773 Mtetra
.64 .74 .921 r
.4631 .39773 .46923 .40458 .48004 .40147 .47393 .39451 Mtetra
.629 .733 .923 r
.47393 .39451 .48004 .40147 .49088 .39906 .48481 .39155 Mtetra
.495 .659 .934 r
.48481 .39155 .49088 .39906 .50192 .37762 .49571 .39141 Mtetra
.009 0 .009 r
.49571 .39141 .50192 .37762 .51276 .38821 .50675 .38009 Mtetra
.584 .681 .907 r
.50675 .38009 .51276 .38821 .52374 .38535 .51775 .37828 Mtetra
.639 .736 .919 r
.51775 .37828 .52374 .38535 .53477 .38196 .52881 .37502 Mtetra
.649 .745 .92 r
.52881 .37502 .53477 .38196 .54585 .37838 .53991 .37148 Mtetra
.653 .749 .92 r
.53991 .37148 .54585 .37838 .55697 .37471 .55106 .36782 Mtetra
.656 .751 .92 r
.55106 .36782 .55697 .37471 .56813 .37096 .56226 .36407 Mtetra
.657 .753 .92 r
.56226 .36407 .56813 .37096 .57934 .36717 .5735 .36027 Mtetra
.658 .753 .92 r
.5735 .36027 .57934 .36717 .5906 .36334 .58478 .35642 Mtetra
.659 .754 .92 r
.58478 .35642 .5906 .36334 .6019 .35949 .59611 .35254 Mtetra
.59611 .35254 .6019 .35949 .61324 .35563 .60749 .34865 Mtetra
.60749 .34865 .61324 .35563 .62463 .35175 .61891 .34474 Mtetra
.658 .754 .92 r
.61891 .34474 .62463 .35175 .63607 .34787 .63038 .34083 Mtetra
.658 .753 .92 r
.63038 .34083 .63607 .34787 .64755 .34398 .64189 .33691 Mtetra
.64189 .33691 .64755 .34398 .65908 .34008 .65346 .33297 Mtetra
.65346 .33297 .65908 .34008 .67066 .33617 .66507 .32903 Mtetra
.66507 .32903 .67066 .33617 .68228 .33224 .67672 .32507 Mtetra
.67672 .32507 .68228 .33224 .69395 .3283 .68843 .3211 Mtetra
.68843 .3211 .69395 .3283 .70567 .32435 .70018 .31712 Mtetra
.657 .753 .92 r
.70018 .31712 .70567 .32435 .71744 .32038 .71199 .31312 Mtetra
.71199 .31312 .71744 .32038 .72926 .3164 .72384 .30911 Mtetra
.72384 .30911 .72926 .3164 .74113 .31241 .73574 .30508 Mtetra
.73574 .30508 .74113 .31241 .75304 .30839 .74769 .30104 Mtetra
.657 .752 .92 r
.74769 .30104 .75304 .30839 .76501 .30437 .75969 .29698 Mtetra
.75969 .29698 .76501 .30437 .77702 .30032 .77174 .2929 Mtetra
.77174 .2929 .77702 .30032 .78909 .29627 .78384 .28881 Mtetra
.78384 .28881 .78909 .29627 .8012 .29219 .79599 .2847 Mtetra
.79599 .2847 .8012 .29219 .81337 .2881 .8082 .28058 Mtetra
.54 .663 .916 r
.15979 .48865 .16649 .49619 .17597 .49501 .16923 .48789 Mtetra
.456 .642 .937 r
.16923 .48789 .17597 .49501 .18832 .46616 .17859 .4883 Mtetra
.21 0 .189 r
.17859 .4883 .18832 .46616 .1957 .48617 .18907 .47832 Mtetra
.533 .652 .911 r
.18907 .47832 .1957 .48617 .20532 .48472 .19861 .47774 Mtetra
.541 .684 .931 r
.19861 .47774 .20532 .48472 .21417 .49198 .20824 .47683 Mtetra
.736 .612 .72 r
.20824 .47683 .21417 .49198 .22526 .47563 .21883 .46614 Mtetra
.456 .57 .881 r
.21883 .46614 .22526 .47563 .235 .4742 .22835 .46726 Mtetra
.582 .702 .925 r
.22835 .46726 .235 .4742 .24473 .47354 .23818 .46558 Mtetra
.917 .521 .157 r
.23818 .46558 .24473 .47354 .25528 .46342 .24583 .49032 Mtetra
0 0 0 r
.24583 .49032 .25528 .46342 .26503 .46343 .25846 .45625 Mtetra
.585 .697 .92 r
.25846 .45625 .26503 .46343 .27499 .46151 .26841 .4545 Mtetra
.56 .694 .93 r
.26841 .4545 .27499 .46151 .28449 .46646 .27838 .4532 Mtetra
.759 .644 .733 r
.27838 .4532 .28449 .46646 .29544 .4519 .28913 .44178 Mtetra
.447 .552 .869 r
.28913 .44178 .29544 .4519 .3055 .45023 .29899 .44324 Mtetra
.604 .713 .922 r
.29899 .44324 .3055 .45023 .31564 .44813 .30915 .44104 Mtetra
.554 .692 .931 r
.30915 .44104 .31564 .44813 .32507 .45841 .31929 .43982 Mtetra
.715 .578 .701 r
.31929 .43982 .32507 .45841 .33638 .43833 .33007 .42905 Mtetra
.497 .601 .887 r
.33007 .42905 .33638 .43833 .34663 .43636 .3402 .42937 Mtetra
.613 .719 .921 r
.3402 .42937 .34663 .43636 .35696 .43389 .35055 .42691 Mtetra
.6 .716 .925 r
.35055 .42691 .35696 .43389 .36725 .43328 .36093 .42473 Mtetra
.945 .709 .551 r
.36093 .42473 .36725 .43328 .37804 .42281 .37575 .32986 Mtetra
0 0 .351 r
.37575 .32986 .37804 .42281 .38843 .42185 .3821 .4146 Mtetra
.609 .712 .918 r
.3821 .4146 .38843 .42185 .39894 .41914 .39262 .41222 Mtetra
.627 .73 .921 r
.39262 .41222 .39894 .41914 .4095 .41638 .4032 .40937 Mtetra
.611 .722 .924 r
.4032 .40937 .4095 .41638 .42006 .41515 .41382 .40689 Mtetra
.885 .474 .048 r
.41382 .40689 .42006 .41515 .43095 .40441 .42358 .43365 Mtetra
0 0 0 r
.42358 .43365 .43095 .40441 .44157 .40383 .43536 .39642 Mtetra
.61 .711 .916 r
.43536 .39642 .44157 .40383 .45231 .40092 .44611 .39396 Mtetra
.636 .736 .92 r
.44611 .39396 .45231 .40092 .4631 .39773 .45692 .39082 Mtetra
.641 .74 .921 r
.45692 .39082 .4631 .39773 .47393 .39451 .46779 .38756 Mtetra
.637 .738 .922 r
.46779 .38756 .47393 .39451 .48481 .39155 .47869 .38438 Mtetra
.607 .721 .925 r
.47869 .38438 .48481 .39155 .49571 .39141 .48964 .3819 Mtetra
.88 .736 .698 r
.48964 .3819 .49571 .39141 .50675 .38009 .50079 .36032 Mtetra
.237 .276 .7 r
.50079 .36032 .50675 .38009 .51775 .37828 .51172 .37091 Mtetra
.625 .723 .917 r
.51172 .37091 .51775 .37828 .52881 .37502 .5228 .36798 Mtetra
.645 .742 .92 r
.5228 .36798 .52881 .37502 .53991 .37148 .53394 .36451 Mtetra
.651 .748 .92 r
.53394 .36451 .53991 .37148 .55106 .36782 .54512 .36086 Mtetra
.655 .75 .92 r
.54512 .36086 .55106 .36782 .56226 .36407 .55634 .35712 Mtetra
.657 .752 .92 r
.55634 .35712 .56226 .36407 .5735 .36027 .56761 .35331 Mtetra
.658 .753 .92 r
.56761 .35331 .5735 .36027 .58478 .35642 .57893 .34944 Mtetra
.659 .754 .92 r
.57893 .34944 .58478 .35642 .59611 .35254 .59029 .34554 Mtetra
.59029 .34554 .59611 .35254 .60749 .34865 .6017 .34162 Mtetra
.6017 .34162 .60749 .34865 .61891 .34474 .61315 .33768 Mtetra
.61315 .33768 .61891 .34474 .63038 .34083 .62465 .33373 Mtetra
.658 .753 .92 r
.62465 .33373 .63038 .34083 .64189 .33691 .6362 .32978 Mtetra
.6362 .32978 .64189 .33691 .65346 .33297 .64779 .32581 Mtetra
.64779 .32581 .65346 .33297 .66507 .32903 .65943 .32183 Mtetra
.65943 .32183 .66507 .32903 .67672 .32507 .67112 .31785 Mtetra
.67112 .31785 .67672 .32507 .68843 .3211 .68286 .31384 Mtetra
.68286 .31384 .68843 .3211 .70018 .31712 .69465 .30983 Mtetra
.657 .753 .92 r
.69465 .30983 .70018 .31712 .71199 .31312 .70649 .3058 Mtetra
.70649 .3058 .71199 .31312 .72384 .30911 .71837 .30176 Mtetra
.71837 .30176 .72384 .30911 .73574 .30508 .73031 .2977 Mtetra
.73031 .2977 .73574 .30508 .74769 .30104 .7423 .29362 Mtetra
.7423 .29362 .74769 .30104 .75969 .29698 .75433 .28953 Mtetra
.657 .752 .92 r
.75433 .28953 .75969 .29698 .77174 .2929 .76642 .28542 Mtetra
.76642 .28542 .77174 .2929 .78384 .28881 .77856 .2813 Mtetra
.77856 .2813 .78384 .28881 .79599 .2847 .79074 .27716 Mtetra
.79074 .27716 .79599 .2847 .8082 .28058 .80298 .273 Mtetra
.188 .292 .74 r
.15389 .47358 .15979 .48865 .16923 .48789 .16243 .48086 Mtetra
.56 .689 .927 r
.16243 .48086 .16923 .48789 .17859 .4883 .17198 .47963 Mtetra
.882 .714 .668 r
.17198 .47963 .17859 .4883 .18907 .47832 .18446 .45062 Mtetra
0 0 .512 r
.18446 .45062 .18907 .47832 .19861 .47774 .19187 .47066 Mtetra
.573 .694 .924 r
.19187 .47066 .19861 .47774 .20824 .47683 .20157 .46917 Mtetra
0 .179 .694 r
.20157 .46917 .20824 .47683 .21883 .46614 .21048 .47641 Mtetra
.731 .906 .533 r
.21048 .47641 .21883 .46614 .22835 .46726 .22168 .45994 Mtetra
.573 .688 .919 r
.22168 .45994 .22835 .46726 .23818 .46558 .23151 .45846 Mtetra
.527 .678 .933 r
.23151 .45846 .23818 .46558 .24583 .49032 .24131 .45775 Mtetra
.651 .482 .642 r
.24131 .45775 .24583 .49032 .25846 .45625 .25196 .44754 Mtetra
.508 .62 .898 r
.25196 .44754 .25846 .45625 .26841 .4545 .26179 .44751 Mtetra
.593 .709 .924 r
.26179 .44751 .26841 .4545 .27838 .4532 .27183 .44553 Mtetra
.053 .4 .856 r
.27183 .44553 .27838 .4532 .28913 .44178 .2814 .45045 Mtetra
.688 .899 .541 r
.2814 .45045 .28913 .44178 .29899 .44324 .29246 .43579 Mtetra
.583 .692 .917 r
.29246 .43579 .29899 .44324 .30915 .44104 .3026 .43405 Mtetra
.599 .714 .925 r
.3026 .43405 .30915 .44104 .31929 .43982 .31282 .4319 Mtetra
0 .004 .538 r
.31282 .4319 .31929 .43982 .33007 .42905 .32232 .44218 Mtetra
.653 .814 .381 r
.32232 .44218 .33007 .42905 .3402 .42937 .33375 .42196 Mtetra
.594 .7 .917 r
.33375 .42196 .3402 .42937 .35055 .42691 .34409 .41994 Mtetra
.615 .722 .923 r
.34409 .41994 .35055 .42691 .36093 .42473 .35451 .4174 Mtetra
.522 .675 .934 r
.35451 .4174 .36093 .42473 .37575 .32986 .36488 .41674 Mtetra
.466 .218 .452 r
.36488 .41674 .37575 .32986 .3821 .4146 .37577 .40618 Mtetra
.551 .654 .903 r
.37577 .40618 .3821 .4146 .39262 .41222 .38625 .40517 Mtetra
.623 .726 .92 r
.38625 .40517 .39262 .41222 .4032 .40937 .39686 .40239 Mtetra
.624 .729 .922 r
.39686 .40239 .4032 .40937 .41382 .40689 .40751 .39957 Mtetra
.554 .691 .931 r
.40751 .39957 .41382 .40689 .42358 .43365 .41816 .39827 Mtetra
.647 .473 .634 r
.41816 .39827 .42358 .43365 .43536 .39642 .42915 .38744 Mtetra
.536 .634 .895 r
.42915 .38744 .43536 .39642 .44611 .39396 .43987 .38681 Mtetra
.629 .729 .919 r
.43987 .38681 .44611 .39396 .45692 .39082 .45071 .38384 Mtetra
.639 .739 .92 r
.45071 .38384 .45692 .39082 .46779 .38756 .4616 .38057 Mtetra
.64 .74 .921 r
.4616 .38057 .46779 .38756 .47869 .38438 .47253 .37729 Mtetra
.629 .733 .923 r
.47253 .37729 .47869 .38438 .48964 .3819 .48351 .37426 Mtetra
.496 .659 .934 r
.48351 .37426 .48964 .3819 .50079 .36032 .49451 .37407 Mtetra
0 0 0 r
.49451 .37407 .50079 .36032 .51172 .37091 .50565 .36265 Mtetra
.584 .681 .907 r
.50565 .36265 .51172 .37091 .5228 .36798 .51675 .36077 Mtetra
.639 .736 .919 r
.51675 .36077 .5228 .36798 .53394 .36451 .52791 .35745 Mtetra
.649 .745 .92 r
.52791 .35745 .53394 .36451 .54512 .36086 .53912 .35384 Mtetra
.653 .749 .92 r
.53912 .35384 .54512 .36086 .55634 .35712 .55038 .3501 Mtetra
.656 .751 .92 r
.55038 .3501 .55634 .35712 .56761 .35331 .56168 .34628 Mtetra
.657 .753 .92 r
.56168 .34628 .56761 .35331 .57893 .34944 .57303 .3424 Mtetra
.658 .753 .92 r
.57303 .3424 .57893 .34944 .59029 .34554 .58442 .33848 Mtetra
.659 .754 .92 r
.58442 .33848 .59029 .34554 .6017 .34162 .59586 .33453 Mtetra
.59586 .33453 .6017 .34162 .61315 .33768 .60734 .33056 Mtetra
.60734 .33056 .61315 .33768 .62465 .33373 .61888 .32658 Mtetra
.658 .754 .92 r
.61888 .32658 .62465 .33373 .6362 .32978 .63046 .32259 Mtetra
.658 .753 .92 r
.63046 .32259 .6362 .32978 .64779 .32581 .64208 .3186 Mtetra
.64208 .3186 .64779 .32581 .65943 .32183 .65376 .31459 Mtetra
.65376 .31459 .65943 .32183 .67112 .31785 .66548 .31057 Mtetra
.66548 .31057 .67112 .31785 .68286 .31384 .67725 .30653 Mtetra
.67725 .30653 .68286 .31384 .69465 .30983 .68908 .30248 Mtetra
.68908 .30248 .69465 .30983 .70649 .3058 .70095 .29842 Mtetra
.657 .753 .92 r
.70095 .29842 .70649 .3058 .71837 .30176 .71287 .29435 Mtetra
.71287 .29435 .71837 .30176 .73031 .2977 .72484 .29025 Mtetra
.72484 .29025 .73031 .2977 .7423 .29362 .73686 .28615 Mtetra
.73686 .28615 .7423 .29362 .75433 .28953 .74893 .28202 Mtetra
.657 .752 .92 r
.74893 .28202 .75433 .28953 .76642 .28542 .76105 .27788 Mtetra
.76105 .27788 .76642 .28542 .77856 .2813 .77323 .27373 Mtetra
.77323 .27373 .77856 .2813 .79074 .27716 .78545 .26956 Mtetra
.78545 .26956 .79074 .27716 .80298 .273 .79773 .26537 Mtetra
0 0 0 r
.14508 .48377 .15389 .47358 .16243 .48086 .15566 .4732 Mtetra
.54 .663 .916 r
.15566 .4732 .16243 .48086 .17198 .47963 .16517 .4724 Mtetra
.457 .642 .937 r
.16517 .4724 .17198 .47963 .18446 .45062 .1746 .47276 Mtetra
.199 0 .177 r
.1746 .47276 .18446 .45062 .19187 .47066 .18518 .4627 Mtetra
.533 .652 .911 r
.18518 .4627 .19187 .47066 .20157 .46917 .1948 .46207 Mtetra
.541 .684 .931 r
.1948 .46207 .20157 .46917 .21048 .47641 .2045 .46111 Mtetra
.736 .613 .721 r
.2045 .46111 .21048 .47641 .22168 .45994 .21519 .45033 Mtetra
.456 .57 .881 r
.21519 .45033 .22168 .45994 .23151 .45846 .22478 .4514 Mtetra
.582 .702 .925 r
.22478 .4514 .23151 .45846 .24131 .45775 .23469 .44967 Mtetra
.916 .518 .15 r
.23469 .44967 .24131 .45775 .25196 .44754 .24237 .47447 Mtetra
0 0 0 r
.24237 .47447 .25196 .44754 .26179 .44751 .25514 .44021 Mtetra
.585 .697 .92 r
.25514 .44021 .26179 .44751 .27183 .44553 .26518 .4384 Mtetra
.56 .694 .93 r
.26518 .4384 .27183 .44553 .2814 .45045 .27523 .43705 Mtetra
.76 .644 .734 r
.27523 .43705 .2814 .45045 .29246 .43579 .28608 .42553 Mtetra
.446 .551 .869 r
.28608 .42553 .29246 .43579 .3026 .43405 .29601 .42695 Mtetra
.604 .713 .922 r
.29601 .42695 .3026 .43405 .31282 .4319 .30626 .42469 Mtetra
.554 .692 .931 r
.30626 .42469 .31282 .4319 .32232 .44218 .3165 .42342 Mtetra
.715 .578 .701 r
.3165 .42342 .32232 .44218 .33375 .42196 .32737 .41255 Mtetra
.496 .6 .887 r
.32737 .41255 .33375 .42196 .34409 .41994 .33759 .41282 Mtetra
.613 .719 .921 r
.33759 .41282 .34409 .41994 .35451 .4174 .34803 .4103 Mtetra
.6 .716 .925 r
.34803 .4103 .35451 .4174 .36488 .41674 .3585 .40806 Mtetra
.946 .709 .549 r
.3585 .40806 .36488 .41674 .37577 .40618 .37351 .31278 Mtetra
0 0 .346 r
.37351 .31278 .37577 .40618 .38625 .40517 .37985 .39779 Mtetra
.608 .712 .918 r
.37985 .39779 .38625 .40517 .39686 .40239 .39047 .39535 Mtetra
.627 .73 .921 r
.39047 .39535 .39686 .40239 .40751 .39957 .40115 .39243 Mtetra
.611 .722 .924 r
.40115 .39243 .40751 .39957 .41816 .39827 .41186 .38989 Mtetra
.881 .47 .04 r
.41186 .38989 .41816 .39827 .42915 .38744 .42169 .41671 Mtetra
0 0 0 r
.42169 .41671 .42915 .38744 .43987 .38681 .4336 .37927 Mtetra
.61 .711 .916 r
.4336 .37927 .43987 .38681 .45071 .38384 .44444 .37674 Mtetra
.636 .736 .92 r
.44444 .37674 .45071 .38384 .4616 .38057 .45536 .37354 Mtetra
.641 .74 .921 r
.45536 .37354 .4616 .38057 .47253 .37729 .46632 .37021 Mtetra
.637 .738 .922 r
.46632 .37021 .47253 .37729 .48351 .37426 .47733 .36696 Mtetra
.607 .721 .925 r
.47733 .36696 .48351 .37426 .49451 .37407 .48838 .36441 Mtetra
.881 .737 .698 r
.48838 .36441 .49451 .37407 .50565 .36265 .49963 .3427 Mtetra
.234 .274 .7 r
.49963 .3427 .50565 .36265 .51675 .36077 .51066 .35327 Mtetra
.625 .723 .917 r
.51066 .35327 .51675 .36077 .52791 .35745 .52185 .35027 Mtetra
.645 .742 .92 r
.52185 .35027 .52791 .35745 .53912 .35384 .53309 .34673 Mtetra
.651 .748 .92 r
.53309 .34673 .53912 .35384 .55038 .3501 .54437 .34301 Mtetra
.655 .75 .92 r
.54437 .34301 .55038 .3501 .56168 .34628 .5557 .3392 Mtetra
.657 .752 .92 r
.5557 .3392 .56168 .34628 .57303 .3424 .56708 .33531 Mtetra
.658 .753 .92 r
.56708 .33531 .57303 .3424 .58442 .33848 .57851 .33137 Mtetra
.659 .754 .92 r
.57851 .33137 .58442 .33848 .59586 .33453 .58998 .32739 Mtetra
.58998 .32739 .59586 .33453 .60734 .33056 .60149 .32339 Mtetra
.60149 .32339 .60734 .33056 .61888 .32658 .61306 .31938 Mtetra
.61306 .31938 .61888 .32658 .63046 .32259 .62467 .31536 Mtetra
.658 .753 .92 r
.62467 .31536 .63046 .32259 .64208 .3186 .63633 .31133 Mtetra
.63633 .31133 .64208 .3186 .65376 .31459 .64804 .30728 Mtetra
.64804 .30728 .65376 .31459 .66548 .31057 .6598 .30323 Mtetra
.6598 .30323 .66548 .31057 .67725 .30653 .6716 .29916 Mtetra
.6716 .29916 .67725 .30653 .68908 .30248 .68346 .29508 Mtetra
.68346 .29508 .68908 .30248 .70095 .29842 .69536 .29099 Mtetra
.657 .753 .92 r
.69536 .29099 .70095 .29842 .71287 .29435 .70732 .28688 Mtetra
.70732 .28688 .71287 .29435 .72484 .29025 .71932 .28276 Mtetra
.71932 .28276 .72484 .29025 .73686 .28615 .73138 .27862 Mtetra
.73138 .27862 .73686 .28615 .74893 .28202 .74349 .27446 Mtetra
.74349 .27446 .74893 .28202 .76105 .27788 .75565 .27029 Mtetra
.657 .752 .92 r
.75565 .27029 .76105 .27788 .77323 .27373 .76786 .2661 Mtetra
.76786 .2661 .77323 .27373 .78545 .26956 .78012 .26189 Mtetra
.78012 .26189 .78545 .26956 .79773 .26537 .79243 .25767 Mtetra
.828 .703 .726 r
.13845 .47421 .14508 .48377 .15566 .4732 .1497 .45799 Mtetra
.185 .29 .739 r
.1497 .45799 .15566 .4732 .16517 .4724 .1583 .46526 Mtetra
.56 .689 .927 r
.1583 .46526 .16517 .4724 .1746 .47276 .16792 .46397 Mtetra
.883 .715 .668 r
.16792 .46397 .1746 .47276 .18518 .4627 .18054 .4348 Mtetra
0 0 .509 r
.18054 .4348 .18518 .4627 .1948 .46207 .18798 .45488 Mtetra
.573 .694 .924 r
.18798 .45488 .1948 .46207 .2045 .46111 .19776 .45333 Mtetra
0 .183 .698 r
.19776 .45333 .2045 .46111 .21519 .45033 .20673 .46055 Mtetra
.739 .911 .541 r
.20673 .46055 .21519 .45033 .22478 .4514 .21804 .44397 Mtetra
.573 .688 .919 r
.21804 .44397 .22478 .4514 .23469 .44967 .22794 .44244 Mtetra
.527 .678 .933 r
.22794 .44244 .23469 .44967 .24237 .47447 .23783 .44167 Mtetra
.65 .481 .641 r
.23783 .44167 .24237 .47447 .25514 .44021 .24858 .43138 Mtetra
.508 .62 .898 r
.24858 .43138 .25514 .44021 .26518 .4384 .25848 .43129 Mtetra
.593 .709 .924 r
.25848 .43129 .26518 .4384 .27523 .43705 .2686 .42926 Mtetra
.057 .402 .857 r
.2686 .42926 .27523 .43705 .28608 .42553 .27825 .43415 Mtetra
.697 .905 .55 r
.27825 .43415 .28608 .42553 .29601 .42695 .28941 .41937 Mtetra
.583 .692 .917 r
.28941 .41937 .29601 .42695 .30626 .42469 .29965 .41759 Mtetra
.599 .714 .924 r
.29965 .41759 .30626 .42469 .3165 .42342 .30996 .41537 Mtetra
0 .01 .544 r
.30996 .41537 .3165 .42342 .32737 .41255 .31953 .42564 Mtetra
.662 .822 .39 r
.31953 .42564 .32737 .41255 .33759 .41282 .33107 .40529 Mtetra
.594 .7 .917 r
.33107 .40529 .33759 .41282 .34803 .4103 .3415 .40321 Mtetra
.615 .722 .923 r
.3415 .40321 .34803 .4103 .3585 .40806 .35201 .40061 Mtetra
.523 .675 .934 r
.35201 .40061 .3585 .40806 .37351 .31278 .36247 .39989 Mtetra
.462 .211 .448 r
.36247 .39989 .37351 .31278 .37985 .39779 .37347 .38923 Mtetra
.551 .654 .904 r
.37347 .38923 .37985 .39779 .39047 .39535 .38404 .38817 Mtetra
.623 .726 .92 r
.38404 .38817 .39047 .39535 .40115 .39243 .39474 .38532 Mtetra
.624 .729 .922 r
.39474 .38532 .40115 .39243 .41186 .38989 .40548 .38244 Mtetra
.554 .691 .931 r
.40548 .38244 .41186 .38989 .42169 .41671 .41623 .38109 Mtetra
.646 .472 .633 r
.41623 .38109 .42169 .41671 .4336 .37927 .42733 .37015 Mtetra
.536 .634 .895 r
.42733 .37015 .4336 .37927 .44444 .37674 .43814 .36947 Mtetra
.629 .729 .919 r
.43814 .36947 .44444 .37674 .45536 .37354 .44907 .36642 Mtetra
.639 .739 .92 r
.44907 .36642 .45536 .37354 .46632 .37021 .46006 .36309 Mtetra
.64 .74 .921 r
.46006 .36309 .46632 .37021 .47733 .36696 .4711 .35974 Mtetra
.629 .733 .922 r
.4711 .35974 .47733 .36696 .48838 .36441 .48218 .35664 Mtetra
.496 .659 .933 r
.48218 .35664 .48838 .36441 .49963 .3427 .49328 .35639 Mtetra
0 0 0 r
.49328 .35639 .49963 .3427 .51066 .35327 .50453 .34487 Mtetra
.584 .681 .907 r
.50453 .34487 .51066 .35327 .52185 .35027 .51574 .34293 Mtetra
.639 .736 .919 r
.51574 .34293 .52185 .35027 .53309 .34673 .527 .33953 Mtetra
.649 .745 .92 r
.527 .33953 .53309 .34673 .54437 .34301 .53832 .33585 Mtetra
.653 .749 .92 r
.53832 .33585 .54437 .34301 .5557 .3392 .54968 .33204 Mtetra
.656 .751 .92 r
.54968 .33204 .5557 .3392 .56708 .33531 .56109 .32815 Mtetra
.657 .753 .92 r
.56109 .32815 .56708 .33531 .57851 .33137 .57255 .32419 Mtetra
.658 .753 .92 r
.57255 .32419 .57851 .33137 .58998 .32739 .58405 .3202 Mtetra
.659 .754 .92 r
.58405 .3202 .58998 .32739 .60149 .32339 .5956 .31617 Mtetra
.5956 .31617 .60149 .32339 .61306 .31938 .6072 .31213 Mtetra
.6072 .31213 .61306 .31938 .62467 .31536 .61884 .30807 Mtetra
.658 .754 .92 r
.61884 .30807 .62467 .31536 .63633 .31133 .63053 .304 Mtetra
.658 .753 .92 r
.63053 .304 .63633 .31133 .64804 .30728 .64227 .29993 Mtetra
.64227 .29993 .64804 .30728 .6598 .30323 .65407 .29584 Mtetra
.65407 .29584 .6598 .30323 .6716 .29916 .66591 .29174 Mtetra
.66591 .29174 .6716 .29916 .68346 .29508 .6778 .28763 Mtetra
.6778 .28763 .68346 .29508 .69536 .29099 .68974 .2835 Mtetra
.68974 .2835 .69536 .29099 .70732 .28688 .70173 .27936 Mtetra
.657 .753 .92 r
.70173 .27936 .70732 .28688 .71932 .28276 .71377 .2752 Mtetra
.71377 .2752 .71932 .28276 .73138 .27862 .72586 .27103 Mtetra
.72586 .27103 .73138 .27862 .74349 .27446 .738 .26684 Mtetra
.738 .26684 .74349 .27446 .75565 .27029 .7502 .26263 Mtetra
.657 .752 .92 r
.7502 .26263 .75565 .27029 .76786 .2661 .76244 .25841 Mtetra
.76244 .25841 .76786 .2661 .78012 .26189 .77474 .25417 Mtetra
.77474 .25417 .78012 .26189 .79243 .25767 .78709 .24991 Mtetra
.377 .601 .935 r
.13153 .46681 .13845 .47421 .1497 .45799 .14078 .46813 Mtetra
0 0 0 r
.14078 .46813 .1497 .45799 .1583 .46526 .15145 .45748 Mtetra
.54 .663 .916 r
.15145 .45748 .1583 .46526 .16792 .46397 .16104 .45663 Mtetra
.457 .642 .937 r
.16104 .45663 .16792 .46397 .18054 .4348 .17054 .45695 Mtetra
.187 0 .166 r
.17054 .45695 .18054 .4348 .18798 .45488 .18121 .4468 Mtetra
.532 .652 .911 r
.18121 .4468 .18798 .45488 .19776 .45333 .19091 .44611 Mtetra
.541 .684 .931 r
.19091 .44611 .19776 .45333 .20673 .46055 .20069 .4451 Mtetra
.736 .613 .721 r
.20069 .4451 .20673 .46055 .21804 .44397 .21148 .43423 Mtetra
.455 .57 .881 r
.21148 .43423 .21804 .44397 .22794 .44244 .22115 .43526 Mtetra
.582 .702 .925 r
.22115 .43526 .22794 .44244 .23783 .44167 .23113 .43347 Mtetra
.914 .515 .143 r
.23113 .43347 .23783 .44167 .24858 .43138 .23885 .45833 Mtetra
0 0 0 r
.23885 .45833 .24858 .43138 .25848 .43129 .25176 .42387 Mtetra
.585 .697 .92 r
.25176 .42387 .25848 .43129 .2686 .42926 .26189 .42201 Mtetra
.56 .694 .93 r
.26189 .42201 .2686 .42926 .27825 .43415 .27202 .4206 Mtetra
.76 .645 .734 r
.27202 .4206 .27825 .43415 .28941 .41937 .28298 .40899 Mtetra
.446 .551 .869 r
.28298 .40899 .28941 .41937 .29965 .41759 .29299 .41036 Mtetra
.604 .713 .922 r
.29299 .41036 .29965 .41759 .30996 .41537 .30333 .40804 Mtetra
.555 .692 .931 r
.30333 .40804 .30996 .41537 .31953 .42564 .31365 .40671 Mtetra
.715 .578 .701 r
.31365 .40671 .31953 .42564 .33107 .40529 .32462 .39575 Mtetra
.496 .6 .887 r
.32462 .39575 .33107 .40529 .3415 .40321 .33493 .39597 Mtetra
.613 .719 .921 r
.33493 .39597 .3415 .40321 .35201 .40061 .34546 .39338 Mtetra
.6 .716 .925 r
.34546 .39338 .35201 .40061 .36247 .39989 .35602 .39108 Mtetra
.947 .71 .547 r
.35602 .39108 .36247 .39989 .37347 .38923 .37124 .29538 Mtetra
0 0 .341 r
.37124 .29538 .37347 .38923 .38404 .38817 .37757 .38066 Mtetra
.608 .712 .918 r
.37757 .38066 .38404 .38817 .39474 .38532 .38828 .37815 Mtetra
.627 .73 .921 r
.38828 .37815 .39474 .38532 .40548 .38244 .39905 .37517 Mtetra
.611 .722 .924 r
.39905 .37517 .40548 .38244 .41623 .38109 .40986 .37257 Mtetra
.878 .465 .031 r
.40986 .37257 .41623 .38109 .42733 .37015 .41976 .39944 Mtetra
0 0 0 r
.41976 .39944 .42733 .37015 .43814 .36947 .4318 .36179 Mtetra
.61 .711 .916 r
.4318 .36179 .43814 .36947 .44907 .36642 .44275 .3592 Mtetra
.636 .736 .92 r
.44275 .3592 .44907 .36642 .46006 .36309 .45376 .35592 Mtetra
.641 .74 .921 r
.45376 .35592 .46006 .36309 .4711 .35974 .46482 .35252 Mtetra
.637 .738 .922 r
.46482 .35252 .4711 .35974 .48218 .35664 .47594 .34921 Mtetra
.607 .721 .925 r
.47594 .34921 .48218 .35664 .49328 .35639 .48709 .3466 Mtetra
.882 .738 .698 r
.48709 .3466 .49328 .35639 .50453 .34487 .49845 .32474 Mtetra
.231 .272 .699 r
.49845 .32474 .50453 .34487 .51574 .34293 .50958 .33529 Mtetra
.625 .723 .917 r
.50958 .33529 .51574 .34293 .527 .33953 .52087 .33222 Mtetra
.645 .742 .92 r
.52087 .33222 .527 .33953 .53832 .33585 .53222 .32861 Mtetra
.651 .748 .92 r
.53222 .32861 .53832 .33585 .54968 .33204 .54361 .32482 Mtetra
.655 .75 .92 r
.54361 .32482 .54968 .33204 .56109 .32815 .55505 .32092 Mtetra
.657 .752 .92 r
.55505 .32092 .56109 .32815 .57255 .32419 .56654 .31696 Mtetra
.658 .753 .92 r
.56654 .31696 .57255 .32419 .58405 .3202 .57808 .31294 Mtetra
.659 .754 .92 r
.57808 .31294 .58405 .3202 .5956 .31617 .58966 .30889 Mtetra
.58966 .30889 .5956 .31617 .6072 .31213 .60129 .30481 Mtetra
.60129 .30481 .6072 .31213 .61884 .30807 .61296 .30072 Mtetra
.61296 .30072 .61884 .30807 .63053 .304 .62469 .29662 Mtetra
.658 .753 .92 r
.62469 .29662 .63053 .304 .64227 .29993 .63647 .29251 Mtetra
.63647 .29251 .64227 .29993 .65407 .29584 .64829 .28839 Mtetra
.64829 .28839 .65407 .29584 .66591 .29174 .66017 .28426 Mtetra
.66017 .28426 .66591 .29174 .6778 .28763 .67209 .28011 Mtetra
.67209 .28011 .6778 .28763 .68974 .2835 .68406 .27595 Mtetra
.68406 .27595 .68974 .2835 .70173 .27936 .69609 .27177 Mtetra
.657 .753 .92 r
.69609 .27177 .70173 .27936 .71377 .2752 .70817 .26758 Mtetra
.70817 .26758 .71377 .2752 .72586 .27103 .72029 .26338 Mtetra
.72029 .26338 .72586 .27103 .738 .26684 .73247 .25915 Mtetra
.73247 .25915 .738 .26684 .7502 .26263 .7447 .25491 Mtetra
.7447 .25491 .7502 .26263 .76244 .25841 .75699 .25066 Mtetra
.657 .752 .92 r
.75699 .25066 .76244 .25841 .77474 .25417 .76932 .24639 Mtetra
.76932 .24639 .77474 .25417 .78709 .24991 .78171 .2421 Mtetra
.547 .683 .928 r
.12454 .45954 .13153 .46681 .14078 .46813 .13408 .45846 Mtetra
.829 .704 .726 r
.13408 .45846 .14078 .46813 .15145 .45748 .14544 .44212 Mtetra
.182 .288 .739 r
.14544 .44212 .15145 .45748 .16104 .45663 .15409 .44937 Mtetra
.56 .689 .926 r
.15409 .44937 .16104 .45663 .17054 .45695 .16379 .44803 Mtetra
.884 .715 .667 r
.16379 .44803 .17054 .45695 .18121 .4468 .17655 .41869 Mtetra
0 0 .505 r
.17655 .41869 .18121 .4468 .19091 .44611 .18402 .4388 Mtetra
.573 .694 .924 r
.18402 .4388 .19091 .44611 .20069 .4451 .19387 .4372 Mtetra
0 .188 .703 r
.19387 .4372 .20069 .4451 .21148 .43423 .20291 .44441 Mtetra
.746 .916 .549 r
.20291 .44441 .21148 .43423 .22115 .43526 .21433 .42771 Mtetra
.573 .688 .919 r
.21433 .42771 .22115 .43526 .23113 .43347 .22432 .42612 Mtetra
.528 .677 .933 r
.22432 .42612 .23113 .43347 .23885 .45833 .23428 .4253 Mtetra
.65 .48 .64 r
.23428 .4253 .23885 .45833 .25176 .42387 .24513 .41491 Mtetra
.508 .62 .898 r
.24513 .41491 .25176 .42387 .26189 .42201 .25512 .41478 Mtetra
.593 .709 .924 r
.25512 .41478 .26189 .42201 .27202 .4206 .26532 .41269 Mtetra
.062 .404 .858 r
.26532 .41269 .27202 .4206 .28298 .40899 .27504 .41755 Mtetra
.705 .911 .559 r
.27504 .41755 .28298 .40899 .29299 .41036 .28632 .40266 Mtetra
.582 .692 .917 r
.28632 .40266 .29299 .41036 .30333 .40804 .29664 .40081 Mtetra
.599 .714 .924 r
.29664 .40081 .30333 .40804 .31365 .40671 .30704 .39854 Mtetra
0 .016 .551 r
.30704 .39854 .31365 .40671 .32462 .39575 .31668 .4088 Mtetra
.671 .829 .4 r
.31668 .4088 .32462 .39575 .33493 .39597 .32833 .38831 Mtetra
.594 .7 .917 r
.32833 .38831 .33493 .39597 .34546 .39338 .33886 .38616 Mtetra
.615 .722 .923 r
.33886 .38616 .34546 .39338 .35602 .39108 .34946 .3835 Mtetra
.523 .675 .933 r
.34946 .3835 .35602 .39108 .37124 .29538 .36002 .38272 Mtetra
.457 .205 .443 r
.36002 .38272 .37124 .29538 .37757 .38066 .37111 .37197 Mtetra
.551 .654 .904 r
.37111 .37197 .37757 .38066 .38828 .37815 .38178 .37084 Mtetra
.623 .726 .92 r
.38178 .37084 .38828 .37815 .39905 .37517 .39257 .36793 Mtetra
.624 .729 .922 r
.39257 .36793 .39905 .37517 .40986 .37257 .40342 .36498 Mtetra
.554 .691 .931 r
.40342 .36498 .40986 .37257 .41976 .39944 .41426 .36357 Mtetra
.645 .47 .632 r
.41426 .36357 .41976 .39944 .4318 .36179 .42547 .35254 Mtetra
.536 .634 .895 r
.42547 .35254 .4318 .36179 .44275 .3592 .43638 .35179 Mtetra
.629 .729 .919 r
.43638 .35179 .44275 .3592 .45376 .35592 .44741 .34868 Mtetra
.639 .739 .921 r
.44741 .34868 .45376 .35592 .46482 .35252 .4585 .34528 Mtetra
.64 .74 .921 r
.4585 .34528 .46482 .35252 .47594 .34921 .46964 .34185 Mtetra
.629 .733 .922 r
.46964 .34185 .47594 .34921 .48709 .3466 .48083 .33869 Mtetra
.497 .659 .933 r
.48083 .33869 .48709 .3466 .49845 .32474 .49203 .33837 Mtetra
0 0 0 r
.49203 .33837 .49845 .32474 .50958 .33529 .50339 .32675 Mtetra
.583 .681 .908 r
.50339 .32675 .50958 .33529 .52087 .33222 .5147 .32474 Mtetra
.639 .736 .919 r
.5147 .32474 .52087 .33222 .53222 .32861 .52607 .32127 Mtetra
.649 .745 .92 r
.52607 .32127 .53222 .32861 .54361 .32482 .5375 .31751 Mtetra
.653 .749 .92 r
.5375 .31751 .54361 .32482 .55505 .32092 .54897 .31363 Mtetra
.656 .751 .92 r
.54897 .31363 .55505 .32092 .56654 .31696 .56049 .30966 Mtetra
.657 .753 .92 r
.56049 .30966 .56654 .31696 .57808 .31294 .57206 .30563 Mtetra
.658 .753 .92 r
.57206 .30563 .57808 .31294 .58966 .30889 .58367 .30155 Mtetra
.659 .754 .92 r
.58367 .30155 .58966 .30889 .60129 .30481 .59533 .29745 Mtetra
.59533 .29745 .60129 .30481 .61296 .30072 .60704 .29332 Mtetra
.60704 .29332 .61296 .30072 .62469 .29662 .6188 .28919 Mtetra
.658 .754 .92 r
.6188 .28919 .62469 .29662 .63647 .29251 .63061 .28504 Mtetra
.658 .753 .92 r
.63061 .28504 .63647 .29251 .64829 .28839 .64247 .28088 Mtetra
.64247 .28088 .64829 .28839 .66017 .28426 .65438 .27672 Mtetra
.65438 .27672 .66017 .28426 .67209 .28011 .66634 .27254 Mtetra
.66634 .27254 .67209 .28011 .68406 .27595 .67835 .26834 Mtetra
.67835 .26834 .68406 .27595 .69609 .27177 .69041 .26413 Mtetra
.69041 .26413 .69609 .27177 .70817 .26758 .70252 .25991 Mtetra
.657 .753 .92 r
.70252 .25991 .70817 .26758 .72029 .26338 .71468 .25567 Mtetra
.71468 .25567 .72029 .26338 .73247 .25915 .7269 .25141 Mtetra
.7269 .25141 .73247 .25915 .7447 .25491 .73917 .24714 Mtetra
.73917 .24714 .7447 .25491 .75699 .25066 .75149 .24285 Mtetra
.657 .752 .92 r
.75149 .24285 .75699 .25066 .76932 .24639 .76386 .23854 Mtetra
.76386 .23854 .76932 .24639 .78171 .2421 .77629 .23421 Mtetra
.527 .653 .915 r
.11758 .45157 .12454 .45954 .13408 .45846 .12708 .45093 Mtetra
.378 .601 .935 r
.12708 .45093 .13408 .45846 .14544 .44212 .13639 .45222 Mtetra
0 0 0 r
.13639 .45222 .14544 .44212 .15409 .44937 .14717 .44148 Mtetra
.54 .663 .916 r
.14717 .44148 .15409 .44937 .16379 .44803 .15683 .44057 Mtetra
.458 .642 .937 r
.15683 .44057 .16379 .44803 .17655 .41869 .16641 .44084 Mtetra
.175 0 .154 r
.16641 .44084 .17655 .41869 .18402 .4388 .17718 .4306 Mtetra
.532 .652 .911 r
.17718 .4306 .18402 .4388 .19387 .4372 .18695 .42987 Mtetra
.541 .684 .931 r
.18695 .42987 .19387 .4372 .20291 .44441 .19681 .4288 Mtetra
.737 .613 .721 r
.19681 .4288 .20291 .44441 .21433 .42771 .2077 .41784 Mtetra
.454 .57 .881 r
.2077 .41784 .21433 .42771 .22432 .42612 .21744 .41882 Mtetra
.582 .702 .925 r
.21744 .41882 .22432 .42612 .23428 .4253 .22751 .41697 Mtetra
.912 .512 .136 r
.22751 .41697 .23428 .4253 .24513 .41491 .23526 .44188 Mtetra
0 0 0 r
.23526 .44188 .24513 .41491 .25512 .41478 .24832 .40723 Mtetra
.585 .697 .92 r
.24832 .40723 .25512 .41478 .26532 .41269 .25853 .40531 Mtetra
.56 .694 .93 r
.25853 .40531 .26532 .41269 .27504 .41755 .26876 .40384 Mtetra
.76 .645 .734 r
.26876 .40384 .27504 .41755 .28632 .40266 .27981 .39213 Mtetra
.445 .551 .87 r
.27981 .39213 .28632 .40266 .29664 .40081 .28991 .39346 Mtetra
.604 .713 .922 r
.28991 .39346 .29664 .40081 .30704 .39854 .30033 .39107 Mtetra
.555 .692 .931 r
.30033 .39107 .30704 .39854 .31668 .4088 .31074 .38969 Mtetra
.715 .578 .701 r
.31074 .38969 .31668 .4088 .32833 .38831 .32182 .37862 Mtetra
.496 .6 .887 r
.32182 .37862 .32833 .38831 .33886 .38616 .33222 .37879 Mtetra
.613 .719 .921 r
.33222 .37879 .33886 .38616 .34946 .3835 .34284 .37615 Mtetra
.6 .715 .925 r
.34284 .37615 .34946 .3835 .36002 .38272 .3535 .37378 Mtetra
.948 .71 .545 r
.3535 .37378 .36002 .38272 .37111 .37197 .36892 .27766 Mtetra
0 0 .336 r
.36892 .27766 .37111 .37197 .38178 .37084 .37524 .36321 Mtetra
.608 .712 .918 r
.37524 .36321 .38178 .37084 .39257 .36793 .38605 .36063 Mtetra
.627 .73 .921 r
.38605 .36063 .39257 .36793 .40342 .36498 .39692 .35758 Mtetra
.611 .722 .924 r
.39692 .35758 .40342 .36498 .41426 .36357 .40783 .35491 Mtetra
.874 .461 .022 r
.40783 .35491 .41426 .36357 .42547 .35254 .4178 .38184 Mtetra
0 0 0 r
.4178 .38184 .42547 .35254 .43638 .35179 .42997 .34398 Mtetra
.61 .711 .916 r
.42997 .34398 .43638 .35179 .44741 .34868 .44102 .34132 Mtetra
.636 .736 .92 r
.44102 .34132 .44741 .34868 .4585 .34528 .45213 .33797 Mtetra
.641 .74 .921 r
.45213 .33797 .4585 .34528 .46964 .34185 .4633 .3345 Mtetra
.637 .738 .922 r
.4633 .3345 .46964 .34185 .48083 .33869 .47452 .33111 Mtetra
.608 .721 .925 r
.47452 .33111 .48083 .33869 .49203 .33837 .48577 .32843 Mtetra
.883 .739 .697 r
.48577 .32843 .49203 .33837 .50339 .32675 .49725 .30643 Mtetra
.229 .271 .698 r
.49725 .30643 .50339 .32675 .5147 .32474 .50848 .31695 Mtetra
.625 .723 .917 r
.50848 .31695 .5147 .32474 .52607 .32127 .51988 .31381 Mtetra
.645 .742 .92 r
.51988 .31381 .52607 .32127 .5375 .31751 .53134 .31013 Mtetra
.651 .748 .92 r
.53134 .31013 .5375 .31751 .54897 .31363 .54284 .30626 Mtetra
.655 .75 .92 r
.54284 .30626 .54897 .31363 .56049 .30966 .55439 .30229 Mtetra
.657 .752 .92 r
.55439 .30229 .56049 .30966 .57206 .30563 .56599 .29825 Mtetra
.658 .753 .92 r
.56599 .29825 .57206 .30563 .58367 .30155 .57764 .29415 Mtetra
.659 .754 .92 r
.57764 .29415 .58367 .30155 .59533 .29745 .58933 .29002 Mtetra
.58933 .29002 .59533 .29745 .60704 .29332 .60108 .28587 Mtetra
.60108 .28587 .60704 .29332 .6188 .28919 .61287 .2817 Mtetra
.61287 .2817 .6188 .28919 .63061 .28504 .62471 .27751 Mtetra
.658 .753 .92 r
.62471 .27751 .63061 .28504 .64247 .28088 .6366 .27332 Mtetra
.6366 .27332 .64247 .28088 .65438 .27672 .64855 .26912 Mtetra
.64855 .26912 .65438 .27672 .66634 .27254 .66054 .2649 Mtetra
.66054 .2649 .66634 .27254 .67835 .26834 .67259 .26067 Mtetra
.67259 .26067 .67835 .26834 .69041 .26413 .68468 .25643 Mtetra
.68468 .25643 .69041 .26413 .70252 .25991 .69683 .25217 Mtetra
.657 .753 .92 r
.69683 .25217 .70252 .25991 .71468 .25567 .70903 .2479 Mtetra
.70903 .2479 .71468 .25567 .7269 .25141 .72128 .2436 Mtetra
.72128 .2436 .7269 .25141 .73917 .24714 .73359 .2393 Mtetra
.73359 .2393 .73917 .24714 .75149 .24285 .74595 .23497 Mtetra
.74595 .23497 .75149 .24285 .76386 .23854 .75836 .23063 Mtetra
.657 .752 .92 r
.75836 .23063 .76386 .23854 .77629 .23421 .77082 .22627 Mtetra
.038 .138 .641 r
.112 .43243 .11758 .45157 .12708 .45093 .12001 .44355 Mtetra
.547 .683 .928 r
.12001 .44355 .12708 .45093 .13639 .45222 .12962 .44241 Mtetra
.83 .705 .726 r
.12962 .44241 .13639 .45222 .14717 .44148 .1411 .42596 Mtetra
.179 .287 .738 r
.1411 .42596 .14717 .44148 .15683 .44057 .14981 .43319 Mtetra
.56 .689 .926 r
.14981 .43319 .15683 .44057 .16641 .44084 .15958 .4318 Mtetra
.885 .716 .667 r
.15958 .4318 .16641 .44084 .17718 .4306 .17248 .40229 Mtetra
0 0 .502 r
.17248 .40229 .17718 .4306 .18695 .42987 .17998 .42244 Mtetra
.573 .694 .924 r
.17998 .42244 .18695 .42987 .19681 .4288 .18992 .42078 Mtetra
0 .192 .707 r
.18992 .42078 .19681 .4288 .2077 .41784 .19902 .42796 Mtetra
.753 .921 .557 r
.19902 .42796 .2077 .41784 .21744 .41882 .21056 .41114 Mtetra
.573 .688 .919 r
.21056 .41114 .21744 .41882 .22751 .41697 .22062 .40949 Mtetra
.528 .677 .933 r
.22062 .40949 .22751 .41697 .23526 .44188 .23067 .40862 Mtetra
.649 .478 .639 r
.23067 .40862 .23526 .44188 .24832 .40723 .24162 .39814 Mtetra
.507 .62 .898 r
.24162 .39814 .24832 .40723 .25853 .40531 .25169 .39795 Mtetra
.593 .709 .924 r
.25169 .39795 .25853 .40531 .26876 .40384 .26198 .3958 Mtetra
.066 .406 .859 r
.26198 .3958 .26876 .40384 .27981 .39213 .27178 .40063 Mtetra
.713 .916 .567 r
.27178 .40063 .27981 .39213 .28991 .39346 .28316 .38563 Mtetra
.582 .692 .917 r
.28316 .38563 .28991 .39346 .30033 .39107 .29357 .38372 Mtetra
.599 .714 .924 r
.29357 .38372 .30033 .39107 .31074 .38969 .30406 .38138 Mtetra
0 .022 .558 r
.30406 .38138 .31074 .38969 .32182 .37862 .31378 .39163 Mtetra
.68 .836 .409 r
.31378 .39163 .32182 .37862 .33222 .37879 .32555 .371 Mtetra
.594 .7 .917 r
.32555 .371 .33222 .37879 .34284 .37615 .33617 .36879 Mtetra
.615 .722 .923 r
.33617 .36879 .34284 .37615 .3535 .37378 .34687 .36607 Mtetra
.523 .675 .933 r
.34687 .36607 .3535 .37378 .36892 .27766 .35751 .36523 Mtetra
.453 .199 .438 r
.35751 .36523 .36892 .27766 .37524 .36321 .36872 .35438 Mtetra
.551 .654 .904 r
.36872 .35438 .37524 .36321 .38605 .36063 .37948 .35319 Mtetra
.623 .726 .92 r
.37948 .35319 .38605 .36063 .39692 .35758 .39037 .35021 Mtetra
.624 .729 .922 r
.39037 .35021 .39692 .35758 .40783 .35491 .40132 .34719 Mtetra
.554 .691 .931 r
.40132 .34719 .40783 .35491 .4178 .38184 .41226 .34571 Mtetra
.644 .469 .632 r
.41226 .34571 .4178 .38184 .42997 .34398 .42357 .33458 Mtetra
.535 .634 .895 r
.42357 .33458 .42997 .34398 .44102 .34132 .43458 .33377 Mtetra
.629 .729 .919 r
.43458 .33377 .44102 .34132 .45213 .33797 .44572 .33059 Mtetra
.639 .739 .921 r
.44572 .33059 .45213 .33797 .4633 .3345 .45691 .32712 Mtetra
.64 .74 .921 r
.45691 .32712 .4633 .3345 .47452 .33111 .46816 .32362 Mtetra
.629 .733 .922 r
.46816 .32362 .47452 .33111 .48577 .32843 .47944 .32038 Mtetra
.497 .659 .933 r
.47944 .32038 .48577 .32843 .49725 .30643 .49076 .32 Mtetra
0 0 0 r
.49076 .32 .49725 .30643 .50848 .31695 .50222 .30827 Mtetra
.583 .681 .908 r
.50222 .30827 .50848 .31695 .51988 .31381 .51364 .30619 Mtetra
.639 .736 .919 r
.51364 .30619 .51988 .31381 .53134 .31013 .52513 .30265 Mtetra
.649 .745 .92 r
.52513 .30265 .53134 .31013 .54284 .30626 .53666 .29881 Mtetra
.653 .749 .92 r
.53666 .29881 .54284 .30626 .55439 .30229 .54824 .29485 Mtetra
.656 .751 .92 r
.54824 .29485 .55439 .30229 .56599 .29825 .55988 .2908 Mtetra
.657 .753 .92 r
.55988 .2908 .56599 .29825 .57764 .29415 .57156 .28669 Mtetra
.658 .753 .92 r
.57156 .28669 .57764 .29415 .58933 .29002 .58328 .28254 Mtetra
.659 .754 .92 r
.58328 .28254 .58933 .29002 .60108 .28587 .59506 .27835 Mtetra
.59506 .27835 .60108 .28587 .61287 .2817 .60689 .27415 Mtetra
.60689 .27415 .61287 .2817 .62471 .27751 .61877 .26993 Mtetra
.658 .754 .92 r
.61877 .26993 .62471 .27751 .6366 .27332 .63069 .2657 Mtetra
.658 .753 .92 r
.63069 .2657 .6366 .27332 .64855 .26912 .64267 .26146 Mtetra
.64267 .26146 .64855 .26912 .66054 .2649 .6547 .25721 Mtetra
.6547 .25721 .66054 .2649 .67259 .26067 .66678 .25295 Mtetra
.66678 .25295 .67259 .26067 .68468 .25643 .67891 .24867 Mtetra
.67891 .24867 .68468 .25643 .69683 .25217 .69109 .24437 Mtetra
.69109 .24437 .69683 .25217 .70903 .2479 .70333 .24006 Mtetra
.657 .753 .92 r
.70333 .24006 .70903 .2479 .72128 .2436 .71562 .23574 Mtetra
.71562 .23574 .72128 .2436 .73359 .2393 .72796 .23139 Mtetra
.72796 .23139 .73359 .2393 .74595 .23497 .74036 .22703 Mtetra
.74036 .22703 .74595 .23497 .75836 .23063 .75281 .22266 Mtetra
.657 .752 .92 r
.75281 .22266 .75836 .23063 .77082 .22627 .76531 .21826 Mtetra
0 0 0 r
.10221 .44582 .112 .43243 .12001 .44355 .11298 .43546 Mtetra
.527 .653 .915 r
.11298 .43546 .12001 .44355 .12962 .44241 .12254 .43477 Mtetra
.379 .601 .935 r
.12254 .43477 .12962 .44241 .1411 .42596 .13193 .43601 Mtetra
0 0 0 r
.13193 .43601 .1411 .42596 .14981 .43319 .14281 .42517 Mtetra
.54 .663 .916 r
.14281 .42517 .14981 .43319 .15958 .4318 .15254 .42422 Mtetra
.458 .642 .937 r
.15254 .42422 .15958 .4318 .17248 .40229 .1622 .42444 Mtetra
.163 0 .141 r
.1622 .42444 .17248 .40229 .17998 .42244 .17306 .4141 Mtetra
.532 .652 .911 r
.17306 .4141 .17998 .42244 .18992 .42078 .18292 .41332 Mtetra
.541 .684 .931 r
.18292 .41332 .18992 .42078 .19902 .42796 .19286 .4122 Mtetra
.737 .614 .721 r
.19286 .4122 .19902 .42796 .21056 .41114 .20385 .40114 Mtetra
.454 .57 .882 r
.20385 .40114 .21056 .41114 .22062 .40949 .21367 .40207 Mtetra
.582 .702 .925 r
.21367 .40207 .22062 .40949 .23067 .40862 .22383 .40016 Mtetra
.91 .509 .129 r
.22383 .40016 .23067 .40862 .24162 .39814 .23161 .42513 Mtetra
0 0 0 r
.23161 .42513 .24162 .39814 .25169 .39795 .24482 .39028 Mtetra
.585 .698 .92 r
.24482 .39028 .25169 .39795 .26198 .3958 .25512 .3883 Mtetra
.561 .694 .93 r
.25512 .3883 .26198 .3958 .27178 .40063 .26543 .38677 Mtetra
.761 .646 .734 r
.26543 .38677 .27178 .40063 .28316 .38563 .27659 .37496 Mtetra
.445 .551 .87 r
.27659 .37496 .28316 .38563 .29357 .38372 .28677 .37624 Mtetra
.604 .713 .922 r
.28677 .37624 .29357 .38372 .30406 .38138 .29728 .37379 Mtetra
.555 .692 .931 r
.29728 .37379 .30406 .38138 .31378 .39163 .30778 .37234 Mtetra
.715 .579 .701 r
.30778 .37234 .31378 .39163 .32555 .371 .31897 .36118 Mtetra
.495 .6 .887 r
.31897 .36118 .32555 .371 .33617 .36879 .32945 .36129 Mtetra
.613 .719 .921 r
.32945 .36129 .33617 .36879 .34687 .36607 .34017 .35858 Mtetra
.6 .715 .925 r
.34017 .35858 .34687 .36607 .35751 .36523 .35092 .35614 Mtetra
.949 .711 .543 r
.35092 .35614 .35751 .36523 .36872 .35438 .36656 .25962 Mtetra
0 0 .331 r
.36656 .25962 .36872 .35438 .37948 .35319 .37287 .34542 Mtetra
.608 .712 .918 r
.37287 .34542 .37948 .35319 .39037 .35021 .38377 .34278 Mtetra
.627 .73 .921 r
.38377 .34278 .39037 .35021 .40132 .34719 .39475 .33966 Mtetra
.611 .722 .924 r
.39475 .33966 .40132 .34719 .41226 .34571 .40575 .33692 Mtetra
.87 .456 .013 r
.40575 .33692 .41226 .34571 .42357 .33458 .4158 .36389 Mtetra
0 0 0 r
.4158 .36389 .42357 .33458 .43458 .33377 .4281 .32582 Mtetra
.61 .711 .916 r
.4281 .32582 .43458 .33377 .44572 .33059 .43925 .32309 Mtetra
.636 .736 .92 r
.43925 .32309 .44572 .33059 .45691 .32712 .45047 .31967 Mtetra
.641 .74 .921 r
.45047 .31967 .45691 .32712 .46816 .32362 .46175 .31613 Mtetra
.637 .738 .921 r
.46175 .31613 .46816 .32362 .47944 .32038 .47307 .31266 Mtetra
.608 .721 .925 r
.47307 .31266 .47944 .32038 .49076 .32 .48443 .30991 Mtetra
.884 .74 .697 r
.48443 .30991 .49076 .32 .50222 .30827 .49603 .28776 Mtetra
.226 .269 .698 r
.49603 .28776 .50222 .30827 .51364 .30619 .50736 .29826 Mtetra
.625 .723 .917 r
.50736 .29826 .51364 .30619 .52513 .30265 .51887 .29505 Mtetra
.645 .742 .92 r
.51887 .29505 .52513 .30265 .53666 .29881 .53043 .29128 Mtetra
.651 .748 .92 r
.53043 .29128 .53666 .29881 .54824 .29485 .54205 .28734 Mtetra
.655 .75 .92 r
.54205 .28734 .54824 .29485 .55988 .2908 .55371 .28329 Mtetra
.657 .752 .92 r
.55371 .28329 .55988 .2908 .57156 .28669 .56543 .27917 Mtetra
.658 .753 .92 r
.56543 .27917 .57156 .28669 .58328 .28254 .57719 .27499 Mtetra
.659 .754 .92 r
.57719 .27499 .58328 .28254 .59506 .27835 .589 .27078 Mtetra
.589 .27078 .59506 .27835 .60689 .27415 .60086 .26654 Mtetra
.60086 .26654 .60689 .27415 .61877 .26993 .61277 .26229 Mtetra
.61277 .26229 .61877 .26993 .63069 .2657 .62473 .25802 Mtetra
.658 .753 .92 r
.62473 .25802 .63069 .2657 .64267 .26146 .63675 .25375 Mtetra
.63675 .25375 .64267 .26146 .6547 .25721 .64881 .24946 Mtetra
.64881 .24946 .6547 .25721 .66678 .25295 .66093 .24516 Mtetra
.66093 .24516 .66678 .25295 .67891 .24867 .67309 .24084 Mtetra
.67309 .24084 .67891 .24867 .69109 .24437 .68531 .23651 Mtetra
.68531 .23651 .69109 .24437 .70333 .24006 .69759 .23217 Mtetra
.657 .753 .92 r
.69759 .23217 .70333 .24006 .71562 .23574 .70991 .22781 Mtetra
.70991 .22781 .71562 .23574 .72796 .23139 .72229 .22343 Mtetra
.72229 .22343 .72796 .23139 .74036 .22703 .73472 .21903 Mtetra
.73472 .21903 .74036 .22703 .75281 .22266 .74721 .21462 Mtetra
.74721 .21462 .75281 .22266 .76531 .21826 .75975 .21019 Mtetra
.851 .71 .707 r
.09528 .43638 .10221 .44582 .11298 .43546 .10734 .41615 Mtetra
.034 .135 .639 r
.10734 .41615 .11298 .43546 .12254 .43477 .11539 .42727 Mtetra
.547 .683 .928 r
.11539 .42727 .12254 .43477 .13193 .43601 .12509 .42607 Mtetra
.83 .705 .727 r
.12509 .42607 .13193 .43601 .14281 .42517 .13668 .40951 Mtetra
.176 .285 .738 r
.13668 .40951 .14281 .42517 .15254 .42422 .14544 .41672 Mtetra
.56 .689 .926 r
.14544 .41672 .15254 .42422 .1622 .42444 .1553 .41527 Mtetra
.886 .717 .666 r
.1553 .41527 .1622 .42444 .17306 .4141 .16834 .38558 Mtetra
0 0 .499 r
.16834 .38558 .17306 .4141 .18292 .41332 .17587 .40576 Mtetra
.573 .694 .924 r
.17587 .40576 .18292 .41332 .19286 .4122 .18589 .40405 Mtetra
0 .196 .711 r
.18589 .40405 .19286 .4122 .20385 .40114 .19505 .41121 Mtetra
.761 .926 .565 r
.19505 .41121 .20385 .40114 .21367 .40207 .20671 .39427 Mtetra
.572 .688 .919 r
.20671 .39427 .21367 .40207 .22383 .40016 .21686 .39256 Mtetra
.528 .677 .933 r
.21686 .39256 .22383 .40016 .23161 .42513 .22699 .39163 Mtetra
.648 .477 .638 r
.22699 .39163 .23161 .42513 .24482 .39028 .23804 .38105 Mtetra
.507 .62 .898 r
.23804 .38105 .24482 .39028 .25512 .3883 .2482 .38081 Mtetra
.593 .709 .924 r
.2482 .38081 .25512 .3883 .26543 .38677 .25858 .3786 Mtetra
.07 .408 .86 r
.25858 .3786 .26543 .38677 .27659 .37496 .26845 .38339 Mtetra
.721 .922 .576 r
.26845 .38339 .27659 .37496 .28677 .37624 .27995 .36827 Mtetra
.582 .692 .917 r
.27995 .36827 .28677 .37624 .29728 .37379 .29045 .3663 Mtetra
.599 .714 .924 r
.29045 .3663 .29728 .37379 .30778 .37234 .30103 .3639 Mtetra
0 .028 .565 r
.30103 .3639 .30778 .37234 .31897 .36118 .31082 .37413 Mtetra
.689 .843 .418 r
.31082 .37413 .31897 .36118 .32945 .36129 .32271 .35337 Mtetra
.594 .7 .917 r
.32271 .35337 .32945 .36129 .34017 .35858 .33343 .35109 Mtetra
.615 .722 .923 r
.33343 .35109 .34017 .35858 .35092 .35614 .34422 .3483 Mtetra
.523 .675 .933 r
.34422 .3483 .35092 .35614 .36656 .25962 .35496 .3474 Mtetra
.448 .192 .432 r
.35496 .3474 .36656 .25962 .37287 .34542 .36628 .33645 Mtetra
.551 .654 .904 r
.36628 .33645 .37287 .34542 .38377 .34278 .37713 .3352 Mtetra
.623 .726 .92 r
.37713 .3352 .38377 .34278 .39475 .33966 .38812 .33215 Mtetra
.624 .729 .922 r
.38812 .33215 .39475 .33966 .40575 .33692 .39917 .32905 Mtetra
.555 .691 .931 r
.39917 .32905 .40575 .33692 .4158 .36389 .41021 .32751 Mtetra
.644 .468 .631 r
.41021 .32751 .4158 .36389 .4281 .32582 .42163 .31627 Mtetra
.535 .634 .896 r
.42163 .31627 .4281 .32582 .43925 .32309 .43275 .3154 Mtetra
.629 .729 .919 r
.43275 .3154 .43925 .32309 .45047 .31967 .44399 .31215 Mtetra
.639 .739 .921 r
.44399 .31215 .45047 .31967 .46175 .31613 .45529 .3086 Mtetra
.64 .74 .921 r
.45529 .3086 .46175 .31613 .47307 .31266 .46664 .30502 Mtetra
.629 .733 .922 r
.46664 .30502 .47307 .31266 .48443 .30991 .47804 .30171 Mtetra
.498 .659 .933 r
.47804 .30171 .48443 .30991 .49603 .28776 .48945 .30127 Mtetra
0 0 0 r
.48945 .30127 .49603 .28776 .50736 .29826 .50103 .28943 Mtetra
.583 .681 .908 r
.50103 .28943 .50736 .29826 .51887 .29505 .51257 .28728 Mtetra
.639 .736 .919 r
.51257 .28728 .51887 .29505 .53043 .29128 .52416 .28366 Mtetra
.649 .745 .92 r
.52416 .28366 .53043 .29128 .54205 .28734 .53581 .27974 Mtetra
.653 .749 .92 r
.53581 .27974 .54205 .28734 .55371 .28329 .5475 .2757 Mtetra
.656 .751 .92 r
.5475 .2757 .55371 .28329 .56543 .27917 .55925 .27157 Mtetra
.657 .753 .92 r
.55925 .27157 .56543 .27917 .57719 .27499 .57105 .26738 Mtetra
.658 .753 .92 r
.57105 .26738 .57719 .27499 .589 .27078 .58289 .26314 Mtetra
.659 .754 .92 r
.58289 .26314 .589 .27078 .60086 .26654 .59479 .25887 Mtetra
.59479 .25887 .60086 .26654 .61277 .26229 .60673 .25459 Mtetra
.60673 .25459 .61277 .26229 .62473 .25802 .61873 .25028 Mtetra
.658 .754 .92 r
.61873 .25028 .62473 .25802 .63675 .25375 .63077 .24597 Mtetra
.658 .753 .92 r
.63077 .24597 .63675 .25375 .64881 .24946 .64287 .24165 Mtetra
.64287 .24165 .64881 .24946 .66093 .24516 .65503 .23731 Mtetra
.65503 .23731 .66093 .24516 .67309 .24084 .66723 .23296 Mtetra
.66723 .23296 .67309 .24084 .68531 .23651 .67949 .22859 Mtetra
.67949 .22859 .68531 .23651 .69759 .23217 .69179 .22421 Mtetra
.69179 .22421 .69759 .23217 .70991 .22781 .70416 .21981 Mtetra
.657 .753 .92 r
.70416 .21981 .70991 .22781 .72229 .22343 .71657 .2154 Mtetra
.71657 .2154 .72229 .22343 .73472 .21903 .72905 .21097 Mtetra
.72905 .21097 .73472 .21903 .74721 .21462 .74157 .20652 Mtetra
.74157 .20652 .74721 .21462 .75975 .21019 .75415 .20205 Mtetra
.409 .617 .936 r
.08806 .42868 .09528 .43638 .10734 .41615 .09742 .42951 Mtetra
0 0 0 r
.09742 .42951 .10734 .41615 .11539 .42727 .10828 .41905 Mtetra
.527 .653 .916 r
.10828 .41905 .11539 .42727 .12509 .42607 .11793 .41831 Mtetra
.38 .601 .934 r
.11793 .41831 .12509 .42607 .13668 .40951 .12739 .41951 Mtetra
0 0 0 r
.12739 .41951 .13668 .40951 .14544 .41672 .13836 .40857 Mtetra
.54 .663 .916 r
.13836 .40857 .14544 .41672 .1553 .41527 .14818 .40756 Mtetra
.459 .642 .936 r
.14818 .40756 .1553 .41527 .16834 .38558 .15791 .40773 Mtetra
.15 0 .128 r
.15791 .40773 .16834 .38558 .17587 .40576 .16888 .3973 Mtetra
.532 .652 .912 r
.16888 .3973 .17587 .40576 .18589 .40405 .17881 .39646 Mtetra
.542 .684 .931 r
.17881 .39646 .18589 .40405 .19505 .41121 .18884 .39528 Mtetra
.737 .614 .721 r
.18884 .39528 .19505 .41121 .20671 .39427 .19993 .38413 Mtetra
.453 .57 .882 r
.19993 .38413 .20671 .39427 .21686 .39256 .20983 .38501 Mtetra
.582 .702 .925 r
.20983 .38501 .21686 .39256 .22699 .39163 .22007 .38304 Mtetra
.908 .506 .122 r
.22007 .38304 .22699 .39163 .23804 .38105 .22788 .40806 Mtetra
0 0 0 r
.22788 .40806 .23804 .38105 .2482 .38081 .24125 .37301 Mtetra
.585 .698 .92 r
.24125 .37301 .2482 .38081 .25858 .3786 .25163 .37096 Mtetra
.561 .694 .93 r
.25163 .37096 .25858 .3786 .26845 .38339 .26203 .36937 Mtetra
.761 .646 .734 r
.26203 .36937 .26845 .38339 .27995 .36827 .2733 .35746 Mtetra
.444 .551 .87 r
.2733 .35746 .27995 .36827 .29045 .3663 .28357 .35869 Mtetra
.604 .713 .922 r
.28357 .35869 .29045 .3663 .30103 .3639 .29418 .35617 Mtetra
.555 .692 .931 r
.29418 .35617 .30103 .3639 .31082 .37413 .30477 .35467 Mtetra
.715 .579 .701 r
.30477 .35467 .31082 .37413 .32271 .35337 .31606 .3434 Mtetra
.495 .6 .888 r
.31606 .3434 .32271 .35337 .33343 .35109 .32664 .34346 Mtetra
.613 .719 .921 r
.32664 .34346 .33343 .35109 .34422 .3483 .33745 .34067 Mtetra
.6 .715 .925 r
.33745 .34067 .34422 .3483 .35496 .3474 .3483 .33817 Mtetra
.951 .711 .541 r
.3483 .33817 .35496 .3474 .36628 .33645 .36416 .24123 Mtetra
0 0 .325 r
.36416 .24123 .36628 .33645 .37713 .3352 .37045 .32728 Mtetra
.608 .712 .918 r
.37045 .32728 .37713 .3352 .38812 .33215 .38145 .32457 Mtetra
.627 .73 .921 r
.38145 .32457 .38812 .33215 .39917 .32905 .39253 .32138 Mtetra
.611 .722 .924 r
.39253 .32138 .39917 .32905 .41021 .32751 .40364 .31857 Mtetra
.866 .451 .004 r
.40364 .31857 .41021 .32751 .42163 .31627 .41376 .34559 Mtetra
0 0 0 r
.41376 .34559 .42163 .31627 .43275 .3154 .4262 .30731 Mtetra
.61 .711 .917 r
.4262 .30731 .43275 .3154 .44399 .31215 .43746 .3045 Mtetra
.636 .736 .92 r
.43746 .3045 .44399 .31215 .45529 .3086 .44878 .30101 Mtetra
.641 .74 .921 r
.44878 .30101 .45529 .3086 .46664 .30502 .46016 .29739 Mtetra
.637 .738 .921 r
.46016 .29739 .46664 .30502 .47804 .30171 .47159 .29385 Mtetra
.608 .721 .925 r
.47159 .29385 .47804 .30171 .48945 .30127 .48306 .29102 Mtetra
.885 .741 .697 r
.48306 .29102 .48945 .30127 .50103 .28943 .49478 .26872 Mtetra
.223 .267 .697 r
.49478 .26872 .50103 .28943 .51257 .28728 .50621 .2792 Mtetra
.625 .723 .917 r
.50621 .2792 .51257 .28728 .52416 .28366 .51784 .27591 Mtetra
.645 .742 .92 r
.51784 .27591 .52416 .28366 .53581 .27974 .52952 .27206 Mtetra
.651 .748 .92 r
.52952 .27206 .53581 .27974 .5475 .2757 .54124 .26804 Mtetra
.655 .75 .92 r
.54124 .26804 .5475 .2757 .55925 .27157 .55302 .26391 Mtetra
.657 .752 .92 r
.55302 .26391 .55925 .27157 .57105 .26738 .56485 .2597 Mtetra
.658 .753 .92 r
.56485 .2597 .57105 .26738 .58289 .26314 .57673 .25544 Mtetra
.659 .754 .92 r
.57673 .25544 .58289 .26314 .59479 .25887 .58866 .25115 Mtetra
.58866 .25115 .59479 .25887 .60673 .25459 .60064 .24682 Mtetra
.60064 .24682 .60673 .25459 .61873 .25028 .61267 .24248 Mtetra
.61267 .24248 .61873 .25028 .63077 .24597 .62476 .23813 Mtetra
.658 .753 .92 r
.62476 .23813 .63077 .24597 .64287 .24165 .63689 .23377 Mtetra
.63689 .23377 .64287 .24165 .65503 .23731 .64908 .2294 Mtetra
.64908 .2294 .65503 .23731 .66723 .23296 .66132 .22501 Mtetra
.66132 .22501 .66723 .23296 .67949 .22859 .67361 .22061 Mtetra
.67361 .22061 .67949 .22859 .69179 .22421 .68596 .21619 Mtetra
.68596 .21619 .69179 .22421 .70416 .21981 .69836 .21176 Mtetra
.657 .753 .92 r
.69836 .21176 .70416 .21981 .71657 .2154 .71081 .20731 Mtetra
.71081 .20731 .71657 .2154 .72905 .21097 .72332 .20284 Mtetra
.72332 .20284 .72905 .21097 .74157 .20652 .73589 .19835 Mtetra
.73589 .19835 .74157 .20652 .75415 .20205 .7485 .19385 Mtetra
.539 .676 .927 r
.08079 .42101 .08806 .42868 .09742 .42951 .09041 .41993 Mtetra
.852 .711 .707 r
.09041 .41993 .09742 .42951 .10828 .41905 .1026 .39957 Mtetra
.029 .131 .637 r
.1026 .39957 .10828 .41905 .11793 .41831 .1107 .41068 Mtetra
.547 .683 .928 r
.1107 .41068 .11793 .41831 .12739 .41951 .12047 .40943 Mtetra
.831 .706 .727 r
.12047 .40943 .12739 .41951 .13836 .40857 .13217 .39275 Mtetra
.173 .283 .737 r
.13217 .39275 .13836 .40857 .14818 .40756 .14099 .39993 Mtetra
.56 .689 .926 r
.14099 .39993 .14818 .40756 .15791 .40773 .15093 .39843 Mtetra
.887 .718 .666 r
.15093 .39843 .15791 .40773 .16888 .3973 .16412 .36857 Mtetra
0 0 .495 r
.16412 .36857 .16888 .3973 .17881 .39646 .17169 .38878 Mtetra
.573 .694 .924 r
.17169 .38878 .17881 .39646 .18884 .39528 .18179 .387 Mtetra
0 .201 .715 r
.18179 .387 .18884 .39528 .19993 .38413 .19102 .39414 Mtetra
.767 .93 .573 r
.19102 .39414 .19993 .38413 .20983 .38501 .20279 .37708 Mtetra
.572 .688 .919 r
.20279 .37708 .20983 .38501 .22007 .38304 .21302 .37531 Mtetra
.528 .677 .933 r
.21302 .37531 .22007 .38304 .22788 .40806 .22324 .37432 Mtetra
.648 .476 .637 r
.22324 .37432 .22788 .40806 .24125 .37301 .23439 .36364 Mtetra
.507 .62 .898 r
.23439 .36364 .24125 .37301 .25163 .37096 .24464 .36335 Mtetra
.593 .709 .924 r
.24464 .36335 .25163 .37096 .26203 .36937 .25511 .36107 Mtetra
.074 .41 .861 r
.25511 .36107 .26203 .36937 .2733 .35746 .26506 .36583 Mtetra
.729 .927 .584 r
.26506 .36583 .2733 .35746 .28357 .35869 .27667 .35059 Mtetra
.582 .692 .917 r
.27667 .35059 .28357 .35869 .29418 .35617 .28726 .34855 Mtetra
.599 .714 .924 r
.28726 .34855 .29418 .35617 .30477 .35467 .29794 .34608 Mtetra
0 .034 .571 r
.29794 .34608 .30477 .35467 .31606 .3434 .3078 .3563 Mtetra
.698 .849 .427 r
.3078 .3563 .31606 .3434 .32664 .34346 .31982 .33539 Mtetra
.594 .7 .917 r
.31982 .33539 .32664 .34346 .33745 .34067 .33063 .33305 Mtetra
.615 .722 .923 r
.33063 .33305 .33745 .34067 .3483 .33817 .34152 .33018 Mtetra
.524 .675 .933 r
.34152 .33018 .3483 .33817 .36416 .24123 .35236 .32922 Mtetra
.442 .185 .427 r
.35236 .32922 .36416 .24123 .37045 .32728 .36379 .31817 Mtetra
.55 .654 .904 r
.36379 .31817 .37045 .32728 .38145 .32457 .37474 .31685 Mtetra
.623 .726 .92 r
.37474 .31685 .38145 .32457 .39253 .32138 .38583 .31373 Mtetra
.624 .729 .922 r
.38583 .31373 .39253 .32138 .40364 .31857 .39698 .31056 Mtetra
.555 .691 .93 r
.39698 .31056 .40364 .31857 .41376 .34559 .40813 .30895 Mtetra
.643 .466 .63 r
.40813 .30895 .41376 .34559 .4262 .30731 .41966 .29761 Mtetra
.535 .634 .896 r
.41966 .29761 .4262 .30731 .43746 .3045 .43088 .29667 Mtetra
.629 .729 .919 r
.43088 .29667 .43746 .3045 .44878 .30101 .44223 .29334 Mtetra
.639 .739 .921 r
.44223 .29334 .44878 .30101 .46016 .29739 .45363 .28971 Mtetra
.64 .74 .921 r
.45363 .28971 .46016 .29739 .47159 .29385 .46509 .28606 Mtetra
.629 .733 .922 r
.46509 .28606 .47159 .29385 .48306 .29102 .4766 .28267 Mtetra
.498 .659 .933 r
.4766 .28267 .48306 .29102 .49478 .26872 .48813 .28217 Mtetra
0 0 0 r
.48813 .28217 .49478 .26872 .50621 .2792 .49982 .27021 Mtetra
.583 .681 .908 r
.49982 .27021 .50621 .2792 .51784 .27591 .51147 .26799 Mtetra
.639 .736 .919 r
.51147 .26799 .51784 .27591 .52952 .27206 .52317 .26429 Mtetra
.649 .745 .92 r
.52317 .26429 .52952 .27206 .54124 .26804 .53494 .26029 Mtetra
.653 .749 .92 r
.53494 .26029 .54124 .26804 .55302 .26391 .54675 .25616 Mtetra
.656 .751 .92 r
.54675 .25616 .55302 .26391 .56485 .2597 .55861 .25195 Mtetra
.657 .753 .92 r
.55861 .25195 .56485 .2597 .57673 .25544 .57053 .24768 Mtetra
.658 .753 .92 r
.57053 .24768 .57673 .25544 .58866 .25115 .58249 .24335 Mtetra
.659 .754 .92 r
.58249 .24335 .58866 .25115 .60064 .24682 .5945 .239 Mtetra
.5945 .239 .60064 .24682 .61267 .24248 .60657 .23462 Mtetra
.60657 .23462 .61267 .24248 .62476 .23813 .61869 .23024 Mtetra
.658 .754 .92 r
.61869 .23024 .62476 .23813 .63689 .23377 .63086 .22584 Mtetra
.658 .753 .92 r
.63086 .22584 .63689 .23377 .64908 .2294 .64308 .22142 Mtetra
.64308 .22142 .64908 .2294 .66132 .22501 .65536 .217 Mtetra
.65536 .217 .66132 .22501 .67361 .22061 .66769 .21256 Mtetra
.66769 .21256 .67361 .22061 .68596 .21619 .68007 .2081 Mtetra
.68007 .2081 .68596 .21619 .69836 .21176 .69251 .20363 Mtetra
.69251 .20363 .69836 .21176 .71081 .20731 .705 .19915 Mtetra
.657 .753 .92 r
.705 .19915 .71081 .20731 .72332 .20284 .71755 .19464 Mtetra
.71755 .19464 .72332 .20284 .73589 .19835 .73015 .19012 Mtetra
.73015 .19012 .73589 .19835 .7485 .19385 .74281 .18557 Mtetra
.484 .616 .906 r
.07365 .41208 .08079 .42101 .09041 .41993 .08311 .41211 Mtetra
.409 .617 .936 r
.08311 .41211 .09041 .41993 .1026 .39957 .09254 .41289 Mtetra
0 0 0 r
.09254 .41289 .1026 .39957 .1107 .41068 .1035 .40234 Mtetra
.526 .653 .916 r
.1035 .40234 .1107 .41068 .12047 .40943 .11322 .40154 Mtetra
.381 .602 .934 r
.11322 .40154 .12047 .40943 .13217 .39275 .12276 .40269 Mtetra
0 0 0 r
.12276 .40269 .13217 .39275 .14099 .39993 .13384 .39166 Mtetra
.54 .663 .916 r
.13384 .39166 .14099 .39993 .15093 .39843 .14373 .39059 Mtetra
.459 .642 .936 r
.14373 .39059 .15093 .39843 .16412 .36857 .15354 .39071 Mtetra
.137 0 .115 r
.15354 .39071 .16412 .36857 .17169 .38878 .16461 .38018 Mtetra
.532 .652 .912 r
.16461 .38018 .17169 .38878 .18179 .387 .17463 .37928 Mtetra
.542 .684 .931 r
.17463 .37928 .18179 .387 .19102 .39414 .18473 .37805 Mtetra
.737 .614 .721 r
.18473 .37805 .19102 .39414 .20279 .37708 .19593 .36679 Mtetra
.453 .569 .882 r
.19593 .36679 .20279 .37708 .21302 .37531 .20591 .36762 Mtetra
.582 .702 .925 r
.20591 .36762 .21302 .37531 .22324 .37432 .21624 .36559 Mtetra
.906 .502 .115 r
.21624 .36559 .22324 .37432 .23439 .36364 .22409 .39065 Mtetra
0 0 0 r
.22409 .39065 .23439 .36364 .24464 .36335 .23761 .35541 Mtetra
.585 .698 .92 r
.23761 .35541 .24464 .36335 .25511 .36107 .24809 .3533 Mtetra
.561 .694 .93 r
.24809 .3533 .25511 .36107 .26506 .36583 .25857 .35165 Mtetra
.762 .647 .735 r
.25857 .35165 .26506 .36583 .27667 .35059 .26996 .33963 Mtetra
.443 .551 .87 r
.26996 .33963 .27667 .35059 .28726 .34855 .28031 .3408 Mtetra
.604 .713 .922 r
.28031 .3408 .28726 .34855 .29794 .34608 .29101 .33822 Mtetra
.555 .692 .93 r
.29101 .33822 .29794 .34608 .3078 .3563 .30169 .33665 Mtetra
.715 .579 .7 r
.30169 .33665 .3078 .3563 .31982 .33539 .3131 .32528 Mtetra
.495 .6 .888 r
.3131 .32528 .31982 .33539 .33063 .33305 .32377 .32527 Mtetra
.613 .719 .921 r
.32377 .32527 .33063 .33305 .34152 .33018 .33468 .32242 Mtetra
.6 .715 .925 r
.33468 .32242 .34152 .33018 .35236 .32922 .34563 .31985 Mtetra
.952 .712 .538 r
.34563 .31985 .35236 .32922 .36379 .31817 .36171 .2225 Mtetra
0 0 .32 r
.36171 .2225 .36379 .31817 .37474 .31685 .36799 .30879 Mtetra
.608 .712 .918 r
.36799 .30879 .37474 .31685 .38583 .31373 .37909 .30601 Mtetra
.627 .73 .921 r
.37909 .30601 .38583 .31373 .39698 .31056 .39027 .30275 Mtetra
.611 .722 .924 r
.39027 .30275 .39698 .31056 .40813 .30895 .40148 .29986 Mtetra
.862 .446 0 r
.40148 .29986 .40813 .30895 .41966 .29761 .41168 .32693 Mtetra
0 0 0 r
.41168 .32693 .41966 .29761 .43088 .29667 .42426 .28843 Mtetra
.61 .711 .917 r
.42426 .28843 .43088 .29667 .44223 .29334 .43562 .28555 Mtetra
.636 .736 .92 r
.43562 .28555 .44223 .29334 .45363 .28971 .44706 .28198 Mtetra
.641 .74 .921 r
.44706 .28198 .45363 .28971 .46509 .28606 .45855 .27828 Mtetra
.637 .738 .921 r
.45855 .27828 .46509 .28606 .4766 .28267 .47009 .27466 Mtetra
.608 .721 .925 r
.47009 .27466 .4766 .28267 .48813 .28217 .48167 .27175 Mtetra
.886 .742 .696 r
.48167 .27175 .48813 .28217 .49982 .27021 .49351 .24931 Mtetra
.22 .265 .696 r
.49351 .24931 .49982 .27021 .51147 .26799 .50505 .25976 Mtetra
.625 .723 .917 r
.50505 .25976 .51147 .26799 .52317 .26429 .51678 .25638 Mtetra
.645 .742 .92 r
.51678 .25638 .52317 .26429 .53494 .26029 .52858 .25246 Mtetra
.651 .748 .92 r
.52858 .25246 .53494 .26029 .54675 .25616 .54042 .24835 Mtetra
.655 .75 .92 r
.54042 .24835 .54675 .25616 .55861 .25195 .55232 .24413 Mtetra
.657 .752 .92 r
.55232 .24413 .55861 .25195 .57053 .24768 .56427 .23984 Mtetra
.658 .753 .92 r
.56427 .23984 .57053 .24768 .58249 .24335 .57627 .2355 Mtetra
.659 .754 .92 r
.57627 .2355 .58249 .24335 .5945 .239 .58832 .23111 Mtetra
.58832 .23111 .5945 .239 .60657 .23462 .60042 .2267 Mtetra
.60042 .2267 .60657 .23462 .61869 .23024 .61257 .22228 Mtetra
.61257 .22228 .61869 .23024 .63086 .22584 .62478 .21784 Mtetra
.658 .753 .92 r
.62478 .21784 .63086 .22584 .64308 .22142 .63704 .21339 Mtetra
.63704 .21339 .64308 .22142 .65536 .217 .64935 .20892 Mtetra
.64935 .20892 .65536 .217 .66769 .21256 .66172 .20445 Mtetra
.66172 .20445 .66769 .21256 .68007 .2081 .67414 .19995 Mtetra
.67414 .19995 .68007 .2081 .69251 .20363 .68661 .19545 Mtetra
.68661 .19545 .69251 .20363 .705 .19915 .69914 .19092 Mtetra
.657 .753 .92 r
.69914 .19092 .705 .19915 .71755 .19464 .71173 .18638 Mtetra
.71173 .18638 .71755 .19464 .73015 .19012 .72437 .18181 Mtetra
.72437 .18181 .73015 .19012 .74281 .18557 .73707 .17723 Mtetra
.685 .713 .191 r
.05625 .47491 .07365 .41208 .08311 .41211 .07576 .40431 Mtetra
.54 .676 .927 r
.07576 .40431 .08311 .41211 .09254 .41289 .08545 .40317 Mtetra
.853 .712 .707 r
.08545 .40317 .09254 .41289 .1035 .40234 .09777 .38268 Mtetra
.024 .128 .636 r
.09777 .38268 .1035 .40234 .11322 .40154 .10591 .39379 Mtetra
.547 .683 .928 r
.10591 .39379 .11322 .40154 .12276 .40269 .11576 .39248 Mtetra
.832 .707 .727 r
.11576 .39248 .12276 .40269 .13384 .39166 .12758 .37567 Mtetra
.171 .281 .736 r
.12758 .37567 .13384 .39166 .14373 .39059 .13646 .38283 Mtetra
.56 .689 .926 r
.13646 .38283 .14373 .39059 .15354 .39071 .14648 .38127 Mtetra
.888 .719 .665 r
.14648 .38127 .15354 .39071 .16461 .38018 .15983 .35124 Mtetra
0 0 .492 r
.15983 .35124 .16461 .38018 .17463 .37928 .16742 .37147 Mtetra
.573 .694 .924 r
.16742 .37147 .17463 .37928 .18473 .37805 .17761 .36963 Mtetra
0 .205 .718 r
.17761 .36963 .18473 .37805 .19593 .36679 .1869 .37674 Mtetra
.774 .935 .58 r
.1869 .37674 .19593 .36679 .20591 .36762 .19879 .35955 Mtetra
.572 .688 .919 r
.19879 .35955 .20591 .36762 .21624 .36559 .20911 .35772 Mtetra
.528 .677 .933 r
.20911 .35772 .21624 .36559 .22409 .39065 .21942 .35668 Mtetra
.647 .475 .637 r
.21942 .35668 .22409 .39065 .23761 .35541 .23068 .3459 Mtetra
.506 .62 .899 r
.23068 .3459 .23761 .35541 .24809 .3533 .24101 .34554 Mtetra
.593 .709 .924 r
.24101 .34554 .24809 .3533 .25857 .35165 .25157 .3432 Mtetra
.078 .412 .863 r
.25157 .3432 .25857 .35165 .26996 .33963 .2616 .34792 Mtetra
.737 .932 .592 r
.2616 .34792 .26996 .33963 .28031 .3408 .27333 .33256 Mtetra
.582 .692 .917 r
.27333 .33256 .28031 .3408 .29101 .33822 .28402 .33046 Mtetra
.599 .714 .924 r
.28402 .33046 .29101 .33822 .30169 .33665 .29479 .32792 Mtetra
0 .041 .578 r
.29479 .32792 .30169 .33665 .3131 .32528 .30473 .33812 Mtetra
.706 .856 .436 r
.30473 .33812 .3131 .32528 .32377 .32527 .31688 .31707 Mtetra
.594 .7 .917 r
.31688 .31707 .32377 .32527 .33468 .32242 .32778 .31465 Mtetra
.615 .722 .923 r
.32778 .31465 .33468 .32242 .34563 .31985 .33877 .31171 Mtetra
.524 .675 .933 r
.33877 .31171 .34563 .31985 .36171 .2225 .34971 .31069 Mtetra
.437 .178 .422 r
.34971 .31069 .36171 .2225 .36799 .30879 .36125 .29953 Mtetra
.55 .654 .904 r
.36125 .29953 .36799 .30879 .37909 .30601 .3723 .29815 Mtetra
.623 .726 .92 r
.3723 .29815 .37909 .30601 .39027 .30275 .3835 .29495 Mtetra
.624 .729 .922 r
.3835 .29495 .39027 .30275 .40148 .29986 .39475 .2917 Mtetra
.555 .691 .93 r
.39475 .2917 .40148 .29986 .41168 .32693 .406 .29003 Mtetra
.642 .465 .628 r
.406 .29003 .41168 .32693 .42426 .28843 .41765 .27858 Mtetra
.535 .634 .896 r
.41765 .27858 .42426 .28843 .43562 .28555 .42897 .27757 Mtetra
.629 .729 .919 r
.42897 .27757 .43562 .28555 .44706 .28198 .44043 .27416 Mtetra
.639 .739 .921 r
.44043 .27416 .44706 .28198 .45855 .27828 .45195 .27045 Mtetra
.64 .74 .921 r
.45195 .27045 .45855 .27828 .47009 .27466 .46352 .26672 Mtetra
.629 .733 .922 r
.46352 .26672 .47009 .27466 .48167 .27175 .47514 .26325 Mtetra
.499 .659 .932 r
.47514 .26325 .48167 .27175 .49351 .24931 .48677 .26267 Mtetra
0 0 0 r
.48677 .26267 .49351 .24931 .50505 .25976 .49859 .25061 Mtetra
.583 .681 .908 r
.49859 .25061 .50505 .25976 .51678 .25638 .51034 .24831 Mtetra
.639 .736 .919 r
.51034 .24831 .51678 .25638 .52858 .25246 .52217 .24452 Mtetra
.649 .745 .92 r
.52217 .24452 .52858 .25246 .54042 .24835 .53405 .24044 Mtetra
.653 .749 .92 r
.53405 .24044 .54042 .24835 .55232 .24413 .54598 .23623 Mtetra
.656 .751 .92 r
.54598 .23623 .55232 .24413 .56427 .23984 .55796 .23193 Mtetra
.657 .753 .92 r
.55796 .23193 .56427 .23984 .57627 .2355 .56999 .22757 Mtetra
.658 .753 .92 r
.56999 .22757 .57627 .2355 .58832 .23111 .58208 .22316 Mtetra
.659 .754 .92 r
.58208 .22316 .58832 .23111 .60042 .2267 .59422 .21872 Mtetra
.59422 .21872 .60042 .2267 .61257 .22228 .60641 .21425 Mtetra
.60641 .21425 .61257 .22228 .62478 .21784 .61865 .20978 Mtetra
.658 .754 .92 r
.61865 .20978 .62478 .21784 .63704 .21339 .63094 .20529 Mtetra
.658 .753 .92 r
.63094 .20529 .63704 .21339 .64935 .20892 .64329 .20078 Mtetra
.64329 .20078 .64935 .20892 .66172 .20445 .6557 .19627 Mtetra
.6557 .19627 .66172 .20445 .67414 .19995 .66816 .19174 Mtetra
.66816 .19174 .67414 .19995 .68661 .19545 .68067 .18719 Mtetra
.68067 .18719 .68661 .19545 .69914 .19092 .69324 .18263 Mtetra
.69324 .18263 .69914 .19092 .71173 .18638 .70586 .17804 Mtetra
.657 .753 .92 r
.70586 .17804 .71173 .18638 .72437 .18181 .71854 .17344 Mtetra
.71854 .17344 .72437 .18181 .73707 .17723 .73128 .16883 Mtetra
.583 .381 .573 r
.05759 .40538 .05625 .47491 .07576 .40431 .06853 .39525 Mtetra
.484 .616 .906 r
.06853 .39525 .07576 .40431 .08545 .40317 .07807 .39523 Mtetra
.41 .617 .936 r
.07807 .39523 .08545 .40317 .09777 .38268 .08756 .39595 Mtetra
0 0 0 r
.08756 .39595 .09777 .38268 .10591 .39379 .09864 .38531 Mtetra
.526 .654 .916 r
.09864 .38531 .10591 .39379 .11576 .39248 .10843 .38445 Mtetra
.381 .602 .934 r
.10843 .38445 .11576 .39248 .12758 .37567 .11804 .38556 Mtetra
0 0 0 r
.11804 .38556 .12758 .37567 .13646 .38283 .12922 .37443 Mtetra
.539 .663 .916 r
.12922 .37443 .13646 .38283 .14648 .38127 .1392 .3733 Mtetra
.46 .643 .936 r
.1392 .3733 .14648 .38127 .15983 .35124 .14909 .37336 Mtetra
.124 0 .101 r
.14909 .37336 .15983 .35124 .16742 .37147 .16026 .36274 Mtetra
.532 .652 .912 r
.16026 .36274 .16742 .37147 .17761 .36963 .17036 .36178 Mtetra
.542 .683 .931 r
.17036 .36178 .17761 .36963 .1869 .37674 .18055 .36049 Mtetra
.738 .615 .721 r
.18055 .36049 .1869 .37674 .19879 .35955 .19186 .34913 Mtetra
.452 .569 .882 r
.19186 .34913 .19879 .35955 .20911 .35772 .20192 .34991 Mtetra
.582 .702 .925 r
.20192 .34991 .20911 .35772 .21942 .35668 .21234 .34781 Mtetra
.904 .499 .107 r
.21234 .34781 .21942 .35668 .23068 .3459 .22022 .37291 Mtetra
.663 .749 .257 r
.22022 .37291 .23068 .3459 .24101 .34554 .2339 .33747 Mtetra
.585 .698 .92 r
.2339 .33747 .24101 .34554 .25157 .3432 .24447 .33529 Mtetra
.561 .694 .93 r
.24447 .33529 .25157 .3432 .2616 .34792 .25505 .33357 Mtetra
.762 .647 .735 r
.25505 .33357 .2616 .34792 .27333 .33256 .26654 .32145 Mtetra
.443 .55 .87 r
.26654 .32145 .27333 .33256 .28402 .33046 .27698 .32257 Mtetra
.604 .713 .922 r
.27698 .32257 .28402 .33046 .29479 .32792 .28778 .31991 Mtetra
.555 .691 .93 r
.28778 .31991 .29479 .32792 .30473 .33812 .29856 .31827 Mtetra
.715 .579 .7 r
.29856 .31827 .30473 .33812 .31688 .31707 .31007 .3068 Mtetra
.494 .6 .888 r
.31007 .3068 .31688 .31707 .32778 .31465 .32084 .30674 Mtetra
.613 .719 .921 r
.32084 .30674 .32778 .31465 .33877 .31171 .33185 .30381 Mtetra
.6 .715 .925 r
.33185 .30381 .33877 .31171 .34971 .31069 .3429 .30116 Mtetra
.953 .712 .536 r
.3429 .30116 .34971 .31069 .36125 .29953 .35921 .2034 Mtetra
0 0 .315 r
.35921 .2034 .36125 .29953 .3723 .29815 .36547 .28994 Mtetra
.608 .712 .918 r
.36547 .28994 .3723 .29815 .3835 .29495 .37668 .28708 Mtetra
.627 .73 .921 r
.37668 .28708 .3835 .29495 .39475 .2917 .38796 .28374 Mtetra
.611 .722 .924 r
.38796 .28374 .39475 .2917 .406 .29003 .39928 .28078 Mtetra
.858 .441 0 r
.39928 .28078 .406 .29003 .41765 .27858 .40955 .30789 Mtetra
0 0 0 r
.40955 .30789 .41765 .27858 .42897 .27757 .42228 .26917 Mtetra
.61 .711 .917 r
.42228 .26917 .42897 .27757 .44043 .27416 .43375 .26622 Mtetra
.636 .736 .92 r
.43375 .26622 .44043 .27416 .45195 .27045 .4453 .26257 Mtetra
.641 .74 .921 r
.4453 .26257 .45195 .27045 .46352 .26672 .4569 .25878 Mtetra
.637 .738 .921 r
.4569 .25878 .46352 .26672 .47514 .26325 .46855 .25508 Mtetra
.608 .72 .925 r
.46855 .25508 .47514 .26325 .48677 .26267 .48024 .2521 Mtetra
.888 .743 .696 r
.48024 .2521 .48677 .26267 .49859 .25061 .49221 .2295 Mtetra
.217 .263 .696 r
.49221 .2295 .49859 .25061 .51034 .24831 .50386 .23992 Mtetra
.625 .723 .917 r
.50386 .23992 .51034 .24831 .52217 .24452 .51571 .23646 Mtetra
.645 .742 .92 r
.51571 .23646 .52217 .24452 .53405 .24044 .52762 .23245 Mtetra
.651 .748 .92 r
.52762 .23245 .53405 .24044 .54598 .23623 .53959 .22825 Mtetra
.655 .75 .92 r
.53959 .22825 .54598 .23623 .55796 .23193 .5516 .22395 Mtetra
.657 .752 .92 r
.5516 .22395 .55796 .23193 .56999 .22757 .56367 .21957 Mtetra
.658 .753 .92 r
.56367 .21957 .56999 .22757 .58208 .22316 .57579 .21514 Mtetra
.659 .754 .92 r
.57579 .21514 .58208 .22316 .59422 .21872 .58796 .21067 Mtetra
.58796 .21067 .59422 .21872 .60641 .21425 .60019 .20617 Mtetra
.60019 .20617 .60641 .21425 .61865 .20978 .61247 .20165 Mtetra
.61247 .20165 .61865 .20978 .63094 .20529 .6248 .19712 Mtetra
.658 .753 .92 r
.6248 .19712 .63094 .20529 .64329 .20078 .63719 .19258 Mtetra
.63719 .19258 .64329 .20078 .6557 .19627 .64963 .18802 Mtetra
.64963 .18802 .6557 .19627 .66816 .19174 .66213 .18345 Mtetra
.66213 .18345 .66816 .19174 .68067 .18719 .67468 .17887 Mtetra
.67468 .17887 .68067 .18719 .69324 .18263 .68728 .17427 Mtetra
.68728 .17427 .69324 .18263 .70586 .17804 .69995 .16964 Mtetra
.657 .753 .92 r
.69995 .16964 .70586 .17804 .71854 .17344 .71267 .16501 Mtetra
.71267 .16501 .71854 .17344 .73128 .16883 .72545 .16035 Mtetra
.95 .646 .425 r
.05024 .39657 .05759 .40538 .06853 .39525 .05084 .45825 Mtetra
.694 .72 .2 r
.05084 .45825 .06853 .39525 .07807 .39523 .07063 .3873 Mtetra
.54 .676 .927 r
.07063 .3873 .07807 .39523 .08756 .39595 .0804 .3861 Mtetra
.854 .713 .706 r
.0804 .3861 .08756 .39595 .09864 .38531 .09285 .36547 Mtetra
.02 .125 .634 r
.09285 .36547 .09864 .38531 .10843 .38445 .10103 .37657 Mtetra
.547 .683 .928 r
.10103 .37657 .10843 .38445 .11804 .38556 .11096 .3752 Mtetra
.832 .708 .727 r
.11096 .3752 .11804 .38556 .12922 .37443 .12291 .35827 Mtetra
.168 .279 .736 r
.12291 .35827 .12922 .37443 .1392 .3733 .13185 .36541 Mtetra
.56 .689 .926 r
.13185 .36541 .1392 .3733 .14909 .37336 .14195 .36378 Mtetra
.889 .719 .665 r
.14195 .36378 .14909 .37336 .16026 .36274 .15545 .33358 Mtetra
0 0 .489 r
.15545 .33358 .16026 .36274 .17036 .36178 .16307 .35383 Mtetra
.573 .694 .924 r
.16307 .35383 .17036 .36178 .18055 .36049 .17334 .35193 Mtetra
0 .209 .722 r
.17334 .35193 .18055 .36049 .19186 .34913 .1827 .35901 Mtetra
.781 .939 .588 r
.1827 .35901 .19186 .34913 .20192 .34991 .19472 .3417 Mtetra
.572 .688 .919 r
.19472 .3417 .20192 .34991 .21234 .34781 .20513 .3398 Mtetra
.528 .677 .933 r
.20513 .3398 .21234 .34781 .22022 .37291 .21552 .33869 Mtetra
.646 .473 .636 r
.21552 .33869 .22022 .37291 .2339 .33747 .22689 .32781 Mtetra
.506 .62 .899 r
.22689 .32781 .2339 .33747 .24447 .33529 .23731 .3274 Mtetra
.593 .709 .924 r
.23731 .3274 .24447 .33529 .25505 .33357 .24797 .32498 Mtetra
.082 .414 .864 r
.24797 .32498 .25505 .33357 .26654 .32145 .25808 .32966 Mtetra
.744 .936 .6 r
.25808 .32966 .26654 .32145 .27698 .32257 .26993 .31418 Mtetra
.582 .692 .917 r
.26993 .31418 .27698 .32257 .28778 .31991 .28071 .31201 Mtetra
.6 .714 .924 r
.28071 .31201 .28778 .31991 .29856 .31827 .29158 .3094 Mtetra
0 .047 .584 r
.29158 .3094 .29856 .31827 .31007 .3068 .30159 .31957 Mtetra
.715 .862 .445 r
.30159 .31957 .31007 .3068 .32084 .30674 .31387 .29838 Mtetra
.594 .7 .917 r
.31387 .29838 .32084 .30674 .33185 .30381 .32488 .29589 Mtetra
.615 .722 .923 r
.32488 .29589 .33185 .30381 .3429 .30116 .33597 .29288 Mtetra
.524 .675 .933 r
.33597 .29288 .3429 .30116 .35921 .2034 .34701 .29179 Mtetra
.432 .171 .416 r
.34701 .29179 .35921 .2034 .36547 .28994 .35866 .28052 Mtetra
.55 .654 .904 r
.35866 .28052 .36547 .28994 .37668 .28708 .36981 .27907 Mtetra
.623 .726 .92 r
.36981 .27907 .37668 .28708 .38796 .28374 .38112 .27579 Mtetra
.624 .729 .922 r
.38112 .27579 .38796 .28374 .39928 .28078 .39248 .27247 Mtetra
.555 .691 .93 r
.39248 .27247 .39928 .28078 .40955 .30789 .40383 .27072 Mtetra
.641 .463 .627 r
.40383 .27072 .40955 .30789 .42228 .26917 .4156 .25916 Mtetra
.534 .634 .896 r
.4156 .25916 .42228 .26917 .43375 .26622 .42703 .25808 Mtetra
.629 .729 .919 r
.42703 .25808 .43375 .26622 .4453 .26257 .4386 .25459 Mtetra
.639 .739 .921 r
.4386 .25459 .4453 .26257 .4569 .25878 .45022 .2508 Mtetra
.64 .74 .921 r
.45022 .2508 .4569 .25878 .46855 .25508 .46191 .24699 Mtetra
.629 .733 .922 r
.46191 .24699 .46855 .25508 .48024 .2521 .47364 .24343 Mtetra
.499 .659 .932 r
.47364 .24343 .48024 .2521 .49221 .2295 .48539 .24279 Mtetra
0 0 0 r
.48539 .24279 .49221 .2295 .50386 .23992 .49733 .23061 Mtetra
.583 .681 .908 r
.49733 .23061 .50386 .23992 .51571 .23646 .5092 .22823 Mtetra
.639 .736 .919 r
.5092 .22823 .51571 .23646 .52762 .23245 .52114 .22436 Mtetra
.649 .745 .92 r
.52114 .22436 .52762 .23245 .53959 .22825 .53314 .22019 Mtetra
.653 .749 .92 r
.53314 .22019 .53959 .22825 .5516 .22395 .54519 .21589 Mtetra
.656 .751 .92 r
.54519 .21589 .5516 .22395 .56367 .21957 .5573 .2115 Mtetra
.657 .753 .92 r
.5573 .2115 .56367 .21957 .57579 .21514 .56945 .20705 Mtetra
.658 .753 .92 r
.56945 .20705 .57579 .21514 .58796 .21067 .58166 .20255 Mtetra
.659 .754 .92 r
.58166 .20255 .58796 .21067 .60019 .20617 .59392 .19802 Mtetra
.59392 .19802 .60019 .20617 .61247 .20165 .60624 .19346 Mtetra
.60624 .19346 .61247 .20165 .6248 .19712 .61861 .18889 Mtetra
.658 .754 .92 r
.61861 .18889 .6248 .19712 .63719 .19258 .63103 .18431 Mtetra
.658 .753 .92 r
.63103 .18431 .63719 .19258 .64963 .18802 .64351 .17971 Mtetra
.64351 .17971 .64963 .18802 .66213 .18345 .65604 .1751 Mtetra
.65604 .1751 .66213 .18345 .67468 .17887 .66864 .17048 Mtetra
.66864 .17048 .67468 .17887 .68728 .17427 .68128 .16584 Mtetra
.68128 .16584 .68728 .17427 .69995 .16964 .69398 .16118 Mtetra
.69398 .16118 .69995 .16964 .71267 .16501 .70674 .1565 Mtetra
.657 .753 .92 r
.70674 .1565 .71267 .16501 .72545 .16035 .71956 .1518 Mtetra
.481 .652 .934 r
.04272 .38862 .05024 .39657 .05084 .45825 .05227 .38833 Mtetra
.581 .378 .571 r
.05227 .38833 .05084 .45825 .07063 .3873 .06332 .3781 Mtetra
.484 .616 .906 r
.06332 .3781 .07063 .3873 .0804 .3861 .07293 .37803 Mtetra
.411 .617 .936 r
.07293 .37803 .0804 .3861 .09285 .36547 .0825 .3787 Mtetra
0 0 0 r
.0825 .3787 .09285 .36547 .10103 .37657 .09367 .36796 Mtetra
.526 .654 .916 r
.09367 .36796 .10103 .37657 .11096 .3752 .10355 .36704 Mtetra
.382 .602 .934 r
.10355 .36704 .11096 .3752 .12291 .35827 .11323 .36809 Mtetra
0 0 0 r
.11323 .36809 .12291 .35827 .13185 .36541 .12452 .35686 Mtetra
.539 .663 .917 r
.12452 .35686 .13185 .36541 .14195 .36378 .13458 .35568 Mtetra
.46 .643 .936 r
.13458 .35568 .14195 .36378 .15545 .33358 .14455 .35568 Mtetra
.11 0 .086 r
.14455 .35568 .15545 .33358 .16307 .35383 .15583 .34496 Mtetra
.531 .652 .912 r
.15583 .34496 .16307 .35383 .17334 .35193 .16602 .34394 Mtetra
.542 .683 .931 r
.16602 .34394 .17334 .35193 .1827 .35901 .17629 .34258 Mtetra
.738 .615 .721 r
.17629 .34258 .1827 .35901 .19472 .3417 .18771 .33112 Mtetra
.452 .569 .882 r
.18771 .33112 .19472 .3417 .20513 .3398 .19786 .33184 Mtetra
.582 .702 .925 r
.19786 .33184 .20513 .3398 .21552 .33869 .20836 .32968 Mtetra
.902 .496 .1 r
.20836 .32968 .21552 .33869 .22689 .32781 .21627 .35483 Mtetra
.672 .756 .267 r
.21627 .35483 .22689 .32781 .23731 .3274 .23012 .31918 Mtetra
.585 .698 .92 r
.23012 .31918 .23731 .3274 .24797 .32498 .24078 .31693 Mtetra
.561 .694 .929 r
.24078 .31693 .24797 .32498 .25808 .32966 .25146 .31515 Mtetra
.762 .648 .735 r
.25146 .31515 .25808 .32966 .26993 .31418 .26306 .30291 Mtetra
.442 .55 .87 r
.26306 .30291 .26993 .31418 .28071 .31201 .27359 .30398 Mtetra
.604 .713 .922 r
.27359 .30398 .28071 .31201 .29158 .3094 .28449 .30125 Mtetra
.555 .691 .93 r
.28449 .30125 .29158 .3094 .30159 .31957 .29536 .29954 Mtetra
.715 .579 .7 r
.29536 .29954 .30159 .31957 .31387 .29838 .30699 .28796 Mtetra
.494 .6 .888 r
.30699 .28796 .31387 .29838 .32488 .29589 .31785 .28783 Mtetra
.613 .719 .921 r
.31785 .28783 .32488 .29589 .33597 .29288 .32897 .28483 Mtetra
.6 .715 .925 r
.32897 .28483 .33597 .29288 .34701 .29179 .34012 .2821 Mtetra
.954 .713 .534 r
.34012 .2821 .34701 .29179 .35866 .28052 .35667 .18394 Mtetra
0 0 .309 r
.35667 .18394 .35866 .28052 .36981 .27907 .36291 .27071 Mtetra
.608 .712 .918 r
.36291 .27071 .36981 .27907 .38112 .27579 .37422 .26778 Mtetra
.627 .73 .921 r
.37422 .26778 .38112 .27579 .39248 .27247 .38561 .26435 Mtetra
.611 .722 .924 r
.38561 .26435 .39248 .27247 .40383 .27072 .39704 .26131 Mtetra
.853 .436 0 r
.39704 .26131 .40383 .27072 .4156 .25916 .40739 .28846 Mtetra
0 0 0 r
.40739 .28846 .4156 .25916 .42703 .25808 .42026 .24953 Mtetra
.61 .711 .917 r
.42026 .24953 .42703 .25808 .4386 .25459 .43184 .24649 Mtetra
.636 .736 .92 r
.43184 .24649 .4386 .25459 .45022 .2508 .4435 .24276 Mtetra
.641 .74 .921 r
.4435 .24276 .45022 .2508 .46191 .24699 .45521 .23889 Mtetra
.637 .738 .921 r
.45521 .23889 .46191 .24699 .47364 .24343 .46698 .23511 Mtetra
.608 .72 .925 r
.46698 .23511 .47364 .24343 .48539 .24279 .47879 .23204 Mtetra
.889 .744 .696 r
.47879 .23204 .48539 .24279 .49733 .23061 .49088 .20929 Mtetra
.214 .261 .695 r
.49088 .20929 .49733 .23061 .5092 .22823 .50264 .21967 Mtetra
.625 .723 .917 r
.50264 .21967 .5092 .22823 .52114 .22436 .51461 .21613 Mtetra
.645 .742 .92 r
.51461 .21613 .52114 .22436 .53314 .22019 .52664 .21203 Mtetra
.651 .748 .92 r
.52664 .21203 .53314 .22019 .54519 .21589 .53873 .20775 Mtetra
.655 .75 .92 r
.53873 .20775 .54519 .21589 .5573 .2115 .55087 .20335 Mtetra
.657 .752 .92 r
.55087 .20335 .5573 .2115 .56945 .20705 .56306 .19889 Mtetra
.658 .753 .92 r
.56306 .19889 .56945 .20705 .58166 .20255 .57531 .19436 Mtetra
.659 .754 .92 r
.57531 .19436 .58166 .20255 .59392 .19802 .5876 .1898 Mtetra
.5876 .1898 .59392 .19802 .60624 .19346 .59996 .18521 Mtetra
.59996 .18521 .60624 .19346 .61861 .18889 .61236 .1806 Mtetra
.61236 .1806 .61861 .18889 .63103 .18431 .62482 .17597 Mtetra
.658 .753 .92 r
.62482 .17597 .63103 .18431 .64351 .17971 .63734 .17133 Mtetra
.63734 .17133 .64351 .17971 .65604 .1751 .64991 .16668 Mtetra
.64991 .16668 .65604 .1751 .66864 .17048 .66254 .16202 Mtetra
.66254 .16202 .66864 .17048 .68128 .16584 .67523 .15734 Mtetra
.67523 .15734 .68128 .16584 .69398 .16118 .68797 .15264 Mtetra
.68797 .15264 .69398 .16118 .70674 .1565 .70077 .14792 Mtetra
.657 .753 .92 r
.70077 .14792 .70674 .1565 .71956 .1518 .71363 .14318 Mtetra
.524 .661 .922 r
.03519 .38031 .04272 .38862 .05227 .38833 .04484 .37938 Mtetra
.951 .645 .421 r
.04484 .37938 .05227 .38833 .06332 .3781 .04532 .44127 Mtetra
.703 .727 .209 r
.04532 .44127 .06332 .3781 .07293 .37803 .0654 .36997 Mtetra
.54 .676 .927 r
.0654 .36997 .07293 .37803 .0825 .3787 .07525 .36871 Mtetra
.854 .714 .706 r
.07525 .36871 .0825 .3787 .09367 .36796 .08783 .34794 Mtetra
.015 .121 .632 r
.08783 .34794 .09367 .36796 .10355 .36704 .09606 .35903 Mtetra
.547 .683 .928 r
.09606 .35903 .10355 .36704 .11323 .36809 .10607 .3576 Mtetra
.833 .709 .727 r
.10607 .3576 .11323 .36809 .12452 .35686 .11814 .34055 Mtetra
.165 .278 .735 r
.11814 .34055 .12452 .35686 .13458 .35568 .12714 .34765 Mtetra
.56 .689 .926 r
.12714 .34765 .13458 .35568 .14455 .35568 .13733 .34596 Mtetra
.89 .72 .664 r
.13733 .34596 .14455 .35568 .15583 .34496 .15098 .31558 Mtetra
0 0 .485 r
.15098 .31558 .15583 .34496 .16602 .34394 .15864 .33585 Mtetra
.573 .694 .924 r
.15864 .33585 .16602 .34394 .17629 .34258 .169 .33388 Mtetra
0 .213 .726 r
.169 .33388 .17629 .34258 .18771 .33112 .17843 .34094 Mtetra
.787 .943 .595 r
.17843 .34094 .18771 .33112 .19786 .33184 .19057 .32349 Mtetra
.572 .688 .919 r
.19057 .32349 .19786 .33184 .20836 .32968 .20107 .32153 Mtetra
.529 .677 .932 r
.20107 .32153 .20836 .32968 .21627 .35483 .21155 .32036 Mtetra
.645 .472 .635 r
.21155 .32036 .21627 .35483 .23012 .31918 .22303 .30937 Mtetra
.506 .62 .899 r
.22303 .30937 .23012 .31918 .24078 .31693 .23354 .30889 Mtetra
.593 .709 .924 r
.23354 .30889 .24078 .31693 .25146 .31515 .24429 .30641 Mtetra
.086 .416 .865 r
.24429 .30641 .25146 .31515 .26306 .30291 .25448 .31104 Mtetra
.751 .941 .608 r
.25448 .31104 .26306 .30291 .27359 .30398 .26646 .29544 Mtetra
.582 .692 .917 r
.26646 .29544 .27359 .30398 .28449 .30125 .27733 .2932 Mtetra
.6 .714 .924 r
.27733 .2932 .28449 .30125 .29536 .29954 .2883 .29051 Mtetra
0 .053 .59 r
.2883 .29051 .29536 .29954 .30699 .28796 .29839 .30066 Mtetra
.723 .868 .454 r
.29839 .30066 .30699 .28796 .31785 .28783 .31081 .27933 Mtetra
.594 .7 .917 r
.31081 .27933 .31785 .28783 .32897 .28483 .32191 .27676 Mtetra
.615 .722 .923 r
.32191 .27676 .32897 .28483 .34012 .2821 .33311 .27367 Mtetra
.524 .675 .933 r
.33311 .27367 .34012 .2821 .35667 .18394 .34425 .27251 Mtetra
.426 .163 .41 r
.34425 .27251 .35667 .18394 .36291 .27071 .35602 .26114 Mtetra
.55 .654 .904 r
.35602 .26114 .36291 .27071 .37422 .26778 .36727 .25961 Mtetra
.623 .726 .92 r
.36727 .25961 .37422 .26778 .38561 .26435 .37869 .25625 Mtetra
.624 .729 .922 r
.37869 .25625 .38561 .26435 .39704 .26131 .39016 .25285 Mtetra
.555 .691 .93 r
.39016 .25285 .39704 .26131 .40739 .28846 .40162 .25102 Mtetra
.64 .462 .626 r
.40162 .25102 .40739 .28846 .42026 .24953 .41351 .23935 Mtetra
.534 .634 .896 r
.41351 .23935 .42026 .24953 .43184 .24649 .42504 .2382 Mtetra
.629 .729 .919 r
.42504 .2382 .43184 .24649 .4435 .24276 .43672 .23463 Mtetra
.639 .739 .921 r
.43672 .23463 .4435 .24276 .45521 .23889 .44847 .23075 Mtetra
.64 .74 .921 r
.44847 .23075 .45521 .23889 .46698 .23511 .46027 .22685 Mtetra
.629 .733 .922 r
.46027 .22685 .46698 .23511 .47879 .23204 .47212 .22321 Mtetra
.499 .659 .932 r
.47212 .22321 .47879 .23204 .49088 .20929 .48398 .22249 Mtetra
0 0 0 r
.48398 .22249 .49088 .20929 .50264 .21967 .49604 .21019 Mtetra
.583 .681 .908 r
.49604 .21019 .50264 .21967 .51461 .21613 .50803 .20773 Mtetra
.639 .736 .919 r
.50803 .20773 .51461 .21613 .52664 .21203 .5201 .20377 Mtetra
.649 .745 .92 r
.5201 .20377 .52664 .21203 .53873 .20775 .53222 .19952 Mtetra
.653 .749 .92 r
.53222 .19952 .53873 .20775 .55087 .20335 .54439 .19513 Mtetra
.656 .751 .92 r
.54439 .19513 .55087 .20335 .56306 .19889 .55662 .19065 Mtetra
.657 .753 .92 r
.55662 .19065 .56306 .19889 .57531 .19436 .5689 .1861 Mtetra
.658 .753 .92 r
.5689 .1861 .57531 .19436 .5876 .1898 .58123 .18151 Mtetra
.659 .754 .92 r
.58123 .18151 .5876 .1898 .59996 .18521 .59362 .17688 Mtetra
.59362 .17688 .59996 .18521 .61236 .1806 .60607 .17223 Mtetra
.60607 .17223 .61236 .1806 .62482 .17597 .61857 .16757 Mtetra
.658 .754 .92 r
.61857 .16757 .62482 .17597 .63734 .17133 .63112 .16289 Mtetra
.658 .753 .92 r
.63112 .16289 .63734 .17133 .64991 .16668 .64373 .1582 Mtetra
.64373 .1582 .64991 .16668 .66254 .16202 .6564 .15349 Mtetra
.6564 .15349 .66254 .16202 .67523 .15734 .66912 .14877 Mtetra
.66912 .14877 .67523 .15734 .68797 .15264 .68191 .14403 Mtetra
.68191 .14403 .68797 .15264 .70077 .14792 .69474 .13927 Mtetra
.69474 .13927 .70077 .14792 .71363 .14318 .70764 .13449 Mtetra
.293 .431 .83 r
.02825 .36781 .03519 .38031 .04484 .37938 .03723 .3713 Mtetra
.481 .652 .934 r
.03723 .3713 .04484 .37938 .04532 .44127 .04685 .37095 Mtetra
.579 .375 .569 r
.04685 .37095 .04532 .44127 .0654 .36997 .05801 .36063 Mtetra
.483 .616 .906 r
.05801 .36063 .0654 .36997 .07525 .36871 .06769 .3605 Mtetra
.411 .617 .936 r
.06769 .3605 .07525 .36871 .08783 .34794 .07733 .36112 Mtetra
0 0 0 r
.07733 .36112 .08783 .34794 .09606 .35903 .08862 .35028 Mtetra
.526 .654 .916 r
.08862 .35028 .09606 .35903 .10607 .3576 .09857 .3493 Mtetra
.383 .602 .934 r
.09857 .3493 .10607 .3576 .11814 .34055 .10833 .3503 Mtetra
.498 .817 .502 r
.10833 .3503 .11814 .34055 .12714 .34765 .11973 .33897 Mtetra
.539 .663 .917 r
.11973 .33897 .12714 .34765 .13733 .34596 .12987 .33771 Mtetra
.46 .643 .936 r
.12987 .33771 .13733 .34596 .15098 .31558 .13992 .33766 Mtetra
.095 0 .072 r
.13992 .33766 .15098 .31558 .15864 .33585 .15132 .32684 Mtetra
.531 .652 .912 r
.15132 .32684 .15864 .33585 .169 .33388 .16158 .32576 Mtetra
.542 .683 .931 r
.16158 .32576 .169 .33388 .17843 .34094 .17195 .32433 Mtetra
.738 .615 .721 r
.17195 .32433 .17843 .34094 .19057 .32349 .18348 .31276 Mtetra
.451 .569 .882 r
.18348 .31276 .19057 .32349 .20107 .32153 .19371 .31343 Mtetra
.582 .702 .925 r
.19371 .31343 .20107 .32153 .21155 .32036 .20431 .3112 Mtetra
.899 .492 .092 r
.20431 .3112 .21155 .32036 .22303 .30937 .21225 .33638 Mtetra
.681 .764 .276 r
.21225 .33638 .22303 .30937 .23354 .30889 .22627 .30053 Mtetra
.585 .698 .92 r
.22627 .30053 .23354 .30889 .24429 .30641 .23702 .29821 Mtetra
.561 .694 .929 r
.23702 .29821 .24429 .30641 .25448 .31104 .24779 .29636 Mtetra
.763 .648 .735 r
.24779 .29636 .25448 .31104 .26646 .29544 .25951 .28401 Mtetra
.441 .55 .871 r
.25951 .28401 .26646 .29544 .27733 .2932 .27013 .28501 Mtetra
.604 .713 .922 r
.27013 .28501 .27733 .2932 .2883 .29051 .28113 .28221 Mtetra
.556 .691 .93 r
.28113 .28221 .2883 .29051 .29839 .30066 .2921 .28043 Mtetra
.715 .579 .7 r
.2921 .28043 .29839 .30066 .31081 .27933 .30385 .26874 Mtetra
.493 .6 .888 r
.30385 .26874 .31081 .27933 .32191 .27676 .31481 .26855 Mtetra
.613 .719 .921 r
.31481 .26855 .32191 .27676 .33311 .27367 .32603 .26546 Mtetra
.6 .715 .925 r
.32603 .26546 .33311 .27367 .34425 .27251 .33729 .26267 Mtetra
.955 .713 .531 r
.33729 .26267 .34425 .27251 .35602 .26114 .35408 .1641 Mtetra
0 0 .303 r
.35408 .1641 .35602 .26114 .36727 .25961 .36029 .25109 Mtetra
.608 .712 .918 r
.36029 .25109 .36727 .25961 .37869 .25625 .37171 .24808 Mtetra
.627 .73 .921 r
.37171 .24808 .37869 .25625 .39016 .25285 .38321 .24458 Mtetra
.611 .722 .924 r
.38321 .24458 .39016 .25285 .40162 .25102 .39475 .24145 Mtetra
.848 .431 0 r
.39475 .24145 .40162 .25102 .41351 .23935 .40517 .26863 Mtetra
0 0 0 r
.40517 .26863 .41351 .23935 .42504 .2382 .4182 .22949 Mtetra
.61 .711 .917 r
.4182 .22949 .42504 .2382 .43672 .23463 .4299 .22637 Mtetra
.636 .736 .92 r
.4299 .22637 .43672 .23463 .44847 .23075 .44167 .22255 Mtetra
.641 .74 .921 r
.44167 .22255 .44847 .23075 .46027 .22685 .4535 .21859 Mtetra
.637 .738 .921 r
.4535 .21859 .46027 .22685 .47212 .22321 .46538 .21472 Mtetra
.608 .72 .925 r
.46538 .21472 .47212 .22321 .48398 .22249 .47731 .21157 Mtetra
.89 .745 .695 r
.47731 .21157 .48398 .22249 .49604 .21019 .48953 .18867 Mtetra
.211 .259 .694 r
.48953 .18867 .49604 .21019 .50803 .20773 .5014 .19901 Mtetra
.625 .723 .917 r
.5014 .19901 .50803 .20773 .5201 .20377 .51349 .19538 Mtetra
.645 .742 .92 r
.51349 .19538 .5201 .20377 .53222 .19952 .52565 .19119 Mtetra
.651 .748 .92 r
.52565 .19119 .53222 .19952 .54439 .19513 .53786 .18681 Mtetra
.655 .75 .92 r
.53786 .18681 .54439 .19513 .55662 .19065 .55012 .18233 Mtetra
.657 .752 .92 r
.55012 .18233 .55662 .19065 .5689 .1861 .56244 .17777 Mtetra
.658 .753 .92 r
.56244 .17777 .5689 .1861 .58123 .18151 .57481 .17315 Mtetra
.659 .754 .92 r
.57481 .17315 .58123 .18151 .59362 .17688 .58724 .16849 Mtetra
.58724 .16849 .59362 .17688 .60607 .17223 .59972 .1638 Mtetra
.59972 .1638 .60607 .17223 .61857 .16757 .61226 .15909 Mtetra
.61226 .15909 .61857 .16757 .63112 .16289 .62485 .15437 Mtetra
.658 .753 .92 r
.62485 .15437 .63112 .16289 .64373 .1582 .6375 .14964 Mtetra
.6375 .14964 .64373 .1582 .6564 .15349 .6502 .14489 Mtetra
.6502 .14489 .6564 .15349 .66912 .14877 .66297 .14013 Mtetra
.66297 .14013 .66912 .14877 .68191 .14403 .67579 .13535 Mtetra
.67579 .13535 .68191 .14403 .69474 .13927 .68867 .13055 Mtetra
.68867 .13055 .69474 .13927 .70764 .13449 .70161 .12573 Mtetra
.755 .974 .709 r
.01813 .37521 .02825 .36781 .03723 .3713 .02961 .36286 Mtetra
.524 .661 .922 r
.02961 .36286 .03723 .3713 .04685 .37095 .03934 .36187 Mtetra
.951 .645 .418 r
.03934 .36187 .04685 .37095 .05801 .36063 .0397 .42396 Mtetra
.712 .734 .218 r
.0397 .42396 .05801 .36063 .06769 .3605 .06008 .3523 Mtetra
.54 .676 .927 r
.06008 .3523 .06769 .3605 .07733 .36112 .07 .35098 Mtetra
.855 .714 .706 r
.07 .35098 .07733 .36112 .08862 .35028 .08272 .33007 Mtetra
.01 .118 .63 r
.08272 .33007 .08862 .35028 .09857 .3493 .091 .34115 Mtetra
.547 .683 .928 r
.091 .34115 .09857 .3493 .10833 .3503 .10109 .33965 Mtetra
.834 .709 .727 r
.10109 .33965 .10833 .3503 .11973 .33897 .11329 .32248 Mtetra
.162 .276 .734 r
.11329 .32248 .11973 .33897 .12987 .33771 .12235 .32955 Mtetra
.56 .689 .926 r
.12235 .32955 .12987 .33771 .13992 .33766 .13262 .32779 Mtetra
.891 .721 .664 r
.13262 .32779 .13992 .33766 .15132 .32684 .14644 .29724 Mtetra
0 0 .481 r
.14644 .29724 .15132 .32684 .16158 .32576 .15412 .31753 Mtetra
.573 .694 .924 r
.15412 .31753 .16158 .32576 .17195 .32433 .16457 .31549 Mtetra
0 .218 .73 r
.16457 .31549 .17195 .32433 .18348 .31276 .17406 .3225 Mtetra
.793 .946 .602 r
.17406 .3225 .18348 .31276 .19371 .31343 .18633 .30493 Mtetra
.572 .688 .92 r
.18633 .30493 .19371 .31343 .20431 .3112 .19693 .3029 Mtetra
.529 .677 .932 r
.19693 .3029 .20431 .3112 .21225 .33638 .2075 .30166 Mtetra
.644 .471 .634 r
.2075 .30166 .21225 .33638 .22627 .30053 .2191 .29057 Mtetra
.505 .62 .899 r
.2191 .29057 .22627 .30053 .23702 .29821 .22969 .29003 Mtetra
.593 .709 .924 r
.22969 .29003 .23702 .29821 .24779 .29636 .24054 .28747 Mtetra
.09 .418 .866 r
.24054 .28747 .24779 .29636 .25951 .28401 .25082 .29205 Mtetra
.758 .945 .616 r
.25082 .29205 .25951 .28401 .27013 .28501 .26292 .27633 Mtetra
.582 .692 .917 r
.26292 .27633 .27013 .28501 .28113 .28221 .27389 .27401 Mtetra
.6 .714 .924 r
.27389 .27401 .28113 .28221 .2921 .28043 .28496 .27125 Mtetra
0 .059 .597 r
.28496 .27125 .2921 .28043 .30385 .26874 .29513 .28137 Mtetra
.731 .874 .462 r
.29513 .28137 .30385 .26874 .31481 .26855 .30768 .25989 Mtetra
.594 .701 .917 r
.30768 .25989 .31481 .26855 .32603 .26546 .31889 .25725 Mtetra
.615 .722 .923 r
.31889 .25725 .32603 .26546 .33729 .26267 .33019 .25408 Mtetra
.525 .675 .932 r
.33019 .25408 .33729 .26267 .35408 .1641 .34143 .25284 Mtetra
.42 .155 .404 r
.34143 .25284 .35408 .1641 .36029 .25109 .35332 .24136 Mtetra
.55 .654 .905 r
.35332 .24136 .36029 .25109 .37171 .24808 .36469 .23975 Mtetra
.623 .726 .92 r
.36469 .23975 .37171 .24808 .38321 .24458 .37621 .23631 Mtetra
.624 .729 .922 r
.37621 .23631 .38321 .24458 .39475 .24145 .38779 .23283 Mtetra
.555 .691 .93 r
.38779 .23283 .39475 .24145 .40517 .26863 .39936 .23092 Mtetra
.639 .46 .625 r
.39936 .23092 .40517 .26863 .4182 .22949 .41137 .21914 Mtetra
.534 .634 .896 r
.41137 .21914 .4182 .22949 .4299 .22637 .42302 .21791 Mtetra
.629 .729 .919 r
.42302 .21791 .4299 .22637 .44167 .22255 .43481 .21425 Mtetra
.639 .739 .921 r
.43481 .21425 .44167 .22255 .4535 .21859 .44668 .21029 Mtetra
.64 .74 .921 r
.44668 .21029 .4535 .21859 .46538 .21472 .45859 .2063 Mtetra
.629 .733 .922 r
.45859 .2063 .46538 .21472 .47731 .21157 .47056 .20257 Mtetra
.5 .659 .932 r
.47056 .20257 .47731 .21157 .48953 .18867 .48254 .20177 Mtetra
0 0 0 r
.48254 .20177 .48953 .18867 .5014 .19901 .49473 .18936 Mtetra
.583 .681 .908 r
.49473 .18936 .5014 .19901 .51349 .19538 .50684 .18681 Mtetra
.639 .736 .919 r
.50684 .18681 .51349 .19538 .52565 .19119 .51903 .18276 Mtetra
.649 .745 .92 r
.51903 .18276 .52565 .19119 .53786 .18681 .53127 .17841 Mtetra
.653 .749 .92 r
.53127 .17841 .53786 .18681 .55012 .18233 .54357 .17393 Mtetra
.656 .751 .92 r
.54357 .17393 .55012 .18233 .56244 .17777 .55592 .16935 Mtetra
.657 .753 .92 r
.55592 .16935 .56244 .17777 .57481 .17315 .56833 .16471 Mtetra
.658 .753 .92 r
.56833 .16471 .57481 .17315 .58724 .16849 .5808 .16002 Mtetra
.659 .754 .92 r
.5808 .16002 .58724 .16849 .59972 .1638 .59332 .1553 Mtetra
.59332 .1553 .59972 .1638 .61226 .15909 .60589 .15055 Mtetra
.60589 .15055 .61226 .15909 .62485 .15437 .61852 .14579 Mtetra
.658 .754 .92 r
.61852 .14579 .62485 .15437 .6375 .14964 .63121 .14101 Mtetra
.658 .753 .92 r
.63121 .14101 .6375 .14964 .6502 .14489 .64396 .13622 Mtetra
.64396 .13622 .6502 .14489 .66297 .14013 .65676 .13141 Mtetra
.65676 .13141 .66297 .14013 .67579 .13535 .66962 .12659 Mtetra
.66962 .12659 .67579 .13535 .68867 .13055 .68254 .12175 Mtetra
.68254 .12175 .68867 .13055 .70161 .12573 .69552 .11689 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`8006Aoo`03D_aBoE;l009Bo008D_eB
o5;lD_aBoE;l001Bo1Moo`03001oogoo04Uoo`00Sgoo0`00I7oo00mBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_d05Woo00<007oo0000BWoo002=Ool3001ROol00e;lD_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo000009Bo1Moo`03001oogoo04Qoo`00RWoo0`000goo00<007ooOol0GGoo
01MBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m01Moo`03001oogoo
04Moo`00Qgoo0`00Hgoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eB
o000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069oo`0PD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoAIoo`03001oogoo04Ioo`00
PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eoo`00P7oo0P00Hgoo02EBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00=BoE;lOol0
5Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1MOol0;5;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EB
oE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00Hgoo039Bo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;m5Woo00<007ooOol0@Woo001cOol3001SOol01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo000D_aBo@03D_`015;mD_aBo5;l5goo00<007ooOol0@Goo001aOol2001ROol0>E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo00EOol00`00
Ool00012Ool006ioo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d0
05;lD_aBo@03D_`015;mD_aBo5;l5Woo00<007ooOol0@7oo001[Ool3000SOol00c1[Oomoo`0mOol0
?TklD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_dGOol00`00Oomoo`0oOol006Uoo`8000=oo`03001oogoo021oo`03=8aoogoo03Qoo`03D_aB
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`0
1E;mD_aBo5;lD_d00U;l5Woo00<007ooOol0?goo001VOol3000XOol00c2<Oomoo`0dOol0BE;mC]aB
oDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m01Ioo`03001oogoo03ioo`00I7oo0P00:goo00<`S7ooOol0<Woo
00=>g5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol0?Goo001QOol3000]
Ool00c1[=8aoo`0`Ool0Ce;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Eoo`03
001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P00<7oo00<dS32<Ool0:Woo0P000TZl00U6_4ZlB[aB
oDkLC_a>g5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0EOol00`00Oomoo`0VOol0
0`00Oomoo`0COol003Aoo`03001oogoo009oo`03001oogoo021oo`<0035oo`03@[d`S3B<02]oo`1F
001^eATFAYa:_4JLB[a6W5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Ioo`03001o
ogoo02Eoo`03001oogoo01=oo`00>Goo00<007ooOol07Woo0P000Woo00<007ooOol0;goo0c2<:Woo
00<006keL_D00QSe0TZl00E6_4ZlB[aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eB
o7oo01Aoo`03001oogoo02Aoo`03001oo`0001Aoo`00;7oo1P001goo00<007ooOol06goo0`00=Woo
00<dS31[=8`0:Woo05Q^eG;fK]DI5ACe6AI>g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoAIoo`03001oogoo02=oo`03001oo`0001Aoo`00=Goo100077oo0P00>Goo00<`S3B<
<8`0:Goo00@nWG;eK_E^m@@Hm@E>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0F
Ool00`00Oomoo`0QOol01@00Oomoogoo00004goo000eOol00`00Oomoo`0JOol3000kOol013B<<8`d
S32<8Goo069>g4kmC]aBoDkL?YdjW7;fK]EbmFkEL_HDmATE5?E>oDkLC]e>g5;mC]aBoDkLD_e>g5;m
C]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo0P008goo00D007ooOomoo`0001=oo`00=Goo00<007oo
Ool05goo0`00?Woo0c2<00<dS7ooOol06goo0Tkl00MBoDkLC_a>g4kmC]a>g@02?Yd3K_D00g;eK_DH
m@036?D01dklC]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0C
Ool00`00Oomoo`0OOol3000017oo000000004Woo000eOol5000COol20011Ool013B<<6/dS32<6goo
015>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e^eG;eK]EbmVkE0080001FB[a6W4ZlAYaBoDkLD_e>g5;m
C_aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Ioo`03001oogoo03Moo`00BWoo0`0000=o
o`00Ool0?goo00E2_C2<=8``S3B<01Uoo`06D_e>g4klC_aBoDkL0Tkl00UBoDkLB]e:g4kMB]a:gFke
L_D00Vke00<Hm@00A[`00dZl00E6_5;lD_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo1Eoo`03001oogoo00Qoo`@002]oo`00B7oo0P00AGoo00DnW3B<<8`dS32<01Eoo`1`
C]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMB]abmVkEL_I^eATF5?D004JLB[a>g4kM
B]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dFOol00`00Oomoo`06Ool0
0`00Oomoo`02Ool00`00Oomoo`0XOol004Eoo`<004Moo`05=8``S32<<8`dS00@Ool024fcCM=2O49l
@W]2O4kLC]d2C]`03dklD_e>g5;lC_aBoDkLC_a>g5;mB]a:gD[LC]e:g002K_D017;e6?DHmASe1TkL
0U;l00EBoDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Ioo`03001oogoo00Eoo`03
001oogoo009oo`03001oogoo02Qoo`00@goo0P00BWoo00D`S3B<<6/dS32<00moo`1gCK=Addfb@Ya2
Nd:L@W]BoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_djW3jM?Y`nWFkEL_I^eATE5?DI5QCeC]e:
g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol0041oo`<004aoo`8`S004=8``S3B<=8`=Ool01Dfc
CM==de7CCK<00d9l00E2NdklC]a>oDkL009>o009D_e>g5;lC_a>oDkLC]e>g4km008nW@03K_EbmFke
009^m@@Hm@05D_e>g4klC]aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eB
o1Ioo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo02Qoo`00?Woo0P00Cgoo00H`JcB<<8`d
S31[=:d<Ool0NdfcDM==/U7CCK=AddZlC]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkL
?YdjW7;fK]EbmVkEL_I6W4ZlAYa:_4JLD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol003]o
o`@0051oo`04=8``S32<<8`2=8`8Ool4A[d2CM<02U7CCK==ddgC001:g4kLB]a>g4[L0Tkl00eBoDkL
C_a>o5;mC]a>o4kLC_e>g4kMC]abm@03K_D00g;e6?D00002B[`024JlB[a>g5;mC]a>o4kLD_d3D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Aoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo02Qoo`00>Goo0P0017oo00<007ooOol0C7oo00M2_C2<=8``JcB<<8`d[@05
Ool034kmC]a>oD[LA[e2_4JmCK9AddfcDM==/P<0001eB[a>gDZlC_e>g5;mC]aBoDkLD_e>g5;mC]aB
oD[LC]e:g4kMB]abmVkEL_I^eG;f5?E:_4JLB[a6W4ZlC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Eoo`03001oogoo00=oo`@002]oo`00=Woo0`00EGoo
00A2WC2<<8`dS08`S003=8aoodkL009>g006C]e>g4kMC]a>gDkL0TJm00EAddfcCM==de7C00@000=>
g00AC]e>g4klC_aBoDkLC_a>g5;mC]a>o4[LC]e:g4[MK_Ebm@03K_D00aTE6?E>g004C]`00e;lD_e>
g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D0
05;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol04Goo0P00
00=oo`00Ool0<Woo000cOol3001HOol0TCB<<6/dS32<AYa2NdJL@Ya6W4[LC_e>g4kMB]a>oDkLC_e:
g4Jm@[aAddfbDM==/e7C@W]2W49k@Ya>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]dn
W7;fK]EbmQSe6AHDmDkmC]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m01Eoo`03001oogoo035oo`00<Goo0P00Fgoo00X`S3B<<8ajd7K@AYa2W4JL
@Ya>g@=>g005C]e:g4kMB]a>g@02A[d00dgCDM==/`02CM<00d9l@W]2O002@W`03dkLC_a>g4kmC]aB
o4klD_e>g4klC]aBoDkLC]e>g002?Yd2K_D01W;eK_DHmASe6ADHm@E>g003D_aBoE;l009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0200000e;lD_eBo002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomoo`0`Ool0
02ioo`<005eoo`1c=8af/7[@MZmjd4:LAYa2NdJL@Ya>oDkLC_e>g4kmB]a>gD[LC]e2_57CCK=Addfc
DM==/dkMB[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;m?Y`nWFkEL_I^eG;fK]DI5QSe
6AHDmE;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d00`0001aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo1Ioo`03001oogoo02moo`00;7oo1000GWoo00Qfd7[@M]1jd7K@00U:g4kM0d[L00Y>gDkLC]a>
g4kMB]a>gD[LA[e=/`9=d`0>DM==ddgC001>g4[LC]a:g4kmC]a>o4kLC_e>g09>o009D_e>g4kMC]a>
oDkLC]e^mG;e00=^m@03L_E6_4Zl009:_008A[a>o4kLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00<00006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol0;goo000ZOol2001NOol07D:m?Ya2
_GJ`N]1f[g[@M[1jd00800U:_4kMB[a>gDkLC_e>g4kmC]a>oD:lA[e2_57CCK9AddfcDM<00P00059:
_4kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e:g4kMK]EbmVkEL_HHm@00AYa:_4JLB[a>
g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@<0000TD_eBo5;mD_aBoE;l
D_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
5Goo00<007ooOol0;Woo000ZOol2001KOol04DkMB]a>gDkL@[e2WG[@M]1jd7K@N]1fd00900P02D[L
C]d00T[L00E>g4kMC]a>gDkL00=6_@03CM=AddgC009=d`<00003C]a>gDkL009>g00>D_e>g4klC_aB
oDkLC_a>g5;mC]a:gD[LC]e:g09^m@06L_E^eASe6?E:_4Jl0dZl00E>g5;lD_aBoDkL009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;l000005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00EOol00`00Oomoo`0^Ool0
011oo`D000=oo`@000Aoo`@000Ioo`03001oo`0005Ioo`1cB[a:gDZlB]e:_4kMB]a>gD[L@[ef[g[@
M[1jd7J_N]00200900P02DkLC]e:g4kmC]a>oD[LC_e>g4Jm@[a6_DfcDM==/e7C@W]2W49k@Ya>g4km
C]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC]e:g7;fK]EbmQSe6AHHmDkMB]a>oDkLC]e>g5;m
C]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`0002YBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol0
0`00Oomoo`0]Ool0019oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomo
o`03Ool200000goo001oo`1COol2Ffh05TZlB]a:_4ZlC]a>gD[LC]e>g7[@M]1jd7K@N]1fd7[@@Ya6
W4:LAYa>g4kM0dkL00=>gD[LC]d00dJm0TgC00=AddgC@W`00T9l00A2NdkLC]a>g@9>g00?C_aBoDkL
D_a>o5;mC]a>o4kLD_e:g4[MB]a>gFkE009^m@046ADHmASe6?D5C]`3D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m
D_`30003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Eoo`03001oogoo02aoo`004Woo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`8000=oo`03001oogoo
055oo`1^GfiKCD[MB[a:gDZlB]e:g4[MB[a>gD[LN]1f[g[@M[1jd7J`AYa2W4JL@W]6W4kLC_e>g4km
C]a>gD[LC]e2_4JmCK=AddfcDM==/d:L@W]2W49kD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4km
>Y`nWFkEL_I^eG;fK]DI5QSe6AHHmE;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo0<0000aD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol0;7oo0007Ool60005Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0Cgoo0U]^019OKU]^C]a:g4kMB]a>g4[LB]e:g4[MM]1jd7K@N]1fd7[@00T2B]`01DkMB]a:
g4kLC]d00TkL00=:g4kMB]`00TJm00iAddgCCM==de7CCM=>g4[LC]a:g4klC]a>oDkL0Tkl00QBoDkL
C_a>o4kmC]a>gDkL0SjM0fke00E^eFkeB[a:_4Jl009:_005D_e>g4klC]aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo0<000=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo01Aoo`03001oogoo02]oo`00
4Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo04ioo`1YESEJESYK?U`jFdkMB]a>gD[LC]e:g4[MB[a>gGJ`N]1f/7[@M[002@08
C]e:_4kMB[a>oDkLC_e>g4km@[a6_D:lA[e=/e7CCK=AddfcDM<004kMB[a>gDZlC]e>g5;mC]aBoDkL
D_e>g5;mC]a>oDkLD_e>g7;fK]EbmVkEL_HHm@00AYa:_4JLB[a>g5;mC]aBoDkLD_e>g5;mC_aBoDkL
D_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l00<0000iD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03001oo`00
02aoo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`80
00Ioo`80045oo`09A[a:_4JlB[a6_4[MB]a:gD[L00=oo`03FfiJEUXe008nF`0??U`nFciKC]a>gD[L
C]e2WD:mM]1jd7K@N]1fd7[@00802@=:g007C]e:g4kMC]a>gDkLC]d00dJm0TgC00=AddgCDM<00P00
00A:g4kLB]a>g@9>g003C_aBoDkL009>o00:D_e>g4klB]a>gD[LB]e:g6keK]D3K_D02ASeB[a:_4Zl
A[a:_5;lD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_`000020003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00U;l00<005;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol0:Woo000@Ool30004Ool00`00Oomoo`02Ool01000
Oomoo`0017oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0?Goo025O/V?CA[a:_DJlB]e:
_4[MB[a>g@0bOol0<UYFFSEJEUHeB]e:_4[MB[a:gD[LC]e:g4kM?Yajd7J`N]1f/7[@M[000`09015:
g4kmC]a>gD[LC_e>g4kmB]a6_D:lA[e2_57CCK=Addfc00<0000iC]aBoDkLC_e>g5;mC]aBoDkLD_e>
g5;mC]aBoD[LC]e:g4kMK]EbmVkEL_I^eATF6?E>oDkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoE;lD_e>
o5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l00<00010D_aC7E;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0Y
Ool0019oo`03001oogoo00=oo`@000Aoo`@000Eoo`03001oogoo00Qoo`03001oogoo03]oo`9O/`0A
Gk9O/dJlB[a6_4ZlB]a:gD[LB]eJ=EYFFSEJEEXeFfiKK@02B[`04D[LB[a>gDkLC]e:g4kMM]1jd7K@
N]1fd7[@@Ya6W4:LAY`00dkL00I>gDkLC]e>g4kMC]`3A[d01DgCDM==de7C@W/00d9l0dkL01I>gDkL
D_a>o5;mC]aBo4kLD_e>g4klC]a>gD[LB]dnWFkeK]E^mASe6ADHm@A>g09Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`30003D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003
001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Ioo`03001o
ogoo02Qoo`00:7oo00<007ooOol02Woo00<007ooOol0>Woo06eSdenbHk=O/V?CB[a>gDZlC]e2_4Jm
@[aJEUXeFUIF=EYFFdeKKTZlB]e:_4[MB[a>gD[LB]e:_4kMM[1jd7J`N]1f/7[@@W]6W4:LAYa:g4km
C]a>gD[LC]e:g4kM@[a6_DfcDM==/e7CCM=2W49k@Ya2Nd:LC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4km
C]aBoDkL?YdjW7;fK]EbmVkEL_HHmATFB]a>oDkLC]e:g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@020000Ae;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<007ooOol0:7oo
000XOol3000;Ool00`00Oomoo`0hOol02encGWINUcHK=S/f6cHkB]a:gD[LB]d00dJm01=JEEXeFUIK
KE]^FfeKKT[LC]a:g4kMB]a:gD[LB]e:g7[@M]1jd003M]001DJL@Ya6W4:LAY`00dkL011>gD[LC]e:
g4kMA[eAddgCDM==de7CCM=>g4[LC]a:g09>g00=C_a>g4kmC]aBo4klD_e>g4klC]a>oDkLC]d00SjM
00e^eFkeK_E^mFkE6ADHmATEC]a>o4kLD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
009Bo0<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol09goo000XOol00`00
Oomoo`0<Ool00`00Oomoo`0_Ool0FDZlB]e6_4[MB[`9^`FJ2K]NMV:GGWHf>cHJ=S/f6TkMB[a>gDZl
C]e2_4JmESEJEUXeFUIF=Cil>U/nG4[LC]e:g4kMB[a>gD[LB]e:_7[AM[1jd7J`N]402DkMB[a>gDZl
C]e>g4kmC]a>oDkLC]e:g4Jm@[aAddfcDM==/e7C001>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkL
D_e>g4kmC]aBoFkEL_I^eG;fK]D00P0001E:_4JLB[a>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;m
D_aBoE;lD_d00`0004iBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomo
o`0VOol002Qoo`03001oogoo00eoo`03001oogoo02Yoo`03DM==dcil008nO00JB]a:gDZlB]d9V`Vk
GWINUejFHYMNMSHk=Q/f>cHKB]e:g4[MB]a:gDJmFUIJ=E]^FSEJEP<nF`09?Ua:g4kLB]a>gD:M@[e2
WG[@00=fd005N]1fd00900U>g@03B]`01TkMC]a>gDkLC]e>g0=6_@04CM=AddgCDM<300001TkLB]a>
g4[LD_e>g09>o00;D_e>g4klC_aBoDkLB]e:g4kMB]a:g@02K_D01FkEK_DHmATEA[`00dZl00E>g5;l
D_aBoDkL009Bo005D_eBo5;lD_aBo@02D_`30002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo003D_eBo5;l01Eoo`03001oogoo02Ioo`00:7oo0P003goo00<007ooOol0:7oo035Ae4gCDM@n
Fcil?U]2O3iKB]e6_4[MGWIRUeifHYMNMV:GGk9:gDJlB[e6_4kMB[a:gDZl0392_5YFESEJEUXeFUHj
Fcil>U/nG4[LC]e:g4kM?Ya2_GJ`N]1f/7[AM[1jd00300T044kMB]a>oDkLC]e:g4kmC]a>oD:lA[e2
_57CCK=AddgC100002M>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMB]abmVkEL_I^eAdF
6?DI5T[LC_e>g4kMC]aBoDkLD_e>g5;mC_aBoDkLD_d00`0005EBoE;lD_eBo5;mD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0UOol002Qoo`03001oogoo00mo
o`03001oogoo02Ioo`08DM==de7CCM=AddZlB[e6_09:_00IA[e6_4JmGYIRUeifGYMO/UncGk9:_4Jl
B[a6_4[MB]a:gD[LFUEJ=EYFFSEJEE]=Ffd00dZl0T[L00A>gDkLC]e:g09fd009N]1fd7K@M]16W4:L
AYa2W4kM00=>g005C]e>g4kMC]a>g@02A[d01dgCDM==de7CCM=2O49k0092O00BC]e>g4kLC]aBoDkL
D_a>o5;mC]a>o4kLD_e:g4[MB]a>gD[L0fke00@HmATE6?DI5@=>g005D_e>g5;lD_aBo@02D_`30002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;l
D_aBo5;m0002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`E
Ool00`00Oomoo`0TOol002Qoo`03001oogoo011oo`03001oogoo00moo`03K]@03goo019oo`1[DMA=
de7DCM=Ae4gCE`Q6_4[MA[a:gDJlA[e2_6:GGWIRUeifGk=O/UncGk9>gDZlC]e:_4Jm@[a6_EHeFUIJ
=EYFESEKKU]=B]e:_4[MB[a:gDZlC]e:g4[MB[ajdGJ`N]1f/7[A00U6W49kAYa>g4kMB]a>oDkLC]e:
g4kMB]a6_D:lDM==de7CCK=Ae49k@Ya2Nd:L@W]BoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoCZL?Ydn
W7;fK]EbmVkE6AHHmAdF6?E>gD[LC_e>g5;mC]aBo@030000GE;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0COol2000VOol002Moo`03
001oogoo019oo`03001oogoo00ioo`03L]A^e7oo00]oo`0=A[e6_4JlA[a6_D:M@[e=de7CCM=AddgC
E`P00UKX00A:_4ZmA[a:_096_@0=A[aNUejFHYMNMSHk=Q/f>cHKB]e:g4[MB]`00dJm011J=EYEFSEK
KE]=FfeKCDkMB]a>g4[LC]e:g4[MB]a:g@=fd009N]1fd009@Ya6W4:LAYa>g4kM00=>g00MC]e:g4kM
B]a6_DgCDM==de7CCM=Add[LC]a:g4kLB]a>oDkLC_a>g5;mC]aBo4klC_e>g4kMC]a>o@02?Yd2K_D0
2VkEK_E^mATE6?DI5ASeD_e>g4kl0`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Aoo`03001oogoo02=oo`009goo
0`004goo00<007ooOol037oo00Abe6kDL]D03PYoo`1]Im=S/TZmA[a:_DJl@[dnW57DCM=Ae4gCDMAB
ieL8D^MG24ZlB]e6_4[M1IY6_EifHYMNMV:GGWHj>cHJ=S]:_4kMB[a>gDZlA[e2_5YFESEJEUXeFUHj
Fcil>U]>gD[LC]e:g4[MB[a>gD[LB]ef/7[AM[1jd00900Y:_4kMB[a>gDkLC_e>g4kmC]a>gD[LC]e2
_57CCK=AddgCDM==/`00B[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4kmK]EbmVkEL_I^
eG;fAYa:_4JLB[`00`0006ABoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo1Eoo`03001oogoo029oo`009goo00<0
07ooOol057oo00<007ooOol02goo00A^e7;DK]@03PUoo`05Ik9S/V>bHk9W/P03A[`01d:m@YeAddgC
DM==de7C00@nO004B]a:gDZlB]d22I/055ifGYMNUV:G=Q/f>cHK=S]:g4[MB]a:gD[LA[eJ=EYFFdeJ
EEXe?U`3?U/01TkMB]a>g4[L@[e2W@9fd004N]1fd7K@M]0300T00d[LC]e:g002B]`014kMC]a>gDkL
0dJm00E=de7CCM=AddgC00800008C]a:g4kLB]a>g4klD_e>g09>o00:D_e>g4klC_a>gD[LB]e:g4kM
K]D3K_D00aSe001:_002000014ZlC]aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00D005;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04goo00<007oo
Ool08Woo000EOol40004Ool40006Ool00`00Oomoo`0EOol00`00Oomoo`0:Ool01G;EK]Abe00>00l0
27oo03aJEUif=S/jG3Hk>S]6_4[M@Ya2_DgCDMA=de7DCM=Ae3iK?W`nFd[MB[a:gDJlB]eNMV:GGWIR
UeifHYM6_4[MA[a:_DZlC]e:_4[M0356_EXeFUIF=EYFFSDnG3YK?W`jFdkMB]a>gD[L@[ef/7[AM[1j
d7J`N]4300T04@0:C]a>gD[LC_e>g4kmB]a>oDkLA[e2_57CCM=AddfcDM@00`0001IBoDkLC_e>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMB]abmVkEL_I^e@<0001ZAYa:_4JLB[a>g5;mC]aBoDkLD_e>
g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_dEOol00`00Oomoo`0QOol001Aoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`03Ool00`00Oomoo`0FOol20009Ool02W;DK]Abe6kD00l03TJmA[a6_DJl0goo00AJEUifFWIN
MP<f>`06B]e6_4Zm@[eAddgC0e7C00==de7C?W`00Sil0dJm00I6_5jGGYIRUeifGYL2Gk8044JlB[a6
_4[MB]a:gD[LB]eJ=EYEFSEJEUXeFUE:_4[L0dZl00E>gD[LC]e>g7[@00=fd009N]1fd4JL@Ya6W4:L
AYa>g4kM00=>g004C]e>g4kMC]`2A[d0157CCM=AddgC0d9l00A2NdkLC]a>g@9>g00=C_aBoDkLD_a>
o5;mC]a>o4[LC]e:g4[MB]`00`000QTE00<HmDkLC]`00dkL00=Bo5;mC]`00U;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoGooOol04goo00<007ooOol087oo000IOol01000Oomoo`0017oo00<007ooOol00goo0P006Goo
00<007ooOol01Woo075^e7;DK]AbeFkD00l03T[MA[a:_@2f0=MJEUifFUINMUYF>S/f>cYL=S]:gDJl
@[e=de7DCM=Ae4gCDMA=deL8A[a:gDJlA]e6_4Jm@[aRUeifHYMKTUncFk9O/TJlB]e6_4Jm@[a6_D:l
FUIF=EYFFSEJEUM<Ffe:_4[MB[a:gDZlB]e:_4kMB]ajd7J`N]5f/7[AM[16W4:LAYa2NdkmC]a>gD[L
C_e:g4kMB]a>gD:lA[e=/e7DCM=Addfc@Ya2Nd:LC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[L
00<0001bK]EbmVkE7AHHmAdF6?E>oDkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo00<0
07ooOol087oo000<Ool60007Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol06Goo00=V
]Q4FOol01Goo01A^e7;DK]Abe6kDL]@03P0?00i6_DJlA[eJEUifFWINMUYFGWIJMTJm0dJl00I2_D:M
DM==de7CCM<2DM<01UKXD^M:_4ZlB[e6_0=6_@0;GWINUejFHYMNMSHk=Q/f>d[LB]e:g004A[d04EYF
FSEJEEXeFfeGCE]=B]a>gD[LC]a:g4[MB]a:gD[LN]000gK@00Ijd009AYa2W4JL@Y`2C]`03TkMC]a>
g4[LC]e:g4kMA[eAddgCDM==de7CCM<3@W`02dkLC_a>g4kmC]aBo4klD_e>g5;lC]`00`000SjM00E^
eFkeK_E^mFkE00<I5@086?E>o4kLD_e>g4klD_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003
001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1Eoo`03001o
ogoo01moo`005Goo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol06Goo00=ZefJf
5AL01Goo06abe6kDL]E^e7;DK]A2WD9l@Y`nO4Jm@Ya6_EYFGWIJEUifFUIWdV>bB[e6_4Zm@Ya2_DgC
DMA=de7DCM=Ae5;WE^QBid[MB[a:gDJl2K]6_4JmGWIRUeifHYLf6SXk=QY>gDZlC]e:_4kM@[a6_EXe
FUIF=EYFFSDnG3YK?Wa:g4kMB]a>gD[LB]e:_4kMM[1jd7J`N]5f/00:00U>gDZlC]e:_4kmC]a>oDkL
C]e:g4kMB]a6_DgCDM==/e7DCM=Ad`00C]e:_4kMC]aBoDkLD_e>g5;mC]`30000NDkLC_e>g5;mC]ab
mVkEL_I^eG;fAYa:_4JLB[a6W5;mC]aBoDkLD_e>o5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
o@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001o
ogoo01moo`005Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo0P006Goo0f[F0Q4F
0TJm00U6_4JmA[ebe6kDL]A^e7;DK]@00d:L0d:m00ANMUYFGWIJMPAS/P03A[e6_4Jl0092_@05CM=A
de7CDM==d`04?W`06d[MB]a:gDZl2I/5Vf:GGWINUejFHYLf6cHk=Q]:gD[LB]e:g4[MA[eJEEXeFfeJ
=EYE?U/nG002?U/02T[LC]e:g4kLB]a:gD[LB]efd7[@0WK@00<02@0:00T00T[L00I>gDkLC]a>g4kM
C]`4A[d01E7CCM=AddgCDM<00P0000=:g4kLB]`00TkL0Tkl0`0000m>o5;mC]a>o4[LC]e:g4[MB]a^
mFkEK_E^eAdEA[`00dZl00E>g4klC]aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00
Oomoo`0NOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00mo
o`03K]H0Dgoo00Eoo`0DJ]MV]V[GI[HA5a3f5AM6_4Jm@[a6_FkDL]A^e7;EK]Abe3il@Ye2O092W01D
A[e2W5ifFUINMUYFGWHf>cYL=S]:gDJl@[e2W57DCM=Ae4gCDMA=dd9l?U/nO4JlB]e:_4[MA[aRUeif
HYMNMV:GGWI:_DJlB]e6_4[MB[a>gDZl0392_5YFFSEJEUHeFUHjFciL>U/nO4[LC]e:g4kM?YajdGJ`
N]5f/7[AM[002P0900Y:_4kMB[a>gD[LC_e>g4kmB]a6_D:lA[e=/e7DCM=Addfc0`0000=>g5;mC]`0
0`00085>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC]e^eG;fK]EbmQSeB[a6W4ZlAYa:_4kLD_e>g5;mC]aB
oDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol07Goo000EOol50003Ool40005Ool00`00
Oomoo`0?Ool00f[EJ]H0L`05Ool2J]H016JfJ]IZeQ4G0a4F00E6_DJlA[djOG;D00=^e00=00m6_4Jm
A[a6_@3F@[eJMUifFUINMUYf>S/00SHk00A6_4[MA[a2_@9Ad`05CM=Ade7CDM==d`03?W`4A[d05Eif
GYMNUV:GGWIO/U^bB[a6_4ZlA[a:gD[LB]e:g5YFFSEJEEXeFUIJ=@02B[`02D[LB[a:_4kLC]e:g4:m
M]1jd003M]001G[@00T02@0900X00dkL00I>gDkLC]e>g4kMC]`3A[d01DgCDM==de7C@W/00T9l0`00
011>g4kMC]aBo4klD_e>g4kmC]aBoDkLB]e:g4kMB]a:g@9^m@03K]DI5ATE00I>g09Bo005D_e>g5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoE;lD_`04goo0P007goo000VOol00`00Oomoo`0>Ool01FZeK]IZ]@Ac05<0
0goo06aV]V[GI[IZefJfJ]M2W4:M@Ya6_D:L>YdfO7;EK]Abe6kDL]D03P0?A[a:gDJlB[d0]P3GFUIN
MUYFGWIJESXk=S/jG4JlB]dnW57DCM=Ae4gCDOA=de7DD/M:gDJlB]e2_4KMA[a6_EifHYMNMUnbFi5O
/U^BB[e6_4[MA[a6_D:lA]eJ=EYFESEJEUXeFdeGC4[MB[a:gDZlB]e:g4kMB]ajdGJ`N]5f/7[AM[1j
dD9kAYa2W4JLB]a>oDkLC]e:g4kMB]a>gD:lA[e2_57CCK=Ae4gC@Y`20000R49kC_e>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLD_e>g4kMB]a>gD[LL_I^eFkf6?DM5QSeC]e:g4kmC]a>gDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;m57oo00<007ooOol077oo000UOol00`00Ool0000?Ool00f[FJ]EZeP03
07<014Jm@[e6_FJf0f[F00=V]Q4G@Y`00d:L00<jOCZMK]@00VkD015be6kD00l03P0?A[a6_DJlA[eJ
EUifFWINMUYFGWI6_4Jm0096_092_@06CM=Ade7CDM==de7C0U;W00E6_4ZlB[a:_DJl0096_@06HYMN
MUjGGYIRUcHK0SHk00A:gD[LB]e:g0=6_@04FSEJEUXeFUD2Edd02EM<C]a:g4kMB]a>g4[LB]e:g002
M]001W[@M]1fd7K@AYa2W0=6W0=>g005C]e>g4kMB]a>g@02A[d00dgCDM<0000200004T9l@W]2O49l
C_e>g4klC]a>oDkLD_a>o5;mC]a>gDkLC_e>g08nW@06K_E^eFkeK]E^mASe0QTE00EBoDkLC_a>g5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l57oo00<007ooOol01goo1@003goo000UOol2
000?Ool07VkFJ[E^eVZeK]H0D`Ac@Ya6_D:LA[eV]V[G;UeZefJf5AM2W4:M@Ya6_FkDL]A^e7;EK]Ab
e3il@Ye2O092W00EA[e2W5ifFUINMUYFGWIO/F>bA[a:_DJlB[e2W57DCM=Am4gCDMA=deKX009Bi`0h
A[a:gDZlB]e6_4KMA[aRUeifHYMNMSHk=QXj>dZlC]e:_4kMB[a6_D:lFUIJ=EYFESEJESYK?U`jFdkM
B]a>gD[LC]e:g4[MB[ajdGJ`N]5f/7[A00U>gDZlC]e:_4kMC]a>oDkLC_e>g4kMB]a6_@<0002>DM==
de7D001>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]abmVkEK_I^eG;fK]E:_4JLB[a6
W5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`07Ool01@00
Oomoogoo00003goo000UOol00`00Oomoo`0>Ool01F[EJ]IZeF[FJ]D00`1c00E2_4Jm@[e6_BiM00=Z
eP084AHA5dJmA[e6_4JmK]Abe0=^e003L]A2W4:L0092W0=2_@03GWIJEUif00AS/P07A[a6_DJlA[a2
_E7CCM<00U7C00=BidgC?W`00Sil01U:_4[MB]a:g@FJ1I]NUV:GGWINUejF=S/f6cHkB]a:gD[LB]e:
g4JmFSEJEEM=FUIJ=@02?U/02SiLB]a>g4[LC]e:g4[MB]a:gD[L0WK@00EfdGK@00X02DkM00=:g005
C]e>g4kMC]a>g@0300001DJmCM=AddgCDM<00P0000M:g4kLB]a>g4[LD_e>g002C_`03U;mC]a>o4kl
D_e:g4[MB]a>gD[LK_E^eFkeK]D26AD01TZlA[a:_4ZlD_e>g09Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mD_aoo`0COol00`00Oomoo`07Ool00`00Oomoo`0@Ool002Eoo`03001oogoo00eo
o`0QJ[E^eVZeK]IZ]FkF05=2WCjL@Yd^G39m;UeZefJfJ]MV]QDG4?HE5dJlA[e2_7;EK]@jWFkDL]E^
e00??Wa2WD9l0092W017A[eJEUifFUINMUYF>S/f>cYLA[a:gDJl@[e=de7DCM=Am4gCDM@nFd9l?U/n
O4JlB]e:_4[MGWIRUeifHYMNMV:GA[a:_DJlB]e:_4[MB[a>g@0aA[eF=EYFFSEJEUHe?W`jFciLB]a>
gD[LC]e:g4:mM[1jdGJ`N]5f/7[A00T02P0900Y:g4kmC]a>g@03000024km@[a6_D:lDM==/e7DCM<3
0000RdkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>gFkEL_I^eFkf6?DM5QSeC]e:g4km
C]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001oogoo00Moo`03
001oogoo00moo`009Goo0P002goo00YJaT:m@Ya2_F[EJ]IZeC9mJ]EZePA2W08^G@9ZeP06I[IZeV[F
4ALA5Q4G0TJm00A6_3ZMK]Abe09^e0803`04A[a6_DJlA[d2@[d01UYfGWIJEUif=S/j>`8f>`03A[a:
gDJl00=Ad`05CM=Ade7CDMA6_002B[`06TZmA[e6_DJmHYMNMUjGGYIRUe^AFk96_4ZlA[a:_4JlB]e:
g4[MFSEJEUXeFUEJ=EM=Ed`2B[`2B]`014kMC]a>gD[L0WK@00IfdGK@M]1fd4JL@Y`3AY`300001TkM
C]a>gDkLC]e2_@96_@09DM==de7CDM=2O49k@Wa>g4kM00=>g00AD_e>g5;lC_aBoDkLC_e>g4kMB]a:
gD[LC]e^eFkeK]DM5P036AD3C]`00e;lD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoGooOol04Woo00<007ooOol027oo00<007ooOol03Woo000UOol00`00Oomoo`09Ool0J5K5F^I2
W4Jm@Ya^eVZe<WeZ]FkFJ[D4Lcil@YdnW4:MI[IZefJfJ]MV]V[G@Ya2WD:LA[dfOCZM=WabeFkDL]E^
e7;E00h03dJlB]e6_03F0;INMUYFGWIJEUif=S/j>cHk>Ua6_4[M?YaAm4gCDMA=de7dCM<004JlB]e6
_4[M@[a6gDJlHYMNMV:GFi5O/U^AGk9:_4kMB[a>gDZlA[e2_5YFFSEJEUHeFUIGC5M=B[a:gDZlB]e:
_4kMB]a:gDZlN]5f/7[AM[1jdGJ`AY`30000WDkMB]a>oDkLC]e:g4kMB]a6_D:lA[e=de7CCM=Ae49k
@Ya2NdJLC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]`nWCZL?Ye^eFkfK]EbmQSe7AHHmAdFC]a>gD[L
C_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Aoo`03001oogoo00Qoo`03
001oogoo00eoo`009Goo00<007ooOol02Goo00=JiU[6F/H00T:m00e2W39m<WeZeV[EJ]H0L`Ac@[a6
_D:mA[eV]P03J]H00a4F0012W003@Y`00cYmL]A^e002K]@00g;DK]@03`0200l02DJlA[e6_5ifFUIN
MUYfGWIJEP02A[`00dJmA[a6_002@[d01DgCDM=Ade7DCM<00P0000E:_DJlB[a:_4Zm0096_@03GYIR
Ueif009NUP07=S/f6cHkB]a:gD[LB]d00dJm00=JEEXeFUH00eM<00UGCD[LC]a:g4kMB]a:gD[LB]d0
0gK@00Ifd@00000004JL@Y`2AY`04TkMC]a>g4kLC]e:g4kMB]a6_DgCDM==de7CCM=Add[LC]a:g09>
g00<C_e>g4klC_aBoDkLD_a>o4kmC]a>gDkL0SjM00M^mFkEK_E^eFke6ADM5P026AD01TkLD_e>g4kl
D_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`03Ool01@00Oomoogoo
00003goo000TOol02000Oomoogoo@[dnW4:MMV`4Ool09WZ=AG4nO3YK?W`bGC9m<Ua^eVZeK]IZ]FkF
05<4Ld:LA[e2W6[GI[HbOFJfJ]L@mQDG@Ya2WD:LA[e^e7;EK]AbeFkDL]E2O4:M@W`2@Y`04dJmFUIN
MUYFGWIJEV>bGi5:_DJlB[e6_4:m@YaAe4gCDOA=de7D00<0000UB]e6_4[MB[a:gD:lA]eNMV:GGWIR
UcHJ=S/f6TkMB[a>gDZlC]e2_4JmESEJEUXeFUIF=Cil>U/nG4[LC]e:g4kMB[a>gD[LB]d00`000:Aj
dGJ`00Y:_4kMB[a>gDZlC_e>g4kmC]a>gD[LC]e2_57CCM=Ae4gCDM==d`00B[a>gDZlD_e>g5;mC]aB
oDkLD_e>g5;mC]a>oDkLD_e>g6kfK]EbmVkEK_I^eDZlAYa:_4JLB[a>g5;mC]aBoDklD_e>g5;mC_aB
oDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l57oo00<007ooOol017oo0`0047oo000TOol300001EoF
GmE2WD:LNXd00Woo00QfS7Z=F/I9LCYl?W`jG3Yl0S9m00EZeF[FJ]EZeV[E0080L`0;17=2_4Jm@[d^
GFJfJ]IVeQDG4AHA5`02A[d014JlA[e^e7;D0fkD00@03d:L@Ya2W0=2_@0?FWINMUYFHk9S/F>bHk5S
/TJlA[e6_4:mDM=Ae4gC009Ad`0:DM@nNcil?Wa:gDZlB]e:g0FK1IX2GYH00ejGGWINUP02=S/033HK
B]e:g4[MB]a:gDJmFUIJ=EM<FSEJEP<nF`06C]e:g4kLB]a>gCjM0P0000EfdGJ`M]1fd7KA00802P03
B]a>gD[L009:g00:C]e>g4kMC]a6_D:mA[e=de7CCM<2DM<2000014kLB]a>g4[L0Tkl00IBoDkLC_a>
o5;mC]`2C_`02TkMB]a:gD[LK_E^eFkeK]DM5QTE0dZl00E6_4ZlD_aBoDkL009Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l4Goo0P0000=oo`00Ool05goo000TOol0JP00Oomoogoo
9KXQVD:mMVajSGI/NXefK4UaAE59LSYL?W`jFcilJ[E^eVZeK]IZ]FkF05=2WCjL@Yd^G39mI[IZefJf
J]MV]QDG4?HE5dJlA[e2_7;EK]AbeFkDL]D03P0?@Wa2WD9lA[e2W5ifFUINMUYFGWHf>cXk=S/jG4Jl
B]dnW4:mCM=Ae4gCDOA=dcil?U]2O3iK?Wa6_4[MB[aRUeifHYMNMV:GFi5K/TJlB[e6_4kMB[a:gDZl
0352_5YFESEJEUXeFUHjFcil>U]>gD[L0`0001XnW7[AM[1jdGJ`N]5f/00:00T02TkLC]e:g4kmC]a>
oD[LC_e>g4Jm@[aAe4gCDM==de7D0`0008iBoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kM
K]E^mVkEL_HHmAdF6?E>oDkLC]e:g4kmC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo1Aoo`03001oogoo01Eoo`006Woo10001Woo00L007ooOomoob6i9KXQ^@02MX`01gZ=
MVafS4EaBG55LEK60092_@08@Ya2_F[EJ]IZeF[FJ]D4L`=2W08^G@09J]IVeV[FI[IZeQ4F5ALA5Q4G
0096_@04A[a^e6kDL]@2K]@200l00dJlA[e6_002@[d035if0;INMUYFGWHf>cXk=S]:_DJlB]e2W@9A
d`06DMA=de7CDM=:_DJl0TZl01M:_DJmA[e6_EjGGWINUU^AFk9KTDZlA[a:_4JlB[a:g4[MB]aJEEXe
FUIJ=EYE009GC009B[`00000001:g4kMC]a>gGJ`009fd003M]5f/7K@0096W004@Ya6W4kLC]d3C]`0
1TkMC]a>gDkLA[e2_@=Ad`05CM=2O49l@Wa2N`02C]`05TkMC]a>g4klD_e>g5;lC]aBoDkLC_e>g4kM
B]a:gFkEK_E^eAdE6ADM5QTE14kL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo004D_eBo5;lD_`COol00`00Oomoo`0EOol001Uoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`0N8ITU^WI/NXefK7Z=MVa9LTEaF^IFaE[V@Ya6_D:LK]IZ]FkFJ[E^eP1c17@nO4:M
?YaZefJfJ]MV]V[G0P0003m2W4:M@Ya6_CIm>Ye^e7;EK]AbeFkD00l03TZmA[a:gDJl0=H0]EifFUIN
MUYFGWHf>cXk=S]2_D:L@[e=de7dCM=Ae4gCDO@004[MA[a:gDJlA[e2_4KMGWIRUeifFk9KTE^bFi5>
gDZlC]e:_4kM@[a6_EHeFUIJ=EYFESD00`000;9:_4[MB[a:gDZlC]e:g4[MM[1jdGJ`N]5f/7[A@Ya6
W49kAYa>g4kMB]a>oD[LC]e:g4kM@[a6_DgCDMA=de7D@W]6W49k@Ya2Ne;mC]aBoDkLD_e>g5;mC]aB
oDkLC_e>g5;mC]`nWCZLL_I^eFkfK]DM5QSe7AI:g4kmC]a>gD[LD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03001oogoo01Aoo`006Goo00<007ooOol00Woo00<0
07ooOol00goo0P000goo00@Q^R6iNXefK09fS007BG55LDUaE/IJaUK5E/H00T:m00E2W6[FJ]EZeV[E
00<4L`0:@[a6_D:mJ]IV]V[FI]IZeQ4F0003@Y`00cZMK]Abe003K]@04W;D00h03`0?A[e6_4JmA[aN
MUYFGWIJMUifGk5S/DJlA[e6_092_@05DMA=de7CDM=Ae00200000dZlB[e6_002B[`3A[d015jFFk9N
MUjF0SHk00Df6d[MB]a:gD[L00=6_@04FSD000000003Ed`03dkMB]a>g4[LC]e:g4[MB]afdGJ`M]5f
d7KAM[002P02AY`014:LAYa>g4kM0TkL00M:g4kMB]a>gDJmDM==d`03DM<02D[LC]a:g4kLB]a>o4kL
C_e>g002C_`05U;mC]a>o4kLC_e>g4kM?Ye^mFkEK_E^eFke6ADM5ATE7AI>g4klC]aBoDkL0U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`057oo00<007ooOol04goo000I
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0@T:mMVajSGI/NXe5LDUaAE5JiTEa
?W`jFcil<UdbOFZeK]IZ]FkFJ[D4M01c17A2W4Jm@YaZefJfJ]MV]V[G4?HE5d:L@Ye2W7;EK]AbeFkD
L]E^e7;E@Wa2WD9lA[e2W4JmFUINMUYFGWIJEV>bGi5:_DJlB[e6_4:mCM=Ae4gCDOA=d`<0000CB[a:
gDJlB]e:_0FK1IYRUeifHYMNMSXk=QXf>cHJC]e:_4kMB[`00`000;UF=EYFFSEJESYK?W`jFdkMB]a>
gD[LC]e:_4kMB]ajdGJ`N]5f/7[A00T02TZlC]e:_4kMC]a>oDkLC_e:g4kMB]a6_DgCDM==de7DCM<0
04ZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoFkEK_I^eG;fK]DM5TJLB[a6W4ZlC]aB
oDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Aoo`03001o
ogoo01=oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo0WJ<019jSGI/BG55
LDUaAG59LCYl?W`jG3YlJ]EZeV[EJ]IZeF[F07<317<02T:lA[e2_BiMI[IZeVJf5ALA5Q4G0TJm00A6
_6kDK]Abe0=^e0A2W0=2_@0?FWINMUYFHk5O/F>aGk5:_DJlB]e2WD:mDM=Ae4gC009Ad`0:?W`nNcil
B]a:gDZlB]e:g5jGGWH2GYH01UjGGWI:_4JlB[a6_0<00005B]a6_EXeFUIGC002FSD043iL?U/nFciK
C]e:g4kMC]a>gCjMM]5fd7KAM[1fdGK@0P0:0T[L00M>gD[LB]a>g4kMC]a>g@02A[d01D:mDM=Ade7C
CM<00`0000=:g4kLB]`00TkL0Tkl019BoDkLC_a>o5;mC]a:gD[LC]e:g4[MK]E^mFkEK_DM5DZlA[`3
B[`01DkLD_aBo5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009
D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;l
Ool04goo00<007ooOol04Woo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
DGI/NXefK5[VAE59LUK5BG95LDUb@Ya6_D:LA[eZ]FkFJ[E^eVZeK]HnO4:M?Ya2WBiL<WeV]V[GI[IZ
efJf5AL@mTJmA[a6_FkDL]E^e7;EK[Abe@0>@Ya2O4:M@Wa6_D:LGWIJEV>bFUINMSHk>S/f>d[MA[a:
gCjLDOA=de7DCM=Am3iK?W`nFd9l?U]6_D:lA]eNMV:GGWIRUeifFk5GT@0300006TJlC]e:_4[MB[a6
gEXeFUIF=EYFFSE:gDZlB]e:_4kMB]a>gD[L@[ef/7[AM[1jdGJ`N]4200X0Y@09C_e>g4kMB]a>oDkL
C_e:g4km@[a6_DgCDMA=de7D@W]6W49k@Ya>g5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gD[L
L_I^eFkfK]DM5QTEC]e:g4kmC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0AOol001Uoo`03001oogoo009oo`03001oogoo009o
o`8000Ioo`0;NXefK7J<AG59LDEaE/I5LDUaAG5Fa@02@[d024:L@[eZeF[FJ]EZeV[E17<4@Y`02FJf
J]IV]V[FI[IZeQ4F5ALA5P03A[d01CImK]A^e7;DK]@00P0?00A6_DJlA[e6_092_@04GWIJMUifFUH2
=S/01SXk=S]:_DJl@[e=d`9Ad`06DMA=de7CB[a:_DJl0TZl0dJm00=NUUjGGWH00`0000E6_4ZlA[a:
_4Jl00=6_@=J=@05FUIJ=E=<Dba:g002B[`034kLC]e:g4kMC]afdGJ`M]5fd7KAM[002P96W004@Ya>
g4kLC]d2C]`00d[LC]e:g003A[d01DgCDM=Ade7C@W/00d9l0dkL019>gDkLD_a>o5;mC]a>oDkLD_e>
g4[MB]a>gD[LK_E^eFke6AD27AD5C]`3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo019oo`03001oogoo015oo`006Woo10001Goo00<007ooOol01Goo04af
K7Z=MVa9LTEaBG5FaDUbAG5FaUK5F/IFaDJm@Ya6_C9MK]IZ]FkF07<4M4:LA[e2W4JmI[IZefJfJ]LA
5P00@Ya6WD:L>YdfOG;EK[AbeFkDL]D03P0?00i:_DJlB]e6_5ifFUINMUYFGWIJETZmA[a:_DJl@[e2
W57DCM<004gCDOA=d`00A[a:gDJlB]e6_4Jm@[aRU`800038GWIRUcHJ=S]:_4kMB[a>gDZlA]e2_4Jm
ESEJEUXeFUIC:eM<Db]:gDZlB]e:g4[MB[a>gD[LN]5f/7[AM[1jd@0:AYa2W4JL@W]>oDkLC_e>g4km
B]a>gD[LA[e2_57CCM=Am4gC@Ya2NdJL@W]2W4kLD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL?YdjWFkf
K]EbmVkEK_HHmAdF6AEBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoA9oo`<0019oo`001Goo0P0000=oo`0000006Goo00<007ooOol01Goo0WJ<
00IjSDEaBG55LDUaAG42BG402Sil>U`jO3Yl<WdbGF[FJ]EZeV[E0`Ac00U2_4Jm@[eZeVJfJ]IV]V[F
4AH01D:L00=^e7;DK]@00VkD100?0d:m00MJMUifFUINMUYfGk5OT@02A[`01TJm@Ye2_E7CDMA=d`9A
d`@00003B]e:_4[M00<0009NUP03GYMNMSHk008f>`05B]a:gD[LB]e:g002A[d01EYFFSEJ=EXeFUH0
0ciK00a>gD[LC]a:g4[MB]a:gGK@M]5f/7KAM]0200X2B]`02TkMB]a>g4kLC]e>g4kMB]a>gD:m0e7C
00M=de7CDM=>g4[LC]a:g002C]`014klC]a>oDkL0Tkl00EBoDkLC]e>g4km008nW@07K]E^mFkEK_E^
eDZlA[`00TZl00EBoDkLC_a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00=BoGooOol04Goo00<007ooOol047oo0004Ool00`00Oomoo`02000JOol00`00Oomo
o`05Ool0AWI/NXe5LDUaAE5JiTEaBG95LDVBAG4nO3YK?W`bGC9mJ[E^eVZeK]IZ]@Ad07<4M4:LA[e2
W6[G;UaZefJf5ALA5TJmA[a6_D:lA[e^e7;EK[AbeFkD@Ya2O4:M@Wa6_D:LA[eJEUifFUINMUnAHk5O
TDZmA[a:_CjL@[e=de7dCM=Am4gC?W`nFd9l0`0002E:g@FJ1I]NMV:GGWIRUeif>S/f6SHkB[a>gDZl
B]e:_4KMFSEJEUHeFUIJ=CiL>U/nO4[LC]e:g4kMB]a:gDZlC]ef/7[AM[1jd@0300X0YdkMB[a>gDkL
C_e>g4kmC]a6_D:lA[e2_57DCM=Ae4gCDO@004kMB[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
C_e^eG;fK]E^mVkE7AH004ZlAYa:_4kLD_e>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;l
D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04goo00<007ooOol03goo0004Ool01@00Oomoogoo0000
6Goo0`001Woo00YjSGI/BG55LDUaE/E9LDEaBG55L@99L@09?W`jG3YlJ]EZeV[EJ]IZeF[F00A2W0<^
G@06J]IV]V[F4AHE5a4F0dJm00=6_6kDK]@00fkD00<03d:L@Y`00T:L0T:m00aNMUYfGWIJEUif=S/j
>cHkB[e6_4:m@Yd2DM<00e7DCM=Ad`03000023ilB]a:gDZlB]eNUUjGGWH2GYH02UjGA[a:_4JlB[a:
g4[MB]a:g@0@0UXe00EJEUXeFSEJ=CiL008nF`0;C]a>gD[LC]e>g4:mM[1fdGK@M]5f/00300X3B]`0
1TkMC]a>gDkLC]e>g0=6_@04CM=Ade7CDM<300001TkMC]a>g4kLC]e>g09>o00?D_e>g4kmC]aBoDkL
B]e:g4kMK]E^mFkEK_DI5AdE009:_005A[a:_5;lD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`00003D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0COol00`00Oomoo`0>Ool000Aoo`05001o
ogooOol0000IOol00`00Oomoo`06Ool0@7I/NXe5DDUbAG59LTEaBG95LDUbAG59TUJUA[e2W4JmJ[E^
eVZeK]IZ]FkF?Wa2WCjL@Yd^G39mI[IZefJfJ]LA5QDG4AHE5dJlA[e2_7;EK]AbeFjdL]D03dZmA[a:
gDJlA[eJEUifGi5NMUYF>U`f>cXkA[a:gDJl@[e=de7d0`0002]Am4gC?W`nFd9lA[a6_D:lHYMNMV:G
GWIRUeNAFi56_4[MA[a:_DJlC]e:_4[M@[aJEUXeFUIF=EYFB[a:gDZlB]e:g4kMB]a>gD[LN]5f/7[A
M[1jd@0400X0Yd[LC_e>g4kMB]a>oDkLC_e:g4Jm@[aAe4gCDOA=de7D@W]6W49kC_e>g5;mC]a>oDkL
D_e>g5;mC]aBoDkLD_e:g4kMB]a^mVkEK_I^eAdF6?DM5TkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoE;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007ooOol03Woo
0004Ool01@00Oomoogoo00006Goo00<007ooOol01Woo00QfS7ooBG55LDUaAG59LDEa0dUa0UK50T:m
00Q2W6[FJ]DbOF[EJ]IZe@Ad14:L00EV]V[FI[IZeVJf00E2W003>WdjWFkD00A^e0803`0?A[e6_4Jm
0;I2_EYFGWIJMUifFUHj>cHk>S]6_4Zm00<0009Ad`07DMAAde7C001:_DJlB[`00dJm0UjF00YNUeNA
Fi5GTE^AB]a:gD[LB]e:g096_@05FUIJ=EXeFSEJEP02Db/02dZlB]a:_4ZlB]a:gD[LB]e:g7KAM[00
0gKA00A2W4JLAYa6W0=>g007C]e:g4kMB]a>gD:mA[d00U7C00E=de7CDM=2O49k0092O00AC_e>g4kl
C]a>oDkLD_a>o5;mC]a>oDkLD_e:g4[MB]a^m@03K]D00adF6ADM5@04C]`00e;lD_eBo002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`COol00`00Oomo
o`0=Ool000=oo`80009oo`8001Uoo`03001oogoo00Ioo`0]MVaoodEaBG5FaDUbAG59LTEaBI95LEK5
DZEFaD:LA[e2W39mJ[E^eVZeK]H4L`Ad@Ya6_D:LA[eV]V[GI[IZea4FA[e2W4JM@Y`jWFkDL]E^]7;E
K]Abe@0>00803`0;B[e6_4[MFUINMUYFGWIJEUnaGi1:_@0300001d:m@YaAm4gCDOA=de7d0080003E
A[a:gDJlB]e6_4JmGWIRUeifHYMNMSXk=QXj>dZlC]e:_4kM@[a6gD:lFUIF=EYFFSECC5<[Eda:g4kM
B]a>gD[LB]e:_4kMM[1jdGJ`N]5f/4JL@W]6W4:LAYa>g4kmC]a>oD[LC]e:g4kM@[aAm4gCDMA=de7d
CM=>gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g4km>Ya^mVkEK_I^eFkf6ADM5QSe7AI>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;l01=oo`03001oogoo00aoo`008Woo0P001goo00mjSGooBG55LDUaAG59LDEaBG55LDUaOoln
O3YL>W`00S9m018bGF[FJ]EZeV[EJ]H4L`Ad@[a6_D:mJ]IV]V[FI[IZeQ4F5AL3@Y`6K]@0100?@Ya2
W4:L0T:m00ENMUYfGWIJEUif00<00096_005A[e6_4:mDM=Ae003DM<3000014[LB]e:_4[M0TJm00EN
MUjFGYINUcHK008f>`05B]e:g4[MB]a:g@02A[d01UXeFUIJ=EXe?U/nG08nF`08B]a>gD[LB]e:g4[M
B]a:g@9fd@04M[1fd@0:C]d3B]`02TkMC]a>g4kLC]e:g4kMB]a6_DgC0e7C00E=de7C001>g4[L009>
g006C_e>g4klC]aBoDkL0Tkl00E>oDkLC]e>g4km00=^e@03K_DM5@00009:_008A[a:_4kLD_e>g4kl
D_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0
4goo00<007ooOol037oo000ROol00`00Oomoo`06Ool02WI/Oom5DDUbAG59LTEaBI95LDUb0Woo02Pj
G3il>U/nO3YLK]IZ]FkFJ[E^eVZe19@4L`Ad@Ya6_D:L;UeV]V[GI[HE5a4F5AM6_4Jm@[abeFkDL]E^
]7;EK]A2W49l@Ye2_4Jm@YaNMP<0001;Gk5OT5naA[a:gDJlB]dnW57dCM=Am4gCDO@nFd9l?U]2O4Zl
B]e6_0FK1IYRUeifHYMNMV:G=QXj>cHJB]e:_4kMB[a:gD:lFUIJ=EYFESEJESYK?U`jFcilB]a>gD[L
@[dnWD:mM[1jdGJ`M]5f/00;00Y>gDZlC]e:_4kMB]a>oDkLC_e2_4KM@[aAe4gCDOA=de7D0080002H
B[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e:g4kMK]E^mVkE7AHI5DZlAYa:_4JLB[a>g5;m
C]aBoDklD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoA=oo`03001oogoo00]oo`008Goo00<007ooOol02Goo00I9LDEaBG55LDUaAG42BG43Ool2@[d0
2D:L@[e2_F[FJ]EZeV[EJ]H4L`03@Y`2;Ud01fJfJ]IV]V[FI[HE5a4F00=6_@I^e00500m2W4:L@Ya2
_@0200002eifGi5NMUYF>S/f>cXkA[a:_DJl@[d00e7C00=Ae57CDM<00Sil00DnNcilB]a:gDZl009N
UP06GYMNMUjFEi1GTDJl0TZl00I:gD[LB]e:g00AA[d2FSD01EYFFSEJ=DZlB]`00TZl00M>g4kMB]a2
_D:MM]5f/003M]4400X3C]`01dkMC]a>gDkLC]e2_DJm009Ad`03CM=Ade7C00<00007C]a>gDkLC]a>
o5;mC]`00Tkl00UBoDkLC_e>g4kMB]a:gD[LK_D00fkE00<M5QdEC]`014kL00=Bo5;mC]`00U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aB
o5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo019o
o`8000aoo`008Goo00<007oo00002Goo00Q5LE[VAG59LTEaBG95LDVB17oo01m2W4:m@Ya6_FZeK]IZ
]FkFJ[D4U3il@YdnW4:MI[IZefJfJ]MV]V[G4AHE5a4FA[e6_4JmK[AbeFkDL]E^]00200l30000jd:l
A[eJEUifFUINMSHk>U`f>cXk=S]:gDJlDOA=de7dCM=Am4gCDOA6_4[MA[a:gDJlA[e2_6:GGWIRUeM`
Fi5GT4ZmA[a:gDJlB[e:_4kMB[aJEUHeFUIJ=EYFCb]C;4ZlB]e:_4kMB]a>gD[LC]ef/7KAM[1jdGJ`
M]52NdJL@Ya6W4[LC_e>g4kMB]a>oDkLC_e2_4JmCM=Ae4gCDOA2Nd:L@W]6W4kLC_e>g5;mC]aBoDkL
D_e>g5;mC]aBoDkLC]e:g4kMB]a^mVkEK_HI5AdF6AE>oDkLC]e:g4kmC]aBoDkLD_eBo5;mC]aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01=oo`03001oogoo
00Yoo`008Goo0P002Woo00A9LGooBG55L@=9L@03AG5oogoo00Aoo`0C@[e2W4:mJ]EZeVZeJ]H4L`Ad
@[a6_D:mA[eV]V[FI[IZeQ4F00000d:L00<jWCYmK]@00fkD0`0000Y6_4JmA[a6_DJlGWIJEUifFUIN
MP=6_005A[e6_4:m@[eAe003DM<01e7DDM<004ZlB[e6_4Zl0096_@05GWINUUjFGYMNMP02=S/02D[M
B]a:gD[LB]e2_DJmFSEJEP03FSD3Db/024ZlB]a:_4[MB]a:gD[LB]d2M]401GJ`M]5fdDJL@Y`00dJL
0dkL00I>gD[LC]e:g4Jm@[d3DM<02DgC@Wa2O49l@W]2O4kLC_e>g002C_`025;mC]aBo4klC_e>g4kM
C]`2?Yd2K]D03FkeK]DM5AdE7AHM5DklC]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0AOol2000;Ool000moo`@000Ao
o`@000Ioo`03001oogoo00Uoo`07AE5oodEaBG95LDVBAG4027oo01PbOC9LK]IZ]F[FJ[E^ePAc19A2
W4Jm@YaZefJfJ]MV]V[F4AI6_D:LAYe2W7;EK]@300006FkD00l03`0?@[a6_D:LA[eJEUifFUINMU^@
Gk56_4ZmA[a:_CjL@[e=de7dCM=Am4gC00<0003GB[a:gDJlB]e6_4JmGWIRUeifHYLf6SXk=QY>gDZl
C]e:_4kM@[a6gEXeFUIF=EYF?U/nG3YK?Wa:g4kMB]a>gD[LB]e:_7[AM[1fdGJ`N]402TkMB[a>gDZl
C]e>g4kmC]a>gD[LC]e:g4JmCM=Am4gCDMA=ddkMB[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL
D_e>g6kfK]E^mVkEK_I6W4ZlAYa:_4JLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00>Ool300000goo001oo`0:Ool0
00ioo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`09Ool01dUaOom9
LDEaBG55LDUa00Qoo`8bO@05J[EZeV[EJ]IZ]@0217<02PAd@[a6_D:mJ]H^GF[FI[HE5a4F0TJm0`00
1FkD0d:L14:m00MJEUifFUIOTEn@Gi5OT002A[`01DJm@YeAde7CDM@00e7C00HnO3ik?Wa:g4[MB[`2
1IX01UjGGWINUUifGYLf6`8f>`06B]e:g4[MB]a:gD:m0UXe00iJEUXe?U/nFciL?U]>g4[LC]e:g4[M
B]a:gD[L0gKA00Af/00:00Y>g@=:g006C]e>g4kLC]a6_D:m0TJm00=AddgCDM<00U7C00T004kLB]a>
g4[LC]a>o5;mC]`00Tkl00UBoDkLC_a>o4kMB]a:gD[LK_D00fkE00<M5TJlB[`00TZl00E>g4klC]aB
oDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eoogoo00Qoo`@000Aoo`03001oogoo00Uoo`004goo00@007ooOol000Aoo`03001o
ogoo00=oo`8000aoo`05AG59LTEaBG95L@09Ool01FZeJ]IZ]FkFJ[D00Woo00Y2WCjL@Yd^G39m;UeZ
eVJfJ]MV]P<0001LA[a6_D:lL]E^e7;EK[AbeD9l@Ya2O4:M@Wa6_D:LGWIJEUifFUHjG3Hk>S/f>d[M
A[a2_DgCDOA=de7dCM=Am3iK@W`nFd9lB[a:gDJlHYMNMV:GGWIRUeifB[e6_4[MA[a:gDZlC]e:_00@
ESEJEUXeFUIF=Cil?U/nG3YKC]e:g4kMB]a2_GJ`M]5f/7[AM[1fd@0:00/02TkMB[a>gDZlC_e:g4km
C]a6_D:lA]e=de7DCM=Am0<0002KD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gFkEK_I^
eFkf7ADM5TJLB[a6W4ZlC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@06Ool30008Ool00`00Oomoo`09Ool001=oo`04
001oogoo0004Ool00`00Oomoo`02Ool2000=Ool014UaAG59LDUa2goo00AZeF[FJ[EZeP9oo`A2W08^
G@07I[H00000000E5QDG4AH00dJm00=6_6kDK]@00VkD00H03dJlA[e6_4JmA[`2@[d02eifFUINMUYF
>S/f>cXkA[a:_DJlDM@00e7C00MAm57CDMA:_4ZmA[a:_003A[d015jFGWINUeif0UN@00=:_4JlB[`0
0TZl00A:g4[MB]a6_@=J=@0:FUI?:dZlB[a:g4ZlC]e>g4kMB]`3M]401GJ`M]5fdDJL@Y`00TJL00Y>
gDkLC]a>g4kMC]a>gDkLA[e2_@=Ad`05CM=Add9l@Wa2N`02C]`04TkMC]a>g4klD_e>g5;lC]aBoDkL
C_e:g4kMB]a:gFkEK_I^e@8M5@037AI>g4kL00=>g09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@00
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l0goo0`0037oo00<007oo
Ool027oo000?Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool014EaBG95
LDVB37oo00=Z]F[FOol00Woo00@4U3il@YdnW0<0003oI[IZeP000012W4JM@Y`jWCIm>Ye^]7;EK]Ab
e@0?0116_4ZmA[a:g@2e0;IJEUifFUINMUYF>U`f>cXkA[a:gD:LDOA=de7dCM=Am4gC0016_4[MA[a6
gDJlA[eNMV:GGWIGTEM`Ei5GL4kMB[a>gDZlC]e2_4KMFSEJEUHeFUI?2U<[C`Y:gDZlB]e:_4kMB]a:
gDZlN]5f/7KAM[1jdGJ`AYa2NdJLC]a>gD[LC_e>g4kMB]a>gD:lA[e2_57dCM=Ae4gCAYa2Nd:L@W]B
oDkLD_e>g5;mC]aBoDkLD_e>g4kmC]aBoCZM?Ye^eFkfK]E^mVkE7AHM5DkMB]a>oDkLC]e>g5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l005Bo@5Bo08000moo`03001oogoo00Qoo`003goo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol037oo0dUa00=5LGooOol03goo00`4L`00000004:mA[eV]V[FI[IZeQDF
0003@Y`00cZMK]A^e003K]@400l02TJmA[a6_EYFGWIJEUifFUIOT5^@0TJl00Q6_D:M@[eAde7DDM=A
e57C0`0000=:_4ZmA[`00dJm00ENMUN@GWINUcHK008f>`0FB]e:g4[MB]a6_D:mA[eJ=EYFFSEC:dl[
Db]?:dkLB]a>gD[LB]e:g4[MM[03M]4027JaM]402TJL@Ya6W4kLC]d3C]`01TkMB]a>gDJmDM==d`9A
d`0:DMAAddkLB]a>g4[LC_a>g4kmC]`2C_`01U;mC]a>o4kLC_e>g08nW@05K_I^eFkEK]E^mP037AD0
1E;mC]a>o4kLD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo11oo`03001oogoo00Qoo`003goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol037oo00=5LDVBAG404Goo0P000?l4L`BD@Ya6_D:L
J]IV]V[GI[IZeQ4F5CM2W4JM@YabeFkDL]E^]7;EK]A2W49l@Ye2O4Jm@YaNMUYFGWIJEUifFi1OTDJl
B[e6_4Zm?YaAm4gCDOA=de7dCM=2O3iK@Wa:_4[MA[`5V`EjHYMNMV:GGWHj>cHJ>S/f6TkMB[a>gDZl
A[e2_5YFFSEC:eHe?W`nFciL>U]>gD[LC]e:g4kMB]a:gGJ`N]5f/7KAM[002`0:C]e:_4kMC]a>oDkL
C_e>g4kMB]a6gD:lDMA=de7dCM=Am000C]e:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a^mVkE
K_I^eFkf7AD40DJLB[a6W5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`000YBoE;lD_eBo5;mD_aBoE;lD_eBo0moo`03001oogoo00Qoo`00
3goo1@000goo10001Goo0P003Goo00=9LDEaBG403Woo0`000Woo00d4M0Ac19A2_4Jm@[d^GFJfJ]IV
]QDG5AHE5`02A[d00dJlK]A^e003K]@00`0?@Ya2W002@Y`2@[d04EifFUINMUYFGWHf>cXkA[a:_DJl
@[eAde7DDM=Am57CDM@00Sil00dnNd[MB]a:gDZlGYINMUjGGWINUUifB[a6_002B[`01D[MB]a:gD[L
A[d00eXe00]JESiK?U/nFciL?U]>gDkLC]e:g4:m009fd@08M[5fdGKAM]402P0;B]a>g@9:g008C]a>
gDkLC]e>g4Jm@[e6_@AAd`<0009>g006C]e>g4klC_aBoDkL0Tkl00IBoDkLB]e:g4kMB]`2K]D01Vkf
K]DM5AdEB[a6_09:_005D_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00?Ool00`00Oomoo`08Ool0021oo`03
001oogoo00eoo`03BG95LGoo00Yoo`<000Ioo`3o@YdnW4:M;U`^OFJfJ]IV]V[GI[HE5a4F5CM6_4Jm
K[AbeFkDL]E^]7;E00m:_DJlB]e6_4JmFUINMU^@GWIJESYL=S/j>dJlB]e6_4:mCM=Am4gCDOA=de7d
?U]2O3iKA]e6_4JmGWIRUeifHYMNMUN@Dg1:_DJlB]e:_4[MB[a>gDZlA[e?2UYFFSEJETZlB]e:_4[M
B[a>gD[LC]dnW7[AM[1fdGJ`N]5f/00;00X02dkLC]e:g4kmC]a>oD[LC_e>g4Jm@[aAm4gCDOA=ddJL
@W]2W49kD_e>g4kmC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMK]E^mVkEK_HI5AdF7AE>gD[LC_e>g5;m
C]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
000:D_aBoE;lD_eBo5;mD_aBoE;lD_d>Ool00`00Oomoo`08Ool0021oo`03001oogoo00eoo`99L@Qo
o`<000Yoo`=2W006I[IZeVJfJ]IV]V[F14:L00<fOCZMK]@00VkD01i^eFkD00l03dJmA[a6_@2e@[eJ
EUifFUINMUYF>S/f>cXkA[a:_D:mDOAAde7DDM=Am57C001:_4ZmA[`3A[d02UifGYINMUN@Dg1GT5M`
B[a6_4Zl0TJm00A2_DJmFSEJEP=J=@0:Cb]:_4ZlB[a:g4ZlC]e>g4kMM[43M]4027JaM]402dJL@Ya6
W4kLC]d2C]`014[LC]e:g4kM0TJm01Q=de7CDM=Ae49k@Wa2Nd9l@W]>o4kLC_e>g5;lC_aBoDkLC_e>
g5;mC]a:gD[LC]d3K]D016kf7ADM5AdE14kL00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00eoo`03001o
ogoo00Qoo`007goo00<007ooOol03Woo00=9TWooOol017oo0`003Woo02Y6_D:LA[eV]V[GI[IZeQ4F
0012W4JM@Y`jWFkDL]E^]7;EK]Abe@0?01003dZmA[a:gEYFGWIJEUifFUINMTJlB[e6_4Zm?Ya2_DgC
DOA=de7dCM<20000gD[MA[a:gDJlA]e6_6:GGWIRUeifHYLf6SXk=QY>gDZlC]e2_4Jm@[a6gEXeFUIF
=E<[C`YC:d[LC]e:g4kMB]a>gD[LB]ef/7[AM[1fdGJ`00]2W4JL@W]6W4kLC_e>g4kmB]a>gD[LC]e2
_57DCM=Am4gCDOA:_4kMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL?Ye^eFkfJ]E^mVkE7AHI
5AdF7AEBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d03Goo00<007ooOol01goo000OOol2000?
Ool014EaOomoogoo0`004Goo00A2_4Jm@[eZeP=V]P03J]HE5QDG00=2W09^e005K]E^e6kDK]A^e@03
@Y`2@[d01eifFUINMUYFGWIKT5n@00=6_007A[e2WE7DDM=Am57CDM@00`0000A:gD[LB]e:_096_@0>
GYMNMUjFGWHf>cHK=S]:g4[MB]a:gD[LA[e2_@9J=@0>FUIJ=CiK?U/nG4[LC]a:g4kMB]a:gD[LB]ef
/@=fd@0400X02d[LC]d2B]`02TkLC]e>g4kLB]a>gD[LA[eAde7D0e7C00@004[LC]a:g09>g004C_a>
g4kmC]`2C_`01U;mC]a>gDkLC_e>g09^e@06K_I^eAdF7AE:_4Jl0TZl00EBoDkLC_a>g5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo003D_eBo7oo00aoo`03001oogoo00Moo`007goo00<007ooOol03Woo00A9LP000000
01Eoo`1U@Ya6_D:L;UeV]V[GI[HE=a4F5CM6_4Jm@[abeFkDL]E^]7;EK[A2W49l@Ye2_4Jm@YaNMUYF
GWIKL5n@Fi1OT4JlB]e6_4:m?YaAm4gCDOA=de7d?U]2O3iKB]e:_4[M1GX5VeifHYMNMV:GGWHj>cHJ
>S]:_4[MB[a>gDZlA[eF=EYFFSEJESYK?W`nFciLB]a>gD[LC]e:g4:mM[1fdGJ`M]5f/00;00X02dZl
C]e:_4kMC]a>oD[LC_e2_4Jm@[aAm4gCDOA=d`030000XDZlC]e:_4kMC]aBoDkLD_e>g5;mC]aBoD[L
C]e:g4kMB]a^mVkEK_HM5AdfAYa:_4JLB[a>g5;mC]aBoDkLD_e>g5;mC_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`037oo
00<007ooOol01goo000OOol00`00Oomoo`0<Ool3000IOol2;Ud00fJfJ]IV]P02I[H00aDG5AI6_@02
A[d3K]@016kEK]A^e00?0d:L0T:m019JEUifFUINMUYF>S/f>cXkA[a:_DJl@[eAde7DDM=Am57CDM@2
?W`02CikB]e:g4[MGWINUUifGYMNMP02Dg002DZlA[a:_4[LB]e:g4[MB]a6_@03FSD015YFB[a:_4Zl
0T[L00A>gDkLC]dnW@=fd@08M[5fd@0;00/02P0;C]a>g@=>g003C]e>g4kM0096_@=Ad`05DMA2Nd9l
@W]2O003C]`03DkMC]a>o4klD_e>g4kmC]aBoD[LB]e:g4kM00=^e@03K]HM5AdF00A>g003D_aBoDkL
009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0:Ool00`00Oomoo`07Ool001moo`03001oogoo00Uo
o`<001eoo`3oI[IZefJfJ]IV]V[G5AHE=a4FA[e6_4JmK[AbeFjdK]E^]00@00m:_DJlB]e2_4JmFUIN
MUYFGWHf>cYL=S/j>dJlB]dnW57dCM=Am4gCDOA=d`00A[a:gDJlA]e6_4JmGWIRUeifEi1CKeN@Dfm:
_DJlB]e2_4Jm@[a6gEXeFUIF=EYFC`Y?:dZlB]e:_4[MB[a>gD[LC]ef/7KAM[1fdGJ`M]52W4JL@W]6
W4kLC]e:g4kmB]a>gD[LA]e2_57dCM=Am4gCDOA2NdJL@W]>oDkLD_e>g4kmC]aBoDkLD_e>g5;mC]aB
oD[LC]e:g4kMJ]E^mVkE7AHM5AdfC]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l000:D_eBo5;mD_aBoE;lD_eBo5;m
D_`:Ool00`00Oomoo`07Ool001moo`8000Qoo`80025oo`=V]P03J]HE5P0000=2W003>YdfOFkE00=^
e00=K]D03`0?00m6_DJlA[eJEUifFUINMUYFGWH00dJl00Q6_D:M@[eAde7d001Ae57C0P000TZl00Y:
_DJlA[e6_EjGGWINUUifGYLf6`8f>`03B]e:g4[M0096_@05@[eJ=EXeFUIJ=@03C`X03D[LC]a:g4kM
B]a:gD[LB]ef/GKAM[5fdGJa00=6W004@Ya6W4kLC]d2C]`00d[LC]e:g002A[d05E7DDM=Ade7CDMA2
Nd9l@W]>oDkLC_a>g4kmC]aBo4klD_e>g4kMC]a>o@02?Yd03VkEK]I^eFkE7ADM5QdE7AI>g5;mC]a>
o5;lD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoGooOol027oo00<007ooOol01goo000NOol00`00Oomo
o`05Ool3000TOol09VJfJ]Moogoo5AHE=d:LAYe2W7;EK[A^eFjdL]E^]4:L@Wa2WD9lA[e2W5ifFUIN
MUYFGWIKKe^@A[a:_DJlB[dnW57dCM=Am4gCDO@30000gd[MB[a:gDJlA]e6_6:GGWIRUeif>S/f6SXk
B[a>gDZlC]e2_4Jm@[aJEUXeFUIF=Cil?U/nG4[LC]e:g4kMB[a>gD[LB]ef/7KAM[5fd@0:C]e:_4kM
B[a>gDkLC_e>g4kmB]a>gD:lDOA=de7dCM=Am4gC001:_4kMB[aBoDkLD_e>g5;mC]aBoDkLD_e>g5;m
C]a>oF[EK_I^eFkfJ]E:_4JLB[a6W4ZlC]aBoDkLD_e>o5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
00Yoo`03001oogoo00Ioo`007Woo00<007ooOol00Woo0`00:goo00<E5aDF5AL00TJm00A6_6kDK]A^
e@=^e0=2W0=2_@03GWIJEUif00AKT00:A[a:_DJl@[e2WE7DDM=Am57CDM@2?W`04SikB]e:g4[M1GX5
VUifGYMNMUjFGWHf>cHK=S]:g4[MB]a:g@96_@04FSE?2UXeFUH4?U/02d[LC]a:g4kM?Ye2_GJaM]5f
/GKAM[400P0;0T[L00M>gD[LB]a>g4kMC]a>g@02A[d01D:mDM=Ade7DDM<00P0000I>g4[LC]a:g5;m
C]`2C_`02E;mC]a>o4klD_e:g4[MB]a>g@03K]D00fkF7AE:_002B[`01DJlB[aBo5;mC]`00U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`015;mD_aBo5;l2Woo00<007ooOol01Woo000NOol00`00Ool00002000_Ool0
GADg5AHE=dJlA[e2_7;EK[A^eFjdL]D03d:L@Wa2WD:lA[eJEUifFUINMUYF>U`f>cXkA[a:gDJl@[e=
de7dCM=Am4gC@W`nFd9l?U]:gDZlB]eNMV:GGWIRUeifEi1CKdZmA[a:gDZlB]e:_4kM@[aJEUHeFUIF
=EYFB[a:gDZlB]e:g4kMB]a>gCjLM]5f/GKAM[1fd@0:00/02TkmC]a>gD[LC_e>g4kmB]a6gD:lA[e=
de7dCM=Am0030000Y4kmC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LK_IZeFkfK]DM5QdEC_e>
g4kMB]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`9Ool00`00Oomoo`06Ool001io
o`<0035oo`8E5`055AHE5dJmA[e6_002K]@01fkEK]@03`0?A[e6_4Jm0092_@0AFUINMUYFGWHf>cXk
=S/j>dJlB[e2_E7dDM=Ae57CDOAAd`02B[`00dZmA[a6_@02A[d015ifGYINMU=`0U=_0TZl00Q6_4Zl
A[e6_D:mA[eJ=EYF0UXe0P000dZl00]>gD[LC]e>g4kMM[5fdGJaM]5f/GKA0096W004@Ya>g4kLC]d3
C]`01DkMC]a6_DJmDM@00e7C00E2O49k@Wa2NdkM00=>g00=D_e>g5;lC_aBoDkLC_e>g5;mB]a:gD[L
K]H00VkE00<M5AdF7AD01DkL00=Bo5;mD_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006
D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l27oo
00<007ooOol01Woo0004Ool50003Ool40004Ool40007Ool00`00Oomoo`0aOol0>d:LAYe2W4Jm=We^
eFjdL]E^]6kE00l0400?B[e6_4[MA[aNMUYFGWIJEUifA[a:_DJlB[dnW4:mCM=Am4gCDOA=de7d001:
gDJlB]e6_4KMA[aRUeifHYMNMV:G=QXj>dZlC]e:_4kM@[a6_D:lFUIF=EYFESD00`000<M:_4[MB[a:
gDZlC]e:g4[MM[1fdGJaM]5f/4JL@Ya6W49kC_e>g4kmC]a>oD[LC]e2_4KMCM=Am4gCDOA=dd:L@W]6
W49kD_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkLC_djW6kfK]E^mV[EK_HM5AdF7AEBoDkLD_e>g5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo007Ool00`00Oomoo`06Ool000Ioo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`05Ool2000cOol3@Y`00fkDK]E^e002
K]@4@Y`3@[d01UYFGWIJEUifFhmKT0=6_007@[e2WE7DDM=Am57CDM@00`0000A:gD[LB]e:_096_@0;
GYMNMUjFGWHf>cHK=S]:g4[MB]a:g@02A[d01D:mFSEJ=EYFFSD00ciK00E:g4kLB]a:gD[L009:g@06
M]5f/GKAM[5fd@0;0T[L00E>gD[LC]a>g4kM009>g003B]a>gD:m009Ad`0>DMAAde7C001>g4[LC]a:
g4kmC]a>o4kLD_e>g09>o005C_e>g4kMC]a>o@03K]D00fkFK]E:_002B[`01DJlC_a>g5;mC]`00U;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`7Ool00`00Oomoo`06Ool000Ioo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`0aOol0odJm@[a6
_FjdK]E^]7;EK[A2W49l@Ye2O4Jm@YaNMUYFGWIGKe^@FfmKT4JlB[e6_4:mCM=Am4gCDOA=de7d?U]2
O3iKB]e:_4[M1GX5VeifHYMNMV:GGWHj>cHJ>S]:_4[MB[a>gD:lA[eF=@00ESEJESYK?W`nFciLB]a>
gD[LB]e:_4kMB]afdGJ`M]5f/@0;00Y>gDZlC]e:_4kmC]a>oD[LC_e2_4JmCM=Am4gCDOA=d`00B[a>
gDZlC]e:_5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e:g6kfJ]E^mVkE8CHM5DZlAYa:_4JLD_e>g5;mC]aB
oDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0015;lD_eBo5;m1Woo00<007ooOol01Woo0006Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol027oo00<007ooOol0<7oo0TJm
00A6_6kDK]A^e@9^e00300m2W4:L0092W092_@09GWIJEUifFUHj>cHk>S]6_4Zm0092_@05DM=Ae57C
DOAAd`03?W`02CikB]e:g4[MGWINUUifGYMNMP02Dfl02DZlA[a:_4[LB]e:g00?A[eJEP03FSD015YF
B[a:_4Zl0T[L00U>gDkL@[ef/GKAM[5fdGJaM]400`0;0TkL00I>gDkLC]e>g4kMC]`2A[d0157DDM=A
de7C0`0000=>g4kMC]`00TkL00YBoDkLC_a>o5;mC]a>oDkLC]e:g09:g@06K]I^eFkE7ADM5QdE14kL
0U;l00EBoDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000D_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`06Ool00`00Oomoo`05Ool0
00Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`09Ool00`00Oomo
o`0`Ool0>4JlA[e2_7;EK[A^eFjdL]D03dZmA[a:gDJlA[eJEUifFUINMSHk>U`f>cXkA[a:gCjLDOA=
de7dDM=Am4gCB]e6_4[MA[a6gDJlA[eNMV:GGWICKdm?Dg1?KdZmA[a:gDZlB]e:_5YFESEJEUHeFUH2
0000bDZlB]e:_4kMB]a>gD[LM]5f/7KAM[5fdG:`00a2W4JL@W]>oDkLC]e:g4kmC]a>oD[LA]e=de7d
CM=Am4gC@Ya2NdJLC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]e^eFkfJ]DQ=QdE8CHM5Dkm
C]a>gD[LD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo006Ool00`00Oomoo`05
Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0:Ool2000a
Ool00cImK]E^e002K]@03FkEK]@0400?0116_4JmA[aNMUYFGWIJEUif00=6_00:A[e2WD:mDM=Am57C
DOAAde7d0002B[`02TZmA[a6_DJmGYMNMUjFGWINUcHK0SHk00=:gD[LB]d00TJm0eXe00=JEUXe0000
0P000dZl00Y:gD[LB]e:gGKAM[5fdGJaM]402`=6W00<@Ya>g4kLC]e>g4kMB]a>gD:mA[eAde7D0e7C
00I2O49k@Wa>g4kmC]`2C_`02E;mC]aBo4klC_e>g4kMC]`nW@03K]D02VkFK]DM5QdE7AI>g4klC]aB
oDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo000
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`04Ool00`00Oomoo`05
Ool000Aoo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0<Ool00`00Oomoo`0_
Ool02FjdK]E^]7;EK[A^eD9l@Ye2O002@Y`04DJmFUINMUYFGWIGKe^?A[a:_DJlB[e6_57dCM=Am4gC
DO@00`0002I:gDZlB]e6_4KMA[aRUeifHYMNMSXk=QXj>dZlC]e:_4kM@[a6_EHeFUIF=EYFESDnO3iK
?Ua:g4kMB]a:gDZlC]e:g7KAL[1fdGJa0P0;0;a>gDZlC]e:_4kmC]a>oDkLC]e:g4kM@[aAm4gCDOA=
de7d001>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_e>g6kfJ]E^mVkEK_I6W4ZlAYa:_4kLD_e>
g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l17oo00<007ooOol01Goo
0006Ool00`00Oomoo`03Ool40004Ool4000@Ool00`00Oomoo`0_Ool01VkDK]E^e6kDOol040=2W0=2
_@0@FUINMUYFFfmGKe^?A[a:_DJlB]eAde7DDM=Am57CDO@2?W`063ikB]e:g4[M1GX5VUifGYMNMUjF
GWHj>cHK=S]:g4[MB]a:gDJmFUIJ=@00FSEJEP@nF`0:B]a>g4[L@[dnWGKAM[5fdGJaM]4300/2B]`0
1TkMB]a>gDkLC]e>g0=6_@=Ad`0:DO@00000001>g4[LC]a>o5;mC]`2C_`01U;mC]a>o4klC]e:g09:
g@06K]I^eFkEK]DM5TJl0dZl00E>g5;lD_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoGooOol00Woo00<007ooOol01Goo000YOol00`00Oomoo`0^Ool00g;EK[Aoo`03Ool0
?`0@@Wa2WD9lA[e2W5ifFUINMUYF>U`f>cXkA[a:gDJl@[e=de7dDM=Am4gCDO@nFd9l?U]:gDZlB]eN
MV:GGWIRUeifDfm?CTZmA[a:gDZlB]e:_4kM@[aJEUHeFUIF=EYFB[a:gDZlB]e:g4kMB]a2_G:`M]5f
/GKAL[00300300/0^dkmC]a>gD[LC_e>g4kmB]a6gDgCDOA=de7dCM=2W49kAYa2NdkmC]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4kMB]a>gFkEK_IZeFkf7ADQ=T[LC_e>g4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00=oo`03001oogoo00Eoo`00:Woo00<007ooOol0<goo
0P0@00=6_4JmA[`00T:m00ANMUYFGWHf>`<j>`0=A[a:_DJlDOAAde7dDMAAm57C001:_4ZmA[`00dJm
00YNMUjFGWICKdm?Dfm?KdZlA[a:_096_@04@[eJ=EXeFUH2FSD20003B[`2B]`024kMC]afdGJaM]5f
/GKAM[43AY`034:LC]a>g4kMC]a>gD[LC]e2_DJmDM=Ae09Ad`06@W]2O49k@Wa>g4kM0TkL019>o5;m
C]aBo4kLD_e>g4kmB]e>gD[LB]e^eFkFK]DM5QdE7AH4C]`3D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l0goo00<007ooOol01Goo000[Ool2000cOol05P0@00l044JlB]e6_5if
FUINMUYFGWI6_4ZmA[a:_CjL@[dnWE7dCM=Am57C0P0001Q:gDJlB]e6_4KMA[aRUeifHYMNMUjG=QXj
>cHJC]e:_4kM@[a6_D:lFUIF=EYFESD30000bd[LC]e:g4kMB[a>gD[LM]5b/7KAM[5fdD9kAYa2W4JL
@W]>oDkLC_e>g4kMB]a>gD:lA]e=de7dCM=Am49k@Ya2NdJLC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;m
>YdnWF[EK_IZeFkf7ADQ=QdE8CI>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`00goo00<007ooOol017oo000]Ool00`00Oomoo`0aOol3@Y`2@[d015YFGWIJ
EUif0UM_0dJl00M6_DJl@[eAde7dDM=Am003000014[MB]a:gDZl0TJm00]NUeifGYINMSXk=Q/f>d[L
B]e:g4[M0096_@=J=@03FUHnFciK008nF`05B]a>g4[LC]e:g002B]d01GKAM[5fdGJa00/00d[L00U>
gD[LC]a>g4kMC]a>gD[LA[d00e7C00IAm57C001:g4kLB]`2C]`03DkmC]a>o4klD_e>g4klC]a>oDkL
C]e^eFkF00=^e@038CI6_4Zl009:_004C]a>o4kLD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`015;mD_aBo5;l0Woo00<007ooOol017oo000^Ool00`00Oomoo`0`Ool00d9l@Ye2O002
@Y`0BdJmFUINMUYFGWHf>cYKA[a:gDJlB]dnW57dDM=Am4gCDO@nFd9l?U]:gDZlB]e6_6:GGWINUeif
HYMNMSXk=QXj>dZlB]e:_4kM@[aJEUHeFUIF=CiL>U/nO3iK?Ua:g4kMB]a>gCjLM]5f/GKAL[5fd@0;
00a:_4kMB[a>gD[LC_e>g4kmB]a6gD:lDOA=de7dCM=Am0020000[dZlC]e:_5;mC]aBoDkLD_e>g5;m
C]aBoD[LC]e:g4kMJ]E^mV[EK_HM5DZlAY]:_4JLB[a>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aoo`0000Ioo`00;goo00<007ooOol0<7oo00U6_4JmA[a6
_D:mGWIJEUifFUH00cXk00Y6_4ZmA[a:gE7CDOAAe57dDM=Am08nO009?W]6_DJmA[eNMUjFGWINUeif
009?CP09B[a6_4ZlB]a:gD[LB]e6_EYF00=J=@04B]a:_4ZlB[`2B]`024kMC]a2_GJaM]5f/GKAM[43
00/3C]`04DkMC]a>gDkLC]e>g4JmDM=Am57CDMAAdd9l@W]2O4kLC]d00TkL00]>o5;mC]a>o4kLD_e>
g4kmB]e>gD[L009^e@04K]I^eAdF7AD6C]`2D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@02D_`00goo001oo`05Ool0031oo`80035oo`3oA[a:gDJl09E2W5ifFUINMUYF
>U`f>cYK=S]:gDJl@[e=de7dDM=Am4gC0016_4[MA[a6gDJlA[eNMV:GGWICKdm>Dfm?CTZmA[a:gD:l
A[e2_5YFESEJEUHeFUH004[MB[a:gDZlB]e:g4kMB]afdG:aM]5f/GKAL[56W4:LAYa:g4kmC]a>gD[L
C]e:g4kM@[aAm4gCDOA=de7d@W]2W49kAYa>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a^mV[E
K]IZeB4f7AE>gD[LC_e>g5;mC]aBoDkLD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@0000Ioo`00<Woo00<007ooOol0;goo00U6_4JmA[aNMUYFGWIJEUifEfh00TJl00Q6
_DJl@[e2_E7d001Am57D0`0000=:_4ZmA[`00TJm00INUeifGYINMUjG=Q/2=S/00d[MB]a:g@02A[d0
14:mFSEJ=EYF0`0000I>gD[LC]a:g4kMB]`2B]d01WKAM[5fdGJaM]402`=6W0=>g006C]e:g4kMB]a>
gD:m0U7C00IAm57CDMA:g4kLB]`2C]`03DkmC]a>o4klD_e>g4kMC]a>oDkLC]dnWFkF00=^e@09K]HM
5AdF7AEBoDkLC_a>g5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00MBoE;lD_aB
o5;mD_`00006Ool003=oo`03001oogoo02moo`3i@Ya6_EYFGWIJEUifEfiGKeM^B[e6_4ZmA[a2_E7C
DOA=de7dDM=2O3iK@Wa:_4[MA[a6gDJlGYMNMV:GGWHj>cHJ>S/f6TkMB[a>gD:lA[eF=EYFESEJESYK
?W`nFdkMB]a>gD[LB]e:_4kMB]afdG:aM]5f/@0<00]>gDZlC]e>g4kmC]a>oD[LC]e:g4JmCM=Am4gC
DOA=d`00B[a>gDZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLD_eZeFkFJ]E^mQdE8CI6VdZlAYaBoDkL
D_e>g5;mC]aBoDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Aoo`03001oogoo
00=oo`00=7oo00<007ooOol0;goo0T:m011JEUifFUINMUYF>S/f>dZmA[a:gD:MDOAAe57dDM=Am08n
O00=?W]:gD[LB]e:_5jFGWINUeifGYINMTZlA[`00TZl00E:gD[LB]e6_EYF00=J=@0BFUHnFciK?U]>
gD[LC]e>g4:mM[5fdGJaM]5f/GKA00/0300;0T[L00I>gDkLC]e>g4kM@[d2A[d0157dDM=Ae57C0`00
00M>g4kMC]a>g4klD_e>g002C_`01U;mC]a:gD[MC]e:g09^e@06K]I^eAdF7ADQ=TJl0TZl00EBoDkL
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d027oo00<007ooOol00goo000eOol2
000`Ool0l4:LGWIJEUM_FUINMSHk>U/f>d[MA[a:gDgCDOAAde7dCM=Am3iK@W`nFdKMA[a6_D:lHYMN
MUjGGWI?Kdm>B[e6_4[MA[a:gDZlC]e2_5YFESEJEUHe001:_4[MB[a>gD[LC]e:g7KAL[5fdGJaM]5b
/DJL@Y]6W49kC_e>g4kMB]a>oDkLC_e2_4KMCM=Am4gCDOA2Nd:L@W]6W4kLC_e>g5;mC]aBoDkLD_e>
g5;mC]aBoD[LC]e:g6kfJ]E^eQdE8CHM5B4fC]a>oDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eB
o5;mD_aBo@]oo`03001oogoo00=oo`00=goo00<007ooOol0;Goo00L0UD:mGWIJEUifFUINMP02>S/0
3CHkB[e6_4:mDM=Am57DDOAAd`00B[a:_DJl00=6_@05GWINUUifGYLf6`02=S/01T[MB]a:gD[LA[e2
_@9J=@05FUIJ=@00001:g003B[`02T[MB]a:gD[MM]5f/GKAM[5fd@0;0dJL01E2W4kLC]a>gD[LC]e:
g4Jm@[eAe57CDOAAdd9l@W]2O49kC_a>g4kmC]`00Tkl00MBoDkLD_a>g4kmC]a>g@02?Yd3K]D016kF
7ADM5QdE14kL00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo0moo`03001oogoo00=oo`00>7oo00<0
07ooOol0;Goo011NMUYFGWIJEUifDdiGKdJlB[e6_4:m?YeAm4gCDOAAd`<0003EA[a:gDJlA]e6_4Jm
GWIRUeif>S/f6SXk=QY>gDZlC]e:_4Jm@[aJEUHeFUIF=Cil?U]>gD[LC]e:g4[MB[a>gGJaM]5b/GKB
M[40300;C]e:_4kMB[a>oDkLC_e:g4kMB]a6_D:lDOAAde7dCM=>gDZlC]e:_5;mC]aBoDkLD_e>g5;m
C]aBoDkLC_e>g3jMJ]E^eV[EK_IZeDZlAY]:_4JLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00019oo`03
001oogoo00=oo`00>Goo00<007ooOol0;Goo00=NMUYFGWH015M^00M6_4JmA[a2_E7DDOAAd`02DO@0
1Sil?W/nO4[LB]e:_085NP06GYMNMUifGWHj>cHK0SHk00E:gD[LB]e:g4Jm00=J=@0BFUHnFciK?U]>
gD[LC]a:g4[MB]a:gGJaM]5f/GKA00/0300;0T[L00I>gD[LC]a>g4kM@[d2A[d02U7dDM=Ae57CDO@0
0DkLB]a>g4[L0Tkl00YBoDkLC_a>o5;mC]a>o4kLC_e>g09^e@06K]I^eB4f7AE:_4Jl0TZl00EBoDkL
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m009Bo0Aoo`03001oogoo00moo`03001oogoo00=oo`00>Woo0P00;Goo00=JEUifFUH00Woo
04<jFcHk>Ua6_4[M?YaAm57CDOA=de7d?U]2O3iK@Wa:_4[MA[aRUeifGYMNMTm>Bde:_DJlB]e6_4[M
B[a>g@0>FUIF=EYFESEJESYK?W`nFdkMB]a>gD[L@[eb/GKBM[5fdG:a00`02`0<B]a>oDkLC]e:g4km
C]a>oD:lA]e2_57dCM=Am0030040U5;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LK_IZeFkF
J]DQ=QdEC]e>g4kmC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l27oo00<007ooOol03goo00<007ooOol00goo000lOol00`00Oomoo`0[
Ool015YFOomoogoo0SXk00`f>cXkA[a:gE7CDOAAe57dDM=Am4ZlB[d2B[`3A[d2GWH00ejGBdi?CP02
B[`024JlB[a:_4[MB]a:gDJmFUH2FSD20003B[`02TkMB]a>gDkLM]5f/GKAM[5fdGJa0dJL0dkL00i>
gDkLC]e>g4kM@[e6_E7CDOAAde7d@W]2O49k0TkL00Y>gDkLD_a>o5;mC]a>oDkLD_e>g09:g@08C]e:
g6kEK]E^eQdE8CHM5@A>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00IBoE;lD_aBo5;mD_`<Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool003eoo`03001oogoo02moo`0S
A[a:_DJlB[dnWD:mCM=Am57CDOA=d`00A[a:gDJlB]e6_4JmGWIRUeifGYLf6SXkB[a>gDZlC]e:_4Jm
@[aJEUHeFUIF=@030000[4ZlB]e:_4[MB[a>gD[LM]5b/GKBL[5fdD9kAYa2VdJLC]a>oDkLC_e>g4kM
B]a6_D:lDOAAde7dCM=Am49k@Ya2Ne;mC]aBoDkLD_e>g5;mC]aBoDkLC_e>g3jM>Ye^eV[EK_IZeB4f
7ADQ=QdED_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
4Goo00<007ooOol03Woo00<007ooOol00Woo000nOol00`00Oomoo`0_Ool01dJlA[e6_4Jl@[eAm57C
009Am0<00004B]a:gDZlB]d2A[d3GWH01cXk=Q/f>d[LB]e:g4[M0096_@=J=@03FUIJ=CiK008nF`0<
B]a>g4[LB]e:g4[MM[5fdGJaM]5f/@0<0d[L01I>gDkLC]a>g4kMB]a>gD[LA[eAde7DDM=Am57C005:
g4kLB]a>o4kLC_e>g09>o006D_e>g4kMC]a>oDkL0VkE00I^eVkEK]DQ5DZlA[`2B[`01E;mC]a>o4kL
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo01=oo`03001oogoo00eoo`03
001oogoo009oo`00?goo00<007ooOol0;goo0456_4[MA[a2_E7CDOA=de7dDM=2O3iK@Wa:_4[MA[`5
VP5jGYMNMV:GGWHj>cHJ>S]:_4[MB[a>gD:lA[eF=@00ESEJESYK?W`nFciLB]a>gD[LB]e:_4kML[5f
dG:aM]802`0<B[a>gDZlC]e:g4kmC]a>oD:lA]e2_57dCM=Am57C00<00@25B[a>gDZlD_e>g5;mC]aB
oDkLD_e>g4kMB]a>gD[LK_IZeFkFJ]DQ=TJLB[a6VdZlC]aBoDkLD_e>g5;mC]aBoDklD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`06Goo00<007ooOol03Goo00<007ooOol00Woo0010Ool2000`Ool00dJlB]e6_003
DO@02E7CDOAAm3il?W/nO4[LB]e:_002GWH03EjGGWI;CD]=B[a6_4ZlB]a:gD[LB]e6_EYF00=J=@04
FUI:_4ZlB[`2B]`024kMC]a2_GJaM]5f/GKAM[4300`3C]`04DkMC]a>gDkLC]e2_DJmDM=Am57CDOA2
Nd9l@W]2O4kLC]d00TkL00M>o5;mC]a>oDkLD_e>g002B]d01dkMK]E^eFkEK]HM5B4f00A>g003D_aB
oDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`MOol00`00Oomoo`0<Ool00`00Oomoo`02Ool0049o
o`03001oogoo02ioo`0PA[a:gCjLDOAAde7dCM=Am000B]e6_4[MA[a6_D:lHYMNMUjGBbe?CT/]B[e6
_4[M@[a6_D:lFUIF=EYFESEJEP80002OB[a:gDZlB]e:g4kmB]afdG:aM]9b/GKBL[56W4:KAYa:g4km
C]a>gD[LC]e:g4Jm@[aAm57CDOA=ddJL@W]2W49kD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLC]e:g4kM
J]E^mV[EK]HM5B4fC]a>gDkLC_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l025oo`03001oogoo00]oo`03
001oogoo009oo`00@goo00<007ooOol0;Woo0T:m00AAde7dDOAAm0<00003B[e:_4Zl0096_@=NMP07
GYLf6cHk=S]:gD[LB]d00TJm00E2_EXeFSEJEUXe00<00005B]a>g4[LC]e:g002B]d01WKAM[5fdGJa
M]4030=6W0=>g00BC]e:g4kMB]a6_D:mDMAAde7dDM=>g4[LC]a:g4klC]a>oDkL0Tkl00YBoDkLC_a>
g4kmC]`nWFkEK]IZe@9^e@098CHM5B4fC]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l:7oo00<007ooOol02goo00<007ooOol0
0Woo0014Ool00`00Oomoo`0^Ool0]3jMDOA=de7dDM=Am3iK@W`nFd[MA[a:gDJlA[eNMV:GGWHj>cHJ
>S/f6TkMB[a>gD:lA[eF=EYFESEJESiK?W`nFciLB]a>gD[LC]e:_4kMB]afdW:aM]9b/@0<00]>gDZl
C]e>g4kmC]a>oD[LC]e2_57dCM=Am57CDO@00DkMB[a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL
K_IZeFkFJ]DQ=Q04B[a6VdZlC]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoBeoo`03001oogoo00]oo`03001oogoo005oo`00AGoo0P00;Woo
00A2_E7dDOAAd`9Am009?W`nNcil?Wa:gDZlB]eNMUjG00=NMP09B[a6_4ZlB[a:gD[LB]e6_EYF00=J
=@0?FUHnFciK?U]>gD[LC]e>g4kMM[5fdGJaM]5f/GKA00<0309:g09>g004C]e>g4kM@[d2A[d00e7d
DM=Am0030042C]`02TkMC]a>o4klD_e>g4kmC]aBoDkL0T[M00M>gD[LK]E^eFkF7ADQ=P02B[`01DJl
B[aBo5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l
035oo`03001oogoo00Yoo`03001oogoo005oo`00Agoo00<007ooOol0;7oo0:eAm57CDOAAde7dDM=:
gDJlB]e6_4Jm@[a6gEifGYMNMT]>Bbe:_DJlB]e6_4[MB[a>gD:lFUIF=EYFESD004ZlB]e:_4kMB]a>
oD[LM]9b/GKBL[5fdW:aAYa2VdJL@W]>oDkLC]e:g4kmC]a>oD:lA]eAde7dCM=Am49k@Ya2Ne;mC]a>
oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gF[EK_IZeB4f7ADQ=TkLC]e>g4kmC]aBoDkLD_e>g5;mC]aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m03Eoo`03001oogoo00Uoo`03001oogoo005o
o`00B7oo00<007ooOol0:goo00Q2WE7dDOAAm57CDO@004Zm0dZl0TJm0Uif00YNUeif=S/f>d[MB]a:
gD[LA[e2_@9J=@03FUIJ=@00008000=:_00:B]e:g4[MB]efdGJaM]5f/GKA00`3AY`3C]`06TkMC]a>
gD[LA[e2_E7dDM=Am57CDOA2Nd9l@W]>o4kLC_e>g5;lC_aBoDkLC]e>g4kmC]`2?Yd03FkFJ]E^eFkE
8CHM5B4fC]aBoDkLC_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo03Qoo`03
001oogoo00Uoo`03001oogoo005oo`00BGoo00<007ooOol0:Woo00E2_DgCDOAAde7d00<0002NB]e6
_4[MB[a6_D:lHYMNMUjG=QXj>cHJC]e:_4kMB[a6_D:lFUIF=EYFESDnO3iK?Ua:g4kMB]a:gDZlC]eb
/GKBL[5fdW:a00a:_4kMB[a>gDkLC_e>g4kmB]a>gD[LA[e=de7dDM=Am4gC009:_4kMB[aBoDkLD_e>
g5;mC]aBoDkLD_e>g4kmC]a^mV[EK]IZeFkfAYa:_4JKB[a>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo3eoo`03001oogoo00Qoo`03001oogoo005oo`00BWoo0P00:Woo00=2_E7dDM<0
0U7d00Moocik?W`nO4[MB[a:g@020GX3GWH02EjG=QXf>cHkB]e:g4[MB]a6_@03FSD00eYF?U/nF`02
?U/024[LC]a:g4[MB]a:gGJaM]42M[4200`3B]`2C]`014kMC]a>gD:m0TJm00YAm57CDOAAe002005>
g4[LC]a:g09>o006D_e>g4klC_aBoDkL0T[M00M>gD[LK]E^eFkF8ADQ=P02B[`01DJlB[aBo5;mC]`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo45oo`03001oogoo00Moo`03001oogoo005oo`00C7oo00<0
07ooOol0:7oo00=Ade7dDM<00goo02DnFd9l?U]:gDJlB]eNMUjGGWIRUdL/Bbe6_4[MA[a:gDZlC]e:
_4JmESEJEUHeFUI:_4[MB[a:gD[LC_e:g4:mL[5fdW:aM]9b/@0300`0L4[LC_e>g4kMB]a>oDkLC_e2
_4KMDM=Am4gCDOA2Nd:L@W]BoDkLC_e>g5;mC]aBoDkLD_e>g5;mC]a>gD[LC]eZeFkfJ]DQ=QdE8CI>
g4kMC]a>oDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mAWoo00<007ooOol01Woo00<007ooOol00Goo001=Ool0
0`00Oomoo`0XOol2DO@4Ool3B[`3A[d01eifGYMNMUif=S/j>dJl009:_005A[e2_DJmFSEJEP03FSD0
1000B[a:_4Zl0T[L00=>gDkLM]400gJa00=fdG:aAY`00TJL0dkL01Y>gD[LC]e:g4Jm@[eAm57CDOAA
dd9l@W]2O49kC_a>g4kmC]aBo4klD_e>g4kmC]aBoD[L0T[M00M>gF[EK]E^eB4f8ADQ=P04C]`00e;l
D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m04Uoo`03001oogoo00Moo`40005oo`5oo`00CWoo00<007ooOol09goo00=Am57C
Ool017oo0916_4[MA[a6_D:lHYMNMUjGGWHj>cHJ>S]:_4kMB[a>gD:lA]eF=EYFESEJESiK?Ua:g4kM
B]a>gDZlC]e:g7KBL[5fdW:aM]8034JL@Y]6W4kLC_e>g4kmB]a>gD[LA[e2_57dDM=Am4gCC]e:_4kM
B[aBoDkLD_e>g5;mC]aBoDkLD_e>g4km>Ya^eV[EK]IZeFkF7ADQ=QdED_e>g5;mC]aBoDkLD_e>g5;m
D_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_e=Ool0
0`00Oomoo`06Ool10001Ool1Ool004moo`8002Moo`03DM=oogoo00Eoo`03B[a:gD[L0081NP9NMP0:
GYMNMSXk=S/j>d[LB]e:g4[M@[d2FSD00eYFFSDnF`02?U/01D[LC]a:g4kMB]`00T[M00AfdG:aM[5f
/@80309:g00BC]a:g4kLC]a>gD[LC]e6_E7dDM=Am57DDO@00DkLB]a>g4[L0Tkl00YBoDkLC_a>o5;m
C]a>gDkLC_eZe@9^e@03K]HQ5B4f009:_005A[a:_4kLD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;lDWoo00<007ooOol01Goo0@000Goo0Goo001A
Ool00`00Oomoo`0TOol00e7dOomoo`06Ool08TJlB]e:_5jGGWIRUeifBbe734[MA[a:_DZlC]e:_4A0
ESEJEUHeFUIF=Cil?U/nG4[LC_e:g4kM?YafdW:aM]9b/GKB0`0<069>oDkLC]e:g4kmC]a>oD:lA]e2
_57dCM=Am00100800E;mC]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>gF[EK]IZeFkF7ADQ=TkLC]e>
g4kmC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lEGoo
00<007ooOol01Goo0@000Goo0Goo001BOol00`00Oomoo`0]Ool2A[d01eifGYMNMTL]Aba7;DL/00=:
_004B]a:gD[LA[d3FSD20002B[`01T[LB[a>gDkLC]eb/@9f/@03M]5b/@0<0096W00A@Ya>g4kLC]e>
g4kMC]a>gD:mA[eAe57dDM=Am49k@Wa2N`02C]`02TkMC]aBo4klD_e>g4kmC]aBoDkL0T[M00M>gF[E
K]E^eB4f8ADQ=P04C]`00e;lD_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_aIOol00`00Oomoo`04Ool10001Ool1Ool005=oo`03001oogoo02eoo`0B@[a6gEifGYMNMV:G=QXj
>cHJC]e:_4kM@[a6gEHeFUIF=EYF0`0006Y>gD[LC]e:g4kMB]a:gG:aM]9b/GKB00`03D:KAYa2Ndkm
C]a>oDkLC]e:g4Jm@[aAm57CDOA=de7d@W]6W49kD_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkL?YdjWFkF
J]E^eQdE8CHM5B4fC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5eo
o`03001oogoo00=oo`40005oo`5oo`00E7oo00<007ooOol0;Goo00e6_EifGWINUeif>S/f>cXk=QY:
gD[LB]e2_@02FSD00eYFFSEJ=@03?U/014kLB]a>gD[L0d[M00=b/GJaM[400`0<00=:g4kLB]`00TkL
019>gDkLC]e:g4JmDM=Am57DDOAAd`02B]a>g4ZlC_a>g4kmC]`2C_`01U;mC]a>gDkLC_e>g09^e@03
K]IZeB4f009:_005A[a:_4kLD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l069oo`03
001oogoo00=oo`40005oo`00EGoo0P00;Woo01iNMV:GGWINUeifB]e6_4ZmA[a>gDZlB]e2_5YF001J
EUHe?W`nFciLB]a>oD[LC]e:g7KBL[5fdW:aM]8300`0EDkMB[a>gD[LC_e>g4kmB]a6gD:lDOA=de7d
DM<00P01D_e>g4kmC]aBoDkLD_e>g5;mC]aBoD[LC]e:g4kMB]a^eV[EK]HM5B4fAYa:_4JKD_e>g5;m
C]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m06Eoo`03001oogoo00=oo`40005oo`00Egoo00<007ooOol0
:goo00ANUeifGWINMP8000=:_004B]a:gD[LA[d3FSD015YF001:_4Zl0T[L00A>gDkLC]eb/@9f/@03
M]9b/GJa0096W00A@Ya>g4kLC]e>g4kMC]a>gD:mA[eAe57dDM=Am49k@Wa2N`02C]`02TkMC]aBo4kl
D_e>g4kmC]aBoDkL0T[M00M>gF[EK]EZeFkF8CDQ=P04C]`00e;lD_e>g002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lD_`0
JGoo00<007ooOol00Woo0@000Goo001HOol00`00Oomoo`0[Ool03ejGGWIoocHJ>S]:_4kMB[a>gD:l
A]eF=EYFESEJEP030000GD[MB[a:gDZlC]e:g4[ML[5fdW:aM]9b/DJL@Y]6W49kC_e>g4kmC]a>gD[L
A[e2_57dDM=Am4gCDOA2NdJL@W]BoDkLD_e>g5;mC]aBoDkLD_e>g4kmC]`nWCZMK]IZeFkFJ]DQ=QdE
8CI>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBo@1]Ool01@00Oomoogoo00000Goo001IOol00`00Oomoo`0ZOol0
3UifOomoocXk=S/j>d[LB]e:g4[M@[e6_EXeFUH2FSD3?U/014kLB]a>gD[L0T[M00IfdW:aM[5f/GKB
00`2B]`02TkLB]a>g4kLC]e>g4kMB]a6_D:m0e7d00UAd`02B]a>g4ZlC_a>g4kmC]`00Tkl00]BoDkL
C]e>g4kmC]a^eF[EK]IZeB4f00A:_006C]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lMGoo00@007ooOol0005oo`00FWoo0P00;Woo064j>cHJ
>S]:_4kMB[a:gD:lFUIF=EYFESDnO3iK?U`nFdkMB]a>gDZlC]e:g7KBL[5fdW:a00d034kMB[a>gDZl
C_e>g4kmB]a6gD:lA[e=de7dDM=Am00200=:_4kMB[aBoDkLD_e>g5;mC]aBoDkLC]e:g4kMB]a^eV[E
K]HQ5AP6AYa:_4JKD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7@1hOol01000Oomoo`000Goo001LOol00`00Oomoo`0/Ool3B[`01DJlB]e:g4[M@[d0
0UXe00YJEUXeB[a:_4[LB[a>gDkLC]e:g09f/@03M]9b/GJa00<0309>g006C]e>g4kMC]a>gDkL0TJm
00UAm57CDOA2Nd9l@W]2O4kLC]d00TkL00M>o5;mC]a>oDkLD_e>g002B]d01TkMJ]E^eF[E8CHQ=@A>
g09Bo005D_e>g5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo7aoo`03001o
o`00005oo`00GGoo00<007ooOol0;7oo05U>gDZlC]e:_4KM@[aJEUHeFUIF=EYF001:gDZlB]e:_4kM
B]a:gDZlM]9b/GKBL[403D:KAYa2NdJLC]a>gD[LC]e:g4kM@[a6gE7CDOAAde7d@W]6W49kD_e>g5;m
C]aBoDkLD_e>g5;mC]aBoD[LC]e:g4kMJ]E^eV[E8CHQ5B4fC]a>gDkLD_e>g5;mC]aBoE;lD_e>g5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<M081oo`40005oo`400000GWoo00<007ooOol0;7oo00A:gD[L
B]e:g096_@04FUIJ=EXeFSD2?U/014kLB]a>gD[L0d[M00Ab/GJaM[5fdP803006B]a>g4[LB]a>g4kM
0TkL00=:g4kM@[d00e7d00UAddkLB]a>g4ZlC_a>g4kmC]`00Tkl00]BoDkLC]e>g4kmC]a^eF[EK]IZ
eFkE00A:_006C]aBoDkLC_aBo5;m0e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Aoo`800000Ggoo
0P00;Goo051>gDZlB]e:_4KMESEJEUHeFUHnFciL?U/nO4[LC]e:g4kMB]a:gG:aM]9b/@0=00`03DZl
C]e:_4kmC]a>oD[LC_e2_4JmDM=Am57CDO@00P03B[a>gDZlD_e>g5;mC]aBoDkLD_e>g4kMB]a>gD[L
K]IZeFkFJ]DQ=TJLB[a6VdZlC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lR7oo0P00001QOol0
0`00Oomoo`0[Ool014[MB]a:gD[L0UXe00EJEUXeFSE:_4[L009:_00;C]a>gD[L@[ef/GKBL[5f/@0<
00d03002C]`01TkMC]a>gDkLC]e>g096_@09DOAAde7dDOA2O49k@Wa>g4kM009>g007C_aBoDkLC_e>
g5;mC]`00T[M00M>gF[EK]EZeFkF8CDQ=P04C]`00e;lD_e>g002D_`01U;mD_aBo5;lD_eBo8]oo`80
0000HWoo00<007ooOol0:goo04Q6gD:lA[e2_5YFESEJEUHe001:_4[MB[a:gD[LC]e:g7KBL[5fdW:a
M]92VdJL@W]>oDkLC]e:g4kMB]a>gD:lA]eAde7dDM=Am49kAYa2NdJLC]aBoDkLD_e>g5;mC]aBoDkL
D_e>g4kMB]a>gF[EK]IZeB4f8ADQ=TkLC]e>g5;mC]aBoDkLD_eBo5;mC]b:Ool40002Ool006=oo`03
001oogoo02aoo`96_@=J=@<nF`04B]a>gD[LC]`2B]d01T[LM[5b/GKBL[403@96W009@Ya>g4kLC]e>
g4kMB]a>gD:m00=Am005DM=Am4[LC]a:_002C]`03dkmC]a>o4klD_e>g4klC]a>oDkL?YeZeFkFJ]E^
e@04B[`01dkLD_e>g4klD_aBoE;l08Uoo`@000Ioo`00I7oo0P00;Goo03I2_5YFESEJEUHe?U`nFcil
B]a>gD[LC]e:g4[ML[5fdW:aM]80300=B[a>gDZlC]e>g4kmC]a6gD:lA[e2_57dDM=Am57C00=:_4kM
B[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmJ]E^eV[EK]H2Ool014JLB[a6VdZlRgoo10002Woo001VOol0
0`00Oomoo`0[Ool01UXeFUIJ=EXeB[a:g09:_00>C]a>gD[L@[eb/GKBL[5f/W:a00d0300=C]a>g@=>
g003C]e>g4kM0096_@08DM=Am57d@Wa2Nd9lC]a>g@9>g007C_aBoDkLC_e>g5;mC]`00T[M00=>gF[E
K]D0SWoo10003Woo001WOol00`00Oomoo`0ZOol0<dKMESEJEUHe001:_4[MB[a:gD[LC]e:g7KBL[5f
dW:aM]9b/DJL@W]6W4kLC]e:g4kmB]a>gD[LA]e2_57dDM=Am57CAYa2NdJLC]a>oDkLD_e>g5;mC]aB
oDkLD_e>g4kMB]a>g@2<Ool3000BOol006Qoo`03001oogoo02Uoo`=J=@07OolnFciKB]a>gD[LC]`0
0T[M00a:g7JbL[5fdW:aM[803DJL@Ya6W4kLC]d2C]`014[LC]e:g4Jm0U7d00EAde7dB]a>g4Zl009>
g00;C_e>g4klC_aBoDkLC_a>g4kmC]`nW@29Ool4000EOol006Uoo`8002Yoo`0aESEJEWoo?U`nFcil
?U]>gD[LC]e:g4[MB[afdW:aM]9b/@0=00a>gDZlC]e>g4kmC]a>gD[LC]e2_57dDM=Am57C00=:_4kM
B[a>gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]`0QGoo10006Goo001[Ool00`00Oomoo`0WOol01EYFOomo
ogooB]`00dZl00e>gD[LC]dn_GKBL[5f/W:aM]80300=C]a>g@03C]`00dkMC]a>g@02A[d0257CDOAA
m57d@W]2O4kLC]d2C]`014klD_e>g4klQgoo10007Goo001/Ool00`00Oomoo`0VOol00eHeOomoo`02
Ool08d[MB[a:gDZlC]e:g4kmL[5fdW:aM]9b/@0=@W]6W4kLC]e:g4kmB]a>gD[LA]eAde7dDM=Am57C
AYa2NdJL@W]>oDkLD_d0QWoo10008Goo001]Ool00`00Oomoo`0[Ool034kMB]a>g4[LB]e:g4[ML[5f
dW:aM[803@=6W008C]a>gDkLC]a:g4kMB]a6_@9Am003DO=Am57d08Uoo`<002Eoo`00KWoo00<007oo
Ool0;7oo01Y:g4kMB]a:gDZlC]eb/GKBL[403@0<C]e:_4kMB[a>oDkLC_e:g4kM@[a6gE7CDOAAde7d
QGoo1000:7oo001_Ool2000]Ool024[LC]e>g7KBL[5f/W:bM]8300d02TkMC]a>g4kLC]e>g4kMC]a6
_E7c0e7dPWoo1000;7oo001aOol00`00Oomoo`0ZOol01dkMB]a>oG:aM]9b/GKB009oo`07@W]6W4:K
C]e:g4kmC]`00goo00E2_57dDM=Am57C07ioo`@0031oo`00LWoo00<007ooOol0:Woo00E:gD[LB]eb
/WKB00Aoo`=6W0Ioo`03A[eAm57d009Am7Yoo`@003Aoo`00Lgoo00<007ooOol0:Woo00=:gDZlC]d0
3goo00=6gE7CDO@0Mgoo1000>7oo001dOol2000[Ool00d:m001oo`0>Ool00d:mDOAAm01dOol3000l
Ool007Ioo`03001oogoo02Uoo`03001oogoo00eoo`03A[eAdgoo071oo`@003moo`00Mgoo00<007oo
Ool0:7oo00<007ooOol03Goo00=2_E7dOol0K7oo1000@goo001hOol00`00Oomoo`0WOol00`00Oomo
o`0>Ool00e7COomoo`1WOol40017Ool007Uoo`8002Moo`03001oogoo07Aoo`@004]oo`00Ngoo00<0
07ooOol097oo00<007ooOol0LGoo0`00Cgoo001lOol00`00Oomoo`0SOol00`00Oomoo`1]Ool4001B
Ool007eoo`03001oogoo029oo`03001oogoo06Uoo`@005Ioo`00OWoo0P008Woo00<007ooOol0IGoo
1000FWoo0020Ool00`00Oomoo`0OOol00`00Oomoo`1QOol4001NOol0085oo`03001oogoo01ioo`03
001oogoo05ioo`<0069oo`00PWoo00<007ooOol07Goo00<007ooOol0FWoo1000IGoo0023Ool00`00
Oomoo`0LOol00`00Oomoo`1FOol4001YOol008Aoo`8001aoo`03001oogoo059oo`@006eoo`00QWoo
00<007ooOol06Goo00<007ooOol0CWoo1000LGoo0027Ool00`00Oomoo`0HOol00`00Oomoo`1;Ool3
001eOol008Qoo`03001oogoo01Moo`03001oogoo04Moo`@007Qoo`00RGoo0P005goo00<007ooOol0
@goo1000O7oo002;Ool00`00Oomoo`0DOol00`00Oomoo`0oOol40020Ool008aoo`03001oogoo019o
o`03001oogoo03aoo`@008Aoo`00SGoo00<007ooOol04Goo00<007ooOol0>Goo0`00R7oo002>Ool2
000AOol00`00Oomoo`0eOol4002;Ool0091oo`03001oogoo00ioo`03001oogoo035oo`@008moo`00
TGoo00<007ooOol03Goo00<007ooOol0;Goo1000Tgoo002BOol00`00Oomoo`0<Ool00`00Oomoo`0Y
Ool4002GOol009=oo`8000aoo`03001oogoo02Eoo`@009]oo`00UGoo00<007ooOol02Goo00<007oo
Ool08Woo0`00Wgoo002FOol00`00Oomoo`08Ool00`00Oomoo`0NOol4002ROol009Moo`03001oogoo
00Moo`03001oogoo01Yoo`@00:Ioo`00V7oo00<007ooOol01Woo00<007ooOol05Woo1000ZWoo002I
Ool20006Ool00`00Oomoo`0BOol4002^Ool009]oo`03001oogoo00=oo`03001oogoo00moo`<00;9o
o`00W7oo00<007ooOol00Woo00<007ooOol02goo1000]Goo002MOol01@00Oomoogoo00002Goo1000
^Goo002NOol200000goo001oo`04Ool4002mOol00:1oo`800003Ool0000000800<5oo`00XGoo0P00
aGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02494 .25992 -24 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-100)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(50)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(100)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.616 .722 .922 r
.39636 .69716 .40168 .70226 .41057 .70081 .40527 .69553 Mtetra
.565 .699 .931 r
.40527 .69553 .41057 .70081 .41923 .70794 .41419 .69486 Mtetra
.735 .61 .718 r
.41419 .69486 .41923 .70794 .42859 .69288 .4234 .68521 Mtetra
.497 .587 .875 r
.4234 .68521 .42859 .69288 .43756 .69167 .43232 .68648 Mtetra
.62 .722 .919 r
.43232 .68648 .43756 .69167 .44659 .68979 .44136 .68474 Mtetra
.626 .73 .922 r
.44136 .68474 .44659 .68979 .45564 .68811 .45044 .68285 Mtetra
.584 .709 .929 r
.45044 .68285 .45564 .68811 .46465 .69161 .45953 .68182 Mtetra
.777 .663 .738 r
.45953 .68182 .46465 .69161 .47393 .6798 .46883 .67089 Mtetra
.458 .535 .849 r
.46883 .67089 .47393 .6798 .48308 .6786 .47793 .67336 Mtetra
.625 .724 .918 r
.47793 .67336 .48308 .6786 .49226 .67652 .48713 .67149 Mtetra
.639 .738 .92 r
.48713 .67149 .49226 .67652 .50149 .67428 .49637 .66928 Mtetra
.64 .74 .921 r
.49637 .66928 .50149 .67428 .51074 .67209 .50565 .66702 Mtetra
.632 .735 .922 r
.50565 .66702 .51074 .67209 .52003 .67035 .51496 .66494 Mtetra
.56 .697 .932 r
.51496 .66494 .52003 .67035 .52939 .69486 .5243 .66432 Mtetra
.661 .496 .65 r
.5243 .66432 .52939 .69486 .5387 .66184 .53367 .6549 Mtetra
.549 .637 .891 r
.53367 .6549 .5387 .66184 .54809 .66014 .54307 .65492 Mtetra
.636 .733 .918 r
.54307 .65492 .54809 .66014 .5575 .65779 .55251 .65275 Mtetra
.648 .744 .92 r
.55251 .65275 .5575 .65779 .56695 .65525 .56198 .65026 Mtetra
.653 .749 .92 r
.56198 .65026 .56695 .65525 .57643 .65262 .57148 .64765 Mtetra
.655 .751 .92 r
.57148 .64765 .57643 .65262 .58595 .64992 .58102 .64496 Mtetra
.657 .752 .92 r
.58102 .64496 .58595 .64992 .59549 .64718 .59058 .64222 Mtetra
.658 .753 .92 r
.59058 .64222 .59549 .64718 .60506 .64441 .60018 .63944 Mtetra
.659 .754 .92 r
.60018 .63944 .60506 .64441 .61467 .64162 .60981 .63663 Mtetra
.60981 .63663 .61467 .64162 .62431 .63883 .61948 .63382 Mtetra
.61948 .63382 .62431 .63883 .63399 .63603 .62917 .631 Mtetra
.62917 .631 .63399 .63603 .6437 .63322 .6389 .62817 Mtetra
.658 .753 .92 r
.6389 .62817 .6437 .63322 .65344 .63042 .64867 .62535 Mtetra
.64867 .62535 .65344 .63042 .66321 .6276 .65847 .62251 Mtetra
.65847 .62251 .66321 .6276 .67302 .62479 .6683 .61968 Mtetra
.6683 .61968 .67302 .62479 .68286 .62196 .67816 .61683 Mtetra
.67816 .61683 .68286 .62196 .69274 .61913 .68806 .61398 Mtetra
.68806 .61398 .69274 .61913 .70265 .61629 .698 .61113 Mtetra
.657 .753 .92 r
.698 .61113 .70265 .61629 .7126 .61345 .70797 .60826 Mtetra
.70797 .60826 .7126 .61345 .72258 .61059 .71797 .60539 Mtetra
.71797 .60539 .72258 .61059 .73259 .60773 .72801 .6025 Mtetra
.72801 .6025 .73259 .60773 .74264 .60486 .73809 .59961 Mtetra
.73809 .59961 .74264 .60486 .75273 .60198 .7482 .59671 Mtetra
.657 .752 .92 r
.7482 .59671 .75273 .60198 .76285 .59909 .75835 .5938 Mtetra
.75835 .5938 .76285 .59909 .77301 .59619 .76853 .59088 Mtetra
.76853 .59088 .77301 .59619 .7832 .59328 .77875 .58796 Mtetra
.77875 .58796 .7832 .59328 .79343 .59036 .789 .58502 Mtetra
.789 .58502 .79343 .59036 .80369 .58743 .79929 .58207 Mtetra
.79929 .58207 .80369 .58743 .814 .58449 .80962 .57911 Mtetra
.80962 .57911 .814 .58449 .82434 .58155 .81999 .57615 Mtetra
.81999 .57615 .82434 .58155 .83471 .57859 .83039 .57317 Mtetra
.83039 .57317 .83471 .57859 .84512 .57562 .84083 .57018 Mtetra
.84083 .57018 .84512 .57562 .85557 .57264 .85131 .56719 Mtetra
.85131 .56719 .85557 .57264 .86606 .56966 .86182 .56418 Mtetra
.86182 .56418 .86606 .56966 .87659 .56666 .87237 .56116 Mtetra
.87237 .56116 .87659 .56666 .88715 .56365 .88296 .55813 Mtetra
.88296 .55813 .88715 .56365 .89775 .56063 .89359 .55509 Mtetra
.89359 .55509 .89775 .56063 .90839 .5576 .90426 .55204 Mtetra
.90426 .55204 .90839 .5576 .91907 .55457 .91497 .54898 Mtetra
.91497 .54898 .91907 .55457 .92978 .55151 .92571 .54591 Mtetra
.92571 .54591 .92978 .55151 .94054 .54845 .9365 .54283 Mtetra
.9365 .54283 .94054 .54845 .95133 .54538 .94732 .53974 Mtetra
.94732 .53974 .95133 .54538 .96217 .5423 .95818 .53664 Mtetra
.95818 .53664 .96217 .5423 .97304 .53921 .96909 .53352 Mtetra
.96909 .53352 .97304 .53921 .98395 .5361 .98003 .5304 Mtetra
.61 .715 .919 r
.39103 .69189 .39636 .69716 .40527 .69553 .39995 .69039 Mtetra
.607 .72 .924 r
.39995 .69039 .40527 .69553 .41419 .69486 .4089 .6889 Mtetra
0 .202 .713 r
.4089 .6889 .41419 .69486 .4234 .68521 .41763 .69604 Mtetra
0 0 0 r
.41763 .69604 .4234 .68521 .43232 .68648 .42706 .68088 Mtetra
.599 .7 .915 r
.42706 .68088 .43232 .68648 .44136 .68474 .4361 .67963 Mtetra
.627 .729 .921 r
.4361 .67963 .44136 .68474 .45044 .68285 .4452 .67772 Mtetra
.617 .726 .924 r
.4452 .67772 .45044 .68285 .45953 .68182 .45432 .676 Mtetra
.237 .521 .914 r
.45432 .676 .45953 .68182 .46883 .67089 .46339 .67949 Mtetra
0 0 0 r
.46339 .67949 .46883 .67089 .47793 .67336 .47275 .66759 Mtetra
.598 .697 .912 r
.47275 .66759 .47793 .67336 .48713 .67149 .48197 .66636 Mtetra
.634 .734 .92 r
.48197 .66636 .48713 .67149 .49637 .66928 .49123 .66424 Mtetra
.64 .74 .921 r
.49123 .66424 .49637 .66928 .50565 .66702 .50052 .66196 Mtetra
.638 .739 .921 r
.50052 .66196 .50565 .66702 .51496 .66494 .50985 .65973 Mtetra
.617 .727 .924 r
.50985 .65973 .51496 .66494 .5243 .66432 .51921 .65795 Mtetra
.906 .502 .114 r
.51921 .65795 .5243 .66432 .53367 .6549 .52864 .68254 Mtetra
0 0 .166 r
.52864 .68254 .53367 .6549 .54307 .65492 .53803 .64934 Mtetra
.617 .714 .915 r
.53803 .64934 .54307 .65492 .55251 .65275 .54749 .64761 Mtetra
.644 .74 .919 r
.54749 .64761 .55251 .65275 .56198 .65026 .55698 .64521 Mtetra
.651 .747 .92 r
.55698 .64521 .56198 .65026 .57148 .64765 .5665 .64263 Mtetra
.654 .75 .92 r
.5665 .64263 .57148 .64765 .58102 .64496 .57606 .63995 Mtetra
.656 .752 .92 r
.57606 .63995 .58102 .64496 .59058 .64222 .58565 .63721 Mtetra
.658 .753 .92 r
.58565 .63721 .59058 .64222 .60018 .63944 .59527 .63443 Mtetra
.659 .754 .92 r
.59527 .63443 .60018 .63944 .60981 .63663 .60492 .63161 Mtetra
.60492 .63161 .60981 .63663 .61948 .63382 .61461 .62878 Mtetra
.61461 .62878 .61948 .63382 .62917 .631 .62433 .62594 Mtetra
.62433 .62594 .62917 .631 .6389 .62817 .63408 .6231 Mtetra
.658 .754 .92 r
.63408 .6231 .6389 .62817 .64867 .62535 .64387 .62025 Mtetra
.658 .753 .92 r
.64387 .62025 .64867 .62535 .65847 .62251 .65369 .61739 Mtetra
.65369 .61739 .65847 .62251 .6683 .61968 .66355 .61454 Mtetra
.66355 .61454 .6683 .61968 .67816 .61683 .67343 .61167 Mtetra
.67343 .61167 .67816 .61683 .68806 .61398 .68336 .6088 Mtetra
.68336 .6088 .68806 .61398 .698 .61113 .69332 .60593 Mtetra
.657 .753 .92 r
.69332 .60593 .698 .61113 .70797 .60826 .70331 .60304 Mtetra
.70331 .60304 .70797 .60826 .71797 .60539 .71334 .60015 Mtetra
.71334 .60015 .71797 .60539 .72801 .6025 .72341 .59725 Mtetra
.72341 .59725 .72801 .6025 .73809 .59961 .73351 .59434 Mtetra
.73351 .59434 .73809 .59961 .7482 .59671 .74364 .59142 Mtetra
.657 .752 .92 r
.74364 .59142 .7482 .59671 .75835 .5938 .75382 .58849 Mtetra
.75382 .58849 .75835 .5938 .76853 .59088 .76402 .58555 Mtetra
.76402 .58555 .76853 .59088 .77875 .58796 .77427 .5826 Mtetra
.77427 .5826 .77875 .58796 .789 .58502 .78455 .57964 Mtetra
.78455 .57964 .789 .58502 .79929 .58207 .79487 .57668 Mtetra
.79487 .57668 .79929 .58207 .80962 .57911 .80522 .5737 Mtetra
.80522 .5737 .80962 .57911 .81999 .57615 .81561 .57071 Mtetra
.81561 .57071 .81999 .57615 .83039 .57317 .82604 .56772 Mtetra
.82604 .56772 .83039 .57317 .84083 .57018 .83651 .56471 Mtetra
.83651 .56471 .84083 .57018 .85131 .56719 .84701 .56169 Mtetra
.84701 .56169 .85131 .56719 .86182 .56418 .85755 .55866 Mtetra
.85755 .55866 .86182 .56418 .87237 .56116 .86813 .55563 Mtetra
.86813 .55563 .87237 .56116 .88296 .55813 .87875 .55258 Mtetra
.87875 .55258 .88296 .55813 .89359 .55509 .88941 .54952 Mtetra
.88941 .54952 .89359 .55509 .90426 .55204 .90011 .54645 Mtetra
.90011 .54645 .90426 .55204 .91497 .54898 .91084 .54337 Mtetra
.91084 .54337 .91497 .54898 .92571 .54591 .92161 .54028 Mtetra
.92161 .54028 .92571 .54591 .9365 .54283 .93243 .53717 Mtetra
.93243 .53717 .9365 .54283 .94732 .53974 .94328 .53406 Mtetra
.94328 .53406 .94732 .53974 .95818 .53664 .95417 .53094 Mtetra
.95417 .53094 .95818 .53664 .96909 .53352 .96511 .5278 Mtetra
.96511 .5278 .96909 .53352 .98003 .5304 .97608 .52465 Mtetra
.58 .684 .912 r
.38568 .68603 .39103 .69189 .39995 .69039 .39459 .68521 Mtetra
.616 .722 .922 r
.39459 .68521 .39995 .69039 .4089 .6889 .40356 .68355 Mtetra
.565 .699 .931 r
.40356 .68355 .4089 .6889 .41763 .69604 .41254 .68284 Mtetra
.736 .61 .718 r
.41254 .68284 .41763 .69604 .42706 .68088 .42183 .67312 Mtetra
.496 .587 .875 r
.42183 .67312 .42706 .68088 .4361 .67963 .43082 .67437 Mtetra
.62 .722 .919 r
.43082 .67437 .4361 .67963 .4452 .67772 .43992 .67259 Mtetra
.626 .73 .922 r
.43992 .67259 .4452 .67772 .45432 .676 .44907 .67066 Mtetra
.584 .709 .929 r
.44907 .67066 .45432 .676 .46339 .67949 .45824 .66959 Mtetra
.777 .663 .738 r
.45824 .66959 .46339 .67949 .47275 .66759 .4676 .65859 Mtetra
.457 .535 .849 r
.4676 .65859 .47275 .66759 .48197 .66636 .47677 .66104 Mtetra
.625 .724 .918 r
.47677 .66104 .48197 .66636 .49123 .66424 .48605 .65913 Mtetra
.639 .738 .92 r
.48605 .65913 .49123 .66424 .50052 .66196 .49536 .65688 Mtetra
.64 .74 .921 r
.49536 .65688 .50052 .66196 .50985 .65973 .50471 .65458 Mtetra
.632 .735 .922 r
.50471 .65458 .50985 .65973 .51921 .65795 .51409 .65246 Mtetra
.56 .697 .932 r
.51409 .65246 .51921 .65795 .52864 .68254 .52351 .65181 Mtetra
.661 .495 .65 r
.52351 .65181 .52864 .68254 .53803 .64934 .53295 .64231 Mtetra
.549 .637 .891 r
.53295 .64231 .53803 .64934 .54749 .64761 .54243 .64231 Mtetra
.636 .733 .918 r
.54243 .64231 .54749 .64761 .55698 .64521 .55195 .64009 Mtetra
.648 .744 .92 r
.55195 .64009 .55698 .64521 .5665 .64263 .56149 .63756 Mtetra
.653 .749 .92 r
.56149 .63756 .5665 .64263 .57606 .63995 .57107 .6349 Mtetra
.655 .751 .92 r
.57107 .6349 .57606 .63995 .58565 .63721 .58068 .63217 Mtetra
.657 .752 .92 r
.58068 .63217 .58565 .63721 .59527 .63443 .59032 .62938 Mtetra
.658 .753 .92 r
.59032 .62938 .59527 .63443 .60492 .63161 .6 .62656 Mtetra
.659 .754 .92 r
.6 .62656 .60492 .63161 .61461 .62878 .60971 .62371 Mtetra
.60971 .62371 .61461 .62878 .62433 .62594 .61945 .62085 Mtetra
.61945 .62085 .62433 .62594 .63408 .6231 .62923 .61799 Mtetra
.62923 .61799 .63408 .6231 .64387 .62025 .63904 .61511 Mtetra
.658 .753 .92 r
.63904 .61511 .64387 .62025 .65369 .61739 .64888 .61224 Mtetra
.64888 .61224 .65369 .61739 .66355 .61454 .65876 .60936 Mtetra
.65876 .60936 .66355 .61454 .67343 .61167 .66868 .60648 Mtetra
.66868 .60648 .67343 .61167 .68336 .6088 .67862 .60359 Mtetra
.67862 .60359 .68336 .6088 .69332 .60593 .68861 .60069 Mtetra
.68861 .60069 .69332 .60593 .70331 .60304 .69863 .59779 Mtetra
.657 .753 .92 r
.69863 .59779 .70331 .60304 .71334 .60015 .70868 .59488 Mtetra
.70868 .59488 .71334 .60015 .72341 .59725 .71877 .59195 Mtetra
.71877 .59195 .72341 .59725 .73351 .59434 .72889 .58902 Mtetra
.72889 .58902 .73351 .59434 .74364 .59142 .73906 .58608 Mtetra
.73906 .58608 .74364 .59142 .75382 .58849 .74925 .58314 Mtetra
.657 .752 .92 r
.74925 .58314 .75382 .58849 .76402 .58555 .75949 .58018 Mtetra
.75949 .58018 .76402 .58555 .77427 .5826 .76976 .57721 Mtetra
.76976 .57721 .77427 .5826 .78455 .57964 .78006 .57423 Mtetra
.78006 .57423 .78455 .57964 .79487 .57668 .79041 .57125 Mtetra
.79041 .57125 .79487 .57668 .80522 .5737 .80079 .56825 Mtetra
.80079 .56825 .80522 .5737 .81561 .57071 .81121 .56524 Mtetra
.81121 .56524 .81561 .57071 .82604 .56772 .82166 .56222 Mtetra
.82166 .56222 .82604 .56772 .83651 .56471 .83216 .5592 Mtetra
.83216 .5592 .83651 .56471 .84701 .56169 .84269 .55616 Mtetra
.84269 .55616 .84701 .56169 .85755 .55866 .85326 .55311 Mtetra
.85326 .55311 .85755 .55866 .86813 .55563 .86387 .55005 Mtetra
.86387 .55005 .86813 .55563 .87875 .55258 .87451 .54698 Mtetra
.87451 .54698 .87875 .55258 .88941 .54952 .8852 .5439 Mtetra
.8852 .5439 .88941 .54952 .90011 .54645 .89592 .54081 Mtetra
.89592 .54081 .90011 .54645 .91084 .54337 .90668 .53771 Mtetra
.90668 .53771 .91084 .54337 .92161 .54028 .91749 .5346 Mtetra
.91749 .5346 .92161 .54028 .93243 .53717 .92833 .53148 Mtetra
.92833 .53148 .93243 .53717 .94328 .53406 .93921 .52834 Mtetra
.93921 .52834 .94328 .53406 .95417 .53094 .95014 .52519 Mtetra
.95014 .52519 .95417 .53094 .96511 .5278 .9611 .52204 Mtetra
.9611 .52204 .96511 .5278 .97608 .52465 .9721 .51887 Mtetra
.376 .452 .811 r
.3805 .67537 .38568 .68603 .39459 .68521 .3892 .67986 Mtetra
.61 .715 .92 r
.3892 .67986 .39459 .68521 .40356 .68355 .39819 .67832 Mtetra
.608 .72 .924 r
.39819 .67832 .40356 .68355 .41254 .68284 .40721 .6768 Mtetra
0 .207 .717 r
.40721 .6768 .41254 .68284 .42183 .67312 .416 .68394 Mtetra
0 0 0 r
.416 .68394 .42183 .67312 .43082 .67437 .42551 .66868 Mtetra
.599 .7 .915 r
.42551 .66868 .43082 .67437 .43992 .67259 .43462 .6674 Mtetra
.627 .729 .921 r
.43462 .6674 .43992 .67259 .44907 .67066 .44378 .66545 Mtetra
.617 .726 .924 r
.44378 .66545 .44907 .67066 .45824 .66959 .45298 .66369 Mtetra
.24 .522 .914 r
.45298 .66369 .45824 .66959 .4676 .65859 .46212 .66717 Mtetra
0 0 0 r
.46212 .66717 .4676 .65859 .47677 .66104 .47155 .65519 Mtetra
.598 .697 .912 r
.47155 .65519 .47677 .66104 .48605 .65913 .48084 .65392 Mtetra
.634 .734 .92 r
.48084 .65392 .48605 .65913 .49536 .65688 .49017 .65176 Mtetra
.64 .74 .921 r
.49017 .65176 .49536 .65688 .50471 .65458 .49954 .64944 Mtetra
.638 .739 .921 r
.49954 .64944 .50471 .65458 .51409 .65246 .50894 .64717 Mtetra
.617 .727 .924 r
.50894 .64717 .51409 .65246 .52351 .65181 .51838 .64535 Mtetra
.904 .498 .106 r
.51838 .64535 .52351 .65181 .53295 .64231 .52787 .67002 Mtetra
0 0 .159 r
.52787 .67002 .53295 .64231 .54243 .64231 .53734 .63664 Mtetra
.617 .714 .915 r
.53734 .63664 .54243 .64231 .55195 .64009 .54688 .63487 Mtetra
.644 .74 .919 r
.54688 .63487 .55195 .64009 .56149 .63756 .55645 .63243 Mtetra
.651 .747 .92 r
.55645 .63243 .56149 .63756 .57107 .6349 .56605 .6298 Mtetra
.654 .75 .92 r
.56605 .6298 .57107 .6349 .58068 .63217 .57568 .62708 Mtetra
.656 .752 .92 r
.57568 .62708 .58068 .63217 .59032 .62938 .58535 .6243 Mtetra
.658 .753 .92 r
.58535 .6243 .59032 .62938 .6 .62656 .59505 .62147 Mtetra
.659 .754 .92 r
.59505 .62147 .6 .62656 .60971 .62371 .60478 .61861 Mtetra
.60478 .61861 .60971 .62371 .61945 .62085 .61454 .61573 Mtetra
.61454 .61573 .61945 .62085 .62923 .61799 .62434 .61284 Mtetra
.62434 .61284 .62923 .61799 .63904 .61511 .63418 .60995 Mtetra
.658 .754 .92 r
.63418 .60995 .63904 .61511 .64888 .61224 .64404 .60706 Mtetra
.658 .753 .92 r
.64404 .60706 .64888 .61224 .65876 .60936 .65395 .60416 Mtetra
.65395 .60416 .65876 .60936 .66868 .60648 .66388 .60125 Mtetra
.66388 .60125 .66868 .60648 .67862 .60359 .67386 .59834 Mtetra
.67386 .59834 .67862 .60359 .68861 .60069 .68386 .59543 Mtetra
.68386 .59543 .68861 .60069 .69863 .59779 .69391 .5925 Mtetra
.657 .753 .92 r
.69391 .5925 .69863 .59779 .70868 .59488 .70399 .58957 Mtetra
.70399 .58957 .70868 .59488 .71877 .59195 .7141 .58663 Mtetra
.7141 .58663 .71877 .59195 .72889 .58902 .72425 .58368 Mtetra
.72425 .58368 .72889 .58902 .73906 .58608 .73444 .58072 Mtetra
.73444 .58072 .73906 .58608 .74925 .58314 .74466 .57775 Mtetra
.657 .752 .92 r
.74466 .57775 .74925 .58314 .75949 .58018 .75492 .57477 Mtetra
.75492 .57477 .75949 .58018 .76976 .57721 .76522 .57178 Mtetra
.76522 .57178 .76976 .57721 .78006 .57423 .77555 .56879 Mtetra
.77555 .56879 .78006 .57423 .79041 .57125 .78592 .56578 Mtetra
.78592 .56578 .79041 .57125 .80079 .56825 .79633 .56276 Mtetra
.79633 .56276 .80079 .56825 .81121 .56524 .80677 .55973 Mtetra
.80677 .55973 .81121 .56524 .82166 .56222 .81725 .5567 Mtetra
.81725 .5567 .82166 .56222 .83216 .5592 .82778 .55365 Mtetra
.82778 .55365 .83216 .5592 .84269 .55616 .83833 .55059 Mtetra
.83833 .55059 .84269 .55616 .85326 .55311 .84893 .54752 Mtetra
.84893 .54752 .85326 .55311 .86387 .55005 .85957 .54444 Mtetra
.85957 .54444 .86387 .55005 .87451 .54698 .87024 .54135 Mtetra
.87024 .54135 .87451 .54698 .8852 .5439 .88096 .53825 Mtetra
.88096 .53825 .8852 .5439 .89592 .54081 .89171 .53514 Mtetra
.89171 .53514 .89592 .54081 .90668 .53771 .9025 .53202 Mtetra
.9025 .53202 .90668 .53771 .91749 .5346 .91333 .52888 Mtetra
.91333 .52888 .91749 .5346 .92833 .53148 .92421 .52574 Mtetra
.92421 .52574 .92833 .53148 .93921 .52834 .93512 .52258 Mtetra
.93512 .52258 .93921 .52834 .95014 .52519 .94607 .51942 Mtetra
.94607 .51942 .95014 .52519 .9611 .52204 .95706 .51624 Mtetra
.95706 .51624 .9611 .52204 .9721 .51887 .9681 .51305 Mtetra
0 0 0 r
.37446 .68426 .3805 .67537 .3892 .67986 .38381 .67393 Mtetra
.58 .684 .912 r
.38381 .67393 .3892 .67986 .39819 .67832 .39278 .67307 Mtetra
.616 .722 .922 r
.39278 .67307 .39819 .67832 .40721 .6768 .40183 .67137 Mtetra
.565 .699 .931 r
.40183 .67137 .40721 .6768 .416 .68394 .41087 .67063 Mtetra
.736 .611 .718 r
.41087 .67063 .416 .68394 .42551 .66868 .42023 .66084 Mtetra
.496 .587 .876 r
.42023 .66084 .42551 .66868 .43462 .6674 .42929 .66206 Mtetra
.62 .722 .919 r
.42929 .66206 .43462 .6674 .44378 .66545 .43846 .66024 Mtetra
.626 .73 .922 r
.43846 .66024 .44378 .66545 .45298 .66369 .44768 .65828 Mtetra
.584 .709 .929 r
.44768 .65828 .45298 .66369 .46212 .66717 .45692 .65718 Mtetra
.777 .664 .738 r
.45692 .65718 .46212 .66717 .47155 .65519 .46636 .64609 Mtetra
.457 .535 .849 r
.46636 .64609 .47155 .65519 .48084 .65392 .4756 .64852 Mtetra
.625 .724 .918 r
.4756 .64852 .48084 .65392 .49017 .65176 .48495 .64657 Mtetra
.639 .738 .92 r
.48495 .64657 .49017 .65176 .49954 .64944 .49434 .64428 Mtetra
.64 .74 .921 r
.49434 .64428 .49954 .64944 .50894 .64717 .50376 .64194 Mtetra
.632 .735 .922 r
.50376 .64194 .50894 .64717 .51838 .64535 .51321 .63978 Mtetra
.56 .697 .932 r
.51321 .63978 .51838 .64535 .52787 .67002 .52271 .63909 Mtetra
.66 .494 .649 r
.52271 .63909 .52787 .67002 .53734 .63664 .53222 .62952 Mtetra
.549 .637 .891 r
.53222 .62952 .53734 .63664 .54688 .63487 .54178 .62948 Mtetra
.636 .733 .918 r
.54178 .62948 .54688 .63487 .55645 .63243 .55137 .62722 Mtetra
.648 .744 .92 r
.55137 .62722 .55645 .63243 .56605 .6298 .56099 .62465 Mtetra
.653 .749 .92 r
.56099 .62465 .56605 .6298 .57568 .62708 .57065 .62195 Mtetra
.655 .751 .92 r
.57065 .62195 .57568 .62708 .58535 .6243 .58034 .61917 Mtetra
.657 .752 .92 r
.58034 .61917 .58535 .6243 .59505 .62147 .59006 .61634 Mtetra
.658 .753 .92 r
.59006 .61634 .59505 .62147 .60478 .61861 .59981 .61347 Mtetra
.659 .754 .92 r
.59981 .61347 .60478 .61861 .61454 .61573 .6096 .61058 Mtetra
.6096 .61058 .61454 .61573 .62434 .61284 .61943 .60767 Mtetra
.61943 .60767 .62434 .61284 .63418 .60995 .62928 .60476 Mtetra
.62928 .60476 .63418 .60995 .64404 .60706 .63917 .60184 Mtetra
.658 .753 .92 r
.63917 .60184 .64404 .60706 .65395 .60416 .6491 .59892 Mtetra
.6491 .59892 .65395 .60416 .66388 .60125 .65906 .59599 Mtetra
.65906 .59599 .66388 .60125 .67386 .59834 .66906 .59306 Mtetra
.66906 .59306 .67386 .59834 .68386 .59543 .67909 .59012 Mtetra
.67909 .59012 .68386 .59543 .69391 .5925 .68916 .58718 Mtetra
.68916 .58718 .69391 .5925 .70399 .58957 .69926 .58423 Mtetra
.657 .753 .92 r
.69926 .58423 .70399 .58957 .7141 .58663 .7094 .58127 Mtetra
.7094 .58127 .7141 .58663 .72425 .58368 .71958 .5783 Mtetra
.71958 .5783 .72425 .58368 .73444 .58072 .72979 .57532 Mtetra
.72979 .57532 .73444 .58072 .74466 .57775 .74004 .57233 Mtetra
.74004 .57233 .74466 .57775 .75492 .57477 .75032 .56933 Mtetra
.657 .752 .92 r
.75032 .56933 .75492 .57477 .76522 .57178 .76065 .56632 Mtetra
.76065 .56632 .76522 .57178 .77555 .56879 .771 .5633 Mtetra
.771 .5633 .77555 .56879 .78592 .56578 .7814 .56028 Mtetra
.7814 .56028 .78592 .56578 .79633 .56276 .79184 .55724 Mtetra
.79184 .55724 .79633 .56276 .80677 .55973 .80231 .55419 Mtetra
.80231 .55419 .80677 .55973 .81725 .5567 .81282 .55113 Mtetra
.81282 .55113 .81725 .5567 .82778 .55365 .82337 .54806 Mtetra
.82337 .54806 .82778 .55365 .83833 .55059 .83395 .54499 Mtetra
.83395 .54499 .83833 .55059 .84893 .54752 .84458 .5419 Mtetra
.84458 .5419 .84893 .54752 .85957 .54444 .85524 .53879 Mtetra
.85524 .53879 .85957 .54444 .87024 .54135 .86594 .53568 Mtetra
.86594 .53568 .87024 .54135 .88096 .53825 .87669 .53256 Mtetra
.87669 .53256 .88096 .53825 .89171 .53514 .88747 .52943 Mtetra
.88747 .52943 .89171 .53514 .9025 .53202 .89829 .52628 Mtetra
.89829 .52628 .9025 .53202 .91333 .52888 .90915 .52313 Mtetra
.90915 .52313 .91333 .52888 .92421 .52574 .92005 .51996 Mtetra
.92005 .51996 .92421 .52574 .93512 .52258 .93099 .51678 Mtetra
.93099 .51678 .93512 .52258 .94607 .51942 .94198 .5136 Mtetra
.94198 .5136 .94607 .51942 .95706 .51624 .953 .5104 Mtetra
.953 .5104 .95706 .51624 .9681 .51305 .96406 .50718 Mtetra
.803 .687 .737 r
.36912 .67571 .37446 .68426 .38381 .67393 .37858 .66317 Mtetra
.375 .451 .811 r
.37858 .66317 .38381 .67393 .39278 .67307 .38735 .66765 Mtetra
.61 .715 .92 r
.38735 .66765 .39278 .67307 .40183 .67137 .3964 .66607 Mtetra
.608 .72 .924 r
.3964 .66607 .40183 .67137 .41087 .67063 .40549 .66451 Mtetra
0 .211 .721 r
.40549 .66451 .41087 .67063 .42023 .66084 .41435 .67165 Mtetra
0 0 0 r
.41435 .67165 .42023 .66084 .42929 .66206 .42393 .6563 Mtetra
.599 .7 .915 r
.42393 .6563 .42929 .66206 .43846 .66024 .43311 .65498 Mtetra
.627 .729 .921 r
.43311 .65498 .43846 .66024 .44768 .65828 .44235 .65299 Mtetra
.617 .726 .924 r
.44235 .65299 .44768 .65828 .45692 .65718 .45162 .65119 Mtetra
.242 .523 .914 r
.45162 .65119 .45692 .65718 .46636 .64609 .46082 .65465 Mtetra
0 0 0 r
.46082 .65465 .46636 .64609 .4756 .64852 .47034 .64259 Mtetra
.598 .697 .912 r
.47034 .64259 .4756 .64852 .48495 .64657 .47969 .64128 Mtetra
.634 .734 .92 r
.47969 .64128 .48495 .64657 .49434 .64428 .4891 .63908 Mtetra
.64 .74 .921 r
.4891 .63908 .49434 .64428 .50376 .64194 .49854 .63672 Mtetra
.638 .739 .921 r
.49854 .63672 .50376 .64194 .51321 .63978 .50802 .63441 Mtetra
.618 .727 .924 r
.50802 .63441 .51321 .63978 .52271 .63909 .51753 .63255 Mtetra
.901 .495 .098 r
.51753 .63255 .52271 .63909 .53222 .62952 .5271 .6573 Mtetra
0 0 .152 r
.5271 .6573 .53222 .62952 .54178 .62948 .53665 .62373 Mtetra
.617 .714 .915 r
.53665 .62373 .54178 .62948 .55137 .62722 .54626 .62192 Mtetra
.644 .74 .919 r
.54626 .62192 .55137 .62722 .56099 .62465 .55591 .61944 Mtetra
.651 .747 .92 r
.55591 .61944 .56099 .62465 .57065 .62195 .56558 .61677 Mtetra
.654 .75 .92 r
.56558 .61677 .57065 .62195 .58034 .61917 .5753 .614 Mtetra
.656 .752 .92 r
.5753 .614 .58034 .61917 .59006 .61634 .58504 .61117 Mtetra
.658 .753 .92 r
.58504 .61117 .59006 .61634 .59981 .61347 .59482 .60829 Mtetra
.659 .754 .92 r
.59482 .60829 .59981 .61347 .6096 .61058 .60463 .60539 Mtetra
.60463 .60539 .6096 .61058 .61943 .60767 .61448 .60246 Mtetra
.61448 .60246 .61943 .60767 .62928 .60476 .62436 .59953 Mtetra
.62436 .59953 .62928 .60476 .63917 .60184 .63427 .59659 Mtetra
.658 .754 .92 r
.63427 .59659 .63917 .60184 .6491 .59892 .64422 .59365 Mtetra
.658 .753 .92 r
.64422 .59365 .6491 .59892 .65906 .59599 .65421 .5907 Mtetra
.65421 .5907 .65906 .59599 .66906 .59306 .66423 .58775 Mtetra
.66423 .58775 .66906 .59306 .67909 .59012 .67429 .58479 Mtetra
.67429 .58479 .67909 .59012 .68916 .58718 .68438 .58182 Mtetra
.68438 .58182 .68916 .58718 .69926 .58423 .69451 .57885 Mtetra
.657 .753 .92 r
.69451 .57885 .69926 .58423 .7094 .58127 .70467 .57587 Mtetra
.70467 .57587 .7094 .58127 .71958 .5783 .71487 .57288 Mtetra
.71487 .57288 .71958 .5783 .72979 .57532 .72511 .56988 Mtetra
.72511 .56988 .72979 .57532 .74004 .57233 .73538 .56687 Mtetra
.73538 .56687 .74004 .57233 .75032 .56933 .7457 .56385 Mtetra
.657 .752 .92 r
.7457 .56385 .75032 .56933 .76065 .56632 .75604 .56082 Mtetra
.75604 .56082 .76065 .56632 .771 .5633 .76643 .55778 Mtetra
.76643 .55778 .771 .5633 .7814 .56028 .77685 .55474 Mtetra
.77685 .55474 .7814 .56028 .79184 .55724 .78731 .55168 Mtetra
.78731 .55168 .79184 .55724 .80231 .55419 .79781 .54861 Mtetra
.79781 .54861 .80231 .55419 .81282 .55113 .80835 .54553 Mtetra
.80835 .54553 .81282 .55113 .82337 .54806 .81893 .54244 Mtetra
.81893 .54244 .82337 .54806 .83395 .54499 .82954 .53934 Mtetra
.82954 .53934 .83395 .54499 .84458 .5419 .84019 .53623 Mtetra
.84019 .53623 .84458 .5419 .85524 .53879 .85089 .53311 Mtetra
.85089 .53311 .85524 .53879 .86594 .53568 .86162 .52998 Mtetra
.86162 .52998 .86594 .53568 .87669 .53256 .87239 .52683 Mtetra
.87239 .52683 .87669 .53256 .88747 .52943 .8832 .52368 Mtetra
.8832 .52368 .88747 .52943 .89829 .52628 .89405 .52051 Mtetra
.89405 .52051 .89829 .52628 .90915 .52313 .90494 .51734 Mtetra
.90494 .51734 .90915 .52313 .92005 .51996 .91587 .51415 Mtetra
.91587 .51415 .92005 .51996 .93099 .51678 .92684 .51095 Mtetra
.92684 .51095 .93099 .51678 .94198 .5136 .93786 .50774 Mtetra
.93786 .50774 .94198 .5136 .953 .5104 .94891 .50451 Mtetra
.94891 .50451 .953 .5104 .96406 .50718 .96 .50128 Mtetra
.351 .589 .934 r
.36364 .66987 .36912 .67571 .37858 .66317 .37249 .67203 Mtetra
0 0 0 r
.37249 .67203 .37858 .66317 .38735 .66765 .3819 .66163 Mtetra
.579 .684 .912 r
.3819 .66163 .38735 .66765 .3964 .66607 .39095 .66074 Mtetra
.616 .722 .922 r
.39095 .66074 .3964 .66607 .40549 .66451 .40006 .659 Mtetra
.565 .699 .931 r
.40006 .659 .40549 .66451 .41435 .67165 .40918 .65823 Mtetra
.736 .611 .718 r
.40918 .65823 .41435 .67165 .42393 .6563 .41861 .64836 Mtetra
.495 .587 .876 r
.41861 .64836 .42393 .6563 .43311 .65498 .42773 .64956 Mtetra
.62 .722 .919 r
.42773 .64956 .43311 .65498 .44235 .65299 .43698 .6477 Mtetra
.626 .73 .922 r
.43698 .6477 .44235 .65299 .45162 .65119 .44627 .6457 Mtetra
.584 .708 .929 r
.44627 .6457 .45162 .65119 .46082 .65465 .45558 .64456 Mtetra
.778 .665 .738 r
.45558 .64456 .46082 .65465 .47034 .64259 .4651 .63339 Mtetra
.456 .535 .849 r
.4651 .63339 .47034 .64259 .47969 .64128 .47441 .6358 Mtetra
.625 .724 .918 r
.47441 .6358 .47969 .64128 .4891 .63908 .48383 .63381 Mtetra
.639 .738 .92 r
.48383 .63381 .4891 .63908 .49854 .63672 .49329 .63148 Mtetra
.64 .74 .921 r
.49329 .63148 .49854 .63672 .50802 .63441 .50279 .6291 Mtetra
.632 .735 .922 r
.50279 .6291 .50802 .63441 .51753 .63255 .51232 .62689 Mtetra
.561 .697 .931 r
.51232 .62689 .51753 .63255 .5271 .6573 .52189 .62616 Mtetra
.66 .494 .648 r
.52189 .62616 .5271 .6573 .53665 .62373 .53148 .61652 Mtetra
.548 .637 .891 r
.53148 .61652 .53665 .62373 .54626 .62192 .54112 .61645 Mtetra
.636 .733 .918 r
.54112 .61645 .54626 .62192 .55591 .61944 .55078 .61415 Mtetra
.648 .744 .92 r
.55078 .61415 .55591 .61944 .56558 .61677 .56049 .61153 Mtetra
.653 .749 .92 r
.56049 .61153 .56558 .61677 .5753 .614 .57022 .60878 Mtetra
.655 .751 .92 r
.57022 .60878 .5753 .614 .58504 .61117 .57999 .60596 Mtetra
.657 .752 .92 r
.57999 .60596 .58504 .61117 .59482 .60829 .58979 .60308 Mtetra
.658 .753 .92 r
.58979 .60308 .59482 .60829 .60463 .60539 .59963 .60016 Mtetra
.659 .754 .92 r
.59963 .60016 .60463 .60539 .61448 .60246 .6095 .59722 Mtetra
.6095 .59722 .61448 .60246 .62436 .59953 .6194 .59427 Mtetra
.6194 .59427 .62436 .59953 .63427 .59659 .62934 .59131 Mtetra
.62934 .59131 .63427 .59659 .64422 .59365 .63931 .58834 Mtetra
.658 .753 .92 r
.63931 .58834 .64422 .59365 .65421 .5907 .64932 .58537 Mtetra
.64932 .58537 .65421 .5907 .66423 .58775 .65937 .5824 Mtetra
.65937 .5824 .66423 .58775 .67429 .58479 .66945 .57942 Mtetra
.66945 .57942 .67429 .58479 .68438 .58182 .67957 .57643 Mtetra
.67957 .57643 .68438 .58182 .69451 .57885 .68972 .57344 Mtetra
.68972 .57344 .69451 .57885 .70467 .57587 .69991 .57044 Mtetra
.657 .753 .92 r
.69991 .57044 .70467 .57587 .71487 .57288 .71014 .56742 Mtetra
.71014 .56742 .71487 .57288 .72511 .56988 .7204 .5644 Mtetra
.7204 .5644 .72511 .56988 .73538 .56687 .7307 .56138 Mtetra
.7307 .56138 .73538 .56687 .7457 .56385 .74104 .55834 Mtetra
.74104 .55834 .7457 .56385 .75604 .56082 .75141 .55529 Mtetra
.657 .752 .92 r
.75141 .55529 .75604 .56082 .76643 .55778 .76182 .55223 Mtetra
.76182 .55223 .76643 .55778 .77685 .55474 .77227 .54916 Mtetra
.77227 .54916 .77685 .55474 .78731 .55168 .78276 .54608 Mtetra
.78276 .54608 .78731 .55168 .79781 .54861 .79329 .54299 Mtetra
.79329 .54299 .79781 .54861 .80835 .54553 .80385 .53989 Mtetra
.80385 .53989 .80835 .54553 .81893 .54244 .81446 .53678 Mtetra
.81446 .53678 .81893 .54244 .82954 .53934 .8251 .53366 Mtetra
.8251 .53366 .82954 .53934 .84019 .53623 .83578 .53053 Mtetra
.83578 .53053 .84019 .53623 .85089 .53311 .8465 .52738 Mtetra
.8465 .52738 .85089 .53311 .86162 .52998 .85726 .52423 Mtetra
.85726 .52423 .86162 .52998 .87239 .52683 .86806 .52106 Mtetra
.86806 .52106 .87239 .52683 .8832 .52368 .8789 .51789 Mtetra
.8789 .51789 .8832 .52368 .89405 .52051 .88978 .5147 Mtetra
.88978 .5147 .89405 .52051 .90494 .51734 .9007 .5115 Mtetra
.9007 .5115 .90494 .51734 .91587 .51415 .91166 .50829 Mtetra
.91166 .50829 .91587 .51415 .92684 .51095 .92266 .50507 Mtetra
.92266 .50507 .92684 .51095 .93786 .50774 .9337 .50184 Mtetra
.9337 .50184 .93786 .50774 .94891 .50451 .94479 .49859 Mtetra
.94479 .49859 .94891 .50451 .96 .50128 .95591 .49533 Mtetra
.579 .705 .928 r
.3581 .6644 .36364 .66987 .37249 .67203 .3671 .66339 Mtetra
.803 .688 .737 r
.3671 .66339 .37249 .67203 .3819 .66163 .37664 .65076 Mtetra
.374 .45 .811 r
.37664 .65076 .3819 .66163 .39095 .66074 .38546 .65523 Mtetra
.61 .715 .92 r
.38546 .65523 .39095 .66074 .40006 .659 .39459 .65362 Mtetra
.608 .72 .924 r
.39459 .65362 .40006 .659 .40918 .65823 .40375 .65202 Mtetra
0 .215 .725 r
.40375 .65202 .40918 .65823 .41861 .64836 .41266 .65917 Mtetra
0 0 0 r
.41266 .65917 .41861 .64836 .42773 .64956 .42233 .64371 Mtetra
.598 .7 .915 r
.42233 .64371 .42773 .64956 .43698 .6477 .43158 .64235 Mtetra
.627 .729 .921 r
.43158 .64235 .43698 .6477 .44627 .6457 .44089 .64032 Mtetra
.617 .726 .924 r
.44089 .64032 .44627 .6457 .45558 .64456 .45023 .63849 Mtetra
.245 .524 .915 r
.45023 .63849 .45558 .64456 .4651 .63339 .4595 .64193 Mtetra
0 0 0 r
.4595 .64193 .4651 .63339 .47441 .6358 .4691 .62978 Mtetra
.598 .697 .912 r
.4691 .62978 .47441 .6358 .48383 .63381 .47853 .62844 Mtetra
.634 .734 .92 r
.47853 .62844 .48383 .63381 .49329 .63148 .48801 .62619 Mtetra
.64 .74 .921 r
.48801 .62619 .49329 .63148 .50279 .6291 .49753 .62379 Mtetra
.638 .739 .921 r
.49753 .62379 .50279 .6291 .51232 .62689 .50708 .62143 Mtetra
.618 .727 .924 r
.50708 .62143 .51232 .62689 .52189 .62616 .51667 .61953 Mtetra
.899 .491 .09 r
.51667 .61953 .52189 .62616 .53148 .61652 .5263 .64436 Mtetra
0 0 .145 r
.5263 .64436 .53148 .61652 .54112 .61645 .53594 .61061 Mtetra
.617 .714 .915 r
.53594 .61061 .54112 .61645 .55078 .61415 .54563 .60876 Mtetra
.644 .74 .919 r
.54563 .60876 .55078 .61415 .56049 .61153 .55535 .60623 Mtetra
.651 .747 .92 r
.55535 .60623 .56049 .61153 .57022 .60878 .56511 .60351 Mtetra
.654 .75 .92 r
.56511 .60351 .57022 .60878 .57999 .60596 .5749 .6007 Mtetra
.656 .752 .92 r
.5749 .6007 .57999 .60596 .58979 .60308 .58473 .59782 Mtetra
.658 .753 .92 r
.58473 .59782 .58979 .60308 .59963 .60016 .59459 .5949 Mtetra
.659 .754 .92 r
.59459 .5949 .59963 .60016 .6095 .59722 .60448 .59195 Mtetra
.60448 .59195 .6095 .59722 .6194 .59427 .61441 .58897 Mtetra
.61441 .58897 .6194 .59427 .62934 .59131 .62437 .58599 Mtetra
.62437 .58599 .62934 .59131 .63931 .58834 .63437 .583 Mtetra
.658 .754 .92 r
.63437 .583 .63931 .58834 .64932 .58537 .64441 .58001 Mtetra
.658 .753 .92 r
.64441 .58001 .64932 .58537 .65937 .5824 .65448 .57702 Mtetra
.65448 .57702 .65937 .5824 .66945 .57942 .66458 .57401 Mtetra
.66458 .57401 .66945 .57942 .67957 .57643 .67472 .57101 Mtetra
.67472 .57101 .67957 .57643 .68972 .57344 .6849 .56799 Mtetra
.6849 .56799 .68972 .57344 .69991 .57044 .69512 .56497 Mtetra
.657 .753 .92 r
.69512 .56497 .69991 .57044 .71014 .56742 .70537 .56194 Mtetra
.70537 .56194 .71014 .56742 .7204 .5644 .71566 .55889 Mtetra
.71566 .55889 .7204 .5644 .7307 .56138 .72598 .55584 Mtetra
.72598 .55584 .7307 .56138 .74104 .55834 .73635 .55278 Mtetra
.73635 .55278 .74104 .55834 .75141 .55529 .74675 .54971 Mtetra
.657 .752 .92 r
.74675 .54971 .75141 .55529 .76182 .55223 .75719 .54663 Mtetra
.75719 .54663 .76182 .55223 .77227 .54916 .76766 .54354 Mtetra
.76766 .54354 .77227 .54916 .78276 .54608 .77818 .54044 Mtetra
.77818 .54044 .78276 .54608 .79329 .54299 .78873 .53733 Mtetra
.78873 .53733 .79329 .54299 .80385 .53989 .79932 .53421 Mtetra
.79932 .53421 .80385 .53989 .81446 .53678 .80996 .53108 Mtetra
.80996 .53108 .81446 .53678 .8251 .53366 .82063 .52794 Mtetra
.82063 .52794 .8251 .53366 .83578 .53053 .83134 .52478 Mtetra
.83134 .52478 .83578 .53053 .8465 .52738 .84208 .52162 Mtetra
.84208 .52162 .8465 .52738 .85726 .52423 .85287 .51844 Mtetra
.85287 .51844 .85726 .52423 .86806 .52106 .8637 .51526 Mtetra
.8637 .51526 .86806 .52106 .8789 .51789 .87457 .51206 Mtetra
.87457 .51206 .8789 .51789 .88978 .5147 .88548 .50885 Mtetra
.88548 .50885 .88978 .5147 .9007 .5115 .89643 .50563 Mtetra
.89643 .50563 .9007 .5115 .91166 .50829 .90742 .5024 Mtetra
.90742 .5024 .91166 .50829 .92266 .50507 .91845 .49915 Mtetra
.91845 .49915 .92266 .50507 .9337 .50184 .92953 .4959 Mtetra
.92953 .4959 .9337 .50184 .94479 .49859 .94064 .49263 Mtetra
.94064 .49263 .94479 .49859 .95591 .49533 .9518 .48935 Mtetra
.603 .715 .923 r
.35253 .65897 .3581 .6644 .3671 .66339 .36156 .65747 Mtetra
.352 .589 .934 r
.36156 .65747 .3671 .66339 .37664 .65076 .37048 .65961 Mtetra
0 0 0 r
.37048 .65961 .37664 .65076 .38546 .65523 .37997 .64913 Mtetra
.579 .684 .912 r
.37997 .64913 .38546 .65523 .39459 .65362 .38908 .64821 Mtetra
.616 .722 .922 r
.38908 .64821 .39459 .65362 .40375 .65202 .39827 .64643 Mtetra
.566 .699 .931 r
.39827 .64643 .40375 .65202 .41266 .65917 .40745 .64562 Mtetra
.736 .611 .719 r
.40745 .64562 .41266 .65917 .42233 .64371 .41696 .63568 Mtetra
.495 .587 .876 r
.41696 .63568 .42233 .64371 .43158 .64235 .42615 .63685 Mtetra
.62 .722 .919 r
.42615 .63685 .43158 .64235 .44089 .64032 .43548 .63495 Mtetra
.626 .73 .922 r
.43548 .63495 .44089 .64032 .45023 .63849 .44484 .63291 Mtetra
.584 .708 .929 r
.44484 .63291 .45023 .63849 .4595 .64193 .45422 .63173 Mtetra
.778 .665 .738 r
.45422 .63173 .4595 .64193 .4691 .62978 .46382 .62049 Mtetra
.456 .535 .849 r
.46382 .62049 .4691 .62978 .47853 .62844 .4732 .62287 Mtetra
.625 .724 .918 r
.4732 .62287 .47853 .62844 .48801 .62619 .48269 .62084 Mtetra
.639 .738 .92 r
.48269 .62084 .48801 .62619 .49753 .62379 .49223 .61846 Mtetra
.64 .74 .921 r
.49223 .61846 .49753 .62379 .50708 .62143 .50181 .61604 Mtetra
.632 .735 .922 r
.50181 .61604 .50708 .62143 .51667 .61953 .51141 .61379 Mtetra
.561 .697 .931 r
.51141 .61379 .51667 .61953 .5263 .64436 .52106 .61303 Mtetra
.659 .493 .648 r
.52106 .61303 .5263 .64436 .53594 .61061 .53073 .6033 Mtetra
.548 .637 .891 r
.53073 .6033 .53594 .61061 .54563 .60876 .54044 .6032 Mtetra
.636 .733 .918 r
.54044 .6032 .54563 .60876 .55535 .60623 .55019 .60085 Mtetra
.648 .744 .92 r
.55019 .60085 .55535 .60623 .56511 .60351 .55997 .59819 Mtetra
.653 .749 .92 r
.55997 .59819 .56511 .60351 .5749 .6007 .56978 .5954 Mtetra
.655 .751 .92 r
.56978 .5954 .5749 .6007 .58473 .59782 .57963 .59252 Mtetra
.657 .752 .92 r
.57963 .59252 .58473 .59782 .59459 .5949 .58952 .5896 Mtetra
.658 .753 .92 r
.58952 .5896 .59459 .5949 .60448 .59195 .59943 .58663 Mtetra
.659 .754 .92 r
.59943 .58663 .60448 .59195 .61441 .58897 .60939 .58364 Mtetra
.60939 .58364 .61441 .58897 .62437 .58599 .61937 .58064 Mtetra
.61937 .58064 .62437 .58599 .63437 .583 .6294 .57763 Mtetra
.6294 .57763 .63437 .583 .64441 .58001 .63945 .57462 Mtetra
.658 .753 .92 r
.63945 .57462 .64441 .58001 .65448 .57702 .64955 .5716 Mtetra
.64955 .5716 .65448 .57702 .66458 .57401 .65968 .56857 Mtetra
.65968 .56857 .66458 .57401 .67472 .57101 .66985 .56555 Mtetra
.66985 .56555 .67472 .57101 .6849 .56799 .68005 .56251 Mtetra
.68005 .56251 .6849 .56799 .69512 .56497 .69029 .55946 Mtetra
.69029 .55946 .69512 .56497 .70537 .56194 .70057 .55641 Mtetra
.657 .753 .92 r
.70057 .55641 .70537 .56194 .71566 .55889 .71088 .55335 Mtetra
.71088 .55335 .71566 .55889 .72598 .55584 .72124 .55028 Mtetra
.72124 .55028 .72598 .55584 .73635 .55278 .73163 .5472 Mtetra
.73163 .5472 .73635 .55278 .74675 .54971 .74205 .5441 Mtetra
.74205 .5441 .74675 .54971 .75719 .54663 .75252 .541 Mtetra
.657 .752 .92 r
.75252 .541 .75719 .54663 .76766 .54354 .76302 .53789 Mtetra
.76302 .53789 .76766 .54354 .77818 .54044 .77356 .53477 Mtetra
.77356 .53477 .77818 .54044 .78873 .53733 .78415 .53164 Mtetra
.78415 .53164 .78873 .53733 .79932 .53421 .79477 .5285 Mtetra
.79477 .5285 .79932 .53421 .80996 .53108 .80542 .52534 Mtetra
.80542 .52534 .80996 .53108 .82063 .52794 .81612 .52218 Mtetra
.81612 .52218 .82063 .52794 .83134 .52478 .82686 .519 Mtetra
.82686 .519 .83134 .52478 .84208 .52162 .83764 .51582 Mtetra
.83764 .51582 .84208 .52162 .85287 .51844 .84846 .51262 Mtetra
.84846 .51262 .85287 .51844 .8637 .51526 .85931 .50941 Mtetra
.85931 .50941 .8637 .51526 .87457 .51206 .87021 .50619 Mtetra
.87021 .50619 .87457 .51206 .88548 .50885 .88115 .50296 Mtetra
.88115 .50296 .88548 .50885 .89643 .50563 .89213 .49971 Mtetra
.89213 .49971 .89643 .50563 .90742 .5024 .90315 .49646 Mtetra
.90315 .49646 .90742 .5024 .91845 .49915 .91421 .49319 Mtetra
.91421 .49319 .91845 .49915 .92953 .4959 .92532 .48991 Mtetra
.92532 .48991 .92953 .4959 .94064 .49263 .93646 .48662 Mtetra
.93646 .48662 .94064 .49263 .9518 .48935 .94765 .48332 Mtetra
.601 .709 .92 r
.34693 .65335 .35253 .65897 .36156 .65747 .35598 .65192 Mtetra
.579 .705 .928 r
.35598 .65192 .36156 .65747 .37048 .65961 .36504 .65088 Mtetra
.804 .688 .737 r
.36504 .65088 .37048 .65961 .37997 .64913 .37466 .63816 Mtetra
.373 .45 .811 r
.37466 .63816 .37997 .64913 .38908 .64821 .38355 .64262 Mtetra
.61 .715 .92 r
.38355 .64262 .38908 .64821 .39827 .64643 .39274 .64097 Mtetra
.608 .72 .924 r
.39274 .64097 .39827 .64643 .40745 .64562 .40197 .63933 Mtetra
0 .22 .729 r
.40197 .63933 .40745 .64562 .41696 .63568 .41095 .64647 Mtetra
0 0 0 r
.41095 .64647 .41696 .63568 .42615 .63685 .4207 .63092 Mtetra
.598 .7 .915 r
.4207 .63092 .42615 .63685 .43548 .63495 .43003 .62952 Mtetra
.627 .729 .921 r
.43003 .62952 .43548 .63495 .44484 .63291 .43941 .62745 Mtetra
.617 .726 .924 r
.43941 .62745 .44484 .63291 .45422 .63173 .44882 .62557 Mtetra
.247 .525 .915 r
.44882 .62557 .45422 .63173 .46382 .62049 .45817 .629 Mtetra
0 0 0 r
.45817 .629 .46382 .62049 .4732 .62287 .46784 .61677 Mtetra
.597 .697 .912 r
.46784 .61677 .4732 .62287 .48269 .62084 .47735 .61538 Mtetra
.634 .734 .92 r
.47735 .61538 .48269 .62084 .49223 .61846 .4869 .61309 Mtetra
.64 .74 .921 r
.4869 .61309 .49223 .61846 .50181 .61604 .4965 .61065 Mtetra
.638 .739 .921 r
.4965 .61065 .50181 .61604 .51141 .61379 .50613 .60825 Mtetra
.618 .727 .924 r
.50613 .60825 .51141 .61379 .52106 .61303 .51579 .6063 Mtetra
.896 .487 .082 r
.51579 .6063 .52106 .61303 .53073 .6033 .5255 .63121 Mtetra
0 0 .138 r
.5255 .63121 .53073 .6033 .54044 .6032 .53522 .59728 Mtetra
.617 .714 .915 r
.53522 .59728 .54044 .6032 .55019 .60085 .54499 .59538 Mtetra
.644 .74 .919 r
.54499 .59538 .55019 .60085 .55997 .59819 .55479 .5928 Mtetra
.651 .747 .92 r
.55479 .5928 .55997 .59819 .56978 .5954 .56463 .59004 Mtetra
.654 .75 .92 r
.56463 .59004 .56978 .5954 .57963 .59252 .5745 .58718 Mtetra
.656 .752 .92 r
.5745 .58718 .57963 .59252 .58952 .5896 .58441 .58425 Mtetra
.658 .753 .92 r
.58441 .58425 .58952 .5896 .59943 .58663 .59435 .58128 Mtetra
.659 .754 .92 r
.59435 .58128 .59943 .58663 .60939 .58364 .60433 .57828 Mtetra
.60433 .57828 .60939 .58364 .61937 .58064 .61434 .57526 Mtetra
.61434 .57526 .61937 .58064 .6294 .57763 .62439 .57222 Mtetra
.62439 .57222 .6294 .57763 .63945 .57462 .63447 .56919 Mtetra
.658 .754 .92 r
.63447 .56919 .63945 .57462 .64955 .5716 .64459 .56615 Mtetra
.658 .753 .92 r
.64459 .56615 .64955 .5716 .65968 .56857 .65475 .5631 Mtetra
.65475 .5631 .65968 .56857 .66985 .56555 .66494 .56005 Mtetra
.66494 .56005 .66985 .56555 .68005 .56251 .67517 .55699 Mtetra
.67517 .55699 .68005 .56251 .69029 .55946 .68543 .55392 Mtetra
.68543 .55392 .69029 .55946 .70057 .55641 .69574 .55085 Mtetra
.657 .753 .92 r
.69574 .55085 .70057 .55641 .71088 .55335 .70608 .54777 Mtetra
.70608 .54777 .71088 .55335 .72124 .55028 .71646 .54467 Mtetra
.71646 .54467 .72124 .55028 .73163 .5472 .72687 .54157 Mtetra
.72687 .54157 .73163 .5472 .74205 .5441 .73733 .53846 Mtetra
.73733 .53846 .74205 .5441 .75252 .541 .74782 .53533 Mtetra
.657 .752 .92 r
.74782 .53533 .75252 .541 .76302 .53789 .75835 .5322 Mtetra
.75835 .5322 .76302 .53789 .77356 .53477 .76892 .52906 Mtetra
.76892 .52906 .77356 .53477 .78415 .53164 .77953 .52591 Mtetra
.77953 .52591 .78415 .53164 .79477 .5285 .79018 .52274 Mtetra
.79018 .52274 .79477 .5285 .80542 .52534 .80086 .51957 Mtetra
.80086 .51957 .80542 .52534 .81612 .52218 .81159 .51638 Mtetra
.81159 .51638 .81612 .52218 .82686 .519 .82236 .51318 Mtetra
.82236 .51318 .82686 .519 .83764 .51582 .83316 .50997 Mtetra
.83316 .50997 .83764 .51582 .84846 .51262 .84401 .50675 Mtetra
.84401 .50675 .84846 .51262 .85931 .50941 .8549 .50352 Mtetra
.8549 .50352 .85931 .50941 .87021 .50619 .86582 .50028 Mtetra
.86582 .50028 .87021 .50619 .88115 .50296 .87679 .49702 Mtetra
.87679 .49702 .88115 .50296 .89213 .49971 .8878 .49376 Mtetra
.8878 .49376 .89213 .49971 .90315 .49646 .89885 .49048 Mtetra
.89885 .49048 .90315 .49646 .91421 .49319 .90995 .48719 Mtetra
.90995 .48719 .91421 .49319 .92532 .48991 .92108 .48389 Mtetra
.92108 .48389 .92532 .48991 .93646 .48662 .93226 .48058 Mtetra
.93226 .48058 .93646 .48662 .94765 .48332 .94348 .47725 Mtetra
.564 .671 .91 r
.34133 .64702 .34693 .65335 .35598 .65192 .35035 .6464 Mtetra
.603 .715 .923 r
.35035 .6464 .35598 .65192 .36504 .65088 .35946 .64487 Mtetra
.353 .589 .934 r
.35946 .64487 .36504 .65088 .37466 .63816 .36843 .64699 Mtetra
0 0 0 r
.36843 .64699 .37466 .63816 .38355 .64262 .37801 .63643 Mtetra
.579 .684 .912 r
.37801 .63643 .38355 .64262 .39274 .64097 .38719 .63547 Mtetra
.616 .722 .922 r
.38719 .63547 .39274 .64097 .40197 .63933 .39644 .63366 Mtetra
.566 .699 .931 r
.39644 .63366 .40197 .63933 .41095 .64647 .4057 .63281 Mtetra
.736 .611 .719 r
.4057 .63281 .41095 .64647 .4207 .63092 .41529 .62279 Mtetra
.494 .587 .876 r
.41529 .62279 .4207 .63092 .43003 .62952 .42455 .62394 Mtetra
.62 .722 .919 r
.42455 .62394 .43003 .62952 .43941 .62745 .43394 .622 Mtetra
.626 .73 .922 r
.43394 .622 .43941 .62745 .44882 .62557 .44338 .61991 Mtetra
.584 .708 .928 r
.44338 .61991 .44882 .62557 .45817 .629 .45283 .6187 Mtetra
.779 .666 .738 r
.45283 .6187 .45817 .629 .46784 .61677 .46251 .60737 Mtetra
.455 .534 .849 r
.46251 .60737 .46784 .61677 .47735 .61538 .47197 .60973 Mtetra
.625 .724 .918 r
.47197 .60973 .47735 .61538 .4869 .61309 .48154 .60766 Mtetra
.639 .738 .92 r
.48154 .60766 .4869 .61309 .4965 .61065 .49115 .60523 Mtetra
.64 .74 .921 r
.49115 .60523 .4965 .61065 .50613 .60825 .5008 .60276 Mtetra
.632 .735 .922 r
.5008 .60276 .50613 .60825 .51579 .6063 .51049 .60047 Mtetra
.561 .697 .931 r
.51049 .60047 .51579 .6063 .5255 .63121 .52021 .59967 Mtetra
.659 .492 .647 r
.52021 .59967 .5255 .63121 .53522 .59728 .52997 .58987 Mtetra
.548 .638 .891 r
.52997 .58987 .53522 .59728 .54499 .59538 .53976 .58973 Mtetra
.636 .733 .918 r
.53976 .58973 .54499 .59538 .55479 .5928 .54958 .58734 Mtetra
.648 .744 .92 r
.54958 .58734 .55479 .5928 .56463 .59004 .55945 .58463 Mtetra
.653 .749 .92 r
.55945 .58463 .56463 .59004 .5745 .58718 .56934 .58179 Mtetra
.655 .751 .92 r
.56934 .58179 .5745 .58718 .58441 .58425 .57927 .57887 Mtetra
.657 .752 .92 r
.57927 .57887 .58441 .58425 .59435 .58128 .58924 .57589 Mtetra
.658 .753 .92 r
.58924 .57589 .59435 .58128 .60433 .57828 .59924 .57288 Mtetra
.659 .754 .92 r
.59924 .57288 .60433 .57828 .61434 .57526 .60927 .56984 Mtetra
.60927 .56984 .61434 .57526 .62439 .57222 .61935 .56678 Mtetra
.61935 .56678 .62439 .57222 .63447 .56919 .62945 .56372 Mtetra
.62945 .56372 .63447 .56919 .64459 .56615 .6396 .56066 Mtetra
.658 .753 .92 r
.6396 .56066 .64459 .56615 .65475 .5631 .64978 .55759 Mtetra
.64978 .55759 .65475 .5631 .66494 .56005 .66 .55452 Mtetra
.66 .55452 .66494 .56005 .67517 .55699 .67025 .55143 Mtetra
.67025 .55143 .67517 .55699 .68543 .55392 .68054 .54835 Mtetra
.68054 .54835 .68543 .55392 .69574 .55085 .69087 .54525 Mtetra
.69087 .54525 .69574 .55085 .70608 .54777 .70124 .54214 Mtetra
.657 .753 .92 r
.70124 .54214 .70608 .54777 .71646 .54467 .71164 .53903 Mtetra
.71164 .53903 .71646 .54467 .72687 .54157 .72209 .53591 Mtetra
.72209 .53591 .72687 .54157 .73733 .53846 .73257 .53277 Mtetra
.73257 .53277 .73733 .53846 .74782 .53533 .74309 .52963 Mtetra
.74309 .52963 .74782 .53533 .75835 .5322 .75364 .52647 Mtetra
.657 .752 .92 r
.75364 .52647 .75835 .5322 .76892 .52906 .76424 .52331 Mtetra
.76424 .52331 .76892 .52906 .77953 .52591 .77488 .52013 Mtetra
.77488 .52013 .77953 .52591 .79018 .52274 .78555 .51695 Mtetra
.78555 .51695 .79018 .52274 .80086 .51957 .79627 .51375 Mtetra
.79627 .51375 .80086 .51957 .81159 .51638 .80702 .51054 Mtetra
.80702 .51054 .81159 .51638 .82236 .51318 .81782 .50732 Mtetra
.81782 .50732 .82236 .51318 .83316 .50997 .82865 .50409 Mtetra
.82865 .50409 .83316 .50997 .84401 .50675 .83953 .50085 Mtetra
.83953 .50085 .84401 .50675 .8549 .50352 .85045 .49759 Mtetra
.85045 .49759 .8549 .50352 .86582 .50028 .8614 .49433 Mtetra
.8614 .49433 .86582 .50028 .87679 .49702 .8724 .49105 Mtetra
.8724 .49105 .87679 .49702 .8878 .49376 .88344 .48776 Mtetra
.88344 .48776 .8878 .49376 .89885 .49048 .89452 .48446 Mtetra
.89452 .48446 .89885 .49048 .90995 .48719 .90565 .48115 Mtetra
.90565 .48115 .90995 .48719 .92108 .48389 .91681 .47782 Mtetra
.91681 .47782 .92108 .48389 .93226 .48058 .92802 .47449 Mtetra
.92802 .47449 .93226 .48058 .94348 .47725 .93927 .47114 Mtetra
.242 .301 .725 r
.33618 .63192 .34133 .64702 .35035 .6464 .3447 .64071 Mtetra
.601 .709 .92 r
.3447 .64071 .35035 .6464 .35946 .64487 .35382 .63924 Mtetra
.579 .705 .928 r
.35382 .63924 .35946 .64487 .36843 .64699 .36295 .63816 Mtetra
.804 .689 .737 r
.36295 .63816 .36843 .64699 .37801 .63643 .37265 .62536 Mtetra
.372 .449 .811 r
.37265 .62536 .37801 .63643 .38719 .63547 .3816 .6298 Mtetra
.61 .715 .92 r
.3816 .6298 .38719 .63547 .39644 .63366 .39087 .62811 Mtetra
.608 .72 .924 r
.39087 .62811 .39644 .63366 .4057 .63281 .40017 .62643 Mtetra
0 .224 .732 r
.40017 .62643 .4057 .63281 .41529 .62279 .40922 .63358 Mtetra
0 0 0 r
.40922 .63358 .41529 .62279 .42455 .62394 .41905 .61792 Mtetra
.598 .701 .915 r
.41905 .61792 .42455 .62394 .43394 .622 .42845 .61648 Mtetra
.627 .729 .921 r
.42845 .61648 .43394 .622 .44338 .61991 .4379 .61437 Mtetra
.617 .726 .924 r
.4379 .61437 .44338 .61991 .45283 .6187 .44739 .61245 Mtetra
.249 .526 .915 r
.44739 .61245 .45283 .6187 .46251 .60737 .45681 .61586 Mtetra
0 0 0 r
.45681 .61586 .46251 .60737 .47197 .60973 .46656 .60354 Mtetra
.597 .697 .912 r
.46656 .60354 .47197 .60973 .48154 .60766 .47614 .60211 Mtetra
.634 .734 .92 r
.47614 .60211 .48154 .60766 .49115 .60523 .48578 .59978 Mtetra
.64 .74 .921 r
.48578 .59978 .49115 .60523 .5008 .60276 .49545 .59729 Mtetra
.638 .739 .921 r
.49545 .59729 .5008 .60276 .51049 .60047 .50516 .59484 Mtetra
.618 .727 .924 r
.50516 .59484 .51049 .60047 .52021 .59967 .5149 .59285 Mtetra
.893 .484 .074 r
.5149 .59285 .52021 .59967 .52997 .58987 .52468 .61783 Mtetra
0 0 .131 r
.52468 .61783 .52997 .58987 .53976 .58973 .53449 .58372 Mtetra
.617 .714 .915 r
.53449 .58372 .53976 .58973 .54958 .58734 .54434 .58177 Mtetra
.644 .74 .919 r
.54434 .58177 .54958 .58734 .55945 .58463 .55423 .57915 Mtetra
.651 .747 .92 r
.55423 .57915 .55945 .58463 .56934 .58179 .56414 .57634 Mtetra
.654 .75 .92 r
.56414 .57634 .56934 .58179 .57927 .57887 .5741 .57343 Mtetra
.656 .752 .92 r
.5741 .57343 .57927 .57887 .58924 .57589 .58409 .57046 Mtetra
.658 .753 .92 r
.58409 .57046 .58924 .57589 .59924 .57288 .59411 .56743 Mtetra
.659 .754 .92 r
.59411 .56743 .59924 .57288 .60927 .56984 .60417 .56438 Mtetra
.60417 .56438 .60927 .56984 .61935 .56678 .61427 .56131 Mtetra
.61427 .56131 .61935 .56678 .62945 .56372 .6244 .55822 Mtetra
.6244 .55822 .62945 .56372 .6396 .56066 .63457 .55514 Mtetra
.658 .754 .92 r
.63457 .55514 .6396 .56066 .64978 .55759 .64478 .55204 Mtetra
.658 .753 .92 r
.64478 .55204 .64978 .55759 .66 .55452 .65502 .54895 Mtetra
.65502 .54895 .66 .55452 .67025 .55143 .6653 .54584 Mtetra
.6653 .54584 .67025 .55143 .68054 .54835 .67562 .54273 Mtetra
.67562 .54273 .68054 .54835 .69087 .54525 .68597 .53961 Mtetra
.68597 .53961 .69087 .54525 .70124 .54214 .69637 .53649 Mtetra
.657 .753 .92 r
.69637 .53649 .70124 .54214 .71164 .53903 .7068 .53335 Mtetra
.7068 .53335 .71164 .53903 .72209 .53591 .71727 .5302 Mtetra
.71727 .5302 .72209 .53591 .73257 .53277 .72778 .52705 Mtetra
.72778 .52705 .73257 .53277 .74309 .52963 .73832 .52388 Mtetra
.73832 .52388 .74309 .52963 .75364 .52647 .74891 .5207 Mtetra
.657 .752 .92 r
.74891 .5207 .75364 .52647 .76424 .52331 .75953 .51752 Mtetra
.75953 .51752 .76424 .52331 .77488 .52013 .7702 .51432 Mtetra
.7702 .51432 .77488 .52013 .78555 .51695 .7809 .51111 Mtetra
.7809 .51111 .78555 .51695 .79627 .51375 .79164 .50789 Mtetra
.79164 .50789 .79627 .51375 .80702 .51054 .80243 .50466 Mtetra
.80243 .50466 .80702 .51054 .81782 .50732 .81325 .50142 Mtetra
.81325 .50142 .81782 .50732 .82865 .50409 .82412 .49817 Mtetra
.82412 .49817 .82865 .50409 .83953 .50085 .83502 .4949 Mtetra
.83502 .4949 .83953 .50085 .85045 .49759 .84597 .49162 Mtetra
.84597 .49162 .85045 .49759 .8614 .49433 .85695 .48834 Mtetra
.85695 .48834 .8614 .49433 .8724 .49105 .86798 .48504 Mtetra
.86798 .48504 .8724 .49105 .88344 .48776 .87905 .48172 Mtetra
.87905 .48172 .88344 .48776 .89452 .48446 .89016 .4784 Mtetra
.89016 .4784 .89452 .48446 .90565 .48115 .90132 .47506 Mtetra
.90132 .47506 .90565 .48115 .91681 .47782 .91252 .47171 Mtetra
.91252 .47171 .91681 .47782 .92802 .47449 .92376 .46835 Mtetra
.92376 .46835 .92802 .47449 .93927 .47114 .93504 .46498 Mtetra
.023 0 .02 r
.3295 .64394 .33618 .63192 .3447 .64071 .33905 .63429 Mtetra
.564 .671 .91 r
.33905 .63429 .3447 .64071 .35382 .63924 .34814 .63364 Mtetra
.603 .715 .923 r
.34814 .63364 .35382 .63924 .36295 .63816 .35731 .63207 Mtetra
.354 .59 .934 r
.35731 .63207 .36295 .63816 .37265 .62536 .36636 .63417 Mtetra
0 0 0 r
.36636 .63417 .37265 .62536 .3816 .6298 .37601 .62353 Mtetra
.579 .684 .912 r
.37601 .62353 .3816 .6298 .39087 .62811 .38526 .62253 Mtetra
.616 .722 .922 r
.38526 .62253 .39087 .62811 .40017 .62643 .39459 .62067 Mtetra
.566 .699 .931 r
.39459 .62067 .40017 .62643 .40922 .63358 .40392 .61979 Mtetra
.737 .612 .719 r
.40392 .61979 .40922 .63358 .41905 .61792 .41359 .6097 Mtetra
.494 .587 .876 r
.41359 .6097 .41905 .61792 .42845 .61648 .42292 .61081 Mtetra
.62 .722 .919 r
.42292 .61081 .42845 .61648 .4379 .61437 .43239 .60883 Mtetra
.626 .73 .922 r
.43239 .60883 .4379 .61437 .44739 .61245 .4419 .6067 Mtetra
.584 .708 .928 r
.4419 .6067 .44739 .61245 .45681 .61586 .45143 .60544 Mtetra
.779 .666 .739 r
.45143 .60544 .45681 .61586 .46656 .60354 .46119 .59403 Mtetra
.454 .534 .85 r
.46119 .59403 .46656 .60354 .47614 .60211 .47072 .59637 Mtetra
.625 .724 .918 r
.47072 .59637 .47614 .60211 .48578 .59978 .48037 .59425 Mtetra
.639 .738 .92 r
.48037 .59425 .48578 .59978 .49545 .59729 .49006 .59178 Mtetra
.64 .74 .921 r
.49006 .59178 .49545 .59729 .50516 .59484 .49979 .58927 Mtetra
.632 .735 .922 r
.49979 .58927 .50516 .59484 .5149 .59285 .50955 .58693 Mtetra
.561 .696 .931 r
.50955 .58693 .5149 .59285 .52468 .61783 .51935 .58609 Mtetra
.658 .491 .646 r
.51935 .58609 .52468 .61783 .53449 .58372 .52919 .57621 Mtetra
.548 .638 .891 r
.52919 .57621 .53449 .58372 .54434 .58177 .53906 .57603 Mtetra
.636 .733 .918 r
.53906 .57603 .54434 .58177 .55423 .57915 .54897 .5736 Mtetra
.648 .744 .92 r
.54897 .5736 .55423 .57915 .56414 .57634 .55891 .57083 Mtetra
.653 .749 .92 r
.55891 .57083 .56414 .57634 .5741 .57343 .56889 .56794 Mtetra
.655 .751 .92 r
.56889 .56794 .5741 .57343 .58409 .57046 .57891 .56497 Mtetra
.657 .752 .92 r
.57891 .56497 .58409 .57046 .59411 .56743 .58896 .56195 Mtetra
.658 .753 .92 r
.58896 .56195 .59411 .56743 .60417 .56438 .59904 .55888 Mtetra
.659 .754 .92 r
.59904 .55888 .60417 .56438 .61427 .56131 .60916 .55579 Mtetra
.60916 .55579 .61427 .56131 .6244 .55822 .61932 .55269 Mtetra
.61932 .55269 .6244 .55822 .63457 .55514 .62951 .54958 Mtetra
.62951 .54958 .63457 .55514 .64478 .55204 .63974 .54646 Mtetra
.658 .753 .92 r
.63974 .54646 .64478 .55204 .65502 .54895 .65001 .54334 Mtetra
.65001 .54334 .65502 .54895 .6653 .54584 .66032 .54021 Mtetra
.66032 .54021 .6653 .54584 .67562 .54273 .67066 .53708 Mtetra
.67066 .53708 .67562 .54273 .68597 .53961 .68104 .53394 Mtetra
.68104 .53394 .68597 .53961 .69637 .53649 .69146 .53079 Mtetra
.69146 .53079 .69637 .53649 .7068 .53335 .70192 .52763 Mtetra
.657 .753 .92 r
.70192 .52763 .7068 .53335 .71727 .5302 .71242 .52446 Mtetra
.71242 .52446 .71727 .5302 .72778 .52705 .72295 .52128 Mtetra
.72295 .52128 .72778 .52705 .73832 .52388 .73352 .5181 Mtetra
.73352 .5181 .73832 .52388 .74891 .5207 .74414 .5149 Mtetra
.74414 .5149 .74891 .5207 .75953 .51752 .75479 .51169 Mtetra
.657 .752 .92 r
.75479 .51169 .75953 .51752 .7702 .51432 .76548 .50847 Mtetra
.76548 .50847 .7702 .51432 .7809 .51111 .77621 .50524 Mtetra
.77621 .50524 .7809 .51111 .79164 .50789 .78699 .50199 Mtetra
.78699 .50199 .79164 .50789 .80243 .50466 .7978 .49874 Mtetra
.7978 .49874 .80243 .50466 .81325 .50142 .80865 .49548 Mtetra
.80865 .49548 .81325 .50142 .82412 .49817 .81954 .4922 Mtetra
.81954 .4922 .82412 .49817 .83502 .4949 .83048 .48891 Mtetra
.83048 .48891 .83502 .4949 .84597 .49162 .84146 .48561 Mtetra
.84146 .48561 .84597 .49162 .85695 .48834 .85247 .4823 Mtetra
.85247 .4823 .85695 .48834 .86798 .48504 .86353 .47898 Mtetra
.86353 .47898 .86798 .48504 .87905 .48172 .87463 .47564 Mtetra
.87463 .47564 .87905 .48172 .89016 .4784 .88577 .47229 Mtetra
.88577 .47229 .89016 .4784 .90132 .47506 .89696 .46893 Mtetra
.89696 .46893 .90132 .47506 .91252 .47171 .90819 .46556 Mtetra
.90819 .46556 .91252 .47171 .92376 .46835 .91946 .46218 Mtetra
.91946 .46218 .92376 .46835 .93504 .46498 .93077 .45878 Mtetra
.839 .706 .716 r
.32388 .636 .3295 .64394 .33905 .63429 .33386 .61907 Mtetra
.239 .3 .725 r
.33386 .61907 .33905 .63429 .34814 .63364 .34244 .62786 Mtetra
.601 .709 .92 r
.34244 .62786 .34814 .63364 .35731 .63207 .35162 .62635 Mtetra
.579 .705 .928 r
.35162 .62635 .35731 .63207 .36636 .63417 .36083 .62523 Mtetra
.805 .69 .737 r
.36083 .62523 .36636 .63417 .37601 .62353 .3706 .61234 Mtetra
.37 .449 .811 r
.3706 .61234 .37601 .62353 .38526 .62253 .37963 .61677 Mtetra
.61 .715 .92 r
.37963 .61677 .38526 .62253 .39459 .62067 .38896 .61504 Mtetra
.608 .72 .924 r
.38896 .61504 .39459 .62067 .40392 .61979 .39834 .61332 Mtetra
0 .228 .736 r
.39834 .61332 .40392 .61979 .41359 .6097 .40745 .62046 Mtetra
0 0 0 r
.40745 .62046 .41359 .6097 .42292 .61081 .41737 .6047 Mtetra
.598 .701 .915 r
.41737 .6047 .42292 .61081 .43239 .60883 .42684 .60323 Mtetra
.627 .729 .921 r
.42684 .60323 .43239 .60883 .4419 .6067 .43637 .60107 Mtetra
.617 .726 .924 r
.43637 .60107 .4419 .6067 .45143 .60544 .44593 .59911 Mtetra
.252 .526 .915 r
.44593 .59911 .45143 .60544 .46119 .59403 .45542 .6025 Mtetra
0 0 0 r
.45542 .6025 .46119 .59403 .47072 .59637 .46526 .59008 Mtetra
.597 .697 .912 r
.46526 .59008 .47072 .59637 .48037 .59425 .47492 .58862 Mtetra
.634 .734 .92 r
.47492 .58862 .48037 .59425 .49006 .59178 .48463 .58624 Mtetra
.64 .74 .921 r
.48463 .58624 .49006 .59178 .49979 .58927 .49438 .5837 Mtetra
.638 .739 .921 r
.49438 .5837 .49979 .58927 .50955 .58693 .50417 .58121 Mtetra
.618 .727 .924 r
.50417 .58121 .50955 .58693 .51935 .58609 .51399 .57918 Mtetra
.891 .48 .066 r
.51399 .57918 .51935 .58609 .52919 .57621 .52385 .60423 Mtetra
0 0 .123 r
.52385 .60423 .52919 .57621 .53906 .57603 .53375 .56993 Mtetra
.617 .714 .915 r
.53375 .56993 .53906 .57603 .54897 .5736 .54368 .56794 Mtetra
.644 .74 .919 r
.54368 .56794 .54897 .5736 .55891 .57083 .55365 .56527 Mtetra
.651 .747 .92 r
.55365 .56527 .55891 .57083 .56889 .56794 .56365 .56241 Mtetra
.654 .75 .92 r
.56365 .56241 .56889 .56794 .57891 .56497 .57369 .55945 Mtetra
.656 .752 .92 r
.57369 .55945 .57891 .56497 .58896 .56195 .58376 .55642 Mtetra
.658 .753 .92 r
.58376 .55642 .58896 .56195 .59904 .55888 .59387 .55335 Mtetra
.659 .754 .92 r
.59387 .55335 .59904 .55888 .60916 .55579 .60402 .55024 Mtetra
.60402 .55024 .60916 .55579 .61932 .55269 .6142 .54712 Mtetra
.6142 .54712 .61932 .55269 .62951 .54958 .62442 .54398 Mtetra
.62442 .54398 .62951 .54958 .63974 .54646 .63468 .54084 Mtetra
.658 .754 .92 r
.63468 .54084 .63974 .54646 .65001 .54334 .64497 .5377 Mtetra
.658 .753 .92 r
.64497 .5377 .65001 .54334 .66032 .54021 .6553 .53455 Mtetra
.6553 .53455 .66032 .54021 .67066 .53708 .66567 .53139 Mtetra
.66567 .53139 .67066 .53708 .68104 .53394 .67608 .52823 Mtetra
.67608 .52823 .68104 .53394 .69146 .53079 .68652 .52505 Mtetra
.68652 .52505 .69146 .53079 .70192 .52763 .69701 .52187 Mtetra
.657 .753 .92 r
.69701 .52187 .70192 .52763 .71242 .52446 .70753 .51868 Mtetra
.70753 .51868 .71242 .52446 .72295 .52128 .71809 .51548 Mtetra
.71809 .51548 .72295 .52128 .73352 .5181 .72869 .51227 Mtetra
.72869 .51227 .73352 .5181 .74414 .5149 .73934 .50905 Mtetra
.73934 .50905 .74414 .5149 .75479 .51169 .75002 .50582 Mtetra
.657 .752 .92 r
.75002 .50582 .75479 .51169 .76548 .50847 .76074 .50258 Mtetra
.76074 .50258 .76548 .50847 .77621 .50524 .7715 .49932 Mtetra
.7715 .49932 .77621 .50524 .78699 .50199 .7823 .49606 Mtetra
.7823 .49606 .78699 .50199 .7978 .49874 .79314 .49278 Mtetra
.79314 .49278 .7978 .49874 .80865 .49548 .80402 .48949 Mtetra
.80402 .48949 .80865 .49548 .81954 .4922 .81494 .48619 Mtetra
.81494 .48619 .81954 .4922 .83048 .48891 .82591 .48288 Mtetra
.82591 .48288 .83048 .48891 .84146 .48561 .83691 .47956 Mtetra
.83691 .47956 .84146 .48561 .85247 .4823 .84796 .47622 Mtetra
.84796 .47622 .85247 .4823 .86353 .47898 .85905 .47288 Mtetra
.85905 .47288 .86353 .47898 .87463 .47564 .87018 .46952 Mtetra
.87018 .46952 .87463 .47564 .88577 .47229 .88135 .46615 Mtetra
.88135 .46615 .88577 .47229 .89696 .46893 .89257 .46276 Mtetra
.89257 .46276 .89696 .46893 .90819 .46556 .90383 .45937 Mtetra
.90383 .45937 .90819 .46556 .91946 .46218 .91513 .45596 Mtetra
.91513 .45596 .91946 .46218 .93077 .45878 .92648 .45254 Mtetra
.432 .631 .938 r
.31812 .62995 .32388 .636 .33386 .61907 .3271 .63108 Mtetra
.01 0 .007 r
.3271 .63108 .33386 .61907 .34244 .62786 .33674 .62135 Mtetra
.564 .671 .91 r
.33674 .62135 .34244 .62786 .35162 .62635 .34589 .62067 Mtetra
.603 .715 .923 r
.34589 .62067 .35162 .62635 .36083 .62523 .35514 .61905 Mtetra
.356 .59 .933 r
.35514 .61905 .36083 .62523 .3706 .61234 .36425 .62113 Mtetra
0 0 0 r
.36425 .62113 .3706 .61234 .37963 .61677 .37398 .61041 Mtetra
.579 .684 .912 r
.37398 .61041 .37963 .61677 .38896 .61504 .38331 .60937 Mtetra
.616 .722 .922 r
.38331 .60937 .38896 .61504 .39834 .61332 .3927 .60747 Mtetra
.566 .699 .93 r
.3927 .60747 .39834 .61332 .40745 .62046 .40211 .60656 Mtetra
.737 .612 .719 r
.40211 .60656 .40745 .62046 .41737 .6047 .41186 .59638 Mtetra
.494 .587 .876 r
.41186 .59638 .41737 .6047 .42684 .60323 .42126 .59746 Mtetra
.62 .722 .919 r
.42126 .59746 .42684 .60323 .43637 .60107 .4308 .59544 Mtetra
.626 .73 .922 r
.4308 .59544 .43637 .60107 .44593 .59911 .44039 .59327 Mtetra
.584 .708 .928 r
.44039 .59327 .44593 .59911 .45542 .6025 .45 .59197 Mtetra
.78 .667 .739 r
.45 .59197 .45542 .6025 .46526 .59008 .45984 .58047 Mtetra
.453 .534 .85 r
.45984 .58047 .46526 .59008 .47492 .58862 .46944 .58278 Mtetra
.625 .724 .918 r
.46944 .58278 .47492 .58862 .48463 .58624 .47917 .58062 Mtetra
.639 .738 .92 r
.47917 .58062 .48463 .58624 .49438 .5837 .48894 .57811 Mtetra
.64 .74 .921 r
.48894 .57811 .49438 .5837 .50417 .58121 .49875 .57554 Mtetra
.632 .735 .922 r
.49875 .57554 .50417 .58121 .51399 .57918 .5086 .57315 Mtetra
.561 .696 .931 r
.5086 .57315 .51399 .57918 .52385 .60423 .51848 .57228 Mtetra
.658 .49 .646 r
.51848 .57228 .52385 .60423 .53375 .56993 .5284 .56232 Mtetra
.548 .638 .892 r
.5284 .56232 .53375 .56993 .54368 .56794 .53835 .56211 Mtetra
.636 .733 .918 r
.53835 .56211 .54368 .56794 .55365 .56527 .54834 .55962 Mtetra
.648 .744 .92 r
.54834 .55962 .55365 .56527 .56365 .56241 .55837 .55681 Mtetra
.653 .749 .92 r
.55837 .55681 .56365 .56241 .57369 .55945 .56843 .55387 Mtetra
.655 .751 .92 r
.56843 .55387 .57369 .55945 .58376 .55642 .57853 .55085 Mtetra
.657 .752 .92 r
.57853 .55085 .58376 .55642 .59387 .55335 .58867 .54777 Mtetra
.658 .753 .92 r
.58867 .54777 .59387 .55335 .60402 .55024 .59884 .54465 Mtetra
.659 .754 .92 r
.59884 .54465 .60402 .55024 .6142 .54712 .60905 .54151 Mtetra
.60905 .54151 .6142 .54712 .62442 .54398 .61929 .53835 Mtetra
.61929 .53835 .62442 .54398 .63468 .54084 .62957 .53519 Mtetra
.62957 .53519 .63468 .54084 .64497 .5377 .63989 .53202 Mtetra
.658 .753 .92 r
.63989 .53202 .64497 .5377 .6553 .53455 .65025 .52884 Mtetra
.65025 .52884 .6553 .53455 .66567 .53139 .66065 .52566 Mtetra
.66065 .52566 .66567 .53139 .67608 .52823 .67108 .52248 Mtetra
.67108 .52248 .67608 .52823 .68652 .52505 .68155 .51928 Mtetra
.68155 .51928 .68652 .52505 .69701 .52187 .69206 .51608 Mtetra
.69206 .51608 .69701 .52187 .70753 .51868 .70261 .51286 Mtetra
.657 .753 .92 r
.70261 .51286 .70753 .51868 .71809 .51548 .7132 .50964 Mtetra
.7132 .50964 .71809 .51548 .72869 .51227 .72383 .50641 Mtetra
.72383 .50641 .72869 .51227 .73934 .50905 .7345 .50316 Mtetra
.7345 .50316 .73934 .50905 .75002 .50582 .74521 .49991 Mtetra
.74521 .49991 .75002 .50582 .76074 .50258 .75596 .49664 Mtetra
.657 .752 .92 r
.75596 .49664 .76074 .50258 .7715 .49932 .76675 .49337 Mtetra
.76675 .49337 .7715 .49932 .7823 .49606 .77757 .49008 Mtetra
.77757 .49008 .7823 .49606 .79314 .49278 .78844 .48678 Mtetra
.78844 .48678 .79314 .49278 .80402 .48949 .79936 .48347 Mtetra
.79936 .48347 .80402 .48949 .81494 .48619 .81031 .48014 Mtetra
.81031 .48014 .81494 .48619 .82591 .48288 .8213 .47681 Mtetra
.8213 .47681 .82591 .48288 .83691 .47956 .83234 .47346 Mtetra
.83234 .47346 .83691 .47956 .84796 .47622 .84341 .47011 Mtetra
.84341 .47011 .84796 .47622 .85905 .47288 .85453 .46673 Mtetra
.85453 .46673 .85905 .47288 .87018 .46952 .8657 .46335 Mtetra
.8657 .46335 .87018 .46952 .88135 .46615 .8769 .45996 Mtetra
.8769 .45996 .88135 .46615 .89257 .46276 .88815 .45655 Mtetra
.88815 .45655 .89257 .46276 .90383 .45937 .89944 .45313 Mtetra
.89944 .45313 .90383 .45937 .91513 .45596 .91077 .44969 Mtetra
.91077 .44969 .91513 .45596 .92648 .45254 .92215 .44625 Mtetra
.579 .703 .927 r
.3123 .62418 .31812 .62995 .3271 .63108 .32143 .62304 Mtetra
.84 .707 .716 r
.32143 .62304 .3271 .63108 .33674 .62135 .3315 .606 Mtetra
.237 .298 .724 r
.3315 .606 .33674 .62135 .34589 .62067 .34014 .6148 Mtetra
.601 .709 .92 r
.34014 .6148 .34589 .62067 .35514 .61905 .34939 .61325 Mtetra
.579 .704 .928 r
.34939 .61325 .35514 .61905 .36425 .62113 .35867 .61209 Mtetra
.805 .69 .738 r
.35867 .61209 .36425 .62113 .37398 .61041 .36853 .59911 Mtetra
.369 .448 .811 r
.36853 .59911 .37398 .61041 .38331 .60937 .37762 .60353 Mtetra
.61 .715 .92 r
.37762 .60353 .38331 .60937 .3927 .60747 .38703 .60175 Mtetra
.608 .72 .924 r
.38703 .60175 .3927 .60747 .40211 .60656 .39648 .59999 Mtetra
0 .232 .74 r
.39648 .59999 .40211 .60656 .41186 .59638 .40566 .60713 Mtetra
0 0 0 r
.40566 .60713 .41186 .59638 .42126 .59746 .41566 .59126 Mtetra
.598 .701 .915 r
.41566 .59126 .42126 .59746 .4308 .59544 .42521 .58975 Mtetra
.627 .729 .921 r
.42521 .58975 .4308 .59544 .44039 .59327 .43481 .58755 Mtetra
.617 .726 .924 r
.43481 .58755 .44039 .59327 .45 .59197 .44445 .58554 Mtetra
.254 .527 .915 r
.44445 .58554 .45 .59197 .45984 .58047 .45402 .58891 Mtetra
0 0 0 r
.45402 .58891 .45984 .58047 .46944 .58278 .46394 .57641 Mtetra
.597 .697 .913 r
.46394 .57641 .46944 .58278 .47917 .58062 .47368 .5749 Mtetra
.634 .734 .92 r
.47368 .5749 .47917 .58062 .48894 .57811 .48347 .57247 Mtetra
.64 .74 .921 r
.48347 .57247 .48894 .57811 .49875 .57554 .4933 .56988 Mtetra
.638 .739 .921 r
.4933 .56988 .49875 .57554 .5086 .57315 .50317 .56734 Mtetra
.618 .727 .924 r
.50317 .56734 .5086 .57315 .51848 .57228 .51307 .56527 Mtetra
.887 .476 .058 r
.51307 .56527 .51848 .57228 .5284 .56232 .523 .5904 Mtetra
0 0 .116 r
.523 .5904 .5284 .56232 .53835 .56211 .53299 .5559 Mtetra
.617 .714 .915 r
.53299 .5559 .53835 .56211 .54834 .55962 .54301 .55386 Mtetra
.644 .74 .919 r
.54301 .55386 .54834 .55962 .55837 .55681 .55306 .55115 Mtetra
.651 .747 .92 r
.55306 .55115 .55837 .55681 .56843 .55387 .56314 .54823 Mtetra
.654 .75 .92 r
.56314 .54823 .56843 .55387 .57853 .55085 .57327 .54522 Mtetra
.656 .752 .92 r
.57327 .54522 .57853 .55085 .58867 .54777 .58343 .54215 Mtetra
.658 .753 .92 r
.58343 .54215 .58867 .54777 .59884 .54465 .59362 .53902 Mtetra
.659 .754 .92 r
.59362 .53902 .59884 .54465 .60905 .54151 .60386 .53586 Mtetra
.60386 .53586 .60905 .54151 .61929 .53835 .61413 .53269 Mtetra
.61413 .53269 .61929 .53835 .62957 .53519 .62444 .5295 Mtetra
.62444 .5295 .62957 .53519 .63989 .53202 .63478 .5263 Mtetra
.658 .754 .92 r
.63478 .5263 .63989 .53202 .65025 .52884 .64516 .5231 Mtetra
.658 .753 .92 r
.64516 .5231 .65025 .52884 .66065 .52566 .65559 .5199 Mtetra
.65559 .5199 .66065 .52566 .67108 .52248 .66605 .51669 Mtetra
.66605 .51669 .67108 .52248 .68155 .51928 .67655 .51347 Mtetra
.67655 .51347 .68155 .51928 .69206 .51608 .68708 .51024 Mtetra
.68708 .51024 .69206 .51608 .70261 .51286 .69766 .507 Mtetra
.657 .753 .92 r
.69766 .507 .70261 .51286 .7132 .50964 .70828 .50376 Mtetra
.70828 .50376 .7132 .50964 .72383 .50641 .71893 .5005 Mtetra
.71893 .5005 .72383 .50641 .7345 .50316 .72963 .49723 Mtetra
.72963 .49723 .7345 .50316 .74521 .49991 .74037 .49396 Mtetra
.74037 .49396 .74521 .49991 .75596 .49664 .75114 .49067 Mtetra
.657 .752 .92 r
.75114 .49067 .75596 .49664 .76675 .49337 .76196 .48737 Mtetra
.76196 .48737 .76675 .49337 .77757 .49008 .77282 .48406 Mtetra
.77282 .48406 .77757 .49008 .78844 .48678 .78372 .48073 Mtetra
.78372 .48073 .78844 .48678 .79936 .48347 .79466 .4774 Mtetra
.79466 .4774 .79936 .48347 .81031 .48014 .80564 .47405 Mtetra
.80564 .47405 .81031 .48014 .8213 .47681 .81666 .4707 Mtetra
.81666 .4707 .8213 .47681 .83234 .47346 .82773 .46733 Mtetra
.82773 .46733 .83234 .47346 .84341 .47011 .83884 .46394 Mtetra
.83884 .46394 .84341 .47011 .85453 .46673 .84999 .46055 Mtetra
.84999 .46055 .85453 .46673 .8657 .46335 .86118 .45714 Mtetra
.86118 .45714 .8657 .46335 .8769 .45996 .87242 .45372 Mtetra
.87242 .45372 .8769 .45996 .88815 .45655 .8837 .45029 Mtetra
.8837 .45029 .88815 .45655 .89944 .45313 .89502 .44684 Mtetra
.89502 .44684 .89944 .45313 .91077 .44969 .90639 .44339 Mtetra
.90639 .44339 .91077 .44969 .92215 .44625 .9178 .43992 Mtetra
.594 .707 .922 r
.30646 .61833 .3123 .62418 .32143 .62304 .31562 .61691 Mtetra
.432 .631 .938 r
.31562 .61691 .32143 .62304 .3315 .606 .32467 .61801 Mtetra
0 0 0 r
.32467 .61801 .3315 .606 .34014 .6148 .33438 .6082 Mtetra
.564 .671 .91 r
.33438 .6082 .34014 .6148 .34939 .61325 .34361 .60748 Mtetra
.603 .715 .923 r
.34361 .60748 .34939 .61325 .35867 .61209 .35292 .60582 Mtetra
.357 .59 .933 r
.35292 .60582 .35867 .61209 .36853 .59911 .36211 .60787 Mtetra
0 0 0 r
.36211 .60787 .36853 .59911 .37762 .60353 .37192 .59707 Mtetra
.579 .684 .912 r
.37192 .59707 .37762 .60353 .38703 .60175 .38132 .596 Mtetra
.616 .722 .922 r
.38132 .596 .38703 .60175 .39648 .59999 .39079 .59406 Mtetra
.566 .699 .93 r
.39079 .59406 .39648 .59999 .40566 .60713 .40026 .5931 Mtetra
.737 .612 .719 r
.40026 .5931 .40566 .60713 .41566 .59126 .4101 .58284 Mtetra
.493 .587 .877 r
.4101 .58284 .41566 .59126 .42521 .58975 .41957 .58389 Mtetra
.62 .722 .919 r
.41957 .58389 .42521 .58975 .43481 .58755 .4292 .58183 Mtetra
.626 .73 .922 r
.4292 .58183 .43481 .58755 .44445 .58554 .43886 .57961 Mtetra
.584 .708 .928 r
.43886 .57961 .44445 .58554 .45402 .58891 .44854 .57827 Mtetra
.78 .667 .739 r
.44854 .57827 .45402 .58891 .46394 .57641 .45847 .56669 Mtetra
.453 .534 .85 r
.45847 .56669 .46394 .57641 .47368 .5749 .46815 .56897 Mtetra
.625 .724 .918 r
.46815 .56897 .47368 .5749 .48347 .57247 .47796 .56676 Mtetra
.639 .738 .92 r
.47796 .56676 .48347 .57247 .4933 .56988 .48781 .5642 Mtetra
.64 .74 .921 r
.48781 .5642 .4933 .56988 .50317 .56734 .4977 .56159 Mtetra
.632 .735 .922 r
.4977 .56159 .50317 .56734 .51307 .56527 .50763 .55915 Mtetra
.561 .696 .931 r
.50763 .55915 .51307 .56527 .523 .5904 .51759 .55823 Mtetra
.657 .489 .645 r
.51759 .55823 .523 .5904 .53299 .5559 .5276 .54819 Mtetra
.547 .638 .892 r
.5276 .54819 .53299 .5559 .54301 .55386 .53763 .54794 Mtetra
.636 .733 .918 r
.53763 .54794 .54301 .55386 .55306 .55115 .54771 .5454 Mtetra
.648 .744 .92 r
.54771 .5454 .55306 .55115 .56314 .54823 .55782 .54254 Mtetra
.653 .749 .92 r
.55782 .54254 .56314 .54823 .57327 .54522 .56797 .53955 Mtetra
.655 .751 .92 r
.56797 .53955 .57327 .54522 .58343 .54215 .57815 .53647 Mtetra
.657 .752 .92 r
.57815 .53647 .58343 .54215 .59362 .53902 .58837 .53334 Mtetra
.658 .753 .92 r
.58837 .53334 .59362 .53902 .60386 .53586 .59863 .53017 Mtetra
.659 .754 .92 r
.59863 .53017 .60386 .53586 .61413 .53269 .60893 .52698 Mtetra
.60893 .52698 .61413 .53269 .62444 .5295 .61926 .52377 Mtetra
.61926 .52377 .62444 .5295 .63478 .5263 .62963 .52055 Mtetra
.62963 .52055 .63478 .5263 .64516 .5231 .64004 .51732 Mtetra
.658 .753 .92 r
.64004 .51732 .64516 .5231 .65559 .5199 .65049 .5141 Mtetra
.65049 .5141 .65559 .5199 .66605 .51669 .66098 .51086 Mtetra
.66098 .51086 .66605 .51669 .67655 .51347 .6715 .50762 Mtetra
.6715 .50762 .67655 .51347 .68708 .51024 .68207 .50437 Mtetra
.68207 .50437 .68708 .51024 .69766 .507 .69267 .50111 Mtetra
.69267 .50111 .69766 .507 .70828 .50376 .70332 .49784 Mtetra
.657 .753 .92 r
.70332 .49784 .70828 .50376 .71893 .5005 .714 .49456 Mtetra
.714 .49456 .71893 .5005 .72963 .49723 .72473 .49127 Mtetra
.72473 .49127 .72963 .49723 .74037 .49396 .73549 .48796 Mtetra
.73549 .48796 .74037 .49396 .75114 .49067 .7463 .48465 Mtetra
.7463 .48465 .75114 .49067 .76196 .48737 .75714 .48133 Mtetra
.657 .752 .92 r
.75714 .48133 .76196 .48737 .77282 .48406 .76803 .47799 Mtetra
.76803 .47799 .77282 .48406 .78372 .48073 .77896 .47465 Mtetra
.77896 .47465 .78372 .48073 .79466 .4774 .78993 .47129 Mtetra
.78993 .47129 .79466 .4774 .80564 .47405 .80094 .46792 Mtetra
.80094 .46792 .80564 .47405 .81666 .4707 .81199 .46454 Mtetra
.81199 .46454 .81666 .4707 .82773 .46733 .82309 .46114 Mtetra
.82309 .46114 .82773 .46733 .83884 .46394 .83423 .45774 Mtetra
.83423 .45774 .83884 .46394 .84999 .46055 .84541 .45432 Mtetra
.84541 .45432 .84999 .46055 .86118 .45714 .85663 .45089 Mtetra
.85663 .45089 .86118 .45714 .87242 .45372 .8679 .44744 Mtetra
.8679 .44744 .87242 .45372 .8837 .45029 .87921 .44399 Mtetra
.87921 .44399 .8837 .45029 .89502 .44684 .89057 .44052 Mtetra
.89057 .44052 .89502 .44684 .90639 .44339 .90197 .43703 Mtetra
.90197 .43703 .90639 .44339 .9178 .43992 .91341 .43354 Mtetra
.574 .684 .916 r
.3006 .61202 .30646 .61833 .31562 .61691 .30975 .61104 Mtetra
.579 .703 .927 r
.30975 .61104 .31562 .61691 .32467 .61801 .31895 .60987 Mtetra
.841 .708 .716 r
.31895 .60987 .32467 .61801 .33438 .6082 .3291 .59272 Mtetra
.234 .297 .724 r
.3291 .59272 .33438 .6082 .34361 .60748 .3378 .60152 Mtetra
.601 .709 .92 r
.3378 .60152 .34361 .60748 .35292 .60582 .34712 .59993 Mtetra
.579 .704 .928 r
.34712 .59993 .35292 .60582 .36211 .60787 .35647 .59874 Mtetra
.806 .691 .738 r
.35647 .59874 .36211 .60787 .37192 .59707 .36642 .58566 Mtetra
.368 .448 .811 r
.36642 .58566 .37192 .59707 .38132 .596 .37557 .59006 Mtetra
.61 .715 .92 r
.37557 .59006 .38132 .596 .39079 .59406 .38506 .58824 Mtetra
.608 .72 .924 r
.38506 .58824 .39079 .59406 .40026 .5931 .39458 .58644 Mtetra
0 .237 .743 r
.39458 .58644 .40026 .5931 .4101 .58284 .40383 .59357 Mtetra
0 0 0 r
.40383 .59357 .4101 .58284 .41957 .58389 .41392 .5776 Mtetra
.598 .701 .915 r
.41392 .5776 .41957 .58389 .4292 .58183 .42354 .57605 Mtetra
.627 .729 .921 r
.42354 .57605 .4292 .58183 .43886 .57961 .43323 .57379 Mtetra
.617 .726 .924 r
.43323 .57379 .43886 .57961 .44854 .57827 .44295 .57174 Mtetra
.256 .528 .915 r
.44295 .57174 .44854 .57827 .45847 .56669 .45259 .57509 Mtetra
0 0 0 r
.45259 .57509 .45847 .56669 .46815 .56897 .4626 .5625 Mtetra
.597 .697 .913 r
.4626 .5625 .46815 .56897 .47796 .56676 .47241 .56094 Mtetra
.634 .734 .92 r
.47241 .56094 .47796 .56676 .48781 .5642 .48228 .55847 Mtetra
.64 .74 .921 r
.48228 .55847 .48781 .5642 .4977 .56159 .4922 .55583 Mtetra
.638 .739 .921 r
.4922 .55583 .4977 .56159 .50763 .55915 .50215 .55324 Mtetra
.618 .727 .924 r
.50215 .55324 .50763 .55915 .51759 .55823 .51213 .55112 Mtetra
.884 .471 .049 r
.51213 .55112 .51759 .55823 .5276 .54819 .52214 .57632 Mtetra
0 0 .108 r
.52214 .57632 .5276 .54819 .53763 .54794 .53222 .54163 Mtetra
.617 .714 .915 r
.53222 .54163 .53763 .54794 .54771 .5454 .54232 .53955 Mtetra
.644 .74 .919 r
.54232 .53955 .54771 .5454 .55782 .54254 .55246 .53678 Mtetra
.651 .747 .92 r
.55246 .53678 .55782 .54254 .56797 .53955 .56263 .53382 Mtetra
.654 .75 .92 r
.56263 .53382 .56797 .53955 .57815 .53647 .57284 .53075 Mtetra
.656 .752 .92 r
.57284 .53075 .57815 .53647 .58837 .53334 .58309 .52762 Mtetra
.658 .753 .92 r
.58309 .52762 .58837 .53334 .59863 .53017 .59337 .52444 Mtetra
.659 .754 .92 r
.59337 .52444 .59863 .53017 .60893 .52698 .6037 .52123 Mtetra
.6037 .52123 .60893 .52698 .61926 .52377 .61405 .518 Mtetra
.61405 .518 .61926 .52377 .62963 .52055 .62445 .51476 Mtetra
.62445 .51476 .62963 .52055 .64004 .51732 .63489 .51151 Mtetra
.658 .754 .92 r
.63489 .51151 .64004 .51732 .65049 .5141 .64536 .50825 Mtetra
.658 .753 .92 r
.64536 .50825 .65049 .5141 .66098 .51086 .65588 .50499 Mtetra
.65588 .50499 .66098 .51086 .6715 .50762 .66643 .50173 Mtetra
.66643 .50173 .6715 .50762 .68207 .50437 .67702 .49845 Mtetra
.67702 .49845 .68207 .50437 .69267 .50111 .68765 .49517 Mtetra
.68765 .49517 .69267 .50111 .70332 .49784 .69833 .49187 Mtetra
.657 .753 .92 r
.69833 .49187 .70332 .49784 .714 .49456 .70904 .48857 Mtetra
.70904 .48857 .714 .49456 .72473 .49127 .71979 .48526 Mtetra
.71979 .48526 .72473 .49127 .73549 .48796 .73058 .48193 Mtetra
.73058 .48193 .73549 .48796 .7463 .48465 .74142 .4786 Mtetra
.74142 .4786 .7463 .48465 .75714 .48133 .75229 .47525 Mtetra
.657 .752 .92 r
.75229 .47525 .75714 .48133 .76803 .47799 .76321 .47189 Mtetra
.76321 .47189 .76803 .47799 .77896 .47465 .77417 .46852 Mtetra
.77417 .46852 .77896 .47465 .78993 .47129 .78517 .46514 Mtetra
.78517 .46514 .78993 .47129 .80094 .46792 .79621 .46174 Mtetra
.79621 .46174 .80094 .46792 .81199 .46454 .80729 .45834 Mtetra
.80729 .45834 .81199 .46454 .82309 .46114 .81842 .45492 Mtetra
.81842 .45492 .82309 .46114 .83423 .45774 .82959 .45149 Mtetra
.82959 .45149 .83423 .45774 .84541 .45432 .8408 .44804 Mtetra
.8408 .44804 .84541 .45432 .85663 .45089 .85205 .44459 Mtetra
.85205 .44459 .85663 .45089 .8679 .44744 .86335 .44112 Mtetra
.86335 .44112 .8679 .44744 .87921 .44399 .8747 .43764 Mtetra
.8747 .43764 .87921 .44399 .89057 .44052 .88608 .43414 Mtetra
.88608 .43414 .89057 .44052 .90197 .43703 .89751 .43063 Mtetra
.89751 .43063 .90197 .43703 .91341 .43354 .90899 .42711 Mtetra
.412 .511 .849 r
.29493 .60234 .3006 .61202 .30975 .61104 .30384 .60511 Mtetra
.594 .707 .922 r
.30384 .60511 .30975 .61104 .31895 .60987 .31307 .60364 Mtetra
.433 .632 .938 r
.31307 .60364 .31895 .60987 .3291 .59272 .32219 .60471 Mtetra
0 0 0 r
.32219 .60471 .3291 .59272 .3378 .60152 .33199 .59483 Mtetra
.564 .671 .911 r
.33199 .59483 .3378 .60152 .34712 .59993 .34129 .59407 Mtetra
.604 .715 .923 r
.34129 .59407 .34712 .59993 .35647 .59874 .35067 .59237 Mtetra
.358 .591 .933 r
.35067 .59237 .35647 .59874 .36642 .58566 .35992 .5944 Mtetra
0 0 0 r
.35992 .5944 .36642 .58566 .37557 .59006 .36982 .58351 Mtetra
.579 .684 .912 r
.36982 .58351 .37557 .59006 .38506 .58824 .37929 .5824 Mtetra
.616 .722 .922 r
.37929 .5824 .38506 .58824 .39458 .58644 .38884 .58041 Mtetra
.566 .699 .93 r
.38884 .58041 .39458 .58644 .40383 .59357 .39839 .57941 Mtetra
.737 .612 .719 r
.39839 .57941 .40383 .59357 .41392 .5776 .40831 .56908 Mtetra
.493 .587 .877 r
.40831 .56908 .41392 .5776 .42354 .57605 .41786 .5701 Mtetra
.62 .722 .919 r
.41786 .5701 .42354 .57605 .43323 .57379 .42756 .56798 Mtetra
.626 .73 .922 r
.42756 .56798 .43323 .57379 .44295 .57174 .4373 .56572 Mtetra
.584 .708 .928 r
.4373 .56572 .44295 .57174 .45259 .57509 .44706 .56434 Mtetra
.781 .668 .739 r
.44706 .56434 .45259 .57509 .4626 .5625 .45708 .55267 Mtetra
.452 .534 .85 r
.45708 .55267 .4626 .5625 .47241 .56094 .46683 .55492 Mtetra
.625 .724 .918 r
.46683 .55492 .47241 .56094 .48228 .55847 .47672 .55267 Mtetra
.639 .738 .92 r
.47672 .55267 .48228 .55847 .4922 .55583 .48666 .55005 Mtetra
.64 .74 .921 r
.48666 .55005 .4922 .55583 .50215 .55324 .49663 .54739 Mtetra
.632 .735 .922 r
.49663 .54739 .50215 .55324 .51213 .55112 .50664 .5449 Mtetra
.562 .696 .931 r
.50664 .5449 .51213 .55112 .52214 .57632 .51669 .54394 Mtetra
.657 .488 .644 r
.51669 .54394 .52214 .57632 .53222 .54163 .52678 .53382 Mtetra
.547 .638 .892 r
.52678 .53382 .53222 .54163 .54232 .53955 .5369 .53353 Mtetra
.636 .733 .918 r
.5369 .53353 .54232 .53955 .55246 .53678 .54706 .53094 Mtetra
.648 .744 .92 r
.54706 .53094 .55246 .53678 .56263 .53382 .55726 .52803 Mtetra
.653 .749 .92 r
.55726 .52803 .56263 .53382 .57284 .53075 .56749 .52498 Mtetra
.655 .751 .92 r
.56749 .52498 .57284 .53075 .58309 .52762 .57777 .52185 Mtetra
.657 .752 .92 r
.57777 .52185 .58309 .52762 .59337 .52444 .58808 .51867 Mtetra
.658 .753 .92 r
.58808 .51867 .59337 .52444 .6037 .52123 .59842 .51544 Mtetra
.659 .754 .92 r
.59842 .51544 .6037 .52123 .61405 .518 .60881 .51219 Mtetra
.60881 .51219 .61405 .518 .62445 .51476 .61923 .50893 Mtetra
.61923 .50893 .62445 .51476 .63489 .51151 .6297 .50565 Mtetra
.6297 .50565 .63489 .51151 .64536 .50825 .6402 .50237 Mtetra
.658 .753 .92 r
.6402 .50237 .64536 .50825 .65588 .50499 .65074 .49909 Mtetra
.65074 .49909 .65588 .50499 .66643 .50173 .66132 .49579 Mtetra
.66132 .49579 .66643 .50173 .67702 .49845 .67194 .49249 Mtetra
.67194 .49249 .67702 .49845 .68765 .49517 .6826 .48919 Mtetra
.6826 .48919 .68765 .49517 .69833 .49187 .6933 .48587 Mtetra
.6933 .48587 .69833 .49187 .70904 .48857 .70404 .48254 Mtetra
.657 .753 .92 r
.70404 .48254 .70904 .48857 .71979 .48526 .71482 .4792 Mtetra
.71482 .4792 .71979 .48526 .73058 .48193 .72564 .47585 Mtetra
.72564 .47585 .73058 .48193 .74142 .4786 .7365 .4725 Mtetra
.7365 .4725 .74142 .4786 .75229 .47525 .74741 .46912 Mtetra
.74741 .46912 .75229 .47525 .76321 .47189 .75835 .46574 Mtetra
.657 .752 .92 r
.75835 .46574 .76321 .47189 .77417 .46852 .76934 .46235 Mtetra
.76934 .46235 .77417 .46852 .78517 .46514 .78037 .45894 Mtetra
.78037 .45894 .78517 .46514 .79621 .46174 .79144 .45552 Mtetra
.79144 .45552 .79621 .46174 .80729 .45834 .80255 .45209 Mtetra
.80255 .45209 .80729 .45834 .81842 .45492 .81371 .44865 Mtetra
.81371 .44865 .81842 .45492 .82959 .45149 .82491 .44519 Mtetra
.82491 .44519 .82959 .45149 .8408 .44804 .83615 .44172 Mtetra
.83615 .44172 .8408 .44804 .85205 .44459 .84744 .43824 Mtetra
.84744 .43824 .85205 .44459 .86335 .44112 .85877 .43475 Mtetra
.85877 .43475 .86335 .44112 .8747 .43764 .87015 .43124 Mtetra
.87015 .43124 .8747 .43764 .88608 .43414 .88157 .42772 Mtetra
.88157 .42772 .88608 .43414 .89751 .43063 .89303 .42419 Mtetra
.89303 .42419 .89751 .43063 .90899 .42711 .90454 .42064 Mtetra
.547 .816 .455 r
.288 .61065 .29493 .60234 .30384 .60511 .29793 .5987 Mtetra
.574 .684 .916 r
.29793 .5987 .30384 .60511 .31307 .60364 .30715 .59769 Mtetra
.579 .703 .927 r
.30715 .59769 .31307 .60364 .32219 .60471 .31642 .59648 Mtetra
.842 .709 .716 r
.31642 .59648 .32219 .60471 .33199 .59483 .32666 .57922 Mtetra
.231 .295 .723 r
.32666 .57922 .33199 .59483 .34129 .59407 .33542 .58802 Mtetra
.601 .709 .92 r
.33542 .58802 .34129 .59407 .35067 .59237 .34482 .58639 Mtetra
.579 .704 .928 r
.34482 .58639 .35067 .59237 .35992 .5944 .35424 .58515 Mtetra
.807 .692 .738 r
.35424 .58515 .35992 .5944 .36982 .58351 .36427 .57199 Mtetra
.366 .447 .811 r
.36427 .57199 .36982 .58351 .37929 .5824 .3735 .57637 Mtetra
.61 .715 .92 r
.3735 .57637 .37929 .5824 .38884 .58041 .38306 .57451 Mtetra
.608 .72 .924 r
.38306 .57451 .38884 .58041 .39839 .57941 .39266 .57266 Mtetra
0 .241 .747 r
.39266 .57266 .39839 .57941 .40831 .56908 .40197 .57979 Mtetra
0 0 0 r
.40197 .57979 .40831 .56908 .41786 .5701 .41215 .56371 Mtetra
.598 .701 .915 r
.41215 .56371 .41786 .5701 .42756 .56798 .42185 .56211 Mtetra
.627 .729 .921 r
.42185 .56211 .42756 .56798 .4373 .56572 .43162 .55981 Mtetra
.617 .726 .924 r
.43162 .55981 .4373 .56572 .44706 .56434 .44141 .55771 Mtetra
.259 .529 .915 r
.44141 .55771 .44706 .56434 .45708 .55267 .45113 .56104 Mtetra
0 0 0 r
.45113 .56104 .45708 .55267 .46683 .55492 .46123 .54835 Mtetra
.597 .697 .913 r
.46123 .54835 .46683 .55492 .47672 .55267 .47113 .54675 Mtetra
.634 .734 .92 r
.47113 .54675 .47672 .55267 .48666 .55005 .48108 .54423 Mtetra
.64 .74 .921 r
.48108 .54423 .48666 .55005 .49663 .54739 .49108 .54154 Mtetra
.638 .739 .921 r
.49108 .54154 .49663 .54739 .50664 .5449 .50111 .5389 Mtetra
.618 .727 .924 r
.50111 .5389 .50664 .5449 .51669 .54394 .51118 .53673 Mtetra
.881 .467 .041 r
.51118 .53673 .51669 .54394 .52678 .53382 .52127 .562 Mtetra
0 0 .101 r
.52127 .562 .52678 .53382 .5369 .53353 .53144 .52712 Mtetra
.617 .714 .915 r
.53144 .52712 .5369 .53353 .54706 .53094 .54163 .52499 Mtetra
.644 .74 .919 r
.54163 .52499 .54706 .53094 .55726 .52803 .55185 .52217 Mtetra
.651 .747 .92 r
.55185 .52217 .55726 .52803 .56749 .52498 .56211 .51915 Mtetra
.654 .75 .92 r
.56211 .51915 .56749 .52498 .57777 .52185 .57241 .51603 Mtetra
.656 .752 .92 r
.57241 .51603 .57777 .52185 .58808 .51867 .58274 .51285 Mtetra
.658 .753 .92 r
.58274 .51285 .58808 .51867 .59842 .51544 .59312 .50961 Mtetra
.659 .754 .92 r
.59312 .50961 .59842 .51544 .60881 .51219 .60353 .50634 Mtetra
.60353 .50634 .60881 .51219 .61923 .50893 .61398 .50306 Mtetra
.61398 .50306 .61923 .50893 .6297 .50565 .62447 .49976 Mtetra
.62447 .49976 .6297 .50565 .6402 .50237 .635 .49645 Mtetra
.658 .754 .92 r
.635 .49645 .6402 .50237 .65074 .49909 .64556 .49314 Mtetra
.658 .753 .92 r
.64556 .49314 .65074 .49909 .66132 .49579 .65617 .48982 Mtetra
.65617 .48982 .66132 .49579 .67194 .49249 .66682 .4865 Mtetra
.66682 .4865 .67194 .49249 .6826 .48919 .67751 .48317 Mtetra
.67751 .48317 .6826 .48919 .6933 .48587 .68823 .47982 Mtetra
.68823 .47982 .6933 .48587 .70404 .48254 .699 .47647 Mtetra
.657 .753 .92 r
.699 .47647 .70404 .48254 .71482 .4792 .70981 .47311 Mtetra
.70981 .47311 .71482 .4792 .72564 .47585 .72066 .46974 Mtetra
.72066 .46974 .72564 .47585 .7365 .4725 .73155 .46635 Mtetra
.73155 .46635 .7365 .4725 .74741 .46912 .74249 .46296 Mtetra
.74249 .46296 .74741 .46912 .75835 .46574 .75346 .45955 Mtetra
.657 .752 .92 r
.75346 .45955 .75835 .46574 .76934 .46235 .76448 .45613 Mtetra
.76448 .45613 .76934 .46235 .78037 .45894 .77554 .4527 Mtetra
.77554 .4527 .78037 .45894 .79144 .45552 .78664 .44926 Mtetra
.78664 .44926 .79144 .45552 .80255 .45209 .79778 .4458 Mtetra
.79778 .4458 .80255 .45209 .81371 .44865 .80897 .44233 Mtetra
.80897 .44233 .81371 .44865 .82491 .44519 .8202 .43885 Mtetra
.8202 .43885 .82491 .44519 .83615 .44172 .83148 .43536 Mtetra
.83148 .43536 .83615 .44172 .84744 .43824 .8428 .43185 Mtetra
.8428 .43185 .84744 .43824 .85877 .43475 .85416 .42833 Mtetra
.85416 .42833 .85877 .43475 .87015 .43124 .86556 .4248 Mtetra
.86556 .4248 .87015 .43124 .88157 .42772 .87702 .42125 Mtetra
.87702 .42125 .88157 .42772 .89303 .42419 .88851 .4177 Mtetra
.88851 .4177 .89303 .42419 .90454 .42064 .90005 .41412 Mtetra
.775 .663 .739 r
.28231 .60016 .288 .61065 .29793 .5987 .29221 .58892 Mtetra
.411 .51 .85 r
.29221 .58892 .29793 .5987 .30715 .59769 .30119 .59167 Mtetra
.594 .707 .922 r
.30119 .59167 .30715 .59769 .31642 .59648 .31049 .59016 Mtetra
.434 .632 .938 r
.31049 .59016 .31642 .59648 .32666 .57922 .31968 .5912 Mtetra
0 0 0 r
.31968 .5912 .32666 .57922 .33542 .58802 .32955 .58124 Mtetra
.564 .671 .911 r
.32955 .58124 .33542 .58802 .34482 .58639 .33892 .58044 Mtetra
.604 .715 .923 r
.33892 .58044 .34482 .58639 .35424 .58515 .34839 .5787 Mtetra
.359 .591 .933 r
.34839 .5787 .35424 .58515 .36427 .57199 .35771 .58069 Mtetra
0 0 0 r
.35771 .58069 .36427 .57199 .3735 .57637 .36769 .56972 Mtetra
.579 .684 .912 r
.36769 .56972 .3735 .57637 .38306 .57451 .37724 .56857 Mtetra
.616 .722 .922 r
.37724 .56857 .38306 .57451 .39266 .57266 .38686 .56654 Mtetra
.566 .699 .93 r
.38686 .56654 .39266 .57266 .40197 .57979 .39649 .5655 Mtetra
.738 .613 .719 r
.39649 .5655 .40197 .57979 .41215 .56371 .40649 .55508 Mtetra
.492 .586 .877 r
.40649 .55508 .41215 .56371 .42185 .56211 .41612 .55606 Mtetra
.62 .723 .919 r
.41612 .55606 .42185 .56211 .43162 .55981 .42589 .5539 Mtetra
.626 .73 .922 r
.42589 .5539 .43162 .55981 .44141 .55771 .43572 .55159 Mtetra
.584 .708 .928 r
.43572 .55159 .44141 .55771 .45113 .56104 .44556 .55016 Mtetra
.781 .669 .739 r
.44556 .55016 .45113 .56104 .46123 .54835 .45566 .5384 Mtetra
.451 .533 .85 r
.45566 .5384 .46123 .54835 .47113 .54675 .4655 .54063 Mtetra
.625 .724 .918 r
.4655 .54063 .47113 .54675 .48108 .54423 .47547 .53833 Mtetra
.639 .738 .92 r
.47547 .53833 .48108 .54423 .49108 .54154 .48548 .53566 Mtetra
.64 .74 .921 r
.48548 .53566 .49108 .54154 .50111 .5389 .49554 .53295 Mtetra
.632 .735 .922 r
.49554 .53295 .50111 .5389 .51118 .53673 .50564 .53041 Mtetra
.562 .696 .931 r
.50564 .53041 .51118 .53673 .52127 .562 .51577 .52941 Mtetra
.656 .487 .644 r
.51577 .52941 .52127 .562 .53144 .52712 .52595 .5192 Mtetra
.547 .638 .892 r
.52595 .5192 .53144 .52712 .54163 .52499 .53615 .51886 Mtetra
.636 .733 .918 r
.53615 .51886 .54163 .52499 .55185 .52217 .5464 .51622 Mtetra
.648 .744 .92 r
.5464 .51622 .55185 .52217 .56211 .51915 .55669 .51326 Mtetra
.653 .749 .92 r
.55669 .51326 .56211 .51915 .57241 .51603 .56701 .51016 Mtetra
.655 .751 .92 r
.56701 .51016 .57241 .51603 .58274 .51285 .57737 .50697 Mtetra
.657 .752 .92 r
.57737 .50697 .58274 .51285 .59312 .50961 .58777 .50373 Mtetra
.658 .753 .92 r
.58777 .50373 .59312 .50961 .60353 .50634 .59821 .50045 Mtetra
.659 .754 .92 r
.59821 .50045 .60353 .50634 .61398 .50306 .60869 .49715 Mtetra
.60869 .49715 .61398 .50306 .62447 .49976 .6192 .49382 Mtetra
.6192 .49382 .62447 .49976 .635 .49645 .62976 .49049 Mtetra
.62976 .49049 .635 .49645 .64556 .49314 .64035 .48715 Mtetra
.658 .753 .92 r
.64035 .48715 .64556 .49314 .65617 .48982 .65099 .48381 Mtetra
.65099 .48381 .65617 .48982 .66682 .4865 .66166 .48046 Mtetra
.66166 .48046 .66682 .4865 .67751 .48317 .67238 .4771 Mtetra
.67238 .4771 .67751 .48317 .68823 .47982 .68313 .47374 Mtetra
.68313 .47374 .68823 .47982 .699 .47647 .69393 .47036 Mtetra
.69393 .47036 .699 .47647 .70981 .47311 .70477 .46697 Mtetra
.657 .753 .92 r
.70477 .46697 .70981 .47311 .72066 .46974 .71565 .46357 Mtetra
.71565 .46357 .72066 .46974 .73155 .46635 .72657 .46017 Mtetra
.72657 .46017 .73155 .46635 .74249 .46296 .73753 .45675 Mtetra
.73753 .45675 .74249 .46296 .75346 .45955 .74853 .45331 Mtetra
.74853 .45331 .75346 .45955 .76448 .45613 .75958 .44987 Mtetra
.657 .752 .92 r
.75958 .44987 .76448 .45613 .77554 .4527 .77067 .44641 Mtetra
.77067 .44641 .77554 .4527 .78664 .44926 .7818 .44295 Mtetra
.7818 .44295 .78664 .44926 .79778 .4458 .79298 .43947 Mtetra
.79298 .43947 .79778 .4458 .80897 .44233 .8042 .43597 Mtetra
.8042 .43597 .80897 .44233 .8202 .43885 .81546 .43247 Mtetra
.81546 .43247 .8202 .43885 .83148 .43536 .82677 .42895 Mtetra
.82677 .42895 .83148 .43536 .8428 .43185 .83812 .42542 Mtetra
.83812 .42542 .8428 .43185 .85416 .42833 .84951 .42187 Mtetra
.84951 .42187 .85416 .42833 .86556 .4248 .86095 .41831 Mtetra
.86095 .41831 .86556 .4248 .87702 .42125 .87243 .41474 Mtetra
.87243 .41474 .87702 .42125 .88851 .4177 .88396 .41116 Mtetra
.88396 .41116 .88851 .4177 .90005 .41412 .89554 .40756 Mtetra
.186 .492 .903 r
.27631 .59361 .28231 .60016 .29221 .58892 .2852 .5972 Mtetra
.559 .825 .467 r
.2852 .5972 .29221 .58892 .30119 .59167 .29522 .58517 Mtetra
.573 .685 .916 r
.29522 .58517 .30119 .59167 .31049 .59016 .3045 .58412 Mtetra
.579 .703 .927 r
.3045 .58412 .31049 .59016 .31968 .5912 .31385 .58286 Mtetra
.842 .709 .716 r
.31385 .58286 .31968 .5912 .32955 .58124 .32418 .56549 Mtetra
.229 .293 .723 r
.32418 .56549 .32955 .58124 .33892 .58044 .333 .5743 Mtetra
.601 .709 .92 r
.333 .5743 .33892 .58044 .34839 .5787 .34247 .57262 Mtetra
.579 .704 .928 r
.34247 .57262 .34839 .5787 .35771 .58069 .35197 .57134 Mtetra
.807 .692 .738 r
.35197 .57134 .35771 .58069 .36769 .56972 .36209 .55808 Mtetra
.365 .446 .812 r
.36209 .55808 .36769 .56972 .37724 .56857 .37138 .56244 Mtetra
.61 .715 .92 r
.37138 .56244 .37724 .56857 .38686 .56654 .38102 .56054 Mtetra
.608 .719 .924 r
.38102 .56054 .38686 .56654 .39649 .5655 .3907 .55864 Mtetra
0 .245 .75 r
.3907 .55864 .39649 .5655 .40649 .55508 .40008 .56577 Mtetra
0 0 0 r
.40008 .56577 .40649 .55508 .41612 .55606 .41036 .54958 Mtetra
.598 .701 .915 r
.41036 .54958 .41612 .55606 .42589 .5539 .42014 .54793 Mtetra
.627 .729 .921 r
.42014 .54793 .42589 .5539 .43572 .55159 .42998 .54558 Mtetra
.617 .726 .924 r
.42998 .54558 .43572 .55159 .44556 .55016 .43986 .54344 Mtetra
.261 .53 .916 r
.43986 .54344 .44556 .55016 .45566 .5384 .44965 .54674 Mtetra
0 0 0 r
.44965 .54674 .45566 .5384 .4655 .54063 .45984 .53396 Mtetra
.597 .697 .913 r
.45984 .53396 .4655 .54063 .47547 .53833 .46982 .53231 Mtetra
.634 .734 .92 r
.46982 .53231 .47547 .53833 .48548 .53566 .47986 .52974 Mtetra
.64 .74 .921 r
.47986 .52974 .48548 .53566 .49554 .53295 .48993 .527 Mtetra
.638 .739 .921 r
.48993 .527 .49554 .53295 .50564 .53041 .50005 .52431 Mtetra
.618 .727 .924 r
.50005 .52431 .50564 .53041 .51577 .52941 .51021 .52208 Mtetra
.877 .463 .032 r
.51021 .52208 .51577 .52941 .52595 .5192 .52037 .54743 Mtetra
0 0 .093 r
.52037 .54743 .52595 .5192 .53615 .51886 .53065 .51236 Mtetra
.617 .714 .915 r
.53065 .51236 .53615 .51886 .5464 .51622 .54092 .51017 Mtetra
.644 .74 .919 r
.54092 .51017 .5464 .51622 .55669 .51326 .55123 .5073 Mtetra
.651 .747 .92 r
.55123 .5073 .55669 .51326 .56701 .51016 .56158 .50422 Mtetra
.654 .75 .92 r
.56158 .50422 .56701 .51016 .57737 .50697 .57197 .50105 Mtetra
.656 .752 .92 r
.57197 .50105 .57737 .50697 .58777 .50373 .58239 .49781 Mtetra
.658 .753 .92 r
.58239 .49781 .58777 .50373 .59821 .50045 .59286 .49452 Mtetra
.659 .754 .92 r
.59286 .49452 .59821 .50045 .60869 .49715 .60336 .49119 Mtetra
.60336 .49119 .60869 .49715 .6192 .49382 .6139 .48785 Mtetra
.6139 .48785 .6192 .49382 .62976 .49049 .62449 .48449 Mtetra
.62449 .48449 .62976 .49049 .64035 .48715 .63511 .48113 Mtetra
.658 .754 .92 r
.63511 .48113 .64035 .48715 .65099 .48381 .64577 .47776 Mtetra
.658 .753 .92 r
.64577 .47776 .65099 .48381 .66166 .48046 .65647 .47438 Mtetra
.65647 .47438 .66166 .48046 .67238 .4771 .66721 .471 Mtetra
.66721 .471 .67238 .4771 .68313 .47374 .678 .46761 Mtetra
.678 .46761 .68313 .47374 .69393 .47036 .68882 .4642 Mtetra
.68882 .4642 .69393 .47036 .70477 .46697 .69969 .46079 Mtetra
.657 .753 .92 r
.69969 .46079 .70477 .46697 .71565 .46357 .7106 .45737 Mtetra
.7106 .45737 .71565 .46357 .72657 .46017 .72155 .45394 Mtetra
.72155 .45394 .72657 .46017 .73753 .45675 .73254 .45049 Mtetra
.73254 .45049 .73753 .45675 .74853 .45331 .74357 .44703 Mtetra
.74357 .44703 .74853 .45331 .75958 .44987 .75465 .44357 Mtetra
.657 .752 .92 r
.75465 .44357 .75958 .44987 .77067 .44641 .76577 .44008 Mtetra
.76577 .44008 .77067 .44641 .7818 .44295 .77693 .43659 Mtetra
.77693 .43659 .7818 .44295 .79298 .43947 .78814 .43309 Mtetra
.78814 .43309 .79298 .43947 .8042 .43597 .79939 .42957 Mtetra
.79939 .42957 .8042 .43597 .81546 .43247 .81068 .42604 Mtetra
.81068 .42604 .81546 .43247 .82677 .42895 .82202 .42249 Mtetra
.82202 .42249 .82677 .42895 .83812 .42542 .8334 .41893 Mtetra
.8334 .41893 .83812 .42542 .84951 .42187 .84483 .41536 Mtetra
.84483 .41536 .84951 .42187 .86095 .41831 .8563 .41178 Mtetra
.8563 .41178 .86095 .41831 .87243 .41474 .86782 .40818 Mtetra
.86782 .40818 .87243 .41474 .88396 .41116 .87938 .40457 Mtetra
.87938 .40457 .88396 .41116 .89554 .40756 .89099 .40094 Mtetra
.559 .693 .93 r
.27024 .58749 .27631 .59361 .2852 .5972 .27946 .5866 Mtetra
.776 .664 .739 r
.27946 .5866 .2852 .5972 .29522 .58517 .28945 .57528 Mtetra
.41 .51 .85 r
.28945 .57528 .29522 .58517 .3045 .58412 .29848 .578 Mtetra
.594 .707 .922 r
.29848 .578 .3045 .58412 .31385 .58286 .30786 .57645 Mtetra
.434 .632 .938 r
.30786 .57645 .31385 .58286 .32418 .56549 .31712 .57746 Mtetra
0 0 0 r
.31712 .57746 .32418 .56549 .333 .5743 .32708 .56741 Mtetra
.563 .671 .911 r
.32708 .56741 .333 .5743 .34247 .57262 .33652 .56657 Mtetra
.604 .715 .923 r
.33652 .56657 .34247 .57262 .35197 .57134 .34606 .56479 Mtetra
.361 .591 .933 r
.34606 .56479 .35197 .57134 .36209 .55808 .35545 .56676 Mtetra
0 0 0 r
.35545 .56676 .36209 .55808 .37138 .56244 .36552 .5557 Mtetra
.579 .684 .913 r
.36552 .5557 .37138 .56244 .38102 .56054 .37514 .5545 Mtetra
.616 .722 .922 r
.37514 .5545 .38102 .56054 .3907 .55864 .38485 .55242 Mtetra
.566 .699 .93 r
.38485 .55242 .3907 .55864 .40008 .56577 .39455 .55134 Mtetra
.738 .613 .719 r
.39455 .55134 .40008 .56577 .41036 .54958 .40464 .54084 Mtetra
.492 .586 .877 r
.40464 .54084 .41036 .54958 .42014 .54793 .41434 .54179 Mtetra
.62 .723 .919 r
.41434 .54179 .42014 .54793 .42998 .54558 .4242 .53958 Mtetra
.626 .73 .922 r
.4242 .53958 .42998 .54558 .43986 .54344 .43411 .53722 Mtetra
.585 .708 .928 r
.43411 .53722 .43986 .54344 .44965 .54674 .44403 .53575 Mtetra
.782 .669 .74 r
.44403 .53575 .44965 .54674 .45984 .53396 .45422 .5239 Mtetra
.451 .533 .85 r
.45422 .5239 .45984 .53396 .46982 .53231 .46413 .52609 Mtetra
.625 .724 .918 r
.46413 .52609 .46982 .53231 .47986 .52974 .47419 .52374 Mtetra
.639 .738 .92 r
.47419 .52374 .47986 .52974 .48993 .527 .48429 .52102 Mtetra
.64 .74 .921 r
.48429 .52102 .48993 .527 .50005 .52431 .49443 .51826 Mtetra
.632 .735 .922 r
.49443 .51826 .50005 .52431 .51021 .52208 .50461 .51567 Mtetra
.562 .696 .931 r
.50461 .51567 .51021 .52208 .52037 .54743 .51483 .51461 Mtetra
.655 .486 .643 r
.51483 .51461 .52037 .54743 .53065 .51236 .5251 .50432 Mtetra
.547 .638 .892 r
.5251 .50432 .53065 .51236 .54092 .51017 .5354 .50394 Mtetra
.636 .733 .918 r
.5354 .50394 .54092 .51017 .55123 .5073 .54573 .50125 Mtetra
.648 .744 .92 r
.54573 .50125 .55123 .5073 .56158 .50422 .55611 .49823 Mtetra
.653 .749 .92 r
.55611 .49823 .56158 .50422 .57197 .50105 .56652 .49507 Mtetra
.655 .751 .92 r
.56652 .49507 .57197 .50105 .58239 .49781 .57697 .49183 Mtetra
.657 .752 .92 r
.57697 .49183 .58239 .49781 .59286 .49452 .58747 .48854 Mtetra
.658 .753 .92 r
.58747 .48854 .59286 .49452 .60336 .49119 .598 .4852 Mtetra
.659 .754 .92 r
.598 .4852 .60336 .49119 .6139 .48785 .60857 .48183 Mtetra
.60857 .48183 .6139 .48785 .62449 .48449 .61917 .47845 Mtetra
.61917 .47845 .62449 .48449 .63511 .48113 .62982 .47506 Mtetra
.62982 .47506 .63511 .48113 .64577 .47776 .64051 .47166 Mtetra
.658 .753 .92 r
.64051 .47166 .64577 .47776 .65647 .47438 .65124 .46826 Mtetra
.65124 .46826 .65647 .47438 .66721 .471 .66201 .46485 Mtetra
.66201 .46485 .66721 .471 .678 .46761 .67283 .46143 Mtetra
.67283 .46143 .678 .46761 .68882 .4642 .68368 .45801 Mtetra
.68368 .45801 .68882 .4642 .69969 .46079 .69458 .45457 Mtetra
.69458 .45457 .69969 .46079 .7106 .45737 .70551 .45112 Mtetra
.657 .753 .92 r
.70551 .45112 .7106 .45737 .72155 .45394 .71649 .44766 Mtetra
.71649 .44766 .72155 .45394 .73254 .45049 .72751 .44419 Mtetra
.72751 .44419 .73254 .45049 .74357 .44703 .73858 .44071 Mtetra
.73858 .44071 .74357 .44703 .75465 .44357 .74968 .43722 Mtetra
.74968 .43722 .75465 .44357 .76577 .44008 .76083 .43371 Mtetra
.657 .752 .92 r
.76083 .43371 .76577 .44008 .77693 .43659 .77203 .43019 Mtetra
.77203 .43019 .77693 .43659 .78814 .43309 .78326 .42666 Mtetra
.78326 .42666 .78814 .43309 .79939 .42957 .79455 .42311 Mtetra
.79455 .42311 .79939 .42957 .81068 .42604 .80587 .41956 Mtetra
.80587 .41956 .81068 .42604 .82202 .42249 .81724 .41599 Mtetra
.81724 .41599 .82202 .42249 .8334 .41893 .82865 .4124 Mtetra
.82865 .4124 .8334 .41893 .84483 .41536 .84011 .40881 Mtetra
.84011 .40881 .84483 .41536 .8563 .41178 .85162 .4052 Mtetra
.85162 .4052 .8563 .41178 .86782 .40818 .86317 .40157 Mtetra
.86317 .40157 .86782 .40818 .87938 .40457 .87476 .39793 Mtetra
.87476 .39793 .87938 .40457 .89099 .40094 .8864 .39428 Mtetra
.584 .701 .923 r
.26413 .5813 .27024 .58749 .27946 .5866 .2734 .57996 Mtetra
.189 .493 .903 r
.2734 .57996 .27946 .5866 .28945 .57528 .28236 .58353 Mtetra
.57 .834 .478 r
.28236 .58353 .28945 .57528 .29848 .578 .29246 .5714 Mtetra
.573 .685 .916 r
.29246 .5714 .29848 .578 .30786 .57645 .30182 .57031 Mtetra
.579 .703 .927 r
.30182 .57031 .30786 .57645 .31712 .57746 .31123 .56901 Mtetra
.843 .71 .716 r
.31123 .56901 .31712 .57746 .32708 .56741 .32166 .55153 Mtetra
.226 .292 .722 r
.32166 .55153 .32708 .56741 .33652 .56657 .33054 .56034 Mtetra
.601 .709 .92 r
.33054 .56034 .33652 .56657 .34606 .56479 .34009 .55862 Mtetra
.579 .704 .928 r
.34009 .55862 .34606 .56479 .35545 .56676 .34966 .55729 Mtetra
.808 .693 .738 r
.34966 .55729 .35545 .56676 .36552 .5557 .35987 .54394 Mtetra
.364 .446 .812 r
.35987 .54394 .36552 .5557 .37514 .5545 .36923 .54828 Mtetra
.61 .715 .92 r
.36923 .54828 .37514 .5545 .38485 .55242 .37895 .54633 Mtetra
.608 .719 .924 r
.37895 .54633 .38485 .55242 .39455 .55134 .38871 .54439 Mtetra
0 .249 .754 r
.38871 .54439 .39455 .55134 .40464 .54084 .39816 .5515 Mtetra
0 0 0 r
.39816 .5515 .40464 .54084 .41434 .54179 .40853 .5352 Mtetra
.598 .701 .915 r
.40853 .5352 .41434 .54179 .4242 .53958 .41839 .53351 Mtetra
.627 .729 .921 r
.41839 .53351 .4242 .53958 .43411 .53722 .42831 .53111 Mtetra
.617 .726 .923 r
.42831 .53111 .43411 .53722 .44403 .53575 .43827 .52892 Mtetra
.263 .531 .916 r
.43827 .52892 .44403 .53575 .45422 .5239 .44815 .53219 Mtetra
0 0 0 r
.44815 .53219 .45422 .5239 .46413 .52609 .45842 .51931 Mtetra
.597 .697 .913 r
.45842 .51931 .46413 .52609 .47419 .52374 .46849 .51762 Mtetra
.634 .734 .92 r
.46849 .51762 .47419 .52374 .48429 .52102 .47861 .51499 Mtetra
.64 .74 .921 r
.47861 .51499 .48429 .52102 .49443 .51826 .48877 .5122 Mtetra
.638 .739 .921 r
.48877 .5122 .49443 .51826 .50461 .51567 .49898 .50946 Mtetra
.618 .727 .924 r
.49898 .50946 .50461 .51567 .51483 .51461 .50922 .50718 Mtetra
.874 .458 .023 r
.50922 .50718 .51483 .51461 .5251 .50432 .51947 .5326 Mtetra
0 0 .085 r
.51947 .5326 .5251 .50432 .5354 .50394 .52984 .49733 Mtetra
.617 .714 .915 r
.52984 .49733 .5354 .50394 .54573 .50125 .5402 .49509 Mtetra
.644 .74 .919 r
.5402 .49509 .54573 .50125 .55611 .49823 .5506 .49216 Mtetra
.651 .747 .92 r
.5506 .49216 .55611 .49823 .56652 .49507 .56104 .48903 Mtetra
.654 .75 .92 r
.56104 .48903 .56652 .49507 .57697 .49183 .57152 .4858 Mtetra
.656 .752 .92 r
.57152 .4858 .57697 .49183 .58747 .48854 .58204 .4825 Mtetra
.658 .753 .92 r
.58204 .4825 .58747 .48854 .598 .4852 .59259 .47915 Mtetra
.659 .754 .92 r
.59259 .47915 .598 .4852 .60857 .48183 .60319 .47577 Mtetra
.60319 .47577 .60857 .48183 .61917 .47845 .61383 .47237 Mtetra
.61383 .47237 .61917 .47845 .62982 .47506 .6245 .46895 Mtetra
.6245 .46895 .62982 .47506 .64051 .47166 .63522 .46553 Mtetra
.658 .754 .92 r
.63522 .46553 .64051 .47166 .65124 .46826 .64598 .4621 Mtetra
.658 .753 .92 r
.64598 .4621 .65124 .46826 .66201 .46485 .65678 .45866 Mtetra
.65678 .45866 .66201 .46485 .67283 .46143 .66762 .45522 Mtetra
.66762 .45522 .67283 .46143 .68368 .45801 .6785 .45176 Mtetra
.6785 .45176 .68368 .45801 .69458 .45457 .68942 .4483 Mtetra
.68942 .4483 .69458 .45457 .70551 .45112 .70039 .44483 Mtetra
.657 .753 .92 r
.70039 .44483 .70551 .45112 .71649 .44766 .7114 .44134 Mtetra
.7114 .44134 .71649 .44766 .72751 .44419 .72245 .43785 Mtetra
.72245 .43785 .72751 .44419 .73858 .44071 .73354 .43434 Mtetra
.73354 .43434 .73858 .44071 .74968 .43722 .74468 .43082 Mtetra
.74468 .43082 .74968 .43722 .76083 .43371 .75586 .42729 Mtetra
.657 .752 .92 r
.75586 .42729 .76083 .43371 .77203 .43019 .76709 .42374 Mtetra
.76709 .42374 .77203 .43019 .78326 .42666 .77836 .42019 Mtetra
.77836 .42019 .78326 .42666 .79455 .42311 .78967 .41662 Mtetra
.78967 .41662 .79455 .42311 .80587 .41956 .80102 .41303 Mtetra
.80102 .41303 .80587 .41956 .81724 .41599 .81243 .40944 Mtetra
.81243 .40944 .81724 .41599 .82865 .4124 .82387 .40583 Mtetra
.82387 .40583 .82865 .4124 .84011 .40881 .83536 .4022 Mtetra
.83536 .4022 .84011 .40881 .85162 .4052 .8469 .39856 Mtetra
.8469 .39856 .85162 .4052 .86317 .40157 .85848 .39491 Mtetra
.85848 .39491 .86317 .40157 .87476 .39793 .87011 .39125 Mtetra
.87011 .39125 .87476 .39793 .8864 .39428 .88179 .38757 Mtetra
.557 .671 .914 r
.25804 .57449 .26413 .5813 .2734 .57996 .26727 .57374 Mtetra
.559 .693 .93 r
.26727 .57374 .2734 .57996 .28236 .58353 .27656 .57281 Mtetra
.776 .664 .739 r
.27656 .57281 .28236 .58353 .29246 .5714 .28663 .5614 Mtetra
.409 .51 .85 r
.28663 .5614 .29246 .5714 .30182 .57031 .29574 .5641 Mtetra
.594 .708 .922 r
.29574 .5641 .30182 .57031 .31123 .56901 .30519 .5625 Mtetra
.435 .632 .937 r
.30519 .5625 .31123 .56901 .32166 .55153 .31452 .56348 Mtetra
0 0 0 r
.31452 .56348 .32166 .55153 .33054 .56034 .32456 .55335 Mtetra
.563 .671 .911 r
.32456 .55335 .33054 .56034 .34009 .55862 .33408 .55247 Mtetra
.604 .715 .923 r
.33408 .55247 .34009 .55862 .34966 .55729 .34369 .55064 Mtetra
.362 .591 .933 r
.34369 .55064 .34966 .55729 .35987 .54394 .35316 .55258 Mtetra
0 0 0 r
.35316 .55258 .35987 .54394 .36923 .54828 .36332 .54144 Mtetra
.579 .684 .913 r
.36332 .54144 .36923 .54828 .37895 .54633 .37301 .5402 Mtetra
.616 .722 .922 r
.37301 .5402 .37895 .54633 .38871 .54439 .3828 .53807 Mtetra
.566 .699 .93 r
.3828 .53807 .38871 .54439 .39816 .5515 .39258 .53694 Mtetra
.738 .613 .719 r
.39258 .53694 .39816 .5515 .40853 .5352 .40276 .52635 Mtetra
.491 .586 .877 r
.40276 .52635 .40853 .5352 .41839 .53351 .41254 .52727 Mtetra
.62 .723 .919 r
.41254 .52727 .41839 .53351 .42831 .53111 .42248 .52501 Mtetra
.626 .73 .922 r
.42248 .52501 .42831 .53111 .43827 .52892 .43247 .5226 Mtetra
.585 .708 .928 r
.43247 .5226 .43827 .52892 .44815 .53219 .44247 .52108 Mtetra
.782 .67 .74 r
.44247 .52108 .44815 .53219 .45842 .51931 .45275 .50913 Mtetra
.45 .533 .851 r
.45275 .50913 .45842 .51931 .46849 .51762 .46275 .5113 Mtetra
.625 .724 .918 r
.46275 .5113 .46849 .51762 .47861 .51499 .47289 .50889 Mtetra
.639 .738 .92 r
.47289 .50889 .47861 .51499 .48877 .5122 .48308 .50612 Mtetra
.64 .74 .921 r
.48308 .50612 .48877 .5122 .49898 .50946 .49331 .5033 Mtetra
.632 .735 .922 r
.49331 .5033 .49898 .50946 .50922 .50718 .50357 .50066 Mtetra
.562 .696 .93 r
.50357 .50066 .50922 .50718 .51947 .5326 .51388 .49956 Mtetra
.655 .485 .642 r
.51388 .49956 .51947 .5326 .52984 .49733 .52424 .48918 Mtetra
.546 .638 .892 r
.52424 .48918 .52984 .49733 .5402 .49509 .53462 .48876 Mtetra
.636 .733 .918 r
.53462 .48876 .5402 .49509 .5506 .49216 .54505 .48601 Mtetra
.648 .744 .92 r
.54505 .48601 .5506 .49216 .56104 .48903 .55552 .48293 Mtetra
.653 .749 .92 r
.55552 .48293 .56104 .48903 .57152 .4858 .56602 .47972 Mtetra
.655 .751 .92 r
.56602 .47972 .57152 .4858 .58204 .4825 .57657 .47642 Mtetra
.657 .752 .92 r
.57657 .47642 .58204 .4825 .59259 .47915 .58715 .47306 Mtetra
.658 .753 .92 r
.58715 .47306 .59259 .47915 .60319 .47577 .59778 .46967 Mtetra
.659 .754 .92 r
.59778 .46967 .60319 .47577 .61383 .47237 .60844 .46624 Mtetra
.60844 .46624 .61383 .47237 .6245 .46895 .61914 .4628 Mtetra
.61914 .4628 .6245 .46895 .63522 .46553 .62989 .45935 Mtetra
.62989 .45935 .63522 .46553 .64598 .4621 .64068 .45589 Mtetra
.658 .753 .92 r
.64068 .45589 .64598 .4621 .65678 .45866 .6515 .45243 Mtetra
.6515 .45243 .65678 .45866 .66762 .45522 .66237 .44896 Mtetra
.66237 .44896 .66762 .45522 .6785 .45176 .67328 .44548 Mtetra
.67328 .44548 .6785 .45176 .68942 .4483 .68424 .44199 Mtetra
.68424 .44199 .68942 .4483 .70039 .44483 .69523 .43849 Mtetra
.69523 .43849 .70039 .44483 .7114 .44134 .70627 .43498 Mtetra
.657 .753 .92 r
.70627 .43498 .7114 .44134 .72245 .43785 .71735 .43146 Mtetra
.71735 .43146 .72245 .43785 .73354 .43434 .72848 .42793 Mtetra
.72848 .42793 .73354 .43434 .74468 .43082 .73964 .42438 Mtetra
.73964 .42438 .74468 .43082 .75586 .42729 .75085 .42082 Mtetra
.75085 .42082 .75586 .42729 .76709 .42374 .76211 .41725 Mtetra
.657 .752 .92 r
.76211 .41725 .76709 .42374 .77836 .42019 .77341 .41367 Mtetra
.77341 .41367 .77836 .42019 .78967 .41662 .78475 .41007 Mtetra
.78475 .41007 .78967 .41662 .80102 .41303 .79614 .40646 Mtetra
.79614 .40646 .80102 .41303 .81243 .40944 .80758 .40284 Mtetra
.80758 .40284 .81243 .40944 .82387 .40583 .81905 .3992 Mtetra
.81905 .3992 .82387 .40583 .83536 .4022 .83058 .39555 Mtetra
.83058 .39555 .83536 .4022 .8469 .39856 .84215 .39189 Mtetra
.84215 .39189 .8469 .39856 .85848 .39491 .85376 .38821 Mtetra
.85376 .38821 .85848 .39491 .87011 .39125 .86543 .38452 Mtetra
.86543 .38452 .87011 .39125 .88179 .38757 .87714 .38081 Mtetra
.271 .36 .771 r
.25242 .5612 .25804 .57449 .26727 .57374 .2611 .56746 Mtetra
.584 .701 .923 r
.2611 .56746 .26727 .57374 .27656 .57281 .27044 .56607 Mtetra
.191 .494 .904 r
.27044 .56607 .27656 .57281 .28663 .5614 .27946 .56962 Mtetra
.581 .843 .489 r
.27946 .56962 .28663 .5614 .29574 .5641 .28965 .5574 Mtetra
.573 .685 .916 r
.28965 .5574 .29574 .5641 .30519 .5625 .29908 .55627 Mtetra
.579 .703 .927 r
.29908 .55627 .30519 .5625 .31452 .56348 .30857 .55493 Mtetra
.844 .711 .716 r
.30857 .55493 .31452 .56348 .32456 .55335 .3191 .53733 Mtetra
.224 .29 .722 r
.3191 .53733 .32456 .55335 .33408 .55247 .32804 .54614 Mtetra
.6 .709 .92 r
.32804 .54614 .33408 .55247 .34369 .55064 .33767 .54437 Mtetra
.579 .704 .928 r
.33767 .54437 .34369 .55064 .35316 .55258 .34731 .543 Mtetra
.808 .694 .738 r
.34731 .543 .35316 .55258 .36332 .54144 .35761 .52955 Mtetra
.363 .445 .812 r
.35761 .52955 .36332 .54144 .37301 .5402 .36705 .53387 Mtetra
.61 .715 .92 r
.36705 .53387 .37301 .5402 .3828 .53807 .37684 .53187 Mtetra
.608 .719 .924 r
.37684 .53187 .3828 .53807 .39258 .53694 .38668 .52988 Mtetra
0 .253 .757 r
.38668 .52988 .39258 .53694 .40276 .52635 .39621 .53699 Mtetra
0 0 0 r
.39621 .53699 .40276 .52635 .41254 .52727 .40667 .52058 Mtetra
.598 .701 .915 r
.40667 .52058 .41254 .52727 .42248 .52501 .41661 .51884 Mtetra
.627 .729 .921 r
.41661 .51884 .42248 .52501 .43247 .5226 .42662 .51639 Mtetra
.617 .726 .923 r
.42662 .51639 .43247 .5226 .44247 .52108 .43666 .51414 Mtetra
.265 .531 .916 r
.43666 .51414 .44247 .52108 .45275 .50913 .44662 .51739 Mtetra
0 0 0 r
.44662 .51739 .45275 .50913 .46275 .5113 .45698 .50442 Mtetra
.597 .697 .913 r
.45698 .50442 .46275 .5113 .47289 .50889 .46713 .50267 Mtetra
.634 .734 .92 r
.46713 .50267 .47289 .50889 .48308 .50612 .47734 .49999 Mtetra
.64 .74 .921 r
.47734 .49999 .48308 .50612 .49331 .5033 .48759 .49715 Mtetra
.638 .739 .921 r
.48759 .49715 .49331 .5033 .50357 .50066 .49789 .49435 Mtetra
.618 .727 .924 r
.49789 .49435 .50357 .50066 .51388 .49956 .50822 .49202 Mtetra
.87 .454 .014 r
.50822 .49202 .51388 .49956 .52424 .48918 .51854 .5175 Mtetra
0 0 .077 r
.51854 .5175 .52424 .48918 .53462 .48876 .52901 .48204 Mtetra
.617 .714 .915 r
.52901 .48204 .53462 .48876 .54505 .48601 .53946 .47975 Mtetra
.644 .74 .919 r
.53946 .47975 .54505 .48601 .55552 .48293 .54995 .47676 Mtetra
.651 .747 .92 r
.54995 .47676 .55552 .48293 .56602 .47972 .56049 .47357 Mtetra
.654 .75 .92 r
.56049 .47357 .56602 .47972 .57657 .47642 .57106 .47028 Mtetra
.656 .752 .92 r
.57106 .47028 .57657 .47642 .58715 .47306 .58167 .46692 Mtetra
.658 .753 .92 r
.58167 .46692 .58715 .47306 .59778 .46967 .59232 .46352 Mtetra
.659 .754 .92 r
.59232 .46352 .59778 .46967 .60844 .46624 .60301 .46007 Mtetra
.60301 .46007 .60844 .46624 .61914 .4628 .61375 .45661 Mtetra
.61375 .45661 .61914 .4628 .62989 .45935 .62452 .45313 Mtetra
.62452 .45313 .62989 .45935 .64068 .45589 .63533 .44964 Mtetra
.658 .754 .92 r
.63533 .44964 .64068 .45589 .6515 .45243 .64619 .44615 Mtetra
.658 .753 .92 r
.64619 .44615 .6515 .45243 .66237 .44896 .65709 .44266 Mtetra
.65709 .44266 .66237 .44896 .67328 .44548 .66803 .43915 Mtetra
.66803 .43915 .67328 .44548 .68424 .44199 .67901 .43563 Mtetra
.67901 .43563 .68424 .44199 .69523 .43849 .69004 .43211 Mtetra
.69004 .43211 .69523 .43849 .70627 .43498 .7011 .42857 Mtetra
.657 .753 .92 r
.7011 .42857 .70627 .43498 .71735 .43146 .71222 .42502 Mtetra
.71222 .42502 .71735 .43146 .72848 .42793 .72337 .42146 Mtetra
.72337 .42146 .72848 .42793 .73964 .42438 .73457 .41789 Mtetra
.73457 .41789 .73964 .42438 .75085 .42082 .74581 .41431 Mtetra
.74581 .41431 .75085 .42082 .76211 .41725 .7571 .41071 Mtetra
.657 .752 .92 r
.7571 .41071 .76211 .41725 .77341 .41367 .76843 .4071 Mtetra
.76843 .4071 .77341 .41367 .78475 .41007 .7798 .40348 Mtetra
.7798 .40348 .78475 .41007 .79614 .40646 .79122 .39984 Mtetra
.79122 .39984 .79614 .40646 .80758 .40284 .80269 .39619 Mtetra
.80269 .39619 .80758 .40284 .81905 .3992 .8142 .39253 Mtetra
.8142 .39253 .81905 .3992 .83058 .39555 .82576 .38885 Mtetra
.82576 .38885 .83058 .39555 .84215 .39189 .83736 .38516 Mtetra
.83736 .38516 .84215 .39189 .85376 .38821 .84901 .38145 Mtetra
.84901 .38145 .85376 .38821 .86543 .38452 .86071 .37773 Mtetra
.86071 .37773 .86543 .38452 .87714 .38081 .87245 .374 Mtetra
0 0 0 r
.2449 .57088 .25242 .5612 .2611 .56746 .25494 .56054 Mtetra
.556 .671 .914 r
.25494 .56054 .2611 .56746 .27044 .56607 .26425 .55976 Mtetra
.559 .693 .93 r
.26425 .55976 .27044 .56607 .27946 .56962 .27361 .55879 Mtetra
.777 .665 .74 r
.27361 .55879 .27946 .56962 .28965 .5574 .28377 .54729 Mtetra
.409 .51 .85 r
.28377 .54729 .28965 .5574 .29908 .55627 .29294 .54996 Mtetra
.594 .708 .922 r
.29294 .54996 .29908 .55627 .30857 .55493 .30247 .54832 Mtetra
.436 .632 .937 r
.30247 .54832 .30857 .55493 .3191 .53733 .31187 .54926 Mtetra
0 0 0 r
.31187 .54926 .3191 .53733 .32804 .54614 .322 .53905 Mtetra
.563 .671 .911 r
.322 .53905 .32804 .54614 .33767 .54437 .33159 .53813 Mtetra
.604 .715 .923 r
.33159 .53813 .33767 .54437 .34731 .543 .34129 .53625 Mtetra
.363 .592 .933 r
.34129 .53625 .34731 .543 .35761 .52955 .35083 .53816 Mtetra
0 0 0 r
.35083 .53816 .35761 .52955 .36705 .53387 .36107 .52693 Mtetra
.579 .684 .913 r
.36107 .52693 .36705 .53387 .37684 .53187 .37085 .52564 Mtetra
.616 .722 .922 r
.37085 .52564 .37684 .53187 .38668 .52988 .38071 .52346 Mtetra
.567 .698 .93 r
.38071 .52346 .38668 .52988 .39621 .53699 .39058 .52229 Mtetra
.738 .614 .719 r
.39058 .52229 .39621 .53699 .40667 .52058 .40084 .51162 Mtetra
.491 .586 .877 r
.40084 .51162 .40667 .52058 .41661 .51884 .4107 .51249 Mtetra
.62 .723 .92 r
.4107 .51249 .41661 .51884 .42662 .51639 .42073 .51019 Mtetra
.626 .73 .922 r
.42073 .51019 .42662 .51639 .43666 .51414 .4308 .50772 Mtetra
.585 .708 .928 r
.4308 .50772 .43666 .51414 .44662 .51739 .44089 .50615 Mtetra
.783 .671 .74 r
.44089 .50615 .44662 .51739 .45698 .50442 .45126 .49411 Mtetra
.449 .533 .851 r
.45126 .49411 .45698 .50442 .46713 .50267 .46134 .49624 Mtetra
.625 .724 .918 r
.46134 .49624 .46713 .50267 .47734 .49999 .47157 .49378 Mtetra
.639 .738 .92 r
.47157 .49378 .47734 .49999 .48759 .49715 .48184 .49096 Mtetra
.64 .74 .921 r
.48184 .49096 .48759 .49715 .49789 .49435 .49216 .48809 Mtetra
.633 .735 .922 r
.49216 .48809 .49789 .49435 .50822 .49202 .50252 .48539 Mtetra
.562 .696 .93 r
.50252 .48539 .50822 .49202 .51854 .5175 .51291 .48424 Mtetra
.654 .484 .642 r
.51291 .48424 .51854 .5175 .52901 .48204 .52336 .47377 Mtetra
.546 .638 .892 r
.52336 .47377 .52901 .48204 .53946 .47975 .53384 .4733 Mtetra
.636 .733 .918 r
.53384 .4733 .53946 .47975 .54995 .47676 .54436 .4705 Mtetra
.648 .744 .92 r
.54436 .4705 .54995 .47676 .56049 .47357 .55491 .46736 Mtetra
.653 .749 .92 r
.55491 .46736 .56049 .47357 .57106 .47028 .56551 .46409 Mtetra
.655 .751 .92 r
.56551 .46409 .57106 .47028 .58167 .46692 .57615 .46073 Mtetra
.657 .752 .92 r
.57615 .46073 .58167 .46692 .59232 .46352 .58683 .45731 Mtetra
.658 .753 .92 r
.58683 .45731 .59232 .46352 .60301 .46007 .59755 .45386 Mtetra
.659 .754 .92 r
.59755 .45386 .60301 .46007 .61375 .45661 .60831 .45037 Mtetra
.60831 .45037 .61375 .45661 .62452 .45313 .61911 .44687 Mtetra
.61911 .44687 .62452 .45313 .63533 .44964 .62996 .44335 Mtetra
.62996 .44335 .63533 .44964 .64619 .44615 .64084 .43983 Mtetra
.658 .753 .92 r
.64084 .43983 .64619 .44615 .65709 .44266 .65177 .43631 Mtetra
.65177 .43631 .65709 .44266 .66803 .43915 .66274 .43277 Mtetra
.66274 .43277 .66803 .43915 .67901 .43563 .67375 .42923 Mtetra
.67375 .42923 .67901 .43563 .69004 .43211 .6848 .42568 Mtetra
.6848 .42568 .69004 .43211 .7011 .42857 .6959 .42212 Mtetra
.6959 .42212 .7011 .42857 .71222 .42502 .70704 .41854 Mtetra
.657 .753 .92 r
.70704 .41854 .71222 .42502 .72337 .42146 .71823 .41496 Mtetra
.71823 .41496 .72337 .42146 .73457 .41789 .72946 .41136 Mtetra
.72946 .41136 .73457 .41789 .74581 .41431 .74073 .40775 Mtetra
.74073 .40775 .74581 .41431 .7571 .41071 .75205 .40412 Mtetra
.75205 .40412 .7571 .41071 .76843 .4071 .76341 .40048 Mtetra
.657 .752 .92 r
.76341 .40048 .76843 .4071 .7798 .40348 .77482 .39683 Mtetra
.77482 .39683 .7798 .40348 .79122 .39984 .78627 .39317 Mtetra
.78627 .39317 .79122 .39984 .80269 .39619 .79777 .38949 Mtetra
.79777 .38949 .80269 .39619 .8142 .39253 .80931 .3858 Mtetra
.80931 .3858 .8142 .39253 .82576 .38885 .8209 .3821 Mtetra
.8209 .3821 .82576 .38885 .83736 .38516 .83254 .37838 Mtetra
.83254 .37838 .83736 .38516 .84901 .38145 .84422 .37465 Mtetra
.84422 .37465 .84901 .38145 .86071 .37773 .85595 .3709 Mtetra
.85595 .3709 .86071 .37773 .87245 .374 .86773 .36714 Mtetra
.82 .699 .731 r
.23885 .56189 .2449 .57088 .25494 .56054 .24928 .54713 Mtetra
.269 .359 .771 r
.24928 .54713 .25494 .56054 .26425 .55976 .25802 .55338 Mtetra
.584 .701 .923 r
.25802 .55338 .26425 .55976 .27361 .55879 .26743 .55195 Mtetra
.194 .495 .904 r
.26743 .55195 .27361 .55879 .28377 .54729 .27652 .55547 Mtetra
.592 .851 .5 r
.27652 .55547 .28377 .54729 .29294 .54996 .2868 .54317 Mtetra
.573 .685 .916 r
.2868 .54317 .29294 .54996 .30247 .54832 .2963 .54199 Mtetra
.579 .703 .927 r
.2963 .54199 .30247 .54832 .31187 .54926 .30587 .5406 Mtetra
.845 .712 .716 r
.30587 .5406 .31187 .54926 .322 .53905 .31649 .52289 Mtetra
.221 .288 .721 r
.31649 .52289 .322 .53905 .33159 .53813 .32549 .53169 Mtetra
.6 .709 .92 r
.32549 .53169 .33159 .53813 .34129 .53625 .3352 .52988 Mtetra
.579 .704 .928 r
.3352 .52988 .34129 .53625 .35083 .53816 .34492 .52847 Mtetra
.809 .694 .738 r
.34492 .52847 .35083 .53816 .36107 .52693 .35531 .51491 Mtetra
.361 .445 .812 r
.35531 .51491 .36107 .52693 .37085 .52564 .36482 .51922 Mtetra
.61 .715 .92 r
.36482 .51922 .37085 .52564 .38071 .52346 .3747 .51716 Mtetra
.608 .719 .924 r
.3747 .51716 .38071 .52346 .39058 .52229 .38462 .51513 Mtetra
0 .257 .76 r
.38462 .51513 .39058 .52229 .40084 .51162 .39422 .52222 Mtetra
0 0 0 r
.39422 .52222 .40084 .51162 .4107 .51249 .40477 .5057 Mtetra
.598 .701 .915 r
.40477 .5057 .4107 .51249 .42073 .51019 .4148 .50391 Mtetra
.627 .729 .921 r
.4148 .50391 .42073 .51019 .4308 .50772 .42489 .50141 Mtetra
.617 .726 .923 r
.42489 .50141 .4308 .50772 .44089 .50615 .43502 .49911 Mtetra
.268 .532 .916 r
.43502 .49911 .44089 .50615 .45126 .49411 .44506 .50233 Mtetra
0 0 0 r
.44506 .50233 .45126 .49411 .46134 .49624 .45552 .48925 Mtetra
.597 .697 .913 r
.45552 .48925 .46134 .49624 .47157 .49378 .46575 .48746 Mtetra
.634 .734 .92 r
.46575 .48746 .47157 .49378 .48184 .49096 .47605 .48472 Mtetra
.64 .74 .921 r
.47605 .48472 .48184 .49096 .49216 .48809 .48639 .48182 Mtetra
.638 .739 .921 r
.48639 .48182 .49216 .48809 .50252 .48539 .49677 .47897 Mtetra
.618 .727 .924 r
.49677 .47897 .50252 .48539 .51291 .48424 .5072 .47658 Mtetra
.866 .449 .005 r
.5072 .47658 .51291 .48424 .52336 .47377 .5176 .50213 Mtetra
0 0 .07 r
.5176 .50213 .52336 .47377 .53384 .4733 .52817 .46647 Mtetra
.617 .714 .915 r
.52817 .46647 .53384 .4733 .54436 .4705 .53872 .46412 Mtetra
.644 .74 .919 r
.53872 .46412 .54436 .4705 .55491 .46736 .5493 .46108 Mtetra
.651 .747 .92 r
.5493 .46108 .55491 .46736 .56551 .46409 .55993 .45783 Mtetra
.654 .75 .92 r
.55993 .45783 .56551 .46409 .57615 .46073 .57059 .45448 Mtetra
.656 .752 .92 r
.57059 .45448 .57615 .46073 .58683 .45731 .5813 .45106 Mtetra
.658 .753 .92 r
.5813 .45106 .58683 .45731 .59755 .45386 .59205 .44759 Mtetra
.659 .754 .92 r
.59205 .44759 .59755 .45386 .60831 .45037 .60284 .44409 Mtetra
.60284 .44409 .60831 .45037 .61911 .44687 .61367 .44056 Mtetra
.61367 .44056 .61911 .44687 .62996 .44335 .62454 .43702 Mtetra
.62454 .43702 .62996 .44335 .64084 .43983 .63545 .43347 Mtetra
.658 .754 .92 r
.63545 .43347 .64084 .43983 .65177 .43631 .64641 .42992 Mtetra
.658 .753 .92 r
.64641 .42992 .65177 .43631 .66274 .43277 .65741 .42636 Mtetra
.65741 .42636 .66274 .43277 .67375 .42923 .66845 .42279 Mtetra
.66845 .42279 .67375 .42923 .6848 .42568 .67953 .41921 Mtetra
.67953 .41921 .6848 .42568 .6959 .42212 .69066 .41562 Mtetra
.69066 .41562 .6959 .42212 .70704 .41854 .70183 .41201 Mtetra
.657 .753 .92 r
.70183 .41201 .70704 .41854 .71823 .41496 .71305 .4084 Mtetra
.71305 .4084 .71823 .41496 .72946 .41136 .72431 .40477 Mtetra
.72431 .40477 .72946 .41136 .74073 .40775 .73561 .40114 Mtetra
.73561 .40114 .74073 .40775 .75205 .40412 .74696 .39749 Mtetra
.74696 .39749 .75205 .40412 .76341 .40048 .75835 .39382 Mtetra
.657 .752 .92 r
.75835 .39382 .76341 .40048 .77482 .39683 .76979 .39014 Mtetra
.76979 .39014 .77482 .39683 .78627 .39317 .78128 .38645 Mtetra
.78128 .38645 .78627 .39317 .79777 .38949 .79281 .38275 Mtetra
.79281 .38275 .79777 .38949 .80931 .3858 .80439 .37903 Mtetra
.80439 .37903 .80931 .3858 .8209 .3821 .81601 .3753 Mtetra
.81601 .3753 .8209 .3821 .83254 .37838 .82768 .37155 Mtetra
.82768 .37155 .83254 .37838 .84422 .37465 .8394 .36779 Mtetra
.8394 .36779 .84422 .37465 .85595 .3709 .85116 .36401 Mtetra
.85116 .36401 .85595 .3709 .86773 .36714 .86297 .36022 Mtetra
.376 .601 .935 r
.23257 .55519 .23885 .56189 .24928 .54713 .24167 .55679 Mtetra
0 0 0 r
.24167 .55679 .24928 .54713 .25802 .55338 .2518 .54636 Mtetra
.556 .671 .914 r
.2518 .54636 .25802 .55338 .26743 .55195 .26117 .54554 Mtetra
.56 .693 .93 r
.26117 .54554 .26743 .55195 .27652 .55547 .27061 .54452 Mtetra
.777 .665 .74 r
.27061 .54452 .27652 .55547 .2868 .54317 .28086 .53294 Mtetra
.408 .509 .85 r
.28086 .53294 .2868 .54317 .2963 .54199 .2901 .53558 Mtetra
.594 .708 .922 r
.2901 .53558 .2963 .54199 .30587 .5406 .2997 .53389 Mtetra
.436 .632 .937 r
.2997 .53389 .30587 .5406 .31649 .52289 .30917 .5348 Mtetra
0 0 0 r
.30917 .5348 .31649 .52289 .32549 .53169 .3194 .52451 Mtetra
.563 .671 .911 r
.3194 .52451 .32549 .53169 .3352 .52988 .32907 .52354 Mtetra
.604 .715 .923 r
.32907 .52354 .3352 .52988 .34492 .52847 .33884 .52161 Mtetra
.364 .592 .932 r
.33884 .52161 .34492 .52847 .35531 .51491 .34845 .52348 Mtetra
0 0 0 r
.34845 .52348 .35531 .51491 .36482 .51922 .35879 .51216 Mtetra
.579 .684 .913 r
.35879 .51216 .36482 .51922 .3747 .51716 .36865 .51083 Mtetra
.616 .722 .922 r
.36865 .51083 .3747 .51716 .38462 .51513 .37859 .5086 Mtetra
.567 .698 .93 r
.37859 .5086 .38462 .51513 .39422 .52222 .38854 .50738 Mtetra
.739 .614 .719 r
.38854 .50738 .39422 .52222 .40477 .5057 .39889 .49662 Mtetra
.491 .586 .878 r
.39889 .49662 .40477 .5057 .4148 .50391 .40884 .49746 Mtetra
.62 .723 .92 r
.40884 .49746 .4148 .50391 .42489 .50141 .41894 .4951 Mtetra
.626 .73 .922 r
.41894 .4951 .42489 .50141 .43502 .49911 .4291 .49257 Mtetra
.585 .708 .928 r
.4291 .49257 .43502 .49911 .44506 .50233 .43927 .49096 Mtetra
.783 .671 .74 r
.43927 .49096 .44506 .50233 .45552 .48925 .44974 .47883 Mtetra
.449 .533 .851 r
.44974 .47883 .45552 .48925 .46575 .48746 .4599 .48092 Mtetra
.625 .724 .918 r
.4599 .48092 .46575 .48746 .47605 .48472 .47022 .47841 Mtetra
.639 .738 .92 r
.47022 .47841 .47605 .48472 .48639 .48182 .48058 .47553 Mtetra
.64 .74 .921 r
.48058 .47553 .48639 .48182 .49677 .47897 .49099 .4726 Mtetra
.633 .735 .922 r
.49099 .4726 .49677 .47897 .5072 .47658 .50144 .46984 Mtetra
.562 .696 .93 r
.50144 .46984 .5072 .47658 .5176 .50213 .51192 .46864 Mtetra
.654 .483 .641 r
.51192 .46864 .5176 .50213 .52817 .46647 .52247 .45809 Mtetra
.546 .638 .892 r
.52247 .45809 .52817 .46647 .53872 .46412 .53304 .45757 Mtetra
.636 .733 .919 r
.53304 .45757 .53872 .46412 .5493 .46108 .54365 .45471 Mtetra
.648 .744 .92 r
.54365 .45471 .5493 .46108 .55993 .45783 .5543 .45151 Mtetra
.653 .749 .92 r
.5543 .45151 .55993 .45783 .57059 .45448 .565 .44817 Mtetra
.655 .751 .92 r
.565 .44817 .57059 .45448 .5813 .45106 .57573 .44476 Mtetra
.657 .752 .92 r
.57573 .44476 .5813 .45106 .59205 .44759 .58651 .44128 Mtetra
.658 .753 .92 r
.58651 .44128 .59205 .44759 .60284 .44409 .59732 .43776 Mtetra
.659 .754 .92 r
.59732 .43776 .60284 .44409 .61367 .44056 .60818 .43421 Mtetra
.60818 .43421 .61367 .44056 .62454 .43702 .61908 .43064 Mtetra
.61908 .43064 .62454 .43702 .63545 .43347 .63002 .42706 Mtetra
.63002 .42706 .63545 .43347 .64641 .42992 .64101 .42348 Mtetra
.658 .753 .92 r
.64101 .42348 .64641 .42992 .65741 .42636 .65204 .41989 Mtetra
.65204 .41989 .65741 .42636 .66845 .42279 .66311 .41629 Mtetra
.66311 .41629 .66845 .42279 .67953 .41921 .67422 .41269 Mtetra
.67422 .41269 .67953 .41921 .69066 .41562 .68538 .40907 Mtetra
.68538 .40907 .69066 .41562 .70183 .41201 .69658 .40544 Mtetra
.69658 .40544 .70183 .41201 .71305 .4084 .70783 .4018 Mtetra
.657 .753 .92 r
.70783 .4018 .71305 .4084 .72431 .40477 .71912 .39814 Mtetra
.71912 .39814 .72431 .40477 .73561 .40114 .73045 .39448 Mtetra
.73045 .39448 .73561 .40114 .74696 .39749 .74184 .3908 Mtetra
.74184 .3908 .74696 .39749 .75835 .39382 .75326 .38711 Mtetra
.75326 .38711 .75835 .39382 .76979 .39014 .76473 .3834 Mtetra
.657 .752 .92 r
.76473 .3834 .76979 .39014 .78128 .38645 .77625 .37969 Mtetra
.77625 .37969 .78128 .38645 .79281 .38275 .78781 .37595 Mtetra
.78781 .37595 .79281 .38275 .80439 .37903 .79942 .37221 Mtetra
.79942 .37221 .80439 .37903 .81601 .3753 .81108 .36845 Mtetra
.81108 .36845 .81601 .3753 .82768 .37155 .82279 .36467 Mtetra
.82279 .36467 .82768 .37155 .8394 .36779 .83454 .36088 Mtetra
.83454 .36088 .8394 .36779 .85116 .36401 .84633 .35708 Mtetra
.84633 .35708 .85116 .36401 .86297 .36022 .85818 .35326 Mtetra
.562 .693 .928 r
.22622 .54874 .23257 .55519 .24167 .55679 .23556 .54768 Mtetra
.821 .699 .731 r
.23556 .54768 .24167 .55679 .2518 .54636 .24608 .53282 Mtetra
.267 .357 .771 r
.24608 .53282 .2518 .54636 .26117 .54554 .25488 .53906 Mtetra
.584 .701 .923 r
.25488 .53906 .26117 .54554 .27061 .54452 .26437 .53758 Mtetra
.196 .496 .904 r
.26437 .53758 .27061 .54452 .28086 .53294 .27352 .54108 Mtetra
.603 .86 .511 r
.27352 .54108 .28086 .53294 .2901 .53558 .28389 .52868 Mtetra
.573 .685 .916 r
.28389 .52868 .2901 .53558 .2997 .53389 .29347 .52746 Mtetra
.579 .703 .927 r
.29347 .52746 .2997 .53389 .30917 .5348 .30311 .52603 Mtetra
.846 .712 .716 r
.30311 .52603 .30917 .5348 .3194 .52451 .31384 .5082 Mtetra
.218 .286 .72 r
.31384 .5082 .3194 .52451 .32907 .52354 .3229 .517 Mtetra
.6 .709 .92 r
.3229 .517 .32907 .52354 .33884 .52161 .33269 .51514 Mtetra
.579 .704 .928 r
.33269 .51514 .33884 .52161 .34845 .52348 .34249 .51367 Mtetra
.81 .695 .739 r
.34249 .51367 .34845 .52348 .35879 .51216 .35298 .50002 Mtetra
.36 .444 .812 r
.35298 .50002 .35879 .51216 .36865 .51083 .36256 .5043 Mtetra
.61 .715 .92 r
.36256 .5043 .36865 .51083 .37859 .5086 .37252 .5022 Mtetra
.608 .719 .924 r
.37252 .5022 .37859 .5086 .38854 .50738 .38252 .50011 Mtetra
0 .261 .763 r
.38252 .50011 .38854 .50738 .39889 .49662 .3922 .50719 Mtetra
0 0 0 r
.3922 .50719 .39889 .49662 .40884 .49746 .40285 .49056 Mtetra
.598 .701 .915 r
.40285 .49056 .40884 .49746 .41894 .4951 .41296 .48871 Mtetra
.627 .729 .921 r
.41296 .48871 .41894 .4951 .4291 .49257 .42313 .48616 Mtetra
.617 .726 .923 r
.42313 .48616 .4291 .49257 .43927 .49096 .43335 .48381 Mtetra
.27 .533 .916 r
.43335 .48381 .43927 .49096 .44974 .47883 .44347 .48699 Mtetra
0 0 0 r
.44347 .48699 .44974 .47883 .4599 .48092 .45403 .47382 Mtetra
.597 .697 .913 r
.45403 .47382 .4599 .48092 .47022 .47841 .46435 .47197 Mtetra
.634 .734 .92 r
.46435 .47197 .47022 .47841 .48058 .47553 .47474 .46918 Mtetra
.64 .74 .921 r
.47474 .46918 .48058 .47553 .49099 .4726 .48517 .46622 Mtetra
.638 .739 .921 r
.48517 .46622 .49099 .4726 .50144 .46984 .49564 .46331 Mtetra
.618 .727 .924 r
.49564 .46331 .50144 .46984 .51192 .46864 .50615 .46087 Mtetra
.862 .444 0 r
.50615 .46087 .51192 .46864 .52247 .45809 .51664 .48648 Mtetra
0 0 .061 r
.51664 .48648 .52247 .45809 .53304 .45757 .52732 .45062 Mtetra
.617 .714 .915 r
.52732 .45062 .53304 .45757 .54365 .45471 .53796 .44822 Mtetra
.644 .74 .919 r
.53796 .44822 .54365 .45471 .5543 .45151 .54864 .44511 Mtetra
.651 .747 .92 r
.54864 .44511 .5543 .45151 .565 .44817 .55936 .4418 Mtetra
.654 .75 .92 r
.55936 .4418 .565 .44817 .57573 .44476 .57012 .43839 Mtetra
.656 .752 .92 r
.57012 .43839 .57573 .44476 .58651 .44128 .58092 .43491 Mtetra
.658 .753 .92 r
.58092 .43491 .58651 .44128 .59732 .43776 .59177 .43138 Mtetra
.659 .754 .92 r
.59177 .43138 .59732 .43776 .60818 .43421 .60266 .42781 Mtetra
.60266 .42781 .60818 .43421 .61908 .43064 .61359 .42422 Mtetra
.61359 .42422 .61908 .43064 .63002 .42706 .62456 .42061 Mtetra
.62456 .42061 .63002 .42706 .64101 .42348 .63557 .417 Mtetra
.658 .754 .92 r
.63557 .417 .64101 .42348 .65204 .41989 .64663 .41338 Mtetra
.658 .753 .92 r
.64663 .41338 .65204 .41989 .66311 .41629 .65773 .40975 Mtetra
.65773 .40975 .66311 .41629 .67422 .41269 .66887 .40612 Mtetra
.66887 .40612 .67422 .41269 .68538 .40907 .68006 .40247 Mtetra
.68006 .40247 .68538 .40907 .69658 .40544 .69129 .39882 Mtetra
.69129 .39882 .69658 .40544 .70783 .4018 .70257 .39515 Mtetra
.657 .753 .92 r
.70257 .39515 .70783 .4018 .71912 .39814 .71389 .39147 Mtetra
.71389 .39147 .71912 .39814 .73045 .39448 .72526 .38777 Mtetra
.72526 .38777 .73045 .39448 .74184 .3908 .73667 .38407 Mtetra
.73667 .38407 .74184 .3908 .75326 .38711 .74813 .38035 Mtetra
.74813 .38035 .75326 .38711 .76473 .3834 .75964 .37661 Mtetra
.657 .752 .92 r
.75964 .37661 .76473 .3834 .77625 .37969 .77119 .37287 Mtetra
.77119 .37287 .77625 .37969 .78781 .37595 .78278 .36911 Mtetra
.78278 .36911 .78781 .37595 .79942 .37221 .79443 .36533 Mtetra
.79443 .36533 .79942 .37221 .81108 .36845 .80612 .36154 Mtetra
.80612 .36154 .81108 .36845 .82279 .36467 .81785 .35774 Mtetra
.81785 .35774 .82279 .36467 .83454 .36088 .82964 .35392 Mtetra
.82964 .35392 .83454 .36088 .84633 .35708 .84147 .35009 Mtetra
.84147 .35009 .84633 .35708 .85818 .35326 .85335 .34624 Mtetra
.569 .688 .921 r
.21986 .54204 .22622 .54874 .23556 .54768 .22921 .54088 Mtetra
.377 .601 .935 r
.22921 .54088 .23556 .54768 .24608 .53282 .23838 .54245 Mtetra
0 0 0 r
.23838 .54245 .24608 .53282 .25488 .53906 .2486 .53194 Mtetra
.556 .671 .914 r
.2486 .53194 .25488 .53906 .26437 .53758 .25805 .53107 Mtetra
.56 .693 .929 r
.25805 .53107 .26437 .53758 .27352 .54108 .26756 .53001 Mtetra
.778 .666 .74 r
.26756 .53001 .27352 .54108 .28389 .52868 .2779 .51833 Mtetra
.407 .509 .85 r
.2779 .51833 .28389 .52868 .29347 .52746 .28721 .52095 Mtetra
.594 .708 .922 r
.28721 .52095 .29347 .52746 .30311 .52603 .29688 .51921 Mtetra
.437 .632 .937 r
.29688 .51921 .30311 .52603 .31384 .5082 .30643 .52008 Mtetra
0 0 0 r
.30643 .52008 .31384 .5082 .3229 .517 .31675 .5097 Mtetra
.563 .671 .911 r
.31675 .5097 .3229 .517 .33269 .51514 .32649 .50869 Mtetra
.604 .715 .923 r
.32649 .50869 .33269 .51514 .34249 .51367 .33635 .50671 Mtetra
.365 .592 .932 r
.33635 .50671 .34249 .51367 .35298 .50002 .34604 .50855 Mtetra
0 0 0 r
.34604 .50855 .35298 .50002 .36256 .5043 .35647 .49714 Mtetra
.578 .684 .913 r
.35647 .49714 .36256 .5043 .37252 .5022 .3664 .49576 Mtetra
.616 .722 .922 r
.3664 .49576 .37252 .5022 .38252 .50011 .37643 .49348 Mtetra
.567 .698 .93 r
.37643 .49348 .38252 .50011 .3922 .50719 .38646 .49221 Mtetra
.739 .614 .719 r
.38646 .49221 .3922 .50719 .40285 .49056 .39691 .48136 Mtetra
.49 .586 .878 r
.39691 .48136 .40285 .49056 .41296 .48871 .40693 .48216 Mtetra
.62 .723 .92 r
.40693 .48216 .41296 .48871 .42313 .48616 .41713 .47974 Mtetra
.626 .73 .922 r
.41713 .47974 .42313 .48616 .43335 .48381 .42737 .47716 Mtetra
.585 .708 .928 r
.42737 .47716 .43335 .48381 .44347 .48699 .43763 .47549 Mtetra
.784 .672 .74 r
.43763 .47549 .44347 .48699 .45403 .47382 .44819 .46327 Mtetra
.448 .532 .851 r
.44819 .46327 .45403 .47382 .46435 .47197 .45844 .46532 Mtetra
.624 .724 .918 r
.45844 .46532 .46435 .47197 .47474 .46918 .46885 .46276 Mtetra
.639 .738 .92 r
.46885 .46276 .47474 .46918 .48517 .46622 .4793 .45982 Mtetra
.64 .74 .921 r
.4793 .45982 .48517 .46622 .49564 .46331 .4898 .45683 Mtetra
.633 .735 .922 r
.4898 .45683 .49564 .46331 .50615 .46087 .50034 .45401 Mtetra
.563 .696 .93 r
.50034 .45401 .50615 .46087 .51664 .48648 .51092 .45276 Mtetra
.653 .482 .64 r
.51092 .45276 .51664 .48648 .52732 .45062 .52156 .44212 Mtetra
.546 .638 .893 r
.52156 .44212 .52732 .45062 .53796 .44822 .53222 .44155 Mtetra
.635 .733 .919 r
.53222 .44155 .53796 .44822 .54864 .44511 .54293 .43862 Mtetra
.648 .744 .92 r
.54293 .43862 .54864 .44511 .55936 .4418 .55368 .43536 Mtetra
.653 .749 .92 r
.55368 .43536 .55936 .4418 .57012 .43839 .56447 .43197 Mtetra
.655 .751 .92 r
.56447 .43197 .57012 .43839 .58092 .43491 .5753 .42849 Mtetra
.657 .752 .92 r
.5753 .42849 .58092 .43491 .59177 .43138 .58617 .42495 Mtetra
.658 .753 .92 r
.58617 .42495 .59177 .43138 .60266 .42781 .59709 .42136 Mtetra
.659 .754 .92 r
.59709 .42136 .60266 .42781 .61359 .42422 .60805 .41775 Mtetra
.60805 .41775 .61359 .42422 .62456 .42061 .61905 .41412 Mtetra
.61905 .41412 .62456 .42061 .63557 .417 .63009 .41047 Mtetra
.63009 .41047 .63557 .417 .64663 .41338 .64118 .40682 Mtetra
.658 .753 .92 r
.64118 .40682 .64663 .41338 .65773 .40975 .65231 .40317 Mtetra
.65231 .40317 .65773 .40975 .66887 .40612 .66349 .3995 Mtetra
.66349 .3995 .66887 .40612 .68006 .40247 .6747 .39583 Mtetra
.6747 .39583 .68006 .40247 .69129 .39882 .68597 .39214 Mtetra
.68597 .39214 .69129 .39882 .70257 .39515 .69728 .38845 Mtetra
.69728 .38845 .70257 .39515 .71389 .39147 .70863 .38474 Mtetra
.657 .753 .92 r
.70863 .38474 .71389 .39147 .72526 .38777 .72003 .38102 Mtetra
.72003 .38102 .72526 .38777 .73667 .38407 .73147 .37728 Mtetra
.73147 .37728 .73667 .38407 .74813 .38035 .74296 .37354 Mtetra
.74296 .37354 .74813 .38035 .75964 .37661 .7545 .36977 Mtetra
.7545 .36977 .75964 .37661 .77119 .37287 .76608 .366 Mtetra
.657 .752 .92 r
.76608 .366 .77119 .37287 .78278 .36911 .77771 .36221 Mtetra
.77771 .36221 .78278 .36911 .79443 .36533 .78939 .35841 Mtetra
.78939 .35841 .79443 .36533 .80612 .36154 .80111 .35459 Mtetra
.80111 .35459 .80612 .36154 .81785 .35774 .81288 .35076 Mtetra
.81288 .35076 .81785 .35774 .82964 .35392 .8247 .34691 Mtetra
.8247 .34691 .82964 .35392 .84147 .35009 .83657 .34305 Mtetra
.83657 .34305 .84147 .35009 .85335 .34624 .84849 .33917 Mtetra
.481 .597 .892 r
.21361 .53361 .21986 .54204 .22921 .54088 .2228 .53433 Mtetra
.562 .693 .928 r
.2228 .53433 .22921 .54088 .23838 .54245 .23221 .53323 Mtetra
.821 .7 .731 r
.23221 .53323 .23838 .54245 .2486 .53194 .24283 .51826 Mtetra
.265 .356 .771 r
.24283 .51826 .2486 .53194 .25805 .53107 .25169 .52449 Mtetra
.584 .701 .923 r
.25169 .52449 .25805 .53107 .26756 .53001 .26125 .52297 Mtetra
.199 .497 .905 r
.26125 .52297 .26756 .53001 .2779 .51833 .27047 .52644 Mtetra
.613 .868 .522 r
.27047 .52644 .2779 .51833 .28721 .52095 .28094 .51395 Mtetra
.573 .685 .916 r
.28094 .51395 .28721 .52095 .29688 .51921 .29059 .51267 Mtetra
.579 .703 .927 r
.29059 .51267 .29688 .51921 .30643 .52008 .30031 .5112 Mtetra
.846 .713 .716 r
.30031 .5112 .30643 .52008 .31675 .5097 .31114 .49325 Mtetra
.215 .285 .72 r
.31114 .49325 .31675 .5097 .32649 .50869 .32027 .50204 Mtetra
.6 .709 .92 r
.32027 .50204 .32649 .50869 .33635 .50671 .33013 .50013 Mtetra
.579 .704 .928 r
.33013 .50013 .33635 .50671 .34604 .50855 .34002 .49862 Mtetra
.81 .696 .739 r
.34002 .49862 .34604 .50855 .35647 .49714 .3506 .48487 Mtetra
.359 .443 .812 r
.3506 .48487 .35647 .49714 .3664 .49576 .36026 .48912 Mtetra
.61 .715 .92 r
.36026 .48912 .3664 .49576 .37643 .49348 .3703 .48697 Mtetra
.608 .719 .924 r
.3703 .48697 .37643 .49348 .38646 .49221 .38038 .48482 Mtetra
0 .265 .767 r
.38038 .48482 .38646 .49221 .39691 .48136 .39014 .49189 Mtetra
.596 .799 .383 r
.39014 .49189 .39691 .48136 .40693 .48216 .40089 .47514 Mtetra
.598 .701 .915 r
.40089 .47514 .40693 .48216 .41713 .47974 .41108 .47325 Mtetra
.627 .729 .921 r
.41108 .47325 .41713 .47974 .42737 .47716 .42135 .47064 Mtetra
.617 .726 .923 r
.42135 .47064 .42737 .47716 .43763 .47549 .43165 .46823 Mtetra
.272 .534 .916 r
.43165 .46823 .43763 .47549 .44819 .46327 .44186 .47138 Mtetra
0 0 0 r
.44186 .47138 .44819 .46327 .45844 .46532 .45251 .45811 Mtetra
.597 .697 .913 r
.45251 .45811 .45844 .46532 .46885 .46276 .46292 .45621 Mtetra
.634 .734 .92 r
.46292 .45621 .46885 .46276 .4793 .45982 .4734 .45336 Mtetra
.64 .74 .921 r
.4734 .45336 .4793 .45982 .4898 .45683 .48392 .45034 Mtetra
.638 .739 .921 r
.48392 .45034 .4898 .45683 .50034 .45401 .49449 .44736 Mtetra
.618 .727 .924 r
.49449 .44736 .50034 .45401 .51092 .45276 .50509 .44487 Mtetra
.858 .439 0 r
.50509 .44487 .51092 .45276 .52156 .44212 .51567 .47054 Mtetra
0 0 .053 r
.51567 .47054 .52156 .44212 .53222 .44155 .52645 .43448 Mtetra
.617 .714 .915 r
.52645 .43448 .53222 .44155 .54293 .43862 .53718 .43202 Mtetra
.644 .74 .919 r
.53718 .43202 .54293 .43862 .55368 .43536 .54796 .42885 Mtetra
.651 .747 .92 r
.54796 .42885 .55368 .43536 .56447 .43197 .55878 .42548 Mtetra
.654 .75 .92 r
.55878 .42548 .56447 .43197 .5753 .42849 .56964 .42201 Mtetra
.656 .752 .92 r
.56964 .42201 .5753 .42849 .58617 .42495 .58054 .41846 Mtetra
.658 .753 .92 r
.58054 .41846 .58617 .42495 .59709 .42136 .59148 .41486 Mtetra
.659 .754 .92 r
.59148 .41486 .59709 .42136 .60805 .41775 .60247 .41123 Mtetra
.60247 .41123 .60805 .41775 .61905 .41412 .6135 .40757 Mtetra
.6135 .40757 .61905 .41412 .63009 .41047 .62457 .4039 Mtetra
.62457 .4039 .63009 .41047 .64118 .40682 .63569 .40022 Mtetra
.658 .754 .92 r
.63569 .40022 .64118 .40682 .65231 .40317 .64685 .39654 Mtetra
.658 .753 .92 r
.64685 .39654 .65231 .40317 .66349 .3995 .65806 .39284 Mtetra
.65806 .39284 .66349 .3995 .6747 .39583 .66931 .38914 Mtetra
.66931 .38914 .6747 .39583 .68597 .39214 .6806 .38542 Mtetra
.6806 .38542 .68597 .39214 .69728 .38845 .69194 .3817 Mtetra
.69194 .3817 .69728 .38845 .70863 .38474 .70333 .37796 Mtetra
.657 .753 .92 r
.70333 .37796 .70863 .38474 .72003 .38102 .71476 .37421 Mtetra
.71476 .37421 .72003 .38102 .73147 .37728 .72623 .37045 Mtetra
.72623 .37045 .73147 .37728 .74296 .37354 .73776 .36667 Mtetra
.73776 .36667 .74296 .37354 .7545 .36977 .74932 .36288 Mtetra
.74932 .36288 .7545 .36977 .76608 .366 .76094 .35908 Mtetra
.657 .752 .92 r
.76094 .35908 .76608 .366 .77771 .36221 .7726 .35526 Mtetra
.7726 .35526 .77771 .36221 .78939 .35841 .78431 .35143 Mtetra
.78431 .35143 .78939 .35841 .80111 .35459 .79607 .34758 Mtetra
.79607 .34758 .80111 .35459 .81288 .35076 .80788 .34372 Mtetra
.80788 .34372 .81288 .35076 .8247 .34691 .81973 .33984 Mtetra
.81973 .33984 .8247 .34691 .83657 .34305 .83163 .33595 Mtetra
.83163 .33595 .83657 .34305 .84849 .33917 .84359 .33205 Mtetra
.679 .816 .37 r
.20502 .54944 .21361 .53361 .2228 .53433 .21637 .52753 Mtetra
.569 .688 .921 r
.21637 .52753 .2228 .53433 .23221 .53323 .2258 .52632 Mtetra
.378 .602 .935 r
.2258 .52632 .23221 .53323 .24283 .51826 .23503 .52786 Mtetra
0 0 0 r
.23503 .52786 .24283 .51826 .25169 .52449 .24534 .51726 Mtetra
.556 .671 .914 r
.24534 .51726 .25169 .52449 .26125 .52297 .25487 .51635 Mtetra
.56 .693 .929 r
.25487 .51635 .26125 .52297 .27047 .52644 .26445 .51524 Mtetra
.778 .666 .74 r
.26445 .51524 .27047 .52644 .28094 .51395 .27488 .50348 Mtetra
.406 .509 .85 r
.27488 .50348 .28094 .51395 .29059 .51267 .28427 .50606 Mtetra
.594 .708 .922 r
.28427 .50606 .29059 .51267 .30031 .5112 .29402 .50427 Mtetra
.438 .632 .937 r
.29402 .50427 .30031 .5112 .31114 .49325 .30365 .5051 Mtetra
0 0 0 r
.30365 .5051 .31114 .49325 .32027 .50204 .31405 .49464 Mtetra
.563 .671 .911 r
.31405 .49464 .32027 .50204 .33013 .50013 .32388 .49358 Mtetra
.604 .715 .923 r
.32388 .49358 .33013 .50013 .34002 .49862 .33381 .49155 Mtetra
.367 .593 .932 r
.33381 .49155 .34002 .49862 .3506 .48487 .34358 .49335 Mtetra
0 0 0 r
.34358 .49335 .3506 .48487 .36026 .48912 .3541 .48185 Mtetra
.578 .684 .913 r
.3541 .48185 .36026 .48912 .3703 .48697 .36412 .48042 Mtetra
.616 .722 .922 r
.36412 .48042 .3703 .48697 .38038 .48482 .37423 .47808 Mtetra
.567 .698 .93 r
.37423 .47808 .38038 .48482 .39014 .49189 .38435 .47676 Mtetra
.739 .614 .72 r
.38435 .47676 .39014 .49189 .40089 .47514 .39489 .46582 Mtetra
.49 .586 .878 r
.39489 .46582 .40089 .47514 .41108 .47325 .405 .46658 Mtetra
.62 .723 .92 r
.405 .46658 .41108 .47325 .42135 .47064 .41528 .46411 Mtetra
.626 .73 .922 r
.41528 .46411 .42135 .47064 .43165 .46823 .42561 .46147 Mtetra
.585 .708 .928 r
.42561 .46147 .43165 .46823 .44186 .47138 .43596 .45975 Mtetra
.784 .673 .741 r
.43596 .45975 .44186 .47138 .45251 .45811 .44662 .44743 Mtetra
.447 .532 .851 r
.44662 .44743 .45251 .45811 .46292 .45621 .45696 .44944 Mtetra
.624 .724 .919 r
.45696 .44944 .46292 .45621 .4734 .45336 .46745 .44682 Mtetra
.639 .738 .92 r
.46745 .44682 .4734 .45336 .48392 .45034 .478 .44382 Mtetra
.64 .74 .921 r
.478 .44382 .48392 .45034 .49449 .44736 .48859 .44077 Mtetra
.633 .735 .922 r
.48859 .44077 .49449 .44736 .50509 .44487 .49922 .4379 Mtetra
.563 .696 .93 r
.49922 .4379 .50509 .44487 .51567 .47054 .5099 .43659 Mtetra
.652 .481 .639 r
.5099 .43659 .51567 .47054 .52645 .43448 .52064 .42585 Mtetra
.546 .638 .893 r
.52064 .42585 .52645 .43448 .53718 .43202 .53139 .42523 Mtetra
.635 .733 .919 r
.53139 .42523 .53718 .43202 .54796 .42885 .5422 .42225 Mtetra
.648 .744 .92 r
.5422 .42225 .54796 .42885 .55878 .42548 .55304 .41892 Mtetra
.653 .749 .92 r
.55304 .41892 .55878 .42548 .56964 .42201 .56393 .41546 Mtetra
.655 .751 .92 r
.56393 .41546 .56964 .42201 .58054 .41846 .57486 .41192 Mtetra
.657 .752 .92 r
.57486 .41192 .58054 .41846 .59148 .41486 .58584 .40831 Mtetra
.658 .753 .92 r
.58584 .40831 .59148 .41486 .60247 .41123 .59685 .40466 Mtetra
.659 .754 .92 r
.59685 .40466 .60247 .41123 .6135 .40757 .60791 .40098 Mtetra
.60791 .40098 .6135 .40757 .62457 .4039 .61902 .39728 Mtetra
.61902 .39728 .62457 .4039 .63569 .40022 .63016 .39357 Mtetra
.63016 .39357 .63569 .40022 .64685 .39654 .64135 .38986 Mtetra
.658 .753 .92 r
.64135 .38986 .64685 .39654 .65806 .39284 .65259 .38613 Mtetra
.65259 .38613 .65806 .39284 .66931 .38914 .66387 .3824 Mtetra
.66387 .3824 .66931 .38914 .6806 .38542 .6752 .37865 Mtetra
.6752 .37865 .6806 .38542 .69194 .3817 .68657 .3749 Mtetra
.68657 .3749 .69194 .3817 .70333 .37796 .69798 .37113 Mtetra
.69798 .37113 .70333 .37796 .71476 .37421 .70945 .36736 Mtetra
.657 .753 .92 r
.70945 .36736 .71476 .37421 .72623 .37045 .72095 .36356 Mtetra
.72095 .36356 .72623 .37045 .73776 .36667 .73251 .35976 Mtetra
.73251 .35976 .73776 .36667 .74932 .36288 .74411 .35594 Mtetra
.74411 .35594 .74932 .36288 .76094 .35908 .75576 .35211 Mtetra
.75576 .35211 .76094 .35908 .7726 .35526 .76746 .34826 Mtetra
.657 .752 .92 r
.76746 .34826 .7726 .35526 .78431 .35143 .7792 .3444 Mtetra
.7792 .3444 .78431 .35143 .79607 .34758 .79099 .34052 Mtetra
.79099 .34052 .79607 .34758 .80788 .34372 .80283 .33663 Mtetra
.80283 .33663 .80788 .34372 .81973 .33984 .81472 .33273 Mtetra
.81472 .33273 .81973 .33984 .83163 .33595 .82666 .3288 Mtetra
.82666 .3288 .83163 .33595 .84359 .33205 .83865 .32487 Mtetra
.695 .551 .686 r
.19983 .52886 .20502 .54944 .21637 .52753 .21006 .51899 Mtetra
.48 .597 .892 r
.21006 .51899 .21637 .52753 .2258 .52632 .21932 .51967 Mtetra
.562 .693 .928 r
.21932 .51967 .2258 .52632 .23503 .52786 .2288 .51852 Mtetra
.822 .701 .731 r
.2288 .51852 .23503 .52786 .24534 .51726 .23952 .50345 Mtetra
.263 .355 .77 r
.23952 .50345 .24534 .51726 .25487 .51635 .24844 .50966 Mtetra
.584 .701 .923 r
.24844 .50966 .25487 .51635 .26445 .51524 .25808 .50809 Mtetra
.201 .498 .905 r
.25808 .50809 .26445 .51524 .27488 .50348 .26737 .51154 Mtetra
.624 .875 .532 r
.26737 .51154 .27488 .50348 .28427 .50606 .27793 .49895 Mtetra
.573 .685 .916 r
.27793 .49895 .28427 .50606 .29402 .50427 .28766 .49763 Mtetra
.579 .703 .927 r
.28766 .49763 .29402 .50427 .30365 .5051 .29746 .4961 Mtetra
.847 .714 .716 r
.29746 .4961 .30365 .5051 .31405 .49464 .30839 .47804 Mtetra
.213 .283 .719 r
.30839 .47804 .31405 .49464 .32388 .49358 .31759 .48683 Mtetra
.6 .709 .92 r
.31759 .48683 .32388 .49358 .33381 .49155 .32753 .48486 Mtetra
.579 .704 .928 r
.32753 .48486 .33381 .49155 .34358 .49335 .3375 .4833 Mtetra
.811 .697 .739 r
.3375 .4833 .34358 .49335 .3541 .48185 .34818 .46944 Mtetra
.357 .443 .812 r
.34818 .46944 .3541 .48185 .36412 .48042 .35791 .47367 Mtetra
.61 .715 .92 r
.35791 .47367 .36412 .48042 .37423 .47808 .36804 .47146 Mtetra
.608 .719 .924 r
.36804 .47146 .37423 .47808 .38435 .47676 .37821 .46926 Mtetra
0 .268 .77 r
.37821 .46926 .38435 .47676 .39489 .46582 .38804 .47632 Mtetra
.607 .807 .393 r
.38804 .47632 .39489 .46582 .405 .46658 .39889 .45945 Mtetra
.598 .701 .915 r
.39889 .45945 .405 .46658 .41528 .46411 .40917 .4575 Mtetra
.627 .729 .921 r
.40917 .4575 .41528 .46411 .42561 .46147 .41953 .45483 Mtetra
.617 .726 .923 r
.41953 .45483 .42561 .46147 .43596 .45975 .42992 .45237 Mtetra
.274 .534 .916 r
.42992 .45237 .43596 .45975 .44662 .44743 .44021 .45549 Mtetra
0 0 0 r
.44021 .45549 .44662 .44743 .45696 .44944 .45096 .44211 Mtetra
.597 .697 .913 r
.45096 .44211 .45696 .44944 .46745 .44682 .46147 .44016 Mtetra
.634 .734 .92 r
.46147 .44016 .46745 .44682 .478 .44382 .47204 .43724 Mtetra
.64 .74 .921 r
.47204 .43724 .478 .44382 .48859 .44077 .48265 .43417 Mtetra
.638 .739 .921 r
.48265 .43417 .48859 .44077 .49922 .4379 .49331 .43113 Mtetra
.618 .727 .924 r
.49331 .43113 .49922 .4379 .5099 .43659 .50401 .42858 Mtetra
.853 .434 0 r
.50401 .42858 .5099 .43659 .52064 .42585 .51468 .45431 Mtetra
0 0 .045 r
.51468 .45431 .52064 .42585 .53139 .42523 .52556 .41804 Mtetra
.617 .714 .915 r
.52556 .41804 .53139 .42523 .5422 .42225 .53639 .41552 Mtetra
.644 .74 .919 r
.53639 .41552 .5422 .42225 .55304 .41892 .54727 .41229 Mtetra
.651 .747 .92 r
.54727 .41229 .55304 .41892 .56393 .41546 .55818 .40886 Mtetra
.654 .75 .92 r
.55818 .40886 .56393 .41546 .57486 .41192 .56914 .40531 Mtetra
.656 .752 .92 r
.56914 .40531 .57486 .41192 .58584 .40831 .58015 .4017 Mtetra
.658 .753 .92 r
.58015 .4017 .58584 .40831 .59685 .40466 .59119 .39804 Mtetra
.659 .754 .92 r
.59119 .39804 .59685 .40466 .60791 .40098 .60228 .39434 Mtetra
.60228 .39434 .60791 .40098 .61902 .39728 .61342 .39061 Mtetra
.61342 .39061 .61902 .39728 .63016 .39357 .62459 .38687 Mtetra
.62459 .38687 .63016 .39357 .64135 .38986 .63582 .38313 Mtetra
.658 .754 .92 r
.63582 .38313 .64135 .38986 .65259 .38613 .64708 .37937 Mtetra
.658 .753 .92 r
.64708 .37937 .65259 .38613 .66387 .3824 .65839 .37561 Mtetra
.65839 .37561 .66387 .3824 .6752 .37865 .66975 .37184 Mtetra
.66975 .37184 .6752 .37865 .68657 .3749 .68115 .36805 Mtetra
.68115 .36805 .68657 .3749 .69798 .37113 .6926 .36426 Mtetra
.6926 .36426 .69798 .37113 .70945 .36736 .70409 .36045 Mtetra
.657 .753 .92 r
.70409 .36045 .70945 .36736 .72095 .36356 .71564 .35663 Mtetra
.71564 .35663 .72095 .36356 .73251 .35976 .72722 .35279 Mtetra
.72722 .35279 .73251 .35976 .74411 .35594 .73886 .34895 Mtetra
.73886 .34895 .74411 .35594 .75576 .35211 .75054 .34508 Mtetra
.75054 .34508 .75576 .35211 .76746 .34826 .76227 .34121 Mtetra
.657 .752 .92 r
.76227 .34121 .76746 .34826 .7792 .3444 .77405 .33732 Mtetra
.77405 .33732 .7792 .3444 .79099 .34052 .78588 .33341 Mtetra
.78588 .33341 .79099 .34052 .80283 .33663 .79775 .32949 Mtetra
.79775 .32949 .80283 .33663 .81472 .33273 .80967 .32555 Mtetra
.80967 .32555 .81472 .33273 .82666 .3288 .82165 .3216 Mtetra
.82165 .3216 .82666 .3288 .83865 .32487 .83367 .31763 Mtetra
.768 .3 0 r
.19335 .52138 .19983 .52886 .21006 .51899 .20136 .53481 Mtetra
.688 .823 .379 r
.20136 .53481 .21006 .51899 .21932 .51967 .21282 .51276 Mtetra
.569 .688 .921 r
.21282 .51276 .21932 .51967 .2288 .51852 .22232 .51151 Mtetra
.379 .602 .935 r
.22232 .51151 .2288 .51852 .23952 .50345 .23163 .51301 Mtetra
0 0 0 r
.23163 .51301 .23952 .50345 .24844 .50966 .24203 .50233 Mtetra
.556 .671 .914 r
.24203 .50233 .24844 .50966 .25808 .50809 .25163 .50137 Mtetra
.56 .693 .929 r
.25163 .50137 .25808 .50809 .26737 .51154 .26129 .50022 Mtetra
.778 .667 .74 r
.26129 .50022 .26737 .51154 .27793 .49895 .27182 .48836 Mtetra
.405 .508 .851 r
.27182 .48836 .27793 .49895 .28766 .49763 .28127 .49091 Mtetra
.594 .708 .922 r
.28127 .49091 .28766 .49763 .29746 .4961 .2911 .48907 Mtetra
.438 .632 .937 r
.2911 .48907 .29746 .4961 .30839 .47804 .30081 .48986 Mtetra
0 0 0 r
.30081 .48986 .30839 .47804 .31759 .48683 .3113 .47931 Mtetra
.563 .671 .911 r
.3113 .47931 .31759 .48683 .32753 .48486 .32121 .4782 Mtetra
.604 .715 .923 r
.32121 .4782 .32753 .48486 .3375 .4833 .33123 .47611 Mtetra
.368 .593 .932 r
.33123 .47611 .3375 .4833 .34818 .46944 .34107 .47788 Mtetra
0 0 0 r
.34107 .47788 .34818 .46944 .35791 .47367 .35169 .46628 Mtetra
.578 .684 .913 r
.35169 .46628 .35791 .47367 .36804 .47146 .3618 .4648 Mtetra
.616 .722 .922 r
.3618 .4648 .36804 .47146 .37821 .46926 .372 .46241 Mtetra
.567 .698 .93 r
.372 .46241 .37821 .46926 .38804 .47632 .38219 .46104 Mtetra
.739 .615 .72 r
.38219 .46104 .38804 .47632 .39889 .45945 .39283 .45 Mtetra
.489 .586 .878 r
.39283 .45 .39889 .45945 .40917 .4575 .40303 .45072 Mtetra
.62 .723 .92 r
.40303 .45072 .40917 .4575 .41953 .45483 .4134 .44819 Mtetra
.626 .73 .922 r
.4134 .44819 .41953 .45483 .42992 .45237 .42382 .4455 Mtetra
.585 .708 .928 r
.42382 .4455 .42992 .45237 .44021 .45549 .43426 .44372 Mtetra
.785 .673 .741 r
.43426 .44372 .44021 .45549 .45096 .44211 .44501 .4313 Mtetra
.447 .532 .852 r
.44501 .4313 .45096 .44211 .46147 .44016 .45544 .43327 Mtetra
.624 .724 .919 r
.45544 .43327 .46147 .44016 .47204 .43724 .46603 .43059 Mtetra
.639 .738 .92 r
.46603 .43059 .47204 .43724 .48265 .43417 .47667 .42753 Mtetra
.64 .74 .921 r
.47667 .42753 .48265 .43417 .49331 .43113 .48736 .42441 Mtetra
.633 .735 .922 r
.48736 .42441 .49331 .43113 .50401 .42858 .49809 .42148 Mtetra
.563 .696 .93 r
.49809 .42148 .50401 .42858 .51468 .45431 .50885 .42012 Mtetra
.652 .48 .638 r
.50885 .42012 .51468 .45431 .52556 .41804 .51969 .40929 Mtetra
.545 .638 .893 r
.51969 .40929 .52556 .41804 .53639 .41552 .53055 .40861 Mtetra
.635 .733 .919 r
.53055 .40861 .53639 .41552 .54727 .41229 .54145 .40556 Mtetra
.648 .744 .92 r
.54145 .40556 .54727 .41229 .55818 .40886 .55239 .40218 Mtetra
.653 .749 .92 r
.55239 .40218 .55818 .40886 .56914 .40531 .56338 .39865 Mtetra
.655 .751 .92 r
.56338 .39865 .56914 .40531 .58015 .4017 .57442 .39504 Mtetra
.657 .752 .92 r
.57442 .39504 .58015 .4017 .59119 .39804 .58549 .39136 Mtetra
.658 .753 .92 r
.58549 .39136 .59119 .39804 .60228 .39434 .59661 .38764 Mtetra
.659 .754 .92 r
.59661 .38764 .60228 .39434 .61342 .39061 .60778 .3839 Mtetra
.60778 .3839 .61342 .39061 .62459 .38687 .61898 .38013 Mtetra
.61898 .38013 .62459 .38687 .63582 .38313 .63023 .37635 Mtetra
.63023 .37635 .63582 .38313 .64708 .37937 .64153 .37257 Mtetra
.658 .753 .92 r
.64153 .37257 .64708 .37937 .65839 .37561 .65287 .36877 Mtetra
.65287 .36877 .65839 .37561 .66975 .37184 .66426 .36497 Mtetra
.66426 .36497 .66975 .37184 .68115 .36805 .6757 .36115 Mtetra
.6757 .36115 .68115 .36805 .6926 .36426 .68718 .35733 Mtetra
.68718 .35733 .6926 .36426 .70409 .36045 .6987 .35349 Mtetra
.6987 .35349 .70409 .36045 .71564 .35663 .71028 .34964 Mtetra
.657 .753 .92 r
.71028 .34964 .71564 .35663 .72722 .35279 .7219 .34578 Mtetra
.7219 .34578 .72722 .35279 .73886 .34895 .73357 .3419 Mtetra
.73357 .3419 .73886 .34895 .75054 .34508 .74528 .33801 Mtetra
.74528 .33801 .75054 .34508 .76227 .34121 .75705 .3341 Mtetra
.75705 .3341 .76227 .34121 .77405 .33732 .76886 .33018 Mtetra
.657 .752 .92 r
.76886 .33018 .77405 .33732 .78588 .33341 .78072 .32624 Mtetra
.78072 .32624 .78588 .33341 .79775 .32949 .79263 .32229 Mtetra
.79263 .32229 .79775 .32949 .80967 .32555 .80459 .31833 Mtetra
.80459 .31833 .80967 .32555 .82165 .3216 .8166 .31434 Mtetra
.8166 .31434 .82165 .3216 .83367 .31763 .82865 .31035 Mtetra
.523 .674 .933 r
.18676 .51458 .19335 .52138 .20136 .53481 .19613 .51407 Mtetra
.695 .55 .686 r
.19613 .51407 .20136 .53481 .21282 .51276 .20645 .50411 Mtetra
.48 .597 .892 r
.20645 .50411 .21282 .51276 .22232 .51151 .21578 .50476 Mtetra
.562 .693 .928 r
.21578 .50476 .22232 .51151 .23163 .51301 .22533 .50356 Mtetra
.822 .701 .731 r
.22533 .50356 .23163 .51301 .24203 .50233 .23615 .48838 Mtetra
.26 .354 .77 r
.23615 .48838 .24203 .50233 .25163 .50137 .24514 .49457 Mtetra
.584 .701 .923 r
.24514 .49457 .25163 .50137 .26129 .50022 .25485 .49295 Mtetra
.204 .499 .905 r
.25485 .49295 .26129 .50022 .27182 .48836 .26421 .49637 Mtetra
.634 .883 .542 r
.26421 .49637 .27182 .48836 .28127 .49091 .27487 .48369 Mtetra
.573 .685 .916 r
.27487 .48369 .28127 .49091 .2911 .48907 .28468 .48232 Mtetra
.579 .703 .927 r
.28468 .48232 .2911 .48907 .30081 .48986 .29456 .48074 Mtetra
.848 .715 .716 r
.29456 .48074 .30081 .48986 .3113 .47931 .30559 .46255 Mtetra
.21 .281 .719 r
.30559 .46255 .3113 .47931 .32121 .4782 .31486 .47133 Mtetra
.6 .709 .92 r
.31486 .47133 .32121 .4782 .33123 .47611 .32489 .46931 Mtetra
.58 .704 .928 r
.32489 .46931 .33123 .47611 .34107 .47788 .33494 .4677 Mtetra
.811 .697 .739 r
.33494 .4677 .34107 .47788 .35169 .46628 .34571 .45374 Mtetra
.356 .442 .812 r
.34571 .45374 .35169 .46628 .3618 .4648 .35553 .45794 Mtetra
.61 .715 .92 r
.35553 .45794 .3618 .4648 .372 .46241 .36574 .45567 Mtetra
.608 .719 .924 r
.36574 .45567 .372 .46241 .38219 .46104 .37599 .45342 Mtetra
0 .272 .773 r
.37599 .45342 .38219 .46104 .39283 .45 .3859 .46046 Mtetra
.616 .815 .403 r
.3859 .46046 .39283 .45 .40303 .45072 .39686 .44347 Mtetra
.598 .701 .915 r
.39686 .44347 .40303 .45072 .4134 .44819 .40723 .44147 Mtetra
.627 .729 .921 r
.40723 .44147 .4134 .44819 .42382 .4455 .41767 .43874 Mtetra
.617 .726 .923 r
.41767 .43874 .42382 .4455 .43426 .44372 .42816 .43622 Mtetra
.276 .535 .916 r
.42816 .43622 .43426 .44372 .44501 .4313 .43854 .4393 Mtetra
.554 .814 .446 r
.43854 .4393 .44501 .4313 .45544 .43327 .44939 .42582 Mtetra
.597 .697 .913 r
.44939 .42582 .45544 .43327 .46603 .43059 .45998 .42381 Mtetra
.634 .734 .92 r
.45998 .42381 .46603 .43059 .47667 .42753 .47065 .42083 Mtetra
.64 .74 .921 r
.47065 .42083 .47667 .42753 .48736 .42441 .48136 .41769 Mtetra
.638 .739 .921 r
.48136 .41769 .48736 .42441 .49809 .42148 .49212 .41459 Mtetra
.618 .727 .924 r
.49212 .41459 .49809 .42148 .50885 .42012 .50291 .41198 Mtetra
.849 .429 0 r
.50291 .41198 .50885 .42012 .51969 .40929 .51366 .43777 Mtetra
0 0 .037 r
.51366 .43777 .51969 .40929 .53055 .40861 .52466 .4013 Mtetra
.617 .714 .915 r
.52466 .4013 .53055 .40861 .54145 .40556 .53559 .39872 Mtetra
.644 .74 .919 r
.53559 .39872 .54145 .40556 .55239 .40218 .54656 .39542 Mtetra
.651 .747 .92 r
.54656 .39542 .55239 .40218 .56338 .39865 .55758 .39192 Mtetra
.654 .75 .92 r
.55758 .39192 .56338 .39865 .57442 .39504 .56864 .38831 Mtetra
.656 .752 .92 r
.56864 .38831 .57442 .39504 .58549 .39136 .57975 .38463 Mtetra
.658 .753 .92 r
.57975 .38463 .58549 .39136 .59661 .38764 .5909 .3809 Mtetra
.659 .754 .92 r
.5909 .3809 .59661 .38764 .60778 .3839 .60209 .37713 Mtetra
.60209 .37713 .60778 .3839 .61898 .38013 .61333 .37333 Mtetra
.61333 .37333 .61898 .38013 .63023 .37635 .62461 .36953 Mtetra
.62461 .36953 .63023 .37635 .64153 .37257 .63594 .36571 Mtetra
.658 .754 .92 r
.63594 .36571 .64153 .37257 .65287 .36877 .64731 .36188 Mtetra
.658 .753 .92 r
.64731 .36188 .65287 .36877 .66426 .36497 .65873 .35805 Mtetra
.65873 .35805 .66426 .36497 .6757 .36115 .6702 .3542 Mtetra
.6702 .3542 .6757 .36115 .68718 .35733 .68171 .35035 Mtetra
.68171 .35035 .68718 .35733 .6987 .35349 .69327 .34648 Mtetra
.69327 .34648 .6987 .35349 .71028 .34964 .70488 .3426 Mtetra
.657 .753 .92 r
.70488 .3426 .71028 .34964 .7219 .34578 .71653 .33871 Mtetra
.71653 .33871 .7219 .34578 .73357 .3419 .72823 .3348 Mtetra
.72823 .3348 .73357 .3419 .74528 .33801 .73998 .33088 Mtetra
.73998 .33088 .74528 .33801 .75705 .3341 .75178 .32694 Mtetra
.75178 .32694 .75705 .3341 .76886 .33018 .76363 .32299 Mtetra
.657 .752 .92 r
.76363 .32299 .76886 .33018 .78072 .32624 .77552 .31902 Mtetra
.77552 .31902 .78072 .32624 .79263 .32229 .78747 .31504 Mtetra
.78747 .31504 .79263 .32229 .80459 .31833 .79946 .31104 Mtetra
.79946 .31104 .80459 .31833 .8166 .31434 .81151 .30703 Mtetra
.81151 .30703 .8166 .31434 .82865 .31035 .8236 .303 Mtetra
.562 .687 .924 r
.18014 .50766 .18676 .51458 .19613 .51407 .18958 .50648 Mtetra
.763 .295 0 r
.18958 .50648 .19613 .51407 .20645 .50411 .19764 .51993 Mtetra
.697 .829 .389 r
.19764 .51993 .20645 .50411 .21578 .50476 .20921 .49774 Mtetra
.569 .688 .921 r
.20921 .49774 .21578 .50476 .22533 .50356 .21879 .49644 Mtetra
.38 .602 .935 r
.21879 .49644 .22533 .50356 .23615 .48838 .22816 .4979 Mtetra
0 0 0 r
.22816 .4979 .23615 .48838 .24514 .49457 .23866 .48713 Mtetra
.556 .671 .914 r
.23866 .48713 .24514 .49457 .25485 .49295 .24833 .48612 Mtetra
.56 .693 .929 r
.24833 .48612 .25485 .49295 .26421 .49637 .25807 .48492 Mtetra
.779 .668 .741 r
.25807 .48492 .26421 .49637 .27487 .48369 .2687 .47297 Mtetra
.404 .508 .851 r
.2687 .47297 .27487 .48369 .28468 .48232 .27822 .47549 Mtetra
.594 .708 .922 r
.27822 .47549 .28468 .48232 .29456 .48074 .28814 .47359 Mtetra
.439 .632 .936 r
.28814 .47359 .29456 .48074 .30559 .46255 .29792 .47434 Mtetra
0 0 0 r
.29792 .47434 .30559 .46255 .31486 .47133 .30851 .4637 Mtetra
.563 .671 .911 r
.30851 .4637 .31486 .47133 .32489 .46931 .3185 .46254 Mtetra
.604 .715 .923 r
.3185 .46254 .32489 .46931 .33494 .4677 .3286 .4604 Mtetra
.369 .593 .932 r
.3286 .4604 .33494 .4677 .34571 .45374 .33853 .46213 Mtetra
0 0 0 r
.33853 .46213 .34571 .45374 .35553 .45794 .34924 .45044 Mtetra
.578 .684 .913 r
.34924 .45044 .35553 .45794 .36574 .45567 .35943 .4489 Mtetra
.616 .722 .922 r
.35943 .4489 .36574 .45567 .37599 .45342 .36972 .44645 Mtetra
.567 .698 .93 r
.36972 .44645 .37599 .45342 .3859 .46046 .38 .44503 Mtetra
.74 .615 .72 r
.38 .44503 .3859 .46046 .39686 .44347 .39074 .4339 Mtetra
.489 .586 .878 r
.39074 .4339 .39686 .44347 .40723 .44147 .40102 .43457 Mtetra
.62 .723 .92 r
.40102 .43457 .40723 .44147 .41767 .43874 .41148 .43198 Mtetra
.626 .73 .922 r
.41148 .43198 .41767 .43874 .42816 .43622 .422 .42923 Mtetra
.585 .708 .928 r
.422 .42923 .42816 .43622 .43854 .4393 .43253 .42739 Mtetra
.785 .674 .741 r
.43253 .42739 .43854 .4393 .44939 .42582 .44338 .41487 Mtetra
.446 .532 .852 r
.44338 .41487 .44939 .42582 .45998 .42381 .4539 .41681 Mtetra
.624 .724 .919 r
.4539 .41681 .45998 .42381 .47065 .42083 .46458 .41406 Mtetra
.639 .738 .92 r
.46458 .41406 .47065 .42083 .48136 .41769 .47532 .41094 Mtetra
.64 .74 .921 r
.47532 .41094 .48136 .41769 .49212 .41459 .4861 .40776 Mtetra
.633 .735 .922 r
.4861 .40776 .49212 .41459 .50291 .41198 .49693 .40476 Mtetra
.563 .696 .93 r
.49693 .40476 .50291 .41198 .51366 .43777 .50779 .40334 Mtetra
.651 .479 .638 r
.50779 .40334 .51366 .43777 .52466 .4013 .51874 .39241 Mtetra
.545 .638 .893 r
.51874 .39241 .52466 .4013 .53559 .39872 .52969 .39168 Mtetra
.635 .733 .919 r
.52969 .39168 .53559 .39872 .54656 .39542 .54069 .38857 Mtetra
.648 .744 .92 r
.54069 .38857 .54656 .39542 .55758 .39192 .55174 .38512 Mtetra
.653 .749 .92 r
.55174 .38512 .55758 .39192 .56864 .38831 .56283 .38152 Mtetra
.655 .751 .92 r
.56283 .38152 .56864 .38831 .57975 .38463 .57396 .37784 Mtetra
.657 .752 .92 r
.57396 .37784 .57975 .38463 .5909 .3809 .58514 .3741 Mtetra
.658 .753 .92 r
.58514 .3741 .5909 .3809 .60209 .37713 .59637 .37031 Mtetra
.659 .754 .92 r
.59637 .37031 .60209 .37713 .61333 .37333 .60764 .36649 Mtetra
.60764 .36649 .61333 .37333 .62461 .36953 .61895 .36265 Mtetra
.61895 .36265 .62461 .36953 .63594 .36571 .63031 .3588 Mtetra
.63031 .3588 .63594 .36571 .64731 .36188 .64171 .35494 Mtetra
.658 .753 .92 r
.64171 .35494 .64731 .36188 .65873 .35805 .65316 .35108 Mtetra
.65316 .35108 .65873 .35805 .6702 .3542 .66466 .3472 Mtetra
.66466 .3472 .6702 .3542 .68171 .35035 .67621 .34332 Mtetra
.67621 .34332 .68171 .35035 .69327 .34648 .6878 .33942 Mtetra
.6878 .33942 .69327 .34648 .70488 .3426 .69944 .33551 Mtetra
.69944 .33551 .70488 .3426 .71653 .33871 .71113 .33158 Mtetra
.657 .753 .92 r
.71113 .33158 .71653 .33871 .72823 .3348 .72286 .32764 Mtetra
.72286 .32764 .72823 .3348 .73998 .33088 .73464 .32369 Mtetra
.73464 .32369 .73998 .33088 .75178 .32694 .74648 .31972 Mtetra
.74648 .31972 .75178 .32694 .76363 .32299 .75836 .31574 Mtetra
.75836 .31574 .76363 .32299 .77552 .31902 .77029 .31174 Mtetra
.657 .752 .92 r
.77029 .31174 .77552 .31902 .78747 .31504 .78227 .30773 Mtetra
.78227 .30773 .78747 .31504 .79946 .31104 .7943 .3037 Mtetra
.7943 .3037 .79946 .31104 .81151 .30703 .80638 .29966 Mtetra
.80638 .29966 .81151 .30703 .8236 .303 .81851 .2956 Mtetra
.504 .626 .904 r
.1736 .49952 .18014 .50766 .18958 .50648 .18292 .49957 Mtetra
.523 .674 .933 r
.18292 .49957 .18958 .50648 .19764 .51993 .19236 .49901 Mtetra
.695 .55 .686 r
.19236 .49901 .19764 .51993 .20921 .49774 .20277 .48897 Mtetra
.48 .597 .893 r
.20277 .48897 .20921 .49774 .21879 .49644 .21217 .48958 Mtetra
.563 .693 .928 r
.21217 .48958 .21879 .49644 .22816 .4979 .2218 .48833 Mtetra
.823 .702 .731 r
.2218 .48833 .22816 .4979 .23866 .48713 .23273 .47304 Mtetra
.258 .353 .77 r
.23273 .47304 .23866 .48713 .24833 .48612 .24178 .47922 Mtetra
.584 .701 .923 r
.24178 .47922 .24833 .48612 .25807 .48492 .25157 .47755 Mtetra
.207 .5 .906 r
.25157 .47755 .25807 .48492 .2687 .47297 .261 .48094 Mtetra
.644 .89 .553 r
.261 .48094 .2687 .47297 .27822 .47549 .27175 .46815 Mtetra
.573 .685 .916 r
.27175 .46815 .27822 .47549 .28814 .47359 .28165 .46673 Mtetra
.579 .703 .927 r
.28165 .46673 .28814 .47359 .29792 .47434 .29161 .4651 Mtetra
.849 .716 .716 r
.29161 .4651 .29792 .47434 .30851 .4637 .30275 .44679 Mtetra
.207 .279 .718 r
.30275 .44679 .30851 .4637 .3185 .46254 .31208 .45556 Mtetra
.6 .709 .92 r
.31208 .45556 .3185 .46254 .3286 .4604 .32219 .45349 Mtetra
.58 .704 .928 r
.32219 .45349 .3286 .4604 .33853 .46213 .33233 .45182 Mtetra
.812 .698 .739 r
.33233 .45182 .33853 .46213 .34924 .45044 .3432 .43776 Mtetra
.355 .441 .812 r
.3432 .43776 .34924 .45044 .35943 .4489 .3531 .44192 Mtetra
.61 .715 .92 r
.3531 .44192 .35943 .4489 .36972 .44645 .36339 .4396 Mtetra
.608 .719 .924 r
.36339 .4396 .36972 .44645 .38 .44503 .37374 .43729 Mtetra
0 .276 .776 r
.37374 .43729 .38 .44503 .39074 .4339 .38373 .44431 Mtetra
.626 .823 .413 r
.38373 .44431 .39074 .4339 .40102 .43457 .39479 .4272 Mtetra
.598 .701 .915 r
.39479 .4272 .40102 .43457 .41148 .43198 .40525 .42514 Mtetra
.627 .729 .921 r
.40525 .42514 .41148 .43198 .422 .42923 .41579 .42235 Mtetra
.617 .726 .923 r
.41579 .42235 .422 .42923 .43253 .42739 .42636 .41977 Mtetra
.278 .536 .916 r
.42636 .41977 .43253 .42739 .44338 .41487 .43683 .42282 Mtetra
.565 .823 .458 r
.43683 .42282 .44338 .41487 .4539 .41681 .44778 .40923 Mtetra
.597 .697 .913 r
.44778 .40923 .4539 .41681 .46458 .41406 .45848 .40716 Mtetra
.634 .734 .92 r
.45848 .40716 .46458 .41406 .47532 .41094 .46924 .40412 Mtetra
.64 .74 .921 r
.46924 .40412 .47532 .41094 .4861 .40776 .48004 .40091 Mtetra
.638 .739 .921 r
.48004 .40091 .4861 .40776 .49693 .40476 .4909 .39775 Mtetra
.618 .727 .924 r
.4909 .39775 .49693 .40476 .50779 .40334 .50179 .39507 Mtetra
.844 .423 0 r
.50179 .39507 .50779 .40334 .51874 .39241 .51263 .42091 Mtetra
0 0 .028 r
.51263 .42091 .51874 .39241 .52969 .39168 .52374 .38424 Mtetra
.617 .714 .915 r
.52374 .38424 .52969 .39168 .54069 .38857 .53477 .3816 Mtetra
.644 .74 .919 r
.53477 .3816 .54069 .38857 .55174 .38512 .54585 .37823 Mtetra
.651 .747 .92 r
.54585 .37823 .55174 .38512 .56283 .38152 .55697 .37466 Mtetra
.654 .75 .92 r
.55697 .37466 .56283 .38152 .57396 .37784 .56813 .37099 Mtetra
.656 .752 .92 r
.56813 .37099 .57396 .37784 .58514 .3741 .57934 .36724 Mtetra
.658 .753 .92 r
.57934 .36724 .58514 .3741 .59637 .37031 .5906 .36343 Mtetra
.659 .754 .92 r
.5906 .36343 .59637 .37031 .60764 .36649 .6019 .35959 Mtetra
.6019 .35959 .60764 .36649 .61895 .36265 .61324 .35573 Mtetra
.61324 .35573 .61895 .36265 .63031 .3588 .62463 .35185 Mtetra
.62463 .35185 .63031 .3588 .64171 .35494 .63607 .34796 Mtetra
.658 .754 .92 r
.63607 .34796 .64171 .35494 .65316 .35108 .64755 .34406 Mtetra
.658 .753 .92 r
.64755 .34406 .65316 .35108 .66466 .3472 .65908 .34015 Mtetra
.65908 .34015 .66466 .3472 .67621 .34332 .67066 .33623 Mtetra
.67066 .33623 .67621 .34332 .6878 .33942 .68228 .3323 Mtetra
.68228 .3323 .6878 .33942 .69944 .33551 .69396 .32836 Mtetra
.69396 .32836 .69944 .33551 .71113 .33158 .70568 .32441 Mtetra
.657 .753 .92 r
.70568 .32441 .71113 .33158 .72286 .32764 .71745 .32044 Mtetra
.71745 .32044 .72286 .32764 .73464 .32369 .72926 .31645 Mtetra
.72926 .31645 .73464 .32369 .74648 .31972 .74113 .31245 Mtetra
.74113 .31245 .74648 .31972 .75836 .31574 .75305 .30844 Mtetra
.75305 .30844 .75836 .31574 .77029 .31174 .76501 .30441 Mtetra
.657 .752 .92 r
.76501 .30441 .77029 .31174 .78227 .30773 .77703 .30037 Mtetra
.77703 .30037 .78227 .30773 .7943 .3037 .78909 .29631 Mtetra
.78909 .29631 .7943 .3037 .80638 .29966 .80121 .29223 Mtetra
.80121 .29223 .80638 .29966 .81851 .2956 .81337 .28814 Mtetra
0 0 0 r
.15557 .59735 .1736 .49952 .18292 .49957 .17623 .49254 Mtetra
.562 .687 .924 r
.17623 .49254 .18292 .49957 .19236 .49901 .18574 .49131 Mtetra
.758 .29 0 r
.18574 .49131 .19236 .49901 .20277 .48897 .19384 .50478 Mtetra
.706 .836 .398 r
.19384 .50478 .20277 .48897 .21217 .48958 .20554 .48245 Mtetra
.569 .688 .921 r
.20554 .48245 .21217 .48958 .2218 .48833 .21519 .4811 Mtetra
.381 .602 .934 r
.21519 .4811 .2218 .48833 .23273 .47304 .22464 .48252 Mtetra
0 0 0 r
.22464 .48252 .23273 .47304 .24178 .47922 .23523 .47166 Mtetra
.556 .671 .914 r
.23523 .47166 .24178 .47922 .25157 .47755 .24498 .4706 Mtetra
.56 .693 .929 r
.24498 .4706 .25157 .47755 .261 .48094 .2548 .46935 Mtetra
.779 .668 .741 r
.2548 .46935 .261 .48094 .27175 .46815 .26552 .4573 Mtetra
.403 .508 .851 r
.26552 .4573 .27175 .46815 .28165 .46673 .27512 .45978 Mtetra
.594 .708 .922 r
.27512 .45978 .28165 .46673 .29161 .4651 .28512 .45784 Mtetra
.44 .632 .936 r
.28512 .45784 .29161 .4651 .30275 .44679 .29498 .45854 Mtetra
0 0 0 r
.29498 .45854 .30275 .44679 .31208 .45556 .30566 .44781 Mtetra
.563 .671 .911 r
.30566 .44781 .31208 .45556 .32219 .45349 .31574 .4466 Mtetra
.604 .715 .923 r
.31574 .4466 .32219 .45349 .33233 .45182 .32592 .4444 Mtetra
.37 .593 .932 r
.32592 .4444 .33233 .45182 .3432 .43776 .33593 .44609 Mtetra
0 0 0 r
.33593 .44609 .3432 .43776 .3531 .44192 .34675 .4343 Mtetra
.578 .684 .913 r
.34675 .4343 .3531 .44192 .36339 .4396 .35702 .43271 Mtetra
.616 .722 .922 r
.35702 .43271 .36339 .4396 .37374 .43729 .3674 .4302 Mtetra
.567 .698 .929 r
.3674 .4302 .37374 .43729 .38373 .44431 .37777 .42872 Mtetra
.74 .615 .72 r
.37777 .42872 .38373 .44431 .39479 .4272 .38861 .4175 Mtetra
.488 .586 .878 r
.38861 .4175 .39479 .4272 .40525 .42514 .39898 .41812 Mtetra
.62 .723 .92 r
.39898 .41812 .40525 .42514 .41579 .42235 .40953 .41547 Mtetra
.626 .73 .922 r
.40953 .41547 .41579 .42235 .42636 .41977 .42014 .41266 Mtetra
.585 .708 .928 r
.42014 .41266 .42636 .41977 .43683 .42282 .43076 .41076 Mtetra
.786 .675 .741 r
.43076 .41076 .43683 .42282 .44778 .40923 .44172 .39814 Mtetra
.445 .532 .852 r
.44172 .39814 .44778 .40923 .45848 .40716 .45233 .40003 Mtetra
.624 .724 .919 r
.45233 .40003 .45848 .40716 .46924 .40412 .46311 .39722 Mtetra
.639 .738 .92 r
.46311 .39722 .46924 .40412 .48004 .40091 .47394 .39403 Mtetra
.64 .74 .921 r
.47394 .39403 .48004 .40091 .4909 .39775 .48482 .39079 Mtetra
.633 .735 .922 r
.48482 .39079 .4909 .39775 .50179 .39507 .49575 .38773 Mtetra
.563 .696 .93 r
.49575 .38773 .50179 .39507 .51263 .42091 .50671 .38625 Mtetra
.65 .477 .637 r
.50671 .38625 .51263 .42091 .52374 .38424 .51776 .37522 Mtetra
.545 .638 .893 r
.51776 .37522 .52374 .38424 .53477 .3816 .52881 .37443 Mtetra
.635 .733 .919 r
.52881 .37443 .53477 .3816 .54585 .37823 .53991 .37125 Mtetra
.648 .744 .92 r
.53991 .37125 .54585 .37823 .55697 .37466 .55106 .36773 Mtetra
.653 .749 .92 r
.55106 .36773 .55697 .37466 .56813 .37099 .56226 .36407 Mtetra
.655 .751 .92 r
.56226 .36407 .56813 .37099 .57934 .36724 .5735 .36031 Mtetra
.657 .752 .92 r
.5735 .36031 .57934 .36724 .5906 .36343 .58479 .3565 Mtetra
.658 .753 .92 r
.58479 .3565 .5906 .36343 .6019 .35959 .59612 .35264 Mtetra
.659 .754 .92 r
.59612 .35264 .6019 .35959 .61324 .35573 .60749 .34875 Mtetra
.60749 .34875 .61324 .35573 .62463 .35185 .61891 .34484 Mtetra
.61891 .34484 .62463 .35185 .63607 .34796 .63038 .34092 Mtetra
.63038 .34092 .63607 .34796 .64755 .34406 .6419 .33698 Mtetra
.658 .753 .92 r
.6419 .33698 .64755 .34406 .65908 .34015 .65346 .33304 Mtetra
.65346 .33304 .65908 .34015 .67066 .33623 .66507 .32909 Mtetra
.66507 .32909 .67066 .33623 .68228 .3323 .67673 .32513 Mtetra
.67673 .32513 .68228 .3323 .69396 .32836 .68843 .32116 Mtetra
.68843 .32116 .69396 .32836 .70568 .32441 .70019 .31717 Mtetra
.70019 .31717 .70568 .32441 .71745 .32044 .71199 .31317 Mtetra
.657 .753 .92 r
.71199 .31317 .71745 .32044 .72926 .31645 .72384 .30916 Mtetra
.72384 .30916 .72926 .31645 .74113 .31245 .73574 .30513 Mtetra
.73574 .30513 .74113 .31245 .75305 .30844 .74769 .30108 Mtetra
.74769 .30108 .75305 .30844 .76501 .30441 .75969 .29702 Mtetra
.75969 .29702 .76501 .30441 .77703 .30037 .77174 .29295 Mtetra
.657 .752 .92 r
.77174 .29295 .77703 .30037 .78909 .29631 .78385 .28885 Mtetra
.78385 .28885 .78909 .29631 .80121 .29223 .796 .28475 Mtetra
.796 .28475 .80121 .29223 .81337 .28814 .8082 .28062 Mtetra
.575 .369 .564 r
.1592 .49402 .15557 .59735 .17623 .49254 .16962 .48428 Mtetra
.504 .626 .905 r
.16962 .48428 .17623 .49254 .18574 .49131 .17901 .48429 Mtetra
.524 .674 .933 r
.17901 .48429 .18574 .49131 .19384 .50478 .18852 .48369 Mtetra
.694 .55 .686 r
.18852 .48369 .19384 .50478 .20554 .48245 .19903 .47356 Mtetra
.479 .597 .893 r
.19903 .47356 .20554 .48245 .21519 .4811 .2085 .47412 Mtetra
.563 .693 .928 r
.2085 .47412 .21519 .4811 .22464 .48252 .21821 .47282 Mtetra
.824 .703 .731 r
.21821 .47282 .22464 .48252 .23523 .47166 .22924 .45743 Mtetra
.256 .351 .77 r
.22924 .45743 .23523 .47166 .24498 .4706 .23835 .46359 Mtetra
.584 .701 .923 r
.23835 .46359 .24498 .4706 .2548 .46935 .24822 .46186 Mtetra
.209 .501 .906 r
.24822 .46186 .2548 .46935 .26552 .4573 .25773 .46522 Mtetra
.653 .897 .563 r
.25773 .46522 .26552 .4573 .27512 .45978 .26858 .45233 Mtetra
.573 .685 .916 r
.26858 .45233 .27512 .45978 .28512 .45784 .27856 .45086 Mtetra
.579 .703 .927 r
.27856 .45086 .28512 .45784 .29498 .45854 .2886 .44917 Mtetra
.85 .716 .716 r
.2886 .44917 .29498 .45854 .30566 .44781 .29985 .43074 Mtetra
.204 .277 .718 r
.29985 .43074 .30566 .44781 .31574 .4466 .30925 .4395 Mtetra
.6 .709 .92 r
.30925 .4395 .31574 .4466 .32592 .4444 .31945 .43737 Mtetra
.58 .704 .928 r
.31945 .43737 .32592 .4444 .33593 .44609 .32967 .43565 Mtetra
.813 .699 .739 r
.32967 .43565 .33593 .44609 .34675 .4343 .34065 .42148 Mtetra
.353 .441 .812 r
.34065 .42148 .34675 .4343 .35702 .43271 .35062 .42561 Mtetra
.61 .715 .92 r
.35062 .42561 .35702 .43271 .3674 .4302 .36101 .42323 Mtetra
.608 .719 .924 r
.36101 .42323 .3674 .4302 .37777 .42872 .37144 .42086 Mtetra
0 .28 .778 r
.37144 .42086 .37777 .42872 .38861 .4175 .38151 .42786 Mtetra
.636 .83 .423 r
.38151 .42786 .38861 .4175 .39898 .41812 .39268 .41063 Mtetra
.598 .701 .916 r
.39268 .41063 .39898 .41812 .40953 .41547 .40323 .40851 Mtetra
.627 .729 .921 r
.40323 .40851 .40953 .41547 .42014 .41266 .41386 .40566 Mtetra
.617 .726 .923 r
.41386 .40566 .42014 .41266 .43076 .41076 .42453 .40301 Mtetra
.28 .537 .916 r
.42453 .40301 .43076 .41076 .44172 .39814 .43509 .40602 Mtetra
.576 .832 .469 r
.43509 .40602 .44172 .39814 .45233 .40003 .44615 .39232 Mtetra
.597 .697 .913 r
.44615 .39232 .45233 .40003 .46311 .39722 .45694 .39019 Mtetra
.634 .734 .92 r
.45694 .39019 .46311 .39722 .47394 .39403 .4678 .38709 Mtetra
.64 .74 .921 r
.4678 .38709 .47394 .39403 .48482 .39079 .4787 .38382 Mtetra
.638 .739 .921 r
.4787 .38382 .48482 .39079 .49575 .38773 .48966 .38059 Mtetra
.618 .727 .924 r
.48966 .38059 .49575 .38773 .50671 .38625 .50065 .37784 Mtetra
.839 .418 0 r
.50065 .37784 .50671 .38625 .51776 .37522 .51158 .40374 Mtetra
0 0 .02 r
.51158 .40374 .51776 .37522 .52881 .37443 .5228 .36686 Mtetra
.617 .714 .915 r
.5228 .36686 .52881 .37443 .53991 .37125 .53394 .36415 Mtetra
.644 .741 .919 r
.53394 .36415 .53991 .37125 .55106 .36773 .54512 .36072 Mtetra
.651 .747 .92 r
.54512 .36072 .55106 .36773 .56226 .36407 .55634 .35708 Mtetra
.654 .75 .92 r
.55634 .35708 .56226 .36407 .5735 .36031 .56761 .35333 Mtetra
.656 .752 .92 r
.56761 .35333 .5735 .36031 .58479 .3565 .57893 .34951 Mtetra
.658 .753 .92 r
.57893 .34951 .58479 .3565 .59612 .35264 .59029 .34563 Mtetra
.659 .754 .92 r
.59029 .34563 .59612 .35264 .60749 .34875 .6017 .34172 Mtetra
.6017 .34172 .60749 .34875 .61891 .34484 .61315 .33778 Mtetra
.61315 .33778 .61891 .34484 .63038 .34092 .62465 .33382 Mtetra
.62465 .33382 .63038 .34092 .6419 .33698 .6362 .32986 Mtetra
.658 .754 .92 r
.6362 .32986 .6419 .33698 .65346 .33304 .64779 .32589 Mtetra
.658 .753 .92 r
.64779 .32589 .65346 .33304 .66507 .32909 .65944 .3219 Mtetra
.65944 .3219 .66507 .32909 .67673 .32513 .67113 .31791 Mtetra
.67113 .31791 .67673 .32513 .68843 .32116 .68287 .3139 Mtetra
.68287 .3139 .68843 .32116 .70019 .31717 .69465 .30989 Mtetra
.69465 .30989 .70019 .31717 .71199 .31317 .70649 .30585 Mtetra
.657 .753 .92 r
.70649 .30585 .71199 .31317 .72384 .30916 .71838 .30181 Mtetra
.71838 .30181 .72384 .30916 .73574 .30513 .73031 .29774 Mtetra
.73031 .29774 .73574 .30513 .74769 .30108 .7423 .29367 Mtetra
.7423 .29367 .74769 .30108 .75969 .29702 .75433 .28958 Mtetra
.75433 .28958 .75969 .29702 .77174 .29295 .76642 .28547 Mtetra
.657 .752 .92 r
.76642 .28547 .77174 .29295 .78385 .28885 .77856 .28134 Mtetra
.77856 .28134 .78385 .28885 .796 .28475 .79075 .2772 Mtetra
.79075 .2772 .796 .28475 .8082 .28062 .80299 .27305 Mtetra
.947 .662 .466 r
.15251 .48591 .1592 .49402 .16962 .48428 .15128 .58248 Mtetra
0 0 0 r
.15128 .58248 .16962 .48428 .17901 .48429 .17225 .47715 Mtetra
.562 .687 .924 r
.17225 .47715 .17901 .48429 .18852 .48369 .18184 .47588 Mtetra
.753 .284 0 r
.18184 .47588 .18852 .48369 .19903 .47356 .18998 .48935 Mtetra
.714 .843 .407 r
.18998 .48935 .19903 .47356 .2085 .47412 .2018 .46688 Mtetra
.569 .688 .921 r
.2018 .46688 .2085 .47412 .21821 .47282 .21153 .46548 Mtetra
.382 .602 .934 r
.21153 .46548 .21821 .47282 .22924 .45743 .22105 .46686 Mtetra
0 0 0 r
.22105 .46686 .22924 .45743 .23835 .46359 .23173 .45591 Mtetra
.556 .671 .914 r
.23173 .45591 .23835 .46359 .24822 .46186 .24156 .4548 Mtetra
.56 .693 .929 r
.24156 .4548 .24822 .46186 .25773 .46522 .25146 .4535 Mtetra
.78 .669 .741 r
.25146 .4535 .25773 .46522 .26858 .45233 .26228 .44135 Mtetra
.402 .507 .851 r
.26228 .44135 .26858 .45233 .27856 .45086 .27196 .4438 Mtetra
.594 .708 .922 r
.27196 .4438 .27856 .45086 .2886 .44917 .28204 .4418 Mtetra
.44 .632 .936 r
.28204 .4418 .2886 .44917 .29985 .43074 .29198 .44246 Mtetra
0 0 0 r
.29198 .44246 .29985 .43074 .30925 .4395 .30277 .43163 Mtetra
.562 .671 .911 r
.30277 .43163 .30925 .4395 .31945 .43737 .31292 .43036 Mtetra
.604 .715 .923 r
.31292 .43036 .31945 .43737 .32967 .43565 .3232 .42811 Mtetra
.371 .594 .932 r
.3232 .42811 .32967 .43565 .34065 .42148 .33329 .42975 Mtetra
0 0 0 r
.33329 .42975 .34065 .42148 .35062 .42561 .34421 .41787 Mtetra
.578 .684 .913 r
.34421 .41787 .35062 .42561 .36101 .42323 .35457 .41622 Mtetra
.616 .722 .922 r
.35457 .41622 .36101 .42323 .37144 .42086 .36504 .41365 Mtetra
.567 .698 .929 r
.36504 .41365 .37144 .42086 .38151 .42786 .3755 .41211 Mtetra
.74 .616 .72 r
.3755 .41211 .38151 .42786 .39268 .41063 .38644 .40079 Mtetra
.488 .586 .879 r
.38644 .40079 .39268 .41063 .40323 .40851 .3969 .40137 Mtetra
.62 .723 .92 r
.3969 .40137 .40323 .40851 .41386 .40566 .40754 .39865 Mtetra
.626 .73 .922 r
.40754 .39865 .41386 .40566 .42453 .40301 .41824 .39578 Mtetra
.585 .708 .927 r
.41824 .39578 .42453 .40301 .43509 .40602 .42896 .39382 Mtetra
.786 .675 .741 r
.42896 .39382 .43509 .40602 .44615 .39232 .44002 .38109 Mtetra
.444 .531 .852 r
.44002 .38109 .44615 .39232 .45694 .39019 .45073 .38294 Mtetra
.624 .725 .919 r
.45073 .38294 .45694 .39019 .4678 .38709 .46161 .38006 Mtetra
.639 .738 .92 r
.46161 .38006 .4678 .38709 .4787 .38382 .47254 .37681 Mtetra
.64 .74 .921 r
.47254 .37681 .4787 .38382 .48966 .38059 .48352 .3735 Mtetra
.633 .735 .922 r
.48352 .3735 .48966 .38059 .50065 .37784 .49455 .37037 Mtetra
.563 .696 .93 r
.49455 .37037 .50065 .37784 .51158 .40374 .50561 .36883 Mtetra
.649 .476 .636 r
.50561 .36883 .51158 .40374 .5228 .36686 .51676 .3577 Mtetra
.545 .638 .893 r
.51676 .3577 .5228 .36686 .53394 .36415 .52791 .35686 Mtetra
.635 .733 .919 r
.52791 .35686 .53394 .36415 .54512 .36072 .53912 .35361 Mtetra
.648 .744 .92 r
.53912 .35361 .54512 .36072 .55634 .35708 .55038 .35001 Mtetra
.653 .749 .92 r
.55038 .35001 .55634 .35708 .56761 .35333 .56168 .34628 Mtetra
.655 .751 .92 r
.56168 .34628 .56761 .35333 .57893 .34951 .57303 .34245 Mtetra
.657 .752 .92 r
.57303 .34245 .57893 .34951 .59029 .34563 .58442 .33856 Mtetra
.658 .753 .92 r
.58442 .33856 .59029 .34563 .6017 .34172 .59586 .33463 Mtetra
.659 .754 .92 r
.59586 .33463 .6017 .34172 .61315 .33778 .60735 .33066 Mtetra
.60735 .33066 .61315 .33778 .62465 .33382 .61888 .32668 Mtetra
.61888 .32668 .62465 .33382 .6362 .32986 .63046 .32268 Mtetra
.63046 .32268 .6362 .32986 .64779 .32589 .64209 .31867 Mtetra
.658 .753 .92 r
.64209 .31867 .64779 .32589 .65944 .3219 .65376 .31466 Mtetra
.65376 .31466 .65944 .3219 .67113 .31791 .66549 .31063 Mtetra
.66549 .31063 .67113 .31791 .68287 .3139 .67726 .30659 Mtetra
.67726 .30659 .68287 .3139 .69465 .30989 .68908 .30254 Mtetra
.68908 .30254 .69465 .30989 .70649 .30585 .70095 .29848 Mtetra
.70095 .29848 .70649 .30585 .71838 .30181 .71287 .2944 Mtetra
.657 .753 .92 r
.71287 .2944 .71838 .30181 .73031 .29774 .72484 .29031 Mtetra
.72484 .29031 .73031 .29774 .7423 .29367 .73686 .2862 Mtetra
.73686 .2862 .7423 .29367 .75433 .28958 .74893 .28207 Mtetra
.74893 .28207 .75433 .28958 .76642 .28547 .76106 .27793 Mtetra
.76106 .27793 .76642 .28547 .77856 .28134 .77323 .27377 Mtetra
.657 .752 .92 r
.77323 .27377 .77856 .28134 .79075 .2772 .78546 .2696 Mtetra
.78546 .2696 .79075 .2772 .80299 .27305 .79773 .26541 Mtetra
.493 .659 .935 r
.14566 .47875 .15251 .48591 .15128 .58248 .15506 .4786 Mtetra
.573 .366 .562 r
.15506 .4786 .15128 .58248 .17225 .47715 .16556 .46878 Mtetra
.504 .626 .905 r
.16556 .46878 .17225 .47715 .18184 .47588 .17503 .46874 Mtetra
.524 .674 .933 r
.17503 .46874 .18184 .47588 .18998 .48935 .18462 .46809 Mtetra
.694 .55 .686 r
.18462 .46809 .18998 .48935 .2018 .46688 .19522 .45787 Mtetra
.479 .597 .893 r
.19522 .45787 .2018 .46688 .21153 .46548 .20477 .45839 Mtetra
.563 .693 .928 r
.20477 .45839 .21153 .46548 .22105 .46686 .21455 .45704 Mtetra
.825 .704 .731 r
.21455 .45704 .22105 .46686 .23173 .45591 .22569 .44154 Mtetra
.254 .35 .769 r
.22569 .44154 .23173 .45591 .24156 .4548 .23487 .44767 Mtetra
.584 .701 .923 r
.23487 .44767 .24156 .4548 .25146 .4535 .24482 .44589 Mtetra
.211 .502 .906 r
.24482 .44589 .25146 .4535 .26228 .44135 .2544 .44921 Mtetra
.663 .904 .572 r
.2544 .44921 .26228 .44135 .27196 .4438 .26535 .43623 Mtetra
.573 .685 .916 r
.26535 .43623 .27196 .4438 .28204 .4418 .27541 .4347 Mtetra
.58 .703 .927 r
.27541 .4347 .28204 .4418 .29198 .44246 .28554 .43296 Mtetra
.85 .717 .716 r
.28554 .43296 .29198 .44246 .30277 .43163 .2969 .4144 Mtetra
.201 .275 .717 r
.2969 .4144 .30277 .43163 .31292 .43036 .30637 .42315 Mtetra
.6 .709 .92 r
.30637 .42315 .31292 .43036 .3232 .42811 .31665 .42096 Mtetra
.58 .704 .928 r
.31665 .42096 .3232 .42811 .33329 .42975 .32696 .41918 Mtetra
.813 .7 .739 r
.32696 .41918 .33329 .42975 .34421 .41787 .33805 .4049 Mtetra
.352 .44 .812 r
.33805 .4049 .34421 .41787 .35457 .41622 .3481 .409 Mtetra
.61 .715 .92 r
.3481 .409 .35457 .41622 .36504 .41365 .35858 .40656 Mtetra
.608 .719 .924 r
.35858 .40656 .36504 .41365 .3755 .41211 .3691 .40413 Mtetra
0 .283 .781 r
.3691 .40413 .3755 .41211 .38644 .40079 .37926 .4111 Mtetra
.645 .838 .433 r
.37926 .4111 .38644 .40079 .3969 .40137 .39053 .39375 Mtetra
.598 .701 .916 r
.39053 .39375 .3969 .40137 .40754 .39865 .40118 .39157 Mtetra
.627 .729 .921 r
.40118 .39157 .40754 .39865 .41824 .39578 .41191 .38865 Mtetra
.617 .726 .923 r
.41191 .38865 .41824 .39578 .42896 .39382 .42267 .38594 Mtetra
.283 .537 .916 r
.42267 .38594 .42896 .39382 .44002 .38109 .43332 .38891 Mtetra
.587 .841 .48 r
.43332 .38891 .44002 .38109 .45073 .38294 .44449 .3751 Mtetra
.596 .697 .913 r
.44449 .3751 .45073 .38294 .46161 .38006 .45537 .37291 Mtetra
.634 .734 .92 r
.45537 .37291 .46161 .38006 .47254 .37681 .46633 .36974 Mtetra
.64 .74 .921 r
.46633 .36974 .47254 .37681 .48352 .3735 .47734 .3664 Mtetra
.638 .739 .921 r
.47734 .3664 .48352 .3735 .49455 .37037 .48839 .3631 Mtetra
.618 .727 .924 r
.48839 .3631 .49455 .37037 .50561 .36883 .49949 .36029 Mtetra
.834 .412 0 r
.49949 .36029 .50561 .36883 .51676 .3577 .51051 .38623 Mtetra
0 0 .011 r
.51051 .38623 .51676 .3577 .52791 .35686 .52185 .34915 Mtetra
.616 .714 .915 r
.52185 .34915 .52791 .35686 .53912 .35361 .53309 .34637 Mtetra
.644 .741 .92 r
.53309 .34637 .53912 .35361 .55038 .35001 .54437 .34286 Mtetra
.651 .747 .92 r
.54437 .34286 .55038 .35001 .56168 .34628 .5557 .33915 Mtetra
.654 .75 .92 r
.5557 .33915 .56168 .34628 .57303 .34245 .56708 .33533 Mtetra
.656 .752 .92 r
.56708 .33533 .57303 .34245 .58442 .33856 .57851 .33143 Mtetra
.658 .753 .92 r
.57851 .33143 .58442 .33856 .59586 .33463 .58998 .32748 Mtetra
.659 .754 .92 r
.58998 .32748 .59586 .33463 .60735 .33066 .6015 .32349 Mtetra
.6015 .32349 .60735 .33066 .61888 .32668 .61306 .31948 Mtetra
.61306 .31948 .61888 .32668 .63046 .32268 .62467 .31545 Mtetra
.62467 .31545 .63046 .32268 .64209 .31867 .63633 .31141 Mtetra
.658 .754 .92 r
.63633 .31141 .64209 .31867 .65376 .31466 .64804 .30736 Mtetra
.658 .753 .92 r
.64804 .30736 .65376 .31466 .66549 .31063 .6598 .3033 Mtetra
.6598 .3033 .66549 .31063 .67726 .30659 .67161 .29923 Mtetra
.67161 .29923 .67726 .30659 .68908 .30254 .68346 .29514 Mtetra
.68346 .29514 .68908 .30254 .70095 .29848 .69537 .29105 Mtetra
.69537 .29105 .70095 .29848 .71287 .2944 .70732 .28693 Mtetra
.657 .753 .92 r
.70732 .28693 .71287 .2944 .72484 .29031 .71933 .28281 Mtetra
.71933 .28281 .72484 .29031 .73686 .2862 .73138 .27867 Mtetra
.73138 .27867 .73686 .2862 .74893 .28207 .74349 .27451 Mtetra
.74349 .27451 .74893 .28207 .76106 .27793 .75565 .27033 Mtetra
.75565 .27033 .76106 .27793 .77323 .27377 .76786 .26614 Mtetra
.657 .752 .92 r
.76786 .26614 .77323 .27377 .78546 .2696 .78012 .26194 Mtetra
.78012 .26194 .78546 .2696 .79773 .26541 .79244 .25771 Mtetra
.552 .681 .924 r
.13877 .47148 .14566 .47875 .15506 .4786 .14829 .47037 Mtetra
.948 .662 .464 r
.14829 .47037 .15506 .4786 .16556 .46878 .14692 .56733 Mtetra
0 0 0 r
.14692 .56733 .16556 .46878 .17503 .46874 .16819 .46148 Mtetra
.562 .687 .924 r
.16819 .46148 .17503 .46874 .18462 .46809 .17786 .46016 Mtetra
.747 .279 0 r
.17786 .46016 .18462 .46809 .19522 .45787 .18605 .47364 Mtetra
.722 .849 .416 r
.18605 .47364 .19522 .45787 .20477 .45839 .19799 .45103 Mtetra
.569 .688 .921 r
.19799 .45103 .20477 .45839 .21455 .45704 .2078 .44958 Mtetra
.383 .603 .934 r
.2078 .44958 .21455 .45704 .22569 .44154 .21739 .45092 Mtetra
0 0 0 r
.21739 .45092 .22569 .44154 .23487 .44767 .22818 .43988 Mtetra
.556 .671 .915 r
.22818 .43988 .23487 .44767 .24482 .44589 .23809 .43872 Mtetra
.56 .693 .929 r
.23809 .43872 .24482 .44589 .2544 .44921 .24807 .43736 Mtetra
.78 .67 .741 r
.24807 .43736 .2544 .44921 .26535 .43623 .25899 .42511 Mtetra
.402 .507 .851 r
.25899 .42511 .26535 .43623 .27541 .4347 .26874 .42752 Mtetra
.594 .708 .922 r
.26874 .42752 .27541 .4347 .28554 .43296 .27891 .42546 Mtetra
.441 .633 .936 r
.27891 .42546 .28554 .43296 .2969 .4144 .28893 .42607 Mtetra
0 0 0 r
.28893 .42607 .2969 .4144 .30637 .42315 .29982 .41515 Mtetra
.562 .671 .911 r
.29982 .41515 .30637 .42315 .31665 .42096 .31006 .41383 Mtetra
.604 .715 .923 r
.31006 .41383 .31665 .42096 .32696 .41918 .32042 .41151 Mtetra
.372 .594 .931 r
.32042 .41151 .32696 .41918 .33805 .4049 .3306 .41312 Mtetra
0 0 0 r
.3306 .41312 .33805 .4049 .3481 .409 .34162 .40113 Mtetra
.578 .684 .913 r
.34162 .40113 .3481 .409 .35858 .40656 .35207 .39942 Mtetra
.616 .722 .922 r
.35207 .39942 .35858 .40656 .3691 .40413 .36263 .39679 Mtetra
.568 .698 .929 r
.36263 .39679 .3691 .40413 .37926 .4111 .37319 .3952 Mtetra
.74 .616 .72 r
.37319 .3952 .37926 .4111 .39053 .39375 .38423 .38378 Mtetra
.488 .586 .879 r
.38423 .38378 .39053 .39375 .40118 .39157 .39478 .3843 Mtetra
.62 .723 .92 r
.39478 .3843 .40118 .39157 .41191 .38865 .40552 .38152 Mtetra
.626 .73 .922 r
.40552 .38152 .41191 .38865 .42267 .38594 .41632 .37858 Mtetra
.585 .708 .927 r
.41632 .37858 .42267 .38594 .43332 .38891 .42713 .37656 Mtetra
.787 .676 .742 r
.42713 .37656 .43332 .38891 .44449 .3751 .4383 .36373 Mtetra
.444 .531 .852 r
.4383 .36373 .44449 .3751 .45537 .37291 .4491 .36552 Mtetra
.624 .725 .919 r
.4491 .36552 .45537 .37291 .46633 .36974 .46007 .36258 Mtetra
.639 .738 .92 r
.46007 .36258 .46633 .36974 .47734 .3664 .47111 .35926 Mtetra
.64 .74 .921 r
.47111 .35926 .47734 .3664 .48839 .3631 .48219 .35588 Mtetra
.633 .735 .922 r
.48219 .35588 .48839 .3631 .49949 .36029 .49332 .35268 Mtetra
.564 .696 .929 r
.49332 .35268 .49949 .36029 .51051 .38623 .50449 .35108 Mtetra
.649 .475 .635 r
.50449 .35108 .51051 .38623 .52185 .34915 .51575 .33985 Mtetra
.544 .638 .893 r
.51575 .33985 .52185 .34915 .53309 .34637 .527 .33894 Mtetra
.635 .733 .919 r
.527 .33894 .53309 .34637 .54437 .34286 .53832 .33562 Mtetra
.648 .744 .92 r
.53832 .33562 .54437 .34286 .5557 .33915 .54968 .33195 Mtetra
.653 .749 .92 r
.54968 .33195 .5557 .33915 .56708 .33533 .56109 .32814 Mtetra
.655 .751 .92 r
.56109 .32814 .56708 .33533 .57851 .33143 .57255 .32424 Mtetra
.657 .752 .92 r
.57255 .32424 .57851 .33143 .58998 .32748 .58405 .32028 Mtetra
.658 .753 .92 r
.58405 .32028 .58998 .32748 .6015 .32349 .5956 .31627 Mtetra
.659 .754 .92 r
.5956 .31627 .6015 .32349 .61306 .31948 .6072 .31223 Mtetra
.6072 .31223 .61306 .31948 .62467 .31545 .61884 .30816 Mtetra
.61884 .30816 .62467 .31545 .63633 .31141 .63054 .30409 Mtetra
.63054 .30409 .63633 .31141 .64804 .30736 .64228 .3 Mtetra
.658 .753 .92 r
.64228 .3 .64804 .30736 .6598 .3033 .65407 .29591 Mtetra
.65407 .29591 .6598 .3033 .67161 .29923 .66591 .29181 Mtetra
.66591 .29181 .67161 .29923 .68346 .29514 .6778 .28769 Mtetra
.6778 .28769 .68346 .29514 .69537 .29105 .68974 .28356 Mtetra
.68974 .28356 .69537 .29105 .70732 .28693 .70173 .27941 Mtetra
.70173 .27941 .70732 .28693 .71933 .28281 .71377 .27525 Mtetra
.657 .753 .92 r
.71377 .27525 .71933 .28281 .73138 .27867 .72586 .27108 Mtetra
.72586 .27108 .73138 .27867 .74349 .27451 .73801 .26689 Mtetra
.73801 .26689 .74349 .27451 .75565 .27033 .7502 .26268 Mtetra
.7502 .26268 .75565 .27033 .76786 .26614 .76245 .25846 Mtetra
.76245 .25846 .76786 .26614 .78012 .26194 .77475 .25421 Mtetra
.657 .752 .92 r
.77475 .25421 .78012 .26194 .79244 .25771 .7871 .24996 Mtetra
.483 .609 .901 r
.13201 .46279 .13877 .47148 .14829 .47037 .14137 .4631 Mtetra
.493 .659 .935 r
.14137 .4631 .14829 .47037 .14692 .56733 .15084 .4629 Mtetra
.571 .363 .56 r
.15084 .4629 .14692 .56733 .16819 .46148 .16144 .45299 Mtetra
.504 .626 .905 r
.16144 .45299 .16819 .46148 .17786 .46016 .17098 .45291 Mtetra
.524 .674 .932 r
.17098 .45291 .17786 .46016 .18605 .47364 .18064 .45221 Mtetra
.694 .549 .685 r
.18064 .45221 .18605 .47364 .19799 .45103 .19134 .4419 Mtetra
.479 .597 .893 r
.19134 .4419 .19799 .45103 .2078 .44958 .20096 .44237 Mtetra
.563 .693 .928 r
.20096 .44237 .2078 .44958 .21739 .45092 .21083 .44097 Mtetra
.825 .705 .731 r
.21083 .44097 .21739 .45092 .22818 .43988 .22207 .42535 Mtetra
.252 .349 .769 r
.22207 .42535 .22818 .43988 .23809 .43872 .23132 .43146 Mtetra
.584 .701 .923 r
.23132 .43146 .23809 .43872 .24807 .43736 .24135 .42963 Mtetra
.214 .503 .906 r
.24135 .42963 .24807 .43736 .25899 .42511 .251 .43291 Mtetra
.672 .911 .582 r
.251 .43291 .25899 .42511 .26874 .42752 .26206 .41982 Mtetra
.573 .685 .916 r
.26206 .41982 .26874 .42752 .27891 .42546 .27221 .41824 Mtetra
.58 .703 .927 r
.27221 .41824 .27891 .42546 .28893 .42607 .28242 .41644 Mtetra
.851 .718 .715 r
.28242 .41644 .28893 .42607 .29982 .41515 .29389 .39776 Mtetra
.198 .274 .716 r
.29389 .39776 .29982 .41515 .31006 .41383 .30343 .40649 Mtetra
.6 .709 .92 r
.30343 .40649 .31006 .41383 .32042 .41151 .31381 .40424 Mtetra
.58 .704 .928 r
.31381 .40424 .32042 .41151 .3306 .41312 .32421 .4024 Mtetra
.814 .7 .74 r
.32421 .4024 .3306 .41312 .34162 .40113 .3354 .38801 Mtetra
.351 .439 .812 r
.3354 .38801 .34162 .40113 .35207 .39942 .34553 .39208 Mtetra
.61 .715 .92 r
.34553 .39208 .35207 .39942 .36263 .39679 .3561 .38957 Mtetra
.608 .719 .924 r
.3561 .38957 .36263 .39679 .37319 .3952 .36672 .38708 Mtetra
0 .287 .784 r
.36672 .38708 .37319 .3952 .38423 .38378 .37696 .39403 Mtetra
.655 .845 .442 r
.37696 .39403 .38423 .38378 .39478 .3843 .38835 .37655 Mtetra
.598 .701 .916 r
.38835 .37655 .39478 .3843 .40552 .38152 .39909 .37431 Mtetra
.627 .729 .921 r
.39909 .37431 .40552 .38152 .41632 .37858 .40991 .37132 Mtetra
.617 .726 .923 r
.40991 .37132 .41632 .37858 .42713 .37656 .42077 .36855 Mtetra
.285 .538 .916 r
.42077 .36855 .42713 .37656 .4383 .36373 .43152 .37147 Mtetra
.598 .849 .49 r
.43152 .37147 .4383 .36373 .4491 .36552 .44279 .35755 Mtetra
.596 .697 .913 r
.44279 .35755 .4491 .36552 .46007 .36258 .45377 .35529 Mtetra
.634 .734 .92 r
.45377 .35529 .46007 .36258 .47111 .35926 .46483 .35205 Mtetra
.64 .74 .921 r
.46483 .35205 .47111 .35926 .48219 .35588 .47594 .34864 Mtetra
.638 .739 .921 r
.47594 .34864 .48219 .35588 .49332 .35268 .4871 .34527 Mtetra
.618 .727 .924 r
.4871 .34527 .49332 .35268 .50449 .35108 .4983 .34239 Mtetra
.829 .407 0 r
.4983 .34239 .50449 .35108 .51575 .33985 .50942 .36838 Mtetra
0 0 .003 r
.50942 .36838 .51575 .33985 .527 .33894 .52088 .3311 Mtetra
.616 .714 .915 r
.52088 .3311 .527 .33894 .53832 .33562 .53222 .32824 Mtetra
.644 .741 .92 r
.53222 .32824 .53832 .33562 .54968 .33195 .54361 .32467 Mtetra
.651 .747 .92 r
.54361 .32467 .54968 .33195 .56109 .32814 .55505 .32088 Mtetra
.654 .75 .92 r
.55505 .32088 .56109 .32814 .57255 .32424 .56654 .31698 Mtetra
.656 .752 .92 r
.56654 .31698 .57255 .32424 .58405 .32028 .57808 .31301 Mtetra
.658 .753 .92 r
.57808 .31301 .58405 .32028 .5956 .31627 .58966 .30898 Mtetra
.659 .754 .92 r
.58966 .30898 .5956 .31627 .6072 .31223 .60129 .30492 Mtetra
.60129 .30492 .6072 .31223 .61884 .30816 .61297 .30082 Mtetra
.61297 .30082 .61884 .30816 .63054 .30409 .62469 .29671 Mtetra
.62469 .29671 .63054 .30409 .64228 .3 .63647 .2926 Mtetra
.658 .754 .92 r
.63647 .2926 .64228 .3 .65407 .29591 .64829 .28847 Mtetra
.658 .753 .92 r
.64829 .28847 .65407 .29591 .66591 .29181 .66017 .28433 Mtetra
.66017 .28433 .66591 .29181 .6778 .28769 .67209 .28017 Mtetra
.67209 .28017 .6778 .28769 .68974 .28356 .68407 .27601 Mtetra
.68407 .27601 .68974 .28356 .70173 .27941 .69609 .27183 Mtetra
.69609 .27183 .70173 .27941 .71377 .27525 .70817 .26764 Mtetra
.657 .753 .92 r
.70817 .26764 .71377 .27525 .72586 .27108 .7203 .26343 Mtetra
.7203 .26343 .72586 .27108 .73801 .26689 .73248 .2592 Mtetra
.73248 .2592 .73801 .26689 .7502 .26268 .74471 .25496 Mtetra
.74471 .25496 .7502 .26268 .76245 .25846 .75699 .25071 Mtetra
.75699 .25071 .76245 .25846 .77475 .25421 .76933 .24643 Mtetra
.657 .752 .92 r
.76933 .24643 .77475 .25421 .7871 .24996 .78172 .24214 Mtetra
.699 .773 .285 r
.12061 .4917 .13201 .46279 .14137 .4631 .1344 .45571 Mtetra
.552 .681 .924 r
.1344 .45571 .14137 .4631 .15084 .4629 .14399 .45456 Mtetra
.949 .662 .461 r
.14399 .45456 .15084 .4629 .16144 .45299 .14247 .5519 Mtetra
0 0 0 r
.14247 .5519 .16144 .45299 .17098 .45291 .16407 .44553 Mtetra
.562 .687 .924 r
.16407 .44553 .17098 .45291 .18064 .45221 .17381 .44416 Mtetra
.742 .273 0 r
.17381 .44416 .18064 .45221 .19134 .4419 .18205 .45765 Mtetra
.731 .855 .424 r
.18205 .45765 .19134 .4419 .20096 .44237 .19411 .43489 Mtetra
.569 .688 .921 r
.19411 .43489 .20096 .44237 .21083 .44097 .204 .43339 Mtetra
.384 .603 .934 r
.204 .43339 .21083 .44097 .22207 .42535 .21367 .43469 Mtetra
0 0 0 r
.21367 .43469 .22207 .42535 .23132 .43146 .22455 .42355 Mtetra
.556 .671 .915 r
.22455 .42355 .23132 .43146 .24135 .42963 .23455 .42233 Mtetra
.56 .693 .929 r
.23455 .42233 .24135 .42963 .251 .43291 .24461 .42092 Mtetra
.781 .67 .741 r
.24461 .42092 .251 .43291 .26206 .41982 .25563 .40857 Mtetra
.401 .507 .851 r
.25563 .40857 .26206 .41982 .27221 .41824 .26546 .41094 Mtetra
.594 .708 .922 r
.26546 .41094 .27221 .41824 .28242 .41644 .27572 .40882 Mtetra
.442 .633 .936 r
.27572 .40882 .28242 .41644 .29389 .39776 .28582 .40938 Mtetra
0 0 0 r
.28582 .40938 .29389 .39776 .30343 .40649 .29681 .39836 Mtetra
.562 .671 .912 r
.29681 .39836 .30343 .40649 .31381 .40424 .30714 .39698 Mtetra
.604 .715 .923 r
.30714 .39698 .31381 .40424 .32421 .4024 .31759 .39461 Mtetra
.374 .594 .931 r
.31759 .39461 .32421 .4024 .3354 .38801 .32785 .39616 Mtetra
.524 .819 .482 r
.32785 .39616 .3354 .38801 .34553 .39208 .33898 .38407 Mtetra
.578 .684 .913 r
.33898 .38407 .34553 .39208 .3561 .38957 .34953 .38231 Mtetra
.616 .722 .922 r
.34953 .38231 .3561 .38957 .36672 .38708 .36018 .37961 Mtetra
.568 .698 .929 r
.36018 .37961 .36672 .38708 .37696 .39403 .37083 .37796 Mtetra
.741 .616 .72 r
.37083 .37796 .37696 .39403 .38835 .37655 .38197 .36644 Mtetra
.487 .586 .879 r
.38197 .36644 .38835 .37655 .39909 .37431 .39262 .3669 Mtetra
.62 .723 .92 r
.39262 .3669 .39909 .37431 .40991 .37132 .40346 .36406 Mtetra
.626 .73 .922 r
.40346 .36406 .40991 .37132 .42077 .36855 .41435 .36105 Mtetra
.585 .708 .927 r
.41435 .36105 .42077 .36855 .43152 .37147 .42526 .35897 Mtetra
.787 .677 .742 r
.42526 .35897 .43152 .37147 .44279 .35755 .43654 .34603 Mtetra
.443 .531 .852 r
.43654 .34603 .44279 .35755 .45377 .35529 .44743 .34777 Mtetra
.624 .725 .919 r
.44743 .34777 .45377 .35529 .46483 .35205 .45851 .34476 Mtetra
.639 .738 .92 r
.45851 .34476 .46483 .35205 .47594 .34864 .46965 .34137 Mtetra
.64 .74 .921 r
.46965 .34137 .47594 .34864 .4871 .34527 .48084 .33792 Mtetra
.633 .735 .922 r
.48084 .33792 .4871 .34527 .4983 .34239 .49207 .33465 Mtetra
.564 .696 .929 r
.49207 .33465 .4983 .34239 .50942 .36838 .50334 .33298 Mtetra
.648 .474 .634 r
.50334 .33298 .50942 .36838 .52088 .3311 .51471 .32164 Mtetra
.544 .638 .894 r
.51471 .32164 .52088 .3311 .53222 .32824 .52607 .32067 Mtetra
.635 .733 .919 r
.52607 .32067 .53222 .32824 .54361 .32467 .5375 .31728 Mtetra
.648 .744 .92 r
.5375 .31728 .54361 .32467 .55505 .32088 .54897 .31354 Mtetra
.653 .749 .92 r
.54897 .31354 .55505 .32088 .56654 .31698 .56049 .30965 Mtetra
.655 .751 .92 r
.56049 .30965 .56654 .31698 .57808 .31301 .57206 .30567 Mtetra
.657 .752 .92 r
.57206 .30567 .57808 .31301 .58966 .30898 .58367 .30163 Mtetra
.658 .753 .92 r
.58367 .30163 .58966 .30898 .60129 .30492 .59534 .29755 Mtetra
.659 .754 .92 r
.59534 .29755 .60129 .30492 .61297 .30082 .60705 .29342 Mtetra
.60705 .29342 .61297 .30082 .62469 .29671 .61881 .28928 Mtetra
.61881 .28928 .62469 .29671 .63647 .2926 .63062 .28513 Mtetra
.63062 .28513 .63647 .2926 .64829 .28847 .64247 .28096 Mtetra
.658 .753 .92 r
.64247 .28096 .64829 .28847 .66017 .28433 .65438 .27679 Mtetra
.65438 .27679 .66017 .28433 .67209 .28017 .66634 .2726 Mtetra
.66634 .2726 .67209 .28017 .68407 .27601 .67835 .2684 Mtetra
.67835 .2684 .68407 .27601 .69609 .27183 .69041 .26419 Mtetra
.69041 .26419 .69609 .27183 .70817 .26764 .70252 .25996 Mtetra
.70252 .25996 .70817 .26764 .7203 .26343 .71469 .25572 Mtetra
.657 .753 .92 r
.71469 .25572 .7203 .26343 .73248 .2592 .7269 .25146 Mtetra
.7269 .25146 .73248 .2592 .74471 .25496 .73917 .24719 Mtetra
.73917 .24719 .74471 .25496 .75699 .25071 .75149 .24289 Mtetra
.75149 .24289 .75699 .25071 .76933 .24643 .76387 .23858 Mtetra
.76387 .23858 .76933 .24643 .78172 .24214 .77629 .23426 Mtetra
.642 .469 .634 r
.11692 .45686 .12061 .4917 .1344 .45571 .12757 .44689 Mtetra
.483 .609 .901 r
.12757 .44689 .1344 .45571 .14399 .45456 .137 .44716 Mtetra
.493 .659 .935 r
.137 .44716 .14399 .45456 .14247 .5519 .14654 .44691 Mtetra
.569 .36 .557 r
.14654 .44691 .14247 .5519 .16407 .44553 .15724 .43692 Mtetra
.503 .626 .905 r
.15724 .43692 .16407 .44553 .17381 .44416 .16686 .43678 Mtetra
.524 .674 .932 r
.16686 .43678 .17381 .44416 .18205 .45765 .17659 .43603 Mtetra
.694 .549 .685 r
.17659 .43603 .18205 .45765 .19411 .43489 .18739 .42563 Mtetra
.478 .597 .893 r
.18739 .42563 .19411 .43489 .204 .43339 .19709 .42606 Mtetra
.563 .693 .928 r
.19709 .42606 .204 .43339 .21367 .43469 .20704 .4246 Mtetra
.826 .705 .731 r
.20704 .4246 .21367 .43469 .22455 .42355 .21839 .40887 Mtetra
.25 .348 .769 r
.21839 .40887 .22455 .42355 .23455 .42233 .2277 .41496 Mtetra
.584 .701 .923 r
.2277 .41496 .23455 .42233 .24461 .42092 .23782 .41306 Mtetra
.216 .504 .907 r
.23782 .41306 .24461 .42092 .25563 .40857 .24755 .41631 Mtetra
.681 .917 .591 r
.24755 .41631 .25563 .40857 .26546 .41094 .25871 .40312 Mtetra
.573 .685 .917 r
.25871 .40312 .26546 .41094 .27572 .40882 .26894 .40147 Mtetra
.58 .703 .927 r
.26894 .40147 .27572 .40882 .28582 .40938 .27924 .39962 Mtetra
.852 .719 .715 r
.27924 .39962 .28582 .40938 .29681 .39836 .29083 .3808 Mtetra
.196 .272 .716 r
.29083 .3808 .29681 .39836 .30714 .39698 .30044 .38952 Mtetra
.6 .709 .92 r
.30044 .38952 .30714 .39698 .31759 .39461 .31091 .38721 Mtetra
.58 .704 .927 r
.31091 .38721 .31759 .39461 .32785 .39616 .3214 .38531 Mtetra
.815 .701 .74 r
.3214 .38531 .32785 .39616 .33898 .38407 .3327 .3708 Mtetra
.349 .439 .812 r
.3327 .3708 .33898 .38407 .34953 .38231 .34291 .37483 Mtetra
.61 .715 .92 r
.34291 .37483 .34953 .38231 .36018 .37961 .35358 .37226 Mtetra
.608 .719 .924 r
.35358 .37226 .36018 .37961 .37083 .37796 .36429 .3697 Mtetra
0 .29 .787 r
.36429 .3697 .37083 .37796 .38197 .36644 .37461 .37663 Mtetra
.664 .852 .452 r
.37461 .37663 .38197 .36644 .39262 .3669 .38612 .35902 Mtetra
.597 .701 .916 r
.38612 .35902 .39262 .3669 .40346 .36406 .39696 .35671 Mtetra
.627 .729 .921 r
.39696 .35671 .40346 .36406 .41435 .36105 .40788 .35366 Mtetra
.617 .726 .923 r
.40788 .35366 .41435 .36105 .42526 .35897 .41884 .35082 Mtetra
.287 .539 .916 r
.41884 .35082 .42526 .35897 .43654 .34603 .42968 .3537 Mtetra
.609 .857 .501 r
.42968 .3537 .43654 .34603 .44743 .34777 .44106 .33967 Mtetra
.596 .697 .913 r
.44106 .33967 .44743 .34777 .45851 .34476 .45215 .33734 Mtetra
.634 .734 .92 r
.45215 .33734 .45851 .34476 .46965 .34137 .46331 .33403 Mtetra
.64 .74 .921 r
.46331 .33403 .46965 .34137 .48084 .33792 .47452 .33054 Mtetra
.638 .739 .921 r
.47452 .33054 .48084 .33792 .49207 .33465 .48579 .3271 Mtetra
.618 .727 .924 r
.48579 .3271 .49207 .33465 .50334 .33298 .4971 .32415 Mtetra
.823 .401 0 r
.4971 .32415 .50334 .33298 .51471 .32164 .50831 .35019 Mtetra
0 0 0 r
.50831 .35019 .51471 .32164 .52607 .32067 .51988 .31269 Mtetra
.616 .715 .916 r
.51988 .31269 .52607 .32067 .5375 .31728 .53134 .30977 Mtetra
.644 .741 .92 r
.53134 .30977 .5375 .31728 .54897 .31354 .54284 .30611 Mtetra
.651 .747 .92 r
.54284 .30611 .54897 .31354 .56049 .30965 .55439 .30225 Mtetra
.654 .75 .92 r
.55439 .30225 .56049 .30965 .57206 .30567 .56599 .29827 Mtetra
.656 .752 .92 r
.56599 .29827 .57206 .30567 .58367 .30163 .57764 .29422 Mtetra
.658 .753 .92 r
.57764 .29422 .58367 .30163 .59534 .29755 .58933 .29011 Mtetra
.659 .754 .92 r
.58933 .29011 .59534 .29755 .60705 .29342 .60108 .28597 Mtetra
.60108 .28597 .60705 .29342 .61881 .28928 .61287 .2818 Mtetra
.61287 .2818 .61881 .28928 .63062 .28513 .62472 .27761 Mtetra
.62472 .27761 .63062 .28513 .64247 .28096 .63661 .27341 Mtetra
.658 .754 .92 r
.63661 .27341 .64247 .28096 .65438 .27679 .64855 .26919 Mtetra
.658 .753 .92 r
.64855 .26919 .65438 .27679 .66634 .2726 .66054 .26497 Mtetra
.66054 .26497 .66634 .2726 .67835 .2684 .67259 .26074 Mtetra
.67259 .26074 .67835 .2684 .69041 .26419 .68469 .25649 Mtetra
.68469 .25649 .69041 .26419 .70252 .25996 .69683 .25223 Mtetra
.69683 .25223 .70252 .25996 .71469 .25572 .70903 .24795 Mtetra
.657 .753 .92 r
.70903 .24795 .71469 .25572 .7269 .25146 .72129 .24366 Mtetra
.72129 .24366 .7269 .25146 .73917 .24719 .73359 .23935 Mtetra
.73359 .23935 .73917 .24719 .75149 .24289 .74595 .23502 Mtetra
.74595 .23502 .75149 .24289 .76387 .23858 .75836 .23068 Mtetra
.75836 .23068 .76387 .23858 .77629 .23426 .77083 .22632 Mtetra
.936 .564 .25 r
.10994 .44861 .11692 .45686 .12757 .44689 .116 .47584 Mtetra
.708 .78 .294 r
.116 .47584 .12757 .44689 .137 .44716 .12996 .43966 Mtetra
.552 .681 .924 r
.12996 .43966 .137 .44716 .14654 .44691 .13962 .43845 Mtetra
.95 .662 .458 r
.13962 .43845 .14654 .44691 .15724 .43692 .13794 .53618 Mtetra
0 0 0 r
.13794 .53618 .15724 .43692 .16686 .43678 .15986 .42929 Mtetra
.562 .687 .924 r
.15986 .42929 .16686 .43678 .17659 .43603 .16969 .42786 Mtetra
.736 .268 0 r
.16969 .42786 .17659 .43603 .18739 .42563 .17797 .44136 Mtetra
.739 .861 .433 r
.17797 .44136 .18739 .42563 .19709 .42606 .19016 .41846 Mtetra
.569 .688 .921 r
.19016 .41846 .19709 .42606 .20704 .4246 .20013 .4169 Mtetra
.385 .603 .934 r
.20013 .4169 .20704 .4246 .21839 .40887 .20987 .41815 Mtetra
0 0 0 r
.20987 .41815 .21839 .40887 .2277 .41496 .22086 .40691 Mtetra
.556 .671 .915 r
.22086 .40691 .2277 .41496 .23782 .41306 .23094 .40564 Mtetra
.56 .693 .929 r
.23094 .40564 .23782 .41306 .24755 .41631 .24109 .40417 Mtetra
.781 .671 .742 r
.24109 .40417 .24755 .41631 .25871 .40312 .25222 .39172 Mtetra
.4 .506 .851 r
.25222 .39172 .25871 .40312 .26894 .40147 .26213 .39405 Mtetra
.594 .708 .923 r
.26213 .39405 .26894 .40147 .27924 .39962 .27247 .39187 Mtetra
.442 .633 .936 r
.27247 .39187 .27924 .39962 .29083 .3808 .28265 .39238 Mtetra
0 0 0 r
.28265 .39238 .29083 .3808 .30044 .38952 .29375 .38126 Mtetra
.562 .671 .912 r
.29375 .38126 .30044 .38952 .31091 .38721 .30417 .37982 Mtetra
.604 .715 .923 r
.30417 .37982 .31091 .38721 .3214 .38531 .31471 .37738 Mtetra
.375 .594 .931 r
.31471 .37738 .3214 .38531 .3327 .3708 .32506 .37889 Mtetra
.537 .829 .495 r
.32506 .37889 .3327 .3708 .34291 .37483 .33629 .3667 Mtetra
.578 .684 .913 r
.33629 .3667 .34291 .37483 .35358 .37226 .34693 .36487 Mtetra
.616 .722 .922 r
.34693 .36487 .35358 .37226 .36429 .3697 .35768 .3621 Mtetra
.568 .698 .929 r
.35768 .3621 .36429 .3697 .37461 .37663 .36842 .36039 Mtetra
.741 .617 .72 r
.36842 .36039 .37461 .37663 .38612 .35902 .37968 .34877 Mtetra
.487 .586 .879 r
.37968 .34877 .38612 .35902 .39696 .35671 .39041 .34918 Mtetra
.62 .723 .92 r
.39041 .34918 .39696 .35671 .40788 .35366 .40135 .34627 Mtetra
.626 .73 .922 r
.40135 .34627 .40788 .35366 .41884 .35082 .41235 .34319 Mtetra
.585 .708 .927 r
.41235 .34319 .41884 .35082 .42968 .3537 .42336 .34104 Mtetra
.788 .677 .742 r
.42336 .34104 .42968 .3537 .44106 .33967 .43475 .32799 Mtetra
.442 .531 .853 r
.43475 .32799 .44106 .33967 .45215 .33734 .44574 .32968 Mtetra
.624 .725 .919 r
.44574 .32968 .45215 .33734 .46331 .33403 .45692 .3266 Mtetra
.639 .738 .92 r
.45692 .3266 .46331 .33403 .47452 .33054 .46816 .32313 Mtetra
.64 .74 .921 r
.46816 .32313 .47452 .33054 .48579 .3271 .47946 .3196 Mtetra
.633 .735 .922 r
.47946 .3196 .48579 .3271 .4971 .32415 .4908 .31626 Mtetra
.564 .696 .929 r
.4908 .31626 .4971 .32415 .50831 .35019 .50218 .31453 Mtetra
.647 .472 .633 r
.50218 .31453 .50831 .35019 .51988 .31269 .51365 .30309 Mtetra
.544 .638 .894 r
.51365 .30309 .51988 .31269 .53134 .30977 .52513 .30205 Mtetra
.635 .733 .919 r
.52513 .30205 .53134 .30977 .54284 .30611 .53666 .29858 Mtetra
.648 .744 .92 r
.53666 .29858 .54284 .30611 .55439 .30225 .54824 .29476 Mtetra
.653 .749 .92 r
.54824 .29476 .55439 .30225 .56599 .29827 .55988 .2908 Mtetra
.655 .751 .92 r
.55988 .2908 .56599 .29827 .57764 .29422 .57156 .28674 Mtetra
.657 .752 .92 r
.57156 .28674 .57764 .29422 .58933 .29011 .58329 .28262 Mtetra
.658 .753 .92 r
.58329 .28262 .58933 .29011 .60108 .28597 .59506 .27845 Mtetra
.659 .754 .92 r
.59506 .27845 .60108 .28597 .61287 .2818 .60689 .27425 Mtetra
.60689 .27425 .61287 .2818 .62472 .27761 .61877 .27003 Mtetra
.61877 .27003 .62472 .27761 .63661 .27341 .6307 .26579 Mtetra
.6307 .26579 .63661 .27341 .64855 .26919 .64267 .26154 Mtetra
.658 .753 .92 r
.64267 .26154 .64855 .26919 .66054 .26497 .6547 .25728 Mtetra
.6547 .25728 .66054 .26497 .67259 .26074 .66678 .25301 Mtetra
.66678 .25301 .67259 .26074 .68469 .25649 .67891 .24873 Mtetra
.67891 .24873 .68469 .25649 .69683 .25223 .6911 .24443 Mtetra
.6911 .24443 .69683 .25223 .70903 .24795 .70333 .24012 Mtetra
.70333 .24012 .70903 .24795 .72129 .24366 .71562 .23579 Mtetra
.657 .753 .92 r
.71562 .23579 .72129 .24366 .73359 .23935 .72797 .23145 Mtetra
.72797 .23145 .73359 .23935 .74595 .23502 .74036 .22708 Mtetra
.74036 .22708 .74595 .23502 .75836 .23068 .75281 .2227 Mtetra
.75281 .2227 .75836 .23068 .77083 .22632 .76531 .21831 Mtetra
.498 .661 .934 r
.10282 .44113 .10994 .44861 .116 .47584 .1123 .44077 Mtetra
.641 .468 .633 r
.1123 .44077 .116 .47584 .12996 .43966 .12304 .43071 Mtetra
.482 .609 .901 r
.12304 .43071 .12996 .43966 .13962 .43845 .13254 .43093 Mtetra
.493 .659 .935 r
.13254 .43093 .13962 .43845 .13794 .53618 .14216 .43064 Mtetra
.567 .356 .555 r
.14216 .43064 .13794 .53618 .15986 .42929 .15296 .42055 Mtetra
.503 .626 .905 r
.15296 .42055 .15986 .42929 .16969 .42786 .16265 .42036 Mtetra
.524 .674 .932 r
.16265 .42036 .16969 .42786 .17797 .44136 .17247 .41956 Mtetra
.694 .549 .685 r
.17247 .41956 .17797 .44136 .19016 .41846 .18337 .40907 Mtetra
.478 .597 .893 r
.18337 .40907 .19016 .41846 .20013 .4169 .19314 .40945 Mtetra
.563 .693 .928 r
.19314 .40945 .20013 .4169 .20987 .41815 .20317 .40793 Mtetra
.827 .706 .732 r
.20317 .40793 .20987 .41815 .22086 .40691 .21464 .39208 Mtetra
.247 .346 .769 r
.21464 .39208 .22086 .40691 .23094 .40564 .22402 .39814 Mtetra
.584 .701 .923 r
.22402 .39814 .23094 .40564 .24109 .40417 .23422 .39619 Mtetra
.219 .505 .907 r
.23422 .39619 .24109 .40417 .25222 .39172 .24403 .3994 Mtetra
.69 .923 .6 r
.24403 .3994 .25222 .39172 .26213 .39405 .2553 .38609 Mtetra
.573 .685 .917 r
.2553 .38609 .26213 .39405 .27247 .39187 .26562 .38439 Mtetra
.58 .703 .927 r
.26562 .38439 .27247 .39187 .28265 .39238 .27601 .38248 Mtetra
.853 .72 .715 r
.27601 .38248 .28265 .39238 .29375 .38126 .28771 .36353 Mtetra
.193 .27 .715 r
.28771 .36353 .29375 .38126 .30417 .37982 .2974 .37223 Mtetra
.6 .709 .92 r
.2974 .37223 .30417 .37982 .31471 .37738 .30795 .36985 Mtetra
.58 .704 .927 r
.30795 .36985 .31471 .37738 .32506 .37889 .31853 .36789 Mtetra
.815 .702 .74 r
.31853 .36789 .32506 .37889 .33629 .3667 .32995 .35327 Mtetra
.348 .438 .812 r
.32995 .35327 .33629 .3667 .34693 .36487 .34025 .35726 Mtetra
.609 .715 .92 r
.34025 .35726 .34693 .36487 .35768 .3621 .35101 .35462 Mtetra
.608 .719 .924 r
.35101 .35462 .35768 .3621 .36842 .36039 .36182 .352 Mtetra
0 .294 .789 r
.36182 .352 .36842 .36039 .37968 .34877 .37222 .35889 Mtetra
.673 .859 .461 r
.37222 .35889 .37968 .34877 .39041 .34918 .38384 .34116 Mtetra
.597 .701 .916 r
.38384 .34116 .39041 .34918 .40135 .34627 .39478 .33878 Mtetra
.627 .729 .921 r
.39478 .33878 .40135 .34627 .41235 .34319 .4058 .33566 Mtetra
.617 .726 .923 r
.4058 .33566 .41235 .34319 .42336 .34104 .41687 .33275 Mtetra
.289 .539 .916 r
.41687 .33275 .42336 .34104 .43475 .32799 .4278 .33558 Mtetra
.619 .865 .512 r
.4278 .33558 .43475 .32799 .44574 .32968 .4393 .32143 Mtetra
.596 .697 .913 r
.4393 .32143 .44574 .32968 .45692 .3266 .45049 .31904 Mtetra
.634 .734 .92 r
.45049 .31904 .45692 .3266 .46816 .32313 .46176 .31565 Mtetra
.64 .74 .921 r
.46176 .31565 .46816 .32313 .47946 .3196 .47308 .31209 Mtetra
.638 .739 .921 r
.47308 .31209 .47946 .3196 .4908 .31626 .48445 .30858 Mtetra
.618 .727 .924 r
.48445 .30858 .4908 .31626 .50218 .31453 .49586 .30555 Mtetra
.817 .395 0 r
.49586 .30555 .50218 .31453 .51365 .30309 .50717 .33163 Mtetra
0 0 0 r
.50717 .33163 .51365 .30309 .52513 .30205 .51887 .29392 Mtetra
.616 .715 .916 r
.51887 .29392 .52513 .30205 .53666 .29858 .53043 .29092 Mtetra
.644 .741 .92 r
.53043 .29092 .53666 .29858 .54824 .29476 .54205 .28719 Mtetra
.651 .747 .92 r
.54205 .28719 .54824 .29476 .55988 .2908 .55371 .28324 Mtetra
.654 .75 .92 r
.55371 .28324 .55988 .2908 .57156 .28674 .56543 .27919 Mtetra
.656 .752 .92 r
.56543 .27919 .57156 .28674 .58329 .28262 .57719 .27506 Mtetra
.658 .753 .92 r
.57719 .27506 .58329 .28262 .59506 .27845 .589 .27087 Mtetra
.659 .754 .92 r
.589 .27087 .59506 .27845 .60689 .27425 .60086 .26664 Mtetra
.60086 .26664 .60689 .27425 .61877 .27003 .61278 .26239 Mtetra
.61278 .26239 .61877 .27003 .6307 .26579 .62474 .25811 Mtetra
.62474 .25811 .6307 .26579 .64267 .26154 .63675 .25383 Mtetra
.658 .754 .92 r
.63675 .25383 .64267 .26154 .6547 .25728 .64881 .24953 Mtetra
.658 .753 .92 r
.64881 .24953 .6547 .25728 .66678 .25301 .66093 .24523 Mtetra
.66093 .24523 .66678 .25301 .67891 .24873 .6731 .24091 Mtetra
.6731 .24091 .67891 .24873 .6911 .24443 .68532 .23658 Mtetra
.68532 .23658 .6911 .24443 .70333 .24012 .69759 .23223 Mtetra
.69759 .23223 .70333 .24012 .71562 .23579 .70992 .22786 Mtetra
.657 .753 .92 r
.70992 .22786 .71562 .23579 .72797 .23145 .72229 .22348 Mtetra
.72229 .22348 .72797 .23145 .74036 .22708 .73473 .21908 Mtetra
.73473 .21908 .74036 .22708 .75281 .2227 .74722 .21467 Mtetra
.74722 .21467 .75281 .2227 .76531 .21831 .75976 .21024 Mtetra
.538 .67 .922 r
.09567 .43338 .10282 .44113 .1123 .44077 .10525 .4324 Mtetra
.936 .562 .245 r
.10525 .4324 .1123 .44077 .12304 .43071 .11131 .4597 Mtetra
.716 .787 .303 r
.11131 .4597 .12304 .43071 .13254 .43093 .12543 .42331 Mtetra
.552 .681 .924 r
.12543 .42331 .13254 .43093 .14216 .43064 .13517 .42204 Mtetra
.95 .662 .455 r
.13517 .42204 .14216 .43064 .15296 .42055 .13332 .52016 Mtetra
0 0 0 r
.13332 .52016 .15296 .42055 .16265 .42036 .15558 .41275 Mtetra
.562 .687 .924 r
.15558 .41275 .16265 .42036 .17247 .41956 .16549 .41126 Mtetra
.73 .262 0 r
.16549 .41126 .17247 .41956 .18337 .40907 .17382 .42477 Mtetra
.746 .867 .442 r
.17382 .42477 .18337 .40907 .19314 .40945 .18614 .40172 Mtetra
.569 .688 .921 r
.18614 .40172 .19314 .40945 .20317 .40793 .19619 .4001 Mtetra
.386 .603 .934 r
.19619 .4001 .20317 .40793 .21464 .39208 .20601 .4013 Mtetra
0 0 0 r
.20601 .4013 .21464 .39208 .22402 .39814 .21711 .38997 Mtetra
.555 .671 .915 r
.21711 .38997 .22402 .39814 .23422 .39619 .22727 .38864 Mtetra
.56 .693 .929 r
.22727 .38864 .23422 .39619 .24403 .3994 .2375 .38711 Mtetra
.782 .671 .742 r
.2375 .38711 .24403 .3994 .2553 .38609 .24874 .37456 Mtetra
.399 .506 .851 r
.24874 .37456 .2553 .38609 .26562 .38439 .25872 .37683 Mtetra
.594 .708 .923 r
.25872 .37683 .26562 .38439 .27601 .38248 .26915 .37459 Mtetra
.443 .633 .935 r
.26915 .37459 .27601 .38248 .28771 .36353 .27943 .37505 Mtetra
0 0 0 r
.27943 .37505 .28771 .36353 .2974 .37223 .29063 .36384 Mtetra
.562 .671 .912 r
.29063 .36384 .2974 .37223 .30795 .36985 .30114 .36233 Mtetra
.604 .715 .923 r
.30114 .36233 .30795 .36985 .31853 .36789 .31178 .35983 Mtetra
.376 .595 .931 r
.31178 .35983 .31853 .36789 .32995 .35327 .32221 .36129 Mtetra
.55 .839 .508 r
.32221 .36129 .32995 .35327 .34025 .35726 .33355 .34899 Mtetra
.578 .684 .913 r
.33355 .34899 .34025 .35726 .35101 .35462 .34429 .34709 Mtetra
.616 .722 .922 r
.34429 .34709 .35101 .35462 .36182 .352 .35513 .34426 Mtetra
.568 .698 .929 r
.35513 .34426 .36182 .352 .37222 .35889 .36597 .34248 Mtetra
.741 .617 .72 r
.36597 .34248 .37222 .35889 .38384 .34116 .37734 .33075 Mtetra
.486 .586 .879 r
.37734 .33075 .38384 .34116 .39478 .33878 .38817 .33111 Mtetra
.62 .723 .92 r
.38817 .33111 .39478 .33878 .4058 .33566 .39921 .32813 Mtetra
.626 .73 .922 r
.39921 .32813 .4058 .33566 .41687 .33275 .4103 .32497 Mtetra
.586 .708 .927 r
.4103 .32497 .41687 .33275 .4278 .33558 .42142 .32276 Mtetra
.789 .678 .742 r
.42142 .32276 .4278 .33558 .4393 .32143 .43292 .30959 Mtetra
.441 .53 .853 r
.43292 .30959 .4393 .32143 .45049 .31904 .44401 .31124 Mtetra
.624 .725 .919 r
.44401 .31124 .45049 .31904 .46176 .31565 .4553 .30808 Mtetra
.639 .738 .92 r
.4553 .30808 .46176 .31565 .47308 .31209 .46665 .30454 Mtetra
.64 .74 .921 r
.46665 .30454 .47308 .31209 .48445 .30858 .47805 .30093 Mtetra
.633 .735 .922 r
.47805 .30093 .48445 .30858 .49586 .30555 .4895 .29751 Mtetra
.564 .696 .929 r
.4895 .29751 .49586 .30555 .50717 .33163 .50099 .29571 Mtetra
.646 .471 .632 r
.50099 .29571 .50717 .33163 .51887 .29392 .51258 .28416 Mtetra
.544 .638 .894 r
.51258 .28416 .51887 .29392 .53043 .29092 .52416 .28306 Mtetra
.635 .733 .919 r
.52416 .28306 .53043 .29092 .54205 .28719 .53581 .27951 Mtetra
.648 .744 .92 r
.53581 .27951 .54205 .28719 .55371 .28324 .5475 .27561 Mtetra
.653 .749 .92 r
.5475 .27561 .55371 .28324 .56543 .27919 .55925 .27156 Mtetra
.655 .751 .92 r
.55925 .27156 .56543 .27919 .57719 .27506 .57105 .26743 Mtetra
.657 .752 .92 r
.57105 .26743 .57719 .27506 .589 .27087 .58289 .26322 Mtetra
.658 .753 .92 r
.58289 .26322 .589 .27087 .60086 .26664 .59479 .25897 Mtetra
.659 .754 .92 r
.59479 .25897 .60086 .26664 .61278 .26239 .60673 .25469 Mtetra
.60673 .25469 .61278 .26239 .62474 .25811 .61873 .25038 Mtetra
.61873 .25038 .62474 .25811 .63675 .25383 .63078 .24606 Mtetra
.63078 .24606 .63675 .25383 .64881 .24953 .64288 .24173 Mtetra
.658 .753 .92 r
.64288 .24173 .64881 .24953 .66093 .24523 .65503 .23738 Mtetra
.65503 .23738 .66093 .24523 .6731 .24091 .66723 .23303 Mtetra
.66723 .23303 .6731 .24091 .68532 .23658 .67949 .22866 Mtetra
.67949 .22866 .68532 .23658 .69759 .23223 .6918 .22427 Mtetra
.6918 .22427 .69759 .23223 .70992 .22786 .70416 .21987 Mtetra
.70416 .21987 .70992 .22786 .72229 .22348 .71658 .21545 Mtetra
.657 .753 .92 r
.71658 .21545 .72229 .22348 .73473 .21908 .72905 .21102 Mtetra
.72905 .21102 .73473 .21908 .74722 .21467 .74157 .20657 Mtetra
.74157 .20657 .74722 .21467 .75976 .21024 .75416 .2021 Mtetra
.386 .517 .867 r
.08886 .42275 .09567 .43338 .10525 .4324 .09804 .42479 Mtetra
.498 .661 .934 r
.09804 .42479 .10525 .4324 .11131 .4597 .1076 .42439 Mtetra
.64 .467 .632 r
.1076 .42439 .11131 .4597 .12543 .42331 .11844 .41423 Mtetra
.482 .609 .901 r
.11844 .41423 .12543 .42331 .13517 .42204 .12801 .4144 Mtetra
.494 .659 .934 r
.12801 .4144 .13517 .42204 .13332 .52016 .13771 .41406 Mtetra
.564 .353 .553 r
.13771 .41406 .13332 .52016 .15558 .41275 .14861 .40388 Mtetra
.503 .626 .905 r
.14861 .40388 .15558 .41275 .16549 .41126 .15837 .40364 Mtetra
.524 .674 .932 r
.15837 .40364 .16549 .41126 .17382 .42477 .16827 .40278 Mtetra
.694 .548 .685 r
.16827 .40278 .17382 .42477 .18614 .40172 .17927 .39219 Mtetra
.477 .597 .893 r
.17927 .39219 .18614 .40172 .19619 .4001 .18912 .39252 Mtetra
.563 .693 .928 r
.18912 .39252 .19619 .4001 .20601 .4013 .19924 .39095 Mtetra
.827 .707 .732 r
.19924 .39095 .20601 .4013 .21711 .38997 .21081 .37498 Mtetra
.245 .345 .768 r
.21081 .37498 .21711 .38997 .22727 .38864 .22026 .38101 Mtetra
.584 .701 .923 r
.22026 .38101 .22727 .38864 .2375 .38711 .23056 .37899 Mtetra
.221 .506 .907 r
.23056 .37899 .2375 .38711 .24874 .37456 .24044 .38216 Mtetra
.699 .928 .609 r
.24044 .38216 .24874 .37456 .25872 .37683 .25182 .36875 Mtetra
.573 .685 .917 r
.25182 .36875 .25872 .37683 .26915 .37459 .26223 .36699 Mtetra
.58 .703 .927 r
.26223 .36699 .26915 .37459 .27943 .37505 .27271 .36501 Mtetra
.854 .721 .715 r
.27271 .36501 .27943 .37505 .29063 .36384 .28453 .34593 Mtetra
.19 .268 .714 r
.28453 .34593 .29063 .36384 .30114 .36233 .29429 .35461 Mtetra
.6 .709 .92 r
.29429 .35461 .30114 .36233 .31178 .35983 .30494 .35216 Mtetra
.58 .704 .927 r
.30494 .35216 .31178 .35983 .32221 .36129 .31562 .35014 Mtetra
.816 .703 .74 r
.31562 .35014 .32221 .36129 .33355 .34899 .32714 .3354 Mtetra
.346 .437 .812 r
.32714 .3354 .33355 .34899 .34429 .34709 .33753 .33935 Mtetra
.609 .715 .92 r
.33753 .33935 .34429 .34709 .35513 .34426 .34839 .33665 Mtetra
.608 .719 .924 r
.34839 .33665 .35513 .34426 .36597 .34248 .3593 .33395 Mtetra
0 .297 .792 r
.3593 .33395 .36597 .34248 .37734 .33075 .36979 .34081 Mtetra
.682 .866 .47 r
.36979 .34081 .37734 .33075 .38817 .33111 .38153 .32295 Mtetra
.597 .701 .916 r
.38153 .32295 .38817 .33111 .39921 .32813 .39257 .3205 Mtetra
.627 .729 .921 r
.39257 .3205 .39921 .32813 .4103 .32497 .40369 .31731 Mtetra
.617 .726 .923 r
.40369 .31731 .4103 .32497 .42142 .32276 .41486 .31432 Mtetra
.291 .54 .916 r
.41486 .31432 .42142 .32276 .43292 .30959 .42589 .31711 Mtetra
.629 .873 .522 r
.42589 .31711 .43292 .30959 .44401 .31124 .4375 .30284 Mtetra
.596 .697 .914 r
.4375 .30284 .44401 .31124 .4553 .30808 .4488 .30037 Mtetra
.634 .734 .92 r
.4488 .30037 .4553 .30808 .46665 .30454 .46017 .29691 Mtetra
.64 .74 .921 r
.46017 .29691 .46665 .30454 .47805 .30093 .4716 .29328 Mtetra
.638 .739 .921 r
.4716 .29328 .47805 .30093 .4895 .29751 .48308 .28968 Mtetra
.618 .727 .924 r
.48308 .28968 .4895 .29751 .50099 .29571 .49461 .28658 Mtetra
.812 .389 0 r
.49461 .28658 .50099 .29571 .51258 .28416 .50601 .31269 Mtetra
0 0 0 r
.50601 .31269 .51258 .28416 .52416 .28306 .51784 .27477 Mtetra
.616 .715 .916 r
.51784 .27477 .52416 .28306 .53581 .27951 .52952 .2717 Mtetra
.643 .741 .92 r
.52952 .2717 .53581 .27951 .5475 .27561 .54124 .26789 Mtetra
.651 .747 .92 r
.54124 .26789 .5475 .27561 .55925 .27156 .55302 .26386 Mtetra
.654 .75 .92 r
.55302 .26386 .55925 .27156 .57105 .26743 .56485 .25972 Mtetra
.656 .752 .92 r
.56485 .25972 .57105 .26743 .58289 .26322 .57673 .25551 Mtetra
.658 .753 .92 r
.57673 .25551 .58289 .26322 .59479 .25897 .58866 .25124 Mtetra
.659 .754 .92 r
.58866 .25124 .59479 .25897 .60673 .25469 .60064 .24692 Mtetra
.60064 .24692 .60673 .25469 .61873 .25038 .61268 .24258 Mtetra
.61268 .24258 .61873 .25038 .63078 .24606 .62476 .23823 Mtetra
.62476 .23823 .63078 .24606 .64288 .24173 .63689 .23386 Mtetra
.658 .754 .92 r
.63689 .23386 .64288 .24173 .65503 .23738 .64908 .22947 Mtetra
.658 .753 .92 r
.64908 .22947 .65503 .23738 .66723 .23303 .66132 .22508 Mtetra
.66132 .22508 .66723 .23303 .67949 .22866 .67361 .22067 Mtetra
.67361 .22067 .67949 .22866 .6918 .22427 .68596 .21625 Mtetra
.68596 .21625 .6918 .22427 .70416 .21987 .69836 .21181 Mtetra
.69836 .21181 .70416 .21987 .71658 .21545 .71082 .20736 Mtetra
.657 .753 .92 r
.71082 .20736 .71658 .21545 .72905 .21102 .72332 .20289 Mtetra
.72332 .20289 .72905 .21102 .74157 .20657 .73589 .1984 Mtetra
.73589 .1984 .74157 .20657 .75416 .2021 .74851 .19389 Mtetra
.785 .969 .67 r
.07944 .43092 .08886 .42275 .09804 .42479 .09081 .41692 Mtetra
.538 .67 .922 r
.09081 .41692 .09804 .42479 .1076 .42439 .10046 .41588 Mtetra
.935 .56 .239 r
.10046 .41588 .1076 .42439 .11844 .41423 .10652 .44325 Mtetra
.725 .793 .312 r
.10652 .44325 .11844 .41423 .12801 .4144 .12081 .40665 Mtetra
.552 .681 .924 r
.12081 .40665 .12801 .4144 .13771 .41406 .13063 .40533 Mtetra
.951 .661 .452 r
.13063 .40533 .13771 .41406 .14861 .40388 .12862 .50383 Mtetra
0 0 0 r
.12862 .50383 .14861 .40388 .15837 .40364 .15122 .39589 Mtetra
.562 .687 .924 r
.15122 .39589 .15837 .40364 .16827 .40278 .16121 .39435 Mtetra
.725 .256 0 r
.16121 .39435 .16827 .40278 .17927 .39219 .16959 .40786 Mtetra
.754 .873 .45 r
.16959 .40786 .17927 .39219 .18912 .39252 .18204 .38466 Mtetra
.569 .688 .921 r
.18204 .38466 .18912 .39252 .19924 .39095 .19217 .38298 Mtetra
.387 .603 .934 r
.19217 .38298 .19924 .39095 .21081 .37498 .20208 .38414 Mtetra
0 0 0 r
.20208 .38414 .21081 .37498 .22026 .38101 .21328 .37271 Mtetra
.555 .671 .915 r
.21328 .37271 .22026 .38101 .23056 .37899 .22352 .37131 Mtetra
.56 .693 .929 r
.22352 .37131 .23056 .37899 .24044 .38216 .23384 .36972 Mtetra
.782 .672 .742 r
.23384 .36972 .24044 .38216 .25182 .36875 .24519 .35706 Mtetra
.398 .506 .852 r
.24519 .35706 .25182 .36875 .26223 .36699 .25526 .3593 Mtetra
.594 .708 .923 r
.25526 .3593 .26223 .36699 .27271 .36501 .26578 .35699 Mtetra
.444 .633 .935 r
.26578 .35699 .27271 .36501 .28453 .34593 .27614 .35739 Mtetra
0 0 0 r
.27614 .35739 .28453 .34593 .29429 .35461 .28745 .34608 Mtetra
.562 .672 .912 r
.28745 .34608 .29429 .35461 .30494 .35216 .29805 .34451 Mtetra
.604 .715 .923 r
.29805 .34451 .30494 .35216 .31562 .35014 .30878 .34194 Mtetra
.377 .595 .931 r
.30878 .34194 .31562 .35014 .32714 .3354 .31931 .34334 Mtetra
.562 .849 .52 r
.31931 .34334 .32714 .3354 .33753 .33935 .33076 .33094 Mtetra
.578 .684 .913 r
.33076 .33094 .33753 .33935 .34839 .33665 .34159 .32898 Mtetra
.616 .722 .922 r
.34159 .32898 .34839 .33665 .3593 .33395 .35254 .32607 Mtetra
.568 .698 .929 r
.35254 .32607 .3593 .33395 .36979 .34081 .36347 .32423 Mtetra
.742 .617 .721 r
.36347 .32423 .36979 .34081 .38153 .32295 .37495 .31239 Mtetra
.486 .585 .879 r
.37495 .31239 .38153 .32295 .39257 .3205 .38588 .31269 Mtetra
.62 .723 .92 r
.38588 .31269 .39257 .3205 .40369 .31731 .39702 .30963 Mtetra
.626 .73 .922 r
.39702 .30963 .40369 .31731 .41486 .31432 .40822 .30641 Mtetra
.586 .708 .927 r
.40822 .30641 .41486 .31432 .42589 .31711 .41944 .30412 Mtetra
.789 .679 .742 r
.41944 .30412 .42589 .31711 .4375 .30284 .43105 .29084 Mtetra
.441 .53 .853 r
.43105 .29084 .4375 .30284 .4488 .30037 .44225 .29243 Mtetra
.624 .725 .919 r
.44225 .29243 .4488 .30037 .46017 .29691 .45365 .28919 Mtetra
.639 .738 .92 r
.45365 .28919 .46017 .29691 .4716 .29328 .4651 .28557 Mtetra
.64 .74 .921 r
.4651 .28557 .4716 .29328 .48308 .28968 .47661 .28189 Mtetra
.633 .735 .922 r
.47661 .28189 .48308 .28968 .49461 .28658 .48817 .27839 Mtetra
.564 .696 .929 r
.48817 .27839 .49461 .28658 .50601 .31269 .49977 .27652 Mtetra
.646 .47 .631 r
.49977 .27652 .50601 .31269 .51784 .27477 .51148 .26486 Mtetra
.544 .638 .894 r
.51148 .26486 .51784 .27477 .52952 .2717 .52318 .26368 Mtetra
.635 .733 .919 r
.52318 .26368 .52952 .2717 .54124 .26789 .53494 .26006 Mtetra
.648 .744 .92 r
.53494 .26006 .54124 .26789 .55302 .26386 .54675 .25607 Mtetra
.653 .749 .92 r
.54675 .25607 .55302 .26386 .56485 .25972 .55861 .25194 Mtetra
.655 .751 .92 r
.55861 .25194 .56485 .25972 .57673 .25551 .57053 .24772 Mtetra
.657 .752 .92 r
.57053 .24772 .57673 .25551 .58866 .25124 .58249 .24344 Mtetra
.658 .753 .92 r
.58249 .24344 .58866 .25124 .60064 .24692 .59451 .2391 Mtetra
.659 .754 .92 r
.59451 .2391 .60064 .24692 .61268 .24258 .60657 .23473 Mtetra
.60657 .23473 .61268 .24258 .62476 .23823 .61869 .23033 Mtetra
.61869 .23033 .62476 .23823 .63689 .23386 .63086 .22592 Mtetra
.63086 .22592 .63689 .23386 .64908 .22947 .64308 .2215 Mtetra
.658 .753 .92 r
.64308 .2215 .64908 .22947 .66132 .22508 .65536 .21707 Mtetra
.65536 .21707 .66132 .22508 .67361 .22067 .66769 .21263 Mtetra
.66769 .21263 .67361 .22067 .68596 .21625 .68007 .20817 Mtetra
.68007 .20817 .68596 .21625 .69836 .21181 .69251 .20369 Mtetra
.69251 .20369 .69836 .21181 .71082 .20736 .70501 .1992 Mtetra
.70501 .1992 .71082 .20736 .72332 .20289 .71755 .19469 Mtetra
.657 .753 .92 r
.71755 .19469 .72332 .20289 .73589 .1984 .73016 .19017 Mtetra
.73016 .19017 .73589 .1984 .74851 .19389 .74281 .18562 Mtetra
.759 .646 .736 r
.07288 .41758 .07944 .43092 .09081 .41692 .08393 .40615 Mtetra
.385 .516 .867 r
.08393 .40615 .09081 .41692 .10046 .41588 .09317 .40815 Mtetra
.499 .661 .934 r
.09317 .40815 .10046 .41588 .10652 .44325 .1028 .40769 Mtetra
.639 .465 .631 r
.1028 .40769 .10652 .44325 .12081 .40665 .11375 .39745 Mtetra
.482 .609 .901 r
.11375 .39745 .12081 .40665 .13063 .40533 .12339 .39756 Mtetra
.494 .659 .934 r
.12339 .39756 .13063 .40533 .12862 .50383 .13317 .39716 Mtetra
.562 .35 .55 r
.13317 .39716 .12862 .50383 .15122 .39589 .14417 .38689 Mtetra
.503 .626 .905 r
.14417 .38689 .15122 .39589 .16121 .39435 .15401 .3866 Mtetra
.524 .674 .932 r
.15401 .3866 .16121 .39435 .16959 .40786 .16399 .38569 Mtetra
.694 .548 .684 r
.16399 .38569 .16959 .40786 .18204 .38466 .1751 .375 Mtetra
.477 .597 .894 r
.1751 .375 .18204 .38466 .19217 .38298 .18503 .37527 Mtetra
.563 .693 .928 r
.18503 .37527 .19217 .38298 .20208 .38414 .19523 .37364 Mtetra
.828 .708 .732 r
.19523 .37364 .20208 .38414 .21328 .37271 .20692 .35756 Mtetra
.243 .344 .768 r
.20692 .35756 .21328 .37271 .22352 .37131 .21644 .36355 Mtetra
.584 .701 .923 r
.21644 .36355 .22352 .37131 .23384 .36972 .22682 .36147 Mtetra
.224 .507 .907 r
.22682 .36147 .23384 .36972 .24519 .35706 .23678 .3646 Mtetra
.707 .934 .618 r
.23678 .3646 .24519 .35706 .25526 .3593 .24828 .35108 Mtetra
.572 .685 .917 r
.24828 .35108 .25526 .3593 .26578 .35699 .25878 .34925 Mtetra
.58 .703 .927 r
.25878 .34925 .26578 .35699 .27614 .35739 .26934 .3472 Mtetra
.855 .722 .715 r
.26934 .3472 .27614 .35739 .28745 .34608 .2813 .328 Mtetra
.187 .266 .714 r
.2813 .328 .28745 .34608 .29805 .34451 .29113 .33664 Mtetra
.6 .709 .92 r
.29113 .33664 .29805 .34451 .30878 .34194 .30187 .33413 Mtetra
.58 .704 .927 r
.30187 .33413 .30878 .34194 .31931 .34334 .31264 .33204 Mtetra
.817 .704 .74 r
.31264 .33204 .31931 .34334 .33076 .33094 .32428 .31719 Mtetra
.345 .437 .812 r
.32428 .31719 .33076 .33094 .34159 .32898 .33476 .32109 Mtetra
.609 .715 .92 r
.33476 .32109 .34159 .32898 .35254 .32607 .34572 .31832 Mtetra
.608 .719 .924 r
.34572 .31832 .35254 .32607 .36347 .32423 .35672 .31555 Mtetra
0 .301 .794 r
.35672 .31555 .36347 .32423 .37495 .31239 .36731 .32237 Mtetra
.691 .872 .479 r
.36731 .32237 .37495 .31239 .38588 .31269 .37917 .30438 Mtetra
.597 .701 .916 r
.37917 .30438 .38588 .31269 .39702 .30963 .39031 .30187 Mtetra
.627 .729 .921 r
.39031 .30187 .39702 .30963 .40822 .30641 .40153 .2986 Mtetra
.618 .725 .923 r
.40153 .2986 .40822 .30641 .41944 .30412 .4128 .29553 Mtetra
.293 .541 .916 r
.4128 .29553 .41944 .30412 .43105 .29084 .42394 .29826 Mtetra
.639 .88 .532 r
.42394 .29826 .43105 .29084 .44225 .29243 .43567 .28388 Mtetra
.596 .697 .914 r
.43567 .28388 .44225 .29243 .45365 .28919 .44707 .28134 Mtetra
.634 .734 .92 r
.44707 .28134 .45365 .28919 .4651 .28557 .45856 .2778 Mtetra
.64 .74 .921 r
.45856 .2778 .4651 .28557 .47661 .28189 .4701 .27408 Mtetra
.638 .739 .921 r
.4701 .27408 .47661 .28189 .48817 .27839 .48169 .27041 Mtetra
.618 .727 .924 r
.48169 .27041 .48817 .27839 .49977 .27652 .49332 .26723 Mtetra
.806 .383 0 r
.49332 .26723 .49977 .27652 .51148 .26486 .50483 .29338 Mtetra
0 0 0 r
.50483 .29338 .51148 .26486 .52318 .26368 .51679 .25524 Mtetra
.616 .715 .916 r
.51679 .25524 .52318 .26368 .53494 .26006 .52858 .25209 Mtetra
.643 .741 .92 r
.52858 .25209 .53494 .26006 .54675 .25607 .54042 .24819 Mtetra
.651 .747 .92 r
.54042 .24819 .54675 .25607 .55861 .25194 .55232 .24409 Mtetra
.654 .75 .92 r
.55232 .24409 .55861 .25194 .57053 .24772 .56427 .23986 Mtetra
.656 .752 .92 r
.56427 .23986 .57053 .24772 .58249 .24344 .57627 .23556 Mtetra
.658 .753 .92 r
.57627 .23556 .58249 .24344 .59451 .2391 .58832 .2312 Mtetra
.659 .754 .92 r
.58832 .2312 .59451 .2391 .60657 .23473 .60042 .2268 Mtetra
.60042 .2268 .60657 .23473 .61869 .23033 .61257 .22238 Mtetra
.61257 .22238 .61869 .23033 .63086 .22592 .62478 .21793 Mtetra
.62478 .21793 .63086 .22592 .64308 .2215 .63704 .21347 Mtetra
.658 .754 .92 r
.63704 .21347 .64308 .2215 .65536 .21707 .64935 .209 Mtetra
.658 .753 .92 r
.64935 .209 .65536 .21707 .66769 .21263 .66172 .20452 Mtetra
.66172 .20452 .66769 .21263 .68007 .20817 .67414 .20002 Mtetra
.67414 .20002 .68007 .20817 .69251 .20369 .68662 .19551 Mtetra
.68662 .19551 .69251 .20369 .70501 .1992 .69915 .19098 Mtetra
.69915 .19098 .70501 .1992 .71755 .19469 .71173 .18643 Mtetra
.657 .753 .92 r
.71173 .18643 .71755 .19469 .73016 .19017 .72438 .18187 Mtetra
.72438 .18187 .73016 .19017 .74281 .18562 .73707 .17728 Mtetra
0 .356 .828 r
.06556 .40942 .07288 .41758 .08393 .40615 .07437 .41426 Mtetra
.791 .972 .677 r
.07437 .41426 .08393 .40615 .09317 .40815 .08586 .40015 Mtetra
.538 .67 .922 r
.08586 .40015 .09317 .40815 .1028 .40769 .09559 .39906 Mtetra
.934 .558 .234 r
.09559 .39906 .1028 .40769 .11375 .39745 .10165 .42649 Mtetra
.733 .8 .321 r
.10165 .42649 .11375 .39745 .12339 .39756 .11611 .38969 Mtetra
.552 .681 .924 r
.11611 .38969 .12339 .39756 .13317 .39716 .12601 .38831 Mtetra
.952 .661 .449 r
.12601 .38831 .13317 .39716 .14417 .38689 .12382 .48718 Mtetra
0 0 0 r
.12382 .48718 .14417 .38689 .15401 .3866 .14678 .37873 Mtetra
.562 .687 .924 r
.14678 .37873 .15401 .3866 .16399 .38569 .15685 .37712 Mtetra
.719 .251 0 r
.15685 .37712 .16399 .38569 .1751 .375 .16528 .39063 Mtetra
.762 .878 .458 r
.16528 .39063 .1751 .375 .18503 .37527 .17786 .36729 Mtetra
.569 .688 .921 r
.17786 .36729 .18503 .37527 .19523 .37364 .18808 .36554 Mtetra
.388 .604 .934 r
.18808 .36554 .19523 .37364 .20692 .35756 .19806 .36665 Mtetra
0 0 0 r
.19806 .36665 .20692 .35756 .21644 .36355 .20937 .35511 Mtetra
.555 .671 .915 r
.20937 .35511 .21644 .36355 .22682 .36147 .21971 .35366 Mtetra
.561 .693 .929 r
.21971 .35366 .22682 .36147 .23678 .3646 .23011 .352 Mtetra
.783 .673 .742 r
.23011 .352 .23678 .3646 .24828 .35108 .24157 .33924 Mtetra
.397 .505 .852 r
.24157 .33924 .24828 .35108 .25878 .34925 .25173 .34142 Mtetra
.594 .708 .923 r
.25173 .34142 .25878 .34925 .26934 .3472 .26234 .33905 Mtetra
.444 .633 .935 r
.26234 .33905 .26934 .3472 .2813 .328 .27279 .33939 Mtetra
0 0 0 r
.27279 .33939 .2813 .328 .29113 .33664 .28421 .32797 Mtetra
.562 .672 .912 r
.28421 .32797 .29113 .33664 .30187 .33413 .2949 .32634 Mtetra
.604 .715 .923 r
.2949 .32634 .30187 .33413 .31264 .33204 .30573 .3237 Mtetra
.378 .595 .931 r
.30573 .3237 .31264 .33204 .32428 .31719 .31635 .32505 Mtetra
.574 .859 .533 r
.31635 .32505 .32428 .31719 .33476 .32109 .32791 .31253 Mtetra
.578 .684 .914 r
.32791 .31253 .33476 .32109 .34572 .31832 .33885 .3105 Mtetra
.616 .722 .922 r
.33885 .3105 .34572 .31832 .35672 .31555 .34989 .30753 Mtetra
.568 .698 .929 r
.34989 .30753 .35672 .31555 .36731 .32237 .36093 .30561 Mtetra
.742 .618 .721 r
.36093 .30561 .36731 .32237 .37917 .30438 .37252 .29367 Mtetra
.485 .585 .88 r
.37252 .29367 .37917 .30438 .39031 .30187 .38355 .2939 Mtetra
.62 .723 .92 r
.38355 .2939 .39031 .30187 .40153 .2986 .39479 .29077 Mtetra
.626 .73 .922 r
.39479 .29077 .40153 .2986 .4128 .29553 .4061 .28747 Mtetra
.586 .708 .927 r
.4061 .28747 .4128 .29553 .42394 .29826 .41742 .28511 Mtetra
.79 .68 .743 r
.41742 .28511 .42394 .29826 .43567 .28388 .42915 .27172 Mtetra
.44 .53 .853 r
.42915 .27172 .43567 .28388 .44707 .28134 .44045 .27324 Mtetra
.624 .725 .919 r
.44045 .27324 .44707 .28134 .45856 .2778 .45196 .26993 Mtetra
.639 .738 .92 r
.45196 .26993 .45856 .2778 .4701 .27408 .46353 .26623 Mtetra
.64 .74 .921 r
.46353 .26623 .4701 .27408 .48169 .27041 .47515 .26247 Mtetra
.633 .735 .922 r
.47515 .26247 .48169 .27041 .49332 .26723 .48682 .25889 Mtetra
.564 .696 .929 r
.48682 .25889 .49332 .26723 .50483 .29338 .49853 .25694 Mtetra
.645 .468 .63 r
.49853 .25694 .50483 .29338 .51679 .25524 .51036 .24517 Mtetra
.543 .638 .894 r
.51036 .24517 .51679 .25524 .52858 .25209 .52217 .24392 Mtetra
.635 .733 .919 r
.52217 .24392 .52858 .25209 .54042 .24819 .53405 .24021 Mtetra
.648 .744 .92 r
.53405 .24021 .54042 .24819 .55232 .24409 .54598 .23614 Mtetra
.653 .749 .92 r
.54598 .23614 .55232 .24409 .56427 .23986 .55796 .23193 Mtetra
.655 .751 .92 r
.55796 .23193 .56427 .23986 .57627 .23556 .56999 .22762 Mtetra
.657 .752 .92 r
.56999 .22762 .57627 .23556 .58832 .2312 .58208 .22324 Mtetra
.658 .753 .92 r
.58208 .22324 .58832 .2312 .60042 .2268 .59422 .21882 Mtetra
.659 .754 .92 r
.59422 .21882 .60042 .2268 .61257 .22238 .60641 .21436 Mtetra
.60641 .21436 .61257 .22238 .62478 .21793 .61865 .20987 Mtetra
.61865 .20987 .62478 .21793 .63704 .21347 .63095 .20538 Mtetra
.63095 .20538 .63704 .21347 .64935 .209 .6433 .20086 Mtetra
.658 .753 .92 r
.6433 .20086 .64935 .209 .66172 .20452 .6557 .19634 Mtetra
.6557 .19634 .66172 .20452 .67414 .20002 .66816 .1918 Mtetra
.66816 .1918 .67414 .20002 .68662 .19551 .68067 .18725 Mtetra
.68067 .18725 .68662 .19551 .69915 .19098 .69324 .18269 Mtetra
.69324 .18269 .69915 .19098 .71173 .18643 .70587 .1781 Mtetra
.70587 .1781 .71173 .18643 .72438 .18187 .71855 .1735 Mtetra
.657 .753 .92 r
.71855 .1735 .72438 .18187 .73707 .17728 .73129 .16888 Mtetra
.518 .668 .93 r
.05814 .40158 .06556 .40942 .07437 .41426 .06775 .40077 Mtetra
.759 .646 .737 r
.06775 .40077 .07437 .41426 .08586 .40015 .0789 .38924 Mtetra
.384 .516 .867 r
.0789 .38924 .08586 .40015 .09559 .39906 .08821 .3912 Mtetra
.499 .661 .933 r
.08821 .3912 .09559 .39906 .10165 .42649 .09792 .39069 Mtetra
.639 .464 .63 r
.09792 .39069 .10165 .42649 .11611 .38969 .10897 .38035 Mtetra
.481 .609 .902 r
.10897 .38035 .11611 .38969 .12601 .38831 .11869 .38041 Mtetra
.494 .659 .934 r
.11869 .38041 .12601 .38831 .12382 .48718 .12854 .37995 Mtetra
.56 .346 .547 r
.12854 .37995 .12382 .48718 .14678 .37873 .13965 .36958 Mtetra
.502 .626 .905 r
.13965 .36958 .14678 .37873 .15685 .37712 .14957 .36924 Mtetra
.525 .674 .932 r
.14957 .36924 .15685 .37712 .16528 .39063 .15963 .36826 Mtetra
.693 .548 .684 r
.15963 .36826 .16528 .39063 .17786 .36729 .17084 .35748 Mtetra
.477 .597 .894 r
.17084 .35748 .17786 .36729 .18808 .36554 .18086 .3577 Mtetra
.563 .693 .928 r
.18086 .3577 .18808 .36554 .19806 .36665 .19114 .356 Mtetra
.829 .708 .732 r
.19114 .356 .19806 .36665 .20937 .35511 .20295 .3398 Mtetra
.24 .342 .768 r
.20295 .3398 .20937 .35511 .21971 .35366 .21254 .34576 Mtetra
.584 .701 .923 r
.21254 .34576 .21971 .35366 .23011 .352 .22301 .34362 Mtetra
.226 .508 .908 r
.22301 .34362 .23011 .352 .24157 .33924 .23305 .3467 Mtetra
.715 .939 .627 r
.23305 .3467 .24157 .33924 .25173 .34142 .24467 .33306 Mtetra
.572 .685 .917 r
.24467 .33306 .25173 .34142 .26234 .33905 .25526 .33117 Mtetra
.58 .703 .927 r
.25526 .33117 .26234 .33905 .27279 .33939 .26592 .32905 Mtetra
.856 .722 .715 r
.26592 .32905 .27279 .33939 .28421 .32797 .27799 .30971 Mtetra
.184 .264 .713 r
.27799 .30971 .28421 .32797 .2949 .32634 .2879 .31833 Mtetra
.6 .709 .92 r
.2879 .31833 .2949 .32634 .30573 .3237 .29874 .31575 Mtetra
.58 .704 .927 r
.29874 .31575 .30573 .3237 .31635 .32505 .30961 .31359 Mtetra
.818 .705 .74 r
.30961 .31359 .31635 .32505 .32791 .31253 .32137 .29862 Mtetra
.344 .436 .812 r
.32137 .29862 .32791 .31253 .33885 .3105 .33193 .30247 Mtetra
.609 .715 .92 r
.33193 .30247 .33885 .3105 .34989 .30753 .34299 .29962 Mtetra
.608 .719 .924 r
.34299 .29962 .34989 .30753 .36093 .30561 .3541 .29678 Mtetra
0 .304 .797 r
.3541 .29678 .36093 .30561 .37252 .29367 .36477 .30357 Mtetra
.699 .879 .488 r
.36477 .30357 .37252 .29367 .38355 .2939 .37676 .28545 Mtetra
.597 .701 .916 r
.37676 .28545 .38355 .2939 .39479 .29077 .388 .28286 Mtetra
.627 .729 .921 r
.388 .28286 .39479 .29077 .4061 .28747 .39933 .27951 Mtetra
.618 .725 .923 r
.39933 .27951 .4061 .28747 .41742 .28511 .41071 .27637 Mtetra
.295 .541 .916 r
.41071 .27637 .41742 .28511 .42915 .27172 .42195 .27904 Mtetra
.649 .888 .542 r
.42195 .27904 .42915 .27172 .44045 .27324 .4338 .26454 Mtetra
.596 .697 .914 r
.4338 .26454 .44045 .27324 .45196 .26993 .44531 .26192 Mtetra
.634 .734 .92 r
.44531 .26192 .45196 .26993 .46353 .26623 .45691 .2583 Mtetra
.64 .74 .921 r
.45691 .2583 .46353 .26623 .47515 .26247 .46856 .25451 Mtetra
.638 .739 .921 r
.46856 .25451 .47515 .26247 .48682 .25889 .48026 .25075 Mtetra
.618 .726 .924 r
.48026 .25075 .48682 .25889 .49853 .25694 .49202 .24749 Mtetra
.799 .377 0 r
.49202 .24749 .49853 .25694 .51036 .24517 .50362 .27366 Mtetra
0 0 0 r
.50362 .27366 .51036 .24517 .52217 .24392 .51571 .23532 Mtetra
.616 .715 .916 r
.51571 .23532 .52217 .24392 .53405 .24021 .52762 .23208 Mtetra
.643 .741 .92 r
.52762 .23208 .53405 .24021 .54598 .23614 .53958 .2281 Mtetra
.651 .747 .92 r
.53958 .2281 .54598 .23614 .55796 .23193 .5516 .22391 Mtetra
.654 .75 .92 r
.5516 .22391 .55796 .23193 .56999 .22762 .56367 .2196 Mtetra
.656 .752 .92 r
.56367 .2196 .56999 .22762 .58208 .22324 .57579 .21521 Mtetra
.658 .753 .92 r
.57579 .21521 .58208 .22324 .59422 .21882 .58797 .21076 Mtetra
.659 .754 .92 r
.58797 .21076 .59422 .21882 .60641 .21436 .60019 .20627 Mtetra
.60019 .20627 .60641 .21436 .61865 .20987 .61247 .20175 Mtetra
.61247 .20175 .61865 .20987 .63095 .20538 .6248 .19722 Mtetra
.6248 .19722 .63095 .20538 .6433 .20086 .63719 .19266 Mtetra
.658 .754 .92 r
.63719 .19266 .6433 .20086 .6557 .19634 .64963 .1881 Mtetra
.658 .753 .92 r
.64963 .1881 .6557 .19634 .66816 .1918 .66213 .18352 Mtetra
.66213 .18352 .66816 .1918 .68067 .18725 .67468 .17893 Mtetra
.67468 .17893 .68067 .18725 .69324 .18269 .68729 .17433 Mtetra
.68729 .17433 .69324 .18269 .70587 .1781 .69995 .1697 Mtetra
.69995 .1697 .70587 .1781 .71855 .1735 .71267 .16506 Mtetra
.657 .753 .92 r
.71267 .16506 .71855 .1735 .73129 .16888 .72545 .1604 Mtetra
.502 .637 .914 r
.05078 .3929 .05814 .40158 .06775 .40077 .06034 .39248 Mtetra
0 .358 .829 r
.06034 .39248 .06775 .40077 .0789 .38924 .06922 .39729 Mtetra
.796 .974 .683 r
.06922 .39729 .0789 .38924 .08821 .3912 .08082 .38307 Mtetra
.538 .67 .922 r
.08082 .38307 .08821 .3912 .09792 .39069 .09062 .38192 Mtetra
.934 .556 .228 r
.09062 .38192 .09792 .39069 .10897 .38035 .09668 .4094 Mtetra
.741 .806 .33 r
.09668 .4094 .10897 .38035 .11869 .38041 .11132 .3724 Mtetra
.552 .681 .924 r
.11132 .3724 .11869 .38041 .12854 .37995 .12131 .37096 Mtetra
.953 .661 .446 r
.12131 .37096 .12854 .37995 .13965 .36958 .11893 .47021 Mtetra
0 0 0 r
.11893 .47021 .13965 .36958 .14957 .36924 .14226 .36123 Mtetra
.562 .687 .924 r
.14226 .36123 .14957 .36924 .15963 .36826 .15241 .35956 Mtetra
.712 .245 0 r
.15241 .35956 .15963 .36826 .17084 .35748 .16088 .37307 Mtetra
.769 .883 .466 r
.16088 .37307 .17084 .35748 .18086 .3577 .1736 .34957 Mtetra
.569 .688 .921 r
.1736 .34957 .18086 .3577 .19114 .356 .18391 .34777 Mtetra
.389 .604 .933 r
.18391 .34777 .19114 .356 .20295 .3398 .19398 .34882 Mtetra
.515 .824 .505 r
.19398 .34882 .20295 .3398 .21254 .34576 .2054 .33718 Mtetra
.555 .671 .915 r
.2054 .33718 .21254 .34576 .22301 .34362 .21582 .33566 Mtetra
.561 .693 .929 r
.21582 .33566 .22301 .34362 .23305 .3467 .22631 .33394 Mtetra
.783 .673 .742 r
.22631 .33394 .23305 .3467 .24467 .33306 .23789 .32107 Mtetra
.396 .505 .852 r
.23789 .32107 .24467 .33306 .25526 .33117 .24812 .3232 Mtetra
.594 .708 .923 r
.24812 .3232 .25526 .33117 .26592 .32905 .25883 .32075 Mtetra
.445 .633 .935 r
.25883 .32075 .26592 .32905 .27799 .30971 .26937 .32104 Mtetra
0 0 0 r
.26937 .32104 .27799 .30971 .2879 .31833 .2809 .30951 Mtetra
.562 .672 .912 r
.2809 .30951 .2879 .31833 .29874 .31575 .2917 .30782 Mtetra
.604 .715 .923 r
.2917 .30782 .29874 .31575 .30961 .31359 .30262 .3051 Mtetra
.379 .596 .931 r
.30262 .3051 .30961 .31359 .32137 .29862 .31333 .30639 Mtetra
.586 .868 .545 r
.31333 .30639 .32137 .29862 .33193 .30247 .32501 .29377 Mtetra
.577 .684 .914 r
.32501 .29377 .33193 .30247 .34299 .29962 .33604 .29167 Mtetra
.616 .722 .922 r
.33604 .29167 .34299 .29962 .3541 .29678 .34719 .28862 Mtetra
.568 .698 .929 r
.34719 .28862 .3541 .29678 .36477 .30357 .35833 .28663 Mtetra
.742 .618 .721 r
.35833 .28663 .36477 .30357 .37676 .28545 .37004 .27457 Mtetra
.485 .585 .88 r
.37004 .27457 .37676 .28545 .388 .28286 .38117 .27474 Mtetra
.62 .723 .92 r
.38117 .27474 .388 .28286 .39933 .27951 .39252 .27154 Mtetra
.626 .73 .922 r
.39252 .27154 .39933 .27951 .41071 .27637 .40393 .26815 Mtetra
.586 .708 .927 r
.40393 .26815 .41071 .27637 .42195 .27904 .41537 .26572 Mtetra
.79 .68 .743 r
.41537 .26572 .42195 .27904 .4338 .26454 .42721 .25221 Mtetra
.439 .53 .853 r
.42721 .25221 .4338 .26454 .44531 .26192 .43862 .25367 Mtetra
.624 .725 .919 r
.43862 .25367 .44531 .26192 .45691 .2583 .45024 .25028 Mtetra
.639 .738 .92 r
.45024 .25028 .45691 .2583 .46856 .25451 .46192 .24649 Mtetra
.64 .74 .921 r
.46192 .24649 .46856 .25451 .48026 .25075 .47365 .24265 Mtetra
.633 .735 .922 r
.47365 .24265 .48026 .25075 .49202 .24749 .48544 .23899 Mtetra
.565 .696 .929 r
.48544 .23899 .49202 .24749 .50362 .27366 .49727 .23696 Mtetra
.644 .467 .629 r
.49727 .23696 .50362 .27366 .51571 .23532 .50922 .22508 Mtetra
.543 .638 .894 r
.50922 .22508 .51571 .23532 .52762 .23208 .52114 .22375 Mtetra
.635 .733 .919 r
.52114 .22375 .52762 .23208 .53958 .2281 .53314 .21995 Mtetra
.648 .744 .92 r
.53314 .21995 .53958 .2281 .5516 .22391 .54519 .2158 Mtetra
.653 .749 .92 r
.54519 .2158 .5516 .22391 .56367 .2196 .5573 .21149 Mtetra
.655 .751 .92 r
.5573 .21149 .56367 .2196 .57579 .21521 .56945 .2071 Mtetra
.657 .752 .92 r
.56945 .2071 .57579 .21521 .58797 .21076 .58166 .20263 Mtetra
.658 .753 .92 r
.58166 .20263 .58797 .21076 .60019 .20627 .59393 .19812 Mtetra
.659 .754 .92 r
.59393 .19812 .60019 .20627 .61247 .20175 .60624 .19356 Mtetra
.60624 .19356 .61247 .20175 .6248 .19722 .61861 .18899 Mtetra
.61861 .18899 .6248 .19722 .63719 .19266 .63103 .1844 Mtetra
.63103 .1844 .63719 .19266 .64963 .1881 .64351 .17979 Mtetra
.658 .753 .92 r
.64351 .17979 .64963 .1881 .66213 .18352 .65605 .17518 Mtetra
.65605 .17518 .66213 .18352 .67468 .17893 .66864 .17055 Mtetra
.66864 .17055 .67468 .17893 .68729 .17433 .68128 .1659 Mtetra
.68128 .1659 .68729 .17433 .69995 .1697 .69399 .16124 Mtetra
.69399 .16124 .69995 .1697 .71267 .16506 .70675 .15655 Mtetra
.70675 .15655 .71267 .16506 .72545 .1604 .71956 .15186 Mtetra
0 0 .376 r
.04701 .36 .05078 .3929 .06034 .39248 .05283 .38451 Mtetra
.518 .668 .93 r
.05283 .38451 .06034 .39248 .06922 .39729 .06252 .38365 Mtetra
.76 .647 .737 r
.06252 .38365 .06922 .39729 .08082 .38307 .07378 .37202 Mtetra
.383 .516 .867 r
.07378 .37202 .08082 .38307 .09062 .38192 .08316 .37393 Mtetra
.499 .661 .933 r
.08316 .37393 .09062 .38192 .09668 .4094 .09295 .37336 Mtetra
.638 .463 .629 r
.09295 .37336 .09668 .4094 .11132 .3724 .10409 .36292 Mtetra
.481 .609 .902 r
.10409 .36292 .11132 .3724 .12131 .37096 .1139 .36293 Mtetra
.494 .659 .934 r
.1139 .36293 .12131 .37096 .11893 .47021 .12383 .36242 Mtetra
.557 .343 .545 r
.12383 .36242 .11893 .47021 .14226 .36123 .13504 .35195 Mtetra
.502 .626 .905 r
.13504 .35195 .14226 .36123 .15241 .35956 .14504 .35154 Mtetra
.525 .674 .932 r
.14504 .35154 .15241 .35956 .16088 .37307 .15519 .35051 Mtetra
.693 .548 .684 r
.15519 .35051 .16088 .37307 .1736 .34957 .1665 .33962 Mtetra
.476 .597 .894 r
.1665 .33962 .1736 .34957 .18391 .34777 .1766 .33979 Mtetra
.563 .693 .928 r
.1766 .33979 .18391 .34777 .19398 .34882 .18697 .33802 Mtetra
.83 .709 .732 r
.18697 .33802 .19398 .34882 .2054 .33718 .19891 .3217 Mtetra
.238 .341 .767 r
.19891 .3217 .2054 .33718 .21582 .33566 .20857 .32762 Mtetra
.584 .701 .923 r
.20857 .32762 .21582 .33566 .22631 .33394 .21913 .32541 Mtetra
.228 .509 .908 r
.21913 .32541 .22631 .33394 .23789 .32107 .22925 .32844 Mtetra
.723 .944 .635 r
.22925 .32844 .23789 .32107 .24812 .3232 .24098 .31469 Mtetra
.572 .685 .917 r
.24098 .31469 .24812 .3232 .25883 .32075 .25167 .31273 Mtetra
.58 .703 .927 r
.25167 .31273 .25883 .32075 .26937 .32104 .26242 .31055 Mtetra
.857 .723 .715 r
.26242 .31055 .26937 .32104 .2809 .30951 .27463 .29107 Mtetra
.18 .262 .712 r
.27463 .29107 .2809 .30951 .2917 .30782 .28461 .29966 Mtetra
.6 .709 .92 r
.28461 .29966 .2917 .30782 .30262 .3051 .29555 .29701 Mtetra
.58 .704 .927 r
.29555 .29701 .30262 .3051 .31333 .30639 .30652 .29477 Mtetra
.818 .705 .74 r
.30652 .29477 .31333 .30639 .32501 .29377 .3184 .27968 Mtetra
.342 .435 .812 r
.3184 .27968 .32501 .29377 .33604 .29167 .32905 .28349 Mtetra
.609 .715 .92 r
.32905 .28349 .33604 .29167 .34719 .28862 .34021 .28056 Mtetra
.608 .719 .924 r
.34021 .28056 .34719 .28862 .35833 .28663 .35143 .27765 Mtetra
0 .308 .799 r
.35143 .27765 .35833 .28663 .37004 .27457 .36219 .28439 Mtetra
.707 .885 .497 r
.36219 .28439 .37004 .27457 .38117 .27474 .3743 .26614 Mtetra
.597 .701 .916 r
.3743 .26614 .38117 .27474 .39252 .27154 .38565 .26347 Mtetra
.627 .729 .921 r
.38565 .26347 .39252 .27154 .40393 .26815 .39709 .26004 Mtetra
.618 .725 .923 r
.39709 .26004 .40393 .26815 .41537 .26572 .40858 .25682 Mtetra
.297 .542 .916 r
.40858 .25682 .41537 .26572 .42721 .25221 .41993 .25944 Mtetra
.658 .895 .552 r
.41993 .25944 .42721 .25221 .43862 .25367 .43189 .24481 Mtetra
.596 .697 .914 r
.43189 .24481 .43862 .25367 .45024 .25028 .44352 .24211 Mtetra
.634 .734 .92 r
.44352 .24211 .45024 .25028 .46192 .24649 .45523 .23841 Mtetra
.64 .74 .921 r
.45523 .23841 .46192 .24649 .47365 .24265 .46699 .23453 Mtetra
.638 .739 .921 r
.46699 .23453 .47365 .24265 .48544 .23899 .47881 .23069 Mtetra
.618 .726 .924 r
.47881 .23069 .48544 .23899 .49727 .23696 .49068 .22734 Mtetra
.793 .37 0 r
.49068 .22734 .49727 .23696 .50922 .22508 .50239 .25354 Mtetra
0 0 0 r
.50239 .25354 .50922 .22508 .52114 .22375 .51462 .21499 Mtetra
.616 .715 .916 r
.51462 .21499 .52114 .22375 .53314 .21995 .52664 .21166 Mtetra
.643 .741 .92 r
.52664 .21166 .53314 .21995 .54519 .2158 .53873 .20759 Mtetra
.651 .747 .92 r
.53873 .20759 .54519 .2158 .5573 .21149 .55087 .20331 Mtetra
.654 .75 .92 r
.55087 .20331 .5573 .21149 .56945 .2071 .56306 .19891 Mtetra
.656 .752 .92 r
.56306 .19891 .56945 .2071 .58166 .20263 .57531 .19443 Mtetra
.658 .753 .92 r
.57531 .19443 .58166 .20263 .59393 .19812 .58761 .18989 Mtetra
.659 .754 .92 r
.58761 .18989 .59393 .19812 .60624 .19356 .59996 .18531 Mtetra
.59996 .18531 .60624 .19356 .61861 .18899 .61237 .1807 Mtetra
.61237 .1807 .61861 .18899 .63103 .1844 .62483 .17607 Mtetra
.62483 .17607 .63103 .1844 .64351 .17979 .63734 .17142 Mtetra
.658 .754 .92 r
.63734 .17142 .64351 .17979 .65605 .17518 .64992 .16676 Mtetra
.658 .753 .92 r
.64992 .16676 .65605 .17518 .66864 .17055 .66255 .16209 Mtetra
.66255 .16209 .66864 .17055 .68128 .1659 .67523 .1574 Mtetra
.67523 .1574 .68128 .1659 .69399 .16124 .68797 .1527 Mtetra
.68797 .1527 .69399 .16124 .70675 .15655 .70077 .14798 Mtetra
.70077 .14798 .70675 .15655 .71956 .15186 .71363 .14324 Mtetra
.169 0 .141 r
.03432 .38599 .04701 .36 .05283 .38451 .04539 .3757 Mtetra
.502 .637 .914 r
.04539 .3757 .05283 .38451 .06252 .38365 .05503 .37522 Mtetra
0 .36 .831 r
.05503 .37522 .06252 .38365 .07378 .37202 .06396 .38 Mtetra
.802 .977 .689 r
.06396 .38 .07378 .37202 .08316 .37393 .07568 .36566 Mtetra
.538 .67 .923 r
.07568 .36566 .08316 .37393 .09295 .37336 .08556 .36446 Mtetra
.933 .554 .222 r
.08556 .36446 .09295 .37336 .10409 .36292 .09162 .392 Mtetra
.749 .812 .339 r
.09162 .392 .10409 .36292 .1139 .36293 .10644 .35478 Mtetra
.552 .681 .924 r
.10644 .35478 .1139 .36293 .12383 .36242 .11651 .35328 Mtetra
.954 .661 .442 r
.11651 .35328 .12383 .36242 .13504 .35195 .11394 .4529 Mtetra
0 0 0 r
.11394 .4529 .13504 .35195 .14504 .35154 .13764 .3434 Mtetra
.562 .687 .924 r
.13764 .3434 .14504 .35154 .15519 .35051 .14788 .34166 Mtetra
.706 .239 0 r
.14788 .34166 .15519 .35051 .1665 .33962 .1564 .35517 Mtetra
.776 .888 .474 r
.1564 .35517 .1665 .33962 .1766 .33979 .16927 .33152 Mtetra
.569 .688 .921 r
.16927 .33152 .1766 .33979 .18697 .33802 .17966 .32965 Mtetra
.39 .604 .933 r
.17966 .32965 .18697 .33802 .19891 .3217 .18981 .33064 Mtetra
.529 .836 .519 r
.18981 .33064 .19891 .3217 .20857 .32762 .20134 .3189 Mtetra
.555 .671 .915 r
.20134 .3189 .20857 .32762 .21913 .32541 .21185 .31731 Mtetra
.561 .693 .929 r
.21185 .31731 .21913 .32541 .22925 .32844 .22244 .31553 Mtetra
.784 .674 .743 r
.22244 .31553 .22925 .32844 .24098 .31469 .23413 .30254 Mtetra
.395 .505 .852 r
.23413 .30254 .24098 .31469 .25167 .31273 .24445 .30462 Mtetra
.594 .708 .923 r
.24445 .30462 .25167 .31273 .26242 .31055 .25525 .3021 Mtetra
.445 .633 .935 r
.25525 .3021 .26242 .31055 .27463 .29107 .26589 .30233 Mtetra
0 0 0 r
.26589 .30233 .27463 .29107 .28461 .29966 .27753 .29069 Mtetra
.562 .672 .912 r
.27753 .29069 .28461 .29966 .29555 .29701 .28842 .28892 Mtetra
.604 .715 .923 r
.28842 .28892 .29555 .29701 .30652 .29477 .29945 .28614 Mtetra
.38 .596 .93 r
.29945 .28614 .30652 .29477 .3184 .27968 .31025 .28737 Mtetra
.598 .877 .557 r
.31025 .28737 .3184 .27968 .32905 .28349 .32205 .27463 Mtetra
.577 .684 .914 r
.32205 .27463 .32905 .28349 .34021 .28056 .33319 .27245 Mtetra
.616 .722 .922 r
.33319 .27245 .34021 .28056 .35143 .27765 .34443 .26932 Mtetra
.568 .698 .929 r
.34443 .26932 .35143 .27765 .36219 .28439 .35568 .26726 Mtetra
.743 .618 .721 r
.35568 .26726 .36219 .28439 .3743 .26614 .36751 .2551 Mtetra
.484 .585 .88 r
.36751 .2551 .3743 .26614 .38565 .26347 .37874 .2552 Mtetra
.62 .723 .92 r
.37874 .2552 .38565 .26347 .39709 .26004 .3902 .25191 Mtetra
.626 .73 .922 r
.3902 .25191 .39709 .26004 .40858 .25682 .40172 .24845 Mtetra
.586 .708 .927 r
.40172 .24845 .40858 .25682 .41993 .25944 .41327 .24593 Mtetra
.791 .681 .743 r
.41327 .24593 .41993 .25944 .43189 .24481 .42524 .2323 Mtetra
.438 .529 .853 r
.42524 .2323 .43189 .24481 .44352 .24211 .43675 .2337 Mtetra
.624 .725 .919 r
.43675 .2337 .44352 .24211 .45523 .23841 .44848 .23023 Mtetra
.639 .738 .92 r
.44848 .23023 .45523 .23841 .46699 .23453 .46028 .22636 Mtetra
.64 .74 .921 r
.46028 .22636 .46699 .23453 .47881 .23069 .47213 .22243 Mtetra
.633 .735 .922 r
.47213 .22243 .47881 .23069 .49068 .22734 .48403 .21868 Mtetra
.565 .696 .929 r
.48403 .21868 .49068 .22734 .50239 .25354 .49598 .21657 Mtetra
.643 .465 .628 r
.49598 .21657 .50239 .25354 .51462 .21499 .50805 .20457 Mtetra
.543 .638 .894 r
.50805 .20457 .51462 .21499 .52664 .21166 .5201 .20316 Mtetra
.635 .733 .919 r
.5201 .20316 .52664 .21166 .53873 .20759 .53222 .19928 Mtetra
.648 .744 .92 r
.53222 .19928 .53873 .20759 .55087 .20331 .54439 .19503 Mtetra
.653 .749 .92 r
.54439 .19503 .55087 .20331 .56306 .19891 .55662 .19064 Mtetra
.655 .751 .92 r
.55662 .19064 .56306 .19891 .57531 .19443 .5689 .18615 Mtetra
.657 .752 .92 r
.5689 .18615 .57531 .19443 .58761 .18989 .58124 .18159 Mtetra
.658 .753 .92 r
.58124 .18159 .58761 .18989 .59996 .18531 .59363 .17698 Mtetra
.659 .754 .92 r
.59363 .17698 .59996 .18531 .61237 .1807 .60607 .17233 Mtetra
.60607 .17233 .61237 .1807 .62483 .17607 .61857 .16767 Mtetra
.61857 .16767 .62483 .17607 .63734 .17142 .63112 .16298 Mtetra
.63112 .16298 .63734 .17142 .64992 .16676 .64374 .15828 Mtetra
.658 .753 .92 r
.64374 .15828 .64992 .16676 .66255 .16209 .6564 .15356 Mtetra
.6564 .15356 .66255 .16209 .67523 .1574 .66913 .14884 Mtetra
.66913 .14884 .67523 .1574 .68797 .1527 .68191 .14409 Mtetra
.68191 .14409 .68797 .1527 .70077 .14798 .69475 .13933 Mtetra
.69475 .13933 .70077 .14798 .71363 .14324 .70765 .13455 Mtetra
.888 .712 .657 r
.02691 .37646 .03432 .38599 .04539 .3757 .04161 .34257 Mtetra
0 0 .371 r
.04161 .34257 .04539 .3757 .05503 .37522 .04743 .36712 Mtetra
.519 .668 .93 r
.04743 .36712 .05503 .37522 .06396 .38 .05719 .36619 Mtetra
.76 .647 .737 r
.05719 .36619 .06396 .38 .07568 .36566 .06856 .35446 Mtetra
.382 .516 .867 r
.06856 .35446 .07568 .36566 .08556 .36446 .07801 .35633 Mtetra
.499 .661 .933 r
.07801 .35633 .08556 .36446 .09162 .392 .08787 .3557 Mtetra
.637 .461 .628 r
.08787 .3557 .09162 .392 .10644 .35478 .09913 .34516 Mtetra
.481 .609 .902 r
.09913 .34516 .10644 .35478 .11651 .35328 .10901 .34511 Mtetra
.495 .659 .934 r
.10901 .34511 .11651 .35328 .11394 .4529 .11902 .34454 Mtetra
.554 .339 .542 r
.11902 .34454 .11394 .4529 .13764 .3434 .13034 .33397 Mtetra
.502 .626 .906 r
.13034 .33397 .13764 .3434 .14788 .34166 .14043 .33351 Mtetra
.525 .674 .932 r
.14043 .33351 .14788 .34166 .1564 .35517 .15066 .33241 Mtetra
.693 .547 .684 r
.15066 .33241 .1564 .35517 .16927 .33152 .16208 .32142 Mtetra
.476 .597 .894 r
.16208 .32142 .16927 .33152 .17966 .32965 .17227 .32152 Mtetra
.563 .693 .928 r
.17227 .32152 .17966 .32965 .18981 .33064 .18273 .31969 Mtetra
.83 .71 .732 r
.18273 .31969 .18981 .33064 .20134 .3189 .19479 .30324 Mtetra
.236 .34 .767 r
.19479 .30324 .20134 .3189 .21185 .31731 .20452 .30913 Mtetra
.584 .701 .923 r
.20452 .30913 .21185 .31731 .22244 .31553 .21517 .30685 Mtetra
.231 .51 .908 r
.21517 .30685 .22244 .31553 .23413 .30254 .22538 .30983 Mtetra
.731 .949 .643 r
.22538 .30983 .23413 .30254 .24445 .30462 .23723 .29597 Mtetra
.572 .685 .917 r
.23723 .29597 .24445 .30462 .25525 .3021 .24801 .29393 Mtetra
.58 .703 .927 r
.24801 .29393 .25525 .3021 .26589 .30233 .25886 .29168 Mtetra
.857 .724 .715 r
.25886 .29168 .26589 .30233 .27753 .29069 .27119 .27206 Mtetra
.177 .26 .711 r
.27119 .27206 .27753 .29069 .28842 .28892 .28125 .28062 Mtetra
.6 .709 .921 r
.28125 .28062 .28842 .28892 .29945 .28614 .2923 .27789 Mtetra
.58 .704 .927 r
.2923 .27789 .29945 .28614 .31025 .28737 .30336 .27558 Mtetra
.819 .706 .741 r
.30336 .27558 .31025 .28737 .32205 .27463 .31537 .26037 Mtetra
.341 .435 .812 r
.31537 .26037 .32205 .27463 .33319 .27245 .32611 .26412 Mtetra
.609 .715 .92 r
.32611 .26412 .33319 .27245 .34443 .26932 .33738 .26112 Mtetra
.608 .719 .924 r
.33738 .26112 .34443 .26932 .35568 .26726 .3487 .25812 Mtetra
0 .311 .801 r
.3487 .25812 .35568 .26726 .36751 .2551 .35956 .26483 Mtetra
.716 .891 .506 r
.35956 .26483 .36751 .2551 .37874 .2552 .37179 .24643 Mtetra
.597 .701 .916 r
.37179 .24643 .37874 .2552 .3902 .25191 .38325 .24368 Mtetra
.627 .729 .921 r
.38325 .24368 .3902 .25191 .40172 .24845 .3948 .24018 Mtetra
.618 .725 .923 r
.3948 .24018 .40172 .24845 .41327 .24593 .4064 .23688 Mtetra
.299 .543 .916 r
.4064 .23688 .41327 .24593 .42524 .2323 .41786 .23943 Mtetra
.668 .901 .561 r
.41786 .23943 .42524 .2323 .43675 .2337 .42995 .22468 Mtetra
.596 .697 .914 r
.42995 .22468 .43675 .2337 .44848 .23023 .44169 .2219 Mtetra
.634 .734 .92 r
.44169 .2219 .44848 .23023 .46028 .22636 .45351 .21811 Mtetra
.64 .74 .921 r
.45351 .21811 .46028 .22636 .47213 .22243 .46539 .21414 Mtetra
.638 .739 .921 r
.46539 .21414 .47213 .22243 .48403 .21868 .47733 .21021 Mtetra
.618 .726 .924 r
.47733 .21021 .48403 .21868 .49598 .21657 .48932 .20678 Mtetra
.786 .364 0 r
.48932 .20678 .49598 .21657 .50805 .20457 .50114 .233 Mtetra
0 0 0 r
.50114 .233 .50805 .20457 .5201 .20316 .5135 .19423 Mtetra
.616 .715 .916 r
.5135 .19423 .5201 .20316 .53222 .19928 .52565 .19082 Mtetra
.643 .741 .92 r
.52565 .19082 .53222 .19928 .54439 .19503 .53786 .18666 Mtetra
.651 .747 .92 r
.53786 .18666 .54439 .19503 .55662 .19064 .55012 .18228 Mtetra
.654 .75 .92 r
.55012 .18228 .55662 .19064 .5689 .18615 .56244 .17779 Mtetra
.656 .752 .92 r
.56244 .17779 .5689 .18615 .58124 .18159 .57481 .17322 Mtetra
.658 .753 .92 r
.57481 .17322 .58124 .18159 .59363 .17698 .58724 .16858 Mtetra
.659 .754 .92 r
.58724 .16858 .59363 .17698 .60607 .17233 .59972 .1639 Mtetra
.59972 .1639 .60607 .17233 .61857 .16767 .61226 .1592 Mtetra
.61226 .1592 .61857 .16767 .63112 .16298 .62485 .15447 Mtetra
.62485 .15447 .63112 .16298 .64374 .15828 .6375 .14973 Mtetra
.658 .754 .92 r
.6375 .14973 .64374 .15828 .6564 .15356 .65021 .14497 Mtetra
.658 .753 .92 r
.65021 .14497 .6564 .15356 .66913 .14884 .66297 .1402 Mtetra
.66297 .1402 .66913 .14884 .68191 .14409 .67579 .13541 Mtetra
.67579 .13541 .68191 .14409 .69475 .13933 .68867 .13061 Mtetra
.68867 .13061 .69475 .13933 .70765 .13455 .70161 .12579 Mtetra
.433 .627 .935 r
.01924 .36824 .02691 .37646 .04161 .34257 .02872 .36856 Mtetra
.155 0 .127 r
.02872 .36856 .04161 .34257 .04743 .36712 .0399 .35817 Mtetra
.501 .637 .914 r
.0399 .35817 .04743 .36712 .05719 .36619 .04961 .35764 Mtetra
0 .363 .832 r
.04961 .35764 .05719 .36619 .06856 .35446 .0586 .36237 Mtetra
.807 .979 .695 r
.0586 .36237 .06856 .35446 .07801 .35633 .07044 .34792 Mtetra
.538 .67 .923 r
.07044 .34792 .07801 .35633 .08787 .3557 .0804 .34665 Mtetra
.932 .552 .216 r
.0804 .34665 .08787 .3557 .09913 .34516 .08646 .37425 Mtetra
.757 .819 .347 r
.08646 .37425 .09913 .34516 .10901 .34511 .10147 .33683 Mtetra
.552 .681 .924 r
.10147 .33683 .10901 .34511 .11902 .34454 .11162 .33526 Mtetra
.955 .66 .439 r
.11162 .33526 .11902 .34454 .13034 .33397 .10885 .43524 Mtetra
0 0 0 r
.10885 .43524 .13034 .33397 .14043 .33351 .13294 .32522 Mtetra
.562 .687 .924 r
.13294 .32522 .14043 .33351 .15066 .33241 .14326 .32342 Mtetra
.7 .233 0 r
.14326 .32342 .15066 .33241 .16208 .32142 .15183 .33691 Mtetra
.783 .893 .482 r
.15183 .33691 .16208 .32142 .17227 .32152 .16484 .31311 Mtetra
.568 .688 .921 r
.16484 .31311 .17227 .32152 .18273 .31969 .17533 .31117 Mtetra
.39 .604 .933 r
.17533 .31117 .18273 .31969 .19479 .30324 .18556 .31211 Mtetra
.543 .847 .533 r
.18556 .31211 .19479 .30324 .20452 .30913 .1972 .30026 Mtetra
.555 .671 .915 r
.1972 .30026 .20452 .30913 .21517 .30685 .20781 .29861 Mtetra
.561 .693 .929 r
.20781 .29861 .21517 .30685 .22538 .30983 .21849 .29675 Mtetra
.785 .675 .743 r
.21849 .29675 .22538 .30983 .23723 .29597 .2303 .28365 Mtetra
.394 .504 .852 r
.2303 .28365 .23723 .29597 .24801 .29393 .24071 .28567 Mtetra
.594 .708 .923 r
.24071 .28567 .24801 .29393 .25886 .29168 .25161 .28308 Mtetra
.446 .633 .935 r
.25161 .28308 .25886 .29168 .27119 .27206 .26233 .28324 Mtetra
0 0 0 r
.26233 .28324 .27119 .27206 .28125 .28062 .2741 .2715 Mtetra
.561 .672 .912 r
.2741 .2715 .28125 .28062 .2923 .27789 .28508 .26965 Mtetra
.604 .715 .923 r
.28508 .26965 .2923 .27789 .30336 .27558 .29621 .26679 Mtetra
.381 .596 .93 r
.29621 .26679 .30336 .27558 .31537 .26037 .30711 .26796 Mtetra
.61 .885 .568 r
.30711 .26796 .31537 .26037 .32611 .26412 .31903 .2551 Mtetra
.577 .684 .914 r
.31903 .2551 .32611 .26412 .33738 .26112 .33027 .25285 Mtetra
.616 .722 .922 r
.33027 .25285 .33738 .26112 .3487 .25812 .34163 .24964 Mtetra
.568 .698 .929 r
.34163 .24964 .3487 .25812 .35956 .26483 .35298 .2475 Mtetra
.743 .619 .721 r
.35298 .2475 .35956 .26483 .37179 .24643 .36492 .23523 Mtetra
.484 .585 .88 r
.36492 .23523 .37179 .24643 .38325 .24368 .37626 .23526 Mtetra
.62 .723 .92 r
.37626 .23526 .38325 .24368 .3948 .24018 .38783 .23189 Mtetra
.626 .73 .922 r
.38783 .23189 .3948 .24018 .4064 .23688 .39947 .22834 Mtetra
.586 .708 .927 r
.39947 .22834 .4064 .23688 .41786 .23943 .41112 .22574 Mtetra
.792 .682 .743 r
.41112 .22574 .41786 .23943 .42995 .22468 .42322 .21199 Mtetra
.438 .529 .854 r
.42322 .21199 .42995 .22468 .44169 .2219 .43484 .21332 Mtetra
.624 .725 .919 r
.43484 .21332 .44169 .2219 .45351 .21811 .44669 .20976 Mtetra
.639 .738 .92 r
.44669 .20976 .45351 .21811 .46539 .21414 .4586 .2058 Mtetra
.64 .74 .921 r
.4586 .2058 .46539 .21414 .47733 .21021 .47057 .20178 Mtetra
.633 .735 .922 r
.47057 .20178 .47733 .21021 .48932 .20678 .4826 .19795 Mtetra
.565 .695 .929 r
.4826 .19795 .48932 .20678 .50114 .233 .49466 .19575 Mtetra
.642 .464 .627 r
.49466 .19575 .50114 .233 .5135 .19423 .50686 .18364 Mtetra
.543 .638 .895 r
.50686 .18364 .5135 .19423 .52565 .19082 .51903 .18215 Mtetra
.635 .733 .919 r
.51903 .18215 .52565 .19082 .53786 .18666 .53127 .17817 Mtetra
.648 .744 .92 r
.53127 .17817 .53786 .18666 .55012 .18228 .54357 .17383 Mtetra
.653 .749 .92 r
.54357 .17383 .55012 .18228 .56244 .17779 .55592 .16934 Mtetra
.655 .751 .92 r
.55592 .16934 .56244 .17779 .57481 .17322 .56833 .16476 Mtetra
.657 .752 .92 r
.56833 .16476 .57481 .17322 .58724 .16858 .5808 .16011 Mtetra
.658 .753 .92 r
.5808 .16011 .58724 .16858 .59972 .1639 .59332 .1554 Mtetra
.659 .754 .92 r
.59332 .1554 .59972 .1639 .61226 .1592 .6059 .15066 Mtetra
.6059 .15066 .61226 .1592 .62485 .15447 .61853 .14589 Mtetra
.61853 .14589 .62485 .15447 .6375 .14973 .63122 .1411 Mtetra
.63122 .1411 .6375 .14973 .65021 .14497 .64396 .1363 Mtetra
.658 .753 .92 r
.64396 .1363 .65021 .14497 .66297 .1402 .65676 .13149 Mtetra
.65676 .13149 .66297 .1402 .67579 .13541 .66963 .12666 Mtetra
.66963 .12666 .67579 .13541 .68867 .13061 .68255 .12181 Mtetra
.68255 .12181 .68867 .13061 .70161 .12579 .69553 .11695 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018a000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
hGoo1000Pgoo003POol00`00Oomoo`02Ool00`00Oomoo`20Ool00>Eoo`03001oogoo081oo`00iGoo
00<007ooOol0P7oo003QOol40023Ool00>5oo`03001oogoo01]oo`8006Moo`00hGoo00<007ooOol0
6Goo0P0000=oo`000000IWoo003QOol5000DOol30003Ool2001VOol00?Qoo`800003Ool007oo00=o
o`03001oo`0006Eoo`00mGoo0`0017oo00D007ooOomoo`00009oo`03001oogoo069oo`00lWoo0`00
2goo00@007oo000006Aoo`00l7oo0P003Woo00D007ooOomoo`0006=oo`00kGoo0`0047oo00<007oo
Ool00Woo00<007ooOol0H7oo003[Ool2000COol00`00Oomoo`02Ool00`00Oomoo`1POol00>Qoo`<0
01Ioo`03001oogoo009oo`03001oogoo05moo`00iWoo0`0067oo00<007ooOol00goo00<007ooOol0
GWoo003SOol30003Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`1NOol00>5oo`8000Io
o`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo05eoo`00MWoo0P000Woo0P00HWoo0`0087oo
00<007ooOol017oo00<007ooOol0GGoo001gOol01000Oomoo`00HGoo0P008goo00<007ooOol01Goo
00<007ooOol0G7oo001hOol2001OOol3000UOol00`00Oomoo`06Ool00`00Oomoo`1KOol007Qoo`80
05aoo`<002Qoo`03001oogoo00Ioo`03001oogoo05]oo`00Mgoo00@007ooOol005Uoo`8002]oo`03
001oogoo00Moo`03001oogoo05Yoo`00MWoo0P000Woo0P00EGoo0`000Woo00<007ooOol0:7oo00<0
07ooOol01Woo0`00Fgoo003?Ool2000`Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00<aoo`<0039o
o`03001oogoo00Uoo`03001oogoo05Qoo`00bWoo0P00=Goo00<007ooOol02Woo00<007ooOol0Egoo
0037Ool3000gOol00`00Oomoo`0:Ool00`00Oomoo`1GOol00<Eoo`8003Yoo`03001oogoo00]oo`03
001oogoo00moo`D0049oo`00`Woo0`00?7oo00<007ooOol037oo00<007ooOol03Woo00D007ooOomo
o`00049oo`00`7oo0P000Woo00<007ooOol0>goo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@goo002mOol30012Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`12Ool0
0;Yoo`<004Eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo045oo`00^7oo0P00B7oo00<0
07ooOol03Goo00<007ooOol047oo00<007ooOol0@7oo002eOol3001:Ool00`00Oomoo`0>Ool00`00
Oomoo`0;Ool01@00Oomoogoo0000@Woo002cOol2001=Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool3
0013Ool008Ioo`@002Ioo`<004moo`03001oogoo00moo`03001oogoo055oo`00QGoo00<007ooOol0
0Woo00<007ooOol08Goo0P000Woo00<007ooOol0CGoo00<007ooOol03Goo0P0000=oo`00Ool0DGoo
0025Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3001DOol00`00Oomoo`0AOol00`00Oomoo`1?Ool0
08Eoo`03001oogoo009oo`03001oogoo01aoo`8005Moo`03001oogoo015oo`03001oogoo04moo`00
QGoo00<007ooOol00Woo00<007ooOol06Goo0`00FGoo00<007ooOol04Woo00<007ooOol0CWoo0025
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol2001LOol00`00Oomoo`0BOol00`00Oomoo`1>Ool008Eo
o`03001oogoo009oo`03001oogoo01Aoo`<005ioo`03001oogoo01=oo`03001oogoo04eoo`00QWoo
100057oo0`00HGoo00<007ooOol057oo00<007ooOol0C7oo002LOol20003Ool00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`1<Ool009Uoo`<0069oo`05D_eBo5;mD_`0000GOol00`00Oomoo`1;
Ool009Moo`8006=oo`=Bo005D_eBo5;lD_`0000GOol00`00Oomoo`1:Ool009Aoo`<006=oo`0:D_eB
o5;mD_aBoE;lD_eBo5;m000GOol00`00Oomoo`1:Ool0099oo`8006Aoo`03D_aBoE;l009Bo008D_eB
o5;lD_aBoE;l001Bo1Moo`03001oogoo04Uoo`00Sgoo0`00I7oo00mBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_d05Woo00<007oo0000BWoo002=Ool3001ROol00e;lD_eBo002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo000009Bo1Moo`03001oogoo04Qoo`00RWoo0`000goo00<007ooOol0GGoo
01MBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m01Moo`03001oogoo
04Moo`00Qgoo0`00Hgoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eB
o000D_aBo@02D_`GOol00`00Oomoo`16Ool008Eoo`80069oo`0PD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoAIoo`03001oogoo04Ioo`00
PWoo0`00HWoo00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo00000=Bo003D_eBo7oo01Ioo`03001oogoo04Eoo`00P7oo0P00Hgoo02EBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo00GOol00`00Oomoo`14Ool007eoo`<0065oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l00=BoE;lOol0
5Goo00<007ooOol0A7oo001kOol20002Ool00`00Oomoo`1MOol0;5;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_dGOol00`00Oomoo`13Ool007Qoo`<0069oo`9Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EB
oE;lD_aBo5;m01Moo`03001oogoo049oo`00MWoo0P00Hgoo039Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;m5Woo00<007ooOol0@Woo001cOol3001SOol01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo000D_aBo@03D_`015;mD_aBo5;l5goo00<007ooOol0@Goo001aOol2001ROol0>E;l
D_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo00EOol00`00
Ool00012Ool006ioo`<0069oo`05D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d0
05;lD_aBo@03D_`015;mD_aBo5;l5Woo00<007ooOol0@7oo001[Ool3001SOol0?TkLD_eBo5;mC]aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_dGOol00`00
Oomoo`0oOol006Uoo`8000=oo`03001oogoo05]oo`03D_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007oo
Ool0?goo001VOol3001OOol0BE;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01Ioo`03001oogoo03io
o`00I7oo0P00GWoo00E2Nd9l@Wa6W49k009>g006C_e>g4kLD_aBoDkl0U;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`FOol00`00
Oomoo`0mOol0065oo`<005moo`1@CK=Add9kAYa2NdJL@W]BoDkLD_e>g5;mC_aBoDkLD_e>o5;mC]aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oAEoo`03001oogoo02Eoo`<001Eoo`00=Goo10009Woo0P00HGoo00E=de7CCM=Add9k0092O006AYa2
Ne;lC_aBoDkL0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0EOol00`00Oomoo`0VOol00`00Oomoo`0COol003Ao
o`03001oogoo009oo`03001oogoo021oo`<0069oo`1CCK=AddfcDM==/e7CB[a>gD[LC]e:_5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo00FOol00`00Oomoo`0UOol00`00Oomoo`0COol003Uoo`03001oogoo
01ioo`80009oo`03001oogoo05moo`09CM=AddgCDM==de7CCM<004[L00A>g004D_a>o5;mC_`2D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo003D_eBo7oo01Aoo`03001oogoo02Aoo`03001oo`0001Aoo`00;7oo1P001goo00<007oo
Ool06goo0`00HGoo00]>g5;mA[a6gDJlDM==/e7CCK=Addfc0080001=C]e:_4kMB]a>gDkLD_e>g5;m
C]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBo@0FOol00`00Oomoo`0SOol00`00Ool0000DOol003Eoo`@001aoo`80069o
o`06C_e>g4kmC]a>oDJl0TJm00EAddgCDM==de7C00<00006C_e>g4kLC]a>oDkl0U;l00EBoDklD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d05Woo00<007ooOol08Goo00D007ooOomoo`0001=oo`00=Goo00<007ooOol06Woo
0`00H7oo069>g5;mC]aBoDkLD_e>g5;mC]aBoDJlA]e=/e7CCK=AddfcAYa2NdJL@W]BoDkLD_e>g5;m
C]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo0P008goo00D007ooOomoo`0001=oo`00=Goo00<007oo
Ool05goo0`00Ggoo00A>o4kLD_e>g09>o00ED_e>g4klC_a>gDkLC]e>g4JmA[aAddgCDM==de7C@W]6
W49k@Wa>g4km00=>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aB
o@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`0COol00`00Oomoo`0O
Ool3000017oo000000004Woo000eOol5000COol2001NOol0Jd[LC_e>g4kMB]aBoDkLD_e>g5;mC]aB
oDkLD_e>g4kMB]a>oD[LA[e=/e7CCK=AddfcAYa2NdJL@W]6W4kLD_e>g5;mC]aBoDkLD_e>o5;mC_aB
oE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`05Woo00<007ooOol0=goo001:Ool300000goo001oo`1HOol2H[L4=QX3C]`01TkM
C]a>o4kLD_e>g09>o007D_e>g4klC]a>gDkLC]d00TJm00E=de7CCM=AddgC00=>g008B]a>g4klD_e>
g5;lC_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003001BoE;l009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l5Goo00<007ooOol027oo1000:goo0018Ool2001M
Ool0LV:FI[MRUSHK=OXf6cHJC]e:g4kmC]a>gDkLD_e>g5;mC]aBoDkLD_e>g5;mB]a>gD[LC_e6_57C
CK=AddgCDM<004kMB]a>gDZlD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mC_aBoE;lD_eBo5;m
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAIoo`03001o
ogoo00Ioo`03001oogoo009oo`03001oogoo02Qoo`00AGoo0`00Ggoo16:g13HJ00I>oDkLC]a>g4km
C]`2C_`01e;mC]a>oDkLC_e>g4km0096_@06A[a6_DgCDM==de7C0P0000E:g4kLC]a>g4[L009Bo005
D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;l5Woo00<007ooOol01Goo00<007ooOol00Woo00<0
07ooOol0:7oo0013Ool2001QOol086JgHYIV]f:FI[M:_4[LB[a:gDZlD_e>g5;mC]aBoDkLD_e>g5;m
C]aBoDkLD_e>g4KMA[a6gDfcDM==/e7CCK<30000DDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo00FOol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0XOol0041oo`<0
069oo`ER]`9CT@A:_003C]a>oDkL009>g00:D_e>g4klC_aBoDkLC_e>g4kmC]`3A[d024JlDM==de7C
@W]2O49kAY`3C]`01DkmC]aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo1Ioo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo02Qoo`00?Woo0P00Ggoo07e>g4kmC]a:gDJlB]e6_6JgHYIV
]e=aEi5CL4[MB[a:g4ZlB]e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4kMA[a6gDJlDM==/e7CCM=6
W49kAYa2Ne;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Ioo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00>goo1000GWoo00E>gDkLC]e>g4kM009:g@03
B[a:gF:g009R]`9CT@05Ei5CTDkLC]a>g@03C]`01U;mC]a>o4kLD_e>g09>o00ED_e>g4kMC]a>gDJl
A[e=de7CCM=AddgCAYa2Nd9l@W]BoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003
D_eBo7oo01Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00>Goo0P0017oo00<0
07ooOol0F7oo08A>oD[LC]e:g4kmC]a>oDkLC_e6_4[MA[a:gF:FEi5RUVJg=QXf6cGjC_e>g4kMB]a>
oDkLD_e>g5;mC]aBoDkLD_e>g4kMB]a>oD[LA]e6_57CCM=AddfcDMA:g4kMB[a>gD[LD_e>g5;mC]aB
oDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`03Ool4000[Ool003Io
o`<005aoo`9NMP8jF`05?U/j>dkLC]a>g@03C]`01dkMC]a>gB8L9S`R72HL00=R]`@f6P9>g006C]e>
g4kLC_aBoDkL0Tkl00IBoDkLC_a>o4JmA[`3A[d01TgCDM==de7CCM<0009>g005B]a>g4kLD_e>o002
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l00000e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d04goo0P0000=oo`00Ool0<Woo000c
Ool3001NOol0<UifFUINMSXk?U`j>ciK>S]>oDkLC_e>g4kmB]a>gD[LC_dR72HmHYIV]f:FI[MRUSHK
=QXf6cGjD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4KMA[a6gDJlDM==/e7DCM<30000ET[LC]e:
_5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dEOol00`00Oomoo`0a
Ool0035oo`80061oo`ENMP=:_00;B]a:_4kLC]a>gDkLC]e>g4kMC]a>g@06H[L5B[`2C]`01TkmC]a>
g4klD_e>g09>o006C_e>g4kmC]a6_DJl0TJm00=AddgCDM<0100000M>g4kmC]a>g5;lD_e>o002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m000005;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d05Goo00<007ooOol0<7oo000^Ool3001Q
Ool0KeifFUINMUYFGWIKKe^?B[a:gDZlB]e>g4kmC]a>oDkLB]e6_4[MA[aV]f:FI[MRUVJgDg1CTDZl
B]e:_4[LC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLA]e6_4KMCM=AddfcDMA2NdJL@W]6W4kL
D_e>g5;mC_aBoDkLD_e>o5;mC]aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@03000075;mD_`005;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Woo00<007ooOol0
;goo000/Ool4001JOol01D[LC]e>g4kMB]`00dJm1Eif00=KSe]_B]`00dZl00I:g4kLC]e>g4kMC]`3
B]d01DZlH[MR]f:gDg000U>A1DZl00E>g4klC]aBoDkL009>o007D_e>g4klC]a>gDkLC]d00TJm00e=
de7CCM=AddgC@Wa2NdJL@W]2O4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@0300001U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo1Eoo`03001oogoo02moo`00:Woo0P00Fgoo07A6W4ZmA[a:_4[LC]e:g4kMB]a:gDJl
A]eJEUifFUIKSeM_Fi1KKdkMB]a>oD[LC]e>g4kmC]a>oDJlB]e6_4[MHYIV]f:FI[LenSHK=QY>gD[L
C_e>g4kMC]aBoDkLD_e>g5;mC]aBoDkLD_e:g4kMB]a>oDJlDM==/e7DCM=AddfcC]e:g4kMB[a>gDkL
D_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;m0`0002ABoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol00`00Oomoo`0^
Ool002Yoo`8005Yoo`03Bg5?LDJl0096_006B[a:g4kMC]a>gD[L0TJm0Uif00AKSeifGWHj>`8jF`0:
C]e>g4kLC]a>gDkLC]e>g4kMB[`3B]d3H[L4=QX01TkMC]a>g4kLC]e>g09>o00>D_e>g4klC_aBoDkL
C_a>g4kMC]a6_DgCDM==d`=Ad`09001>g4kLC]a:g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_eB
o0800005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m009Bo1Eoo`03001oogoo02ioo`0047oo1@000goo100017oo1000
1Woo00<007oo0000F7oo049;LDnBBg5:_4JLB[e6_4ZlB]a>gD[LC]e:g4[MA[aNMUYFGWIJESiK>S/n
G3XkC]e:g4kmB]a>gD[LC_e:g4kM8Q`V?B8LI[MRUVJgHYHf6cGj=Q/f6U;mC]aBoDkLD_e>g5;mC]aB
oDkLD_e>g5;mC]aBoDJlA]e6_57DCM=AddfcDM@20000;DZlC]e:g4kMB[aBoDkLD_e>g5;mD_aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo0030000:U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAEoo`03001oogoo02eoo`004Woo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`800003Ool007oo05Eoo`03
Bg5VebVi008Y^@0;C]e:g4[LB]a>gD[LB]e:g4kM0CP1>@05GWH01CiK>S/jFcYKC]d00dkL00I>gDkL
C]e>g2HL8Q`5H[L5B[`01TkmC]a>g4kLD_e>g09>o006D_e>g4kmC]a>oDkL0dJm00E6_57CDM=AddgC
00<000=>g006C_e>g5;lD_aBoDkl0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00IBoE;lD_aBo5;mD_`30003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005001Bo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo
01Eoo`03001oogoo02aoo`004Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03
001oogoo009oo`8000=oo`03001oogoo059oo`05;UaZefJfI]LUV002:KT0ITkMB[a>gD[LC]e:g4kM
B]a>gEYFGWIJEUifFUINMTZlB]e:_4[MB[a>oDkLC_e>g4kmB]a>oD[LI[MRUVJgHYIV]dm`Di5:_4[L
B[a:gDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>g4KMA[a6gDfcDMA=de7C@W]6W49kAYa>g5;m
C]aBoDkLD_e>o5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo0<0000aD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`05Goo00<0
07ooOol0;7oo0007Ool60005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0BWoo00A:g4[MB]a:g@@^G@03I[IVefJg00<Y^@03
B]a>gD[L009:g004A[e6_4JmA[d5GWH015M_Ffm:_4[L0TZl00M>g4kMC]a>gDkLC]e:_002B]d4H[L0
0e>@Dg1CL004B[`01dkLD_e>g4klC]aBoDkL009>o006D_e>g4kMC]a>gDJl0TJm00UAddgCDM=AddJL
@W]2O49kC_d00TkL00=>o5;mC]`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoE;l00000P000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00D005;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00=BoE;lOol057oo00<007ooOol0:goo000BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0AGoo0796_4:LA[e6W4JlB[a>
gD[LC]d^G39MI[IVefJfJ]MV]RVi9IPY^D[LC]e:g4kMB]a6gDJlB]e6_5ifFUINMUYFFhmGKT[MB[a:
gDZlB]e>g4kmC]a>oDkLB]e6_4[MA[aV]f:FDi5?L5>ACg1CTDkLC]e:g4kmC]aBoDkLD_e>g5;mC]aB
oDkLD_e:g4kmB]a>oDJlA]e=de7CCK=Ae4gCAYa2NdJL@W]BoDkLD_e>g5;mC]aBoDklD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_`30000>E;lDaeBo5;mD_aC7E;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Ool0000/Ool0019oo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool20006Ool20013Ool05000
5?H004JlAYa6_4JLB]e:g4[MB]a:gFJfI]MV]fKGI[IVedJlB[`2A[`014kLC]e:g4kM0TJm00=6_4Jm
GWH00Uif00AKKeM_FfmGK`9>g00;C]e>g4kLC]a>gDkLC]e>g4[MB[a:g@04H[L4=QX00dkLC]e>g002
C]`01U;mC]a>o4klD_e>g09>o006C]e>g4kMC]a6_DJl0e7C00E=de7CC]a>g4[L009>g005D_e>g5;l
C_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo000008000=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`0
0`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol0
0`00Oomoo`0ZOol0011oo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`0oOol0KcImK]IZeADFAYa6_4:LA[e6W4[MA[a:gDJlB]eV]V[GI[IV
ed]`Cg56_4ZlAYa:_D[LC]e:g4kMA[a6gDJlGWIJEU^?FUINMSXk?U/j>dkmB]a>gD[LC_e:g4kMB]a>
oD[L9SdR72HmHYIV]f:F=Q/f6SHK=OY>oDkLC]e:g4kmC]aBoDkLD_e>g5;mC]aBoDkLA]e6_4KMA[a6
gDfcDMA=de7CCM<004[LC]e:_4kMB]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo0030000@5;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m5Goo00<007ooOol0:Goo000BOol00`00Oomoo`03Ool40004Ool4
0005Ool00`00Oomoo`08Ool00`00Oomoo`0mOol02CImJ]IZeVkF4?HDmT[LB]e:_002B]`02T[MA[a:
gDJmI]MV]VKGI[LY^D]a0TJl00Y:_4JlA[a:g4kMB]a:g@4hA[e6_0=NMP05FWHnFcYK?U/j>`02C]`0
2DkMC]a>g4kLC]e>g4kM8Q`V7005H[L4=QX2C]`01TkmC]a>g4klD_e>g09>o006C_e>g4kmC]a6_DJl
0TJm00AAddgCDM=Ad`<00003C]a>oDkL009>g005D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00=BoE;l00000P000e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`FOol00`00Oomoo`0XOol002Qoo`03001oogoo00Yo
o`03001oogoo03Eoo`1bB[a:gDZlB]e:_3ZM=We^eV[EK_IZeQDF4?DE5TZlB]e:_4kMB[a:gDJlB]e6
_6KGI[IZefJf:KTUV4kMB]a>gDZlC]e:g4kMB]a>g@4H0CUJEUifFUINMUYFB]e:_4[MB[a>oDkLC_e>
g4kmB]a>gD[LC_eRUVJgHYIV]f:FI[M:_4[MB[a:g4ZlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6
_4KMA[a6gDJlDM==de7D@W]6W49kAYa>g5;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;m0P0004MBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l01Eoo`03001oogoo02Qoo`00:7oo0`002goo00<0
07ooOol0<7oo00UR]f:G<OX]nS7jB[a:gD[LB]d00SIm00=ZeVkFJ]H00V[F00PDmQ3f5?HDmT[MB]a:
gD[L12iM00=VefJfI]L00bVi0T[L00M>gD[LB]a:g4kMB]a:g@02GWH01EYfGWINMUM_Efh00TZl00I:
g4ZlC]a>g4kMC]`3B]d00dZlB]eR]`03H[L00dm`Dg1:_004B[`014klC]aBoDkL0Tkl00MBoDkLC_a>
g4kmC]a>o@02A[d02DJlA[eAde7CCM=2O49kAYa2N`02C]`01DkmC]a>g5;lD_d00e;l00EBoE;lD_aB
o5;m009Bo0<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`015;mD_aBo5;l5Goo00<007ooOol09goo000XOol0
0`00Oomoo`0<Ool00`00Oomoo`0^Ool08F:gHYIR]bgj<Q/]nT[MB[a:gDZlB]eZeFkfJ]I^eV[EK_I6
W4Jl@Ya6_DJLC]e:_4kMB]`^GBiLJ]MV]VKGI[IZe`02:KT0CRFHC]e:g4kMB]a>gDJlA]e6_5ifFUIN
MUYFGWIGKU]_B[a:gDZlB]e:_4kmC]a>oDkLB]e6_4[MA[aV]f:FI[M?L5>@Cg1CL4[LC_e>g4kMB]aB
oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>oDJlA]e=de7DCM=Add9kAYa2NdJL@W]BoDkLD_e>g5;mC_aB
oDkLD_e>o5;mC_aBo@<0001>D_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l5Goo00<0
07ooOol09Woo000XOol00`00Oomoo`0=Ool00`00Oomoo`0/Ool03F:gHYMR]f:GH[L]nS7j;OY:gDJl
B[e6_D[M00=ZeP0BK]HDmP00AYa6_4JLA[a:g4[MB]a:gD[LI]MV]VKGI[MVefJf0TJl00I:_4JlC]e>
g4kMB]`3A[d024JlGWINMUifEfiGKeM^Efl3C]`01dkMC]a>gDkLC]e>g4kM009:g@05B[aR]dm`H[MR
UP03=QX3C]`01TkMC]a>o4kLD_e>g09>o006D_e>g4klC]a>gDkL0TJm00=AddgCDM<00U7C00U:g4kL
C]a>g4[LD_a>o5;mC]`00U;l00=BoE;lD_`00`000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_aBo00EOol00`00Oomoo`0VOol002Qoo`8000moo`03001oogoo02Yoo`1]H[MRUV:g
HYIR]f:FB[e6W4ZmA[a:gDJlB]e6_6kFJ]E^mV[FK]H@mDJmAYa6_4:LA[e6_4[MA[a:gDJlI]MV]V[G
I[I;LDM@B[e6_4ZlAYa>gD[LC]e:g4[MA[a6gEYFGWIJEUif>S/nG3Xk?U]:g4kmB]a>gDkLC_e>g4kM
B]a>oB8L9SdR76JgHYIR]cGj=Q/f6TkMB]a>oDkLC]e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4KM
CM=AddgCDMA=d`00B[a>gD[LC]e:_5;mC]aBoDkLD_d00`0005EBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0EOol00`00Oomoo`0UOol002Qoo`03001oogoo00mo
o`03001oogoo02Eoo`0;A[a6_DJmA[e6_6:gHYMR]f:GFkAK/`04A[`01D[MA[a:_DJmK]H00f[F00hE
5QCfB]a:g4[MB[a:g4JmB]e6_4[MI[MVefJf0T]`00];LDJlA[a6_4ZlA[a:gD[LC]e:g04i0096_@08
FWINMUifGWHj>ciK>U]>g@=>g006C]e>g4kMC]a>gDkL0R8L00=R]f:FH[L00V:g0cHJ00I>oDkLC]a>
g4kmC]`2C_`01e;mC]a>oDkLC_e>g4km0096_@09A[aAde7CDM==de7C001>g4[L009>g003C_e>g5;l
00<0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
009Bo1Eoo`03001oogoo02Aoo`00:7oo00<007ooOol047oo00<007ooOol087oo02]7D4=@A[e2W4Jm
@[a6gDJlA[eRUV:gHYIOe5^cGmAK/dZmAYa:_DJlB]e6_4[MJ]I^eV[EK_H@mADF4?E>gDZlB]e:_4[M
A[a:gDJlB]eV]T]aI[IZe`02:KT0?4ZlC]e:g4kMB[a>gD[LC]e:g04i0AQNMUYFGWIJEUif>S/nG3Xk
C_e>g4kmC]a>oD[LC_e:g4kMB]aV]f:FH[MRUVJgHYI:g4ZlB]e:_5;mC]aBoDkLD_e>g5;mC]aBoDkL
D_e>g5;mC]a6gDJlA]e6_57DCM=Ad`<00003D_e>g5;m00<0001MD_e>g5;mC]aBoE;lD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m01=oo`8002Ioo`009goo
00<007ooOol04Woo00<007ooOol07Woo00=ZeQUGAe000dJL00=6_4JLA[d00TJm00ERUe^dHYMR]bgj
008anP04B]e:_4[MB]`2=Wd2J]H01VkFJ]IZeQCf5AHDmP9:g00:B]e:_4[MA[e:gDJl;UeV]fKGI[H3
:KT3B]`01TkMB]a:gD[LC]e:g0=NMP04FWINMUM^Efh3B[`01TkMC]a>g4kLC]e:_0=:g@05HYIR]f:g
H[MRUP02Cg04B[`01TkmC]a>g4kLD_e>g09>o006D_e>g4kmC]a>oDkL0dJm00I=de7CDM=Add9k@W`3
0002C]`01DkmD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00U;l57oo00<007ooOol08goo000WOol3000COol00`00Oomoo`0LOol0;V[G
I[IZeaUG7EQ6_4[MA[a:gDJl7Q`Io1hLHYIR]f:F<O/]nS8K;OY:gDZlB]e:_6kFJ]E^mV[FK]IZeADF
4?DE5Q3eC]e:g4kMB[`bGBiL;UeV]V[GI[IVefJf0bVi03Y:g4kMB]a>gD[LB]e6_4KMFUINMUYFGWIJ
EUM_Efi:gDZlB]e:_4kmC]a>oDkLC_e6_4[MA[a:gF:FI[MRUTm`CdmCL4ZlB]a:_4[MB[aBoDkLD_e>
g5;mC]aBoDkLD_e:g4kmB]a>oD[LA]e6_57CCM=Ae0<0001TAYa2NdJLC]aBoDkLD_e>g5;mC_aBoDkL
D_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`EOol0
0`00Oomoo`0ROol002Moo`03001oogoo01Aoo`03001oogoo01Yoo`0;;UeVeV[GI[HMF1UG7EQ6_4Zm
B[a:g@026O`01f:GH[MRUf:gHYLanRgj008anP05B]e6_4ZmA[e^eP03J]H04ADF0016_4JLA[a6W4[M
B]a:gD[LB]eV]fKGI[IVefJgI]L00dJl00I:_4[LC]e>g4kMA[`3A[d00eYfGWINMP04Efh02TkMC]a>
g4kLC]e>g4kMC]a:gDZl0T[M00AR]f:FH[MR]`<f6P03C]a>gDkL009>g006D_e>g4klC]aBoDkL0Tkl
00QBoDkLC]e>g4kMA[a6_E7C0P000U7C00=>g4[LC]`00dkL00=Bo4klD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aoo`0COol00`00
Oomoo`0ROol001Eoo`@000Aoo`@000Ioo`03001oogoo01Eoo`03001oogoo019oo`1^Hhm6_4JmA[a:
_BiL<WeV]V[GI[IZefJf7EPIEaeHA[a:gDJlB]eRUV:gHYIR]f:FH[M6_4ZmAYa:_DJlB]e6_4[MJ]I^
eV[EK]IZeQDF4?E6_DJLA[a2W4[MA[a:gDJlB]eV]VKGI[IZedM@Bg16W4ZmA[a:_4[LC]e:g4kMA[a:
gDJlGWIJEUifFUHnFcXk?U`j>dkMB]a>oD[LC_e>g4kmC]a:gDJlB]e6_6:gHYIV]cHJ=Q/enSHKC]a>
gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g0<0001ZCM=Ae4gCDM@004kMB[a>gD[LD_e>g5;m
C]aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_dEOol00`00Oomoo`0QOol001Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomo
o`03Ool00`00Oomoo`0FOol2000AOol01F>?HfiSSTJlA[d00TJl00]VeV[GI[IZeVKFJ]LIEaeH6ELM
F4Jl00=6_@04HYMR]f:GH[L2Fk<4A[`01TJmB]e6_4ZmJ]I^eP9ZeP035?HE5QCf009:g009B]e:_4[M
A[e:gDJlI]MV]fKG00=7D00:B[a6_4JlA[a:_4[LB]e:g4kM0AP2A[d02EifFUINMSYK?U/j>ciKC]a>
g@03C]`014kMB]a>gDkL0R8L0f:g00=RUV:g=QX00cHJ00=>g4kmC]`00TkL00QBoDkLC_a>o4kmC]a>
oDkL0`000TJm00A=de7CDM=Ad`80009>g005B]a>g4kLD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_`0
0003D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@0EOol00`00Oomo
o`0POol001Uoo`04001oogoo0004Ool00`00Oomoo`03Ool2000IOol00`00Oomoo`0>Ool0=f=^HhmS
KV>?A[a6_DJlA]eV]V[GI[IZed<_@e12W4Jm@Ya6_D:lA]e6_6:gHYIR]e^cFkAK/dZmA[a:_DJLB[e6
_4[MA[`jWF[FK]IZeADF5?DE5Q3eC]e:_4[MA[a:gDJlB]e6_6[GI[IVebVH008Y^@0`C]e:_4kMB]a>
gD[LC]e:g04i0AQNMUYFGWIJEUif>S/nFcXk?Ua>g4kmC]a>oDkLC]e:g4kmB]aR]f:FI[MRUV:gHYI:
gDZlB]a:_4[MC]aBoDkLD_e>g5;mC]aBoDkL0`0000U>g4KMA[a6gDgCDM==de7DCM<00`0006I>g5;m
C]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_dDOol00`00Oomoo`0POol000aoo`H000Moo`04001oogoo0004Ool0
0`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`0<Ool01UHEESDjFcYL>U/jG096_@08A[aZeVKF
J]MV]QeH@dm6_0=6W096_096_@0;H[MK/f:gHYLanRgjB]e:g4[MB[a:g@02=Wd3J]H01VkFJ]HDmQCf
5AI:_09:g009B]e6_4[MA[e:gBiMI]MV]fKG00<Y^@0:C]e:g4[LB]a>gD[LB]e:g5ifFUH3GWH015YF
B[a:_4[L0TZl00=>g4kMC]`00TkL00=:gDZlB]d00V:g00ERUV:gH[M?L4m?00A:_09>g004C_e>g4kL
C_`300001dklC_e>g4kmC]a6_DJl0096_@09DM==de7C@W]6W49k@Wa>g4km00=>g005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m009Bo003001BoE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00AB
oE;lD_aBo1Eoo`03001oogoo01moo`005Goo10000goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol06goo00<007ooOol00goo00@004:LA[e6_0=oo`0kE<1F=EHDFSDjFcYL>U]6gDJlA[e6_6[G
I[IZefJf7EPIEd[MA[a:gDJlB]dIo1hL6OaR]f:FH[L]nS7k;OY:gDZlB]e:_3ZM=We^eV[EK]IZeVkF
4?DE5QCe5AI:_4kMB]a>gBiL;Ud^G6KGI[IZefJf:KTYV002:KT0:4kMB[a>gD[LA]e6_4[MFUINMUYF
GWIJEUM^Ddi:gDZlB]e:_4[MC]a>oDkLC_e>g4[MA[a:gF:FH[MRUTm`Bdm?L4ZlB]e:_4[LB[aBoDkL
0`0007U>g5;mC]aBoDkLC_e:g4kmB]a6gDJlDMA=de7DCM=6W49kAYa2NdJLC]aBoDkLD_e>g5;mC]aB
oDklD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo00DOol00`00Oomoo`0OOol001Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
009oo`8001eoo`03001oogoo009oo`0?0016_DJlA[eD`7ooE<1F=EHEESEF5EHe>U/jG3YK00=6_@0;
;UeZeVKFJ]LIEaeH6EM:gDJlB[e:_0026O`01F:gHYMR]f:FH[L00S7j00D]nS7jB]a:gDZl009ZeP0E
K]IZeV[F5?H004JLA[a6W4JlB]a:gD[LB]e:g6KGI[MVefJfI]MV]dZl00=6_007C]e:g4kMC]a6_DJl
A[d00Uif00EJEUM^EfiGKUM>009>g007C]e>g4kLC]a>gDkLC]d00T[M00I:_6:gH[MR]f:FH[L2=QX3
C]`300000dkLD_e>g002C_`01e;mC]a>o4klC]e>g4kM0096_@05CM=Ade7CDM==d`03C]`024[LC]a>
o5;mC]aBo4klD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo004D_eBo5;lD_`DOol00`00Oomoo`0NOol001Eoo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo009oo`03001oogoo01eoo`03001oogoo00<0000dA[e2W4JmE<1Hh5HDFSEF5EHe
GfiSSdJlA[e6_39m;UaZefJfJ]MV]V[G6CLMF1UGB]e6_4[MA[aR]f:FH[MRUV:gHYI:_DJlB[e6W4Zm
A[a:gDJlK]IZeVkFJ]E^eQCe5AI2W4JmAY`2A[`0;T[MA[a:gDJlJ]MV]VKGI[I7L4M?B[a6W4ZmB]a>
gD[LC]e:g4KMA[aNMUYFGWIJEUif>S/nFcXkC_e:g4kMB]a>oDkLC_e>g4kmA[a:gDJlI[MRUV:gHYHj
6cHJ0`00085>g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oDJlDMA=de7DCM=Ae000C]e:_4kM
B[aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`057oo00<007ooOol07Goo000EOol50003Ool40005Ool0
0`00Oomoo`0NOol00`00MXe5D003?W`02T:m@YeF=EHEESEF5EHeEQESSV=^0TJl00i6_DJlJ]IVeV[G
I[IZeVKF7EPIEaeH6EM6_DJl0TJm00AR]f:FH[MRU`9K/`A6_004B[e6_D[MA[`4J]H011DF5?HE5TZl
0T[L00e:gDJlB]e6_D[MI[IVefJgAe17CdM@A[a:_002A[`01d[LC]e:g4[MB]a6_DJl00=NMP05FUHn
FcYK?U/jF`02C]`01dkMC]a>gDkLC]e:g4kM008R7003HYIR]f:g00<0008f6P=>g00?C_e>g4klC_aB
oDkLC_a>g4kmC]a>oDkLA[e6_4Jm009Ad`05CM=Ad`00001:g003C]`01D[LD_aBo5;mC_`00U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`02E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o003D_eBo5;l01=oo`8001moo`009Woo00<007ooOol05Woo00EO:TJm@Ya6_GJ=00=oo`05MXejSD4`
?W`nN`02?W`07d:m?YaJ=EHEESEF56>?GfiSSUm^A]e6_4JmA[aZefJfJ]MV]T=@?bm6_D:LA[e2W4Jm
@[a6gDJlH[MRUV:g009K/`0lEk=:_DJlB[e6W4[MA[a:gDJlK]IZeVkF4?DE5QCe5AI:_4kMB[a:gDJl
B]e6_4[MI[IVefJf:KTYV2ViB]a>gDZlC]e:g4kMB]a>g@4H0CUJEUifFUINMUYF?U`j>ciK>S]>oDkL
C_e>g4kmB]a>gD[LC_eRUV:g0P0001]RUV:gB[a:gDZlB]a>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>
g5;mA[a6gDgCDMA=de7DCM<00`0006Y>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eB
o5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03
001oogoo01aoo`009Goo00<007oo00005Woo0elZ00=6_DJlNXd00Woo00=fSGZ=00000TE@13il00Y2
_EHEESEF5EHeEQEF=CYK>U`jF`=6_@08A[aZeVKFJ]MV]QeH?bm6_0=6W007A[e6_4JmHYMR]f:FH[L0
0S7j00D]nT[MB]a:gDZl008fO@EZeP055?HE5QCfB]e:_002B]`01T[MA[a:gDJm;UeV]P9V]`<Y^@03
B]a>gD[L009:g003C]e:g4[M009NMP05FUINMUifEfiCCP02B[`01T[LB[a>g4kLC]e>g0=:g@<00005
H[MRUV:gBdm?K`04B[`3C]`02dkmC]a>o4klD_e>g4kmC]a>oDkLC_d00TJm00Q6_57CDM=Add9k@Wa2
NdJL0dkL00E>oDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00IBoE;lD_aBo5;m0002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`DOol00`00Oomoo`07Ool5000?Ool002Eo
o`8000Aoo`0340=oogoo011oo`1=HdYO:UlZGbY6_GJ=NXefSGZ=MXe5DD4`AE4004Jm@Ya6_DJlESEF
55XeEQEF=EHD?U`jFcYLA[a6gDJlA[eV]V[GI[IZefJf7EPIEd[MA[a:gDJl6Q`Io1hL6OaR]f:FH[L]
nS7k;OY:gDZlB]e:_6kFJ]I^eV[EK]IZeQDF4?DE5QCeC]e:_4kMB]`^GBiL;UeV]VKGI[IVe`02:KT0
62VH:KU:g4kMB[a>gDJlA]e6_5ifFUINMUYFGWICCEM^B[a:gDZlB]e:_4kmC]a>o@<0002>B]e6_6Jg
HYIR]d]?Cfm;Cd[LB[a:gDZlB]a>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e:g4KMA[aAe4gCDOA=ddJL
@W]6W49kAYa>g5;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomoo`07Ool01@00Oomo
ogoo00003goo000UOol00`00Oomoo`03Ool240<8Ool014:m@Ya2WGHV17oo00]O:TgCCM<jG3il>Uaj
SGJ=NXefSGZ=0095D00A@E000000A[e6_4JmEQEF=F=^ESEF5EHeEQDjG3YK>Ua6_003A[d02biMJ]IV
eV[G6ELMF1eGB]e6_4ZmB[`00QWl00AR]f:GH[MRUP<anP05;OY:_DJmB]e6_004J]H031DF0016_4JL
A[a6W4[MB]a:gD[LB]eV]P9V]`05I]MV]VJgA[a:_002A[`014kLC]e:g4kM0TJm00Q6_5ifGWINMU=>
EdiCCUM^0dkL00I>g@00000004kMC]`3B]d016:FH[MR]f:g0cHJ00Y>gDkLC]a>g4kMC]a>o4kLD_e>
g09>o007D_e>g4kMC]a>gDkLA[d00U7C00E=de7CDM=>g4[L00A>g004D_a>o5;mC]`2D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`00e;mD_aoo`0COol00`00Oomoo`07Ool00`00Oomoo`0@Ool002Eoo`03001oogoo009oo`03
40<<0a0300Moo`06IoISeD:m@Yaf9W860Woo00if9UlZDM==/cil>U/nO7J=NXefSGZ=MXe5DD4`1000
0556_D:LA[eF5EHeEQAJ=EHEESEOKDZmA[a6_BiL<Wd^G6[GI[IZefJfJ]LI=aeHA[a:gDJlB]e6_6:g
HYIR]f:FH[MRUTZmA[a:_DJLB]e6_4[MA[a^eV[FK]IZeADF5?E6_4:LA[e6W4[MA[a:gDJlB]eV]VKG
I[IVed<_Ae16_4ZlAYa>gD[LC]e:g4kMA[a6gEYFGWICCEifFUHnG3Xk?U/00`0009I>gDkLC_e>g4km
C]a:gDJlB]eRUVJgHYHf6cGj>Q/f6TkMB]a>oDkLC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e6_57d
CM=Ae4gCDO@004kMB[a>gDZlD_e>g5;mC]aBoDkLD_eBo5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;m
D_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`DOol00`00Oomo
o`07Ool00`00Oomoo`0?Ool002Eoo`8000=oo`<@0`Ioo`EWe@05@Yaf9WHVMRIf1P02CM<02U7CCM=6
_DJlNXefSGZ=MXejSD5@0TE@13il00U2_D:MESEF5EHeEQEF=Em^Hfh00dJl00]6_DJlJ]IVeV[GI[IZ
eVKF7EPIEaeH0096_@09A[a6_DJmH[MRUV:gHYMK/eNc00A6_003B[e6_D[M00AZeP055?HE5QCfB]e:
_002B]`01d[MA[a:gDJmI]MV]VJg008Y^@0:@dm6_4JlB[a6_4[MB]a>gD[LB]d2A[d015YFGWINMUif
0`0000Y>gDkLC]a>g4kMB]a>gDkLC]e:g08R7004H[MRUV:gH[L4=QX01TkmC]a>g4kLC_e>g09>o006
D_e>g4kmC]a>oDkL0dJm00==de7CDM<00U7C00@004kLC]a:g09>g005D_e>o5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`00e;mOomoo`0BOol00`00Oomoo`08Ool00`00Oomoo`0>Ool002Eoo`05001oogooOol<
0`0340<5Ool0<6OfGWIRUbgj<Q/]nRhKLPEf9W86GbY=/e7CCK=Ade/9A[efSGZ=MXejS@00AE51<4EA
@E0nO3ik?W`nW4:m?YaJ=EHEESEF56>>GfiSSTJlA]e6_4JmA[aZefJfJ]MV]P80000WA[e2W4JmA[a6
_D:lA]eRUV:gHYIK/eNbFk=GTTZmA[a:_DJlB]e6_4[MJ]E^eV[F5AHDmADF5?E:gDZlC]e6_4[MA[a:
gDJlI]MV]VKG008Y^@0<:KQ>gD[LC]e:_4kMB]a>gD[L0CT165if0`0002aNMSXk?U`j>dkmC]a>oDkL
C_e:g4kmB]a>gD[LI[MRUV:gHYIV]dZlB]a:_4[MB[aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDJl
A]e6_57DCM=Am4gC0`0006i>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m57oo
00<007ooOol027oo00<007ooOol03Goo000UOol00`00Oomoo`0240<2K]@04Sil?Y`nO05j0ET1NP5I
GYMNUUjG;OX^6bgkMRIf1WHVCM=Ad`9=d`9O:P05@[ajSGJ=NXefS@06AE03?W`02d:M@[eF5EHeEQEF
=EHE>U`jFcYLA[`00dJm00QV]V[FI]IZeaeG0016W4Jl0TJL0TJm00E6_4JmHYMR]f:F00<anP04;OY:
gD[LB]d3=Wd4J]H03QDF5?HE5QCfB]e:_4[LA[e:gDJlB]eV]fKGI[H4:KT2B]`01DkMB]a:gD[LC]d0
0`0000ENMUYFGWICCE=>00=:_006C]e>g4kLC]a>gDJl0d[M00I6_6:gH[MR]d]>Bdl4B[`01dkLC_e>
g4klC]aBoDkL009>o006C_e>g4kmC]a>oDJl0TJm157C00E6W49k@Wa>g4km00=>g005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`EOol00`00Oomoo`03Ool01@00Oomoogoo00003goo000TOol0A@00Oomo
ogoo=We^]7;DK[Abe3il?Y`nO05j0EURUeifHYMNMRhK;OXb6g86MRIO:U7CCK=AddfcGbYO:ElZMXej
SGJ=NXe1<4EA@E15DD4`AE4004Jm@Ya6_CjLESEF55XeEQEF=CYK?U`jFciL>U]6gDJlA[eV]V[GI[IZ
eaUG7EQ6_4[MA[a:g@036O`08AhLHYIR]f:F<Q/]nS7kB[a:gDZlB]e:_6kFJ]I^eV[EK]I6W4Jl@Ya6
_DJLC]e:_4kM;U`^GBiLI]MV]VKGI[H]^@02:KT012VhC]e:g4kM0`000:A6gEYFGWIJEUifFUIGKU==
B]e:_4[MB[a>oDkLC_e>g4kmA[a:gDJlB]eRUVJgHYI;Cd]>Cfm:_4[LB[a:gDkLD_e>g5;mC]aBoDkL
D_e>g4kmB]a>oD[LC_e6_4KMCM=Ae4gCDOA2NdJL@W]6W4kLD_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l57oo00<007ooOol017oo0`0047oo000TOol300005CImK]A^e6kDL]A^e00;?W`n
W3ilGYMNUUjGGWINUejF@[e2W4:MMRIAd`03CM<02UlZCM<jG3YLNXefSGZ=MXe5D45@0TE@00e5DDE@
0016_4JmA[a6_EHEESEF5EHeEQEF=@03A[`01TJmA[`^GBiM<UeV]P9VeP077EPMEaeHB[a:gDJlB[d0
0QWl00ERUV:gHYMR]bgj00<anP05A[a:_DJmB]e6_003J]H011Cf0016W4Jl0TJL00M:g4[MB]a:gD[L
I]MV]P02I[L01VKGA[a6_4JlB[a6_0800003C]e:g4Jm0096_@04FUINMUifDdh3Ddd02TkMC]a>g4kL
C]e>g4kMC]a>gDJl0d[M00=RUV:gH[L00cHJ00=>g4kMC]`00TkL00IBoDkLC_a>g5;mC]`2C_`01TkM
C]a>gDkLA[e6_0EAd`9>g008B]a>g4klD_e>g5;lC_aBo@=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;l001Bo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`A
Ool200000goo001oo`0GOol002Aoo`0X000bO3Im<Webe6jdL]A^]7;D00X02cjL@[dnW6:GGWIRUeif
IoESeD:m@YaSBTfcDM==/e7CCK=Addfc?WafSGZ=MXd0044`AE51<4EA@E030000?cjL@[dnW4:mEQEF
=EHDFSEF5F=^A[a:_DJlA[d^G39mI[IZefJfJ]MV]QeH6ELMF4JlB]e6_4[MHYIR]f:FH[MRUV:gAYa:
_DJlB[e6_4[MA[a:gF[EK]IZeVkF5?DI5TJLA[a2W4JmA[a:gDJlB]e6_6KGI[IVed<^@dm6W0030000
Zd[LC]e:g4kMB]a:gDJlGWIJEUifFUHnFcXk?U`j>dkMB]a>oD[LC]e:g4kmB]a>gB8L8SdR76:gHYIV
]cHJ=Q/enSXKC]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e:g4KMCM=Am4gCDMA=d`00B[a>
gDZlC]e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0EOol0
01Yoo`@000Ioo`03001oocIm009^e004L]A^e6kDK]@200/024:M?Ye2_EifGYMNUVOEHmD2ImD01D:m
@Y`nWDgCDM<00dgC00IAddgCNXefSGZ=@E02AE0014EAAE15D4E@0cil00M2WD:m@YeF=EHEESEF5@02
Gfh01V=^A[a6_4JlA[eV]P9VeP05J]MV]VKFAYa6_002AY`2A[d024JlA[eRUf:gHYIR]eNbEk<5A[`0
0dZmA[e:g@03J]H03QDF5?HE5T[LB]e:_4[LA[e:gDJlB]eV]fKGI[H30003A[`01TZlB]a:gD[LC]e:
g096_@09GWIJEUifGWHnFcYK?U/jFdkM00=>g004C]e:g4kMC]`28Q`3H[L00f:FH[Lf6P03=QX01dkL
C_e>g4kLC_aBoDkL009>o004C_e>g4kmC]`4A[d4DM<300001dkLC_e>g4kLD_aBoDkl009Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_`COol00`00Oomoo`0EOol001Uoo`03001oogoo009o
o`03001oogoo00=oo`0Y001oogooK[Abe6jdL]A^]7;D00X02`0:@[dnW4:mGWIWmEifHYL]nS8K;OXn
WCZLDM==/e7CCK=Ae4fcDM=fSGZ=MXe5DD4`AE51D4EA@C15D@02?W`053ik?W`nW4:mEQAJ=EHEESEO
KF=^GfeSKTJlA]e6_4JmI[IZefJfJ]L200008d:LA[e2W4JmA[a6_D:lH[MRUV:gHYIR]bgj<OY:_4[M
B[a:gCIl>YdfOFkFJ]E^eQCf5AHDmATFB[a:gDZlC]e6_4[MA[`00`000;9V]Rfi:KTY^DZlC]e:g4kM
B]a>gD[LC]d1604iFUINMUYFGWIJET[MB[a>gDZlC_e>g4kmC]a>gD[LC_e:g6:gHYIV]f:FH[MRUT[M
B[a:g4ZlB]e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4KMA[aAm4gCDMA=de7d@W]6W49kAYa>g5;m
C]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoAAoo`03001oogoo01Aoo`006Goo
00<007ooOol00Woo00<007ooOol00goo0P000Woo0fkD015be7ooOolnO3jL?W`1NP5IGYMNMUjGGYH^
6bgj;Q/]ncjM00==d`07DM==ddgCGbUjSGJ=NXd01DE@0195DDE@AE56_4JmA[a6_D:MESEF5EHeEQEF
=CYK>U`jFcYLA[`2A[d01V[GI[IVeVJf7EP00096W003A[a6W4JL0096_@05A[aR]f:GH[MRUP03<OX0
14ZlB]e:g4[M0SIm16[F0QDF00DDmQDFB]a:gD[L00<00004;UeV]fJgI]L4:KT02D[LC]a:g4kMB]a:
gD[LC]eJEP03GWH015YFDdeCCD[L0TZl00=>g4kMC]`00TkL00I:gDJlB]e:gF:gHYH2H[L2Bdh5B[`0
0dkLD_e>g002C_`01e;mC]a>o4klC_e>g4km00A6_@=Ad`04@Wa2NdJL@W/2C]`01DkmC]aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00UBoE;lD_aBo5;mD_`005;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00DOol00`00Oomoo`0COol001Uoo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`03L]A^]7oo00=oo`0m?YdnO3jL?WaRUeifHYMNMV:G
GWHb6bgj<Q/nW57CCK=Ae4fcDM==/e7DMXejSGJ=AE51<4EA@C15DDE@AE51D000A[a6_D:L@[eF5EHe
EQAJ=EHEESDjFciL>U/nG4JlA]e6_6[GI[IZefJf7EPIEd[MA[a:gDJlB]d00aWl01AR]f:FH[MRUS8K
;OY:gDZlB]e:_4[MJ]E^eV[FK]IZeDJmAYa6_4:L0`0000Y:_4kM;U`^GFJfI]MV]VKG:KP]^@8Y^@2]
B]a>gD[LC]e6_4[MA[aNMUYFGWIJEUifCdeCCTZlB]e:_4kMC]a>oDkLC_e>g4[MA[a:gF:FH[MRUT]?
Adi;CdL^C_e>g4kMB]a>oDkLD_e>g5;mC]aBoDkLD_e>g4kmB]a>oDJlA]e=de7dCM=Am49kAYa2NdJL
@W]BoDkLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00DOol00`00Oomoo`0C
Ool001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Uoo`08@YdnWD:m?YeNUejFGYMN
MP9Se@05@[e2W4:MCM=Ad`03CM<01U7CCM=jSGJ=0011D095D005AE55D4EAAE15D@0300002DJmA[a2
_EHEESEF5EHeEQEF=@03A[`03TJm;Ud^GBiMJ]MV]VKF7ELMF1eGB[e:_4[MA[`26O`01F:gHYIRUf:G
H[L00c7j00E:gDJlB[e6_D[M00=ZeP035AHDmP0000800009AYa:gD[LB]e:g4[MI[MVefJf009V]`0:
B[a6_4JlA[a:_4[LC]e>g4JmA[`2A[d02EifFUINMUif?U/jFciKC]a>g@03C]`02dkMC]a>gDkLB]e6
_4[MH[M;CV:FH[L00cHJ0TkL00I>gDkLC_a>g5;mC]`2C_`01U;mC]a>o4kLC]e>g096_@AAd`03DMA:
g4kL009>g005B]aBo4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0
4goo00<007ooOol04Woo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`09Ool07P0;
@[dnW4:mGWIRUeifHYMSe6OeHmA2_D:L?[e=/e7CCK=Ae4fcNXefSGZ=@C15DD4`AE51D4EA@E15D@8n
O00]?W/nO3il@[dnW5XeEQEF=EHDFSEOKEm^A[a:_DJl<Wd^G6[GI[IZefJfJ]LIEaeH6ELMF4JlB]e6
_6:gHYIR]f:FH[MGTUNbAYa:_DJlB]e6_4[MA[a^eV[E00<000315?DI5TJLA[a2W4[MA[a:gDJlB]eV
]VKGI[I3Ccl^B[a6W4ZmA[a:_4[LC]e:g4KMA[a:gEYFGWIJEUif>S/nFcXk?Ua:g4kMB]a>oD[LC]e:
g4kmB]`R7B8L8SeRUV:gHYHj6cHJ=Q]:g4kmC]a>gD[LD_e>g5;mC]aBoDkLD_e>g5;mA[a6gDJlA]e=
de7DCM=Am4gC001:_4kMB[a>gDZlD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`057oo00<007ooOol04Goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool2000:Ool300/0
2cjM@[eNMUjGHmENUeif;Q/]nd:m@Y`00TgC00IAddgCCM=fSGZ=MXd2AE001dEAAE15D4E@AE55D4EA
00@nO007@Ye2_D:MESEF5EHeEQD00Um]00YOKTJlA[a6_6[GI[IVeVJfJ]MV]P96W003A[a6W4JL0096
_@07A[aRUf:GH[MGTUNbEi8014Jl00=:gDJl00000P000V[F0QDF00TDmQDFB]a:gDZlB]e6_D[MA[`0
0VJg00mVefJf:KTY^DkMB]a>g4[LC]e:g4[MB]`164JlA[d00Uif00QJEUif>U/nFcYK?U]>g4kM0dkL
00=>gD[LC]d00R8L00ERUV:gHYMR]f:F00<f6P=>g00;C_e>g4klC_aBoDkLC_e>g4kmC]a>o@03A[d2
DM<00e7DDM<000020003C]`01TkmC]aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;m001Bo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`00e;mD_aoo`0BOol00`00Oomoo`0AOol001Yoo`@000Eoo`03001oogoo00Yoo`17?Y`nO3jM?YaR
UeifHYMNMV:G;OXb6bgj?Ye=/e7DCK=AddfcNXefSGZ=@C15DD5@AE51<4EAAE15DD5@AG55D3il?W/n
O3jL@[eF55XeEQEF=EHD?U`jFciLA[a6gDJlJ]MV]V[GI[IZeaUGA[e2W4Jm@Ya6gDJlA[eRUV:gHYIR
]ejF<Q/]nT[MB[a:g@020000b3Il>YeZeVkFJ]E^eQCf6AHDmDkMB[a:gDZlB]e6_4[MA[aVefJfI]LY
^2fi:KU>gDZlC]e:g4kMB]a>gD[LC]eJEUifFUINMUYFC]e:_4[MB[a>gDkLC_e>g4kmB]a>gD[LC_eR
UV:gHYIV]f:FBdi7;T[MB[a:g4kLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e6_4KMCM=Am4gCDOA2
NdJL@W]6W4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_dB
Ool3000BOol000Eoo`800003Ool0000001Uoo`03001oogoo00Yoo`0>?W`nW3il0EX1FEjGGWINUejF
GYL]nRhK?YeAd`==d`06DM=fSGZ=MXe5D45@0TE@01I5DDE@AE55D4EAAE15D@00A[e6_4Jm@YeF=EHE
ESEF5EHe>U/jG3YKA[e6_096_@0:J]MV]VKFI[HMF1eG7EQ6W4JlAY`3A[d016:FHYMRUf:g0S7j0`00
00A:gD[L=WdfO@AZeP<E5P055?I:gD[LB]e:g003;Ud016JfI[MV]fKG0bVi00I>gD[LC]a:g4JmA[`2
A[d01UifFUINMUifDde?C@9:_007B]a:_4ZlC]a>gDkLC]d00T[M00Q6_4[MHYMR]f:FAdi7;T]>14Zl
00E>g4klC]aBoDkL009>o006D_e>g4kMC]a>gDkL0dJm0e7C00U6W49k@Wa2NdJLC]aBo4klD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;lD_aBo@000U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d04goo00<007ooOol047oo0004
Ool00`00Oomoo`02000JOol00`00Oomoo`0;Ool0@3il?Y`nO6:GGWIRUeifHYMNMS8K;OXb6cjLDM==
/e7DCK=jSGJ=AE51<4EA@C15DD5@AE51D4EAAE15DD5@0016_4Jm@YaM05HEESEF55XeEQEF=CYK?U`j
FdJmA[a6gDJlJ]MV]V[GI[HMF1UG7EQ6_4[MA[`J71WlH[MNUV:g0`000<lb6bgjB]e:_4[MB[a^eV[E
K]IZeQTF0016_DJLA[a2W4kMB]a>gBYL;UeV]VKGI[IVefJf:KTY^2fi:KU>gD[LC]e:g4KMA[a:gDJl
GWIJEUifCbaCCDl/C_e:g4kMB]a>oDkLC_e>g4[MA[a:gDJlI[MRUV:gHYHj6cHJ=Q]:g4kmC]a>gDkL
D_e>g5;mC]aBoDkLD_e>g4kmB]a>oD[LA]e=de7dCM=Am4gCC]e:_4kMB[a>gDkLD_e>g5;mC]aBoE;l
D_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d04goo00<007ooOol03goo0004Ool0
1@00Oomoogoo00006Goo0`003Goo00LnWD:mGWINUejFGYMNMP02HmD01D:m@Y`nWDgCDM<00TgC00=f
SGZ=@E000TE@00Q5DDE@AE15D4EAAE15DDE@0`0000Y6_4JmA[a2_EHEESEF5EHeEQEOK@=6_0<^G@0<
I[IZefJfI]HMEaeH7EM:_DZlB]e6_6:G0`000V:G14Jl00A:gDJlB[e6_@AZeP8E5P96W006A[a6W4[M
B]a:gFJf0VJg00EVefJf000004Zl00=6_007C]e:g4kMC]a6_DJlA[d00Uif00EJEUif>U/nFcYK009>
g006C]e>g4kMC]a>gDkL0d[M00A6_6:gHYMR]`@f6P=>g006C]e>g4klC_aBoDkL0Tkl00IBoDkLC]e>
g4kMA[d2DM<01U7DDM=Ad`00C]a:g09>g005D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m01=oo`03001oogoo00ioo`0017oo00D007ooOomoo`0001Uoo`03
001oogoo00eoo`0i@[dnW4:mGWIRUeifImESe6OEHmAWeCZLDMA=/e7CCK=jSGJ=AE51<4EA@E15DD4`
AE55D4EA@E15LDE@?W`nNcil?Ya2_EHDFSEF5EHeEQAOKU]=A[e6_4ZmA[a6_FJfJ]MV]V[GI[IZeaeG
7EPIEdKM00<0003FH[MRUV:gGYIG/U>BB[e6W4ZmA[a:gDJlB]eZeVkFJ[E^eQCf6AHDmDkMB[a:gDZl
B]e6_4[MI[IVefJfI]LY^000A[a:_4JLB[e6_4kMB]a>gD[L0AQ6_4[MFUINMUYF?U`j>ciKB]a>oD[L
C]e:g4kmB]a>gD[L8SdR76:gHYIV]f:FH[Lf6SXK=QXf6dkLD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkL
A]e6_4KMCM=Am4gCDOA=d`00B[a>gDZlC]e:_5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`COol00`00Oomoo`0>Ool000Aoo`05001oogooOol0000IOol00`00
Oomoo`0>Ool034:M?YeNUeifGYMSeEjGGWH^6bgk;Q/nW@9=d`03DM=fSGZ=00E5D007AE55D4EAAE15
DDE@AE400cil00Q2_D:M@[eF5EHeEQEF=Em=0Um]00=6_DJlA[d00TJm00AV]VKFI[IZe`D000=6_@03
HYIRUf:G00AGTPA6_003B]e6_4Zm00=ZeP@E5P9:g006B]e6_4[MA[e:gFJf0VJg00]VebVi:KU:g4kM
B]a>g4[LC]e:g4[M00816008FUINMUifGWIJESiK>U/nF`=>g00<C]e>g4kMC]a>gD[LH[MRUf:gHYIR
]f:G1DZl0dkL00U>oDkLC_a>o5;mC]a>oDkLC_d00dJm00AAe57CDM=Ad`<00003C]a>oDkL009>g005
D_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo1=oo`03001o
ogoo00eoo`000goo0P000Woo0P006Goo00<007ooOol03goo01e2_CjLHYL1FF:GGWIRUbgj<Q/]nSjM
CK=Ae4gCNXd004EA@C15DD4`AE55D4EA@E15LDE@AE55D4Ea008nO00B?W]2_CjLESEF55XeEQEF=CYK
?U`jFdJmA[a6gDJlJ]MV]V[G0`0001E6_D:LA[e2W4KMA[a6_EjFEk9RUV:g;OXb6bgjB]e:_4[MB[`f
WCIlK]H00V[F0<MZ]ATF5?HI5QCeC]e:_4[MA[a:gDJlB]eV]VKGI[H]^BVh;KU:g4kMB[a>gD[LC]e:
g4kMFUINMUYFGWIJEU==Cba>gDZlB]e>g4kmC]a>oDkLB]e6_4[MA[aV]f:FH[MRUTM>Abe:g4ZlB]e:
_4[LC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a6gDJlDOA=de7dCM=6W49kAYa>g5;mC]aBoDkLD_e>
g5;mC_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d0
05;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo00COol00`00Oomo
o`0<Ool0029oo`80015oo`81F@09GYMNMUjGGYINUbgj;Q/nWE7C009=d`03MXdnWD5@0095D006AE55
D4EAAE15DDE@0dEA0195D000A[a6_DJl@[eF5EHeEQEF=EHE>U`jFcYL>U/jG4JlA[d3000026KFI[HM
F1eGB[e:_4[MA[`36O`00f:FHYMRU`03<OX01D[LB]e:_4[MB]`01F[F0dJL00E6_4JLB]e:g4[M008^
G@03I[MVefJf009V]`<Y^@07C]a>gD[LC]e>g4JmA[`00eif00AJEUifCba?C@=:_006B]a>g4kMC]a>
gDkL0d[M00ERUV:gHYM7;TL]0097;P0:C]e>g4kLC]a>gDkLC_a>g5;mC]`2C_`01E;mC]a>gDkLC]d0
0TJm00iAde7DDM=Add9kAYa2Nd9lC_aBoDkLD_a>o5;m0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo003D_eBo5;l01=oo`03001oogoo00aoo`008Woo00<007ooOol04Goo02UR
UeifHYMNMV:GHmASeD:L?[e=/e7CCK=jSCZMAE5=/dEA@E15DD5@AE55D4EA@E15LDE@AG4004JmA[a6
_D:LFSEF5EHeEQAJ=EHEA[e6_4Zm00<0003U<Wd^GF[GI[IZeaeG7EPIEd[MA[a:gAGl6QaRUV:gGYIR
]f:F<OX]nS8KA[a:gDJlB]e6_6[FJ[E^eQCf6AI2W4JmAYa6_4ZlC]e:g4kMI[IVefJfI]MV]VKGA[a:
_4JLB[e:g4kMB]a>gDJlA]e6_5ifFUINMTl/Dde?;5==B]a>oD[LC]e>g4kmC]a>oDkLB]e6_4[MHYI7
CV:FH[Lf6SXK=QY>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4KMA[aAm4gCDOA=de7dB[a>
gDZlC]e>g5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d04goo00<007ooOol02goo000QOol00`00Oomoo`0COol00ejGGYINU`03Hm@02D:m@Ya=ddgC
DM=fSCjMAE0nW@03AE001dEAAE15DDE@AE55D4EA00<0000:@[e2WD:m@YeF=EHEESEF5Em]Gdd20002
A[`2;Ud036KFI[IZefJfI]HMEaeH7EM:_DZlB]eRUP9RU`04H[MRUUNBDi43A[`014JmB]e6_4Zm16[F
00<E5QTF5AH00TJL0TJl00A:gDJmB]eV]P9V]`05I]L00000A[a:_003A[`00dkMB]a>g@02A[d025YF
GWI?;5ifFUHnFcYK?U/3C]`01TkMC]a>gDkLC]e:g0<R7003HYIR]f:G00<f6P03C]a>gDkL009>g006
D_e>g4klC_aBoDkL0Tkl00=BoDJmA[d00TJm0e7C00=Ae57C00000TkL00E:g4kLD_aBoDkl009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol04Woo0P0037oo
000QOol00`00Ool0000COol00eifHYMNMP02Ool05C8K;OY2_D:L?[e=dgZ=>Ya5DCZMAE51<4EAAE15
DD5@AG55D4EaAE19L@02?W`01cik@[dnW4:mEQAJ=EHE00<0001]FdaOKDJlB[e6_6[GI[IZefJfJ]MV
]TJm@Ya6_D:LA]e6_4JmGYIR]f:FEi9CTENbA[a:_DJLB[e6_4[MA[a:gCImJ]IZ]ATF5?HI5QCeC]e:
_4[MA[a:gDJlI]MV]VKGI[IVebVh;KU:g4kMB[a>gD[LC]e:g4kMA[a6gEYFGWIJEUif>S/nFcXk?U]>
g4kmC]a>oDkLC_e:g4kM7Q`R?F:FH[MRUV:gHYHj6cHJ>Q]>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_e>
g5;mA[a6gDJlDOA=de7dCM<00`0007]>g5;mC]aBoDkLD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eB
o5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`04goo00<007ooOol02Woo000QOol2000EOol01eif
Oomoogoo;OX^6bgk008nW@9=d`0:AE11D3jMAE15DDE@AE55D4EAAE05AE44?W`02d:M00000000GdeF
=EHE>U`jFcYLA[`00TJm00IZefJfI]IV]QeH0002AY`2A[`2A[d01F:gHYIRUf:GH[L00S7j00E:g4[M
B[a:gD[L008fO@AZeP8E5P0:6AI:_4[LB]a:gDJlB]e6_FKGI[H2I[L3:KT024[LC]e:g4kLB]a>gD[L
B]d2GWH015YFGWINMUif0dZl00i:g4kLC]a>g4kMC]a>gDkLC]eRUV:gHYMR]f:F0TL]0dZl00=>g4km
C]`00TkL00UBoDkLC_a>o4kmC]a>oDkLC_d00TJm00YAde7DDM=Add9kAYa2Nd9lC]a>o@9>g003D_aB
oE;l009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol0
4Goo0P002goo000?Ool40004Ool40006Ool00`00Oomoo`0IOol05bgj<Q/]nSjMCK=Ae44`AE4jW4EA
@E15DD5@AE55D4EAAE15LDE@AG55D000A[`00`0002PnW5HeEQAJ=EHEESDjFciL>U]6_DJlA]eV]V[G
I[IZefJf7EPMEdJm@Ya6_D:lA]e6_6:gGYIR]f:F<OX]nS8KB[a:gDZlB]dfOCJMJ[E^eP9ZeP395?DI
5QCf6AI:_4kMB]a>gBYL;UdZG6KGI[IVefJf;KTY^4kMB]a>gDZlC]e6_4KMA[aNMUYFGWIJEUifCba?
C4ZlC]e:_4[MC]a>oDkLC_e>g4[MA[a:gF:FH[MRUTL^@be7;TZlB]a:_4[MC]aBoDkLD_e>g5;mC]aB
oDkLC_e:g4kmB]a6gDJlA]e=de7dCM=6W49kAYa2Ne;mC]aBoDkLD_e>o5;mC]aBoE;lD_e>o5;mD_aB
oE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00ioo`<00003Ool007oo00Yoo`00
3Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo01Uoo`09@[e2W4:M
?YeAddgCAE1=dcjM00=5D006AE55D4EAAE15DDE@0TEA0`0001Y6_4JmA[a2_EHEGfeF5EHeEQEF=CYK
>U`jFdJmA[a6_BiMJ]MV]VKF7ELMF1eGB[e:_4[M0QWl00=RUf:gHYH00V:G0c7j00A:g4[MB[a:g@AZ
eP035AH004JL0096W004A[a:g4[MB]`2;Ud3I[L00fJfI[LY^@02:KT01DkMC]a>gD[LC]d00TJm00A6
_5ifGWINMPA?;0=>g006C]e>g4kMC]a>gDJl0T[M00AR]f:FH[MRU`<f6P03C]a>gDkL009>g006D_e>
g4klC]aBoDkL0Tkl00E>gDkLC]e>g4Jm00=Ad`03DOAAddkL009>g005B]aBo4klD_e>g002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo006D_eBo5;l
D_aBo@000U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d02Woo1000
17oo00<007ooOol02Goo000COol01000Oomoo`0017oo00<007ooOol00goo0P006goo0112_D:LA[e=
de7C@C1Ae3ZMAE51D4EAAE15DD5@AG55D0L0000XA[a6_D:LFSEF5EHeEQAJ=EHEGfe6_4ZmA[`bOBiL
J]MV]V[GI[IZeaeG7EQ6_4[MA[a:gEjFH[MRUV:gGYIR]dJlB[e6W4ZmA[a:gDJlB]d2J]H046ZeK]HD
mQTF@Ya6_DJLA[a:_4kMB]aVefJfI]MV]VKG0P000;Y6_4ZlAYa>gD[LC]e:g4kMA[a6gEYFGWIJEUif
>S/nFcXk?U]:g4kmB]a>oDkLC_e>g4kmA[a:gDJlH[MRUV:g=QXj6cHJ>Q]>g4kMB]a>oDkLD_e>g5;m
C]aBoDkLD_e>g4kmB]a>oDJlDOA=de7dCM=Am001C]e:_4kMC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;m
C_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d6Ool30008Ool00`00Oomo
o`09Ool001=oo`04001oogoo0004Ool00`00Oomoo`02Ool2000NOol02d:L@Ye=ddE@CM<nWDE@AE55
D4EAAE000`0000E5DDEaAE4004EA00<nO00:@Ye2_EHEESEF5EHeEQEKCE]<A[d3A[`02V[GI[IVeVJf
J]MV]QeH7ELMF4Jl0dJm00ARUV:GHYMR]`9CT@A6_003A[e:gDJl00AZeP046AHE5QTFB[`2B]`01T[M
A[a:gDJmI[MV]P=V]`0:0016_4JlB[a6_4[MB]a>gD[LB]d2A[d01EYFGWINMSiK>U/00ciK0dkL00E>
gD[LC]e>g4kM008R7004HYMR]f:FH[L4=QX03DkLC_e>g4kLC_aBoDkLC_a>g4kmC]a>oDkL00=6_@04
DM=Ae57CDM<30043C]`01DklD_aBo5;mC_`00U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01U;mD_aBo5;lD_d0009Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo0=oo`<000aoo`03001oogoo00Qoo`003goo10000goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo00LjW57D@C1AdcZLAE55D003000024E@AG55
D4EaAE15L@00BG42?W`0:Sik?W`nW4:mEQAJ=EHEESEKC5m]Fda6_DJlA]e6_6[GI[IZefJf7EP004Jm
@Ya6_D:lA]e6_4JmGYIR]f:FH[L]nS8KA[a:_DJLB[e6_4[MA[a^eP9ZeP3;5?DI5QCf6AI:_4kMB[a:
gDJlB]eV]VKGH[IVefJf;KTY^4kMB]a>gDZlC]e:g4kMB]`1603gGWIJEUifFUI:gDZlC]e:_4[MC]a>
oDkLC]e:g4kmB]a>gF:FH[MRUV:gHYI:gDZlB]a:_4[MC]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mA[a6
gDgCDOA=de7dCM=6W49kAYa2Ne;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo002000?Ool00`00Oomoo`08Ool000moo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01ioo`04?Ye=ddgCCM<300000dE@
AE55D003AE407DE@AE55DDEaAE55LDJlA[e6_4Jm@YeF=EHEESEF5EHe>U/jG3YKA[e6_4JmI[IZefJf
I]IV]QeH7EL00TJL0TJl0TJm00AR]f:FHYMRU`<anP04B]a:gDZlB]d2=Wd4J]H021DF6AHE5QTFB]a:
gD[LB]d3;Ud016JgI[IV]fJg0RVi00Q>g4[LC]e:g4[MB]a>gD[L0eif00AJEUifCba:g0=:_006C]e>
g4kLC]a:gDJl0d[M00=RUV:gHYL00P001DZl00=>g5;mC]`00Tkl00MBoDkLC_a>g4kmC]a>o@03A[d2
DM<01E7d@W]2O49kAY`00dkL00E>oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo11oo`03001oogoo00Qoo`003goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07goo03]Ad`000011D4EA@E15DDE@AE51D4Ea
AE15LDE@BG55D4EaAE0004JlA[e2W4:mEQEF=EHDFSEF5CiL>U/nG3YKA[e6_4KMI[IZefJfJ]LMEaeH
7EM:gDJlB]dEnaWl5OaR]ejFH[MRUS7j;OY:gDZlB]e:_4[M009ZeP3?J[E^eV[FA[a6W4JmAYa6_4Zl
C]e:g2iM:SaVefJfI]MR]VKG:KT]^BVhC]e:g4kMB]a:gDJlA]eJEUifFUINMT/[Cba;;4[MB[a>gDZl
C_e>g4kmC]a:gDJlB]e6_6:gHYIR]f:F>QXf6TkmC]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[L
A]e6_4KMCM=Am57CDOA2NdJL@W]6W4kLD_e>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00moo`03001oogoo00Qoo`003goo1@00
0goo10001Goo0P007Woo0`0000YAddgCAE1=ddEAAE15DDE@AE55D095D@05AG4004EaAE55L@020000
2TJlA[e6_5HeEQEF=EHEESEF5DJm0dJl0RiM00aVeVJfJ]MV]VKF7ELMF4JlB[e:_4[MA[`2HYL00f:g
HYIRU`03<OX01DZmA[e:gDJlB[d016[F00<E5TJlAY`00TJL00I6_4[LB]e:g6JgI[H3I[L200001dJl
B[a6_4kMC]a>gD[L00=6_@05FUINMUifGWHjF`02?U/02TkMC]a>g4kLC]e>g4kMC]a:gDJl0T[M00=R
]f:FH[L00cHJ0TkL00I>gDkLC_a>o5;mC]`2C_`02E;mC]a>gDkLC]e>g4JmDM=Am003DM<00`01B]a>
g003C]`00e;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01@00D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@02D_`?Ool00`00Oomoo`08Ool0021oo`03001oogoo01Yoo`<0009oo`0m?[e=
de7D@C1Ae4E@AE51D4EaAE15LDE@BG55D000AE19LDEA?W`nNd9l?Ya2_CjLFSEF5EHeEQAKKE]<A[e6
_4Zm;UdbOFJfJ]MV]V[GI[HQN1eG7EQ2_4KMA[a6_D:lH[MRUV:gCg5CTDJlB[e6W4[MA[a:gDJlK]H0
0V[F0<iZ]ATF5AI:gDZlC]e:_4[MA[a:gDJlI]MR]VKGI[H]^@00B[e6_4ZlAYa>gD[LC]e:g4[MA[aN
MUYFGWIJESiK>S/nFd[LC]e:g4kmB]a>gD[LC_e:g28M7QaR]f:FH[MRUV:g=QXj6SHJD_e>g5;mC]aB
oDkLD_e>g5;mC]aBoDkLA]e6_4KMA[aAm4gCDOA=de7d005>gDZlC]e:_4kMC]aBoDkLD_e>g5;mD_aB
oDklD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m3Woo
00<007ooOol027oo000POol00`00Oomoo`0GOol30006Ool023jMCM=5DDgCAE55D4EAAE05AE401000
AG55DDEa0cil00M2_D:M@[eF5EHeEQEF=@03Fd`024JmA[a6_6JfJ]MV]VKFI[H20002AY`2A[`3A[d0
1V:FHYMRUe>ADg5CT@A6_003A[e:gDJl00=ZeP055AHI5QDFB]e:_002B]`00d[MA[a:g@02I[L04FJf
I[LY^Bfi:KU>g4[LC]e:g4[MB]a>gD[L0AQ6_EifFUH00Uif00DnFcYK?U]>g4kM00=>g00:C]e:g4kM
C]aR]f:FH[MRUf:gHYH4B[`2C]`02TkmC]a>o4klD_e>g4klC]a>oDkL0dJm0e7C00EAm00100400Dkm
00=>g005C_e>o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_`00`00D_eBo002D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00eoo`03001oogoo00Qoo`007goo00<007ooOol05Goo0`00
2Goo018jW57D@E1Ae45@AE55D4EAAE15LDE@AG55D4UaAE15LDE@BG42?W`09Sik@[dnW5HeEQAJ=EHE
ESDjFciL>U]6_DJlA]eV]V[GI[IZefJf0012W4Jm@Ya6_4:lA]e6_4JmGYIR]f:F<QX]nS8KB[a:gDZl
B]d2=Wd0<fZeK]IZeV[F5?DI5QDF6AI:_4kMB[a:gDJlB]dZG6KGH[IVebVi;KTY^4kMB]a>gDZlC]e:
g4kMB]aNMUYFGWIJETl/B`]:gDZlC]e>g4kmC]a>oDkLB]e6_4[MA[aR]f:FH[MRUP020000WD[MB[a:
g4ZlD_e>g5;mC]aBoDkLD_e>g5;mC]aBoDkLA]e6_57dCM=Am57CAYa2NdJL@W]BoDkLD_e>g5;mC]aB
oDklD_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m00eoo`03001oogoo00Moo`007goo0P004goo0`0037oo00XnWDgCDM==ddEA?Ye5DDE@
AE55D095D@0IAG55DDEaAE55LDEA0016_4JmA[a2_EHEESEF5EHeEQDjG3YK>U`jFdJmA[a6_FJfJ]L0
0VJf0QeH00E6_4ZmB[a:gAGl00<Io003HYIRUc7j008anP05B]e:g4[MB[a:g@05J]H024JlAYa6W4JL
A[a:g4[MB]`2;Ud3I[L02FJf:KTY^Bfi:KU>gDkLC]e:g003A[d025YFGWINMUifBb];;4ZlB]`2B[`0
2dkLC]e>g4kMC]a:gDJlB]eRUf:gHYH010000TkL00I>gDkLC_a>g5;mC]`2C_`01U;mC]a>gDkLC]e>
g096_@0=DOAAde7CDM=6W49k@Wa2Ne;mC]aBo4klD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=BoE;lOol037oo00<007ooOol01goo
000OOol00`00Oomoo`0?Ool3000?Ool04SjMDMA=de7DAE0nWD5@AG55D4EaAE19L@00AG55D4UaAE59
L@80000XA[a6_D:LFSEF5EHeEQAJ=EHEA[e6_4ZmA[`^OBiL<WeV]V[GI[IZeaeG7EQ6_4[MA[a:gAGk
6OaRUV:gGYIR]c7j<QX]nT[MA[a:gDJlB]d2J]H0dFZeK]HE5TJlAYa6_DJLC]e:_4kMB]aVef:fI]MV
]VKGAYa:_DJlB[a6W4kMB]a>gDJlB]e6_5ifFUINMUYFGWHj>ciKB]a>gD[LC_e>g4kmC]a>oDkLB]e6
_4[MHYIR]f:F>Q/f6SXJ=QY>oDkLC]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e6_4KMDM=Am4gCDOA:
_4kMB[a>gDZlD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`037oo00<007ooOol01goo000OOol00`00Oomoo`0<
Ool3000COol01dgCDM==ddEA?Ye5DDE@0095D@06AG55D@00AE55LDEA0TEa0cil00M2WD:m@YeF=EHE
ESEF5@02Fd`014JmA[a6_4Jl0RiM0VJf00=VefJf7EP00QeH00E6_4ZmB[a:gF:F009RU`03H[M?L5=a
00=6_004B[e6_D[MA[`4J]H26AH02dJlAYa6W4JLB]e6_4[MA[eV]fJfI[L00P000dJl00E:_4JlC]e>
g4kM00=6_@09GWI;:eifGWHnFcYK?U]>g4kM00=>g009C]e:g4kMC]`R71hL8QaRUf:g00Df6P9>g006
C]e>g4klC_aBoDkL0Tkl00=BoDkLA[d00dJm0U7C00=Am57C00400TkL00E:g4kLC]aBoDkl009Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo009D_eBo5;lD_aBoE;l001Bo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00=BoE;lOol02Woo00<007ooOol01goo000OOol00`00Oomoo`09Ool3000GOol09DgCDMA1
D3jMAE15LDE@AG55D4EaAE19LDE@BG55D4UaAE4nO3ik@W`nW4:mEQAJ=EHEESEG;5]<Eda6_DJlB[e6
_6[GI[IZefJf0080000EA[e2W4Jl@[a6gDJlA[eNUV:gHYICTDm`B[e6_4ZmAYa:_DJlB]e6_6kF009Z
eP175?HI5QDFB]e:_4kMB[a:gDJlB]eV]VKGH[IVebVi;KTY^4kMB]a>gDZlC]e:g4kMA[a:gEYFGWIJ
EUifFUHnFcXk?U]>g4kmC]a>oD[LC]e:g4km7Q`R7F:FH[MRUV:gB[a:gDZlB]a>g5;mC]aBoDkLD_e>
g5;mC]aBoDkLD_e>g4KMA[a6gDgCDOAAd`020040R002C]aBoDkLD_e>g5;mC]aBoDkLD_e>g5;mD_aB
oDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l2Woo00<007ooOol01goo000OOol20008Ool2000JOol0157CCM=5DCjM0dEA00U5D4EAAE55LDEA
AG55DDEaAE400TEa0cil00]2WEHeEQEF=EHEESDjFcYL>U]6_DJl0096_@05I]MV]VJfI[H00003AY`0
1TJlAYa6_DJmH[MRUP9RU`8anP05B]e:g4[MB[a:g@02=Wd4J]H01ADF6AI:g4[MB[`00T[L00I:gDJl
B]d^GFJgI[H2:KT02Rfi:KU>g4[LC]e:g4[MB]a>gEYF0eif00AJEUifB[a:g09:_003C]a>gDkL009>
g007C]e:g4kMHYMR]f:FH[L00P0014Zl0dkL00Y>oDkLC_a>o5;mC]a>oDkLC_e>g096_@09DOAAde7D
DM=6W49k@Wa>g4km00=>g005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_`005;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`00e;mOomoo`08Ool00`00Oomoo`07Ool001io
o`03001oogoo00Eoo`<001aoo`0jCM=Ae7ooAE51D4EaAE15LDE@BG55D4EaAE19LDEABG55D4Ua0016
_D:LA[dnW5HeEQAJ=EHE?U`jFciL>U/nG4JlA]eV]V[GI[IZeaeG8GQ6_4[MA[a:gDJl6O`Eo1WlGYIR
]c7j<QX]nT[MB[a:gDZlB]d2J]H0<FZeK]IZeQTF5?HI5T[LC]e:_4kMB]`^GBXlI]MV]VKGH[H]fBVi
;KTY^4kMB]a>gD[LB]e6_5ifFUINMUYFGWI;2d//B[a:gDZlC]e>g4kmC]a>oDJlB]e6_4[MHYIR]f:F
00<0002PB[a:gDZlD_e>g5;mC]aBoDkLD_e>g5;mB]a>oD[LC_e2_4KMA[aAm4gCDOA2NdJL@W]6W4kL
D_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d:Ool00`00Oomoo`06Ool001ioo`03001oogoo009oo`<0
01moo`06DM==dgooAE15DDE@0TEA00I5LDEAAG55DDEaAE43AG4034EA0016_4JmA[a2_EHEESEF5EHe
EQE6_@=6_005A[d^GBiMI[IVe`02I[H27EP02TJlB[e:_4[M5O`Io6:GH[MRUV:G0c7j00E:_DJmB]e6
_4Zm00AZeP0;6AI6_4JLAYa:g4[MB]a:gD[LI[MV]P03I[L3A[`01DZlA[a>gDkLC]d00dJm00UNMUYF
GWI;2d/[B`];:dkLC]d00dkL00=>gDkLC]d00T[M00E6_6:gHYMR]f:F00<f6P=>g006D_e>g4klC]aB
oDkL0Tkl00]BoDkLC]e>g4kMA[eAe57CDOAAde7D009>g005B]a>g4klD_e>g002D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBo@00D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l2Woo00<007ooOol01Woo000NOol00`00Ool00002000SOol0457DOom5LGooAG55D4UaAE00
04E@BG55DDUaAE19LDEA0`0002PnW4:m?YaJ=EHEESEF55XeEb]6_DJlB[e6_2im;UaZefJfJ]MV]R5h
7ELQN1eGB]e6_4[MGYIR]f:FH[M?L5>AA[a:_DJLB]e6_4[MA[a^eP9ZeP0>J[DI5QDFA[a6W4JmAYa:
gDJlB]e6_6KGH[IVe`800033AYa:_DJlB[a6W4kMB]a>gDJlB]eJEUifFUINMSXk?U/j>ciKB]a>gD[L
C_e:g4kMB]a>oAhL8QdN76:gHYIR]cHJ>Q/f6TkMB]a>oDkLD_e>g5;mC]aBoDkLD_e>g5;m@[a6gDJl
A]e=de7dDM=Am4gC009:_4kMB[a>gDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d005;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Uoo`03001oogoo
00Ioo`007Woo0`009goo00=5D7ooAE4014EA00I5LDEAAG55DDEaAE42AG43?W`02T:M@[e2WEHeEQEF
=EM;FdaGC5]<0dJl00AVefJfI[IV]P800096W003A[a6W4Jm0096_@03HYIRUf:G009?L0E6_003A[e:
gDJl00=ZeP<I5P07B]e:_4[LB]a:gDJlB]d00VJg00aV]VJg:KT]^D[LC]a:g4kMB]a:gD[LC]d2A[d2
GWH025YF?U/nFciK>U/nFdkLC]d3C]`01TkMB]`R728LH[MRUP9RU`05H[Lf6SHJ=QY>o@03C]`02E;m
C]a>o4klD_e>g4kmC]a>o@02A[d01U7CDOAAde7DDM<00P800@07C]a>oDkLC]aBo5;mC_`00U;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo0Qoo`03001oogoo00Ioo`0017oo1@000goo100017oo10001goo00<007ooOol0
9Woo03M5DGooAG55D4EaAE19LDE@AG55D4UaAE59LDE@BG55DCil?W]2O3jL@[eF55XeEQEF=EHD?U`j
FciLA[a6gDJlJ]MV]V[GI[HQN4:LA[e2W4Jl@Ya6gDJlH[MNUV:gHYHb6RgjB]e:_4[MB[a:g@02=Wd0
<VZeJ]IZ]V[F5AHI5TZlB]e:_4kMB[a:gDJlB]dZG6KGH[H]fBVi;KU:_4kMB]a>gD[LC]e:g4kMFUIN
MUYFGWIJETkMB[a:gDZlC]e>g4kmC]a>oD[LC]e:g6:gHYIR]f:FH[L20000XdZlB]e:_5;mC]aBoDkL
D_e>g5;mC]aBoDkLD_e>g5;m@[a6gE7CDOA=de7d@W]6W49kAYa>g5;mC]aBoDklD_e>g5;mD_aBoDkL
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l00Moo`03001oogoo00Ioo`001Woo00<007ooOol00Woo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo00Eoo`8002Ioo`03AE1oodE@0095D@06AG55DDEaAE55LDEA1DEa0180
04JmA[a6_D:MESEF5E]<EQEF=CYK>U`jFdJmA[a6_FJfI]L3I[H02aeHA[a:_DZlB]e6_1Wl5O`Io6:F
HYL00c7j00E:gD[LB]e:_4[M00EZeP<I5P07B]a:gD[LB]e:g2iM:Ud00fJg00QV]RVi:KT]^D[LC]a:
g4kM0dJm00ANMUYFGWINMP80009:_007B]a:_4ZlC]a>gDkLC]d00T[M00A6_6:GHYMR]`@000=:_006
D_e>g4klC]aBoDkL0Tkl00ABoDkLC]e>g0=6_@0;DM=Am57C@Wa2NdJL@W]Bo4klD_e>g002D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00=BoE;lD_`01goo00<007ooOol01Woo0006Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01000Oomoo`0017oo00<007ooOol01goo00<007ooOol09Goo05M5LCZLBG55D4EaAE19LDEA
BG55D4UaAE59LDEA0016_4Jm@Ya6_EHEESEF55XeEQEF=CYK?U`jFdJmA[a6gBiMJ]MV]V[G7ELQN4Jl
B]e6_4[M5M/Io6:FH[MNUV:g<OXb6RgjB]e6_4[MA[a:gFZfJ]IZ]F[F6AI6_4JLA[e:g4kMB[a>gD[L
I]MR]VKGI[IVedJLB[e6_4ZlB]a>gD[LC]e6_4[MA[aNMUYFGWH00`000;E>oD[LC]e:g4kmC]a>oDkL
C_e6_4[MHYIR]f:FH[Lf6SXK=QY>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4KMCM=Am57C
DOA=ddkMB[a>gDZlD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
001Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@06Ool00`00Oomoo`06
Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`08Ool00`00
Oomoo`0TOol01dEA?Ye5D@00AE55LDEA00=5L@03AE55LDEa00<0000:@Ye2_CjM@[eGC5HeEQEF=EL[
Ed`3A[`2;Ud2I[H00fKGI[HMF0027EP01AeGB[e:_4[MHYH00f:G0Tm`0dJl00A:_DJmB]e6_0AZeP8I
5P0;A[a6W4JLA[e:gDJlB]e6_FJgI[IV]`020003A[`01DZlB]a>gDkLC]d00TJm0Uif00EJEUif?U/n
FcYK009>g00:C]e>g4kLC]a>gD[LC]dN728L7Q`2HYL4=QX01TkMC]a>g4kLD_e>g09>o00>D_e>g4kl
C_a>gDkLC]e6_E7dDM=Ae57CDO@00@=>g005B]aBo5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_`005;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00=B
oE;lOol01Woo00<007ooOol01Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol02Goo00<007ooOol08goo0295LCZMAG55D4UaAE19LDE@BG55DDUaAE59LGoo?W`n
Nd9l?Ya2_CjLFSEF5EHeEQAKC5L[Fda6_4ZmA[aZefJfJ]MV]P80000HA[e2W4Jl@Ya6gDJlA[eNUV:g
HYI?L4]@B[e6_4ZmAYa:_DJlB]e6_6[FJ[IZeQDF0QTF0=9:gDZlC]e6_4[MA[a:gFJfI]MR]VKG:KT]
^DZlC]e:g4kMB]a>gD[LC]e6_4[MFUINMUYF?U/j>ciK>S]>oDkLC_e>g4kmB]a>gD[L8QdN76:gHYIR
]f:F>QXf6SXKC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mC]a6gD:lA]eAde7dCM=Am00100800E;mC]aB
oDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`6Ool00`00Oomoo`05Ool000Ioo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0:Ool2000SOol02DE@?Ye5DDEa
AE55LDEAAG55D@02AG4014UaAG5oogoo0cil00]2WD:mEQEF=EHEESEF5CYL>U/jG4Jl0096_@06I]MV
]VJfI[IVe`000TJL00I6_4JLA[e6_F:GHYH2HYL2<OX01D[MB]a:gDZlB]d00SIm16[F0QTF00Q:g4[M
B[a:g4JmB]e6_4[M0VJg00eV]Rfi:KT]^D[LC]a:g4kMB]a:gD[LC]eJEP03GWH01EYFB[a:_4[LB[`0
0TkL00I>gDkLC]e>g4kMB]`2HYL016:gHYH000000dZl00=>g4kmC]`00TkL00QBoDkLC_a>o4kmC]a>
oDkL0TJm00QAe57CDOAAddIl@W]6W49k0TkL00E>oDkLD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo000D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
0e;mD_aoo`04Ool00`00Oomoo`05Ool000Aoo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool0
0`00Oomoo`0<Ool00`00Oomoo`0POol03DEa>Ya9LDE@AG55D4UaAE59LDE@BG55DDUa00=oo`18A[e2
W4Jm?YaF=EHDFSEF5EHe>U/nG3YK?Ua2_4KMI[IZefJfJ]MV]R5h7EM:gDJlB]e6_1Wl5O`Io5jFH[La
nS8J;OY:gDZlB]e:_4[MJ[IZeVZeJ]IZ]QTF5AHI5T[LC]e:_4kM:U`^GF:fI]MV]VJgH[H]fBVi;KU:
_4kMB]a6gDJlB]e6_5ifFUINMUYF0P0000m>gDZlB]e:_4kmC]a>oDkLB]e6_4[MA[aR]f:FH[L00`00
0:I:g4ZlB]e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LC_e:g4KM@[aAm57CDOA2NdJL@W]6W49kD_e>g5;m
C]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<M
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Aoo`03001oogoo00Eoo`001Woo00<007oo
Ool00goo100017oo100047oo00<007ooOol087oo00I5LDEAAG55DDEaAE43AG400dEAAG55L@04Ool0
2DJmA[a6_EHEESEF5EHeEQEF=@03A[`01DJm;Ud^GBiMI]L00fJf00DQF1eGB[e:_4[M008Eo09RU`03
HYIRUc7j008anP05B[e6_D[MA[a:_@04J]H021TFA[a6W4JLB]a:gD[LB]d2I[L02fJfI[MV]fJgA[a:
_4JlB[a:g4kMC]`00dJm0Uif00EJEUifFWHnFcYK009>g006C]e>g4kMC]a>gDkL0d[M00ARUV:GHYMR
]`<f6P0:C]e>g4kLC]aBoDkLC_a>g5;mC]`2C_`00dkMC]a>g@02A[d01E7CDOAAde7dB]`00dkL00E:
g5;lC_aBoDkL009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`02E;mD_aBo5;lD_eBo000D_aB
o@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eoogoo009oo`03001oogoo00Eo
o`00:Goo00<007ooOol07goo00]5D7ooAE19LDEABG55D4UaAE59LDEA00Ioo`0g@[dnW4:mEQEF=EHD
FSEG:eM;A[a:_DJl;Wd^G6[GI[IZefJfJ]LMEb5h7EM:gDJlB]eNUV:gHYIR]d]?Cg16_4ZmAYa:gDJl
B]e6_6[FJ[IZeVZe6CHI5TJlAYa6_DJlB]e6_4[MI[IV]f:fI]L00P000<Q6W4ZmA[a:_4[LC]e:g4KM
A[a:gEYFGWIJEUif>S/nFcXkC_e:g4kMB]a>oD[LC]e:g28M7Q`R7F:FH[MRUSXJ=QXj6cHJC]e:g4km
C]aBoDkLD_e>g5;mC]aBoDkLA]e2_4KMA[aAm4gCDOAAd`02B[a>gDZlC]e>g5;mC]aBoDkLD_eBo5;m
C]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0goo00<007ooOol01Goo000ZOol00`00Oomoo`0NOol024EA
Oom5LDEAAG55DDEaAE42AG400dUaOomoo`04Ool01d:M@[dnWEHeEQEF=EHE00=G:`=6_005I]MV]VJf
I[IVe`0200000dJLA[a6W003A[d01F:FHYMRUdm`Bfl014Jl00A:_DJmB]e6_0=ZeP<I5P06B]e:_4[L
A[e:gDJl0VJg00`006JfI[LY^BfiB]a>g4[LC]e:g4[MB]`2A[d01EifFWINMUYFGWH00SiK00PjFdkL
C]a>gDkLC]e>g4kM0QhL00=RUf:gHYH00V:G14Zl00a>oDkLC]a>o5;mC]a>o4kLC_e>g4kmC]`3A[d0
0e7CDOAAd`030083C]`01TkmC_aBo5;lD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
2E;mD_aBo5;lD_eBo000D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo0=oo`03
001oogoo00Eoo`00:goo0P007Woo00]5D7ooAE15LDE@BG55DDUaAE19LDEA00Moo`0T?Ya2_EHDFSEF
5EHeEQ@nG3YK?Ua2_4KMA[aZefJfJ]MV]V[G0016_D:LA[a2W4KMA[aR]ejFH[MRUS8J<OY:gDZlB]e:
_3JM0SIm035Z]F[FJ[IZeQDF6CHI5T[MB[a>gDJlB]e6_2iMI[IV]f:f;MTY^BfiB[a>gD[LC]e:g4kM
B]aNMUYFGWIJEUif001>gDZlB]e:_4kmC]a>oDkLC_e:g4kMHYIR]f:FH[MRUP020000Z4[LB[a:gDZl
D_e>g5;mC]aBoDkLD_e>g4kmC]aBoDkLA]e2_57dDM=Am4gCAYa2NdJLC]aBoDkLD_e>g5;mC_aBoDkL
D_eBo5;mC]aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0=oo`03001oogoo00Aoo`00;Goo00<007ooOol06goo
00I5LGooAG55DDEaAE45AG48Ool00d:MESEF5@03ESD023YK>U`jFcYLA[a6_FJfI]L3I[H01R5h7EM:
_DZlB]e6_0<Eo003HYIRUc7j008anP05B]e:g4[MB[a:g@05J]H01dJlAYa6W4JLB]e:g4[M008^G@0<
I[IV]fJfI[MV]Rfi:KT]^D[LC]e>g4kM0TJm00EJMUifFUINMUYf0080009:_006B]a:_4kMC]a>gDkL
0d[M00=RUV:GHYL00`0000=>g4kMC]`00TkL00]BoDkLC_a>o5;mC]a>o4kLC]e>g4kM00=6_@0;DOAA
de7d@W]6O49kAYa>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo09oo`03
001oogoo00Aoo`00;Woo00<007ooOol06Woo00]5D7ooAE19LDEABG55D4UaAE59LDEA00Uoo`3oEQEF
=EHDFSEF5EHeA[a:_DJlA[d^G2im;UeZefJfJ]MV]R5h7EM:gDJlB]dEfaWlHYIR]ejFH[LanS8J<OY:
gDJlB]e6_4[MJ[IZeVZeJ]HI5TJlAYa6_DJLC]e:_4kMI[IV]f:fI]MV]VJgAYa:_DJlB[a:g4kMB]a>
gDJlB]eJEUifFUINMSXk?U]:g4kmB]a>gD[LC_e>g4kmC]a:gDJlH[MRUV:gHYHj6SHJ>Q]>g4kMB]a>
oDkLD_e>g5;mC]aBoDkLD_e:g4kmB]a>oDJlDOA=de7dDM=Am4ZlC]e:_4kMC]aBoDkLD_e>g5;mD_aB
oDklD_eBo5;mC_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l0004D_eBo7oo0006Ool002moo`03001oogoo01]oo`06
AG55DDEa?Ye5LDEA0TEa2Woo00E2_EHEESEF5EHe009G:`=6_08^G@9V]P0:I]MV]VJf7EPQN1eGB[e:
_4[MHYH3HYL00d]?Bfm6_002A[`014ZmA[e:gDJl16[F0QTF01Y:gDZlB]a:g4[MA[a:gFJfI[MV]VJg
:KT004JlB[a6_4ZlB]a:gD[LC]e6_EifFWINMUYF0ciK0dkL00I>gDkLC]e>g4kMB]`27Q`01F:gHYIR
UcHJ>QX00SHJ00=>g4kmC]`00TkL00MBoDkLC_a>o5;mC]a>o004A[d01e7CDOAAde7dDM<00T[L00=>
g004C_aBo5;lD_d3D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_d005;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo003Ool007oo00Eoo`00
<7oo0P006goo00Q5D4UaAE19LDEABG55DDUa2goo0?mJ=EHEESEF55L[DbYG:dJlB[e6_6[GI[IZefJf
J]LME`00@Ya6_4:LA]e6_4JmGYIR]f:FH[LanS8KA[a:_DJLB]e6_4[MA[aZeVZfJ]HI5QTf6AI:gDZl
C]e6_4[MA[aVefJfI[MR]RgI:KT]^DZlC]e:g4kMB]a>gD[L0?M6_5ifFUINMUYF?U/j>ciKC]a>oDkL
C_e>g4kmB]a>gD[LH[MRUV:gHYIR]dZlB]a:_4[MC]aBoDkLD_e>g5;mC]aBoDkLC_e>g5;mA[a6gDgC
DOAAde7dCM<00`02D_e>g5;mC]aBoDkLD_e>g5;mC]aBoE;lD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_d000=Bo5;m00001Woo000bOol00`00Oomoo`0HOol014EaAE55LDEA0TEa00=9LDEaOol02Woo00=F
5EHeESD00Woo00@jG3YK?Ua6_096_@06I]MV]VJfI[IV]aeG0TJL00I6_4JLA[e6_F:GHYH2HYL3<OX0
0d[LB]e:_002=Wd5J]H36AH06T[MB[a:g4JmB]e6_6JgI[IV]fJf;KTY^BfiB]a>g4[LC]e:g4[MB]aN
MUYFGWIJEUif0002B[`01T[LC]a>g4kLC]e>g0=:g@04A[aRUf:GH[L20004B[`00dkLD_e>g002C_`0
1e;mC]a>o4klC_e>g4km0096_@08DM=Am57CDOA2NdIl@W]>o@=>g005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005001Bo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00MBoE;lD_aBo5;mD_`00006Ool003=oo`03001oogoo01Moo`08AE19LDEABG55
D4UaAE59L@aoo`03EQAJ=Goo009oo`0m?U`jFciL@[a6gFJfJ]MV]V[GI[HQN1eGB]e6_4[MA[`Io1GL
H[MNUV:gGYHb6S7j<Q]:_4[MB[aZeVZfJ]IZ]F[FJ[I6_4JLA[e6W4kMB[a>gBYL;UeR]VKGH[IV]bVh
;MTY^DkMB]a>gD[LC]e6_4KMFUINMUYFGWH00`000;Q>gDZlB]e>g4kmC]a>oDkLB]e6_4[MHYIR]f:F
>QXf6SXKC]a>gD[LC_e>g5;mC]aBoDkLD_e>g5;mC]a>oD[LA]e6_4KMCM=Am57CDOA2NdJL@W]BoDkL
D_e>g5;mC]aBoDklD_e>o5;mD_aBoE;lD_eBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;l
D_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo000D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0Aoo`03001oogoo00=oo`00=7oo
00<007ooOol05Woo00=5LDEAAG400TEa00=5DDEaAG4037oo00=F=GooOol00goo0TJl00E6_BiM;UeV
]VJg00=V]P068GPMEdZmB[a:gDJl0f:G00=RUV:GA[`00dJl00=6_D[MA[`01F[F00<I5TJlAY`00TJL
00M:gD[LB]eV]VJgI[IV]`02000024JlB[a6_4kMB]a>gDkLC]d2A[d015YFGWIJEUif0SiK00TjFdkL
C]a>gDkLC]e>g4kMA[`00d[M00ARUV:GHYLj6P8f6P07C]a>gDkLC]a>o5;mC]`00Tkl00iBoDkLC_a>
g4kMC]a6_E7CDOAAde7dDM<00d[L0TkL00EBoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo00000=Bo005D_eBo5;lD_aBo@03D_`00e;m
Oomoo`06Ool00`00Oomoo`03Ool003Eoo`8001Moo`06BG5oodUaAE59LDEA3Goo00=F5GooOol00goo
0?16_4ZmA[a6_FJfJ]MV]V[GI[IZeaeG8GPMEdKMA[a6_D:lH[MNUV:gAdi;KdJlB[e6W4[MA[a:gFZe
J]IZ]V[FJ[DM=QTFB]e:_4kMB[a:gDJlB]eR]VJgH[IVe`00B[a6W4ZmA[a>gD[LC]e:g4kMA[aNMUYF
GWIJESiK>S/nFcXkC_e:g4kMB]a>oD[LC]dMo28MHYIR]ejFH[Lf6SXJ=QXj6dkLD_e>g5;mC]aBoDkL
D_e>g4kmC]aBoDJlA]e2_57dDM=Am57C00<00P03B[a>gDZlD_e>g5;mC]aBoDkLD_eBo5;mC_aBoE;l
D_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;l
D_d;Ool00`00Oomoo`03Ool003Moo`03001oogoo01Aoo`03AE5oodEA0095L@03BG5oogoo019oo`04
A[a6_DJmA[d3I[H01VJg7EL004JLA[a6W0=6_@04HYIRUf:GHYL2<OX3A[`00dZmA[e:g@05J]H26AH0
2T[MB[a:g4[LB]e6_6JgI[IV]fJf0Rfi00i>gD[LC]a:g4kMB]a:gD[L0?M6_EifFUINMUYF0TZl00Y:
g4ZlC]a>g4kMB]a>gDkLC]eRUP9RU`03H[MRUTZl00A:_00<C]a>oDkLC]a>o5;mC]a>o4kLC_e>g4km
0TJm00QAde7dDM=Am49kAWa2NdJL0dkL00E>oDklD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_`005;m00=Bo0moo`03001oogoo00=oo`00>7oo
00<007ooOol04goo00I9LGooBG55D4UaAE4EOol0>d:lA]e6_6[GI[IZefJfI]LMEb5h@Ya6_4:LA]e6
_4JmGYIR]ejF<QXanS8KB[a:gDZl=YdfOF[FJ[EZeVZfJ]HI5Qdf6AI>gDZlC]e:g2iM:SaVef:fI[MR
]RgI:KU>gDZlC]e:g4kMB]a>gD[LGWIJEUifFUH00P0000i>gDZlB]e:_4kmC]a>oDJlB]e6_4[MGYIR
]f:F0P0009Y:gDZlB]a:_4[MC]aBoDkLD_e>g5;mC]aBoD[LC_e:g4KMA[aAm4gCDOAAddJL@W]6W49k
D_e>g5;mC]aBoDkLD_e>o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;l
DaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d0019oo`03001oogoo00=oo`00>Goo00<007ooOol04Woo00=5DGooAG400dEa
5Woo00A6_4JmA[d^G@=V]P068GPMEb5HB[a:gDJl0QGl00ARUf:FHYMRU`<anP03B]a:gDZl00EZeP03
6AH004JL0096W00:B]e:g4[MB]aV]fJfI[MV]VJg:KT2;KT014kMB]a>gDkL0dJm00=JEUifFUH01000
0TkL00I>gDkLC]e>g4kMA[`2B]d01V:gHYIRUf:G>QXf6P9>g006C]e>g4kLC]aBoDkL0Tkl00IBoDkL
C_a>g4kMC]`2A[d01U7dDM=Am57dC]a:g09>g005D_e>g5;lC_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo5;l00Aoo`03001oogoo00moo`03001oogoo
00=oo`00>Woo0P004Woo00I9LGooBG55DDUaAE4GOol0:RiL;WeV]VKGI[IZefJf8GPMEb5hA[a:gDJl
H[MNUV:gGYIR]dJlB[e6W4ZmA[a:gDJlJ]IZ]V[FI[DM=QTFA[a6W4JmAYa:gDJlB]e6_6JgH[IVe`80
002aAYa:_DJlC]e:g4kMB]a6gDJlA]eJEUifFUHnFcXk?U/j>dkmB]a>gD[LC_e>g4kmA[a:gDJlH[MN
UV:g=QXj6SHJC_e>g4kMB]aBoDkLD_e>g5;mC]aBoDkLD_e:g4km@[aAm57CDOAAde7d009>gDZlC]e:
_5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00Qo
o`03001oogoo00moo`03001oogoo00=oo`00?7oo00<007ooOol04Goo00=5DDEaAG406Goo0fJf00EV
]fJfI[I6W4Jl0096W0=6_@=RU`03Adi;CdJl00=6_003A[e:gF[F00=ZeP05J[HI5QTFB]e:_002B]`0
1d[MA[a:gFJfI[MV]VJg008]^@07A[a:_4JlC]e:g4[MB]`00TJm00ANMUYFGWHjF`<nF`08>U]>g4kL
C]e>g4kMC]a>g@8N7007HYMR]f:FHYLf6SXJ=QX00TkL00]>oDkLC_a>o5;mC]a>oDkLC_e>g4km00=6
_@04DOAAde7d008200<01TkmC]a>g4kLD_e>o09Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`0
1U;mD_aBo5;lD_eBo0aoo`03001oogoo00moo`03001oogoo009oo`00?Goo00<007ooOol047oo00=9
LDEABG406Woo01IV]V[GI[IVegoo0012W4Jl@Ya6_DJlA[eNUV:gGYIRUc7j<Q]:_4[MB[a:g@8fO@0`
I[EZeVZfJ]HI5Qdf6AI:gDZlC]e:_4[MA[a:gF:fI[MR]RgI:KT]fDZlC]e:g4kMB]a>gD[LGWIJEUif
FUINMTZlC]e:_4[MB[a>oDkLC_e>g4kmB]a>gEjFH[MRUV:g0P0008Y:_4[LB[aBoDkLD_e>g5;mC]aB
oDkLD_e>g4kmC]aBoDJlA]eAde7dDM=6W49kAYa2Ne;mC]aBoDkLD_e>g5;mC_aBoDkLD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_dAOol00`00Oomoo`0>Ool00`00Oomoo`02Ool003ioo`03001oogoo00mo
o`03AG59LDEa01Yoo`03I[MV]Woo009oo`067ELQN4ZlB]e6_4Zm0TJm00=RUV:GHYL00c7j00A:g4[M
B[a:g@9ZeP03J[IZeV[F00@I5P0:B]e:g4[MB]`^GBYMI[MV]VJgI[H3;KT00d[LC]a:g003A[d015YF
GWIJEUif0P000dZl00I:g4kLC]e>g4kMC]`3B]d00f:FHYMRU`030003B[`014klC]aBoDkL0Tkl00IB
oDkLC]e>g4kMC]`2A[d03E7dDM=Am57dAYa2NdIl@W]BoDkLD_a>o5;m00=Bo005D_eBo5;lD_aBo@03
D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;l
D_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;l
D_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005
D_eBo5;lD_aBo@0EOol00`00Oomoo`0=Ool00`00Oomoo`02Ool003moo`03001oogoo00ioo`03BG55
DDUa021oo`377ELQN4JlB]e6_1Gl5MaRUejFH[MNUS8J<OXb6dJlB]e6_4[MJ[IZeVJeJ]HI5TJlAYa6
_DJLC]e:_4kMB]aV]f:fI]MR]VJgAYa:_DJlB[a:g4kMB]a6gDJlA]eJEUifFUINMSXk?U]:g4kMB]a>
gDkLC_e>g4kmA[a:gDJlH[MNUV:g=QXj6SHJ>Q]>g4kMB]a>oDkLD_e>g5;mC]aBoDkLC_e:g4kmB]a6
gE7CDOAAde7dB[a>gDZlC]e:_5;mC]aBoDkLD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`06Goo00<007ooOol0
3Goo00<007ooOol00Woo0010Ool2000>Ool00dEAAG55L@0POol01R5h7ELQN4ZlB]e6_0=RU`03HYI7
CTM>00=6_003A[e:gDJl00=ZeP04J[HI5QTFA[`2AY`04DJmB]e6_4[MI[IV]fJfI[L]^@00A[a:_4Jl
B[a:g4kMC]`00TJm00ANMUYFGWIJEP<nF`=>g005C]e:g4kMC]a>g@027Q`2HYL016:FHYLf6SXJ0SHJ
00M>g4kmC]a>g4klD_e>g002C_`00e;mC]a6_@03A[d3DO@02E7C00=>g4kLB]a>g5;lD_e>o002D_`0
1E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d0
0e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`MOol00`00Oomoo`0<Ool00`00Oomoo`02Ool0049oo`03001oogoo00aoo`03AE5o
ogoo021oo`30A[a2W4JmA[a6_D:lH[MNUV:GGYHb6c7jB[e6W4ZmA[a:gDJlJ]IZ]V[FI[DM=aTFB]e:
_4kMA[a:gDJlB]eR]VJgH[IVebVi;MU:_4kMB]a>gD[LC]e:g4KMA[aNMUYFGWIJESiK>S/nFdkLC_e>
g4kmB]a>oD[LC]eNUV:gHYIR]ejFB]e:_4[LB[a:gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a6gDJlDOAA
de7dDM<00`0200=>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l8Goo00<007ooOol02goo00<007ooOol00Woo
0013Ool00`00Oomoo`0;Ool00dUaOomoo`0QOol00dJlAYa6W002A[d016:FHYMRUf:G0c7j00=:gDZl
B]d00SIm00AZ]V[FJ]IZeP<I5P0:B]e:_4[LA[e:gDJl:UeV]VJgI[H3;KT02d[LC]a:g4kMB]a:gD[L
GWIJEUifFUH00P000TZl00I:g4kLC]a>g4kMA[`3B]d00f:FHYMRU`020004B[`014klC]aBoDkL0Tkl
00IBoDkLC_a>g4kmC]`2A[d02E7dDM=Am57dAYa2NdIlC]a>o@02C]`00e;lD_eBo002D_`01E;mD_aB
o5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00ABoE;lD_aBo2Qoo`03001oogoo00]oo`03
001oogoo009oo`00A7oo00<007ooOol02Woo00=5DGooOol08Woo02m:gDJlB]dEg1GlGYIR]ejFHYLa
nS8K<OY:gDZlB]eZ]V[FI[EZeQTF0016W4JmAYa>gDZlC]dZG2iMH[IVef:fI[LY^2gI:KT]fD[LC]e:
g4kMA[a6gDJlGWIJEUif00<00021C]e:_4[MC]a>oDkLC_e6_4[MA[aR]ejFH[MRUSXJ=QY>oDkLC]e:
g5;mC]aBoDkLD_e>g5;mC]aBoD[LC_e2_4KMA[aAm57CDOAAddJL@W]6W4kLD_e>g5;mC]aBoDkLD_eB
o5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m02eoo`03001oogoo00]oo`03001o
ogoo005oo`00AGoo0P002Woo00=5LGooOol08goo00=:gDJlB[d00V:G00=RUV:GHYL014Jl00=:gDJl
B[d00V[F00AZ]V[F6AI6_0=6W007B]e:g4[MI[IV]fJfI[L00P0000Q6_4ZlA[a:_4[LC]e>g4kM0TJm
00AJEUifFUINMP<nF`9>g006C]e>g4kMC]a>gDJl0T[M00IRUf:FHYLf6SXJ=QX2C]`01TkMC]a>o4kl
D_e>g09>o006D_e>g4kMC]a>gDJm0e7d00EAde7d00=>g4[L009>g005D_e>o5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l
00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m
00=Bo005D_eBo5;lD_aBo@03D_`00e;mD_aBo00aOol00`00Oomoo`0:Ool00`00Oomoo`01Ool004Mo
o`03001oogoo00Moo`03AE5oogoo02Aoo`2[A[e2_4KMGYIRUejFAdi7;TZmAYa:_DJlB]e6_6[FJ[IZ
eVJe7CLI5T[MB[a>gDZlB]e6_4[MH[IV]f:fI[LY^BgIAYa:_DJlC]e:g4kMB]a>gDJlA]eJEUifFUHn
FcXk?U/j>dkmC]a>oDkLC_e:g4kM7O`R7F:FH[MNUV:g=QXj6SHJD_e>g5;mC]aBoDkLD_e>g5;mC]a>
oDkLA]e6_4KMDM=Am57CDO@00`04C]aBoDkLD_e>g5;mC]aBoE;lD_e>g5;mD_aBoDklD_eBo5;mD_aB
oE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;m03Eoo`03001oogoo00Uoo`03001oogoo005oo`00B7oo00<007ooOol0;Woo0TJm0f:G
00MRUS7j<OY:gDZlB]e:_002=Wd3J]H01FZf6AHI5T[MB[`00T[L00I:gDJlI[MV]VJgI[H3;KT03D[L
C]a:g4kMB]a:gD[LGWIJEUifFUINMUYF009:_00:B]a:_4kLC]a>gDkLC]e>g4kMHYH3HYL20003B[`2
C]`02TkmC]a>o4klD_e>g4kmC]a>oDkL0TJm00UAm57CDOAAm4JL@W]6O4kLC_d00TkL00=Bo5;mD_`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`01U;mD_aBo5;lD_eBo3Uoo`03001oogoo00Uoo`03001oogoo005oo`00BGoo00<0
07ooOol0;Woo02a6_D:lH[MNUV:G<OXf6c7jB]e:_4[MB[aZeVJeJ]IZ]V[F6AHM=aTFC]e:_4kMB]`^
GBXlI[MR]VJgH[H]fBVi;MU:_4kMB]a6gDJlA]eJEUifFUINMUYF0P0000i>gDZlB]e>g4kmC]a>oDkL
B]e6_4[MGYIR]f:F0`0006=:_4[LB[aBoDkLD_e>g5;mC]aBoDkLC_e:g4km@[a6gE7CDOAAde7d@W]6
W49kAYa>g5;mC]aBoDklD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC
7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0?Goo00<007ooOol027oo00<007ooOol0
0Goo001:Ool2000^Ool25O`016:FHYMRUf:G0c7j00I:gDJlB[e6_F[FJ[H2J]H051dfAYa6W4JLB]e:
g4[MB]aV]fJfI[MV]VJgA[a:_4JlB[a:g4kMC]`3A[d015YFGWIJEUif0SiK0dkL00I>gDkLC]e>g4kM
A[`2B]d02F:GHYIRUcHJ>QXf6SXJC]a>g@03C]`02E;mC]a>o4klD_e>g4kMC]a>g@02A[d2DO@02E7C
DOA>g4kLB]a>g4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;l
D_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo003D_eBo7oo041oo`03001oogoo00Moo`03001oogoo
005oo`00C7oo00<007ooOol0;7oo09YNUV:GGYIR]d<]Abi6W4ZmA[a:gDJlB]eZ]V[FI[EZeQTF7CI6
W4JmAYa:gDJlB]e6_6JgH[IV]f:f0016W4ZmA[a:_4[LC]e:g4KMA[aNMUYFGWIJESiK>S/nFd[LC]e:
g4kMB]a>oD[LC]dMo1hMHYIR]ejF>Q/f6SXJ=QYBoDkLD_e>g5;mC]aBoDkLD_e>g5;mC]a6gDJlA]e2
_57dDM=Am57C00A:_4kMB[a>gDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeB
o5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoDIoo`03001oogoo00Ioo`03001oogoo005oo`00
CGoo00<007ooOol0;7oo0V:G00ARUWoo<OXanP=6_003B]e6_4Zm009ZeP05J[IZeQTF7CI:_002B]`0
1d[MA[a:gFJfI[MV]VJg008]^@07B]a>g4[LC]e:g4[MB]`00TJm00ANMUYFGWIJEP<nF`=>g006C]e:
g4kMC]a>gF:F0f:G00=RUTZlB[`00TZl0TkL00Y>oDkLC_a>o5;mC]a>oDkLC_e>g0=6_@04DM=Am57d
00@200<01dkLC_e>g4kLD_aBoDkl009Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EB
oE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`00e;mOomoo`17Ool00`00Oomoo`07Ool10001Ool1Ool004ioo`03001o
ogoo02]oo`0ZH[MNUWooOolf6c7j<QY:_4[MB[`fOC9mJ]IZ]V[FI[DM=aTF7CI:_4kMB]a>gBXl;UeR
]VJgH[IV]bVi;MU:_4kMB]a>gD[LC]e:g5ifFUINMUYF0P0000i>gDZlB]e:_4kmC]a>oDJlB]e6_4[M
GYIR]f:F0P0005M:gDZlB]a:_5;mC]aBoDkLD_e>g5;mC]aBoDkLC_e2_4KMA[aAm57CDOA2NdJL@W]6
W4kLD_e>g5;mC_aBoDkLD_eBo5;mC_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aB
oE;lDaeBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d0CGoo00<007ooOol01Woo0@000Goo0Goo001?Ool2000`Ool3<OX01DZlB]e:_6[FJ[H00V[F
00hM=P00AYa6W4JlB]a:gD[L;UdZGFJgI[IV]fJf0bfi00A:g4kMC]a>g@=6_@03GWIJEUif00<0009>
g006C]e>g4kMC]a>gDJl0T[M00IRUf:FHYMRUSXJ=QX2C]`01TkMC]a>o4kLD_e>g09>o005D_e>g4kM
C]a>g@02A[d2DO@02E7CDOA>g4kLB]a>g4klD_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aB
o5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eB
o5;lD_aBo@03D_`015;mD_aBo5;lDWoo00<007ooOol01Goo0@000Goo0Goo001AOol00`00Oomoo`0^
Ool05TZmA[a:_DJlB]e6_6[FI[EZeVZf7CHI5TJlAYa6_4ZlC]e:g6JgH[IV]f:f0P0006i:_DJlB[a6
W4kMB]a>gDJlA]eJEUifFUINMSXk?U/j>dkMB]a>gD[LC_e>g4kmA[a:gDJlH[MNUV:g=QXj6SHJC_e>
g4kMB]aBoDkLD_e>g5;mC]aBoDkLC_e:g4KM@[aAm57CDOAAd`04B[a>gDZlC]e>g5;mC]aBoE;lD_e>
g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lEGoo00<007ooOol01Goo0@000Goo0Goo001B
Ool00`00Oomoo`0]Ool5A[`024ZmA[eZeVZfJ]HI5Qdf6AH2B]`01d[MA[a:gDJmI[MV]VJg00<]^@07
C]a:g4kMB]a:gD[LC]d00TJm00AJEUifFUINMP<nF`9>g005C]e>g4kMC]a>g@027Q`01f:FHYMRUV:G
=QXj6SHJ009>g00:C_e>g4klC_aBoDkLC_e>g4kmC]`3A[d0257CDOAAm00400<014kLC_d2C]`00e;l
D_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo004D_eBo5;lD_aIOol00`00Oomoo`04Ool10001Ool1
Ool005=oo`03001oogoo02eoo`0TB[a:gDZlB]dbOCJMJ[IZeVJeJ]HI5Qdf6AI>gDZlB]e6_4[MA[aV
]f:fI[LY^BgI:KQ>gD[LC]e:_4kMB]a>gEYFGWIJEUif0P0000i:_4[MB[a>oDkLC_e>g4kmB]a>gEjF
H[MRUV:g0P0004U:_4[LB[a:gDkLD_e>g5;mC]aBoDkLD_e>g4kmC]a6gDJlDOAAde7dDM=6W49kAYa>
g5;mC]aBoDklD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eB
o5<MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo01MOol00`00Oomoo`03Ool10001Ool1
Ool005Aoo`03001oogoo02ioo`08B]e:_4[MJ[IZeVZfJ]IZ]P96W00:A[a6W4[MB]a:gBYMI[MV]VJg
I[H4;KT014kMC]a>gD[L0TJm00ANMUYFGWIJEP80009:_006B]a:_4kMC]a>gDkL0T[M00IRUf:FHYMR
USXJ=QX2C]`01TkMC]a>g4kLD_e>g09>o005D_e>g4kMC]a>g@02A[d2DO@02E7cDOA2NdJL@W]Bo4kl
D_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@03D_`01E;m
D_aBo5;lD_d00e;l00EBoE;lD_aBo5;m009Bo69oo`03001oogoo00=oo`40005oo`00EGoo0P00;goo
019:gDJlJ]IV]F[FJ[HM=P00A[a6W4JlB[a>gD[LI[MR]VJgH[H20000HDZmA[a:_4JLC]e:g4kMA[a6
gEYFGWIJEUif>S/nFcXkC]e:g4kMB]a>oDkLC_e6_4[MA[aR]ejFH[Lf6SXJ=QY>oDkLC]e:g5;mC]aB
oDkLD_e>g5;mC]a>oD[LC_e2_4KMDM=Am57C00A:_4kMB[a>gDkLD_e>g5;mD_aBoDkLD_eBo5;mC_aB
oE;lD_eBo5;mD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5<MD_aBoE;lDaeBo5;mD_aBoE;lD_eBo5;m06Eo
o`03001oogoo00=oo`40005oo`00Egoo00<007ooOol0;7oo00U6_4ZmA[eZeVZfJ]IZ]QdfB[`00T[L
00Q:gDJlB]e6_FJgI[IV]fJf0Rfi00M:_4JlB[a:g4[MB]a>g@02A[d00eYFGWIJEP04?U/2C]`01DkM
B]a>gDkLC]d00QhL00MRUV:GHYIRUcHJ>QXf6P02C]`02TkmC]a>o4klD_e>g4kmC]a>oDkL0dJm00=A
le7dDO@00`0400M>g4kmC]a>g5;lD_e>o002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=B
o005D_eBo5;lD_aBo@03D_`01E;mD_aBo5;lD_d00U;lJGoo00<007ooOol00Woo0@000Goo001HOol0
0`00Oomoo`0/Ool0<39m=YeV]V[FI[EZeQTF7CI:_4kMB[a:gDJlB]eR]VJgH[IV]bfi;MTY^4kMB]a>
gD[LC]e:g4kMA[aNMUYFGWIJETkMB[a:gDZlC_e>g4kmC]a>oD[LC]eNUV:gHYIR]`80000lB[a:g4Zl
D_e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLA]eAde7dDM=Am49kAYa2NdJLC]aBoDkLD_e>o5;mC]aBoE;l
D_e>g5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaeBo5;mD_aC7E;lD_eBo5;mKGoo00D0
07ooOomoo`00005oo`00FGoo00<007ooOol0;7oo00aZ]V[FJ[IZeVZf7CHM5QdfB]a:gD[LB]d2:Ud0
16JfI[MR]VJg0bfi00=>g4[LC]d00dJm00ANMUYFGWIJEP80009:_006B]a:_4kMC]a>gDkL0d[M00=R
UV:GHYH00`000dZl00A>o4kLD_e>g09>o005D_e>g4kMC]a>g@02A[d2DO@02E7cDOA2NdJL@W]6O4kl
D_e>g002D_`01E;mD_aBo5;lD_d00e;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_aeOol0
1000Oomoo`000Goo001JOol2000]Ool0HVJeJ]IV]Woo6AI6_4JLA[a6W4kMB]a>gF:fI[MR]VJgH[I:
_DJlB[a6W4kMB]a>gD[LA]e6_5ifFUINMUYF?U/j>dkMB]a>gD[LC_e>g4kmC]a:gDJlH[MNUV:g=QXj
6SHJ>Q]>g4kMB]a>oDkLD_e>g5;mC]aBoDkLC_e:g4km@[a6gE7CDOAAddkMB[a>gDZlC]e>g5;mC]aB
oE;lD_e>g5;mD_aBoDklD_eBo5;mD_aBoE;lD_eBo5<MD_aBoE;lDaehOol01000Oomoo`000Goo001L
Ool00`00Oomoo`0ZOol01V[FJ[Ioogoo7CHI5P9:g00GB]e:_4[MA[e:gF:fI[MV]VJg001:_4JlB[a6
_4[MB]a>gD[LA[eJEUifFUINMP04?U/01dkLC]e>g4kMC]a>gD[L008N7009HYMRUV:G=QXj6SHJ>QY>
g4km009>g003C_aBoDkL009>o003D_e>g4Jm0096_@04DO=Am57dDO@200@2C]`01D[LD_aBo5;mC_`0
0U;l00EBoE;lD_aBo5;m00=Bo005D_eBo5;lD_aBo@02D_alOol00`00Ool00001Ool005eoo`03001o
ogoo02ioo`1G7CHI5TkMB[a:gDZlB]e6_6JgH[IV]f:f;MTY^4kMB]a>gDZlC]e:g4kM0=I6gEYFGWIJ
EUifB[a:gDZlC]e>g4kmC]a>oD[LC]e:g6:gHYIR]ejFC]e:_4[LB[a>gDkLD_e>g5;mC]aBoDkLD_e>
g4kmC]a6gDJlDOAAde7dDM=6W49kAYa>g5;mC]aBoDkLD_e>g5;mD_aBoDkLD_eBo5;mD_aBoE;lD_eB
o5;m081oo`40005oo`400000GWoo00<007ooOol0;Goo0Qdf00DI5T[MB]a:gD[L008ZG@05I[MR]VJg
I[H]f@02;KT02T[LC]e:g4[MB]a>gEYFGWIJEUif0P0000M:_4[LB[a:_4kLC]e>g003B]d00f:FHYMR
UP030003B[`014klC]aBoDkL0Tkl00EBoDkLC]e>g4kM0096_@AAm007@W]6W49kAWa>o5;mC]`00U;l
00EBoE;lD_aBo5;m00=Bo003D_eBo5;l08Aoo`800000Ggoo0P00;Woo04m6W4JlAYa>gD[LC]e:_6Jg
H[IV]f:fI[M6_4ZlAYa:_D[LC]e:g4KMA[a6gEYFGWIJESiK>S]>gD[LC]e:g4kMC]a>oDkLB]e6_4[M
GYIR]ejF>QXf6SXKC]a>gD[LD_e>g5;mC]aBoDkLD_e>g4kmB]a>oD:lA]eAde7dDM=Em4ZlC]e:_4kM
C]aBoDkLD_eBo5;mC]aBoE;lD_e>o028Ool20000065oo`03001oogoo02aoo`0CAYa6_4JLB]e6_D[M
A[aV]fJfI[L]^@00A[a:_4JlB[a>g4kMB]`00TJm00=NMUYFGWH00ciK0TkL00I>gDkLC]e>g4kMB]`2
7Q`02V:GHYIRUcHJ>QXf6SXJC]a>gDkL0Tkl00UBoDkLC_a>o5;mC]a>gDkLA[d01E7d00@014kLC]a:
g09Bo006D_e>o5;lD_aBoE;lRgoo0P00001ROol00`00Oomoo`0/Ool0AdZlB]e:_4kMA[a:gF:fI[MR
]VJg:KP]fD[LC]e:_4kMB]a>gD[LA]e6_5ifFUENMSXk?U/j>dkmC]a>oDkLC_e:g4kMB]aR]ejFHYMN
UV:gB[a:g4ZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLA]e6_4KMDM=Em57C00D015;mC]aBoDkLD_e>
g5;mC]`0RWoo10000Woo001SOol00`00Oomoo`0/Ool014[LB]e:g4[M0RYM00AR]VJgI[H]f@8]^@0:
B]a>gD[LB]e:g4kMFUINMUYFGWH200001dZlB]a:_4ZlC]a>gDkL00=:g@04A[aRUf:FHYL20004B[`0
0dkLD_e>g002C_`01U;mC]a>oDkLC_e>g096_@=Am007@W]6W49kAWa>g4kmC]`0RGoo10001Woo001T
Ool2000]Ool05D[LC]e:_4kMH[IV]f:fI[M6_4ZlAYa:_D[LC]e:g4KMA[a6gEYEGWIJEP03000094[L
C]e:g4kMC]a>oDkLC_e6_4[MGYIR]ejF>QXf6SXKC]a>gD[LC_e>g5;mC]aBoDkLD_e>g4kmB]a>oD:l
A]eAde7dDM=Em8]oo`@000Yoo`00IWoo00<007ooOol0:goo00m6_D[MA[aV]fJfI[MR]P00A[a:_4Jl
B[a>g4kMB]`00TJm00ANMUYFGWIJEP<nF`03C]a>gDkL009>g003C]e:g4kM009:g@09HYIRUf:F>QXf
6SXJC]a>gDkL009>o00:D_e>g4klC_aBoDkLC]e>g4kMA[d4DOB7Ool4000>Ool006Moo`03001oogoo
02]oo`0iA[a:gDJlI[MR]VJg:KP]fD[LC]e:_4kMB]a>gD[LA]e6_5ifFUENMUYF?U/j>ciKC]a>oDkL
C_e:g4kMB]aR]ejFHYMNUV:gB[a:g4ZlC]e>g5;mC]aBoDkLD_e>g5;mC]a>oDkLA]e6_4KMDM=Em57C
08Eoo`<0019oo`00J7oo00<007ooOol0:goo0RYM00AR]VJgI[IV]`8]^@0;B]a>gD[LC]a:g4kMB]aN
MUYFGWIJEP0200001T[LB[a:_4kLC]e>g0=:g@04A[aRUf:FHYL20004B[`00dkLD_e>g002C_`01e;m
C]a>o4kLC_e>g4Jm00AAm85oo`@001Eoo`00JGoo0P00;7oo019R]VJgHYIV]f:f;MTY^2gIB]a>gD[L
C]e6_4KMA[aNMUYFGWH2000064[LC]e:g4kMC]a>oDkLB]e6_4[MGYIR]ejFHYLf6SXKC]a>gD[LC_e>
g5;mC]aBo@Ioo`05@[a6gE7CDOAAd`1mOol4000IOol006]oo`03001oogoo02Yoo`0<I[IV]f:fOol0
04ZlA[a:_4JlC]e:g4kM0TJm00AJEUifFUINMP8nF`03C]a>gDkL009>g003C]e>g4[M009:g@05HYIR
Uf:F>QXf6P02>QX00dkMC]a>g00:Ool2A[d2DOAiOol4000MOol006aoo`03001oogoo02Uoo`0RI[MR
]WooOol]fBfiC]e:_4kMB]a>gD[LC]e6_4KMFUENMUYF?U/j>SiKC]a>oDkLC_e:g4kMB]a>oEjFHYMN
UV:gGYH@Ool00dKMDM=Em01fOol4000QOol006eoo`03001oogoo02eoo`8]^@0:C]e:g4kLB]a>gD[L
GWIJEUifFUH200001D[LB[a:_4ZlC]d00TkL0T[M00E6_4[MHYIRUf:F019oo`9Am7=oo`<002Eoo`00
KWoo00<007ooOol0;7oo00`]^2gI;KU>gD[LC]e:g4KMA[aNMUYFGWH300003DkMB]a>gD[LC_e>g4km
C]a:gDJlH[MNUV:G019oo`03DM=Am7oo06ioo`@002Qoo`00Kgoo0P00;Goo00I6_4ZlA[a>gD[LC]d2
A[d015YFGWIJEUif0ciK00A>gDkLC]a>g0Aoo`03B]e6_6:G01=oo`03A[eAm7oo06Yoo`@002aoo`00
LGoo00<007ooOol0:Woo011>gDZlC]e:g4kMB]a>gDJlA]eJEEifFUINMSXj?U/n>hIoo`@0031oo`00
LWoo00<007ooOol0:goo00Y:g4kLB]a>gD[LB]eJEUifFUINMXIoo`@003Aoo`00Lgoo00<007ooOol0
:goo00U:g4kMB]a6gDJlA]eJEUifFUD0PWoo1000>7oo001dOol2000/Ool00d[LC]e>g002A[d00eif
FUIoo`1oOol3000lOol007Ioo`03001oogoo02Uoo`07001oogooOom6gDJlGWH0O7oo1000?goo001g
Ool00`00Oomoo`0XOol00`00Oomoo`1lOol40013Ool007Qoo`03001oogoo02Moo`03001oogoo07Qo
o`@004Moo`00NGoo0P009goo00<007ooOol0M7oo1000Bgoo001kOol00`00Oomoo`0TOol00`00Oomo
o`1aOol3001?Ool007aoo`03001oogoo02=oo`03001oogoo06eoo`@0059oo`00OGoo00<007ooOol0
8Woo00<007ooOol0JGoo1000EWoo001nOol2000ROol00`00Oomoo`1UOol4001JOol0081oo`03001o
ogoo01moo`03001oogoo065oo`@005ioo`00PGoo00<007ooOol07Woo00<007ooOol0GWoo0`00HWoo
0022Ool00`00Oomoo`0MOol00`00Oomoo`1JOol4001UOol008=oo`03001oogoo01aoo`03001oogoo
05Ioo`@006Uoo`00Q7oo0P0077oo00<007ooOol0DWoo1000KGoo0026Ool00`00Oomoo`0IOol00`00
Oomoo`1>Ool4001aOol008Moo`03001oogoo01Qoo`03001oogoo04]oo`<007Eoo`00R7oo00<007oo
Ool05goo00<007ooOol0Agoo1000N7oo0029Ool2000GOol00`00Oomoo`13Ool4001lOol008]oo`03
001oogoo01Aoo`03001oogoo03moo`@0081oo`00S7oo00<007ooOol04Woo00<007ooOol0?7oo1000
Q7oo002=Ool00`00Oomoo`0AOol00`00Oomoo`0iOol30028Ool008ioo`80015oo`03001oogoo03Eo
o`@008]oo`00T7oo00<007ooOol03Woo00<007ooOol0<Goo1000Sgoo002AOol00`00Oomoo`0=Ool0
0`00Oomoo`0]Ool4002COol0099oo`03001oogoo00aoo`03001oogoo02Uoo`@009Moo`00Tgoo0P00
37oo00<007ooOol09Goo1000Vgoo002EOol00`00Oomoo`09Ool00`00Oomoo`0ROol3002OOol009Io
o`03001oogoo00Qoo`03001oogoo01ioo`@00:9oo`00Ugoo00<007ooOol01goo00<007ooOol06Woo
1000YWoo002HOol00`00Oomoo`06Ool00`00Oomoo`0FOol4002ZOol009Uoo`8000Ioo`03001oogoo
019oo`@00:ioo`00Vgoo00<007ooOol00goo00<007ooOol03goo0`00/Woo002LOol00`00Oomoo`02
Ool00`00Oomoo`0;Ool4002eOol009eoo`05001oogooOol00009Ool4002iOol009ioo`800003Ool0
07oo00Aoo`@00;eoo`00X7oo0P0000=oo`0000000P00`Goo002QOol20035Ool00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0882282, 0.0217347, \
0.00362403, 0.00362403}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "In the animation of these pictures, we observe that a train of waves moves \
from the left to the right. The simpler solution of the ZK equation is given \
by a ",
  Cell[BoxData[
      \(TraditionalForm\`Tanh[]\)],
    CellTags->"Tanh[]"],
  " function representing a propagating step from the left to the right:"
}], "Text",
  CellTags->"ZK-equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Plot3D[
        pls /. t \[Rule] \[Tau], {x, \(-2\) \[Pi], 2  \[Pi]}, {y, \(-\[Pi]\), 
          \[Pi]}, AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<u\>"}, 
        PlotRange \[Rule] All, PlotPoints \[Rule] 40, Mesh \[Rule] False], {
        \[Tau], \(-2\), 2,  .25}]\)], "Input",
  CellTags->"ZK-Soliton"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02905 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.873 .884 .84 r
.39028 .78432 .39875 .78609 .41303 .7676 .40455 .76901 Mtetra
.934 .907 .771 r
.40455 .76901 .41303 .7676 .42749 .7414 .41902 .74668 Mtetra
.97 .914 .696 r
.41902 .74668 .42749 .7414 .44201 .70801 .43362 .71646 Mtetra
.98 .913 .641 r
.43362 .71646 .44201 .70801 .45643 .67172 .44821 .68072 Mtetra
.978 .918 .628 r
.44821 .68072 .45643 .67172 .47061 .63866 .46261 .64518 Mtetra
.969 .932 .671 r
.46261 .64518 .47061 .63866 .48455 .61284 .47675 .61535 Mtetra
.943 .938 .757 r
.47675 .61535 .48455 .61284 .49833 .59454 .49068 .59333 Mtetra
.885 .912 .84 r
.49068 .59333 .49833 .59454 .51204 .58198 .50449 .57809 Mtetra
.811 .862 .886 r
.50449 .57809 .51204 .58198 .52574 .5731 .51828 .56754 Mtetra
.751 .815 .903 r
.51828 .56754 .52574 .5731 .53949 .56638 .53208 .55983 Mtetra
.712 .783 .907 r
.53208 .55983 .53949 .56638 .5533 .56084 .54594 .55373 Mtetra
.69 .764 .908 r
.54594 .55373 .5533 .56084 .56717 .55593 .55986 .54851 Mtetra
.678 .754 .908 r
.55986 .54851 .56717 .55593 .58111 .55135 .57385 .54374 Mtetra
.671 .748 .908 r
.57385 .54374 .58111 .55135 .59513 .54694 .58791 .53921 Mtetra
.667 .745 .908 r
.58791 .53921 .59513 .54694 .60921 .54261 .60204 .5348 Mtetra
.666 .743 .908 r
.60204 .5348 .60921 .54261 .62337 .5383 .61624 .53043 Mtetra
.665 .742 .908 r
.61624 .53043 .62337 .5383 .6376 .534 .63052 .52608 Mtetra
.664 .742 .908 r
.63052 .52608 .6376 .534 .6519 .5297 .64487 .52173 Mtetra
.64487 .52173 .6519 .5297 .66627 .52538 .6593 .51736 Mtetra
.664 .741 .908 r
.6593 .51736 .66627 .52538 .68072 .52104 .6738 .51298 Mtetra
.6738 .51298 .68072 .52104 .69524 .51668 .68837 .50858 Mtetra
.68837 .50858 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.837 .868 .866 r
.38175 .7813 .39028 .78432 .40455 .76901 .39602 .76864 Mtetra
.906 .898 .808 r
.39602 .76864 .40455 .76901 .41902 .74668 .41048 .74996 Mtetra
.956 .912 .733 r
.41048 .74996 .41902 .74668 .43362 .71646 .42512 .7235 Mtetra
.977 .914 .664 r
.42512 .7235 .43362 .71646 .44821 .68072 .43983 .68982 Mtetra
.98 .915 .628 r
.43983 .68982 .44821 .68072 .46261 .64518 .45444 .65321 Mtetra
.975 .925 .642 r
.45444 .65321 .46261 .64518 .47675 .61535 .4688 .61987 Mtetra
.96 .938 .711 r
.4688 .61987 .47675 .61535 .49068 .59333 .48292 .59381 Mtetra
.918 .929 .802 r
.48292 .59381 .49068 .59333 .50449 .57809 .49686 .57533 Mtetra
.848 .888 .868 r
.49686 .57533 .50449 .57809 .51828 .56754 .51073 .56262 Mtetra
.778 .837 .897 r
.51073 .56262 .51828 .56754 .53208 .55983 .5246 .55362 Mtetra
.729 .797 .906 r
.5246 .55362 .53208 .55983 .54594 .55373 .53851 .54678 Mtetra
.699 .772 .908 r
.53851 .54678 .54594 .55373 .55986 .54851 .55248 .54113 Mtetra
.683 .758 .908 r
.55248 .54113 .55986 .54851 .57385 .54374 .56651 .53612 Mtetra
.674 .75 .908 r
.56651 .53612 .57385 .54374 .58791 .53921 .58062 .53144 Mtetra
.669 .746 .908 r
.58062 .53144 .58791 .53921 .60204 .5348 .5948 .52693 Mtetra
.666 .744 .908 r
.5948 .52693 .60204 .5348 .61624 .53043 .60905 .52249 Mtetra
.665 .743 .908 r
.60905 .52249 .61624 .53043 .63052 .52608 .62338 .51808 Mtetra
.664 .742 .908 r
.62338 .51808 .63052 .52608 .64487 .52173 .63778 .51368 Mtetra
.63778 .51368 .64487 .52173 .6593 .51736 .65225 .50927 Mtetra
.664 .741 .908 r
.65225 .50927 .6593 .51736 .6738 .51298 .6668 .50484 Mtetra
.6668 .50484 .6738 .51298 .68837 .50858 .68143 .5004 Mtetra
.68143 .5004 .68837 .50858 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.803 .851 .887 r
.37317 .77727 .38175 .7813 .39602 .76864 .38743 .76674 Mtetra
.873 .885 .84 r
.38743 .76674 .39602 .76864 .41048 .74996 .40188 .75125 Mtetra
.934 .907 .771 r
.40188 .75125 .41048 .74996 .42512 .7235 .41653 .7287 Mtetra
.97 .914 .696 r
.41653 .7287 .42512 .7235 .43983 .68982 .43132 .69819 Mtetra
.98 .913 .64 r
.43132 .69819 .43983 .68982 .45444 .65321 .4461 .66215 Mtetra
.978 .918 .628 r
.4461 .66215 .45444 .65321 .4688 .61987 .46069 .6263 Mtetra
.969 .932 .671 r
.46069 .6263 .4688 .61987 .48292 .59381 .47501 .59621 Mtetra
.943 .938 .758 r
.47501 .59621 .48292 .59381 .49686 .57533 .48911 .57398 Mtetra
.884 .911 .84 r
.48911 .57398 .49686 .57533 .51073 .56262 .50309 .55858 Mtetra
.811 .861 .886 r
.50309 .55858 .51073 .56262 .5246 .55362 .51703 .54788 Mtetra
.751 .815 .903 r
.51703 .54788 .5246 .55362 .53851 .54678 .531 .54005 Mtetra
.712 .783 .907 r
.531 .54005 .53851 .54678 .55248 .54113 .54502 .53384 Mtetra
.69 .764 .908 r
.54502 .53384 .55248 .54113 .56651 .53612 .55911 .52851 Mtetra
.678 .754 .908 r
.55911 .52851 .56651 .53612 .58062 .53144 .57326 .52364 Mtetra
.671 .748 .908 r
.57326 .52364 .58062 .53144 .5948 .52693 .58749 .51901 Mtetra
.667 .745 .908 r
.58749 .51901 .5948 .52693 .60905 .52249 .60179 .51449 Mtetra
.666 .743 .908 r
.60179 .51449 .60905 .52249 .62338 .51808 .61617 .51002 Mtetra
.665 .742 .908 r
.61617 .51002 .62338 .51808 .63778 .51368 .63062 .50556 Mtetra
.664 .742 .908 r
.63062 .50556 .63778 .51368 .65225 .50927 .64514 .5011 Mtetra
.64514 .5011 .65225 .50927 .6668 .50484 .65974 .49663 Mtetra
.664 .741 .908 r
.65974 .49663 .6668 .50484 .68143 .5004 .67442 .49214 Mtetra
.67442 .49214 .68143 .5004 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.771 .834 .901 r
.36452 .77245 .37317 .77727 .38743 .76674 .37878 .76357 Mtetra
.838 .869 .866 r
.37878 .76357 .38743 .76674 .40188 .75125 .39322 .75076 Mtetra
.906 .898 .808 r
.39322 .75076 .40188 .75125 .41653 .7287 .40787 .73187 Mtetra
.956 .912 .732 r
.40787 .73187 .41653 .7287 .43132 .69819 .4227 .70516 Mtetra
.977 .914 .664 r
.4227 .70516 .43132 .69819 .4461 .66215 .4376 .67118 Mtetra
.98 .915 .628 r
.4376 .67118 .4461 .66215 .46069 .6263 .4524 .63426 Mtetra
.975 .925 .642 r
.4524 .63426 .46069 .6263 .47501 .59621 .46695 .60063 Mtetra
.96 .938 .712 r
.46695 .60063 .47501 .59621 .48911 .57398 .48124 .57433 Mtetra
.918 .929 .803 r
.48124 .57433 .48911 .57398 .50309 .55858 .49535 .55566 Mtetra
.847 .887 .868 r
.49535 .55566 .50309 .55858 .51703 .54788 .50939 .5428 Mtetra
.778 .837 .897 r
.50939 .5428 .51703 .54788 .531 .54005 .52342 .53367 Mtetra
.729 .797 .906 r
.52342 .53367 .531 .54005 .54502 .53384 .5375 .52671 Mtetra
.7 .772 .908 r
.5375 .52671 .54502 .53384 .55911 .52851 .55163 .52095 Mtetra
.683 .758 .908 r
.55163 .52095 .55911 .52851 .57326 .52364 .56584 .51583 Mtetra
.674 .75 .908 r
.56584 .51583 .57326 .52364 .58749 .51901 .58011 .51105 Mtetra
.669 .746 .908 r
.58011 .51105 .58749 .51901 .60179 .51449 .59446 .50643 Mtetra
.666 .744 .908 r
.59446 .50643 .60179 .51449 .61617 .51002 .60889 .50188 Mtetra
.665 .743 .908 r
.60889 .50188 .61617 .51002 .63062 .50556 .62339 .49737 Mtetra
.664 .742 .908 r
.62339 .49737 .63062 .50556 .64514 .5011 .63796 .49286 Mtetra
.63796 .49286 .64514 .5011 .65974 .49663 .65262 .48834 Mtetra
.664 .741 .908 r
.65262 .48834 .65974 .49663 .67442 .49214 .66735 .48381 Mtetra
.66735 .48381 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47467 Mtetra
.69704 .47467 .70401 .4831 .71892 .47854 .712 .47007 Mtetra
.712 .47007 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.743 .819 .911 r
.3558 .767 .36452 .77245 .37878 .76357 .37007 .7594 Mtetra
.803 .851 .887 r
.37007 .7594 .37878 .76357 .39322 .75076 .38451 .74872 Mtetra
.873 .885 .84 r
.38451 .74872 .39322 .75076 .40787 .73187 .39914 .73306 Mtetra
.934 .907 .771 r
.39914 .73306 .40787 .73187 .4227 .70516 .41398 .71027 Mtetra
.97 .914 .696 r
.41398 .71027 .4227 .70516 .4376 .67118 .42897 .67948 Mtetra
.98 .913 .64 r
.42897 .67948 .4376 .67118 .4524 .63426 .44394 .64312 Mtetra
.978 .918 .628 r
.44394 .64312 .4524 .63426 .46695 .60063 .45872 .60696 Mtetra
.97 .932 .671 r
.45872 .60696 .46695 .60063 .48124 .57433 .47323 .57661 Mtetra
.943 .938 .758 r
.47323 .57661 .48124 .57433 .49535 .55566 .4875 .55417 Mtetra
.884 .911 .84 r
.4875 .55417 .49535 .55566 .50939 .5428 .50165 .53859 Mtetra
.811 .861 .886 r
.50165 .53859 .50939 .5428 .52342 .53367 .51576 .52776 Mtetra
.751 .815 .903 r
.51576 .52776 .52342 .53367 .5375 .52671 .5299 .5198 Mtetra
.712 .783 .907 r
.5299 .5198 .5375 .52671 .55163 .52095 .54408 .51348 Mtetra
.69 .764 .908 r
.54408 .51348 .55163 .52095 .56584 .51583 .55834 .50804 Mtetra
.678 .754 .908 r
.55834 .50804 .56584 .51583 .58011 .51105 .57266 .50306 Mtetra
.671 .748 .908 r
.57266 .50306 .58011 .51105 .59446 .50643 .58706 .49831 Mtetra
.667 .745 .908 r
.58706 .49831 .59446 .50643 .60889 .50188 .60154 .49369 Mtetra
.666 .743 .908 r
.60154 .49369 .60889 .50188 .62339 .49737 .61609 .48911 Mtetra
.665 .742 .908 r
.61609 .48911 .62339 .49737 .63796 .49286 .63072 .48454 Mtetra
.664 .742 .908 r
.63072 .48454 .63796 .49286 .65262 .48834 .64542 .47997 Mtetra
.64542 .47997 .65262 .48834 .66735 .48381 .6602 .47539 Mtetra
.664 .741 .908 r
.6602 .47539 .66735 .48381 .68215 .47925 .67506 .47079 Mtetra
.67506 .47079 .68215 .47925 .69704 .47467 .69 .46617 Mtetra
.69 .46617 .69704 .47467 .712 .47007 .70502 .46152 Mtetra
.70502 .46152 .712 .47007 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.72 .806 .918 r
.34701 .76107 .3558 .767 .37007 .7594 .3613 .75442 Mtetra
.771 .834 .901 r
.3613 .75442 .37007 .7594 .38451 .74872 .37573 .74541 Mtetra
.838 .869 .867 r
.37573 .74541 .38451 .74872 .39914 .73306 .39036 .73243 Mtetra
.906 .898 .808 r
.39036 .73243 .39914 .73306 .41398 .71027 .40519 .71334 Mtetra
.956 .912 .732 r
.40519 .71334 .41398 .71027 .42897 .67948 .42022 .68637 Mtetra
.977 .914 .664 r
.42022 .68637 .42897 .67948 .44394 .64312 .43532 .65208 Mtetra
.98 .915 .628 r
.43532 .65208 .44394 .64312 .45872 .60696 .45032 .61484 Mtetra
.975 .925 .643 r
.45032 .61484 .45872 .60696 .47323 .57661 .46506 .58092 Mtetra
.96 .938 .712 r
.46506 .58092 .47323 .57661 .4875 .55417 .47952 .55438 Mtetra
.918 .929 .803 r
.47952 .55438 .4875 .55417 .50165 .53859 .49381 .53552 Mtetra
.847 .887 .867 r
.49381 .53552 .50165 .53859 .51576 .52776 .50802 .5225 Mtetra
.778 .836 .896 r
.50802 .5225 .51576 .52776 .5299 .5198 .52222 .51323 Mtetra
.729 .797 .906 r
.52222 .51323 .5299 .5198 .54408 .51348 .53646 .50615 Mtetra
.7 .772 .908 r
.53646 .50615 .54408 .51348 .55834 .50804 .55077 .50028 Mtetra
.683 .758 .908 r
.55077 .50028 .55834 .50804 .57266 .50306 .56514 .49505 Mtetra
.674 .75 .908 r
.56514 .49505 .57266 .50306 .58706 .49831 .57959 .49016 Mtetra
.669 .746 .908 r
.57959 .49016 .58706 .49831 .60154 .49369 .59412 .48543 Mtetra
.666 .744 .908 r
.59412 .48543 .60154 .49369 .61609 .48911 .60872 .48077 Mtetra
.665 .743 .908 r
.60872 .48077 .61609 .48911 .63072 .48454 .6234 .47615 Mtetra
.664 .742 .908 r
.6234 .47615 .63072 .48454 .64542 .47997 .63815 .47152 Mtetra
.63815 .47152 .64542 .47997 .6602 .47539 .65299 .46689 Mtetra
.664 .741 .908 r
.65299 .46689 .6602 .47539 .67506 .47079 .6679 .46224 Mtetra
.6679 .46224 .67506 .47079 .69 .46617 .6829 .45758 Mtetra
.6829 .45758 .69 .46617 .70502 .46152 .69797 .45288 Mtetra
.69797 .45288 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Mtetra
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.702 .796 .923 r
.33814 .75477 .34701 .76107 .3613 .75442 .35245 .74881 Mtetra
.743 .819 .911 r
.35245 .74881 .3613 .75442 .37573 .74541 .3669 .74108 Mtetra
.803 .851 .887 r
.3669 .74108 .37573 .74541 .39036 .73243 .38152 .73025 Mtetra
.873 .885 .84 r
.38152 .73025 .39036 .73243 .40519 .71334 .39634 .7144 Mtetra
.934 .907 .771 r
.39634 .7144 .40519 .71334 .42022 .68637 .41137 .69138 Mtetra
.97 .914 .695 r
.41137 .69138 .42022 .68637 .43532 .65208 .42656 .66031 Mtetra
.98 .913 .64 r
.42656 .66031 .43532 .65208 .45032 .61484 .44173 .62362 Mtetra
.978 .918 .628 r
.44173 .62362 .45032 .61484 .46506 .58092 .45671 .58715 Mtetra
.97 .932 .672 r
.45671 .58715 .46506 .58092 .47952 .55438 .4714 .55653 Mtetra
.943 .937 .758 r
.4714 .55653 .47952 .55438 .49381 .53552 .48585 .53387 Mtetra
.884 .911 .84 r
.48585 .53387 .49381 .53552 .50802 .5225 .50018 .51812 Mtetra
.811 .861 .886 r
.50018 .51812 .50802 .5225 .52222 .51323 .51446 .50714 Mtetra
.751 .815 .903 r
.51446 .50714 .52222 .51323 .53646 .50615 .52877 .49906 Mtetra
.712 .783 .907 r
.52877 .49906 .53646 .50615 .55077 .50028 .54312 .49261 Mtetra
.69 .764 .908 r
.54312 .49261 .55077 .50028 .56514 .49505 .55755 .48705 Mtetra
.678 .754 .908 r
.55755 .48705 .56514 .49505 .57959 .49016 .57205 .48196 Mtetra
.671 .748 .908 r
.57205 .48196 .57959 .49016 .59412 .48543 .58662 .47711 Mtetra
.667 .745 .908 r
.58662 .47711 .59412 .48543 .60872 .48077 .60128 .47237 Mtetra
.666 .743 .908 r
.60128 .47237 .60872 .48077 .6234 .47615 .61601 .46768 Mtetra
.665 .742 .908 r
.61601 .46768 .6234 .47615 .63815 .47152 .63082 .463 Mtetra
.664 .742 .908 r
.63082 .463 .63815 .47152 .65299 .46689 .64571 .45831 Mtetra
.64571 .45831 .65299 .46689 .6679 .46224 .66067 .45362 Mtetra
.664 .741 .908 r
.66067 .45362 .6679 .46224 .6829 .45758 .67572 .4489 Mtetra
.67572 .4489 .6829 .45758 .69797 .45288 .69085 .44416 Mtetra
.69085 .44416 .69797 .45288 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42905 .76773 .42009 Mtetra
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.688 .787 .926 r
.3292 .74816 .33814 .75477 .35245 .74881 .34353 .74271 Mtetra
.72 .806 .918 r
.34353 .74271 .35245 .74881 .3669 .74108 .358 .73593 Mtetra
.771 .835 .901 r
.358 .73593 .3669 .74108 .38152 .73025 .37261 .72679 Mtetra
.838 .869 .867 r
.37261 .72679 .38152 .73025 .39634 .7144 .38742 .71364 Mtetra
.906 .898 .808 r
.38742 .71364 .39634 .7144 .41137 .69138 .40245 .69434 Mtetra
.956 .912 .732 r
.40245 .69434 .41137 .69138 .42656 .66031 .41767 .6671 Mtetra
.977 .914 .664 r
.41767 .6671 .42656 .66031 .44173 .62362 .43298 .6325 Mtetra
.98 .915 .628 r
.43298 .6325 .44173 .62362 .45671 .58715 .44818 .59493 Mtetra
.975 .925 .643 r
.44818 .59493 .45671 .58715 .4714 .55653 .46311 .56072 Mtetra
.96 .938 .712 r
.46311 .56072 .4714 .55653 .48585 .53387 .47777 .53393 Mtetra
.917 .929 .803 r
.47777 .53393 .48585 .53387 .50018 .51812 .49223 .51488 Mtetra
.847 .887 .867 r
.49223 .51488 .50018 .51812 .51446 .50714 .50661 .5017 Mtetra
.778 .836 .896 r
.50661 .5017 .51446 .50714 .52877 .49906 .52099 .4923 Mtetra
.729 .797 .906 r
.52099 .4923 .52877 .49906 .54312 .49261 .5354 .48509 Mtetra
.7 .772 .908 r
.5354 .48509 .54312 .49261 .55755 .48705 .54988 .4791 Mtetra
.683 .758 .908 r
.54988 .4791 .55755 .48705 .57205 .48196 .56443 .47375 Mtetra
.674 .75 .908 r
.56443 .47375 .57205 .48196 .58662 .47711 .57906 .46874 Mtetra
.669 .746 .908 r
.57906 .46874 .58662 .47711 .60128 .47237 .59376 .4639 Mtetra
.666 .744 .908 r
.59376 .4639 .60128 .47237 .61601 .46768 .60855 .45913 Mtetra
.665 .743 .908 r
.60855 .45913 .61601 .46768 .63082 .463 .62341 .45439 Mtetra
.664 .742 .908 r
.62341 .45439 .63082 .463 .64571 .45831 .63835 .44965 Mtetra
.63835 .44965 .64571 .45831 .66067 .45362 .65337 .44491 Mtetra
.664 .741 .908 r
.65337 .44491 .66067 .45362 .67572 .4489 .66847 .44014 Mtetra
.66847 .44014 .67572 .4489 .69085 .44416 .68366 .43535 Mtetra
.68366 .43535 .69085 .44416 .70606 .4394 .69892 .43054 Mtetra
.69892 .43054 .70606 .4394 .72135 .43461 .71427 .42571 Mtetra
.71427 .42571 .72135 .43461 .73673 .4298 .72971 .42084 Mtetra
.72971 .42084 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.677 .781 .928 r
.32017 .74131 .3292 .74816 .34353 .74271 .33454 .73622 Mtetra
.702 .796 .923 r
.33454 .73622 .34353 .74271 .358 .73593 .34902 .73015 Mtetra
.743 .819 .911 r
.34902 .73015 .358 .73593 .37261 .72679 .36365 .72229 Mtetra
.803 .852 .887 r
.36365 .72229 .37261 .72679 .38742 .71364 .37845 .71131 Mtetra
.873 .885 .84 r
.37845 .71131 .38742 .71364 .40245 .69434 .39346 .69528 Mtetra
.935 .908 .771 r
.39346 .69528 .40245 .69434 .41767 .6671 .40869 .67202 Mtetra
.97 .914 .695 r
.40869 .67202 .41767 .6671 .43298 .6325 .42408 .64064 Mtetra
.98 .914 .64 r
.42408 .64064 .43298 .6325 .44818 .59493 .43946 .60363 Mtetra
.978 .918 .628 r
.43946 .60363 .44818 .59493 .46311 .56072 .45464 .56684 Mtetra
.97 .932 .672 r
.45464 .56684 .46311 .56072 .47777 .53393 .46953 .53595 Mtetra
.943 .937 .758 r
.46953 .53595 .47777 .53393 .49223 .51488 .48417 .51307 Mtetra
.884 .911 .84 r
.48417 .51307 .49223 .51488 .50661 .5017 .49866 .49714 Mtetra
.811 .861 .885 r
.49866 .49714 .50661 .5017 .52099 .4923 .51312 .48601 Mtetra
.751 .815 .902 r
.51312 .48601 .52099 .4923 .5354 .48509 .52761 .4778 Mtetra
.712 .783 .907 r
.52761 .4778 .5354 .48509 .54988 .4791 .54214 .47123 Mtetra
.69 .764 .908 r
.54214 .47123 .54988 .4791 .56443 .47375 .55674 .46555 Mtetra
.678 .754 .908 r
.55674 .46555 .56443 .47375 .57906 .46874 .57142 .46034 Mtetra
.671 .748 .908 r
.57142 .46034 .57906 .46874 .59376 .4639 .58618 .45537 Mtetra
.667 .745 .908 r
.58618 .45537 .59376 .4639 .60855 .45913 .60101 .45052 Mtetra
.666 .743 .908 r
.60101 .45052 .60855 .45913 .62341 .45439 .61593 .44571 Mtetra
.665 .742 .908 r
.61593 .44571 .62341 .45439 .63835 .44965 .63092 .44091 Mtetra
.664 .742 .908 r
.63092 .44091 .63835 .44965 .65337 .44491 .646 .43611 Mtetra
.646 .43611 .65337 .44491 .66847 .44014 .66116 .43129 Mtetra
.664 .741 .908 r
.66116 .43129 .66847 .44014 .68366 .43535 .6764 .42646 Mtetra
.6764 .42646 .68366 .43535 .69892 .43054 .69172 .4216 Mtetra
.69172 .4216 .69892 .43054 .71427 .42571 .70712 .41671 Mtetra
.70712 .41671 .71427 .42571 .72971 .42084 .72262 .4118 Mtetra
.72262 .4118 .72971 .42084 .74522 .41596 .73819 .40686 Mtetra
.73819 .40686 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.669 .776 .93 r
.31106 .73427 .32017 .74131 .33454 .73622 .32546 .72944 Mtetra
.688 .787 .926 r
.32546 .72944 .33454 .73622 .34902 .73015 .33997 .72387 Mtetra
.72 .806 .918 r
.33997 .72387 .34902 .73015 .36365 .72229 .35461 .71697 Mtetra
.771 .835 .901 r
.35461 .71697 .36365 .72229 .37845 .71131 .36941 .70769 Mtetra
.838 .869 .867 r
.36941 .70769 .37845 .71131 .39346 .69528 .38441 .69437 Mtetra
.907 .899 .808 r
.38441 .69437 .39346 .69528 .40869 .67202 .39963 .67485 Mtetra
.956 .913 .732 r
.39963 .67485 .40869 .67202 .42408 .64064 .41506 .64735 Mtetra
.977 .914 .663 r
.41506 .64735 .42408 .64064 .43946 .60363 .43058 .61243 Mtetra
.98 .915 .628 r
.43058 .61243 .43946 .60363 .45464 .56684 .44598 .57453 Mtetra
.975 .925 .643 r
.44598 .57453 .45464 .56684 .46953 .53595 .46112 .54001 Mtetra
.96 .937 .712 r
.46112 .54001 .46953 .53595 .48417 .51307 .47596 .51298 Mtetra
.917 .928 .803 r
.47596 .51298 .48417 .51307 .49866 .49714 .49061 .49373 Mtetra
.847 .887 .867 r
.49061 .49373 .49866 .49714 .51312 .48601 .50517 .48038 Mtetra
.778 .836 .896 r
.50517 .48038 .51312 .48601 .52761 .4778 .51972 .47084 Mtetra
.729 .797 .906 r
.51972 .47084 .52761 .4778 .54214 .47123 .53432 .4635 Mtetra
.7 .772 .908 r
.53432 .4635 .54214 .47123 .55674 .46555 .54897 .45739 Mtetra
.683 .758 .908 r
.54897 .45739 .55674 .46555 .57142 .46034 .5637 .45193 Mtetra
.674 .75 .908 r
.5637 .45193 .57142 .46034 .58618 .45537 .57851 .4468 Mtetra
.669 .746 .908 r
.57851 .4468 .58618 .45537 .60101 .45052 .5934 .44183 Mtetra
.666 .744 .908 r
.5934 .44183 .60101 .45052 .61593 .44571 .60837 .43695 Mtetra
.665 .743 .908 r
.60837 .43695 .61593 .44571 .63092 .44091 .62342 .43209 Mtetra
.664 .742 .908 r
.62342 .43209 .63092 .44091 .646 .43611 .63855 .42723 Mtetra
.63855 .42723 .646 .43611 .66116 .43129 .65376 .42236 Mtetra
.664 .741 .908 r
.65376 .42236 .66116 .43129 .6764 .42646 .66906 .41747 Mtetra
.66906 .41747 .6764 .42646 .69172 .4216 .68444 .41256 Mtetra
.68444 .41256 .69172 .4216 .70712 .41671 .6999 .40763 Mtetra
.6999 .40763 .70712 .41671 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40686 .73109 .39768 Mtetra
.73109 .39768 .73819 .40686 .75385 .4019 .74681 .39266 Mtetra
.74681 .39266 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.663 .772 .931 r
.30186 .72706 .31106 .73427 .32546 .72944 .3163 .7224 Mtetra
.677 .781 .928 r
.3163 .7224 .32546 .72944 .33997 .72387 .33084 .7172 Mtetra
.702 .796 .923 r
.33084 .7172 .33997 .72387 .35461 .71697 .3455 .71101 Mtetra
.743 .819 .911 r
.3455 .71101 .35461 .71697 .36941 .70769 .36031 .70302 Mtetra
.803 .852 .887 r
.36031 .70302 .36941 .70769 .38441 .69437 .3753 .69189 Mtetra
.873 .886 .84 r
.3753 .69189 .38441 .69437 .39963 .67485 .39051 .67565 Mtetra
.935 .908 .771 r
.39051 .67565 .39963 .67485 .41506 .64735 .40594 .65215 Mtetra
.97 .914 .695 r
.40594 .65215 .41506 .64735 .43058 .61243 .42154 .62048 Mtetra
.98 .914 .64 r
.42154 .62048 .43058 .61243 .44598 .57453 .43714 .58314 Mtetra
.978 .918 .628 r
.43714 .58314 .44598 .57453 .46112 .54001 .45253 .54603 Mtetra
.97 .932 .672 r
.45253 .54603 .46112 .54001 .47596 .51298 .46761 .51485 Mtetra
.943 .937 .758 r
.46761 .51485 .47596 .51298 .49061 .49373 .48243 .49175 Mtetra
.884 .911 .84 r
.48243 .49175 .49061 .49373 .50517 .48038 .49712 .47564 Mtetra
.811 .861 .885 r
.49712 .47564 .50517 .48038 .51972 .47084 .51176 .46436 Mtetra
.751 .815 .902 r
.51176 .46436 .51972 .47084 .53432 .4635 .52642 .456 Mtetra
.712 .783 .907 r
.52642 .456 .53432 .4635 .54897 .45739 .54113 .44931 Mtetra
.69 .764 .908 r
.54113 .44931 .54897 .45739 .5637 .45193 .55591 .44351 Mtetra
.678 .754 .908 r
.55591 .44351 .5637 .45193 .57851 .4468 .57077 .43818 Mtetra
.671 .748 .908 r
.57077 .43818 .57851 .4468 .5934 .44183 .58572 .43309 Mtetra
.667 .745 .908 r
.58572 .43309 .5934 .44183 .60837 .43695 .60074 .42811 Mtetra
.666 .743 .908 r
.60074 .42811 .60837 .43695 .62342 .43209 .61584 .42318 Mtetra
.665 .742 .908 r
.61584 .42318 .62342 .43209 .63855 .42723 .63103 .41826 Mtetra
.664 .742 .908 r
.63103 .41826 .63855 .42723 .65376 .42236 .6463 .41334 Mtetra
.6463 .41334 .65376 .42236 .66906 .41747 .66165 .4084 Mtetra
.664 .741 .908 r
.66165 .4084 .66906 .41747 .68444 .41256 .67709 .40344 Mtetra
.67709 .40344 .68444 .41256 .6999 .40763 .69261 .39845 Mtetra
.69261 .39845 .6999 .40763 .71545 .40267 .70822 .39344 Mtetra
.70822 .39344 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39266 .73969 .38333 Mtetra
.73969 .38333 .74681 .39266 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.658 .77 .932 r
.29257 .71971 .30186 .72706 .3163 .7224 .30705 .71517 Mtetra
.669 .776 .93 r
.30705 .71517 .3163 .7224 .33084 .7172 .32163 .71023 Mtetra
.688 .787 .926 r
.32163 .71023 .33084 .7172 .3455 .71101 .33631 .70455 Mtetra
.72 .806 .918 r
.33631 .70455 .3455 .71101 .36031 .70302 .35114 .69752 Mtetra
.771 .835 .901 r
.35114 .69752 .36031 .70302 .3753 .69189 .36613 .68809 Mtetra
.838 .869 .867 r
.36613 .68809 .3753 .69189 .39051 .67565 .38132 .6746 Mtetra
.907 .899 .808 r
.38132 .6746 .39051 .67565 .40594 .65215 .39674 .65486 Mtetra
.956 .913 .732 r
.39674 .65486 .40594 .65215 .42154 .62048 .41238 .62708 Mtetra
.977 .914 .663 r
.41238 .62708 .42154 .62048 .43714 .58314 .42812 .59184 Mtetra
.98 .915 .628 r
.42812 .59184 .43714 .58314 .45253 .54603 .44374 .55361 Mtetra
.975 .924 .643 r
.44374 .55361 .45253 .54603 .46761 .51485 .45908 .51878 Mtetra
.96 .937 .712 r
.45908 .51878 .46761 .51485 .48243 .49175 .47412 .4915 Mtetra
.917 .928 .803 r
.47412 .4915 .48243 .49175 .49712 .47564 .48895 .47204 Mtetra
.847 .887 .867 r
.48895 .47204 .49712 .47564 .51176 .46436 .50369 .45853 Mtetra
.778 .836 .896 r
.50369 .45853 .51176 .46436 .52642 .456 .51843 .44884 Mtetra
.729 .797 .906 r
.51843 .44884 .52642 .456 .54113 .44931 .5332 .44137 Mtetra
.7 .772 .908 r
.5332 .44137 .54113 .44931 .55591 .44351 .54804 .43513 Mtetra
.683 .758 .908 r
.54804 .43513 .55591 .44351 .57077 .43818 .56296 .42954 Mtetra
.674 .75 .908 r
.56296 .42954 .57077 .43818 .58572 .43309 .57795 .42429 Mtetra
.669 .746 .908 r
.57795 .42429 .58572 .43309 .60074 .42811 .59303 .41921 Mtetra
.666 .744 .908 r
.59303 .41921 .60074 .42811 .61584 .42318 .60819 .41419 Mtetra
.665 .743 .908 r
.60819 .41419 .61584 .42318 .63103 .41826 .62343 .40921 Mtetra
.664 .742 .908 r
.62343 .40921 .63103 .41826 .6463 .41334 .63875 .40423 Mtetra
.63875 .40423 .6463 .41334 .66165 .4084 .65417 .39923 Mtetra
.664 .741 .908 r
.65417 .39923 .66165 .4084 .67709 .40344 .66966 .39422 Mtetra
.66966 .39422 .67709 .40344 .69261 .39845 .68524 .38918 Mtetra
.68524 .38918 .69261 .39845 .70822 .39344 .70091 .38412 Mtetra
.70091 .38412 .70822 .39344 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38333 .7325 .37391 Mtetra
.7325 .37391 .73969 .38333 .75556 .37824 .74843 .36876 Mtetra
.74843 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.655 .768 .932 r
.28319 .71223 .29257 .71971 .30705 .71517 .29771 .70777 Mtetra
.663 .772 .931 r
.29771 .70777 .30705 .71517 .32163 .71023 .31233 .703 Mtetra
.677 .781 .928 r
.31233 .703 .32163 .71023 .33631 .70455 .32705 .69769 Mtetra
.702 .796 .923 r
.32705 .69769 .33631 .70455 .35114 .69752 .34189 .69137 Mtetra
.743 .819 .912 r
.34189 .69137 .35114 .69752 .36613 .68809 .35689 .68324 Mtetra
.803 .852 .887 r
.35689 .68324 .36613 .68809 .38132 .6746 .37207 .67195 Mtetra
.873 .886 .84 r
.37207 .67195 .38132 .6746 .39674 .65486 .38748 .65552 Mtetra
.935 .908 .771 r
.38748 .65552 .39674 .65486 .41238 .62708 .40312 .63177 Mtetra
.97 .914 .695 r
.40312 .63177 .41238 .62708 .42812 .59184 .41894 .59979 Mtetra
.98 .914 .64 r
.41894 .59979 .42812 .59184 .44374 .55361 .43475 .56211 Mtetra
.978 .918 .628 r
.43475 .56211 .44374 .55361 .45908 .51878 .45035 .52468 Mtetra
.97 .932 .672 r
.45035 .52468 .45908 .51878 .47412 .4915 .46564 .49322 Mtetra
.943 .937 .758 r
.46564 .49322 .47412 .4915 .48895 .47204 .48066 .46989 Mtetra
.884 .91 .84 r
.48066 .46989 .48895 .47204 .50369 .45853 .49553 .45359 Mtetra
.811 .861 .885 r
.49553 .45359 .50369 .45853 .51843 .44884 .51035 .44215 Mtetra
.751 .815 .902 r
.51035 .44215 .51843 .44884 .5332 .44137 .5252 .43366 Mtetra
.712 .783 .907 r
.5252 .43366 .5332 .44137 .54804 .43513 .5401 .42683 Mtetra
.69 .764 .908 r
.5401 .42683 .54804 .43513 .56296 .42954 .55506 .4209 Mtetra
.678 .754 .908 r
.55506 .4209 .56296 .42954 .57795 .42429 .57011 .41545 Mtetra
.671 .748 .908 r
.57011 .41545 .57795 .42429 .59303 .41921 .58524 .41023 Mtetra
.667 .745 .908 r
.58524 .41023 .59303 .41921 .60819 .41419 .60046 .40513 Mtetra
.666 .743 .908 r
.60046 .40513 .60819 .41419 .62343 .40921 .61575 .40007 Mtetra
.665 .742 .908 r
.61575 .40007 .62343 .40921 .63875 .40423 .63114 .39503 Mtetra
.664 .742 .908 r
.63114 .39503 .63875 .40423 .65417 .39923 .6466 .38998 Mtetra
.6466 .38998 .65417 .39923 .66966 .39422 .66216 .38491 Mtetra
.664 .741 .908 r
.66216 .38491 .66966 .39422 .68524 .38918 .6778 .37982 Mtetra
.6778 .37982 .68524 .38918 .70091 .38412 .69352 .3747 Mtetra
.69352 .3747 .70091 .38412 .71666 .37903 .70934 .36956 Mtetra
.70934 .36956 .71666 .37903 .7325 .37391 .72524 .36438 Mtetra
.72524 .36438 .7325 .37391 .74843 .36876 .74123 .35918 Mtetra
.74123 .35918 .74843 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.652 .766 .933 r
.27371 .70464 .28319 .71223 .29771 .70777 .28828 .70022 Mtetra
.658 .77 .932 r
.28828 .70022 .29771 .70777 .31233 .703 .30293 .69558 Mtetra
.669 .776 .93 r
.30293 .69558 .31233 .703 .32705 .69769 .31769 .69052 Mtetra
.688 .787 .926 r
.31769 .69052 .32705 .69769 .34189 .69137 .33256 .68472 Mtetra
.72 .806 .918 r
.33256 .68472 .34189 .69137 .35689 .68324 .34757 .67756 Mtetra
.771 .835 .901 r
.34757 .67756 .35689 .68324 .37207 .67195 .36275 .66798 Mtetra
.838 .87 .867 r
.36275 .66798 .37207 .67195 .38748 .65552 .37815 .65431 Mtetra
.907 .899 .808 r
.37815 .65431 .38748 .65552 .40312 .63177 .39378 .63435 Mtetra
.956 .913 .732 r
.39378 .63435 .40312 .63177 .41894 .59979 .40964 .60628 Mtetra
.978 .914 .663 r
.40964 .60628 .41894 .59979 .43475 .56211 .42559 .57072 Mtetra
.98 .915 .628 r
.42559 .57072 .43475 .56211 .45035 .52468 .44143 .53215 Mtetra
.975 .924 .643 r
.44143 .53215 .45035 .52468 .46564 .49322 .45698 .49701 Mtetra
.96 .937 .713 r
.45698 .49701 .46564 .49322 .48066 .46989 .47222 .46947 Mtetra
.917 .928 .803 r
.47222 .46947 .48066 .46989 .49553 .45359 .48725 .4498 Mtetra
.847 .886 .867 r
.48725 .4498 .49553 .45359 .51035 .44215 .50218 .43612 Mtetra
.778 .836 .896 r
.50218 .43612 .51035 .44215 .5252 .43366 .5171 .42628 Mtetra
.729 .797 .906 r
.5171 .42628 .5252 .43366 .5401 .42683 .53206 .41867 Mtetra
.7 .772 .908 r
.53206 .41867 .5401 .42683 .55506 .4209 .54709 .4123 Mtetra
.683 .758 .908 r
.54709 .4123 .55506 .4209 .57011 .41545 .56219 .40658 Mtetra
.674 .75 .908 r
.56219 .40658 .57011 .41545 .58524 .41023 .57738 .40121 Mtetra
.669 .746 .908 r
.57738 .40121 .58524 .41023 .60046 .40513 .59265 .39599 Mtetra
.666 .744 .908 r
.59265 .39599 .60046 .40513 .61575 .40007 .608 .39085 Mtetra
.665 .743 .908 r
.608 .39085 .61575 .40007 .63114 .39503 .62344 .38574 Mtetra
.664 .742 .908 r
.62344 .38574 .63114 .39503 .6466 .38998 .63897 .38063 Mtetra
.63897 .38063 .6466 .38998 .66216 .38491 .65458 .3755 Mtetra
.664 .741 .908 r
.65458 .3755 .66216 .38491 .6778 .37982 .67028 .37036 Mtetra
.67028 .37036 .6778 .37982 .69352 .3747 .68606 .36519 Mtetra
.68606 .36519 .69352 .3747 .70934 .36956 .70194 .35999 Mtetra
.70194 .35999 .70934 .36956 .72524 .36438 .7179 .35476 Mtetra
.7179 .35476 .72524 .36438 .74123 .35918 .73396 .34951 Mtetra
.73396 .34951 .74123 .35918 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.651 .765 .933 r
.26414 .69695 .27371 .70464 .28828 .70022 .27875 .69255 Mtetra
.655 .768 .932 r
.27875 .69255 .28828 .70022 .30293 .69558 .29345 .68797 Mtetra
.663 .772 .931 r
.29345 .68797 .30293 .69558 .31769 .69052 .30825 .6831 Mtetra
.677 .781 .929 r
.30825 .6831 .31769 .69052 .33256 .68472 .32315 .67766 Mtetra
.702 .796 .923 r
.32315 .67766 .33256 .68472 .34757 .67756 .33818 .67122 Mtetra
.743 .82 .912 r
.33818 .67122 .34757 .67756 .36275 .66798 .35337 .66294 Mtetra
.803 .852 .887 r
.35337 .66294 .36275 .66798 .37815 .65431 .36875 .65149 Mtetra
.873 .886 .84 r
.36875 .65149 .37815 .65431 .39378 .63435 .38437 .63485 Mtetra
.935 .908 .77 r
.38437 .63485 .39378 .63435 .40964 .60628 .40023 .61085 Mtetra
.97 .914 .695 r
.40023 .61085 .40964 .60628 .42559 .57072 .41627 .57856 Mtetra
.98 .914 .64 r
.41627 .57856 .42559 .57072 .44143 .53215 .43231 .54054 Mtetra
.978 .918 .628 r
.43231 .54054 .44143 .53215 .45698 .49701 .44813 .50277 Mtetra
.97 .932 .673 r
.44813 .50277 .45698 .49701 .47222 .46947 .46362 .47103 Mtetra
.943 .937 .759 r
.46362 .47103 .47222 .46947 .48725 .4498 .47884 .44746 Mtetra
.884 .91 .84 r
.47884 .44746 .48725 .4498 .50218 .43612 .4939 .43098 Mtetra
.811 .861 .885 r
.4939 .43098 .50218 .43612 .5171 .42628 .50891 .41938 Mtetra
.751 .815 .902 r
.50891 .41938 .5171 .42628 .53206 .41867 .52395 .41074 Mtetra
.712 .783 .907 r
.52395 .41074 .53206 .41867 .54709 .4123 .53903 .40378 Mtetra
.69 .764 .908 r
.53903 .40378 .54709 .4123 .56219 .40658 .55419 .39772 Mtetra
.678 .754 .908 r
.55419 .39772 .56219 .40658 .57738 .40121 .56943 .39213 Mtetra
.671 .748 .908 r
.56943 .39213 .57738 .40121 .59265 .39599 .58476 .38679 Mtetra
.667 .745 .908 r
.58476 .38679 .59265 .39599 .608 .39085 .60017 .38155 Mtetra
.666 .743 .908 r
.60017 .38155 .608 .39085 .62344 .38574 .61567 .37636 Mtetra
.665 .742 .908 r
.61567 .37636 .62344 .38574 .63897 .38063 .63125 .37119 Mtetra
.664 .742 .908 r
.63125 .37119 .63897 .38063 .65458 .3755 .64692 .366 Mtetra
.64692 .366 .65458 .3755 .67028 .37036 .66268 .3608 Mtetra
.664 .741 .908 r
.66268 .3608 .67028 .37036 .68606 .36519 .67853 .35557 Mtetra
.67853 .35557 .68606 .36519 .70194 .35999 .69446 .35032 Mtetra
.69446 .35032 .70194 .35999 .7179 .35476 .71049 .34504 Mtetra
.71049 .34504 .7179 .35476 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.649 .764 .933 r
.25447 .68916 .26414 .69695 .27875 .69255 .26913 .68476 Mtetra
.652 .766 .933 r
.26913 .68476 .27875 .69255 .29345 .68797 .28387 .68022 Mtetra
.658 .77 .932 r
.28387 .68022 .29345 .68797 .30825 .6831 .29871 .67546 Mtetra
.669 .776 .93 r
.29871 .67546 .30825 .6831 .32315 .67766 .31365 .67029 Mtetra
.688 .787 .926 r
.31365 .67029 .32315 .67766 .33818 .67122 .32871 .66436 Mtetra
.72 .806 .919 r
.32871 .66436 .33818 .67122 .35337 .66294 .34391 .65706 Mtetra
.771 .835 .902 r
.34391 .65706 .35337 .66294 .36875 .65149 .35929 .64733 Mtetra
.838 .87 .867 r
.35929 .64733 .36875 .65149 .38437 .63485 .37489 .63348 Mtetra
.907 .899 .808 r
.37489 .63348 .38437 .63485 .40023 .61085 .39074 .61328 Mtetra
.956 .913 .732 r
.39074 .61328 .40023 .61085 .41627 .57856 .40681 .58494 Mtetra
.978 .914 .663 r
.40681 .58494 .41627 .57856 .43231 .54054 .423 .54904 Mtetra
.98 .915 .628 r
.423 .54904 .43231 .54054 .44813 .50277 .43906 .51012 Mtetra
.975 .924 .644 r
.43906 .51012 .44813 .50277 .46362 .47103 .45483 .47467 Mtetra
.96 .937 .713 r
.45483 .47467 .46362 .47103 .47884 .44746 .47028 .44687 Mtetra
.917 .928 .803 r
.47028 .44687 .47884 .44746 .4939 .43098 .4855 .42699 Mtetra
.847 .886 .867 r
.4855 .42699 .4939 .43098 .50891 .41938 .50063 .41314 Mtetra
.778 .836 .896 r
.50063 .41314 .50891 .41938 .52395 .41074 .51574 .40314 Mtetra
.729 .797 .906 r
.51574 .40314 .52395 .41074 .53903 .40378 .53089 .39539 Mtetra
.7 .772 .908 r
.53089 .39539 .53903 .40378 .55419 .39772 .54611 .38888 Mtetra
.683 .758 .908 r
.54611 .38888 .55419 .39772 .56943 .39213 .56141 .38303 Mtetra
.674 .75 .908 r
.56141 .38303 .56943 .39213 .58476 .38679 .57679 .37752 Mtetra
.669 .746 .908 r
.57679 .37752 .58476 .38679 .60017 .38155 .59226 .37217 Mtetra
.666 .744 .908 r
.59226 .37217 .60017 .38155 .61567 .37636 .60781 .3669 Mtetra
.665 .743 .908 r
.60781 .3669 .61567 .37636 .63125 .37119 .62345 .36165 Mtetra
.664 .742 .908 r
.62345 .36165 .63125 .37119 .64692 .366 .63918 .35641 Mtetra
.63918 .35641 .64692 .366 .66268 .3608 .655 .35115 Mtetra
.664 .741 .908 r
.655 .35115 .66268 .3608 .67853 .35557 .67091 .34586 Mtetra
.67091 .34586 .67853 .35557 .69446 .35032 .68691 .34055 Mtetra
.68691 .34055 .69446 .35032 .71049 .34504 .703 .33522 Mtetra
.703 .33522 .71049 .34504 .72661 .33973 .71918 .32985 Mtetra
.71918 .32985 .72661 .33973 .74282 .33439 .73545 .32445 Mtetra
.73545 .32445 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.648 .764 .933 r
.24471 .68127 .25447 .68916 .26913 .68476 .25941 .67686 Mtetra
.651 .765 .933 r
.25941 .67686 .26913 .68476 .28387 .68022 .2742 .67234 Mtetra
.655 .768 .932 r
.2742 .67234 .28387 .68022 .29871 .67546 .28908 .66765 Mtetra
.663 .772 .931 r
.28908 .66765 .29871 .67546 .31365 .67029 .30406 .66266 Mtetra
.677 .781 .929 r
.30406 .66266 .31365 .67029 .32871 .66436 .31915 .6571 Mtetra
.702 .796 .923 r
.31915 .6571 .32871 .66436 .34391 .65706 .33438 .65052 Mtetra
.743 .82 .912 r
.33438 .65052 .34391 .65706 .35929 .64733 .34976 .6421 Mtetra
.803 .852 .887 r
.34976 .6421 .35929 .64733 .37489 .63348 .36535 .63047 Mtetra
.874 .886 .84 r
.36535 .63047 .37489 .63348 .39074 .61328 .38117 .61363 Mtetra
.935 .909 .77 r
.38117 .61363 .39074 .61328 .40681 .58494 .39726 .58937 Mtetra
.97 .915 .694 r
.39726 .58937 .40681 .58494 .423 .54904 .41353 .55677 Mtetra
.98 .914 .64 r
.41353 .55677 .423 .54904 .43906 .51012 .42979 .5184 Mtetra
.978 .918 .629 r
.42979 .5184 .43906 .51012 .45483 .47467 .44584 .4803 Mtetra
.97 .932 .673 r
.44584 .4803 .45483 .47467 .47028 .44687 .46155 .44826 Mtetra
.943 .936 .759 r
.46155 .44826 .47028 .44687 .4855 .42699 .47697 .42446 Mtetra
.884 .91 .84 r
.47697 .42446 .4855 .42699 .50063 .41314 .49223 .40778 Mtetra
.811 .86 .885 r
.49223 .40778 .50063 .41314 .51574 .40314 .50744 .39601 Mtetra
.751 .814 .902 r
.50744 .39601 .51574 .40314 .53089 .39539 .52266 .38722 Mtetra
.712 .783 .907 r
.52266 .38722 .53089 .39539 .54611 .38888 .53794 .38012 Mtetra
.69 .764 .908 r
.53794 .38012 .54611 .38888 .56141 .38303 .5533 .37392 Mtetra
.678 .754 .908 r
.5533 .37392 .56141 .38303 .57679 .37752 .56874 .3682 Mtetra
.671 .748 .908 r
.56874 .3682 .57679 .37752 .59226 .37217 .58426 .36272 Mtetra
.667 .745 .908 r
.58426 .36272 .59226 .37217 .60781 .3669 .59987 .35735 Mtetra
.666 .743 .908 r
.59987 .35735 .60781 .3669 .62345 .36165 .61557 .35203 Mtetra
.665 .742 .908 r
.61557 .35203 .62345 .36165 .63918 .35641 .63136 .34671 Mtetra
.664 .742 .908 r
.63136 .34671 .63918 .35641 .655 .35115 .64724 .34139 Mtetra
.64724 .34139 .655 .35115 .67091 .34586 .66321 .33605 Mtetra
.664 .741 .908 r
.66321 .33605 .67091 .34586 .68691 .34055 .67927 .33068 Mtetra
.67927 .33068 .68691 .34055 .703 .33522 .69543 .32529 Mtetra
.69543 .32529 .703 .33522 .71918 .32985 .71167 .31987 Mtetra
.71167 .31987 .71918 .32985 .73545 .32445 .72801 .31441 Mtetra
.72801 .31441 .73545 .32445 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.648 .763 .933 r
.23484 .67329 .24471 .68127 .25941 .67686 .24959 .66886 Mtetra
.649 .764 .933 r
.24959 .66886 .25941 .67686 .2742 .67234 .26442 .66434 Mtetra
.652 .766 .933 r
.26442 .66434 .2742 .67234 .28908 .66765 .27935 .65969 Mtetra
.658 .77 .932 r
.27935 .65969 .28908 .66765 .30406 .66266 .29437 .65481 Mtetra
.669 .776 .93 r
.29437 .65481 .30406 .66266 .31915 .6571 .30951 .64951 Mtetra
.688 .787 .926 r
.30951 .64951 .31915 .6571 .33438 .65052 .32476 .64346 Mtetra
.72 .807 .919 r
.32476 .64346 .33438 .65052 .34976 .6421 .34016 .63602 Mtetra
.771 .835 .902 r
.34016 .63602 .34976 .6421 .36535 .63047 .35574 .62613 Mtetra
.838 .87 .867 r
.35574 .62613 .36535 .63047 .38117 .61363 .37154 .61208 Mtetra
.907 .9 .808 r
.37154 .61208 .38117 .61363 .39726 .58937 .38761 .59165 Mtetra
.956 .913 .731 r
.38761 .59165 .39726 .58937 .41353 .55677 .40392 .56302 Mtetra
.978 .914 .663 r
.40392 .56302 .41353 .55677 .42979 .5184 .42034 .52678 Mtetra
.98 .915 .628 r
.42034 .52678 .42979 .5184 .44584 .4803 .43663 .48752 Mtetra
.975 .924 .644 r
.43663 .48752 .44584 .4803 .46155 .44826 .45263 .45175 Mtetra
.96 .937 .713 r
.45263 .45175 .46155 .44826 .47697 .42446 .46829 .42368 Mtetra
.917 .927 .803 r
.46829 .42368 .47697 .42446 .49223 .40778 .48371 .40358 Mtetra
.847 .886 .867 r
.48371 .40358 .49223 .40778 .50744 .39601 .49903 .38955 Mtetra
.778 .836 .896 r
.49903 .38955 .50744 .39601 .52266 .38722 .51434 .37939 Mtetra
.729 .797 .906 r
.51434 .37939 .52266 .38722 .53794 .38012 .52969 .37149 Mtetra
.7 .772 .908 r
.52969 .37149 .53794 .38012 .5533 .37392 .54511 .36484 Mtetra
.683 .758 .908 r
.54511 .36484 .5533 .37392 .56874 .3682 .5606 .35885 Mtetra
.674 .75 .908 r
.5606 .35885 .56874 .3682 .58426 .36272 .57618 .3532 Mtetra
.669 .746 .908 r
.57618 .3532 .58426 .36272 .59987 .35735 .59185 .34772 Mtetra
.666 .744 .908 r
.59185 .34772 .59987 .35735 .61557 .35203 .60761 .34231 Mtetra
.665 .743 .908 r
.60761 .34231 .61557 .35203 .63136 .34671 .62346 .33693 Mtetra
.664 .742 .908 r
.62346 .33693 .63136 .34671 .64724 .34139 .6394 .33154 Mtetra
.6394 .33154 .64724 .34139 .66321 .33605 .65544 .32614 Mtetra
.664 .741 .908 r
.65544 .32614 .66321 .33605 .67927 .33068 .67156 .32071 Mtetra
.67156 .32071 .67927 .33068 .69543 .32529 .68778 .31526 Mtetra
.68778 .31526 .69543 .32529 .71167 .31987 .70408 .30977 Mtetra
.70408 .30977 .71167 .31987 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.647 .763 .934 r
.22486 .66522 .23484 .67329 .24959 .66886 .23966 .66076 Mtetra
.648 .764 .933 r
.23966 .66076 .24959 .66886 .26442 .66434 .25455 .65623 Mtetra
.651 .765 .933 r
.25455 .65623 .26442 .66434 .27935 .65969 .26952 .6516 Mtetra
.655 .768 .932 r
.26952 .6516 .27935 .65969 .29437 .65481 .28459 .64679 Mtetra
.663 .772 .931 r
.28459 .64679 .29437 .65481 .30951 .64951 .29976 .64167 Mtetra
.677 .781 .929 r
.29976 .64167 .30951 .64951 .32476 .64346 .31505 .63598 Mtetra
.702 .796 .923 r
.31505 .63598 .32476 .64346 .34016 .63602 .33047 .62926 Mtetra
.743 .82 .912 r
.33047 .62926 .34016 .63602 .35574 .62613 .34606 .62069 Mtetra
.803 .852 .887 r
.34606 .62069 .35574 .62613 .37154 .61208 .36185 .60889 Mtetra
.874 .886 .84 r
.36185 .60889 .37154 .61208 .38761 .59165 .37789 .59184 Mtetra
.935 .909 .77 r
.37789 .59184 .38761 .59165 .40392 .56302 .3942 .5673 Mtetra
.97 .915 .694 r
.3942 .5673 .40392 .56302 .42034 .52678 .41071 .53439 Mtetra
.98 .914 .64 r
.41071 .53439 .42034 .52678 .43663 .48752 .42722 .49567 Mtetra
.978 .918 .629 r
.42722 .49567 .43663 .48752 .45263 .45175 .44349 .45723 Mtetra
.97 .931 .673 r
.44349 .45723 .45263 .45175 .46829 .42368 .45942 .42489 Mtetra
.943 .936 .759 r
.45942 .42489 .46829 .42368 .48371 .40358 .47505 .40085 Mtetra
.884 .91 .84 r
.47505 .40085 .48371 .40358 .49903 .38955 .49052 .38397 Mtetra
.811 .86 .885 r
.49052 .38397 .49903 .38955 .51434 .37939 .50592 .37203 Mtetra
.751 .814 .902 r
.50592 .37203 .51434 .37939 .52969 .37149 .52135 .36309 Mtetra
.712 .783 .907 r
.52135 .36309 .52969 .37149 .54511 .36484 .53683 .35584 Mtetra
.69 .764 .908 r
.53683 .35584 .54511 .36484 .5606 .35885 .55238 .3495 Mtetra
.678 .754 .908 r
.55238 .3495 .5606 .35885 .57618 .3532 .56802 .34364 Mtetra
.671 .748 .908 r
.56802 .34364 .57618 .3532 .59185 .34772 .58375 .33801 Mtetra
.667 .745 .908 r
.58375 .33801 .59185 .34772 .60761 .34231 .59957 .3325 Mtetra
.666 .743 .908 r
.59957 .3325 .60761 .34231 .62346 .33693 .61548 .32704 Mtetra
.665 .742 .908 r
.61548 .32704 .62346 .33693 .6394 .33154 .63148 .32158 Mtetra
.664 .742 .908 r
.63148 .32158 .6394 .33154 .65544 .32614 .64758 .31612 Mtetra
.64758 .31612 .65544 .32614 .67156 .32071 .66376 .31063 Mtetra
.664 .741 .908 r
.66376 .31063 .67156 .32071 .68778 .31526 .68004 .30512 Mtetra
.68004 .30512 .68778 .31526 .70408 .30977 .69642 .29958 Mtetra
.69642 .29958 .70408 .30977 .72049 .30426 .71289 .294 Mtetra
.71289 .294 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.647 .763 .934 r
.21479 .65706 .22486 .66522 .23966 .66076 .22963 .65257 Mtetra
.648 .763 .933 r
.22963 .65257 .23966 .66076 .25455 .65623 .24457 .64801 Mtetra
.649 .764 .933 r
.24457 .64801 .25455 .65623 .26952 .6516 .25959 .64338 Mtetra
.652 .766 .933 r
.25959 .64338 .26952 .6516 .28459 .64679 .27471 .63861 Mtetra
.658 .77 .932 r
.27471 .63861 .28459 .64679 .29976 .64167 .28992 .6336 Mtetra
.669 .776 .93 r
.28992 .6336 .29976 .64167 .31505 .63598 .30525 .62817 Mtetra
.688 .787 .926 r
.30525 .62817 .31505 .63598 .33047 .62926 .3207 .62198 Mtetra
.72 .807 .919 r
.3207 .62198 .33047 .62926 .34606 .62069 .3363 .6144 Mtetra
.771 .835 .902 r
.3363 .6144 .34606 .62069 .36185 .60889 .35209 .60434 Mtetra
.838 .87 .867 r
.35209 .60434 .36185 .60889 .37789 .59184 .36811 .5901 Mtetra
.907 .9 .808 r
.36811 .5901 .37789 .59184 .3942 .5673 .3844 .56943 Mtetra
.956 .914 .731 r
.3844 .56943 .3942 .5673 .41071 .53439 .40094 .5405 Mtetra
.978 .914 .663 r
.40094 .5405 .41071 .53439 .42722 .49567 .4176 .50392 Mtetra
.98 .915 .628 r
.4176 .50392 .42722 .49567 .44349 .45723 .43414 .4643 Mtetra
.975 .924 .644 r
.43414 .4643 .44349 .45723 .45942 .42489 .45036 .42821 Mtetra
.96 .937 .713 r
.45036 .42821 .45942 .42489 .47505 .40085 .46624 .39987 Mtetra
.917 .927 .803 r
.46624 .39987 .47505 .40085 .49052 .38397 .48187 .37956 Mtetra
.847 .886 .867 r
.48187 .37956 .49052 .38397 .50592 .37203 .4974 .36533 Mtetra
.778 .836 .896 r
.4974 .36533 .50592 .37203 .52135 .36309 .51291 .35501 Mtetra
.729 .797 .905 r
.51291 .35501 .52135 .36309 .53683 .35584 .52846 .34696 Mtetra
.7 .772 .908 r
.52846 .34696 .53683 .35584 .55238 .3495 .54407 .34017 Mtetra
.683 .758 .908 r
.54407 .34017 .55238 .3495 .56802 .34364 .55978 .33403 Mtetra
.674 .75 .908 r
.55978 .33403 .56802 .34364 .58375 .33801 .57556 .32824 Mtetra
.669 .746 .908 r
.57556 .32824 .58375 .33801 .59957 .3325 .59144 .32261 Mtetra
.666 .744 .908 r
.59144 .32261 .59957 .3325 .61548 .32704 .60741 .31706 Mtetra
.665 .743 .908 r
.60741 .31706 .61548 .32704 .63148 .32158 .62348 .31153 Mtetra
.664 .742 .908 r
.62348 .31153 .63148 .32158 .64758 .31612 .63963 .306 Mtetra
.63963 .306 .64758 .31612 .66376 .31063 .65588 .30045 Mtetra
.664 .741 .908 r
.65588 .30045 .66376 .31063 .68004 .30512 .67223 .29487 Mtetra
.67223 .29487 .68004 .30512 .69642 .29958 .68867 .28927 Mtetra
.68867 .28927 .69642 .29958 .71289 .294 .7052 .28364 Mtetra
.7052 .28364 .71289 .294 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.647 .763 .934 r
.20461 .64881 .21479 .65706 .22963 .65257 .2195 .64428 Mtetra
.2195 .64428 .22963 .65257 .24457 .64801 .23448 .6397 Mtetra
.648 .764 .933 r
.23448 .6397 .24457 .64801 .25959 .64338 .24955 .63504 Mtetra
.651 .765 .933 r
.24955 .63504 .25959 .64338 .27471 .63861 .26472 .63029 Mtetra
.655 .768 .932 r
.26472 .63029 .27471 .63861 .28992 .6336 .27998 .62535 Mtetra
.663 .772 .931 r
.27998 .62535 .28992 .6336 .30525 .62817 .29535 .6201 Mtetra
.677 .781 .929 r
.29535 .6201 .30525 .62817 .3207 .62198 .31083 .61428 Mtetra
.702 .796 .923 r
.31083 .61428 .3207 .62198 .3363 .6144 .32645 .60742 Mtetra
.743 .82 .912 r
.32645 .60742 .3363 .6144 .35209 .60434 .34225 .5987 Mtetra
.803 .853 .887 r
.34225 .5987 .35209 .60434 .36811 .5901 .35826 .58671 Mtetra
.874 .887 .84 r
.35826 .58671 .36811 .5901 .3844 .56943 .37452 .56944 Mtetra
.935 .909 .77 r
.37452 .56944 .3844 .56943 .40094 .5405 .39107 .54464 Mtetra
.97 .915 .694 r
.39107 .54464 .40094 .5405 .4176 .50392 .40781 .51139 Mtetra
.98 .914 .639 r
.40781 .51139 .4176 .50392 .43414 .4643 .42457 .47232 Mtetra
.978 .918 .629 r
.42457 .47232 .43414 .4643 .45036 .42821 .44108 .43353 Mtetra
.97 .931 .673 r
.44108 .43353 .45036 .42821 .46624 .39987 .45724 .4009 Mtetra
.943 .936 .759 r
.45724 .4009 .46624 .39987 .48187 .37956 .47309 .37661 Mtetra
.884 .909 .84 r
.47309 .37661 .48187 .37956 .4974 .36533 .48876 .35953 Mtetra
.811 .86 .885 r
.48876 .35953 .4974 .36533 .51291 .35501 .50437 .34741 Mtetra
.751 .814 .902 r
.50437 .34741 .51291 .35501 .52846 .34696 .51999 .33831 Mtetra
.712 .783 .907 r
.51999 .33831 .52846 .34696 .54407 .34017 .53568 .3309 Mtetra
.69 .764 .908 r
.53568 .3309 .54407 .34017 .55978 .33403 .55144 .32442 Mtetra
.678 .754 .908 r
.55144 .32442 .55978 .33403 .57556 .32824 .56729 .31841 Mtetra
.671 .748 .908 r
.56729 .31841 .57556 .32824 .59144 .32261 .58323 .31264 Mtetra
.667 .745 .908 r
.58323 .31264 .59144 .32261 .60741 .31706 .59926 .30699 Mtetra
.666 .743 .908 r
.59926 .30699 .60741 .31706 .62348 .31153 .61538 .30137 Mtetra
.665 .742 .908 r
.61538 .30137 .62348 .31153 .63963 .306 .6316 .29577 Mtetra
.664 .742 .908 r
.6316 .29577 .63963 .306 .65588 .30045 .64792 .29015 Mtetra
.64792 .29015 .65588 .30045 .67223 .29487 .66433 .28451 Mtetra
.664 .741 .908 r
.66433 .28451 .67223 .29487 .68867 .28927 .68083 .27885 Mtetra
.68083 .27885 .68867 .28927 .7052 .28364 .69743 .27316 Mtetra
.69743 .27316 .7052 .28364 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25588 Mtetra
.74783 .25588 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24419 Mtetra
.78193 .24419 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .763 .934 r
.19431 .64047 .20461 .64881 .2195 .64428 .20926 .6359 Mtetra
.647 .763 .934 r
.20926 .6359 .2195 .64428 .23448 .6397 .22429 .63128 Mtetra
.648 .763 .933 r
.22429 .63128 .23448 .6397 .24955 .63504 .23941 .6266 Mtetra
.649 .764 .933 r
.23941 .6266 .24955 .63504 .26472 .63029 .25462 .62184 Mtetra
.652 .766 .933 r
.25462 .62184 .26472 .63029 .27998 .62535 .26993 .61694 Mtetra
.658 .77 .932 r
.26993 .61694 .27998 .62535 .29535 .6201 .28534 .6118 Mtetra
.669 .776 .93 r
.28534 .6118 .29535 .6201 .31083 .61428 .30087 .60624 Mtetra
.688 .787 .926 r
.30087 .60624 .31083 .61428 .32645 .60742 .31652 .59991 Mtetra
.72 .807 .919 r
.31652 .59991 .32645 .60742 .34225 .5987 .33233 .59218 Mtetra
.771 .835 .902 r
.33233 .59218 .34225 .5987 .35826 .58671 .34833 .58195 Mtetra
.838 .87 .867 r
.34833 .58195 .35826 .58671 .37452 .56944 .36458 .56751 Mtetra
.907 .9 .808 r
.36458 .56751 .37452 .56944 .39107 .54464 .3811 .5466 Mtetra
.956 .914 .731 r
.3811 .5466 .39107 .54464 .40781 .51139 .39789 .51736 Mtetra
.978 .914 .662 r
.39789 .51736 .40781 .51139 .42457 .47232 .41479 .48043 Mtetra
.98 .915 .628 r
.41479 .48043 .42457 .47232 .44108 .43353 .43158 .44046 Mtetra
.975 .924 .644 r
.43158 .44046 .44108 .43353 .45724 .4009 .44804 .40404 Mtetra
.96 .936 .714 r
.44804 .40404 .45724 .4009 .47309 .37661 .46414 .37543 Mtetra
.917 .927 .803 r
.46414 .37543 .47309 .37661 .48876 .35953 .47998 .35488 Mtetra
.847 .886 .867 r
.47998 .35488 .48876 .35953 .50437 .34741 .49572 .34047 Mtetra
.778 .836 .896 r
.49572 .34047 .50437 .34741 .51999 .33831 .51143 .32998 Mtetra
.729 .797 .905 r
.51143 .32998 .51999 .33831 .53568 .3309 .52719 .32177 Mtetra
.7 .772 .908 r
.52719 .32177 .53568 .3309 .55144 .32442 .54302 .31482 Mtetra
.683 .758 .908 r
.54302 .31482 .55144 .32442 .56729 .31841 .55893 .30854 Mtetra
.674 .75 .908 r
.55893 .30854 .56729 .31841 .58323 .31264 .57493 .3026 Mtetra
.669 .746 .908 r
.57493 .3026 .58323 .31264 .59926 .30699 .59102 .29682 Mtetra
.666 .744 .908 r
.59102 .29682 .59926 .30699 .61538 .30137 .60721 .29112 Mtetra
.665 .743 .908 r
.60721 .29112 .61538 .30137 .6316 .29577 .62349 .28544 Mtetra
.664 .742 .908 r
.62349 .28544 .6316 .29577 .64792 .29015 .63987 .27975 Mtetra
.63987 .27975 .64792 .29015 .66433 .28451 .65634 .27405 Mtetra
.664 .741 .908 r
.65634 .27405 .66433 .28451 .68083 .27885 .67291 .26832 Mtetra
.67291 .26832 .68083 .27885 .69743 .27316 .68958 .26256 Mtetra
.68958 .26256 .69743 .27316 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25588 .74019 .24509 Mtetra
.74019 .24509 .74783 .25588 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24419 .77443 .23327 Mtetra
.77443 .23327 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.646 .763 .934 r
.18391 .63204 .19431 .64047 .20926 .6359 .19891 .62742 Mtetra
.647 .763 .934 r
.19891 .62742 .20926 .6359 .22429 .63128 .21399 .62276 Mtetra
.21399 .62276 .22429 .63128 .23941 .6266 .22916 .61805 Mtetra
.648 .764 .933 r
.22916 .61805 .23941 .6266 .25462 .62184 .24442 .61327 Mtetra
.651 .765 .933 r
.24442 .61327 .25462 .62184 .26993 .61694 .25978 .60839 Mtetra
.655 .768 .932 r
.25978 .60839 .26993 .61694 .28534 .6118 .27524 .60332 Mtetra
.663 .772 .931 r
.27524 .60332 .28534 .6118 .30087 .60624 .29081 .59794 Mtetra
.677 .781 .929 r
.29081 .59794 .30087 .60624 .31652 .59991 .30649 .59198 Mtetra
.702 .796 .923 r
.30649 .59198 .31652 .59991 .33233 .59218 .32233 .58497 Mtetra
.743 .82 .912 r
.32233 .58497 .33233 .59218 .34833 .58195 .33833 .57608 Mtetra
.803 .853 .887 r
.33833 .57608 .34833 .58195 .36458 .56751 .35456 .56391 Mtetra
.874 .887 .841 r
.35456 .56391 .36458 .56751 .3811 .5466 .37106 .54641 Mtetra
.935 .909 .77 r
.37106 .54641 .3811 .5466 .39789 .51736 .38784 .52134 Mtetra
.97 .915 .694 r
.38784 .52134 .39789 .51736 .41479 .48043 .40484 .48776 Mtetra
.98 .914 .639 r
.40484 .48776 .41479 .48043 .43158 .44046 .42185 .44833 Mtetra
.978 .918 .629 r
.42185 .44833 .43158 .44046 .44804 .40404 .43861 .40919 Mtetra
.97 .931 .674 r
.43861 .40919 .44804 .40404 .46414 .37543 .455 .37626 Mtetra
.943 .936 .759 r
.455 .37626 .46414 .37543 .47998 .35488 .47107 .35171 Mtetra
.884 .909 .84 r
.47107 .35171 .47998 .35488 .49572 .34047 .48695 .33442 Mtetra
.811 .86 .885 r
.48695 .33442 .49572 .34047 .51143 .32998 .50277 .32212 Mtetra
.751 .814 .902 r
.50277 .32212 .51143 .32998 .52719 .32177 .5186 .31285 Mtetra
.712 .783 .907 r
.5186 .31285 .52719 .32177 .54302 .31482 .5345 .30529 Mtetra
.69 .764 .908 r
.5345 .30529 .54302 .31482 .55893 .30854 .55047 .29865 Mtetra
.678 .754 .908 r
.55047 .29865 .55893 .30854 .57493 .3026 .56653 .29249 Mtetra
.671 .748 .908 r
.56653 .29249 .57493 .3026 .59102 .29682 .58269 .28657 Mtetra
.667 .745 .908 r
.58269 .28657 .59102 .29682 .60721 .29112 .59894 .28077 Mtetra
.666 .743 .908 r
.59894 .28077 .60721 .29112 .62349 .28544 .61529 .275 Mtetra
.665 .742 .908 r
.61529 .275 .62349 .28544 .63987 .27975 .63173 .26924 Mtetra
.664 .742 .908 r
.63173 .26924 .63987 .27975 .65634 .27405 .64827 .26347 Mtetra
.64827 .26347 .65634 .27405 .67291 .26832 .66491 .25767 Mtetra
.664 .741 .908 r
.66491 .25767 .67291 .26832 .68958 .26256 .68164 .25185 Mtetra
.68164 .25185 .68958 .26256 .70635 .25677 .69848 .246 Mtetra
.69848 .246 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23419 Mtetra
.73246 .23419 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.646 .763 .934 r
.1734 .62352 .18391 .63204 .19891 .62742 .18844 .61885 Mtetra
.18844 .61885 .19891 .62742 .21399 .62276 .20357 .61415 Mtetra
.647 .763 .934 r
.20357 .61415 .21399 .62276 .22916 .61805 .2188 .6094 Mtetra
.648 .763 .933 r
.2188 .6094 .22916 .61805 .24442 .61327 .23411 .6046 Mtetra
.649 .764 .933 r
.23411 .6046 .24442 .61327 .25978 .60839 .24952 .5997 Mtetra
.652 .766 .933 r
.24952 .5997 .25978 .60839 .27524 .60332 .26503 .59467 Mtetra
.658 .77 .932 r
.26503 .59467 .27524 .60332 .29081 .59794 .28064 .5894 Mtetra
.669 .776 .93 r
.28064 .5894 .29081 .59794 .30649 .59198 .29637 .5837 Mtetra
.688 .788 .926 r
.29637 .5837 .30649 .59198 .32233 .58497 .31223 .57722 Mtetra
.72 .807 .919 r
.31223 .57722 .32233 .58497 .33833 .57608 .32825 .56933 Mtetra
.771 .835 .902 r
.32825 .56933 .33833 .57608 .35456 .56391 .34447 .55893 Mtetra
.838 .871 .867 r
.34447 .55893 .35456 .56391 .37106 .54641 .36094 .54428 Mtetra
.907 .9 .808 r
.36094 .54428 .37106 .54641 .38784 .52134 .37771 .52312 Mtetra
.956 .914 .731 r
.37771 .52312 .38784 .52134 .40484 .48776 .39474 .49357 Mtetra
.978 .914 .662 r
.39474 .49357 .40484 .48776 .42185 .44833 .41191 .4563 Mtetra
.98 .915 .628 r
.41191 .4563 .42185 .44833 .43861 .40919 .42894 .41596 Mtetra
.975 .924 .644 r
.42894 .41596 .43861 .40919 .455 .37626 .44565 .37921 Mtetra
.96 .936 .714 r
.44565 .37921 .455 .37626 .47107 .35171 .46198 .35031 Mtetra
.917 .927 .803 r
.46198 .35031 .47107 .35171 .48695 .33442 .47804 .32954 Mtetra
.847 .885 .867 r
.47804 .32954 .48695 .33442 .50277 .32212 .49399 .31493 Mtetra
.778 .835 .896 r
.49399 .31493 .50277 .32212 .5186 .31285 .50992 .30426 Mtetra
.729 .797 .905 r
.50992 .30426 .5186 .31285 .5345 .30529 .52589 .29589 Mtetra
.7 .772 .908 r
.52589 .29589 .5345 .30529 .55047 .29865 .54193 .28878 Mtetra
.683 .758 .908 r
.54193 .28878 .55047 .29865 .56653 .29249 .55805 .28235 Mtetra
.674 .75 .908 r
.55805 .28235 .56653 .29249 .58269 .28657 .57427 .27625 Mtetra
.669 .746 .908 r
.57427 .27625 .58269 .28657 .59894 .28077 .59058 .27032 Mtetra
.666 .744 .908 r
.59058 .27032 .59894 .28077 .61529 .275 .60699 .26446 Mtetra
.665 .743 .908 r
.60699 .26446 .61529 .275 .63173 .26924 .6235 .25862 Mtetra
.664 .742 .908 r
.6235 .25862 .63173 .26924 .64827 .26347 .64011 .25278 Mtetra
.64011 .25278 .64827 .26347 .66491 .25767 .65681 .24691 Mtetra
.664 .741 .908 r
.65681 .24691 .66491 .25767 .68164 .25185 .67362 .24102 Mtetra
.67362 .24102 .68164 .25185 .69848 .246 .69052 .2351 Mtetra
.69052 .2351 .69848 .246 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23419 .72464 .22316 Mtetra
.72464 .22316 .73246 .23419 .7496 .22823 .74185 .21714 Mtetra
.74185 .21714 .7496 .22823 .76684 .22223 .75917 .21108 Mtetra
.75917 .21108 .76684 .22223 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .763 .934 r
.16277 .6149 .1734 .62352 .18844 .61885 .17787 .61018 Mtetra
.17787 .61018 .18844 .61885 .20357 .61415 .19305 .60544 Mtetra
.647 .763 .934 r
.19305 .60544 .20357 .61415 .2188 .6094 .20832 .60065 Mtetra
.20832 .60065 .2188 .6094 .23411 .6046 .22369 .59581 Mtetra
.648 .764 .933 r
.22369 .59581 .23411 .6046 .24952 .5997 .23915 .5909 Mtetra
.651 .765 .933 r
.23915 .5909 .24952 .5997 .26503 .59467 .25471 .58588 Mtetra
.655 .768 .932 r
.25471 .58588 .26503 .59467 .28064 .5894 .27037 .58067 Mtetra
.663 .772 .931 r
.27037 .58067 .28064 .5894 .29637 .5837 .28614 .57515 Mtetra
.677 .781 .929 r
.28614 .57515 .29637 .5837 .31223 .57722 .30204 .56905 Mtetra
.702 .796 .923 r
.30204 .56905 .31223 .57722 .32825 .56933 .31808 .56189 Mtetra
.743 .82 .912 r
.31808 .56189 .32825 .56933 .34447 .55893 .33431 .55283 Mtetra
.803 .853 .887 r
.33431 .55283 .34447 .55893 .36094 .54428 .35076 .54047 Mtetra
.874 .887 .841 r
.35076 .54047 .36094 .54428 .37771 .52312 .3675 .52274 Mtetra
.935 .91 .77 r
.3675 .52274 .37771 .52312 .39474 .49357 .38453 .49738 Mtetra
.97 .915 .694 r
.38453 .49738 .39474 .49357 .41191 .4563 .40178 .46347 Mtetra
.98 .914 .639 r
.40178 .46347 .41191 .4563 .42894 .41596 .41905 .42367 Mtetra
.978 .918 .629 r
.41905 .42367 .42894 .41596 .44565 .37921 .43606 .38418 Mtetra
.97 .931 .674 r
.43606 .38418 .44565 .37921 .46198 .35031 .45269 .35093 Mtetra
.943 .936 .759 r
.45269 .35093 .46198 .35031 .47804 .32954 .46899 .32613 Mtetra
.884 .909 .84 r
.46899 .32613 .47804 .32954 .49399 .31493 .48509 .30863 Mtetra
.811 .86 .885 r
.48509 .30863 .49399 .31493 .50992 .30426 .50113 .29614 Mtetra
.751 .814 .902 r
.50113 .29614 .50992 .30426 .52589 .29589 .51718 .2867 Mtetra
.712 .783 .907 r
.51718 .2867 .52589 .29589 .54193 .28878 .53329 .27898 Mtetra
.69 .764 .908 r
.53329 .27898 .54193 .28878 .55805 .28235 .54948 .27218 Mtetra
.678 .754 .908 r
.54948 .27218 .55805 .28235 .57427 .27625 .56576 .26586 Mtetra
.671 .748 .908 r
.56576 .26586 .57427 .27625 .59058 .27032 .58214 .25978 Mtetra
.667 .745 .908 r
.58214 .25978 .59058 .27032 .60699 .26446 .59861 .25382 Mtetra
.666 .743 .908 r
.59861 .25382 .60699 .26446 .6235 .25862 .61518 .24789 Mtetra
.665 .742 .908 r
.61518 .24789 .6235 .25862 .64011 .25278 .63186 .24197 Mtetra
.664 .742 .908 r
.63186 .24197 .64011 .25278 .65681 .24691 .64863 .23604 Mtetra
.64863 .23604 .65681 .24691 .67362 .24102 .6655 .23008 Mtetra
.664 .741 .908 r
.6655 .23008 .67362 .24102 .69052 .2351 .68248 .22409 Mtetra
.68248 .22409 .69052 .2351 .70753 .22915 .69955 .21807 Mtetra
.69955 .21807 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21714 .73402 .20592 Mtetra
.73402 .20592 .74185 .21714 .75917 .21108 .75141 .19979 Mtetra
.75141 .19979 .75917 .21108 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .6149 .17787 .61018 .16718 .60142 Mtetra
.646 .763 .934 r
.16718 .60142 .17787 .61018 .19305 .60544 .18241 .59663 Mtetra
.18241 .59663 .19305 .60544 .20832 .60065 .19773 .59179 Mtetra
.647 .763 .934 r
.19773 .59179 .20832 .60065 .22369 .59581 .21315 .58691 Mtetra
.648 .763 .933 r
.21315 .58691 .22369 .59581 .23915 .5909 .22866 .58197 Mtetra
.649 .764 .933 r
.22866 .58197 .23915 .5909 .25471 .58588 .24427 .57695 Mtetra
.652 .766 .933 r
.24427 .57695 .25471 .58588 .27037 .58067 .25998 .57178 Mtetra
.658 .77 .932 r
.25998 .57178 .27037 .58067 .28614 .57515 .2758 .56636 Mtetra
.669 .776 .93 r
.2758 .56636 .28614 .57515 .30204 .56905 .29174 .56052 Mtetra
.688 .788 .926 r
.29174 .56052 .30204 .56905 .31808 .56189 .30782 .55389 Mtetra
.72 .807 .919 r
.30782 .55389 .31808 .56189 .33431 .55283 .32406 .54584 Mtetra
.771 .836 .902 r
.32406 .54584 .33431 .55283 .35076 .54047 .3405 .53525 Mtetra
.838 .871 .867 r
.3405 .53525 .35076 .54047 .3675 .52274 .35721 .52039 Mtetra
.907 .901 .808 r
.35721 .52039 .3675 .52274 .38453 .49738 .37422 .49897 Mtetra
.956 .914 .731 r
.37422 .49897 .38453 .49738 .40178 .46347 .39151 .46911 Mtetra
.978 .914 .662 r
.39151 .46911 .40178 .46347 .41905 .42367 .40894 .43148 Mtetra
.98 .915 .628 r
.40894 .43148 .41905 .42367 .43606 .38418 .42624 .39077 Mtetra
.975 .924 .645 r
.42624 .39077 .43606 .38418 .45269 .35093 .44319 .35369 Mtetra
.96 .936 .714 r
.44319 .35369 .45269 .35093 .46899 .32613 .45976 .32451 Mtetra
.917 .926 .803 r
.45976 .32451 .46899 .32613 .48509 .30863 .47605 .3035 Mtetra
.847 .885 .867 r
.47605 .3035 .48509 .30863 .50113 .29614 .49222 .28868 Mtetra
.778 .835 .896 r
.49222 .28868 .50113 .29614 .51718 .2867 .50836 .27784 Mtetra
.729 .797 .905 r
.50836 .27784 .51718 .2867 .53329 .27898 .52455 .2693 Mtetra
.7 .772 .908 r
.52455 .2693 .53329 .27898 .54948 .27218 .54081 .26202 Mtetra
.683 .758 .908 r
.54081 .26202 .54948 .27218 .56576 .26586 .55716 .25542 Mtetra
.674 .75 .908 r
.55716 .25542 .56576 .26586 .58214 .25978 .5736 .24917 Mtetra
.669 .746 .908 r
.5736 .24917 .58214 .25978 .59861 .25382 .59014 .24307 Mtetra
.666 .744 .908 r
.59014 .24307 .59861 .25382 .61518 .24789 .60678 .23705 Mtetra
.665 .743 .908 r
.60678 .23705 .61518 .24789 .63186 .24197 .62351 .23105 Mtetra
.664 .742 .908 r
.62351 .23105 .63186 .24197 .64863 .23604 .64035 .22504 Mtetra
.64035 .22504 .64863 .23604 .6655 .23008 .6573 .21901 Mtetra
.664 .741 .908 r
.6573 .21901 .6655 .23008 .68248 .22409 .67434 .21295 Mtetra
.67434 .21295 .68248 .22409 .69955 .21807 .69149 .20686 Mtetra
.69149 .20686 .69955 .21807 .71674 .21201 .70874 .20074 Mtetra
.70874 .20074 .71674 .21201 .73402 .20592 .7261 .19458 Mtetra
.7261 .19458 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16718 .60142 .15637 .59256 Mtetra
.646 .763 .934 r
.15637 .59256 .16718 .60142 .18241 .59663 .17165 .58772 Mtetra
.17165 .58772 .18241 .59663 .19773 .59179 .18703 .58283 Mtetra
.647 .763 .934 r
.18703 .58283 .19773 .59179 .21315 .58691 .2025 .57791 Mtetra
.2025 .57791 .21315 .58691 .22866 .58197 .21806 .57293 Mtetra
.648 .764 .933 r
.21806 .57293 .22866 .58197 .24427 .57695 .23372 .56789 Mtetra
.651 .765 .933 r
.23372 .56789 .24427 .57695 .25998 .57178 .24949 .56273 Mtetra
.655 .768 .932 r
.24949 .56273 .25998 .57178 .2758 .56636 .26536 .55738 Mtetra
.663 .772 .931 r
.26536 .55738 .2758 .56636 .29174 .56052 .28134 .55171 Mtetra
.677 .781 .929 r
.28134 .55171 .29174 .56052 .30782 .55389 .29745 .54546 Mtetra
.702 .796 .923 r
.29745 .54546 .30782 .55389 .32406 .54584 .31371 .53814 Mtetra
.743 .82 .912 r
.31371 .53814 .32406 .54584 .3405 .53525 .33016 .52891 Mtetra
.803 .853 .887 r
.33016 .52891 .3405 .53525 .35721 .52039 .34685 .51635 Mtetra
.874 .887 .841 r
.34685 .51635 .35721 .52039 .37422 .49897 .36383 .49838 Mtetra
.935 .91 .77 r
.36383 .49838 .37422 .49897 .39151 .46911 .38112 .47273 Mtetra
.97 .915 .694 r
.38112 .47273 .39151 .46911 .40894 .43148 .39864 .43849 Mtetra
.98 .914 .639 r
.39864 .43849 .40894 .43148 .42624 .39077 .41617 .39831 Mtetra
.978 .918 .629 r
.41617 .39831 .42624 .39077 .44319 .35369 .43345 .35846 Mtetra
.97 .931 .674 r
.43345 .35846 .44319 .35369 .45976 .32451 .45032 .3249 Mtetra
.943 .935 .759 r
.45032 .3249 .45976 .32451 .47605 .3035 .46685 .29984 Mtetra
.884 .909 .84 r
.46685 .29984 .47605 .3035 .49222 .28868 .48318 .28212 Mtetra
.811 .86 .885 r
.48318 .28212 .49222 .28868 .50836 .27784 .49944 .26944 Mtetra
.751 .814 .902 r
.49944 .26944 .50836 .27784 .52455 .2693 .51571 .25982 Mtetra
.712 .783 .907 r
.51571 .25982 .52455 .2693 .54081 .26202 .53204 .25193 Mtetra
.69 .764 .908 r
.53204 .25193 .54081 .26202 .55716 .25542 .54846 .24496 Mtetra
.678 .753 .908 r
.54846 .24496 .55716 .25542 .5736 .24917 .56496 .23848 Mtetra
.671 .748 .908 r
.56496 .23848 .5736 .24917 .59014 .24307 .58157 .23224 Mtetra
.667 .745 .908 r
.58157 .23224 .59014 .24307 .60678 .23705 .59827 .22611 Mtetra
.666 .743 .908 r
.59827 .22611 .60678 .23705 .62351 .23105 .61508 .22001 Mtetra
.665 .742 .908 r
.61508 .22001 .62351 .23105 .64035 .22504 .63199 .21393 Mtetra
.664 .742 .908 r
.63199 .21393 .64035 .22504 .6573 .21901 .649 .20782 Mtetra
.649 .20782 .6573 .21901 .67434 .21295 .66612 .20169 Mtetra
.664 .741 .908 r
.66612 .20169 .67434 .21295 .69149 .20686 .68334 .19553 Mtetra
.68334 .19553 .69149 .20686 .70874 .20074 .70066 .18934 Mtetra
.70066 .18934 .70874 .20074 .7261 .19458 .71809 .1831 Mtetra
.71809 .1831 .7261 .19458 .74357 .18838 .73563 .17684 Mtetra
.73563 .17684 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58847 .14117 .59738 .15637 .59256 .14544 .58361 Mtetra
.14544 .58361 .15637 .59256 .17165 .58772 .16078 .57871 Mtetra
.646 .763 .934 r
.16078 .57871 .17165 .58772 .18703 .58283 .1762 .57377 Mtetra
.1762 .57377 .18703 .58283 .2025 .57791 .19173 .5688 Mtetra
.647 .763 .934 r
.19173 .5688 .2025 .57791 .21806 .57293 .20735 .56378 Mtetra
.648 .763 .933 r
.20735 .56378 .21806 .57293 .23372 .56789 .22306 .55871 Mtetra
.649 .764 .933 r
.22306 .55871 .23372 .56789 .24949 .56273 .23888 .55354 Mtetra
.652 .766 .933 r
.23888 .55354 .24949 .56273 .26536 .55738 .2548 .54822 Mtetra
.658 .77 .932 r
.2548 .54822 .26536 .55738 .28134 .55171 .27083 .54267 Mtetra
.669 .776 .93 r
.27083 .54267 .28134 .55171 .29745 .54546 .28698 .53667 Mtetra
.688 .788 .927 r
.28698 .53667 .29745 .54546 .31371 .53814 .30327 .52988 Mtetra
.72 .807 .919 r
.30327 .52988 .31371 .53814 .33016 .52891 .31974 .52166 Mtetra
.771 .836 .902 r
.31974 .52166 .33016 .52891 .34685 .51635 .33642 .51089 Mtetra
.838 .871 .867 r
.33642 .51089 .34685 .51635 .36383 .49838 .35337 .49581 Mtetra
.907 .901 .808 r
.35337 .49581 .36383 .49838 .38112 .47273 .37063 .47412 Mtetra
.956 .914 .731 r
.37063 .47412 .38112 .47273 .39864 .43849 .38819 .44395 Mtetra
.978 .914 .662 r
.38819 .44395 .39864 .43849 .41617 .39831 .40588 .40595 Mtetra
.98 .915 .628 r
.40588 .40595 .41617 .39831 .43345 .35846 .42345 .36487 Mtetra
.975 .924 .645 r
.42345 .36487 .43345 .35846 .45032 .3249 .44066 .32744 Mtetra
.96 .936 .714 r
.44066 .32744 .45032 .3249 .46685 .29984 .45748 .29797 Mtetra
.917 .926 .803 r
.45748 .29797 .46685 .29984 .48318 .28212 .474 .27673 Mtetra
.847 .885 .867 r
.474 .27673 .48318 .28212 .49944 .26944 .49039 .26171 Mtetra
.778 .835 .896 r
.49039 .26171 .49944 .26944 .51571 .25982 .50676 .25067 Mtetra
.729 .797 .905 r
.50676 .25067 .51571 .25982 .53204 .25193 .52317 .24195 Mtetra
.7 .772 .908 r
.52317 .24195 .53204 .25193 .54846 .24496 .53966 .23451 Mtetra
.683 .758 .908 r
.53966 .23451 .54846 .24496 .56496 .23848 .55623 .22774 Mtetra
.674 .75 .908 r
.55623 .22774 .56496 .23848 .58157 .23224 .5729 .22132 Mtetra
.669 .746 .908 r
.5729 .22132 .58157 .23224 .59827 .22611 .58968 .21506 Mtetra
.666 .744 .908 r
.58968 .21506 .59827 .22611 .61508 .22001 .60655 .20886 Mtetra
.665 .743 .908 r
.60655 .20886 .61508 .22001 .63199 .21393 .62353 .20269 Mtetra
.664 .742 .908 r
.62353 .20269 .63199 .21393 .649 .20782 .64061 .19651 Mtetra
.64061 .19651 .649 .20782 .66612 .20169 .6578 .19031 Mtetra
.664 .741 .908 r
.6578 .19031 .66612 .20169 .68334 .19553 .67509 .18407 Mtetra
.67509 .18407 .68334 .19553 .70066 .18934 .69249 .17781 Mtetra
.69249 .17781 .70066 .18934 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17684 .72761 .16516 Mtetra
.72761 .16516 .73563 .17684 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58847 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16078 .57871 .14978 .5696 Mtetra
.646 .763 .934 r
.14978 .5696 .16078 .57871 .1762 .57377 .16526 .56461 Mtetra
.16526 .56461 .1762 .57377 .19173 .5688 .18084 .55959 Mtetra
.647 .763 .934 r
.18084 .55959 .19173 .5688 .20735 .56378 .19651 .55452 Mtetra
.19651 .55452 .20735 .56378 .22306 .55871 .21228 .54941 Mtetra
.648 .764 .933 r
.21228 .54941 .22306 .55871 .23888 .55354 .22815 .54422 Mtetra
.651 .765 .933 r
.22815 .54422 .23888 .55354 .2548 .54822 .24412 .53891 Mtetra
.655 .768 .932 r
.24412 .53891 .2548 .54822 .27083 .54267 .2602 .53342 Mtetra
.663 .772 .931 r
.2602 .53342 .27083 .54267 .28698 .53667 .2764 .5276 Mtetra
.677 .781 .929 r
.2764 .5276 .28698 .53667 .30327 .52988 .29273 .52118 Mtetra
.702 .796 .923 r
.29273 .52118 .30327 .52988 .31974 .52166 .30922 .5137 Mtetra
.743 .82 .912 r
.30922 .5137 .31974 .52166 .33642 .51089 .3259 .50429 Mtetra
.803 .853 .888 r
.3259 .50429 .33642 .51089 .35337 .49581 .34283 .49152 Mtetra
.874 .888 .841 r
.34283 .49152 .35337 .49581 .37063 .47412 .36006 .47332 Mtetra
.936 .91 .77 r
.36006 .47332 .37063 .47412 .38819 .44395 .37761 .44737 Mtetra
.97 .915 .693 r
.37761 .44737 .38819 .44395 .40588 .40595 .3954 .41278 Mtetra
.98 .914 .639 r
.3954 .41278 .40588 .40595 .42345 .36487 .41321 .37223 Mtetra
.978 .918 .629 r
.41321 .37223 .42345 .36487 .44066 .32744 .43076 .33201 Mtetra
.97 .931 .674 r
.43076 .33201 .44066 .32744 .45748 .29797 .44789 .29814 Mtetra
.943 .935 .76 r
.44789 .29814 .45748 .29797 .474 .27673 .46466 .27281 Mtetra
.884 .908 .84 r
.46466 .27281 .474 .27673 .49039 .26171 .48122 .25486 Mtetra
.811 .859 .885 r
.48122 .25486 .49039 .26171 .50676 .25067 .4977 .24199 Mtetra
.751 .814 .902 r
.4977 .24199 .50676 .25067 .52317 .24195 .5142 .23219 Mtetra
.712 .783 .907 r
.5142 .23219 .52317 .24195 .53966 .23451 .53076 .22412 Mtetra
.69 .764 .908 r
.53076 .22412 .53966 .23451 .55623 .22774 .5474 .21698 Mtetra
.678 .753 .908 r
.5474 .21698 .55623 .22774 .5729 .22132 .56414 .21032 Mtetra
.671 .748 .908 r
.56414 .21032 .5729 .22132 .58968 .21506 .58098 .20391 Mtetra
.667 .745 .908 r
.58098 .20391 .58968 .21506 .60655 .20886 .59793 .1976 Mtetra
.666 .743 .908 r
.59793 .1976 .60655 .20886 .62353 .20269 .61497 .19134 Mtetra
.665 .742 .908 r
.61497 .19134 .62353 .20269 .64061 .19651 .63212 .18507 Mtetra
.664 .742 .908 r
.63212 .18507 .64061 .19651 .6578 .19031 .64938 .17879 Mtetra
.64938 .17879 .6578 .19031 .67509 .18407 .66675 .17249 Mtetra
.664 .741 .908 r
.66675 .17249 .67509 .18407 .69249 .17781 .68422 .16615 Mtetra
.68422 .16615 .69249 .17781 .70999 .1715 .7018 .15977 Mtetra
.7018 .15977 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56038 Mtetra
.13866 .56038 .14978 .5696 .16526 .56461 .15419 .55534 Mtetra
.646 .763 .934 r
.15419 .55534 .16526 .56461 .18084 .55959 .16982 .55027 Mtetra
.16982 .55027 .18084 .55959 .19651 .55452 .18555 .54515 Mtetra
.647 .763 .934 r
.18555 .54515 .19651 .55452 .21228 .54941 .20137 .53999 Mtetra
.648 .763 .933 r
.20137 .53999 .21228 .54941 .22815 .54422 .2173 .53477 Mtetra
.649 .764 .933 r
.2173 .53477 .22815 .54422 .24412 .53891 .23332 .52945 Mtetra
.652 .766 .933 r
.23332 .52945 .24412 .53891 .2602 .53342 .24946 .52399 Mtetra
.658 .77 .932 r
.24946 .52399 .2602 .53342 .2764 .5276 .2657 .51828 Mtetra
.669 .776 .93 r
.2657 .51828 .2764 .5276 .29273 .52118 .28208 .51213 Mtetra
.688 .788 .927 r
.28208 .51213 .29273 .52118 .30922 .5137 .2986 .50517 Mtetra
.72 .807 .919 r
.2986 .50517 .30922 .5137 .3259 .50429 .3153 .49678 Mtetra
.771 .836 .902 r
.3153 .49678 .3259 .50429 .34283 .49152 .33221 .48581 Mtetra
.838 .871 .867 r
.33221 .48581 .34283 .49152 .36006 .47332 .34941 .47051 Mtetra
.907 .901 .808 r
.34941 .47051 .36006 .47332 .37761 .44737 .36693 .44855 Mtetra
.957 .914 .731 r
.36693 .44855 .37761 .44737 .3954 .41278 .38476 .41805 Mtetra
.978 .915 .662 r
.38476 .41805 .3954 .41278 .41321 .37223 .40274 .37968 Mtetra
.98 .915 .628 r
.40274 .37968 .41321 .37223 .43076 .33201 .42059 .33822 Mtetra
.975 .924 .645 r
.42059 .33822 .43076 .33201 .44789 .29814 .43807 .30045 Mtetra
.96 .936 .714 r
.43807 .30045 .44789 .29814 .46466 .27281 .45513 .27069 Mtetra
.917 .926 .803 r
.45513 .27069 .46466 .27281 .48122 .25486 .4719 .2492 Mtetra
.847 .885 .867 r
.4719 .2492 .48122 .25486 .4977 .24199 .48852 .23396 Mtetra
.778 .835 .896 r
.48852 .23396 .4977 .24199 .5142 .23219 .50512 .22273 Mtetra
.729 .796 .905 r
.50512 .22273 .5142 .23219 .53076 .22412 .52176 .21384 Mtetra
.7 .772 .908 r
.52176 .21384 .53076 .22412 .5474 .21698 .53848 .20622 Mtetra
.683 .758 .908 r
.53848 .20622 .5474 .21698 .56414 .21032 .55528 .19927 Mtetra
.674 .75 .908 r
.55528 .19927 .56414 .21032 .58098 .20391 .57219 .19267 Mtetra
.669 .746 .908 r
.57219 .19267 .58098 .20391 .59793 .1976 .5892 .18623 Mtetra
.666 .744 .908 r
.5892 .18623 .59793 .1976 .61497 .19134 .60632 .17986 Mtetra
.665 .743 .908 r
.60632 .17986 .61497 .19134 .63212 .18507 .62354 .17351 Mtetra
.664 .742 .908 r
.62354 .17351 .63212 .18507 .64938 .17879 .64087 .16715 Mtetra
.64087 .16715 .64938 .17879 .66675 .17249 .65831 .16077 Mtetra
.664 .741 .908 r
.65831 .16077 .66675 .17249 .68422 .16615 .67586 .15435 Mtetra
.67586 .15435 .68422 .16615 .7018 .15977 .69351 .1479 Mtetra
.69351 .1479 .7018 .15977 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56038 .12741 .55107 Mtetra
.12741 .55107 .13866 .56038 .15419 .55534 .143 .54597 Mtetra
.646 .763 .934 r
.143 .54597 .15419 .55534 .16982 .55027 .15868 .54084 Mtetra
.15868 .54084 .16982 .55027 .18555 .54515 .17447 .53567 Mtetra
.647 .763 .934 r
.17447 .53567 .18555 .54515 .20137 .53999 .19034 .53046 Mtetra
.19034 .53046 .20137 .53999 .2173 .53477 .20632 .5252 Mtetra
.648 .764 .933 r
.20632 .5252 .2173 .53477 .23332 .52945 .2224 .51986 Mtetra
.651 .765 .933 r
.2224 .51986 .23332 .52945 .24946 .52399 .23859 .5144 Mtetra
.655 .768 .932 r
.23859 .5144 .24946 .52399 .2657 .51828 .25489 .50875 Mtetra
.663 .772 .931 r
.25489 .50875 .2657 .51828 .28208 .51213 .27131 .50277 Mtetra
.677 .781 .929 r
.27131 .50277 .28208 .51213 .2986 .50517 .28787 .4962 Mtetra
.702 .796 .923 r
.28787 .4962 .2986 .50517 .3153 .49678 .30459 .48854 Mtetra
.743 .82 .912 r
.30459 .48854 .3153 .49678 .33221 .48581 .32151 .47894 Mtetra
.803 .853 .888 r
.32151 .47894 .33221 .48581 .34941 .47051 .33869 .46596 Mtetra
.874 .888 .841 r
.33869 .46596 .34941 .47051 .36693 .44855 .35617 .44751 Mtetra
.936 .91 .77 r
.35617 .44751 .36693 .44855 .38476 .41805 .374 .42126 Mtetra
.97 .915 .693 r
.374 .42126 .38476 .41805 .40274 .37968 .39207 .38632 Mtetra
.98 .914 .639 r
.39207 .38632 .40274 .37968 .42059 .33822 .41017 .34539 Mtetra
.978 .918 .629 r
.41017 .34539 .42059 .33822 .43807 .30045 .42799 .3048 Mtetra
.97 .931 .675 r
.42799 .3048 .43807 .30045 .45513 .27069 .44538 .27061 Mtetra
.943 .935 .76 r
.44538 .27061 .45513 .27069 .4719 .2492 .4624 .24501 Mtetra
.884 .908 .84 r
.4624 .24501 .4719 .2492 .48852 .23396 .4792 .22683 Mtetra
.811 .859 .885 r
.4792 .22683 .48852 .23396 .50512 .22273 .49592 .21375 Mtetra
.751 .814 .902 r
.49592 .21375 .50512 .22273 .52176 .21384 .51265 .20376 Mtetra
.712 .783 .907 r
.51265 .20376 .52176 .21384 .53848 .20622 .52944 .1955 Mtetra
.69 .764 .908 r
.52944 .1955 .53848 .20622 .55528 .19927 .54632 .18818 Mtetra
.678 .753 .908 r
.54632 .18818 .55528 .19927 .57219 .19267 .5633 .18135 Mtetra
.671 .748 .908 r
.5633 .18135 .57219 .19267 .5892 .18623 .58038 .17476 Mtetra
.667 .745 .908 r
.58038 .17476 .5892 .18623 .60632 .17986 .59757 .16827 Mtetra
.666 .743 .908 r
.59757 .16827 .60632 .17986 .62354 .17351 .61486 .16182 Mtetra
.665 .742 .908 r
.61486 .16182 .62354 .17351 .64087 .16715 .63226 .15538 Mtetra
.664 .742 .908 r
.63226 .15538 .64087 .16715 .65831 .16077 .64977 .14891 Mtetra
.64977 .14891 .65831 .16077 .67586 .15435 .6674 .14242 Mtetra
.664 .741 .908 r
.6674 .14242 .67586 .15435 .69351 .1479 .68513 .13589 Mtetra
.68513 .13589 .69351 .1479 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54164 Mtetra
.11604 .54164 .12741 .55107 .143 .54597 .13168 .53649 Mtetra
.13168 .53649 .143 .54597 .15868 .54084 .14742 .53131 Mtetra
.646 .763 .934 r
.14742 .53131 .15868 .54084 .17447 .53567 .16326 .52608 Mtetra
.16326 .52608 .17447 .53567 .19034 .53046 .17919 .52082 Mtetra
.647 .763 .934 r
.17919 .52082 .19034 .53046 .20632 .5252 .19523 .51551 Mtetra
.648 .763 .933 r
.19523 .51551 .20632 .5252 .2224 .51986 .21136 .51013 Mtetra
.649 .764 .933 r
.21136 .51013 .2224 .51986 .23859 .5144 .22761 .50466 Mtetra
.652 .766 .933 r
.22761 .50466 .23859 .5144 .25489 .50875 .24396 .49904 Mtetra
.658 .77 .932 r
.24396 .49904 .25489 .50875 .27131 .50277 .26043 .49317 Mtetra
.669 .776 .93 r
.26043 .49317 .27131 .50277 .28787 .4962 .27703 .48685 Mtetra
.687 .788 .927 r
.27703 .48685 .28787 .4962 .30459 .48854 .29379 .47973 Mtetra
.72 .807 .919 r
.29379 .47973 .30459 .48854 .32151 .47894 .31072 .47115 Mtetra
.771 .836 .902 r
.31072 .47115 .32151 .47894 .33869 .46596 .32788 .45998 Mtetra
.838 .871 .867 r
.32788 .45998 .33869 .46596 .35617 .44751 .34534 .44445 Mtetra
.908 .901 .808 r
.34534 .44445 .35617 .44751 .374 .42126 .36313 .42221 Mtetra
.957 .915 .73 r
.36313 .42221 .374 .42126 .39207 .38632 .38124 .39138 Mtetra
.978 .915 .662 r
.38124 .39138 .39207 .38632 .41017 .34539 .39951 .35264 Mtetra
.98 .915 .628 r
.39951 .35264 .41017 .34539 .42799 .3048 .41764 .3108 Mtetra
.975 .924 .645 r
.41764 .3108 .42799 .3048 .44538 .27061 .43539 .27268 Mtetra
.96 .936 .715 r
.43539 .27268 .44538 .27061 .4624 .24501 .45272 .24262 Mtetra
.917 .926 .803 r
.45272 .24262 .4624 .24501 .4792 .22683 .46973 .22087 Mtetra
.847 .885 .867 r
.46973 .22087 .4792 .22683 .49592 .21375 .48659 .20542 Mtetra
.778 .835 .896 r
.48659 .20542 .49592 .21375 .51265 .20376 .50343 .19399 Mtetra
.729 .796 .905 r
.50343 .19399 .51265 .20376 .52944 .1955 .5203 .1849 Mtetra
.7 .772 .908 r
.5203 .1849 .52944 .1955 .54632 .18818 .53726 .1771 Mtetra
.683 .758 .908 r
.53726 .1771 .54632 .18818 .5633 .18135 .55431 .16997 Mtetra
.674 .75 .908 r
.55431 .16997 .5633 .18135 .58038 .17476 .57146 .16319 Mtetra
.669 .746 .908 r
.57146 .16319 .58038 .17476 .59757 .16827 .58872 .15657 Mtetra
.666 .744 .908 r
.58872 .15657 .59757 .16827 .61486 .16182 .60608 .15001 Mtetra
.665 .743 .908 r
.60608 .15001 .61486 .16182 .63226 .15538 .62356 .14348 Mtetra
.664 .742 .908 r
.62356 .14348 .63226 .15538 .64977 .14891 .64114 .13693 Mtetra
.64114 .13693 .64977 .14891 .6674 .14242 .65884 .13035 Mtetra
.664 .741 .908 r
.65884 .13035 .6674 .14242 .68513 .13589 .67665 .12374 Mtetra
.67665 .12374 .68513 .13589 .70297 .12932 .69457 .1171 Mtetra
.69457 .1171 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54164 .10454 .53211 Mtetra
.10454 .53211 .11604 .54164 .13168 .53649 .12023 .5269 Mtetra
.12023 .5269 .13168 .53649 .14742 .53131 .13603 .52166 Mtetra
.646 .763 .934 r
.13603 .52166 .14742 .53131 .16326 .52608 .15192 .51638 Mtetra
.15192 .51638 .16326 .52608 .17919 .52082 .16791 .51106 Mtetra
.647 .763 .934 r
.16791 .51106 .17919 .52082 .19523 .51551 .184 .5057 Mtetra
.184 .5057 .19523 .51551 .21136 .51013 .20019 .50027 Mtetra
.648 .764 .933 r
.20019 .50027 .21136 .51013 .22761 .50466 .21649 .49478 Mtetra
.651 .765 .933 r
.21649 .49478 .22761 .50466 .24396 .49904 .2329 .48916 Mtetra
.655 .768 .932 r
.2329 .48916 .24396 .49904 .26043 .49317 .24943 .48335 Mtetra
.663 .772 .931 r
.24943 .48335 .26043 .49317 .27703 .48685 .26608 .47721 Mtetra
.677 .781 .929 r
.26608 .47721 .27703 .48685 .29379 .47973 .28287 .47046 Mtetra
.702 .796 .923 r
.28287 .47046 .29379 .47973 .31072 .47115 .29983 .46263 Mtetra
.743 .82 .912 r
.29983 .46263 .31072 .47115 .32788 .45998 .31699 .45283 Mtetra
.803 .853 .888 r
.31699 .45283 .32788 .45998 .34534 .44445 .33442 .43964 Mtetra
.874 .888 .841 r
.33442 .43964 .34534 .44445 .36313 .42221 .35217 .42092 Mtetra
.936 .91 .77 r
.35217 .42092 .36313 .42221 .38124 .39138 .37028 .39437 Mtetra
.97 .916 .693 r
.37028 .39437 .38124 .39138 .39951 .35264 .38864 .35907 Mtetra
.98 .914 .639 r
.38864 .35907 .39951 .35264 .41764 .3108 .40703 .31775 Mtetra
.978 .918 .629 r
.40703 .31775 .41764 .3108 .43539 .27268 .42514 .2768 Mtetra
.97 .931 .675 r
.42514 .2768 .43539 .27268 .45272 .24262 .44281 .24227 Mtetra
.943 .935 .76 r
.44281 .24227 .45272 .24262 .46973 .22087 .46008 .2164 Mtetra
.884 .908 .84 r
.46008 .2164 .46973 .22087 .48659 .20542 .47712 .19798 Mtetra
.811 .859 .885 r
.47712 .19798 .48659 .20542 .50343 .19399 .49408 .18469 Mtetra
.751 .814 .902 r
.49408 .18469 .50343 .19399 .5203 .1849 .51105 .1745 Mtetra
.713 .783 .907 r
.51105 .1745 .5203 .1849 .53726 .1771 .52809 .16606 Mtetra
.69 .764 .908 r
.52809 .16606 .53726 .1771 .55431 .16997 .54521 .15855 Mtetra
.678 .753 .908 r
.54521 .15855 .55431 .16997 .57146 .16319 .56243 .15153 Mtetra
.671 .748 .908 r
.56243 .15153 .57146 .16319 .58872 .15657 .57976 .14475 Mtetra
.667 .745 .908 r
.57976 .14475 .58872 .15657 .60608 .15001 .5972 .13808 Mtetra
.666 .743 .908 r
.5972 .13808 .60608 .15001 .62356 .14348 .61475 .13144 Mtetra
.665 .742 .908 r
.61475 .13144 .62356 .14348 .64114 .13693 .63241 .1248 Mtetra
.664 .742 .908 r
.63241 .1248 .64114 .13693 .65884 .13035 .65018 .11815 Mtetra
.65018 .11815 .65884 .13035 .67665 .12374 .66806 .11146 Mtetra
.664 .741 .908 r
.66806 .11146 .67665 .12374 .69457 .1171 .68606 .10473 Mtetra
.68606 .10473 .69457 .1171 .7126 .11041 .70418 .09797 Mtetra
.70418 .09797 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53211 .09291 .52247 Mtetra
.09291 .52247 .10454 .53211 .12023 .5269 .10866 .5172 Mtetra
.10866 .5172 .12023 .5269 .13603 .52166 .1245 .5119 Mtetra
.1245 .5119 .13603 .52166 .15192 .51638 .14045 .50656 Mtetra
.646 .763 .934 r
.14045 .50656 .15192 .51638 .16791 .51106 .1565 .50118 Mtetra
.1565 .50118 .16791 .51106 .184 .5057 .17264 .49576 Mtetra
.647 .763 .934 r
.17264 .49576 .184 .5057 .20019 .50027 .1889 .49029 Mtetra
.648 .763 .933 r
.1889 .49029 .20019 .50027 .21649 .49478 .20525 .48476 Mtetra
.649 .764 .933 r
.20525 .48476 .21649 .49478 .2329 .48916 .22172 .47913 Mtetra
.652 .766 .933 r
.22172 .47913 .2329 .48916 .24943 .48335 .2383 .47334 Mtetra
.658 .77 .932 r
.2383 .47334 .24943 .48335 .26608 .47721 .255 .46731 Mtetra
.669 .776 .93 r
.255 .46731 .26608 .47721 .28287 .47046 .27184 .46082 Mtetra
.687 .788 .927 r
.27184 .46082 .28287 .47046 .29983 .46263 .28883 .45352 Mtetra
.72 .807 .919 r
.28883 .45352 .29983 .46263 .31699 .45283 .30601 .44475 Mtetra
.771 .836 .902 r
.30601 .44475 .31699 .45283 .33442 .43964 .32342 .43337 Mtetra
.838 .871 .868 r
.32342 .43337 .33442 .43964 .35217 .42092 .34114 .4176 Mtetra
.908 .902 .808 r
.34114 .4176 .35217 .42092 .37028 .39437 .35921 .39508 Mtetra
.957 .915 .73 r
.35921 .39508 .37028 .39437 .38864 .35907 .37761 .36391 Mtetra
.978 .915 .661 r
.37761 .36391 .38864 .35907 .40703 .31775 .39618 .32479 Mtetra
.98 .915 .627 r
.39618 .32479 .40703 .31775 .42514 .2768 .41461 .28256 Mtetra
.975 .924 .645 r
.41461 .28256 .42514 .2768 .44281 .24227 .43264 .24409 Mtetra
.96 .936 .715 r
.43264 .24409 .44281 .24227 .46008 .2164 .45023 .21373 Mtetra
.917 .926 .803 r
.45023 .21373 .46008 .2164 .47712 .19798 .4675 .19172 Mtetra
.847 .884 .867 r
.4675 .19172 .47712 .19798 .49408 .18469 .48461 .17604 Mtetra
.778 .835 .895 r
.48461 .17604 .49408 .18469 .51105 .1745 .50169 .16441 Mtetra
.729 .796 .905 r
.50169 .16441 .51105 .1745 .52809 .16606 .51881 .15512 Mtetra
.7 .772 .908 r
.51881 .15512 .52809 .16606 .54521 .15855 .53601 .14713 Mtetra
.683 .758 .908 r
.53601 .14713 .54521 .15855 .56243 .15153 .5533 .13981 Mtetra
.674 .75 .908 r
.5533 .13981 .56243 .15153 .57976 .14475 .5707 .13283 Mtetra
.669 .746 .908 r
.5707 .13283 .57976 .14475 .5972 .13808 .58821 .12602 Mtetra
.666 .744 .908 r
.58821 .12602 .5972 .13808 .61475 .13144 .60584 .11927 Mtetra
.665 .743 .908 r
.60584 .11927 .61475 .13144 .63241 .1248 .62357 .11254 Mtetra
.664 .742 .908 r
.62357 .11254 .63241 .1248 .65018 .11815 .64142 .1058 Mtetra
.64142 .1058 .65018 .11815 .66806 .11146 .65938 .09903 Mtetra
.664 .741 .908 r
.65938 .09903 .66806 .11146 .68606 .10473 .67746 .09222 Mtetra
.67746 .09222 .68606 .10473 .70418 .09797 .69566 .08537 Mtetra
.69566 .08537 .70418 .09797 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10866 .5172 .09694 .50739 Mtetra
.09694 .50739 .10866 .5172 .1245 .5119 .11284 .50203 Mtetra
.11284 .50203 .1245 .5119 .14045 .50656 .12885 .49663 Mtetra
.646 .763 .934 r
.12885 .49663 .14045 .50656 .1565 .50118 .14495 .49119 Mtetra
.14495 .49119 .1565 .50118 .17264 .49576 .16116 .48571 Mtetra
.647 .763 .934 r
.16116 .48571 .17264 .49576 .1889 .49029 .17747 .48019 Mtetra
.17747 .48019 .1889 .49029 .20525 .48476 .19388 .47461 Mtetra
.648 .764 .933 r
.19388 .47461 .20525 .48476 .22172 .47913 .21041 .46894 Mtetra
.651 .765 .933 r
.21041 .46894 .22172 .47913 .2383 .47334 .22704 .46316 Mtetra
.655 .768 .932 r
.22704 .46316 .2383 .47334 .255 .46731 .2438 .45718 Mtetra
.663 .773 .931 r
.2438 .45718 .255 .46731 .27184 .46082 .26068 .45087 Mtetra
.677 .781 .929 r
.26068 .45087 .27184 .46082 .28883 .45352 .27771 .44395 Mtetra
.702 .796 .924 r
.27771 .44395 .28883 .45352 .30601 .44475 .29492 .43592 Mtetra
.743 .82 .912 r
.29492 .43592 .30601 .44475 .32342 .43337 .31234 .42593 Mtetra
.803 .854 .888 r
.31234 .42593 .32342 .43337 .34114 .4176 .33003 .41251 Mtetra
.874 .888 .841 r
.33003 .41251 .34114 .4176 .35921 .39508 .34805 .39353 Mtetra
.936 .911 .77 r
.34805 .39353 .35921 .39508 .37761 .36391 .36644 .36667 Mtetra
.97 .916 .693 r
.36644 .36667 .37761 .36391 .39618 .32479 .38511 .331 Mtetra
.98 .914 .639 r
.38511 .331 .39618 .32479 .41461 .28256 .4038 .28929 Mtetra
.978 .918 .629 r
.4038 .28929 .41461 .28256 .43264 .24409 .42221 .24796 Mtetra
.97 .931 .675 r
.42221 .24796 .43264 .24409 .45023 .21373 .44015 .2131 Mtetra
.942 .935 .76 r
.44015 .2131 .45023 .21373 .4675 .19172 .45769 .18695 Mtetra
.883 .908 .84 r
.45769 .18695 .4675 .19172 .48461 .17604 .47498 .16829 Mtetra
.811 .859 .884 r
.47498 .16829 .48461 .17604 .50169 .16441 .49219 .15478 Mtetra
.751 .814 .902 r
.49219 .15478 .50169 .16441 .51881 .15512 .50941 .14438 Mtetra
.713 .783 .907 r
.50941 .14438 .51881 .15512 .53601 .14713 .52669 .13574 Mtetra
.69 .764 .908 r
.52669 .13574 .53601 .14713 .5533 .13981 .54406 .12804 Mtetra
.678 .753 .908 r
.54406 .12804 .5533 .13981 .5707 .13283 .56154 .12083 Mtetra
.671 .748 .908 r
.56154 .12083 .5707 .13283 .58821 .12602 .57912 .11385 Mtetra
.667 .745 .908 r
.57912 .11385 .58821 .12602 .60584 .11927 .59682 .10698 Mtetra
.666 .743 .908 r
.59682 .10698 .60584 .11927 .62357 .11254 .61463 .10014 Mtetra
.665 .742 .908 r
.61463 .10014 .62357 .11254 .64142 .1058 .63256 .09331 Mtetra
.664 .742 .908 r
.63256 .09331 .64142 .1058 .65938 .09903 .6506 .08645 Mtetra
.6506 .08645 .65938 .09903 .67746 .09222 .66875 .07956 Mtetra
.664 .741 .908 r
.66875 .07956 .67746 .09222 .69566 .08537 .68703 .07263 Mtetra
.68703 .07263 .69566 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05864 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49663 .11711 .48658 Mtetra
.11711 .48658 .12885 .49663 .14495 .49119 .13327 .48108 Mtetra
.646 .763 .934 r
.13327 .48108 .14495 .49119 .16116 .48571 .14953 .47554 Mtetra
.14953 .47554 .16116 .48571 .17747 .48019 .1659 .46996 Mtetra
.647 .763 .934 r
.1659 .46996 .17747 .48019 .19388 .47461 .18238 .46432 Mtetra
.648 .763 .933 r
.18238 .46432 .19388 .47461 .21041 .46894 .19896 .45862 Mtetra
.649 .764 .933 r
.19896 .45862 .21041 .46894 .22704 .46316 .21566 .45282 Mtetra
.652 .766 .933 r
.21566 .45282 .22704 .46316 .2438 .45718 .23247 .44687 Mtetra
.658 .77 .932 r
.23247 .44687 .2438 .45718 .26068 .45087 .24941 .44066 Mtetra
.669 .776 .93 r
.24941 .44066 .26068 .45087 .27771 .44395 .26648 .43399 Mtetra
.687 .788 .927 r
.26648 .43399 .27771 .44395 .29492 .43592 .28372 .42651 Mtetra
.72 .807 .919 r
.28372 .42651 .29492 .43592 .31234 .42593 .30115 .41754 Mtetra
.771 .836 .902 r
.30115 .41754 .31234 .42593 .33003 .41251 .31883 .40595 Mtetra
.838 .872 .868 r
.31883 .40595 .33003 .41251 .34805 .39353 .33681 .38992 Mtetra
.908 .902 .808 r
.33681 .38992 .34805 .39353 .36644 .36667 .35517 .36711 Mtetra
.957 .915 .73 r
.35517 .36711 .36644 .36667 .38511 .331 .37387 .3356 Mtetra
.978 .915 .661 r
.37387 .3356 .38511 .331 .4038 .28929 .39275 .2961 Mtetra
.98 .915 .627 r
.39275 .2961 .4038 .28929 .42221 .24796 .41148 .25348 Mtetra
.975 .924 .646 r
.41148 .25348 .42221 .24796 .44015 .2131 .42981 .21465 Mtetra
.96 .935 .715 r
.42981 .21465 .44015 .2131 .45769 .18695 .44767 .18397 Mtetra
.917 .925 .803 r
.44767 .18397 .45769 .18695 .47498 .16829 .4652 .16171 Mtetra
.847 .884 .867 r
.4652 .16171 .47498 .16829 .49219 .15478 .48256 .1458 Mtetra
.778 .835 .895 r
.48256 .1458 .49219 .15478 .50941 .14438 .49989 .13395 Mtetra
.729 .796 .905 r
.49989 .13395 .50941 .14438 .52669 .13574 .51726 .12446 Mtetra
.7 .772 .908 r
.51726 .12446 .52669 .13574 .54406 .12804 .53471 .11626 Mtetra
.683 .758 .908 r
.53471 .11626 .54406 .12804 .56154 .12083 .55227 .10874 Mtetra
.674 .75 .908 r
.55227 .10874 .56154 .12083 .57912 .11385 .56993 .10157 Mtetra
.669 .746 .908 r
.56993 .10157 .57912 .11385 .59682 .10698 .5877 .09456 Mtetra
.666 .744 .908 r
.5877 .09456 .59682 .10698 .61463 .10014 .60558 .08761 Mtetra
.665 .743 .908 r
.60558 .08761 .61463 .10014 .63256 .09331 .62359 .08067 Mtetra
.664 .742 .908 r
.62359 .08067 .63256 .09331 .6506 .08645 .64171 .07372 Mtetra
.64171 .07372 .6506 .08645 .66875 .07956 .65994 .06674 Mtetra
.664 .741 .908 r
.65994 .06674 .66875 .07956 .68703 .07263 .6783 .05973 Mtetra
.6783 .05973 .68703 .07263 .70542 .06565 .69678 .05267 Mtetra
.69678 .05267 .70542 .06565 .72394 .05864 .71537 .04557 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47641 Mtetra
.10523 .47641 .11711 .48658 .13327 .48108 .12145 .47085 Mtetra
.646 .763 .934 r
.12145 .47085 .13327 .48108 .14953 .47554 .13777 .46525 Mtetra
.13777 .46525 .14953 .47554 .1659 .46996 .1542 .4596 Mtetra
.647 .763 .934 r
.1542 .4596 .1659 .46996 .18238 .46432 .17073 .45391 Mtetra
.17073 .45391 .18238 .46432 .19896 .45862 .18738 .44816 Mtetra
.648 .764 .933 r
.18738 .44816 .19896 .45862 .21566 .45282 .20413 .44233 Mtetra
.651 .765 .933 r
.20413 .44233 .21566 .45282 .23247 .44687 .221 .43637 Mtetra
.655 .768 .932 r
.221 .43637 .23247 .44687 .24941 .44066 .238 .43022 Mtetra
.663 .773 .931 r
.238 .43022 .24941 .44066 .26648 .43399 .25512 .42372 Mtetra
.677 .781 .929 r
.25512 .42372 .26648 .43399 .28372 .42651 .2724 .41661 Mtetra
.702 .796 .924 r
.2724 .41661 .28372 .42651 .30115 .41754 .28986 .4084 Mtetra
.743 .82 .912 r
.28986 .4084 .30115 .41754 .31883 .40595 .30753 .39819 Mtetra
.803 .854 .888 r
.30753 .39819 .31883 .40595 .33681 .38992 .32549 .38454 Mtetra
.874 .888 .841 r
.32549 .38454 .33681 .38992 .35517 .36711 .3438 .36529 Mtetra
.936 .911 .77 r
.3438 .36529 .35517 .36711 .37387 .3356 .36249 .3381 Mtetra
.97 .916 .693 r
.36249 .3381 .37387 .3356 .39275 .2961 .38147 .30206 Mtetra
.98 .914 .639 r
.38147 .30206 .39275 .2961 .41148 .25348 .40048 .25996 Mtetra
.978 .918 .63 r
.40048 .25996 .41148 .25348 .42981 .21465 .41919 .21825 Mtetra
.97 .931 .675 r
.41919 .21825 .42981 .21465 .44767 .18397 .43742 .18306 Mtetra
.942 .934 .76 r
.43742 .18306 .44767 .18397 .4652 .16171 .45523 .15662 Mtetra
.883 .908 .84 r
.45523 .15662 .4652 .16171 .48256 .1458 .47278 .13771 Mtetra
.811 .859 .884 r
.47278 .13771 .48256 .1458 .49989 .13395 .49025 .12397 Mtetra
.751 .814 .902 r
.49025 .12397 .49989 .13395 .51726 .12446 .50772 .11336 Mtetra
.713 .783 .907 r
.50772 .11336 .51726 .12446 .53471 .11626 .52525 .10452 Mtetra
.69 .764 .908 r
.52525 .10452 .53471 .11626 .55227 .10874 .54288 .09661 Mtetra
.678 .753 .908 r
.54288 .09661 .55227 .10874 .56993 .10157 .56062 .08919 Mtetra
.671 .748 .908 r
.56062 .08919 .56993 .10157 .5877 .09456 .57847 .08201 Mtetra
.667 .745 .908 r
.57847 .08201 .5877 .09456 .60558 .08761 .59643 .07494 Mtetra
.666 .743 .908 r
.59643 .07494 .60558 .08761 .62359 .08067 .61451 .06789 Mtetra
.665 .742 .908 r
.61451 .06789 .62359 .08067 .64171 .07372 .63271 .06085 Mtetra
.664 .742 .908 r
.63271 .06085 .64171 .07372 .65994 .06674 .65103 .05378 Mtetra
.65103 .05378 .65994 .06674 .6783 .05973 .66946 .04667 Mtetra
.664 .741 .908 r
.66946 .04667 .6783 .05973 .69678 .05267 .68802 .03953 Mtetra
.68802 .03953 .69678 .05267 .71537 .04557 .70671 .03234 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48278 Mtetra
.04501 .48278 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47641 .09322 .46612 Mtetra
.09322 .46612 .10523 .47641 .12145 .47085 .10949 .4605 Mtetra
.10949 .4605 .12145 .47085 .13777 .46525 .12587 .45483 Mtetra
.646 .763 .934 r
.12587 .45483 .13777 .46525 .1542 .4596 .14236 .44912 Mtetra
.14236 .44912 .1542 .4596 .17073 .45391 .15895 .44337 Mtetra
.647 .763 .934 r
.15895 .44337 .17073 .45391 .18738 .44816 .17566 .43756 Mtetra
.648 .763 .933 r
.17566 .43756 .18738 .44816 .20413 .44233 .19247 .43168 Mtetra
.649 .764 .933 r
.19247 .43168 .20413 .44233 .221 .43637 .2094 .42571 Mtetra
.652 .766 .933 r
.2094 .42571 .221 .43637 .238 .43022 .22646 .41958 Mtetra
.658 .77 .932 r
.22646 .41958 .238 .43022 .25512 .42372 .24364 .41318 Mtetra
.669 .776 .93 r
.24364 .41318 .25512 .42372 .2724 .41661 .26096 .40633 Mtetra
.687 .788 .927 r
.26096 .40633 .2724 .41661 .28986 .4084 .27845 .39865 Mtetra
.72 .807 .919 r
.27845 .39865 .28986 .4084 .30753 .39819 .29614 .38948 Mtetra
.771 .836 .902 r
.29614 .38948 .30753 .39819 .32549 .38454 .31408 .37766 Mtetra
.838 .872 .868 r
.31408 .37766 .32549 .38454 .3438 .36529 .33235 .36139 Mtetra
.908 .902 .808 r
.33235 .36139 .3438 .36529 .36249 .3381 .351 .33828 Mtetra
.957 .915 .73 r
.351 .33828 .36249 .3381 .38147 .30206 .37001 .30642 Mtetra
.978 .915 .661 r
.37001 .30642 .38147 .30206 .40048 .25996 .38921 .26652 Mtetra
.98 .915 .627 r
.38921 .26652 .40048 .25996 .41919 .21825 .40826 .22351 Mtetra
.975 .924 .646 r
.40826 .22351 .41919 .21825 .43742 .18306 .42689 .18431 Mtetra
.96 .935 .715 r
.42689 .18431 .43742 .18306 .45523 .15662 .44504 .15333 Mtetra
.917 .925 .803 r
.44504 .15333 .45523 .15662 .47278 .13771 .46283 .13079 Mtetra
.847 .884 .867 r
.46283 .13079 .47278 .13771 .49025 .12397 .48046 .11464 Mtetra
.778 .835 .895 r
.48046 .11464 .49025 .12397 .50772 .11336 .49804 .10257 Mtetra
.729 .796 .905 r
.49804 .10257 .50772 .11336 .52525 .10452 .51567 .09287 Mtetra
.7 .772 .908 r
.51567 .09287 .52525 .10452 .54288 .09661 .53339 .08446 Mtetra
.683 .758 .908 r
.53339 .08446 .54288 .09661 .56062 .08919 .5512 .07674 Mtetra
.674 .75 .908 r
.5512 .07674 .56062 .08919 .57847 .08201 .56912 .06935 Mtetra
.669 .746 .908 r
.56912 .06935 .57847 .08201 .59643 .07494 .58717 .06213 Mtetra
.666 .744 .908 r
.58717 .06213 .59643 .07494 .61451 .06789 .60532 .05497 Mtetra
.665 .743 .908 r
.60532 .05497 .61451 .06789 .63271 .06085 .6236 .04782 Mtetra
.664 .742 .908 r
.6236 .04782 .63271 .06085 .65103 .05378 .642 .04066 Mtetra
.642 .04066 .65103 .05378 .66946 .04667 .66052 .03346 Mtetra
.664 .741 .908 r
.66052 .03346 .66946 .04667 .68802 .03953 .67916 .02623 Mtetra
.67916 .02623 .68802 .03953 .70671 .03234 .69793 .01895 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48278 .03269 .47257 Mtetra
.03269 .47257 .04501 .48278 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46612 .08106 .45571 Mtetra
.08106 .45571 .09322 .46612 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45483 .11383 .44429 Mtetra
.646 .763 .934 r
.11383 .44429 .12587 .45483 .14236 .44912 .13038 .43851 Mtetra
.13038 .43851 .14236 .44912 .15895 .44337 .14703 .43269 Mtetra
.647 .763 .934 r
.14703 .43269 .15895 .44337 .17566 .43756 .1638 .42683 Mtetra
.1638 .42683 .17566 .43756 .19247 .43168 .18067 .4209 Mtetra
.648 .764 .933 r
.18067 .4209 .19247 .43168 .2094 .42571 .19767 .41489 Mtetra
.651 .765 .933 r
.19767 .41489 .2094 .42571 .22646 .41958 .21478 .40875 Mtetra
.655 .768 .932 r
.21478 .40875 .22646 .41958 .24364 .41318 .23202 .40241 Mtetra
.663 .773 .931 r
.23202 .40241 .24364 .41318 .26096 .40633 .24939 .39573 Mtetra
.677 .781 .929 r
.24939 .39573 .26096 .40633 .27845 .39865 .26692 .38842 Mtetra
.702 .796 .924 r
.26692 .38842 .27845 .39865 .29614 .38948 .28464 .38 Mtetra
.743 .821 .912 r
.28464 .38 .29614 .38948 .31408 .37766 .30258 .36958 Mtetra
.803 .854 .888 r
.30258 .36958 .31408 .37766 .33235 .36139 .32082 .35568 Mtetra
.874 .889 .841 r
.32082 .35568 .33235 .36139 .351 .33828 .33942 .33616 Mtetra
.936 .911 .77 r
.33942 .33616 .351 .33828 .37001 .30642 .35841 .30865 Mtetra
.97 .916 .692 r
.35841 .30865 .37001 .30642 .38921 .26652 .37771 .27223 Mtetra
.98 .914 .638 r
.37771 .27223 .38921 .26652 .40826 .22351 .39705 .22973 Mtetra
.978 .918 .63 r
.39705 .22973 .40826 .22351 .42689 .18431 .41607 .18763 Mtetra
.97 .931 .675 r
.41607 .18763 .42689 .18431 .44504 .15333 .4346 .1521 Mtetra
.942 .934 .76 r
.4346 .1521 .44504 .15333 .46283 .13079 .45269 .12537 Mtetra
.883 .907 .84 r
.45269 .12537 .46283 .13079 .48046 .11464 .47051 .1062 Mtetra
.811 .859 .884 r
.47051 .1062 .48046 .11464 .49804 .10257 .48824 .09223 Mtetra
.751 .814 .902 r
.48824 .09223 .49804 .10257 .51567 .09287 .50597 .0814 Mtetra
.713 .782 .907 r
.50597 .0814 .51567 .09287 .53339 .08446 .52377 .07234 Mtetra
.69 .764 .908 r
.52377 .07234 .53339 .08446 .5512 .07674 .54167 .06422 Mtetra
.678 .753 .908 r
.54167 .06422 .5512 .07674 .56912 .06935 .55967 .05659 Mtetra
.671 .748 .908 r
.55967 .05659 .56912 .06935 .58717 .06213 .57779 .0492 Mtetra
.667 .745 .908 r
.57779 .0492 .58717 .06213 .60532 .05497 .59603 .04191 Mtetra
.666 .743 .908 r
.59603 .04191 .60532 .05497 .6236 .04782 .61439 .03465 Mtetra
.665 .742 .908 r
.61439 .03465 .6236 .04782 .642 .04066 .63287 .02738 Mtetra
.664 .742 .908 r
.63287 .02738 .642 .04066 .66052 .03346 .65147 .02009 Mtetra
.65147 .02009 .66052 .03346 .67916 .02623 .6702 .01276 Mtetra
.664 .741 .908 r
.6702 .01276 .67916 .02623 .69793 .01895 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{Inherited, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooe;lD]`0
07oo0000Egoo003EOol30003Ool00e;lD]aBo002D_`01000D_aoo`00EWoo003BOol30004Ool02e;L
E_aBg5;lD]aFo5;L001Bg5Kl0000EWoo003@Ool20003Ool00e;lD]aBo002D_`02e;LD_aBo5;lD]aB
o000D_aBg5;l0000EGoo003=Ool30003Ool04e;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;l
D]aoo`0005Aoo`00bgoo0P000goo00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01P00D_aB
o5;lD]`005Aoo`00b7oo0`0001aoo`00OomFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo000E_aBg5;lOol005=oo`00Igoo0P000Woo0P00FGoo0P000goo00ABo000D_aBg0=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00=oo`00Ool0DGoo001XOol01000
Oomoo`00Egoo0`000goo01mBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_`005;lD]aFo5;LOol0001BOol006Uoo`8005Ioo`80009oo`MBo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo7oo0000DGoo001YOol2001COol3
0002Ool095;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo000E_aBg5;lD]aFo09oo`03001oogoo04ioo`00J7oo00@007ooOol0051oo`80009oo`iB
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo004D]aBo7oo001@
Ool006Moo`80009oo`8004aoo`<0009oo`0]E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aoo`0004mo
o`00]Woo0`000Woo00D005;lD_aBo5Kl011Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg000D_aBo5;L00=Bo003D]`0000004moo`00]7oo0P000goo03=Bo5KlD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o000E_aBg5;lD]aFo5;LD_aBg7oo0000CWoo002aOol30002Ool01E;lE_aFo5KlD_`00eKl0e;l00=F
o5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00MB
g5;lD_aBo5;LOol0001=Ool00:moo`8000Aoo`0hE_aG75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000
D_aBg5KlD]aBo5;LE_aBg5;lOol0015oo`D003Moo`00[7oo0`0017oo00IG75KlE_aFo5LLD_`3E_`0
15;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;L
D_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`00goo001oo`0?Ool01@00Oomoogoo0000=goo002Z
Ool20005Ool01UKlEaaFo5LLE_aG709Fo00fD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aoo`0047oo00<007ooOol0>7oo002WOol30002Ool00`00Oomoo`03Fa`3E_`00eLL
E_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo003001oogoo00Eoo`H000Aoo`03001o
ogoo03Moo`00YGoo0P001Goo04AK75LLFaaG75/LEaaK75KlEaaFo5LLD_aG75;lE_aBg5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`004Goo00<007ooOol0=Woo002ROol30006
Ool2Gc`7Fa`6E_`01U;lE_aBo5KlD_aFo11Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0@Ool00`00Oomoo`0eOol007Eo
o`@002Moo`8000Moo`18Gc]O?5lkGcaO>e/LEaaK75LLFaaFo5/LD_aG75;lEaaBo5LLD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg0003Goo00D007ooOomoo`0003Moo`00
M7oo00<007ooOol00Woo00<007ooOol08Goo0`001goo1ell15/L00=Fo5LLEa`01EKl00ABo5KlD_aF
o0=Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l
00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000=Ool3000hOol007Aoo`03001oogoo009oo`03001oogoo
01ioo`<000Uoo`1=IgaSFellGc]O?5lkGcaO>ellE_aK75KlFaaFo5/LE_aG75;lE_aBo5KlD_aFo5;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol00017Ool007Aoo`03001o
ogoo009oo`03001oogoo01aoo`80009oo`03001oogoo00Ioo`9WF`03Ig]WFell00=O?09K7007FcaF
o5LLEaaK75KlEa`00UKl00ABo5KlE_aFo0=Bo005E_aBo5;lD_aFo00<D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000Agoo
001dOol00`00Oomoo`02Ool00`00Oomoo`0IOol3000;Ool036MKIgaSFfMlIe]WO6=KGcaK75llFa]O
?09K7013E_aK75KlEaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg7oo0000AWoo001dOol00`00Oomoo`02Ool00`00Oomoo`0GOol2000=Ool3
Ie/01VMkIe]WFfMKHeaS>`9K7005FcaK75/LFaaG7003E_`00eLLE_aFo002E_`015;lE_aBo5Kl0e;l
00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00000e;l
00EBg5;lD_aBo5;L00=Bo004D]aBo5;lD_`2Ool00`00Oomoo`13Ool007Aoo`03001oogoo009oo`03
001oogoo01Aoo`<000ioo`0@KiYcVV=KIgaWFfMlHe]SG6<kHeaK6ellFaaO?5LLFa`2Ea`0@UKlEaaF
o5LLE_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lOol004Eoo`00MGoo10005Goo0P0047oo16nJ0VMK0V=L00AS>f=LHeaSG0MK7003EaaFo5Kl00AF
o006D_aFo5;lE_aBo5Kl45;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`005;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aoo`00A7oo002;Ool3000BOol04g>JKiUcVVnJ
LiYO>f=LHc]SG5lkHeaO>ellEaaK75LLFaaG75/L009G7012D_aG75;lEaaBo5LLD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`00@goo0029Ool20002
Ool00`00Oomoo`0?Ool5KiX2Jg/00f<kHeaSG005Gc`5Fa`2Ea`7E_`00e;lE_aBo002D_`00eKlD_aB
o00>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aoo`0004=oo`00QWoo0`005Goo05YcVVnILiY_VV^KJgY[Vf]jJi]O>ell
Gc]O?5lkGcaO>e/LEaaK75KlFaaFo5/LE_aG75;lEaaBo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo0012Ool008Aoo`8001Moo`A_VP=[N`04
JgY[NfMKIg/7Gc`01e/LE_aG75LLFaaFo5LL00IFo0=Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00U;l00=oo`00Ool0@7oo0021Ool3000HOol04gNhMiMk^6]jJi][NV^KJgY[Vf=KIgaWFfMlGc]O
?5lkGcaK6ell009K7018E_aK75KlFaaFo5/LD_aFo5;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`00@Goo001nOol3000JOol3MkL01G>H
LkU[Nf]kJgX00VMK00EWNfMKIe]WFfMk00=K7003FcaK75/L009K7004E_aG75LLEa`4E_`015;lE_aF
o5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`00@7oo001lOol2000L
Ool07GNhMiMk^7NgMkUcV7NiLiQWO6=KIgaWFfMlHe]WO6<kHeaK6ellFaaO?5/KGcaK75LLE_aG75Kl
Ea`00UKl049Bo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo7oo000oOol007Uoo`<0009oo`8001Yoo`=g]`04LkUcVG>iLiP2KiX01VMk
Ie]WFfMKIg]S>`=SG0=K7005FcaK75/LFaaG7003E_`02ELLE_aFo5;lE_aBo5KlD_aFo003D_`00eKl
D_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`0003moo`00Mgoo0P0087oo06=gUg^hMkMg
^G>HMkUcV7>JKiUcVVnJIgaSFf=LHc]SG5lkHeaS>f=LEaaK75LLFaaG75/LE_aG75KlEaaBo5LLD_aF
o5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg7oo0000?Woo001dOol3000QOol3MkL01G>iLiUc^G>HLkT01FnJ00=SG6<kHe`00V=L00AS
>f=LGcaO?0IK70QFo003D_aFo5;l009Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00AB
g5;lD_aBo09oo`03001oogoo03]oo`00LWoo0P008goo06IgUg^hMkMg^7>HMkUcV7NiKiUcVVnJLiY_
VF^KJgYSG5lkHeaS>ellGc]O?5lkFaaG75/LEaaK75KlFaaBo5LLD_aG75;lEaaBo5KlD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000m
Ool006moo`<002Eoo`07NkEk]7^eLiUc^G>HLkT01FnJ00=[Nf]jJg/00V]k1ell00MK75KlEaaG75/L
E_aG7006E_`3D_`00eKlD_aBo00>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l009oo`03001o
ogoo03Yoo`00KGoo0P0000=oo`00Ool097oo01Uk]G^DNkEgUG^fMkIk]VnILiY_VW>JJgY[Vf]jJi][
NV^KIe]WO5lkGcaO>ellGc]O?002Fa`0BeKlFaaFo5/LE_aK75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg002Ool0
0`00Oomoo`0iOol006Yoo`<002Uoo`06NkAk]G^dNkIg]W^f17Ng0V]k00A[NV]kJg][N`=WF`05Ig]O
?5llFaaK?004Fa`015KlEaaG75LL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0jOol006Moo`<002]oo`1[NiAk]G^DNkIg
]W^fMiEk^7NgMkQcV7NiJgY[Vf]jIgaWFfMlHe]WO6MKIgaK6ellFaaO?5/KGcaK75LLE_aG75KlEaaF
o5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000jOol006Eoo`8002ioo`04NkEk]7^eMkH2NkH3MkL01W>I
LkUcV7>iLiUWN`=WF`03Ig]WFfMK009SG0=K7005FcaK75/LFaaG7003E_`02ELLE_aFo5;lE_aBo5Kl
D_aFo003D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg002D_`00`00Oomoo`0hOol0069oo`<002moo`0ONkEkU7^eMkIk]WNENkQg]gNhMiMg^G>HMkUc
V7>JKiYWO6=KIgaWFf=LGc]SG6<kGcaK6ellEaaK75LLFa`00ULL04aFo5LLE_aG75;lEaaBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]`003Uoo`00H7oo0P00<Woo00=k]7^eNk@00W^f17Ng00Ac^G>HLkUcV@E_VP05Hc]S
G6=LHeaS>`02He`7Fa`00eKlEaaFo005E_`015;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000hOol005eoo`<00003Ool007oo031oo`1_NiAk]G^DNkIg
UG^fMkMg^7NGMkUcV7NiLiQcVVnJLiY_VG>JJgY[VelkHeaS>f=LGc]O?5lkFaaG75/LEaaK75LLFaaB
o5LLD_aG75;lEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo00003Qoo`00Fgoo0P00=Woo00=k]G^dNkD00W^f
0gNg00Ac^G>HLkUcV@E_VP06JgY[Nf]kHeaS>f=L1Ell1E/L00=Fo5LLE_`01EKl0e;l00=Fo5;lD_`0
3U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000=goo000^Ool4000V
Ool3000gOol0LW^eNiAk]G^COkAkTg^eNiAk]WNfNkIgUG>JKiYcVVnILiY[NV^KJgY[Vf]jGcaO>ell
Gc]O?5lkGcaO>e/LE_aK75KlFaaFo5LLD_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0029o
o`<0015oo`00;Goo00<007ooOol00Woo00<007ooOol08Goo0P00>Woo0g^C00Ik]7^CNkEk]7^eMkH2
NkH2MkL3KiX01F]jJg][Nf]kJgX00VMK1Ell15/L00AFo5LLEaaK70AFo004D_aFo5KlE_`3D_`00eKl
D_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo000T
Ool00`00Oomoo`0?Ool0039oo`03001oogoo01eoo`@003aoo`0UOk=kTgndNi=k]7^DNkEg]W^fMiEk
]WNgMkQgUg^hJgY[Vf]jJi]WFfMlHe]WO6MKIgaK6ellFaaO?5/KGcaFo5/LE_aK75KlEa`00UKl04aB
o5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol002=oo`03001oogoo00moo`009Goo1P001goo00<0
07ooOol077oo0`00?Goo0W^C00Ik/g^CNkAk]7^eNk@3NkH4MkL017>HLkUc^G>i0fMK00=WNfMKIe/0
0V=L0e/L00EK?5/LFaaFo5LL00=Fo003EaaFo5Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol0
025oo`03001oo`00011oo`00;Woo100077oo0`00@7oo01ikTgndNi=k]7^CNkEkU7^fMiEk]WNfMkQg
Ug^hLiQg^G>HMkU_VW>JHe]WO6MKIgaO>f=LHc]SG5/KGc`2Fa`025LLFaaFo5LLE_aG75KlEa`2E_`0
Be;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000QOol00`00Ool0000@Ool002ioo`03001oogoo
01Yoo`<0049oo`08Ni=k/g^CNkAkU7^eNkAk]@9k]P03MkIg]gNg009g]`=c^@=_VP03Ig]WFf=L009S
G004Hc]SG6=LHe`6Fa`00eKlEaaFo005E_`015;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`2000OOol01@00Oomoogoo00003goo000^Ool0
0`00Oomoo`0HOol20015Ool0N7ndNi=k]7^COkAkU7^eMiEk]WNfMkQgUg^hMkMg^G>HMkUcV7>JKiUc
VVnJHeaO>f=LHc]SG5lkHeaO>ellEaaK75LLFaaG75/LD_aG75;lEaaBo5LLD]aFo5;lE_aBg5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LOol001ioo`05001oogooOol0000?Ool002ioo`D001=oo`<004Moo`9kT`08
NiAk]7^dNkEk]7^fMkIk]P=g]`=c^@03LiQ_VVnJ009_VP9[N`04HeaS>f=LHe`4Gc`5Fa`00eKlEaaF
o005E_`3D_`00eKlD_aBo00>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;L
D_aBo5;lD]aBo7oo000MOol3000017oo000000003Woo0014Ool20019Ool0NW^COk=kTgndNi=k]G^D
NkIg]W^fMiMk^7NgMkUcV7NiLiQcVVnILiY_VV^KJgY[Vf]jJi]O>ellGc]O?5lkGcaO>e/LE_aK75Kl
FaaFo5/LD_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0009Ool4000TOol0
045oo`<00003Ool007oo04Qoo`9kT`0:NkAkTg^CNi=k/g^CNkAkU7^eNk@3NkH01GNfKiY_VVnJJgX0
0f]k00A[NV]kIe]WN`EO?0=K7006E_aG75LLFaaFo5LL0UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00YB
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QBg5;lD_aBo5;LD_ao
o`001goo00<007ooOol00Woo00<007ooOol08Goo000oOol2001=Ool08gncNi=o]7^COk=kTgndNi=k
]7^CNkEkU7^eMiEk]WNfMkQgUg^hJgY[Vf]jJi][NV^KHe]WO6MKIgaO>ellFaaO?5/KGc`00U/L05MF
o5/LE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<0
07ooOol00Woo00<007ooOol08Goo000lOol3001?Ool00g^CNk=kT`02Ni<017^cNi=k]7^D0W^d00Ek
]G^fNkIg]W^f009g]`05LiQc^F]kJg][NP02Ie/01FMkIe]WFfMKIg/00e/L00EK?5/LFaaK75LL00=F
o003EaaFo5Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00MBg5;lD_aBo5;LOol00006Ool00`00Oomoo`02
Ool00`00Oomoo`0QOol003Yoo`80055oo`0VNi=o]7^COk=kTgndNi=k]7^COkAkU7^eNiAk]WNfNkIg
Ug^hMkMg^G>HMkUcV6MlHe]WO6MKIgaSFfMlHc]SG5/KGcaK75llEaaK709G7004E_aG75KlEa`2E_`0
CU;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo09oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo025oo`00=goo0`00Dgoo00EkU7^CNi=kTg^c009kT`08NiAk]7^CNkEk]7^fMkIk
]P=g]`=c^@04LiQ_VVnJIg/3Ie/00f=LHc]SG002He`6Fa`00eKlEaaFo005E_`015;lE_aBo5Kl3U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00=oo`00Ool017oo00<007ooOol00Woo00<007ooOol08Goo000eOol200000goo001oo`1COol0OG^C
OiAkTgncNi=o/g^COkAkTg^eNiAk]GNfNkIgUg^hMkMg^G>HMkUcV7>JKiUcVVnJLiYO>f=LHc]SG5lk
HeaO>ellEaaK75LLFaaG75/LD_aG75;lEaaBo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]`00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol08Goo000bOol3001GOol7
Ni<01W^dNi=k]7^dNkEg]P9k]P=g]`9c^@03LiQ_VVnJ00=_VP9[N`03Hc]SG6=L00EO?0AK7003E_aG
75Kl00IFo09Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`00e;LD_aBo0030004Ool4000TOol002moo`<005Yoo`22OiAkTgncNi=o/g^C
OkAkTg^dNiAk]G^DNkIgUG^hMkMg^7>HMkUcV7>JKiUcVVnJLiY[NV^KJgY[VelkGcaO>ellGc]O?5lk
GcaFo5/LE_aK75KlFaaBo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg7oo000/Ool002eoo`8005aoo`9kT`09NiAkTg^CNi=k/g^CNkAkU7^e009k]004NiAk]7^dNkD2
NkH00gNfKiY_VP02KiX3Jg/016]jJg]WFfMk1Ell00AK?5/LFcaFo09G7003FaaFo5LL009Fo004D_aF
o5KlE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg00200000e;lD]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`0002]oo`00:Woo0`00GWoo02IkTgndNi=o
/g^COkAkTg^dNi=o]7^COk=kTgndNiAk]G^DNkIg]WNhMiMk^7NgJi][NV^KJgY[Vf=KIgaWFfMlHe]O
?5/LGcaK6ell0U/L02eFo5/LE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`00`0002YBg5Kl001Bo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_`2Ool00`00Oomoo`0XOol002Qoo`800003Ool007oo05eoo`03Ni=kU7^C009k
T`03Nk=kTg^C00AkT`08NiAk]7^CNkEk]7^fMkIk]P=g]`9c^@05Jg][NV]kIe]WN`03Ie/02F=LHc]K
?5/LFcaK75/lFaaG7003E_`00eLLE_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L00000000D]`00e;l00EBg000D_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`015;LD_aoo`00:Woo000VOol2001ROol0:GndNi=o/g^COkAkTgnDNi=o/g^COk=kTgndNi=k]G^D
NkEg]W^fMiMk^7NgMkUcV7NiLiQg^F=KIgaWFfMlHe]SG6<kHeaO>ellFaaO?5LLFa`00ULL00AFo5LL
E_aG709Fo00PD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo080000aD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`00Woo
00<007ooOol09goo000VOol2001QOol00g^DNi=kT`09Ni<01W^dNi=k]7^dNkEg]P9k]P=g]`9c^@04
LiQc^FnJKiX2Ie/2He`01F<kHeaSG6=LHc/01U/L00=G75KlE_`015Kl00IBo5KlD_aFo5;lE_`<D_`0
1E;LD_aBo5;lD]`00e;l00=Bg5;l00000P000e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00ABg7ooOol002Qoo`009Woo0`00H7oo02akTgnDNi=o/g^DOiAkTgncNi=o/g^COkAkTg^d
NiAk]G^DNkIgUG^hMkMg^7>HMkUcV7NiKiUcVVnJLiYO>f=LHc]SG5lkHeaS>ellGc]K75LLFaaG75/L
0ULL01iBo5LLD_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_`30000>UKlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aoo`00:7oo000VOol01000Oomoo`00GWoo0g^C0W^D1W^C00Ik/g^CNkAkU7^eNk@3NkH2MkL2LkT0
0g>HLkU_VP03KiX2Jg/016<kHeaSG6=L15ll15/L00=Fo5LLEa`01UKl0U;l00=Fo5;lD_`03U;l00=B
g5;l00000P000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo09oo`03001oogoo02Eoo`009Goo00<007ooOol00Woo00<007ooOol0Fgoo04MoU7^EOkEkU7nd
Ni=o]7^COk=kTgndNi=k]7^CNkEkU7^eMiEk]WNgMkQcV7NiLiQg^FnILiY_VW>JJgY[Vf]jJi][NUll
Gc]O?5lkGcaO>ellE_aK75KlFaaFo5/LD_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5Kl00<00011E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000WOol002Eoo`03001oogoo00=oo`03001oogoo05Uo
o`=kU@9kU003Ni=kU7^C009kT`04Nk=kTg^dNi@2Nk@01G^eNiAk]7^CNkD00W^f00=g]W^fKiX00fnJ
0V]k00E[NV]kJg]WNfMK00AO?004FcaK75/lE_`2Ea`00e/LE_aG7002E_`015;lE_aFo5Kl0e;l00=F
o5;lD_`025;l0`000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`0UOol002Eoo`03001oogoo00Aoo`03001oogoo
05Qoo`12NiEk]W^DOkAkU7ndNi=o/g^COkAkTgncNi=o]7^COk=kTgndNi=k]G^DNkIg]G^fMiMk^7Ng
MkQ[NV^KJgY[Vf=KIgaWFfMlHe]O?5/LGcaK6ellFaaO?5KlFaaFo5LLE_aG75;lE_aBo5LLD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5Kl0`0004IFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg09oo`03001oogoo02=oo`00
9Goo0P001Woo0P00Egoo0g^E0g^D1W^C00=kU7^dNi<00W^C00Ik]7^CNkAk]7^fMkH2NkH3MkL2LkT0
47>HIg]WFfMkIe]WNfMKHeaS>e/lFaaK?5/LFcaK75/l0eKl00=G75KlE_`00UKl00ABo5KlD_aFo0=B
o004E_aBo5;lD_`20003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000UOol002Eoo`03
001oogoo00Moo`03001oogoo05Aoo`0nNkIkUGndNiAo]G^COiAkTgncNi=o/g^COk=kTgncNi=o]7^C
NkAkU7^eMkEk]WNENkQg]gNhLiQg^G>HLiY_VFMlIe]WO5lkHeaS>f=LGc]O?5/LGcaK6e/LEaaK75Kl
EaaFo5LLE_aG75;lE_aBg5KlD_aFo5;LE_aBg0<0001?D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg7oo000097oo000UOol00`00Oomoo`08Ool00`00Oomoo`1BOol3NiD2Ni@7Ni<02W^DNi=k
Tg^CNk=kTg^dNiAk]GNf0W^f17Ng00=c^G>HLkT016nJ0V=L00ES>f=LHeaSG6<k00MK70IFo005D_aF
o5;lE_aBo003000:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo7ooOol0000SOol002Eoo`03001o
ogoo00Uoo`03001oogoo055oo`0iNiEk]G^DOkEkU7nDNi=o/g^COkAkTgndNi=o/g^COkAkTg^dNi=k
]G^DNkIgUG^hMkMg^7NGMkUcV7NiKiUcVVnJLiY[NV^KHc]SG5lkHeaO>ellGc]K75LLFaaG75/LE_aK
75;lEaaBo5LLD_aG75;l00<0001FD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlOol002=oo`0097oo0P0037oo00<007ooOol0Cgoo0g^E0W^D0W^C0g^D00=kTg^DNi<0
0W^C00Ak/g^CNkAkU09k]0=k]P=g]`03LkUcV7>i00A_VP9[N`03JgY[Nell00IO?09G7004FaaFo5LL
Ea`4E_`300000e;lE_aBo00?D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol0029oo`0097oo00<007oo
Ool037oo00<007ooOol0CWoo03Ak]G^EOkEkU7ndNi=k]W^EOkAkU7ndNi=o/g^COk=kTgncNi=o]7^D
NkEgUG^fMkMg^7NGMkUcV7NiLiQcVVnJLiY[NV^KJgY[Vf=KIgaO>ellGc]O?5lkGcaK6e/LE_aK75Kl
FaaFo0<0001KD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]`00Woo00<007ooOol07goo000TOol00`00Oomoo`0=Ool00`00Oomoo`1<Ool3NiD2
Ni@3NiD3Ni@6Ni<02g^DNkAkTg^eNiAk]7^CNkEk]7^fMkH00W^f0fnJ0V]k00I[NV]kIe]WNfMKIg/2
Gc`01E/LFcaK75/lFa`00ULL0`000UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`0
05;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo003D]aoo`00025oo`0097oo00<007ooOol03Woo00<007ooOol0Bgoo031kUG^f
MiIk]gNFNkIkUG^eNiAo]G^COiAkTgncNi=o/g^COkAkTgncNi=o]7^CNkEkU7^eMkEk]WNENkQg]gNh
JgY[Vf]jJi]SFfMlIe]WO6=KIgaK75llFa]O?5/LGc`2000015KlEaaFo5LL0UKl05mBo5LLD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00
021oo`0097oo00<007ooOol03goo00<007ooOol0BGoo0WNH00=gUW^FMiH00g^E0W^D1g^C00Ik]7^C
Ni=kTg^dNi<2Nk@00g^eMkIk]P02NkH2MkL2LkT037>HLkUWFfMkIe]WNfMKIg]S>f=LFaaK?0<0009K
709Fo003EaaFo5Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L0002
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00ABg5;lD_aBo09oo`03001oogoo01eoo`0097oo0P004Goo00<007ooOol0Agoo02acUgNh
MiMk]gNFNkMkUG^eNiEo]G^DOiAkTgncNi=o/g^COkAkTgncNi=o]7^CNkAkU7^eNiAk]WNENkIg]gNh
MiMg^G>HMkU_VG>JIe]WO6=KHeaS>f=L0`0006]K75LLFaaG75/LE_aG75KlEaaBo5LLD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_ao
o`0001moo`008goo00<007ooOol04Woo00<007ooOol0AWoo00EgV7NGNiIgUW^F00=kU@9kU09kT`05
NiAkTg^CNi=k/`03Ni<01W^cNi=k]7^DNkEk]0=k]P=g]`03LkUcV7>i00A_VP9SG0<00003HeaO?5ll
00IK70IFo006D_aFo5;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_ao
o`007Woo000JOol40005Ool00`00Oomoo`0COol00`00Oomoo`14Ool09gNhMiMgV7NFNkMgUW^eNiEk
]W^DOkAkTgndNi=o/g^COkAkTgncNi=o]7^CNkAkTg^eNiAk]WNENkIg]gNhMiMg^G>HMkU_VG>JKiYc
VP030000L6=LGc]O?5lkGcaO>ellEaaK75LLFaaFo5/LD_aG75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00<007oo
Ool06goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`12Ool0
1WNHMiMgV7NFNiIgUP=kU@9kU004Ni=kU7^CNi<2Ni@3Ni<017^cNi=k]7^D0W^d00Ak]G^fNkIg]P=g
]`04LiQc^FnJKiX3000016]kJgY[Nf]k1ell00=G75/LE_`00ULL00=K75KlE_`00UKl00ABo5KlD_aF
o0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000MOol001Uo
o`03001oogoo009oo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo041oo`0SMkQgUgNHLiMk
]gNFNkMkUG^fNiEo]7^DOkAkTgndNiAo]G^COiAkTgncNi=o/g^COkAkU7^eMiEk]WNeMkQgUg^hLiQg
^@030000NW>JJgY[Vf]jJi][NVMlIe]O?5lkGcaO>ellFa]O?5KlFaaFo5/LE_aK75;lEaaBo5KlD_aG
75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg7oo000LOol001Uoo`03001oogoo009oo`03001oogoo009oo`8001Moo`80041oo`06MiMg
V7NHNiIgUW^F0g^E0W^D0g^E0W^D1W^C00]kU7^dNi=k]G^CNkAkTg^eNkAk]GNf008000=g]`9[N`0@
JgY[NfMKIg]WFfMkIe]K?5/LFcaK75/lFaaK?5KlEa`3E_`00eLLD_aFo002E_`015;lE_aBo5Kl35;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo01Yoo`006Goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol067oo00<007ooOol0?7oo01mgUgNHLiMg^7NFNkMg
UW^fNiEk]G^DNkMkUG^eNiAo]G^DOiAkTgncNi=o/g^COkAkTgncNi=o]7^CNkAkU00300004WNENkQg
]gNhLiQg^G>HIgaSFfMlIe]WO6=KHeaS>ellFa]O?09K701/EaaK75KlEaaFo5LLE_aG75;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg0006goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00
Oomoo`0jOol01gNGMiQgV7NHMiIkUWNF00=kU@03MiIkUW^E009kU@9kU09kT`03NiAkTg^C00EkT`03
Nk=kT`0000800003NkAk]W^f00=g]`9c^@06LiQ_VVnJIg]WFfMk0V=L00ASFf=LHeaSG0IK7003E_aG
75Kl00=Fo006D_aFo5;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00ABg5;lOol001Yoo`006Goo00<007ooOol00Woo00D007ooOomoo`0001eoo`03001oogoo03Qoo`0K
KgY_VV]iKiYcN7>ILgQg^7NGMiQgUW^gMiIk]G^EOkEkU7ndNi=o]7^COk=kTgndNi=o/g^C00<00028
Ni=k]G^DNkEgUG^fMkMg^7NGMkUcV7>JKiUcVVnJLiYO>f=LHc]SG5lkHeaO>ellEaaK75LLFaaG75/L
D_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0007Ool5000=Ool001Yoo`@000Aoo`8001eoo`03
001oogoo03Ioo`=_NP03KiYcVG>I009cV@05MiMgV7NHNiIgUP03NiD2Ni@00g^CNiAkT`02Ni<00g^D
Ni<0000200001W^CNkAkU7^eNkAk]@9k]P=g]`03LkUcV7>i00A_VP9[N`03He]SG6=L00AO?0EK7003
E_aG75Kl00EFo0=Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o003D]aoo`0000Moo`05001oogooOol0000=Ool0029oo`03001oogoo01eoo`03001oogoo03Aoo`0G
KgY_VV]iKiYcN7>ILgQcVGNGMiQcUg^gMiIk]g^ENkIkU7ndNiAo]7^COk=kU0030000Sg^COkAkTg^d
Ni=o]7^DNkEgUG^fMkEg^7NGMkUcV7NiKiUcVVnJLiY[NV^KJgY[VelkGcaO>ellGc]O?5lkFaaFo5/L
E_aK75KlEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol03Woo000ROol0
0`00Oomoo`0NOol00`00Oomoo`0bOol3KgX00fnJKgYcV@03LiT3MiP00gNFNiIkU@02NiD3Ni@017^C
000000001W^C00MkU7^dNkAk]G^dNkIg]P02MkL00g>iLiQc^@03KiX3Jg/016]jJg]WFfMk15ll00EK
75/lFaaK75Kl009G7003FaaFo5Kl009Fo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo009D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`05Ool00`00Oomo
o`0=Ool0029oo`03001oogoo01moo`03001oogoo031oo`0DKgY_VV]iKiY_NW>ILgQcVG=hMiQcUgNh
MiIk]gNFNkIkUGndNiAo]@80002FNiAo]G^COiAkTgncNi=o/g^COkAkTg^eNiAo]7^CNkAkU7^eMkEk
]WNGNkQg]f^KJgY[Vf]jJi]SFfMlIe]WO6=KGcaK75llFa]O?5/LGcaFo5LLE_aG75KlEaaBo5KlD_aG
75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aoo`0027oo00<007ooOol037oo000ROol00`00Oomoo`0POol00`00Oomo
o`0^Ool01F=KIe]_NVnJKgX017>I0gNH00=gUg^FMiH00g^E0`000W^E00=kU7^CNi<01G^C00Ik]7^C
Ni=kTg^cNi<2Nk@017^eMkIk]W^f0WNg0W>i00m[Nf]jJg]WFfMkIe]WNfMKHeaSFe/lFaaK?5/LFc`0
0U/L0eKl00UG75KlE_aBo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo002Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
025oo`8002=oo`03001oogoo02aoo`0@He]WO6=KIgaSFg>ILgQcVG=hLiUcUgNhMiMk]gNFNkL30000
:GneMiIk]G^EOkEkU7nDNi=o/g^COk=kTgndNi=o/g^COkAkTg^dNi=k]G^DNkIgUG^hMkMg^7>HMkUc
V7NiHe]WO6MKIgaO>f=LHc]SG5/KGc`00U/L06mG75/LEaaG75KlEaaBo5LLD_aFo5;lE_aBg5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]`00Woo00D007ooOomoo`0000=oo`03001oogoo00]oo`008Goo00<007ooOol08goo
00<007ooOol0:Goo00IWG6=KIe]WFfMLHe/5Jg/2MiP00gNGMiP000020002NiD00g^FMiIkU@02NiD2
Ni@00g^CNiAkT`02Ni<02W^cNi=kTg^CNk=kTg^dNiAk]G^d0W^f0gNg0W>i00=cV7>iKiX00VnJ0f=L
00ASFf=LHeaSG0MK70MFo003D_aFo5;l00mBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L
0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00=Bg5;lD_`00P0017oo0`003Woo000QOol00`00Oomoo`0TOol00`00Oomoo`0WOol0
3FMlHe]WO6=KIgaSFf]kIeY[NfMjJg][NFnJ00<0002TNkMgUWNHLiMk]gNFNkMkUG^fNiAo]7^COkAk
TgncNi=o]7^COk=kTgndNi=k]7^COkAkU7^eMiEk^7NgMkQcV7NiLiQg^FnILiY_VV^KJgYSG6<kHeaO
>ellGc]O?5LLFaaG75/LE_aK75KlEaaBo5LLD_aG75;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0
01Aoo`008Goo00<007ooOol09Goo00<007ooOol09Goo0Ull0VMK00=WG6=KJg/016]k0`0000A_NW>I
LiUcV@=gV003MiIkUW^E009kU@=kU0=kT`05NiAkTg^CNi=k/`02Ni<017^DNkAk]7^e0W^f0gNg00=c
^G>HKiX00fnJ0f]k00=[NV]kGc`01Ull0ULL00=K75KlEa`01UKl0e;l00=Fo5;lD_`03U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000COol0025oo`03001o
ogoo02Ioo`03001oogoo029oo`0:FcaOGE/lGeaK?6MlHe][NfMJJg/30000ZfnJKgY_VW=hLiUcN7>I
LiMg^7NFNkMgUW^fNiEo]7^DOkAkTgncNi=o]G^COiAkTgncNi=o/g^COkAkTg^eNiAk]WNgMkQgUgNi
LiQcVVnILiY_VV^KJgY[Vf]jJi]SFfMlGc]O?5lkGcaK75llFa]K75KlFaaFo5/LD_aFo5;lEaaBo5Kl
D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol0000COol0025oo`8002Qoo`80021oo`QO?09[N`800003
Jg]_NVnJ00=_NP=cV@9gV003MiMkUWNF00=kU@9kU09kT`9kU0MkT`03NkAkTg^e009k]005Ni=k]G^d
NkIg]P04MkL3Jg/03F]jIg]WFfMkIe]WNe/LFcaK75/lFaaK?5/L009Fo003EaaFo5Kl009Fo004D_aF
o5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000BOol0025oo`03001oogoo02Uoo`03001oogoo01aoo`08
FceG75mMFcaOG5/lGeeK?0<0000nIgY[Nf]iKiY_NVnJJgUcVG=hLiUcUgNhMiMk]gNFNkMkUG^eNiAo
]G^COiAkUGneNiAoU7^COk=kTgncNi=o]7^CNkAkU7ndNi=k]G^DNkEg]G^fMiMk^7NgMkUcV7NiIe]W
O6=KIgaWFfMlGc]SG5/LGcaK6ellEaaK709G7004E_aG75KlEa`2E_`0Je;LE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`0
05KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5Kl00004Woo000POol00`00Oomoo`0[Ool00`00Oomoo`0IOol01ELLEaeG75/m
Ea`00Ull0`000V=L00AOG6=LKgY_VP=_NP=cV@9gV004MiMgV7NFNiH3NiD2Ni@2NiD2Ni@2Ni<02W^D
Ni=kTg^CNk=kTg^dNi=k/g^C0W^d00=k]GNfNkH00gNg0g>i0VnJ00=WFfMkIe/00f=L00=SFf=LHe`0
1E/L0eKl00=G75KlE_`00UKl00ABo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00004Goo000POol00`00Oomoo`0/Ool00`00
Oomoo`0FOol01U/mEaaK?ELLFceG70<0002iGc]SG5lkHeaO>f=LHe]WO6=KIgaSFg>ILgQcVG=hMkQg
UgNHMiIk]gNFNkEkUGneNiAk]g^ENkIkU7ndNi=o]7^COk=kTgndNi=o/g^COkAkTg^dNiAk]G^DNkIg
UG^hMkMg^7>HMkU_VW>JKiUcVVnJHeaO>f=LHc]SG5lkGcaO>e/LEaaK75LLFaaBo5LLD_aG75;lEaaB
o5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000@Ool0021oo`03001oo`0002eoo`03
001oogoo01=oo`9G7@03DaaG7ELL00<00003EaaK?E/l00=SG005GeaSG6MKIeaSF`02Ie/4Jg/01WNH
MiMgV7NHNiIgUP=kU@04MiIkUW^ENiD4Ni@3Ni<02W^cNi=kTg^CNk=kTg^dNi=k]G^d0W^f0gNg0W>i
00=cV6nJKiX00VnJ0V]k00=SG6=KHe`015ll0e/L0ULL00=K75KlE_`015Kl00=Bo5KlD_`00U;l00=F
o5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`2000@Ool0021oo`8002moo`03001oogoo00moo`05DaaG7E;lEaeC70030000`5LLFceK75/m
FaaK?E/LHeaO>fMlHe]WO6=KIgaSFf]kIgY[NfMJKiY_NVnJJgUcVG=hMiQcUgNHMiIk]gNFNkIkUGnd
NiAo]7^COk=kTgndNi=o/g^COk=kTgncNi=o]7^DNkIgUG^fMkMg^7>HMkUcV7>JKiUcVVnJJi][NV^K
JgYO?5lkGcaO>ellGc]O?5KlFaaFo5/LE_aK75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lOol000moo`001Goo1@001Goo0P001Goo10001Woo00<007ooOol0;goo00<007oo
Ool037oo00AC7E;mDaeG7@<0009G7@04DaaK?5/lFcd3Fc`01e/mFcaWFfMKIeaSFfMK00E[N`04KiY_
NVmjKgX3LiT2MiP00gNGNiIgUP02NiD3Ni@;Ni<2Nk@00g^eNkIk]P02MkL2LkT01G>HKiY_VVnJJgX0
0f]k00=[NVMkIe/015ll00UK?5/LFcaG75/LE_aG75KlEa`015Kl00ABo5KlD_aFo0=Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo009D]aBo5;lD_aBg5;l001Bo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg002D_`2Ool00`00Oomoo`0<Ool000Aoo`800005Ool00000Ool00004Ool20004Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool01E<MD_aG7E;lDad00P000<MC
75LMD_aG7ELLEaeC75/mFaaK?E/LFceK?5llFcaWO6=KIgaWFV]kIgY[NfMJJg]_NVnJJgUcVG=hLiUc
UgNHMiMk]gNFNkMkUG^eNiAo]G^COiAkTgncNiAoU7^COk=kTgncNi=o]7^CNkEkTgndNi=k]G^DNkIg
]GNhMiMk^6]jJi][NV^KIe]WO6=KIgaWFfMlFa]O?5/LGcaK6ellE_aG75KlEaaFo5LLD_aG75;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000>Ool000Aoo`80009oo`03001oo`00
00moo`03001oogoo00=oo`03001oogoo035oo`03001oogoo00Eoo`04D_eC7E;mDad300000e<MD_eC
7@02Ead01ULLEaeG7ELMEaaG7@QO?0I[N`=_NP09KiYcVG>ILiUgV7NGMiQgUW^F009kU@=kU09kT`9k
U0IkT`0;NkAkTg^eNi=k]7^CNkEk]7^fMkIk]P02MkL02W>HLkUc^G>iIe]WNfMKIg]WFfMk0V=L00=K
75/lFa`00e/L00=Fo5LLE_`00UKl00EG75;lE_aBo5Kl00=Bo003E_aBo5;l00IBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009B
o003Ool007oo00aoo`0017oo0P000Woo00<007oo00003goo00<007ooOol00Woo0P00=7oo00P007oo
OomoodklDaeBo5<M0`000<iC7E;lEaeBo5LMD_aG7ELLEaeC75LmEaaG7ELLFceK?5llFcaOGE/lGcaO
>f=LGc][NfMJJg]_NVnJJgU_VW=hLiUcN7NHMiMgV7NFNkMgUW^eNiEo]G^DOiAkTg^fNiAoU7^COkAk
TgncNi=o]7^CNkAkTgndNi=k]7^DNkEg]G^fMiMk^7NgMkUcV7NiKiYcVV=KIgaWFf=LGc]SG6<kHeaG
75/LEaaK75LLFaaFo5LLE_aG75;lEaaBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aoo`0037oo0004Ool20002Ool00`00Ool0000;Ool40005Ool00`00Oomoo`0bOol00e;mDaeB
o@02D_d02E<M00000000DaeBoE<MD_eG7@03Dad00eLMDaeC7@02Ead01ULLEaeG75/mEaaG7@=O?0=S
G004GeaSG6=LHe`3KgX02VnJLiUcVG>IMiQgUgNHMiIkUWNF0W^E0g^D0W^E0W^D00=kTg^DNi<00W^C
00Ik/g^CNkAkTg^cNi<2Nk@017^eMkIk]W^f0WNg0g>i16nJ00ISFf=LHeaSG6=KHe`2Gc`6Fa`6E_`3
D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol000aoo`000goo0`0000Eoo`00001oo`0000]oo`03001o
ogoo00Ioo`03001oogoo031oo`05Dae>o5<MC_aC7@030000eE<MC_aC7E;lDaeBo5<MD_aG7E;lEaeB
o5LMD_aG7ELLFceG75/mEaaK?ELLFceO>f=LGc]SG5lkHeaO>f=LHe]WO6=KIgacN7>ILgQcVGNGMiQc
Ug^gMiIk]g^ENkIgUW^GMiIk]W^EOiAkU7ndNi=o/g^COkAkTgncNi=o]7^CNkAkTg^eNiAk]WNENkQg
]gNiLiQg^G>HLiY_VG>JJgY[VelkHeaS>ellGc]O?5lkGcaFo5/LE_aK75KlFaaBo5LLD_aG75;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol0000;Ool000Eoo`03001oogoo
009oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo02eoo`05Dae>oE;mD_eC7@0300001U<M
D_eBoE;mDaeBo@=C7@04D_eC7E<MEad3Dad02ELMDaaG7ELLFceG75LMEaaK?@03Fc`01V=LGeaSG6=L
IeaSF`9WF`03Iea[Nf]k009[N`06MiMgV7NHNiIgUW^F0WNH00=gUW^FMiH00W^E0g^D0g^C00=k/g^C
Ni<00g^C00Ak]7^CNkEk]0=k]P9g]`9c^@05LiQ_VVnJKiY[NP03Jg/00f]jGcaO?003Gc`00e/LFcaF
o002Ea`00e/LE_aG7002E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]aBo08000Yoo`00
1Woo100037oo1@0017oo00<007ooOol0:goo00A>o5<MC_eC7@<0003LDae>o5<MC_aC7DklDae>o5<M
D_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMD_aG7ELLFceG75/mFaaK?E/LFceK75/mHe]WO6=KIgaSFfMl
IeY[NfMJJg]_NVnJJgUcVG=hLiUcUgNHMiMkUgNFNkMkUG^eNiAo]G^COiAkTgncNi=oU7^COk=kTgnc
Ni=o]7^DNkEgUG^fMkMg^7>HMkUcV7>JKiUcVV]jJi][NV^KJgYWO6=KGcaO>ellFa]O?5/LGcaFo5/L
E_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo
000:Ool001moo`03001oogoo02Qoo`05C_eBoE;mDae>o@0200001E<MC_eBoE;mDad00e;m00IC7E;m
DaeBoE<MD_d3Dad01E;mDaeC7ELMDa`00eLM00AC75LMFcaK?@=K?003FceK?5/l009O?004He]WFfMK
Ie`4Jg/3KgX02FnJLiUcVG>IMiQgUg^FMiIkU`02NiD2Ni@4Ni<00g^DNi=kT`04Ni<2Nk@027^eNi=k
]7^dNkEk]7^fMkH3MkL046]jJg][Nf]kIe]WNfMKIg]WFe/lFaaK?5/LFcaK75/l0eKl00UG75KlE_aB
o5KlD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg00000002Goo000NOol2000U
Ool01dkmDae>o5<MC_eC7Dkl00<0003RC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LM
D_aC7E;lEaeBo5<MD_aG7E<LEaeC75LmEaaK?E/LFceK75llFcaOGE/lGcaSFfMlIeY[NfMJJg]_NVnJ
JgU_VW=hLiUcN7NHMiMgV7NFNkMgUW^eNiEo]G^DOiAkTgneNiAoU7^COk=kTgncNi=o]7^CNkEkTgnd
Ni=k]G^DNkIg]G^fMiMk^7>HMkUcV6MlIe]WO6=KIgaS>f=LGc]O?5/LGcaK6e/LEaaK75KlEaaFo5LL
D_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0009Ool0
01ioo`03001oogoo029oo`06Dae>oE;mD_eC7Dkm0`0000E>oE;mD_eC7Dkm009Bo@05DaeBoE;mD_eC
7@03D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG7003Ead015LLEaeG7ELM25ll16]k0fmj00=_
VW>ILiT00W>I00EgUgNHMiIkUgNF009kU@9kU09kT`05NiEkU7^DNi=kU003Ni<02g^cNi=kTg^CNkAk
Tg^eNkAk]GNfNkH00WNg00=cV7>iLkT016nJ00=SG6=KHe`00V=L00=SFe/LFa`01E/L1UKl00=Bo5Kl
D_`00U;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00<007ooOol01goo000NOol00`00Oomoo`0POol0
1DklDae>oE<MC_`00`000>=>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDae>o5LMD_aC7E;lEaeBo5LMDaaG?ELLEaeC75LmEaaK?E/lGeeK?5llFcaOGElkHeaO>f=LKgY_
VV]iKiYcN7>ILgQcVGNGMiQcUg^gMiIkUg^ENkIkU7nDNiEk]W^DOiAkTgndNi=o/g^COkAkTgncNi=o
]7^CNkAkU7^eMkEk]WNGNkQg]gNiLiQcVVnJLiY_VF^KJgYSG5lkHeaO>ellGc]K75LLFaaG75/LE_aK
75;lEaaBo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L00Aoo`03001o
ogoo00Moo`007Woo00<007ooOol07Woo0U;m00=C7Dkm00000P0000E>oE;mD_eC7Dkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00IG7E<MDaeC7ELMEa`2
Ead01E/mEaaG7ELLFcd00ell00=SG5mLHe`00V=L00ESFfMKKgY_VVmj00=cV@06MiMgV7NHNiMgUW^F
0W^E0W^D00=gUW^ENiD00g^D0g^C00Ik/g^CNi=kTg^cNi<2Nk@00g^eNkAk]P03MkL3LkT3KiX016]k
JgY[Nf]k1ell00=G75/LE_`00ULL00=K75;lE_`00UKl0e;l00=Fo5;lD_`03U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`7Ool00`00Oomoo`06Ool0
01ioo`03001oogoo01]oo`04Dae>oE<MC_`30000i4klDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeBo5LMEaaK?ELLFceG
75/mEaaK?ElkHeaO>f=LGc]SG6=KIgaSFfMlHe]cVG=hLiUcN7NHLiMgV7NFNiMgUW^fNiEkUgNFNkIk
UGnDNiAo]7^COk=kTgndNi=oU7^COkAkTg^dNi=k]G^DNkIgUG^hMkMg^G>HMkU_VW>JJgY[Vf]jJi][
NVMlIe]O?5lkGcaO>ellFa]O?5KlFaaFo5LLE_aG75;lEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo0Yoo`03001oogoo00Ioo`007Goo0P0067oo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<M
C_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<M
D_d3Dad01E;mDaeC7ELMDad00eLM00EG75LMEaaK?ELL009K?006FceOG6=LHeaWG6=K0VMK00=WG6=K
Jg/00V]k00a[NWNHMiQgV7NFNiIgUWNHMiMkUWNFNiL2NiD2Ni@9Ni<027^dNi=k]G^dNkEk]W^eNk@3
NkH2KiX2Jg/046]jJg]WFfMkIe]WNfMKFcaK75/lFaaK?5/LFcaFo5LL15Kl00ABo5KlD_aFo0=Bo003
E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00U;l3Woo00<007ooOol01Woo000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@80001fC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7E;lDaeBo5LMDaaG7E;lEaeC75LMD_aK?E/LFceK75/mFaaK?E/LIgaSFfMlHe]W
O6=KJg]WFV]kIeY_VV]iKiYcN7>ILgQgV7NGMiQgUW^gNiEk]G^DOkEkTgnDNi=o/g^DOiAkTgncNi=o
/g^COkAkU7^eNi=o]7^DNkEgUG^fMkMg^7>HMkUcV7NiHe]WO6MKIgaSFf=LHc]O?5/KGc`2Fa`01ULL
FaaFo5LLE_aG709Fo01QD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`0
05;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`04goo00<007ooOol01Woo000MOol00`00Oomoo`0C
Ool2D_d00e<MC_eBo@030002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMDa`00eLM
00AG75/lFcaK?@=K?09O?09WF`03Iea[NV]k009[N`04JgY_NVmjKiX4LiT01GNGMiQgUW^GMiH00W^E
0W^D0W^C0W^D1W^C00Ak]7^CNi=kT`9k]004NkEk]W^fMkH2MkL00g>iLiQc^@02KiX01FMKIg]SG6=L
He/00f=L1U/L1UKl00ABo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo006D]aBo5;lD_aB
g5;l5Goo00<007ooOol01Woo000MOol00`00Oomoo`0AOol014kmDae>o5<M0`000>9C7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG7ELLEaeC75LmEaaG7E<LFceK75/mFcaOGE/lGcaK?5mM
IeY[NfMJJg]WFVnJJgU_VVmjLiUcN7>IMiMgV7>GNkMgUW^eNiEo]G^DOiAkTg^fNiAoU7^COkAkTgnc
Ni=o]7^COk=kTgndNi=k]G^DNkIg]GNhMiMg^G>HMkU_VG>JKiYcVUlkHeaS>f=LGc]O?5lkGcaG75/L
EaaK75KlFaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aBo5;LE_aBg1Moo`03001oogoo00Ioo`007Goo0P003goo00ABoE<MC_eBo@<0
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00=G7E<MDad00ULM00EG
75LMEaeG7ELL00MO?005GeaSG6]kJg][NP02KgX00fnJKgYcV@02LiT01WNGMiQgV7^GMiIkUP9kU@9k
U09kU@9kU003Ni=kU7^C00IkT`06Nk=kTg^eNkAk]WNf0WNg00Ac^G>HLkUc^@=_VP03Jg][Vf]j00MO
?004E_aG75LLFa`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`0
77oo00<007ooOol01Woo000MOol00`00Oomoo`09Ool01TklDae>oE<MC_aC7@<0003QDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeBo5LMEaaG7E<LEceG75/mEaaO
GE/lGcaK?6=LGc]SG5lkHeaO>fnJJgU_VVmjLiUcN7>IMiMgV7>GNkMgUW^GNiEk]W^DOiAgUW^fNiEo
U7^DOkAkTgncNi=o]7^COk=kTgndNi=k]7^DNkIg]G^fMiMk^7>HMkUcV7>JKiYcVV]jJi][NVMlHe]O
?5lkGcaO>ellFaaO?5KlFaaFo5/LE_aG75;lE_aBo5LLD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aoo`0001moo`03001oogoo00Eoo`007Goo00<007ooOol01goo0U;m00=C
7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d2
Dad01ELMDaeC7E<MEad00U<M00QG75/mEaaG7ELLFceG75LM0V=L00EOG6=LHeaSG5mL009WF`03IeaS
Fg>I00=cV@=gV003MiIkUWNF009kU@04NiIgUW^ENiD3Ni@3Ni<01W^cNi=kTg^CNk=kT`9k]003NkEg
]W^f009g]`03LiQc^G>i00=_VP0>Jg][Vf]jIg]WFfMkIe]WNe/LFcaK75/lFaaK?0=Fo003EaaFo5Kl
009Fo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoogoo009oo`03001oogoo01ao
o`03001oogoo00Eoo`007Goo00<007ooOol01Goo00A>oE<MC_aC7@<0002?Dae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMD_aG7ELLFceG
75/mEaaK?E/LFceO>f=LGc]SG5lkIgaSFfMlHe][NfMJJg]WFWNHLiMgV7NFNiMgUWNHMiMkUgNFNkMk
UG^eNiAo]G^COiAkTgncNi=o/g^COkAkTg^dNi=k]G^CNkAkU7^eNiAk]WNENkQg]gNhJgY[Vf]jIgaS
FfMlIe]WO5lkHeaK75llFa]K75LLFaaFo5LLE_aG7002E_`0Ce;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;L00Qoo`03001oogoo01]oo`03001oogoo00Eoo`007Goo00@007ooOom>o@9B
o@04Dae>oE;mD_d20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7003Ead01E<LEaeG75/mEa`00U/l00=K?E/lFc`00V=L
00ESFfMKIe]WG6=K00=[N`04JgY_NVmjKiX3LiT01GNHMiMgV7NFNiL00W^E0W^D17^C00AkU7^CNi=k
/`=kT`06NkEkTg^dNi=k]G^d0g^f0WNg0W>i00EcV6MkIe]WNfMK00=SG003He]SG5/L00AK7003EaaF
o5Kl00AFo004D_aFo5;lE_`>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l37oo00<007ooOol06goo00<007ooOol01Goo000LOol02000OomC7DkmDae>o5<M
C_d30000T4kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMD_aG7E/LFceK75/mFaaK?E/LFceSFfMlHe]WO6=KJg]W
FV]kIeY_VV]iKiYcN7>ILgQcVGNGMiQgUW^gMiIk]G^EOkEkU7nDNi=o]G^DOiAkTgncNi=o/g^COkAk
Tg^dNi=k]G^DNkEgUG^fMkMg^7>HMkUcV7>JKiUc^VnJHeaO>f=LHc]SG5lkGcaG75/LEaaK709G701;
D_aG75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L015oo`03001oogoo01Yoo`03001oogoo00Eoo`00
77oo00<005<MC_d00U;m0`0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>
oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7E<L00=G7@04EaaG7E/l
Fcd3Fc`3Gc`00fMKIeaSF`03Jg/01F]jKgY_NVnJKgX00g>I00EgUgNHMiQkUgNF009kU@9kU09kT`03
NiEkU7^D00EkT`04NkAkTg^CNi<2Nk@00g^eNkIk]P03MkL00g>iLiQ_VP03KiX2Jg/00f=LHe]O?004
Gc`00eLLFaaFo002Ea`5E_`015;lE_aBo5Kl45;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`05goo00<007ooOol06Goo00<007ooOol01Goo000BOol50005Ool00`00C_d000020000V4kmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MD_aC7DklEaeBo5<MD_aG7E;lDaeC75LmEaaG7E<LEceG75llFcaOGE/lGcaK?5mMFca[NfMJJg]W
FVnJJgU_VVmjLiUcN7>IMiMgV7>GNkMgUW^GNiEk]W^DOiAkUG^fNiAoU7^COkAkTgncNi=o/g^COk=k
TgndNiAk]G^DNkIg]gNhMiMg^G>HLiY_VG>jKiY[Vf]jJi][NUllGc]O?5lkGcaK6ellE_aK75KlFa`2
E_`0@U;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo1Yoo`03001oogoo01Qoo`03001oogoo00Eoo`0057oo00<007ooOol01Goo
0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC
7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMEa`00eLM00=G75LM
Ea`01Ull0f=L00EOG6mjKgY_VVmj00=cV@06MiMgV7NHNiMgUW^F0W^E0W^D00=gUW^ENiD00g^D0g^C
00YkU7^CNi=kTg^dNi=k]G^dNkIg]P9g]`03LkUcV6nJ009_VP0@JgY[Nf]kJi][NVMkIe]WNe/LFcaK
75/lFaaK?5KlEa`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00U;l77oo00<007ooOol06Goo00<007ooOol017oo000DOol00`00Oomoo`06Ool0
UP00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E;lEaeBo5/mEaaK?ELLFceG75llFcaO
GElkHeaO>f=LGc]WO6=KIgaSFg>ILgQcVG=hMiQcUgNHMiIkUgNFNkIkUG^GMiIk]W^EOiAkU7ndNi=o
/g^COkAkTgncNi=o]7^CNkEkU7^eMkEk]G^DNkIg]GNhMiMk^6]jJi][NV^KIe]WO6=KIgaS>f=LFa]O
?09K7012EaaK75KlEaaFo5LLE_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5Kl8Goo00<007ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07
Ool200000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MC_eBoE;mDad00e;m00IC7E;mD_eBoE<MD_d3Dad015;mDaeC7ELM0U<M0ULM00UC75LMEaaK?ELL
EaeG76=LGe`00f=L00EOG6MKIe]WG6=K00=[N`0<JgYgV7NHMiQgUW^FMiIgV7NGNiIgUW^G0W^E0W^D
0W^C0W^D0g^C00Ik/g^CNkAk]7^eNi<2Nk@00g^eMkIk]P02MkL02G>HLkUc^G>iIe]WNfMKHeaSF`03
He`6Fa`00eKlEaaFo003E_`015;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg00VOol00`00Oomoo`0G
Ool00`00Oomoo`04Ool001Aoo`03001oogoo00Uoo`2A001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC
75LMD_aG7E<LEaeBo5/mEaaK?E/LFceK76=LGc]SG6=KIgaSFfMlHe][NfMJJg]WFVnJJgU_VW=hLiUc
N7NHMiMgV7NFNkMkUG^eNiAo]G^COiAkTgndNi=o/g^COkAkTg^dNi=o/g^CNkAkU7^eMkEk]WNGNkQc
V7NiLiQg^FnJLiY_VF=LHc]SG5lkHe`00Ull03iG75/LEaaK75LLFaaBo5LLD_aG75;lEaaBg5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl:7oo00<007ooOol05goo00<007ooOol017oo
000DOol00`00Oomoo`0:Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<L00=G
7@04DaaK?5/lFcd3Fc`01U/mHe]WFfMKIeaSF`=[N`04JgY_NVmjKiX4LiT01GNGMiQgUW^GMiH00W^E
0W^D0W^C00=kU7^CNi<00g^C00Qk]7^CNk=kTg^dNi=k]G^d0W^f0WNg0g>i0fnJ00A[Vf]jHeaSG0EO
?006E_aG75LLFaaFo5LL1UKl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;LD_`/Ool00`00Oomoo`0FOol00`00Oomoo`04
Ool0019oo`<000eoo`2<001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeC75LMD_aG7ELLEaeG75/mFaaK
?E/LGeeK?5llHe]WO6=KJg]WFV]kIeY_VV]iKiY_NW>ILgQcVGNGMiQcUg^gMiIk]G^EOkEkU7nDNi=k
]W^DOiAkTgncNi=o/g^COk=kTgncNi=k]G^DNkIgUG^hMkMg^G>HMkU_VW>JKiU[Vf]jJi][NP=O?00i
Gc]O?5/LGcaFo5/LE_aK75KlFaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L035oo`03
001oogoo01Eoo`03001oogoo00Aoo`0057oo00<007ooOol037oo0P0000IoodkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<M
D_d3Dad01E;mDaeG7ELMEa`00eLM00=G75LMGc`01Ull0f]k00E[NVmjKgY_VVmj00=cV@06MiMgV7NH
NiMgUW^F0W^E0W^D0W^E00=kU7^CNi<027^C0W^d0g^f00Ag]g>iLkUc^@=_VP0>Ji][NV]kJg]WNfMK
Ig]K75/lFaaK?5/LFcaK709Fo003EaaFo5Kl009Fo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`fOol00`00Oomoo`0DOol0
0`00Oomoo`04Ool002Eoo`2B001oodklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaG7ELLEceG75LMEaaK?E/l
GcaK?5mMFcaSG5lkHeaO>fnJJgU_VVmjLiUcN7>IMiMgV7>GNkMgUW^GNiEk]W^DOiAkUG^fNiEoU7^C
Ok=kTgncNi=o/g^COk=kTgndNiAk]GNENkIkU7^eMiEk]WNgMkQgUf^KJgY[Vf=KIgaWFfMlGc]SG5/L
GcaK6ellEaaK709G700YE_aG75KlEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg00jOol00`00Oomoo`0EOol00`00Oomo
o`03Ool002Ioo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@0=DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mEad00e<M00=G7E<MDad00ULM00IG75LMEaaK?ELL
Ead2Gc`01EmLHeaSG6=LGe`00VMK00=WG6=KLiT00g>I0gNH00=gUW^FMiH00W^E00MkUWNFNiEkUG^D
Ni=kU003Ni<02g^DNi=kTg^CNkAkTg^eNi=k]7^CNkD00W^f00Ug]WNgMkMc^G>HLkUWFfMkIe/00f=L
00=SFf=LHe`01E/L1UKl00ABo5KlD_aFo0iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
?Goo00<007ooOol057oo00<007ooOol00goo000WOol0R`00Oomooe<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMD_aG7ELL
FceG75/mEaaK?ELLFceO>f=LGc]SG5lkIgaSFfMlHe][NfMJJg]WFWNHLiMgV7NFNiMgUWNHMiMkUgNF
NkIkUG^eNiAo]7^COk=kU7ndNi=o/g^COk=kTg^eNi=o]7^CNkEkU7^fMkEg^7NGMkUcV7NiKiUc^VnJ
HeaO>f=LHc]SG5lk009O?00ZFaaG75/LEaaK75;lEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L@7oo00<007ooOol04goo00<0
07ooOol00goo000XOol200001GooD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05
Dae>oE;mD_eC7@03D_d00e<MD_eC7@02Dad01E;mDaeC7E<MDa`00eLM00QC75LMEaaK?ELLEaeG75/m
0U/l0V=L00EOG6MKIe]WG6=K00=[N`04JgY_NVmjKiX3LiT01GNHMiMgV7NFNiL00W^E0W^D00AkTg^D
NiAkU0=kT`06Nk=kTg^dNi=k]7^C0W^d00=k]WNfMkL00WNg00=cV7>iKiX00VnJ0V]k00=[Vf]jGc`0
1Ell00EK75KlEaaG75/L00AFo004D_aFo5;lE_`@D_`01E;LD_aBo5;lD]`00U;lAWoo00<007ooOol0
4Woo00<007ooOol00goo000ZOol0QP00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMDaaG7E;lEaeC75/mFaaK?E/LFceK75/m
FaaWO6=KIgaSFfMlIeY[NfMJKiY[NFnJLgQcVG=hLiUgUgNHMiIk]g^ENkEkUGneNi=k]G^DOkEkTgnD
Ni=o/g^CNkAkTgncNi=k]7^DNkEg]GNhMiMk^7>HMkU_VG>jKiY[Vf]jJi][NVMlHe/3Gc`08U/KGcaK
75/LE_aK75KlFaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlBWoo00<007ooOol04Woo00<007ooOol00goo000[Ool01P00OomBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7E<L00=G7@04
EaaG7ELMFcd3Fc`01e/mGcaO?5llIeaSFfMK009[N`05JgY[NfmjKiY_NP03LiT01GNGMiQgV7^GMiH0
0W^E0W^D00=kUG^DNi@01g^C00Mk/g^CNkAkTg^eMkIk]P02MkL00g>HLkU_VP02KiX2Jg/03F^KJgYW
NfMKIg]WFe/lFaaK?5/LFcaK75LL00=Fo003EaaBo5Kl009Fo0=Bo003E_aBo5;l00IBo005D]aBo5;l
D_aBg01?Ool00`00Oomoo`0AOol00`00Oomoo`03Ool002aoo`2;001ooe<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aC7ELLEceG75LMEaaG
?ELLEaeK?5mMFcaO?5/lGeeK?5llIeY[NfMJJg][NFnJKgYcVG=hLiUgUgNHLiMk]gNFNkEkUG^fNiAk
Ug^EOkEkU7nDNi=o/g^COiAkTgncNi=k]7^CNkEkU7^fNiAk]G^DNkIgUg^hMkM[Vf]jJi][NVMlHe]W
O6MKHeaO>ellFaaO?5LLFa`00ULL01AFo5LLE_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlE7oo00<007ooOol047oo00<007ooOol00goo000]Ool20002D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@04EaaG
7ELLFcd6Gc`2He`01EmLHea_NVnJKgX00g>I00IgUgNHMiQkUgNFNiH2NiD01GNFNiIkUG^ENi@02W^C
0g^d00=kTg^eNk@00W^f0WNg0W>i00Ig^G>HIg]WFfMkHe/3He`00f=KFaaK7004Fa`5E_`015;lE_aB
o5Kl2E;lEgoo00<007ooOol047oo00<007ooOol00Woo000_Ool0PP00Dae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMEaaG?ELLFceG75/m
EaaK?E/lGeeK?6=LGc]SG5lkHeaSFfMlHe]cVG=hLiUcN7NHLiMgV7NFNiMcUgNHMiIkUgNFNkIkU7nD
Ni=o]7^COiAkTgncNi=o/g^COkAkU7ncNi=k]G^DNkEg]G^hMkMg^G>HMkUcV7>JKiUc^V<kHeaO>f=L
0Ull01IO>e/LEaaK75KlFaaFo5LLD_aG75;lEaaBg5KlD_aFo5;LE_aBg5KlD]aFo5Uoo`03001oogoo
011oo`03001oogoo009oo`00<7oo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MD_eBoE;mDaeBo@=C7@04D_eC7E<MEad3Dad02ULMEaaG7ELLFceG75LMEaaK?EmL0f=L00EO
G6=LIe]WG6=K00=[N`04JgYgV7NHMiP2LiT2MiP00gNGNiIgUP02NiD01g^DNi=kU7^CNiAkTg^D00=k
T`04NkAkTg^CNi<2Nk@00g^eNkIk]P02MkL00g>iMkUcV003KiX3Jg/6Gc`3Ea`01EKlEaaG75KlD_`0
0eKl0e;l00=Fo5;lOol0GGoo00<007ooOol03goo00<007ooOol00Woo000aOol0RP00Oomooe<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMEaaK
?ELLFceG75/mFaaK?ElkHeaO>fMlHe]WO6=KJg]WFV]kIeY_VV]iKiYcN7>ILgQgV7NGNiMgUW^gNiEo
U7^DOkAkTgnDNiAo]7^COk=kTgndNi=o/g^COkAkU7^eNiAk]WNgMkQcV7NiLiQcVVnIJi][NV^KJgYW
O6MKGcaO>ellFaaO?5/KFaaFo5/LE_aG709Fo004D_aG75;lE_aSOol00`00Oomoo`0>Ool00`00Oomo
o`02Ool0039oo`05001oogooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeB
oE<MD_d3Dad01E;mDaeC7ELMDa`00eLM00AC75/lFcaK?@=K?006FceK?6MKIe]WG6=K0f]k00A[NVmj
KgY_VP=cV@05MiQgUgNHMiIkU`02NiD2Ni@017^CNiEkU7^D0g^C00ik/g^CNi=kTg^dNi=k]G^dNkIg
]WNgLkUg^G>H0VnJ00i[Vf]kJg]WFfMkIe]WNfMKFcaK75/lFaaK?5/L0UKl00=G75KlE_`00UKl00=B
o7ooOol0Hgoo00<007ooOol03Woo00<007ooOol00Woo000cOol20000PWooDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeBo5LMD_aG7ELLEaeG75/mFaaK?E/LFceK
?5llFcaOGE/lJg]WFV]kIeY[Nf]iKiY_NW>ILgQgV7NGMiQgUW^gMiIk]G^EOkEkUG^eNiAo]G^COk=k
TgncNi=o/g^COk=kTg^eNiAk]GNeNkEkU7^fMkEg^7NgMkUcV7NiHe]WO6MKIgaO>f=LHc]O?5/KGcaG
75/L0ULL00AFo5LLE_aG76Qoo`03001oogoo00eoo`03001oogoo009oo`00=Goo00@007ooDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@03
EaaG7Ell00IO?09SG006Jg][NV]kKgY_VVmj0W>I00IgV7NGMiQgUW^GMiH2NiD01G^DMiIkUG^ENi@0
0g^C00IkU7^CNi=kTg^cNi<2Nk@01W^eNi=k]7^dNkIg]P=g]`03LiQc^FnJ009_VP=SG003He]SG6=L
00IK76eoo`03001oogoo00aoo`03001oogoo009oo`00=Woo07`007ooDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aG7E;lEaeBo5LMEaaG?ELLFceG75/mFcaO?5/lGeeO>f=L
Gc]SG5lkHea[NFnJKgYcVG=hLiUgUgNHLiMk]gNFNiMkUG^fMiIk]G^EOkEkU7nDNi=o]G^COiAkTgnc
Ni=k]7^DNkEkTg^dNiAk]GNeNkIg]g^hLiQg^FnILkY_VV^KJgYSG6<kHeaO>`=O?79oo`03001oogoo
00]oo`03001oogoo009oo`00=goo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@03
DaeBoE<M009C7@04D_eC7E<MEad3Dad02ULMEaaG7ELLFceG75LMEaaSG5ll0f=L00EO?6=LIe]WG6=K
00=cV@06MiMgV7NHNiMgUW^F0WNH00EgUW^FNiEkUG^D00YkT`07Nk=kTg^dNi=k]GNfNkH00WNg00=c
V7>iLkT00VnJ0V]k00=[Vf]kGc`00ellM7oo00<007ooOol037oo00<007ooOol00Goo000hOol20000
Me<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMDaaG7ELLFceG
75/mEaaK?E/LHeaO>f=LGc]WO6=KIgaSFf]kIeY[NfmjKiY[NG>ILgQcVG>GMiQgUg^GNiEk]W^EOiAk
TgndNiAoU7^COk=kTgncNi=o/g^COk=kTg^eNiAk]WNgNkQg]gNiLiQc^VnJJi][NVnKJgYWO6=KIg`0
Mgoo00<007ooOol02goo00<007ooOol00Goo000jOol00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE<M
D_eC7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMDa`00eLM00AG75LMFcaK?@=K?006FceSFfMKIe]WG6=K
0f]k0fmj17>I00AgV7NGNiIgUP9kU@07NiAkTg^DNiEkU7^CNi@01g^C0W^d00Ak]WNgMkMg]`9c^@9_
VP9[N`05Ji]WFfMkIe]WN`1iOol00`00Oomoo`0:Ool00`00Oomoo`01Ool003]oo`1d001oogooDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeK75/mFaaK?E/LFceK
?5llHe]WO6=KJg]WFV]kIeY_VV]iKiYcN7>ILgQgV7NGMiQgUW^fNiEk]G^DNkIkUGnDNi=o]7^COk=k
TgndNi=o/g^COkAkU7^eNi=k]G^DNkIg]G^hMkMg^G>HMkUWFfMlHe]WO7]oo`03001oogoo00Uoo`03
001oogoo005oo`00?7oo00<007ooOol00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad0
1E;mDaeG7ELMEa`00eLM0e/l1Ull0f]k00A[NVmjKgY_VP=cV@05MiQgUgNHMiIkU`02NiD017^DNiMk
UG^E0W^D0g^C00UkU7^CNi=kTg^dNi=k]G^CNkD00W^d0W^f00Ag]g>iLkUg^@A_VWaoo`03001oogoo
00Uoo`03001oogoo005oo`00?Goo0P00059ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;l
EaeBo5LMEaaG7ELLEceG75LMFcaOGE/lGcaK?5mMFcaSG5lkHeaO>fnJJgU_VW=hLiUcN7NHMiMgV7NF
NkMkUG^eNiEk]`9kU@0JNiAo]7^COiAkU7ndNi=o/g^COk=kTgncNi=o]7^DNkEg]G^fMkMg^7>HMkU_
VW>JKiUc^Wioo`03001oogoo00Qoo`03001oogoo005oo`00?goo00H007ooD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeB
oE<MD_eC7E;mDaeBo@AC7@03EaeC7E<M009G7@04EaaG7ELLFcd5Gc`3He`015llIe]WFfML17>I00Eg
UgNHMiQkUgNF009gV005NiMgUW^ENiEkU003Ni<01G^DNi=kTg^CNk<00g^C17^d00Ek]WNgMkMc^GNi
00A_VX1oo`03001oogoo00Moo`03001oogoo005oo`00@7oo050007ooDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
C_aC7E;lDaeBo5LMD_aG7E;lEaeG75/mEaaK?ELLFceG76=LGc]SG5lkHeaO>fMlHe]WO6MJJg]WFV]k
MiMgV7>GLiUcN7NHLiMgV7NF0W^E01Uo]G^DOiAkTgneNi=oU7^COk=kTgncNi=o/g^CNkEkU7^fMkEg
^7>HMkU_VW>JKiUc^P22Ool00`00Oomoo`07Ool10001Ool1Ool0045oo`06001oogooD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mD_eB
oE<MD_d3Dad01E;mDaeC7E<MDa`00eLM00UC75LMEaaK?ELLEaeK?5/mFc`00f=L00ESFfMKIe]WG6]j
00=[N`=_NP=cV@9gV005MiIkUW^ENiEkU002Ni<00g^ENiAkT`05Ni<01W^cNi=k]7^dNkEg]P9k]003
NkIg]gNg009g]h=oo`03001oogoo00Moo`40005oo`5oo`00@Woo0P00069oodkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
DaeBo5LMD_aC7E;lEaeC75LMD_aG7E<LFceK75/mFaaK?E/LFceSFfMlHe]WO6MJJg]WFV]kKgY_VV]i
LiUcN7>ILiMgV7NGNiMkUG^fNiAoU7^ENkIkU7nDNi=o/g^COiAkTgncNi=k]7^DNkEkTg^dNiAk]WNe
0WNg00=k^7ooOol0Pgoo00<007ooOol01Woo0@000Goo0Goo0014Ool01@00OomBoE<MC_d00U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeB
o@=C7@05D_eC7E<MDaeC7003Ead015LLEaeG7E/m0e/l1Ell00E[NV]kJg][Nf]j00=_NP9cV@9gV003
MiMkUWNF009kU@05NiAkUG^ENiEkU007Ni<2Nk@01W^eNi=k]7^dNkEg]P=g]hMoo`03001oogoo00Eo
o`40005oo`5oo`00AGoo05l007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MEaaG?ELLEaeG75LmEaaG
7E/lGeeK?5llFcaOGElkHeaWFV]kIeY_VV]iKiYcN7>ILiMgV7NGNiMgUW^fNiEkUgNFNkIkUGnDNi=o
]7^COiAkTgncNi=o/g^COk=kTg^dNi=k]GNe009g]`03NkQg]goo08Ioo`03001oogoo00Eoo`40005o
o`5oo`00AWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MC_eBoE;mDad00e;m00UC7E;mDaeBoE<MD_eC7E;mEad00e<M00=G7ELLEad00ULM00AG75LMEaaK
?@=O?003HeaO?6=L009SG004Gca_NVmjKgX3LiT027NHMiMgV7NFNiMgUgNHMiH3NiD2Ni@00g^CNiAk
T`08Ni<00g^eNkAk]P03MkN9Ool00`00Oomoo`04Ool10001Ool1Ool004Moo`800018OomC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeB
o5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/mEaaK?ElkHeaO>f=LGc]SG5lkIgaSFfMlLgQcVG=hMiQg
UgNHLgQcVGNGMiQgUW^g0W^E01=kU7neNi=oU7^DOkAkTgncNi=o/g^COk=kTgndNiAk]WNgNkQg]`2;
Ool00`00Oomoo`03Ool10001Ool1Ool004Uoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@03DaeBoE<M009C7@04D_eC7E<MEad2Dad2Ead0
1E<LEaeG75/mEa`00U/l00=K?EllHe`00V=L00ESFfMKIe]WG6]j009[N`=_NP=cV@9gV007NiMkUG^E
NiEkU7^CNiD00W^D0g^C00AkU7^CNi=kT`=k]003Ni=k]G^d08eoo`03001oogoo00=oo`40005oo`00
BWoo04H007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E;lEaeK75/mFaaK?E/LFceK76MlHe]WO6=KIgaW
FV]kIeY_VVmjKiYcN7>ILgQgV7>GNkMgUP9kU@0COkEkU7^ENiAo]G^COk=kTgndNi=o/g^COk=kTg^e
Ni=k]G^DNkD0SGoo00<007ooOol00goo0@000Goo001;Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMDa`0
0eLM00AG75LMFcaK?@9K?0=O?09WF`03Iea[NV]k009[N`=_NP9cV@=gV005MiIkUG^ENiEkU002NiD0
1G^DNi=kTg^CNi@00g^C00Ak/g^CNkAkT`=k]8moo`03001oogoo009oo`40005oo`00C7oo0P0005IC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG
7E;lDaeBo5LMD_aC7ELLEceG75LMEaaG?ELLGcaK?5mMFcaO?5/lGeeWFV]kIeY[NfmjKiY[NG>ILgQg
V7>GMiQgUW^GNiEk]WNFNiMkUGneNiAoU7^COkEkTgnDNi=o/g^CNkAkTgndNiAk]G^DT7oo00D007oo
Oomoo`00005oo`00CWoo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMEa`00eLM00=G75LMEa`015ll00=SG5ll
He`00V=L0fmj0g>I0WNH00IgUg^FMiQgV7NGNiH2NiD017^DNi=kTg^D0g^C00Ik/g^CNkAkTg^cNi<2
NkBBOol01000Oomoo`000Goo001?Ool0E000Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E;lEaeG75/mEaaK?ELLFceG75/mGc]S
G5lkHeaO>f=LHe]WO6=KLiUcN7>ILiMgV7NGLiUcUgNHMiMkUgNFNkIkUGnDNi=k]W^DOiAkTgncNi=o
/g^COk=kTg^eNiAk]I9oo`04001oogoo0001Ool0051oo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eBoE;mDaeBo@=C7@05D_eC7E<MEaeC7@03Ead01ELLEaeG
75/mEa`00U/l00IK?EllHeaSG6MLHe/2Ie/00f]kJgY[N`03KgX2LiT017NHMiMgV7NF0W^E00AkU7^C
NiEkU0QkT`9k]003NkEoogoo099oo`03001oo`00005oo`00DGoo0P0003i>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMD_aG7E<LEaeBo5/m
FaaK?E/LFceK75/mHe]WO6=KIgaSFf]kIeY[Nf]iKiY_NW>ILgQgV7NGMiQgUW^g0W^E00mkU7^fNiEo
U7^COkAkTgnDNi=o/g^CNkAkU7^eNi<0UGoo0@000Goo0@00001COol01P00C_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeC7003Ead01ELL
FcaK?5/mFc`00ell00ESFfMKIe][Nf]j009[N`=_NP9cV@04MiMgV7NHNiL2NiD00g^DNiMkU@03Ni@0
17^CNiAkTg^D0g^C00=k/g^COol0UWoo0P00001DOol0?000OomC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG7ELLEceG75LMEaaG?E/lGcaK?5mM
FcaO?5/lJg]WFV]kIeY_VVmjKiYcN7>IMiMgV7>GNkMgUP9kU@0?NkMkUG^ENiAo]7^COk=kTgndNi=o
/g^COk=kTgnc09Moo`800000EGoo00H007ooD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;m
D_eBoE<MD_eC7E;mDaeBo@IC7@07EaeG75LMEaeK?ELLEad015ll0V=L00=O?6=LHe`00fmj0g>I0gNH
00EgUWNHMiQkUgNF009kU@03NiAkTg^C009kU0IkTiQoo`800000EWoo03`007ooOom>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7E;lEaeG75/mEaaK?ELL
FceG76=LGc]SG5lkHeaO>fMlHe]WO7=hLiUcN7NHLiMgV7=hMiQcUgNHMiH2NiD037neNi=oU7^EOkEk
TgncNi=o]7^COk=kTiAoo`@0009oo`00Egoo0P0000Aooe;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7E;mD_eBoE<MD_d6Dad00eLMDaeG7@02Ead015LLEaeG75/m0e/l00MSG5llHeaWFfMLHe]WF`02
Jg/016]jKgY_NVmj0W>I0WNH00EgUW^FNiEkUG^D009kU@05NiAkTg^CNi=k/`03Ni<00g^cOomoo`2>
Ool40006Ool005Uoo`16001oodkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeB
o5<MD_aG7E<LEaeBo5LMDaaG7E/LFceK75/mFaaK?E/LIgaSFfMlHe][NfMJJg]WFVnJJgU_VW=hLiUc
UgNHMiIkUg^ENkIkU7^GNiEk]W^DOiAkTgncNi=o/g^COk>=Ool4000:Ool005Yoo`05001ooe;mDae>
o@02D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMDa`00eLM0e/l00=K
?EllGc`00ell0f]k00A[NV]kKgY_NP=cV@04MiQgUW^FMiH2NiD017^FNiEkUG^D0g^C00EkU7^CNi=k
/g^C08Uoo`@000ioo`00Fgoo04<007ooC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
D_aG7E;lDaeBo5LMEaaG7ELLEceG75LMEaaOGE/lGcaK?5mMFcaSG5lkJg]WFV]kJgU_VW=hLiUcN7NH
MiMkUgNFNkIkUG^GMiIk]W^EOiAkTgneNiAoU7^COk=kT`26Ool4000BOol005aoo`800003OomC7Dkm
009Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@9C7@03EaeC7E<M009G7@05EaaG7ELLFceG
7004Gc`3He`015llHea_NVmj17>I00MgUg^FMiIkUgNGMiQgUP02NiD2Ni@00g^ENiAkU004Ni>3Ool3
000FOol005ioo`0e001ooe<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;l
EaeBo5/mEaaK?ELLFceG75/mGc]SG5lkHeaO>f=LHe]WO6MJJg]WFV]kKgYcVG=hLiUgUgNHMiIk]`02
NiD02G^DOkAkU7nDNi=o/g^COk=kT`1oOol4000IOol005moo`04001ooe<MC_d2D_d01E<MC_eBoE;m
Dad00U;m0U<M00=BoE<MDad015<M00UG7E<LEaeG7E/mEaaG7ELLFcd00U/l0V=L00EO?6MKIe]WG6]j
00=[N`9_NP=cV@9gV003NiMkUG^E009kU007NiEkU7^DNiAkTg^DNi<0O7oo10007Goo001POol0<P00
OomC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LMDaaK?E/LFceK75/m
FaaK?F=KIgaSFfMlIeY[NfMJJg]_NVnJLgQcVG=hMiQcUg^gMiH2NiD02GneMiIoU7^DOkEkTgnDNi=o
]01hOol4000QOol0065oo`80000>OomBoE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05DaaG7ELM
EaeG7002Ead015/mFcaK?5/l1Ell00A[NV]kJg][N`9_NP=cV@9gV007NiMgUW^ENiEkUgNFNiD00W^D
0g^C00=kU7ooOol0Lgoo10009Goo001SOol0>@00Oom>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LM
D_aC7E;lEceG75LMEaaG?ELLEaeK?5mMFcaO?5/lGeeO>f=LGc]SG6mjKiY[NG>ILgQcVG>GMiQgUW^G
LiMk]gNFNiMkUGneNiAoU7^DOkAkT`1bOol3000YOol006Aoo`03001ooe;m009Bo@08DaeBoE;mD_eC
7E;mDaeBo@AC7@03EaeC7ELM009G7@04EaaG7ELLFcd3Gc`00f=LGcaSG002He`00f=KIe]WF`03LiT2
MiP01g=iLiUgV7NHMiIkUW^E009kU005Ni=kUG^DNi=kU01^Ool4000/Ool006Eoo`0f001oodklDae>
o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7ELLFceG75/mEaaK?ELLHeaO>f=LGc]WO6=KIgaS
Ff]kIeY[Nf]iKiYcN7>IKgQgV7NFNiMgUW^fNiAoU7^EOkEkTgnDJgoo1000<7oo001VOol20003D_d0
0e<MD_eBo@02Dad01E;mDaeC7E<MD_d00eLM00QC75LMEaaK?ELLEaeK?5/m0U/l00=WFfMLHe/00VMK
00=[Nf]jJg/00Vmj00QcNG>ILiUgV7NGNiIgUW^E0W^D0W^E0W^D00=kTgooOol0IGoo1000=7oo001X
Ool0<P00OomC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LMFaaK?E/LFceK75/mFcaOGF=K
IgaSFf]kIeY[Nf]iKiY_NW>IKgQcVGNGNiMgUW^gNiEkUgNFNkIkU7nDNi=TOol4000hOol006Uoo`06
001ooe<MD_eC7E;m0e<M00EBoE<MDaeC7E;m00=G7@05EaaG7E/lFceK?006Gc`00f]kJgY[N`03KgX3
LiT01gNGMiQgUW^GNiEgV7NF009kU@03NiAkTg^D061oo`@003aoo`00JWoo02l007ooDaeBo5<MC_aC
7E;lDaeBo5LMD_aG7E;lEceG75LMEaaG?ELLGcaK?5mMFcaO?5lkHeaO>f=LJgU_VVmjLiU_N7>ILgQg
V7NFNkMgUWNHMiIk]g^EOiAkTgnd05ioo`<0041oo`00Jgoo0P0000MC7E;mDaeBoE<MD_eG7@03Dad0
2ULMDaeC7ELLFceG75LMEaaK?ELL0f=L00EO?6=LIe]WG6=K00=[N`05JgY_NW>ILiUcN@02MiP017^G
NiEkUG^D0W^EFWoo1000@goo001]Ool0:`00OomBo5<MD_aC7E;lEaeBo5LMD_aG7E;lEaeG75/mEaaK
?E/LFceK76=LGc]WO6=KIgaSFf]kIeY[NfMJKiY[NG>ILgQgV7>GNkMgUW^FNiAk]g^E05Moo`@004Mo
o`00KWoo00D007ooDaeC7E;m00=C7@08DaaG7ELMEaeC75LMFcaK?@=K?006FceK?6MKIe]WG6=K0f]k
00I[NVmjKgYcVG=iLiT2MiP017NFNiEkUG^G0W^EDgoo1000Bgoo001_Ool0:000Oomooe<MD_aG7E;l
DaeBo5LMDaaG7ELLEceK75/mFaaK?E/lGcaK?5mMFca[NfMJJg]_NVnJJgUcVG=hLiUcUgNHMiIkUg^E
MiQgUW^FD7oo1000Cgoo001`Ool200000gooDaeBo@03Dad01ELLEaeG7ELMEa`00ULM1Ull0f=L16mj
00IcNG>IMiQgV7NGNiH2MiP00gNFNiEkU@1=Ool3001COol0079oo`0T001ooeLMD_aG7E;lEaeG75Lm
EaaG7ELLFceG75llFcaOGElkHeaO>f=LHe]WG6=KIgacN7>ILiMgV7NGLiUcUgNHMiMkUg^EBWoo1000
EWoo001cOol00`00OomG7@03Dad02ULMDaeG7ELLFceG75LMEaaK?Ell0V=L00MWG6=KIe]WFfMLJgY[
N`03KgX2LiT00gNHMiMkUP02NiE6Ool4001JOol007Aoo`0Q001oogooD_aG7E<LEaeBo5/mEaaK?ELL
FceK75/mFaaWO6=KIeaSFfMlIeY[Nf]iKiY_NW>IKgQgV7NGMiQgUW^f04=oo`@005ioo`00MGoo0P00
00=ooe<LEad00ULM00AC75/lFcaK?@9K?0=O?09WF`03Iea[NV]k00A_NP07LiUgV7NGMiQgUW^EMiL0
?goo1000HWoo001gOol07@00OomG75LmEaaG7ELLEceG75llFcaOGE/lGcaK?5mMIeY[Nf]iKiY_NVnJ
KgQcVGNGMiQcUg^gMiL0?7oo1000IWoo001hOol00`00OomG7003Ead00eLLEaeG7004Gc`01f=LGcaS
G6MKIeaSFfMK009cV@06MiMgV7NHLiUgUgNH>Goo0`00JWoo001iOol06P00Oomooe/mEaaK?ELLFceG
75/mGc]SG5lkHeaSFfMlHe]WG6MJJg]_NVnJJgUcVG=hMiPfOol4001]Ool007Yoo`07001oogooEaeG
75/mEa`00U/l00MK?EllHeaWFfMLHe]WF`02Jg/3KgX017>ILgUgV7NH<Woo1000LGoo001kOol20000
5GooFceK75/mFaaK?E/LFceSFfMlHe]WG6MJJg]WFVnJJgUcVG=hMiQcU`0_Ool4001eOol007eoo`06
001ooe/lFcaK?E/l1Ell0V]k00I[NVmjKgYcVG=iLiT2MiP[Ool4001iOol007ioo`0C001oogooFcaO
?5/lGeeK?6=LGc]SG5lkKiY[NG>ILgQcVG>GMiP0:7oo1000OGoo001oOol01P00OomoogooHeaO?0=S
G006GcaWFfMKJg][NV]k0Vmj9Woo0`00PGoo0020Ool20002Ool02f=LGc]SG6=KIeaSFf]kIeY[Nf]i
KiX08goo1000Q7oo0022Ool01@00OomoogooHe/00VMK00A[Nf]jJg][N`9_NQmoo`@008Qoo`00Pgoo
00<007ooOol00Woo00I[NfMJJg]WFVnJKgXLOol4002<Ool008Aoo`03001oogoo00Aoo`9_NP03001o
ogoo01Ioo`@0091oo`00QGoo0P001Woo00<007ooOol04goo0`00U7oo0027Ool00`00Oomoo`03Ool0
0`00Oomoo`0?Ool4002GOol008Qoo`03001oogoo009oo`03001oogoo00]oo`@009]oo`00RGoo00D0
07ooOomoo`0000Uoo`@009moo`00RWoo0P0000=oo`00Ool017oo1000Xgoo002<Ool200000goo0000
0002002WOol008eoo`800:]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol0
0?mooc]oo`00ogoo>goo003oOolkOol00001\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02905 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.818 .86 .879 r
.39007 .78984 .39849 .79336 .41266 .77968 .40424 .77851 Mtetra
.889 .892 .826 r
.40424 .77851 .41266 .77968 .42699 .75954 .41858 .76177 Mtetra
.945 .911 .753 r
.41858 .76177 .42699 .75954 .44146 .73151 .43308 .73762 Mtetra
.974 .915 .679 r
.43308 .73762 .44146 .73151 .45593 .69693 .44766 .70576 Mtetra
.98 .914 .63 r
.44766 .70576 .45593 .69693 .47027 .66079 .46217 .66945 Mtetra
.976 .922 .629 r
.46217 .66945 .47027 .66079 .48436 .6291 .47648 .63475 Mtetra
.966 .936 .685 r
.47648 .63475 .48436 .6291 .49825 .60501 .49055 .6066 Mtetra
.933 .937 .777 r
.49055 .6066 .49825 .60501 .51201 .58815 .50445 .58622 Mtetra
.868 .903 .854 r
.50445 .58622 .51201 .58815 .52575 .57656 .51827 .57219 Mtetra
.796 .851 .892 r
.51827 .57219 .52575 .57656 .5395 .56826 .53209 .56239 Mtetra
.741 .807 .905 r
.53209 .56239 .5395 .56826 .55331 .56184 .54595 .55511 Mtetra
.706 .778 .908 r
.54595 .55511 .55331 .56184 .56718 .55646 .55987 .54924 Mtetra
.686 .761 .909 r
.55987 .54924 .56718 .55646 .58112 .55164 .57385 .54413 Mtetra
.676 .752 .908 r
.57385 .54413 .58112 .55164 .59513 .54709 .58791 .53942 Mtetra
.67 .747 .908 r
.58791 .53942 .59513 .54709 .60921 .54269 .60204 .5349 Mtetra
.667 .744 .908 r
.60204 .5349 .60921 .54269 .62337 .53834 .61624 .53049 Mtetra
.665 .743 .908 r
.61624 .53049 .62337 .53834 .6376 .53403 .63052 .52611 Mtetra
.664 .742 .908 r
.63052 .52611 .6376 .53403 .6519 .52971 .64487 .52174 Mtetra
.64487 .52174 .6519 .52971 .66627 .52538 .6593 .51737 Mtetra
.6593 .51737 .66627 .52538 .68072 .52104 .6738 .51298 Mtetra
.664 .741 .908 r
.6738 .51298 .68072 .52104 .69524 .51668 .68837 .50858 Mtetra
.68837 .50858 .69524 .51668 .70984 .5123 .70302 .50416 Mtetra
.70302 .50416 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.784 .842 .896 r
.38159 .78544 .39007 .78984 .40424 .77851 .39576 .77596 Mtetra
.854 .877 .856 r
.39576 .77596 .40424 .77851 .41858 .76177 .41009 .76212 Mtetra
.92 .904 .791 r
.41009 .76212 .41858 .76177 .43308 .73762 .42461 .74177 Mtetra
.963 .914 .714 r
.42461 .74177 .43308 .73762 .44766 .70576 .43926 .71347 Mtetra
.979 .914 .65 r
.43926 .71347 .44766 .70576 .46217 .66945 .45393 .67859 Mtetra
.979 .917 .622 r
.45393 .67859 .46217 .66945 .47648 .63475 .46844 .64214 Mtetra
.972 .929 .65 r
.46844 .64214 .47648 .63475 .49055 .6066 .48271 .61017 Mtetra
.954 .94 .73 r
.48271 .61017 .49055 .6066 .50445 .58622 .49677 .58586 Mtetra
.904 .924 .82 r
.49677 .58586 .50445 .58622 .51827 .57219 .5107 .56883 Mtetra
.831 .877 .877 r
.5107 .56883 .51827 .57219 .53209 .56239 .5246 .5571 Mtetra
.766 .827 .9 r
.5246 .5571 .53209 .56239 .54595 .55511 .53851 .54867 Mtetra
.721 .791 .907 r
.53851 .54867 .54595 .55511 .55987 .54924 .55248 .54214 Mtetra
.695 .769 .908 r
.55248 .54214 .55987 .54924 .57385 .54413 .56652 .53666 Mtetra
.68 .756 .909 r
.56652 .53666 .57385 .54413 .58791 .53942 .58062 .53173 Mtetra
.672 .749 .908 r
.58062 .53173 .58791 .53942 .60204 .5349 .5948 .52708 Mtetra
.668 .745 .908 r
.5948 .52708 .60204 .5349 .61624 .53049 .60905 .52257 Mtetra
.666 .743 .908 r
.60905 .52257 .61624 .53049 .63052 .52611 .62338 .51812 Mtetra
.665 .742 .908 r
.62338 .51812 .63052 .52611 .64487 .52174 .63778 .5137 Mtetra
.664 .742 .908 r
.63778 .5137 .64487 .52174 .6593 .51737 .65225 .50928 Mtetra
.65225 .50928 .6593 .51737 .6738 .51298 .6668 .50485 Mtetra
.664 .741 .908 r
.6668 .50485 .6738 .51298 .68837 .50858 .68143 .5004 Mtetra
.68143 .5004 .68837 .50858 .70302 .50416 .69613 .49593 Mtetra
.69613 .49593 .70302 .50416 .71774 .49971 .71091 .49145 Mtetra
.71091 .49145 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.755 .826 .907 r
.37303 .78036 .38159 .78544 .39576 .77596 .38722 .7723 Mtetra
.818 .86 .879 r
.38722 .7723 .39576 .77596 .41009 .76212 .40155 .76082 Mtetra
.889 .892 .826 r
.40155 .76082 .41009 .76212 .42461 .74177 .41607 .74389 Mtetra
.945 .911 .753 r
.41607 .74389 .42461 .74177 .43926 .71347 .43076 .71951 Mtetra
.974 .915 .679 r
.43076 .71951 .43926 .71347 .45393 .67859 .44553 .68736 Mtetra
.98 .914 .63 r
.44553 .68736 .45393 .67859 .46844 .64214 .46024 .65074 Mtetra
.976 .922 .629 r
.46024 .65074 .46844 .64214 .48271 .61017 .47473 .61574 Mtetra
.966 .936 .686 r
.47473 .61574 .48271 .61017 .49677 .58586 .48897 .58733 Mtetra
.933 .937 .778 r
.48897 .58733 .49677 .58586 .5107 .56883 .50304 .56676 Mtetra
.868 .903 .854 r
.50304 .56676 .5107 .56883 .5246 .5571 .51702 .55257 Mtetra
.796 .851 .892 r
.51702 .55257 .5246 .5571 .53851 .54867 .53101 .54263 Mtetra
.741 .807 .905 r
.53101 .54263 .53851 .54867 .55248 .54214 .54503 .53524 Mtetra
.706 .778 .908 r
.54503 .53524 .55248 .54214 .56652 .53666 .55911 .52925 Mtetra
.686 .761 .909 r
.55911 .52925 .56652 .53666 .58062 .53173 .57327 .52404 Mtetra
.676 .752 .908 r
.57327 .52404 .58062 .53173 .5948 .52708 .58749 .51922 Mtetra
.67 .747 .908 r
.58749 .51922 .5948 .52708 .60905 .52257 .60179 .5146 Mtetra
.667 .744 .908 r
.60179 .5146 .60905 .52257 .62338 .51812 .61617 .51008 Mtetra
.665 .743 .908 r
.61617 .51008 .62338 .51812 .63778 .5137 .63062 .50559 Mtetra
.664 .742 .908 r
.63062 .50559 .63778 .5137 .65225 .50928 .64514 .50112 Mtetra
.64514 .50112 .65225 .50928 .6668 .50485 .65974 .49664 Mtetra
.65974 .49664 .6668 .50485 .68143 .5004 .67442 .49215 Mtetra
.664 .741 .908 r
.67442 .49215 .68143 .5004 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49145 .70401 .4831 Mtetra
.70401 .4831 .71091 .49145 .72577 .48693 .71892 .47855 Mtetra
.71892 .47855 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.73 .812 .916 r
.36441 .77473 .37303 .78036 .38722 .7723 .37861 .76775 Mtetra
.784 .842 .896 r
.37861 .76775 .38722 .7723 .40155 .76082 .39295 .75814 Mtetra
.854 .877 .856 r
.39295 .75814 .40155 .76082 .41607 .74389 .40747 .74413 Mtetra
.92 .904 .791 r
.40747 .74413 .41607 .74389 .43076 .71951 .42217 .72356 Mtetra
.963 .915 .714 r
.42217 .72356 .43076 .71951 .44553 .68736 .43701 .695 Mtetra
.979 .914 .649 r
.43701 .695 .44553 .68736 .46024 .65074 .45187 .6598 Mtetra
.979 .917 .622 r
.45187 .6598 .46024 .65074 .47473 .61574 .46657 .62304 Mtetra
.972 .929 .651 r
.46657 .62304 .47473 .61574 .48897 .58733 .48103 .5908 Mtetra
.954 .94 .73 r
.48103 .5908 .48897 .58733 .50304 .56676 .49526 .56626 Mtetra
.904 .924 .82 r
.49526 .56626 .50304 .56676 .51702 .55257 .50936 .54905 Mtetra
.831 .877 .877 r
.50936 .54905 .51702 .55257 .53101 .54263 .52342 .53717 Mtetra
.766 .827 .9 r
.52342 .53717 .53101 .54263 .54503 .53524 .5375 .52861 Mtetra
.721 .791 .907 r
.5375 .52861 .54503 .53524 .55911 .52925 .55164 .52197 Mtetra
.695 .769 .908 r
.55164 .52197 .55911 .52925 .57327 .52404 .56584 .51637 Mtetra
.68 .756 .908 r
.56584 .51637 .57327 .52404 .58749 .51922 .58012 .51133 Mtetra
.672 .749 .908 r
.58012 .51133 .58749 .51922 .60179 .5146 .59446 .50658 Mtetra
.668 .745 .908 r
.59446 .50658 .60179 .5146 .61617 .51008 .60889 .50196 Mtetra
.666 .743 .908 r
.60889 .50196 .61617 .51008 .63062 .50559 .62339 .49741 Mtetra
.665 .742 .908 r
.62339 .49741 .63062 .50559 .64514 .50112 .63796 .49288 Mtetra
.664 .742 .908 r
.63796 .49288 .64514 .50112 .65974 .49664 .65262 .48835 Mtetra
.65262 .48835 .65974 .49664 .67442 .49215 .66735 .48381 Mtetra
.664 .741 .908 r
.66735 .48381 .67442 .49215 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47468 Mtetra
.69704 .47468 .70401 .4831 .71892 .47855 .712 .47008 Mtetra
.712 .47008 .71892 .47855 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.709 .8 .921 r
.35572 .76868 .36441 .77473 .37861 .76775 .36994 .76251 Mtetra
.755 .826 .908 r
.36994 .76251 .37861 .76775 .39295 .75814 .38429 .75433 Mtetra
.818 .86 .879 r
.38429 .75433 .39295 .75814 .40747 .74413 .3988 .7427 Mtetra
.889 .893 .826 r
.3988 .7427 .40747 .74413 .42217 .72356 .4135 .72558 Mtetra
.945 .912 .753 r
.4135 .72558 .42217 .72356 .43701 .695 .42838 .70095 Mtetra
.974 .915 .678 r
.42838 .70095 .43701 .695 .45187 .6598 .44335 .6685 Mtetra
.98 .915 .63 r
.44335 .6685 .45187 .6598 .46657 .62304 .45825 .63156 Mtetra
.976 .922 .629 r
.45825 .63156 .46657 .62304 .48103 .5908 .47293 .59626 Mtetra
.966 .936 .686 r
.47293 .59626 .48103 .5908 .49526 .56626 .48735 .5676 Mtetra
.933 .936 .778 r
.48735 .5676 .49526 .56626 .50936 .54905 .50159 .54682 Mtetra
.868 .902 .854 r
.50159 .54682 .50936 .54905 .52342 .53717 .51575 .53247 Mtetra
.796 .851 .892 r
.51575 .53247 .52342 .53717 .5375 .52861 .5299 .5224 Mtetra
.741 .807 .905 r
.5299 .5224 .5375 .52861 .55164 .52197 .54409 .51488 Mtetra
.706 .778 .908 r
.54409 .51488 .55164 .52197 .56584 .51637 .55835 .50878 Mtetra
.686 .761 .909 r
.55835 .50878 .56584 .51637 .58012 .51133 .57267 .50345 Mtetra
.676 .752 .908 r
.57267 .50345 .58012 .51133 .59446 .50658 .58707 .49852 Mtetra
.67 .747 .908 r
.58707 .49852 .59446 .50658 .60889 .50196 .60154 .4938 Mtetra
.667 .744 .908 r
.60154 .4938 .60889 .50196 .62339 .49741 .61609 .48916 Mtetra
.665 .743 .908 r
.61609 .48916 .62339 .49741 .63796 .49288 .63072 .48457 Mtetra
.664 .742 .908 r
.63072 .48457 .63796 .49288 .65262 .48835 .64542 .47999 Mtetra
.64542 .47999 .65262 .48835 .66735 .48381 .6602 .4754 Mtetra
.6602 .4754 .66735 .48381 .68215 .47925 .67506 .47079 Mtetra
.664 .741 .908 r
.67506 .47079 .68215 .47925 .69704 .47468 .69 .46617 Mtetra
.69 .46617 .69704 .47468 .712 .47008 .70502 .46152 Mtetra
.70502 .46152 .712 .47008 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.694 .791 .925 r
.34695 .76231 .35572 .76868 .36994 .76251 .36119 .75672 Mtetra
.73 .812 .916 r
.36119 .75672 .36994 .76251 .38429 .75433 .37556 .74962 Mtetra
.784 .843 .896 r
.37556 .74962 .38429 .75433 .3988 .7427 .39008 .73987 Mtetra
.854 .878 .856 r
.39008 .73987 .3988 .7427 .4135 .72558 .40478 .72568 Mtetra
.92 .904 .791 r
.40478 .72568 .4135 .72558 .42838 .70095 .41966 .7049 Mtetra
.963 .915 .714 r
.41966 .7049 .42838 .70095 .44335 .6685 .4347 .67606 Mtetra
.979 .914 .649 r
.4347 .67606 .44335 .6685 .45825 .63156 .44976 .64055 Mtetra
.979 .917 .623 r
.44976 .64055 .45825 .63156 .47293 .59626 .46466 .60347 Mtetra
.972 .929 .651 r
.46466 .60347 .47293 .59626 .48735 .5676 .4793 .57095 Mtetra
.954 .94 .731 r
.4793 .57095 .48735 .5676 .50159 .54682 .49371 .54618 Mtetra
.904 .923 .82 r
.49371 .54618 .50159 .54682 .51575 .53247 .50798 .52879 Mtetra
.831 .877 .877 r
.50798 .52879 .51575 .53247 .5299 .5224 .52222 .51675 Mtetra
.766 .827 .9 r
.52222 .51675 .5299 .5224 .54409 .51488 .53647 .50807 Mtetra
.721 .791 .907 r
.53647 .50807 .54409 .51488 .55835 .50878 .55078 .5013 Mtetra
.695 .769 .908 r
.55078 .5013 .55835 .50878 .57267 .50345 .56515 .4956 Mtetra
.68 .756 .908 r
.56515 .4956 .57267 .50345 .58707 .49852 .5796 .49044 Mtetra
.672 .749 .908 r
.5796 .49044 .58707 .49852 .60154 .4938 .59412 .48558 Mtetra
.668 .745 .908 r
.59412 .48558 .60154 .4938 .61609 .48916 .60872 .48085 Mtetra
.666 .743 .908 r
.60872 .48085 .61609 .48916 .63072 .48457 .6234 .47619 Mtetra
.665 .742 .908 r
.6234 .47619 .63072 .48457 .64542 .47999 .63815 .47155 Mtetra
.664 .742 .908 r
.63815 .47155 .64542 .47999 .6602 .4754 .65299 .4669 Mtetra
.65299 .4669 .6602 .4754 .67506 .47079 .6679 .46225 Mtetra
.664 .741 .908 r
.6679 .46225 .67506 .47079 .69 .46617 .6829 .45758 Mtetra
.6829 .45758 .69 .46617 .70502 .46152 .69797 .45289 Mtetra
.69797 .45289 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Mtetra
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.681 .784 .928 r
.3381 .75567 .34695 .76231 .36119 .75672 .35237 .7505 Mtetra
.709 .8 .921 r
.35237 .7505 .36119 .75672 .37556 .74962 .36676 .74421 Mtetra
.755 .826 .908 r
.36676 .74421 .37556 .74962 .39008 .73987 .38129 .7359 Mtetra
.818 .86 .879 r
.38129 .7359 .39008 .73987 .40478 .72568 .39598 .72411 Mtetra
.889 .893 .826 r
.39598 .72411 .40478 .72568 .41966 .7049 .41087 .7068 Mtetra
.946 .912 .753 r
.41087 .7068 .41966 .7049 .4347 .67606 .42595 .68192 Mtetra
.974 .915 .678 r
.42595 .68192 .4347 .67606 .44976 .64055 .44111 .64917 Mtetra
.98 .915 .63 r
.44111 .64917 .44976 .64055 .46466 .60347 .45621 .61191 Mtetra
.976 .921 .629 r
.45621 .61191 .46466 .60347 .4793 .57095 .47109 .5763 Mtetra
.966 .936 .686 r
.47109 .5763 .4793 .57095 .49371 .54618 .4857 .54738 Mtetra
.933 .936 .778 r
.4857 .54738 .49371 .54618 .50798 .52879 .50011 .5264 Mtetra
.868 .902 .854 r
.50011 .5264 .50798 .52879 .52222 .51675 .51444 .51188 Mtetra
.796 .85 .892 r
.51444 .51188 .52222 .51675 .53647 .50807 .52877 .50167 Mtetra
.741 .807 .905 r
.52877 .50167 .53647 .50807 .55078 .5013 .54313 .49402 Mtetra
.706 .778 .908 r
.54313 .49402 .55078 .5013 .56515 .4956 .55756 .4878 Mtetra
.686 .761 .908 r
.55756 .4878 .56515 .4956 .5796 .49044 .57205 .48236 Mtetra
.676 .752 .908 r
.57205 .48236 .5796 .49044 .59412 .48558 .58663 .47732 Mtetra
.67 .747 .908 r
.58663 .47732 .59412 .48558 .60872 .48085 .60128 .47248 Mtetra
.667 .744 .908 r
.60128 .47248 .60872 .48085 .6234 .47619 .61601 .46773 Mtetra
.665 .743 .908 r
.61601 .46773 .6234 .47619 .63815 .47155 .63082 .46303 Mtetra
.664 .742 .908 r
.63082 .46303 .63815 .47155 .65299 .4669 .64571 .45833 Mtetra
.64571 .45833 .65299 .4669 .6679 .46225 .66067 .45363 Mtetra
.66067 .45363 .6679 .46225 .6829 .45758 .67572 .44891 Mtetra
.664 .741 .908 r
.67572 .44891 .6829 .45758 .69797 .45289 .69085 .44416 Mtetra
.69085 .44416 .69797 .45289 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42905 .76773 .42009 Mtetra
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.672 .778 .929 r
.32916 .74882 .3381 .75567 .35237 .7505 .34347 .74395 Mtetra
.693 .791 .925 r
.34347 .74395 .35237 .7505 .36676 .74421 .35789 .73825 Mtetra
.73 .812 .916 r
.35789 .73825 .36676 .74421 .38129 .7359 .37243 .73103 Mtetra
.784 .843 .896 r
.37243 .73103 .38129 .7359 .39598 .72411 .38713 .72113 Mtetra
.854 .878 .856 r
.38713 .72113 .39598 .72411 .41087 .7068 .40202 .70677 Mtetra
.92 .905 .791 r
.40202 .70677 .41087 .7068 .42595 .68192 .4171 .68576 Mtetra
.963 .915 .714 r
.4171 .68576 .42595 .68192 .44111 .64917 .43234 .65665 Mtetra
.979 .915 .649 r
.43234 .65665 .44111 .64917 .45621 .61191 .4476 .62082 Mtetra
.979 .917 .623 r
.4476 .62082 .45621 .61191 .47109 .5763 .4627 .58342 Mtetra
.972 .929 .651 r
.4627 .58342 .47109 .5763 .4857 .54738 .47753 .5506 Mtetra
.954 .94 .731 r
.47753 .5506 .4857 .54738 .50011 .5264 .49212 .5256 Mtetra
.904 .923 .82 r
.49212 .5256 .50011 .5264 .51444 .51188 .50658 .50803 Mtetra
.831 .876 .877 r
.50658 .50803 .51444 .51188 .52877 .50167 .52098 .49584 Mtetra
.766 .827 .9 r
.52098 .49584 .52877 .50167 .54313 .49402 .53541 .48702 Mtetra
.721 .791 .907 r
.53541 .48702 .54313 .49402 .55756 .4878 .54989 .48013 Mtetra
.695 .768 .908 r
.54989 .48013 .55756 .4878 .57205 .48236 .56444 .4743 Mtetra
.68 .756 .908 r
.56444 .4743 .57205 .48236 .58663 .47732 .57906 .46903 Mtetra
.672 .749 .908 r
.57906 .46903 .58663 .47732 .60128 .47248 .59377 .46405 Mtetra
.668 .745 .908 r
.59377 .46405 .60128 .47248 .61601 .46773 .60855 .45921 Mtetra
.666 .743 .908 r
.60855 .45921 .61601 .46773 .63082 .46303 .62341 .45443 Mtetra
.665 .742 .908 r
.62341 .45443 .63082 .46303 .64571 .45833 .63835 .44968 Mtetra
.664 .742 .908 r
.63835 .44968 .64571 .45833 .66067 .45363 .65337 .44492 Mtetra
.65337 .44492 .66067 .45363 .67572 .44891 .66847 .44015 Mtetra
.664 .741 .908 r
.66847 .44015 .67572 .44891 .69085 .44416 .68366 .43536 Mtetra
.68366 .43536 .69085 .44416 .70606 .4394 .69892 .43054 Mtetra
.69892 .43054 .70606 .4394 .72135 .43461 .71427 .42571 Mtetra
.71427 .42571 .72135 .43461 .73673 .4298 .72971 .42085 Mtetra
.72971 .42085 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.665 .774 .931 r
.32014 .74179 .32916 .74882 .34347 .74395 .33449 .73713 Mtetra
.681 .784 .928 r
.33449 .73713 .34347 .74395 .35789 .73825 .34894 .73185 Mtetra
.709 .8 .921 r
.34894 .73185 .35789 .73825 .37243 .73103 .3635 .72544 Mtetra
.755 .826 .908 r
.3635 .72544 .37243 .73103 .38713 .72113 .37821 .717 Mtetra
.818 .86 .879 r
.37821 .717 .38713 .72113 .40202 .70677 .39309 .70505 Mtetra
.889 .893 .826 r
.39309 .70505 .40202 .70677 .4171 .68576 .40818 .68754 Mtetra
.946 .912 .753 r
.40818 .68754 .4171 .68576 .43234 .65665 .42345 .66241 Mtetra
.974 .915 .678 r
.42345 .66241 .43234 .65665 .4476 .62082 .43882 .62936 Mtetra
.98 .915 .63 r
.43882 .62936 .4476 .62082 .4627 .58342 .45413 .59176 Mtetra
.976 .921 .63 r
.45413 .59176 .4627 .58342 .47753 .5506 .4692 .55585 Mtetra
.966 .936 .686 r
.4692 .55585 .47753 .5506 .49212 .5256 .484 .52666 Mtetra
.933 .936 .778 r
.484 .52666 .49212 .5256 .50658 .50803 .4986 .50547 Mtetra
.868 .902 .854 r
.4986 .50547 .50658 .50803 .52098 .49584 .51311 .49078 Mtetra
.796 .85 .891 r
.51311 .49078 .52098 .49584 .53541 .48702 .52761 .48042 Mtetra
.741 .807 .904 r
.52761 .48042 .53541 .48702 .54989 .48013 .54215 .47264 Mtetra
.706 .778 .908 r
.54215 .47264 .54989 .48013 .56444 .4743 .55675 .46631 Mtetra
.686 .761 .908 r
.55675 .46631 .56444 .4743 .57906 .46903 .57143 .46074 Mtetra
.676 .752 .908 r
.57143 .46074 .57906 .46903 .59377 .46405 .58618 .45558 Mtetra
.67 .747 .908 r
.58618 .45558 .59377 .46405 .60855 .45921 .60101 .45063 Mtetra
.667 .744 .908 r
.60101 .45063 .60855 .45921 .62341 .45443 .61593 .44577 Mtetra
.665 .743 .908 r
.61593 .44577 .62341 .45443 .63835 .44968 .63092 .44094 Mtetra
.664 .742 .908 r
.63092 .44094 .63835 .44968 .65337 .44492 .646 .43613 Mtetra
.646 .43613 .65337 .44492 .66847 .44015 .66116 .4313 Mtetra
.66116 .4313 .66847 .44015 .68366 .43536 .6764 .42646 Mtetra
.664 .741 .908 r
.6764 .42646 .68366 .43536 .69892 .43054 .69172 .4216 Mtetra
.69172 .4216 .69892 .43054 .71427 .42571 .70712 .41671 Mtetra
.70712 .41671 .71427 .42571 .72971 .42085 .72262 .4118 Mtetra
.72262 .4118 .72971 .42085 .74522 .41596 .73819 .40686 Mtetra
.73819 .40686 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.66 .771 .932 r
.31104 .73462 .32014 .74179 .33449 .73713 .32542 .7301 Mtetra
.672 .778 .929 r
.32542 .7301 .33449 .73713 .34894 .73185 .33991 .72512 Mtetra
.693 .791 .925 r
.33991 .72512 .34894 .73185 .3635 .72544 .3545 .7193 Mtetra
.73 .812 .916 r
.3545 .7193 .3635 .72544 .37821 .717 .36922 .71196 Mtetra
.784 .843 .896 r
.36922 .71196 .37821 .717 .39309 .70505 .38411 .70191 Mtetra
.854 .878 .856 r
.38411 .70191 .39309 .70505 .40818 .68754 .39918 .68738 Mtetra
.921 .905 .791 r
.39918 .68738 .40818 .68754 .42345 .66241 .41447 .66614 Mtetra
.964 .915 .714 r
.41447 .66614 .42345 .66241 .43882 .62936 .42991 .63674 Mtetra
.979 .915 .649 r
.42991 .63674 .43882 .62936 .45413 .59176 .44538 .60059 Mtetra
.979 .917 .623 r
.44538 .60059 .45413 .59176 .4692 .55585 .46069 .56286 Mtetra
.972 .929 .651 r
.46069 .56286 .4692 .55585 .484 .52666 .47572 .52975 Mtetra
.954 .94 .731 r
.47572 .52975 .484 .52666 .4986 .50547 .4905 .50451 Mtetra
.904 .923 .82 r
.4905 .50451 .4986 .50547 .51311 .49078 .50513 .48675 Mtetra
.831 .876 .877 r
.50513 .48675 .51311 .49078 .52761 .48042 .51972 .4744 Mtetra
.766 .827 .9 r
.51972 .4744 .52761 .48042 .54215 .47264 .53432 .46544 Mtetra
.721 .791 .907 r
.53432 .46544 .54215 .47264 .55675 .46631 .54898 .45843 Mtetra
.695 .768 .908 r
.54898 .45843 .55675 .46631 .57143 .46074 .56371 .45248 Mtetra
.68 .756 .908 r
.56371 .45248 .57143 .46074 .58618 .45558 .57852 .44709 Mtetra
.672 .749 .908 r
.57852 .44709 .58618 .45558 .60101 .45063 .5934 .44199 Mtetra
.668 .745 .908 r
.5934 .44199 .60101 .45063 .61593 .44577 .60837 .43703 Mtetra
.666 .743 .908 r
.60837 .43703 .61593 .44577 .63092 .44094 .62342 .43213 Mtetra
.665 .742 .908 r
.62342 .43213 .63092 .44094 .646 .43613 .63855 .42725 Mtetra
.664 .742 .908 r
.63855 .42725 .646 .43613 .66116 .4313 .65376 .42237 Mtetra
.65376 .42237 .66116 .4313 .6764 .42646 .66906 .41748 Mtetra
.664 .741 .908 r
.66906 .41748 .6764 .42646 .69172 .4216 .68444 .41257 Mtetra
.68444 .41257 .69172 .4216 .70712 .41671 .6999 .40763 Mtetra
.6999 .40763 .70712 .41671 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40686 .73109 .39768 Mtetra
.73109 .39768 .73819 .40686 .75385 .4019 .74681 .39266 Mtetra
.74681 .39266 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.656 .769 .932 r
.30184 .72731 .31104 .73462 .32542 .7301 .31627 .72289 Mtetra
.665 .774 .931 r
.31627 .72289 .32542 .7301 .33991 .72512 .33079 .71812 Mtetra
.681 .784 .928 r
.33079 .71812 .33991 .72512 .3545 .7193 .34541 .71273 Mtetra
.709 .8 .921 r
.34541 .71273 .3545 .7193 .36922 .71196 .36016 .7062 Mtetra
.755 .826 .908 r
.36016 .7062 .36922 .71196 .38411 .70191 .37505 .69761 Mtetra
.818 .861 .879 r
.37505 .69761 .38411 .70191 .39918 .68738 .39013 .6855 Mtetra
.889 .893 .827 r
.39013 .6855 .39918 .68738 .41447 .66614 .40541 .66778 Mtetra
.946 .912 .752 r
.40541 .66778 .41447 .66614 .42991 .63674 .42089 .6424 Mtetra
.974 .915 .678 r
.42089 .6424 .42991 .63674 .44538 .60059 .43647 .60904 Mtetra
.98 .915 .63 r
.43647 .60904 .44538 .60059 .46069 .56286 .45199 .57111 Mtetra
.976 .921 .63 r
.45199 .57111 .46069 .56286 .47572 .52975 .46726 .53488 Mtetra
.966 .936 .687 r
.46726 .53488 .47572 .52975 .4905 .50451 .48226 .50542 Mtetra
.933 .936 .778 r
.48226 .50542 .4905 .50451 .50513 .48675 .49705 .48402 Mtetra
.868 .902 .854 r
.49705 .48402 .50513 .48675 .51972 .4744 .51174 .46915 Mtetra
.796 .85 .891 r
.51174 .46915 .51972 .4744 .53432 .46544 .52642 .45865 Mtetra
.741 .807 .904 r
.52642 .45865 .53432 .46544 .54898 .45843 .54114 .45073 Mtetra
.706 .778 .908 r
.54114 .45073 .54898 .45843 .56371 .45248 .55592 .44427 Mtetra
.686 .761 .908 r
.55592 .44427 .56371 .45248 .57852 .44709 .57078 .43858 Mtetra
.676 .752 .908 r
.57078 .43858 .57852 .44709 .5934 .44199 .58572 .4333 Mtetra
.67 .747 .908 r
.58572 .4333 .5934 .44199 .60837 .43703 .60074 .42822 Mtetra
.667 .744 .908 r
.60074 .42822 .60837 .43703 .62342 .43213 .61584 .42324 Mtetra
.665 .743 .908 r
.61584 .42324 .62342 .43213 .63855 .42725 .63103 .41829 Mtetra
.664 .742 .908 r
.63103 .41829 .63855 .42725 .65376 .42237 .6463 .41336 Mtetra
.6463 .41336 .65376 .42237 .66906 .41748 .66165 .40841 Mtetra
.66165 .40841 .66906 .41748 .68444 .41257 .67709 .40344 Mtetra
.664 .741 .908 r
.67709 .40344 .68444 .41257 .6999 .40763 .69261 .39845 Mtetra
.69261 .39845 .6999 .40763 .71545 .40267 .70822 .39344 Mtetra
.70822 .39344 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39266 .73969 .38333 Mtetra
.73969 .38333 .74681 .39266 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.653 .767 .933 r
.29256 .71989 .30184 .72731 .31627 .72289 .30703 .71552 Mtetra
.66 .771 .932 r
.30703 .71552 .31627 .72289 .33079 .71812 .32159 .7109 Mtetra
.672 .778 .929 r
.32159 .7109 .33079 .71812 .34541 .71273 .33625 .70581 Mtetra
.693 .791 .925 r
.33625 .70581 .34541 .71273 .36016 .7062 .35102 .69987 Mtetra
.73 .812 .916 r
.35102 .69987 .36016 .7062 .37505 .69761 .36593 .69239 Mtetra
.784 .843 .896 r
.36593 .69239 .37505 .69761 .39013 .6855 .38101 .6822 Mtetra
.854 .878 .856 r
.38101 .6822 .39013 .6855 .40541 .66778 .39628 .66747 Mtetra
.921 .905 .791 r
.39628 .66747 .40541 .66778 .42089 .6424 .41177 .646 Mtetra
.964 .915 .713 r
.41177 .646 .42089 .6424 .43647 .60904 .42742 .61632 Mtetra
.979 .915 .649 r
.42742 .61632 .43647 .60904 .45199 .57111 .44311 .57984 Mtetra
.979 .917 .623 r
.44311 .57984 .45199 .57111 .46726 .53488 .45862 .54178 Mtetra
.972 .929 .652 r
.45862 .54178 .46726 .53488 .48226 .50542 .47386 .50838 Mtetra
.954 .939 .731 r
.47386 .50838 .48226 .50542 .49705 .48402 .48883 .48289 Mtetra
.904 .923 .82 r
.48883 .48289 .49705 .48402 .51174 .46915 .50365 .46493 Mtetra
.831 .876 .877 r
.50365 .46493 .51174 .46915 .52642 .45865 .51842 .45242 Mtetra
.766 .827 .9 r
.51842 .45242 .52642 .45865 .54114 .45073 .53321 .44332 Mtetra
.721 .791 .907 r
.53321 .44332 .54114 .45073 .55592 .44427 .54805 .43617 Mtetra
.695 .768 .908 r
.54805 .43617 .55592 .44427 .57078 .43858 .56297 .4301 Mtetra
.68 .756 .908 r
.56297 .4301 .57078 .43858 .58572 .4333 .57796 .42458 Mtetra
.672 .749 .908 r
.57796 .42458 .58572 .4333 .60074 .42822 .59303 .41936 Mtetra
.668 .745 .908 r
.59303 .41936 .60074 .42822 .61584 .42324 .60819 .41428 Mtetra
.666 .743 .908 r
.60819 .41428 .61584 .42324 .63103 .41829 .62343 .40925 Mtetra
.665 .742 .908 r
.62343 .40925 .63103 .41829 .6463 .41336 .63876 .40425 Mtetra
.664 .742 .908 r
.63876 .40425 .6463 .41336 .66165 .40841 .65417 .39925 Mtetra
.65417 .39925 .66165 .40841 .67709 .40344 .66966 .39423 Mtetra
.664 .741 .908 r
.66966 .39423 .67709 .40344 .69261 .39845 .68524 .38918 Mtetra
.68524 .38918 .69261 .39845 .70822 .39344 .70091 .38412 Mtetra
.70091 .38412 .70822 .39344 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38333 .7325 .37391 Mtetra
.7325 .37391 .73969 .38333 .75556 .37824 .74844 .36876 Mtetra
.74844 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.651 .766 .933 r
.28318 .71236 .29256 .71989 .30703 .71552 .29769 .70802 Mtetra
.656 .769 .932 r
.29769 .70802 .30703 .71552 .32159 .7109 .3123 .70349 Mtetra
.665 .774 .931 r
.3123 .70349 .32159 .7109 .33625 .70581 .32699 .69861 Mtetra
.681 .784 .928 r
.32699 .69861 .33625 .70581 .35102 .69987 .3418 .6931 Mtetra
.709 .8 .921 r
.3418 .6931 .35102 .69987 .36593 .69239 .35673 .68644 Mtetra
.755 .827 .908 r
.35673 .68644 .36593 .69239 .38101 .6822 .37182 .67772 Mtetra
.818 .861 .879 r
.37182 .67772 .38101 .6822 .39628 .66747 .38708 .66544 Mtetra
.889 .894 .827 r
.38708 .66544 .39628 .66747 .41177 .646 .40257 .64751 Mtetra
.946 .912 .752 r
.40257 .64751 .41177 .646 .42742 .61632 .41826 .62186 Mtetra
.974 .916 .678 r
.41826 .62186 .42742 .61632 .44311 .57984 .43406 .58819 Mtetra
.98 .915 .63 r
.43406 .58819 .44311 .57984 .45862 .54178 .44979 .54992 Mtetra
.976 .921 .63 r
.44979 .54992 .45862 .54178 .47386 .50838 .46528 .51337 Mtetra
.966 .936 .687 r
.46528 .51337 .47386 .50838 .48883 .48289 .48047 .48365 Mtetra
.933 .936 .778 r
.48047 .48365 .48883 .48289 .50365 .46493 .49545 .46202 Mtetra
.868 .901 .854 r
.49545 .46202 .50365 .46493 .51842 .45242 .51033 .44698 Mtetra
.796 .85 .891 r
.51033 .44698 .51842 .45242 .53321 .44332 .5252 .43632 Mtetra
.741 .807 .904 r
.5252 .43632 .53321 .44332 .54805 .43617 .5401 .42826 Mtetra
.706 .778 .908 r
.5401 .42826 .54805 .43617 .56297 .4301 .55507 .42167 Mtetra
.686 .761 .908 r
.55507 .42167 .56297 .4301 .57796 .42458 .57012 .41585 Mtetra
.676 .752 .908 r
.57012 .41585 .57796 .42458 .59303 .41936 .58525 .41045 Mtetra
.67 .747 .908 r
.58525 .41045 .59303 .41936 .60819 .41428 .60046 .40524 Mtetra
.667 .744 .908 r
.60046 .40524 .60819 .41428 .62343 .40925 .61576 .40013 Mtetra
.665 .743 .908 r
.61576 .40013 .62343 .40925 .63876 .40425 .63114 .39506 Mtetra
.664 .742 .908 r
.63114 .39506 .63876 .40425 .65417 .39925 .6466 .38999 Mtetra
.6466 .38999 .65417 .39925 .66966 .39423 .66216 .38492 Mtetra
.66216 .38492 .66966 .39423 .68524 .38918 .6778 .37982 Mtetra
.664 .741 .908 r
.6778 .37982 .68524 .38918 .70091 .38412 .69352 .3747 Mtetra
.69352 .3747 .70091 .38412 .71666 .37903 .70934 .36956 Mtetra
.70934 .36956 .71666 .37903 .7325 .37391 .72524 .36439 Mtetra
.72524 .36439 .7325 .37391 .74844 .36876 .74123 .35919 Mtetra
.74123 .35919 .74844 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.65 .765 .933 r
.27371 .70474 .28318 .71236 .29769 .70802 .28827 .70041 Mtetra
.653 .767 .933 r
.28827 .70041 .29769 .70802 .3123 .70349 .30291 .69593 Mtetra
.66 .771 .932 r
.30291 .69593 .3123 .70349 .32699 .69861 .31765 .69119 Mtetra
.672 .778 .929 r
.31765 .69119 .32699 .69861 .3418 .6931 .33249 .68599 Mtetra
.693 .791 .925 r
.33249 .68599 .3418 .6931 .35673 .68644 .34745 .67993 Mtetra
.73 .812 .916 r
.34745 .67993 .35673 .68644 .37182 .67772 .36255 .67231 Mtetra
.784 .843 .896 r
.36255 .67231 .37182 .67772 .38708 .66544 .37782 .66196 Mtetra
.854 .878 .856 r
.37782 .66196 .38708 .66544 .40257 .64751 .3933 .64705 Mtetra
.921 .905 .791 r
.3933 .64705 .40257 .64751 .41826 .62186 .40899 .62534 Mtetra
.964 .915 .713 r
.40899 .62534 .41826 .62186 .43406 .58819 .42487 .59537 Mtetra
.979 .915 .649 r
.42487 .59537 .43406 .58819 .44979 .54992 .44077 .55855 Mtetra
.979 .917 .623 r
.44077 .55855 .44979 .54992 .46528 .51337 .45651 .52015 Mtetra
.973 .928 .652 r
.45651 .52015 .46528 .51337 .48047 .48365 .47195 .48645 Mtetra
.954 .939 .731 r
.47195 .48645 .48047 .48365 .49545 .46202 .48712 .46072 Mtetra
.904 .922 .82 r
.48712 .46072 .49545 .46202 .51033 .44698 .50213 .44256 Mtetra
.831 .876 .877 r
.50213 .44256 .51033 .44698 .5252 .43632 .51709 .42988 Mtetra
.766 .826 .9 r
.51709 .42988 .5252 .43632 .5401 .42826 .53207 .42063 Mtetra
.721 .79 .907 r
.53207 .42063 .5401 .42826 .55507 .42167 .5471 .41335 Mtetra
.695 .768 .908 r
.5471 .41335 .55507 .42167 .57012 .41585 .5622 .40714 Mtetra
.68 .756 .908 r
.5622 .40714 .57012 .41585 .58525 .41045 .57738 .4015 Mtetra
.672 .749 .908 r
.57738 .4015 .58525 .41045 .60046 .40524 .59265 .39615 Mtetra
.668 .745 .908 r
.59265 .39615 .60046 .40524 .61576 .40013 .608 .39094 Mtetra
.666 .743 .908 r
.608 .39094 .61576 .40013 .63114 .39506 .62344 .38578 Mtetra
.665 .742 .908 r
.62344 .38578 .63114 .39506 .6466 .38999 .63897 .38065 Mtetra
.664 .742 .908 r
.63897 .38065 .6466 .38999 .66216 .38492 .65458 .37552 Mtetra
.65458 .37552 .66216 .38492 .6778 .37982 .67028 .37036 Mtetra
.664 .741 .908 r
.67028 .37036 .6778 .37982 .69352 .3747 .68606 .36519 Mtetra
.68606 .36519 .69352 .3747 .70934 .36956 .70194 .35999 Mtetra
.70194 .35999 .70934 .36956 .72524 .36439 .7179 .35476 Mtetra
.7179 .35476 .72524 .36439 .74123 .35919 .73396 .34951 Mtetra
.73396 .34951 .74123 .35919 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.649 .764 .933 r
.26414 .69702 .27371 .70474 .28827 .70041 .27874 .69268 Mtetra
.651 .766 .933 r
.27874 .69268 .28827 .70041 .30291 .69593 .29343 .68823 Mtetra
.656 .769 .932 r
.29343 .68823 .30291 .69593 .31765 .69119 .30822 .68359 Mtetra
.665 .774 .931 r
.30822 .68359 .31765 .69119 .33249 .68599 .3231 .67859 Mtetra
.681 .784 .928 r
.3231 .67859 .33249 .68599 .34745 .67993 .33809 .67296 Mtetra
.709 .801 .922 r
.33809 .67296 .34745 .67993 .36255 .67231 .35321 .66617 Mtetra
.755 .827 .908 r
.35321 .66617 .36255 .67231 .37782 .66196 .36849 .6573 Mtetra
.818 .861 .879 r
.36849 .6573 .37782 .66196 .3933 .64705 .38396 .64485 Mtetra
.889 .894 .827 r
.38396 .64485 .3933 .64705 .40899 .62534 .39965 .6267 Mtetra
.946 .913 .752 r
.39965 .6267 .40899 .62534 .42487 .59537 .41556 .60078 Mtetra
.974 .916 .677 r
.41556 .60078 .42487 .59537 .44077 .55855 .43158 .56679 Mtetra
.98 .915 .63 r
.43158 .56679 .44077 .55855 .45651 .52015 .44754 .52818 Mtetra
.976 .921 .63 r
.44754 .52818 .45651 .52015 .47195 .48645 .46324 .4913 Mtetra
.966 .936 .687 r
.46324 .4913 .47195 .48645 .48712 .46072 .47864 .46131 Mtetra
.933 .935 .778 r
.47864 .46131 .48712 .46072 .50213 .44256 .49382 .43946 Mtetra
.868 .901 .854 r
.49382 .43946 .50213 .44256 .51709 .42988 .50889 .42423 Mtetra
.796 .85 .891 r
.50889 .42423 .51709 .42988 .53207 .42063 .52395 .41341 Mtetra
.741 .806 .904 r
.52395 .41341 .53207 .42063 .5471 .41335 .53904 .40522 Mtetra
.706 .778 .908 r
.53904 .40522 .5471 .41335 .5622 .40714 .5542 .39848 Mtetra
.686 .761 .908 r
.5542 .39848 .5622 .40714 .57738 .4015 .56944 .39254 Mtetra
.676 .752 .908 r
.56944 .39254 .57738 .4015 .59265 .39615 .58476 .387 Mtetra
.67 .747 .908 r
.58476 .387 .59265 .39615 .608 .39094 .60017 .38166 Mtetra
.667 .744 .908 r
.60017 .38166 .608 .39094 .62344 .38578 .61567 .37642 Mtetra
.665 .743 .908 r
.61567 .37642 .62344 .38578 .63897 .38065 .63125 .37122 Mtetra
.664 .742 .908 r
.63125 .37122 .63897 .38065 .65458 .37552 .64692 .36602 Mtetra
.64692 .36602 .65458 .37552 .67028 .37036 .66268 .36081 Mtetra
.66268 .36081 .67028 .37036 .68606 .36519 .67853 .35558 Mtetra
.664 .741 .908 r
.67853 .35558 .68606 .36519 .70194 .35999 .69446 .35032 Mtetra
.69446 .35032 .70194 .35999 .7179 .35476 .71049 .34504 Mtetra
.71049 .34504 .7179 .35476 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.648 .764 .933 r
.25447 .68921 .26414 .69702 .27874 .69268 .26912 .68486 Mtetra
.65 .765 .933 r
.26912 .68486 .27874 .69268 .29343 .68823 .28386 .68041 Mtetra
.653 .767 .933 r
.28386 .68041 .29343 .68823 .30822 .68359 .29869 .67582 Mtetra
.66 .771 .932 r
.29869 .67582 .30822 .68359 .3231 .67859 .31361 .67097 Mtetra
.672 .778 .929 r
.31361 .67097 .3231 .67859 .33809 .67296 .32864 .66564 Mtetra
.693 .791 .925 r
.32864 .66564 .33809 .67296 .35321 .66617 .34379 .65945 Mtetra
.73 .812 .916 r
.34379 .65945 .35321 .66617 .36849 .6573 .35908 .6517 Mtetra
.785 .843 .896 r
.35908 .6517 .36849 .6573 .38396 .64485 .37455 .64118 Mtetra
.854 .879 .856 r
.37455 .64118 .38396 .64485 .39965 .6267 .39024 .62608 Mtetra
.921 .906 .791 r
.39024 .62608 .39965 .6267 .41556 .60078 .40615 .60413 Mtetra
.964 .916 .713 r
.40615 .60413 .41556 .60078 .43158 .56679 .42225 .57385 Mtetra
.979 .915 .648 r
.42225 .57385 .43158 .56679 .44754 .52818 .43838 .5367 Mtetra
.979 .917 .623 r
.43838 .5367 .44754 .52818 .46324 .4913 .45434 .49796 Mtetra
.973 .928 .652 r
.45434 .49796 .46324 .4913 .47864 .46131 .46999 .46395 Mtetra
.953 .939 .732 r
.46999 .46395 .47864 .46131 .49382 .43946 .48537 .43797 Mtetra
.904 .922 .82 r
.48537 .43797 .49382 .43946 .50889 .42423 .50058 .41961 Mtetra
.831 .876 .877 r
.50058 .41961 .50889 .42423 .52395 .41341 .51573 .40676 Mtetra
.766 .826 .9 r
.51573 .40676 .52395 .41341 .53904 .40522 .5309 .39736 Mtetra
.721 .79 .907 r
.5309 .39736 .53904 .40522 .5542 .39848 .54612 .38993 Mtetra
.695 .768 .908 r
.54612 .38993 .5542 .39848 .56944 .39254 .56141 .38359 Mtetra
.68 .756 .908 r
.56141 .38359 .56944 .39254 .58476 .387 .57679 .37781 Mtetra
.672 .749 .908 r
.57679 .37781 .58476 .387 .60017 .38166 .59226 .37233 Mtetra
.668 .745 .908 r
.59226 .37233 .60017 .38166 .61567 .37642 .60781 .36698 Mtetra
.666 .743 .908 r
.60781 .36698 .61567 .37642 .63125 .37122 .62345 .3617 Mtetra
.665 .742 .908 r
.62345 .3617 .63125 .37122 .64692 .36602 .63918 .35643 Mtetra
.664 .742 .908 r
.63918 .35643 .64692 .36602 .66268 .36081 .655 .35116 Mtetra
.655 .35116 .66268 .36081 .67853 .35558 .67091 .34587 Mtetra
.664 .741 .908 r
.67091 .34587 .67853 .35558 .69446 .35032 .68691 .34056 Mtetra
.68691 .34056 .69446 .35032 .71049 .34504 .703 .33522 Mtetra
.703 .33522 .71049 .34504 .72661 .33973 .71918 .32985 Mtetra
.71918 .32985 .72661 .33973 .74282 .33439 .73545 .32445 Mtetra
.73545 .32445 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.647 .763 .934 r
.2447 .68131 .25447 .68921 .26912 .68486 .2594 .67693 Mtetra
.649 .764 .933 r
.2594 .67693 .26912 .68486 .28386 .68041 .27419 .67248 Mtetra
.651 .766 .933 r
.27419 .67248 .28386 .68041 .29869 .67582 .28906 .66791 Mtetra
.656 .769 .932 r
.28906 .66791 .29869 .67582 .31361 .67097 .30403 .66315 Mtetra
.665 .774 .931 r
.30403 .66315 .31361 .67097 .32864 .66564 .3191 .65803 Mtetra
.681 .784 .928 r
.3191 .65803 .32864 .66564 .34379 .65945 .33428 .65228 Mtetra
.709 .801 .922 r
.33428 .65228 .34379 .65945 .35908 .6517 .3496 .64535 Mtetra
.755 .827 .908 r
.3496 .64535 .35908 .6517 .37455 .64118 .36508 .63633 Mtetra
.818 .861 .879 r
.36508 .63633 .37455 .64118 .39024 .62608 .38075 .6237 Mtetra
.889 .894 .827 r
.38075 .6237 .39024 .62608 .40615 .60413 .39666 .60534 Mtetra
.946 .913 .752 r
.39666 .60534 .40615 .60413 .42225 .57385 .41279 .57914 Mtetra
.974 .916 .677 r
.41279 .57914 .42225 .57385 .43838 .5367 .42904 .54482 Mtetra
.98 .915 .629 r
.42904 .54482 .43838 .5367 .45434 .49796 .44523 .50587 Mtetra
.976 .921 .63 r
.44523 .50587 .45434 .49796 .46999 .46395 .46115 .46866 Mtetra
.966 .935 .687 r
.46115 .46866 .46999 .46395 .48537 .43797 .47677 .43838 Mtetra
.933 .935 .778 r
.47677 .43838 .48537 .43797 .50058 .41961 .49214 .41631 Mtetra
.868 .901 .854 r
.49214 .41631 .50058 .41961 .51573 .40676 .50741 .40089 Mtetra
.796 .85 .891 r
.50741 .40089 .51573 .40676 .5309 .39736 .52266 .38991 Mtetra
.741 .806 .904 r
.52266 .38991 .5309 .39736 .54612 .38993 .53795 .38157 Mtetra
.706 .778 .908 r
.53795 .38157 .54612 .38993 .56141 .38359 .55331 .37469 Mtetra
.686 .761 .908 r
.55331 .37469 .56141 .38359 .57679 .37781 .56874 .36861 Mtetra
.676 .752 .908 r
.56874 .36861 .57679 .37781 .59226 .37233 .58427 .36294 Mtetra
.67 .747 .908 r
.58427 .36294 .59226 .37233 .60781 .36698 .59988 .35746 Mtetra
.667 .744 .908 r
.59988 .35746 .60781 .36698 .62345 .3617 .61558 .35209 Mtetra
.665 .743 .908 r
.61558 .35209 .62345 .3617 .63918 .35643 .63136 .34675 Mtetra
.664 .742 .908 r
.63136 .34675 .63918 .35643 .655 .35116 .64724 .34141 Mtetra
.64724 .34141 .655 .35116 .67091 .34587 .66321 .33606 Mtetra
.66321 .33606 .67091 .34587 .68691 .34056 .67927 .33069 Mtetra
.664 .741 .908 r
.67927 .33069 .68691 .34056 .703 .33522 .69543 .32529 Mtetra
.69543 .32529 .703 .33522 .71918 .32985 .71167 .31987 Mtetra
.71167 .31987 .71918 .32985 .73545 .32445 .72801 .31441 Mtetra
.72801 .31441 .73545 .32445 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.647 .763 .934 r
.23483 .67332 .2447 .68131 .2594 .67693 .24958 .66891 Mtetra
.648 .764 .933 r
.24958 .66891 .2594 .67693 .27419 .67248 .26442 .66444 Mtetra
.65 .765 .933 r
.26442 .66444 .27419 .67248 .28906 .66791 .27934 .65988 Mtetra
.653 .767 .933 r
.27934 .65988 .28906 .66791 .30403 .66315 .29435 .65517 Mtetra
.66 .771 .932 r
.29435 .65517 .30403 .66315 .3191 .65803 .30946 .6502 Mtetra
.672 .778 .93 r
.30946 .6502 .3191 .65803 .33428 .65228 .32468 .64474 Mtetra
.693 .791 .925 r
.32468 .64474 .33428 .65228 .3496 .64535 .34003 .63842 Mtetra
.73 .812 .916 r
.34003 .63842 .3496 .64535 .36508 .63633 .35552 .63052 Mtetra
.785 .843 .896 r
.35552 .63052 .36508 .63633 .38075 .6237 .3712 .61985 Mtetra
.854 .879 .856 r
.3712 .61985 .38075 .6237 .39666 .60534 .38709 .60454 Mtetra
.921 .906 .791 r
.38709 .60454 .39666 .60534 .41279 .57914 .40323 .58234 Mtetra
.964 .916 .713 r
.40323 .58234 .41279 .57914 .42904 .54482 .41956 .55176 Mtetra
.979 .915 .648 r
.41956 .55176 .42904 .54482 .44523 .50587 .43592 .51426 Mtetra
.979 .917 .623 r
.43592 .51426 .44523 .50587 .46115 .46866 .45211 .47518 Mtetra
.973 .928 .652 r
.45211 .47518 .46115 .46866 .47677 .43838 .46799 .44086 Mtetra
.953 .939 .732 r
.46799 .44086 .47677 .43838 .49214 .41631 .48357 .41463 Mtetra
.903 .922 .821 r
.48357 .41463 .49214 .41631 .50741 .40089 .49898 .39606 Mtetra
.831 .876 .877 r
.49898 .39606 .50741 .40089 .52266 .38991 .51433 .38303 Mtetra
.766 .826 .9 r
.51433 .38303 .52266 .38991 .53795 .38157 .52969 .37347 Mtetra
.721 .79 .907 r
.52969 .37347 .53795 .38157 .55331 .37469 .54511 .3659 Mtetra
.695 .768 .908 r
.54511 .3659 .55331 .37469 .56874 .36861 .56061 .35942 Mtetra
.68 .756 .908 r
.56061 .35942 .56874 .36861 .58427 .36294 .57619 .3535 Mtetra
.672 .749 .908 r
.57619 .3535 .58427 .36294 .59988 .35746 .59186 .34788 Mtetra
.668 .745 .908 r
.59186 .34788 .59988 .35746 .61558 .35209 .60762 .34239 Mtetra
.666 .743 .908 r
.60762 .34239 .61558 .35209 .63136 .34675 .62347 .33697 Mtetra
.665 .742 .908 r
.62347 .33697 .63136 .34675 .64724 .34141 .6394 .33156 Mtetra
.664 .742 .908 r
.6394 .33156 .64724 .34141 .66321 .33606 .65544 .32615 Mtetra
.65544 .32615 .66321 .33606 .67927 .33069 .67156 .32072 Mtetra
.664 .741 .908 r
.67156 .32072 .67927 .33069 .69543 .32529 .68778 .31526 Mtetra
.68778 .31526 .69543 .32529 .71167 .31987 .70408 .30978 Mtetra
.70408 .30978 .71167 .31987 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Mtetra
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.647 .763 .934 r
.22486 .66524 .23483 .67332 .24958 .66891 .23966 .6608 Mtetra
.23966 .6608 .24958 .66891 .26442 .66444 .25454 .6563 Mtetra
.649 .764 .933 r
.25454 .6563 .26442 .66444 .27934 .65988 .26951 .65174 Mtetra
.651 .766 .933 r
.26951 .65174 .27934 .65988 .29435 .65517 .28457 .64705 Mtetra
.656 .769 .932 r
.28457 .64705 .29435 .65517 .30946 .6502 .29973 .64216 Mtetra
.665 .774 .931 r
.29973 .64216 .30946 .6502 .32468 .64474 .31499 .63692 Mtetra
.681 .784 .928 r
.31499 .63692 .32468 .64474 .34003 .63842 .33037 .63103 Mtetra
.709 .801 .922 r
.33037 .63103 .34003 .63842 .35552 .63052 .34589 .62397 Mtetra
.755 .827 .908 r
.34589 .62397 .35552 .63052 .3712 .61985 .36157 .61479 Mtetra
.818 .861 .879 r
.36157 .61479 .3712 .61985 .38709 .60454 .37746 .60197 Mtetra
.89 .894 .827 r
.37746 .60197 .38709 .60454 .40323 .58234 .39358 .58339 Mtetra
.946 .913 .752 r
.39358 .58339 .40323 .58234 .41956 .55176 .40994 .55691 Mtetra
.974 .916 .677 r
.40994 .55691 .41956 .55176 .43592 .51426 .42643 .52227 Mtetra
.98 .915 .629 r
.42643 .52227 .43592 .51426 .45211 .47518 .44285 .48295 Mtetra
.976 .921 .63 r
.44285 .48295 .45211 .47518 .46799 .44086 .45901 .44542 Mtetra
.966 .935 .688 r
.45901 .44542 .46799 .44086 .48357 .41463 .47484 .41485 Mtetra
.933 .935 .778 r
.47484 .41485 .48357 .41463 .49898 .39606 .49042 .39255 Mtetra
.868 .901 .854 r
.49042 .39255 .49898 .39606 .51433 .38303 .50589 .37694 Mtetra
.796 .85 .891 r
.50589 .37694 .51433 .38303 .52969 .37347 .52134 .36579 Mtetra
.741 .806 .904 r
.52134 .36579 .52969 .37347 .54511 .3659 .53683 .35729 Mtetra
.706 .778 .908 r
.53683 .35729 .54511 .3659 .56061 .35942 .55239 .35027 Mtetra
.686 .761 .908 r
.55239 .35027 .56061 .35942 .57619 .3535 .56803 .34405 Mtetra
.676 .752 .908 r
.56803 .34405 .57619 .3535 .59186 .34788 .58376 .33823 Mtetra
.67 .747 .908 r
.58376 .33823 .59186 .34788 .60762 .34239 .59957 .33262 Mtetra
.667 .744 .908 r
.59957 .33262 .60762 .34239 .62347 .33697 .61548 .3271 Mtetra
.665 .743 .908 r
.61548 .3271 .62347 .33697 .6394 .33156 .63148 .32162 Mtetra
.664 .742 .908 r
.63148 .32162 .6394 .33156 .65544 .32615 .64758 .31613 Mtetra
.64758 .31613 .65544 .32615 .67156 .32072 .66376 .31064 Mtetra
.66376 .31064 .67156 .32072 .68778 .31526 .68004 .30512 Mtetra
.664 .741 .908 r
.68004 .30512 .68778 .31526 .70408 .30978 .69642 .29958 Mtetra
.69642 .29958 .70408 .30978 .72049 .30426 .71289 .29401 Mtetra
.71289 .29401 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28276 Mtetra
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Mtetra
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .763 .934 r
.21479 .65708 .22486 .66524 .23966 .6608 .22963 .65259 Mtetra
.647 .763 .934 r
.22963 .65259 .23966 .6608 .25454 .6563 .24456 .64807 Mtetra
.648 .764 .933 r
.24456 .64807 .25454 .6563 .26951 .65174 .25958 .64348 Mtetra
.65 .765 .933 r
.25958 .64348 .26951 .65174 .28457 .64705 .27469 .6388 Mtetra
.653 .767 .933 r
.27469 .6388 .28457 .64705 .29973 .64216 .2899 .63396 Mtetra
.66 .771 .932 r
.2899 .63396 .29973 .64216 .31499 .63692 .3052 .62886 Mtetra
.672 .778 .93 r
.3052 .62886 .31499 .63692 .33037 .63103 .32062 .62328 Mtetra
.693 .791 .925 r
.32062 .62328 .33037 .63103 .34589 .62397 .33616 .61682 Mtetra
.73 .813 .916 r
.33616 .61682 .34589 .62397 .36157 .61479 .35186 .60877 Mtetra
.785 .843 .896 r
.35186 .60877 .36157 .61479 .37746 .60197 .36775 .59792 Mtetra
.854 .879 .856 r
.36775 .59792 .37746 .60197 .39358 .58339 .38386 .58241 Mtetra
.921 .906 .791 r
.38386 .58241 .39358 .58339 .40994 .55691 .40023 .55996 Mtetra
.964 .916 .713 r
.40023 .55996 .40994 .55691 .42643 .52227 .41679 .52907 Mtetra
.979 .915 .648 r
.41679 .52907 .42643 .52227 .44285 .48295 .4334 .49122 Mtetra
.979 .917 .623 r
.4334 .49122 .44285 .48295 .45901 .44542 .44982 .45178 Mtetra
.973 .928 .652 r
.44982 .45178 .45901 .44542 .47484 .41485 .46592 .41716 Mtetra
.953 .939 .732 r
.46592 .41716 .47484 .41485 .49042 .39255 .48172 .39067 Mtetra
.903 .922 .821 r
.48172 .39067 .49042 .39255 .50589 .37694 .49734 .37188 Mtetra
.831 .875 .877 r
.49734 .37188 .50589 .37694 .52134 .36579 .51289 .35868 Mtetra
.766 .826 .9 r
.51289 .35868 .52134 .36579 .53683 .35729 .52846 .34896 Mtetra
.721 .79 .907 r
.52846 .34896 .53683 .35729 .55239 .35027 .54408 .34123 Mtetra
.695 .768 .908 r
.54408 .34123 .55239 .35027 .56803 .34405 .55978 .3346 Mtetra
.68 .756 .908 r
.55978 .3346 .56803 .34405 .58376 .33823 .57557 .32854 Mtetra
.672 .749 .908 r
.57557 .32854 .58376 .33823 .59957 .33262 .59145 .32277 Mtetra
.668 .745 .908 r
.59145 .32277 .59957 .33262 .61548 .3271 .60742 .31714 Mtetra
.666 .743 .908 r
.60742 .31714 .61548 .3271 .63148 .32162 .62348 .31157 Mtetra
.665 .742 .908 r
.62348 .31157 .63148 .32162 .64758 .31613 .63963 .30602 Mtetra
.664 .742 .908 r
.63963 .30602 .64758 .31613 .66376 .31064 .65588 .30046 Mtetra
.65588 .30046 .66376 .31064 .68004 .30512 .67223 .29488 Mtetra
.664 .741 .908 r
.67223 .29488 .68004 .30512 .69642 .29958 .68867 .28927 Mtetra
.68867 .28927 .69642 .29958 .71289 .29401 .7052 .28364 Mtetra
.7052 .28364 .71289 .29401 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28276 .73856 .27227 Mtetra
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .763 .934 r
.2046 .64882 .21479 .65708 .22963 .65259 .2195 .6443 Mtetra
.647 .763 .934 r
.2195 .6443 .22963 .65259 .24456 .64807 .23448 .63973 Mtetra
.23448 .63973 .24456 .64807 .25958 .64348 .24955 .63512 Mtetra
.649 .764 .933 r
.24955 .63512 .25958 .64348 .27469 .6388 .26471 .63043 Mtetra
.651 .766 .933 r
.26471 .63043 .27469 .6388 .2899 .63396 .27996 .62562 Mtetra
.656 .769 .932 r
.27996 .62562 .2899 .63396 .3052 .62886 .29531 .6206 Mtetra
.665 .774 .931 r
.29531 .6206 .3052 .62886 .32062 .62328 .31077 .61523 Mtetra
.681 .784 .928 r
.31077 .61523 .32062 .62328 .33616 .61682 .32635 .60921 Mtetra
.709 .801 .922 r
.32635 .60921 .33616 .61682 .35186 .60877 .34207 .60199 Mtetra
.755 .827 .908 r
.34207 .60199 .35186 .60877 .36775 .59792 .35796 .59265 Mtetra
.818 .861 .879 r
.35796 .59265 .36775 .59792 .38386 .58241 .37407 .57965 Mtetra
.89 .895 .827 r
.37407 .57965 .38386 .58241 .40023 .55996 .39042 .56083 Mtetra
.946 .913 .752 r
.39042 .56083 .40023 .55996 .41679 .52907 .40702 .53408 Mtetra
.974 .916 .677 r
.40702 .53408 .41679 .52907 .4334 .49122 .42375 .49909 Mtetra
.98 .915 .629 r
.42375 .49909 .4334 .49122 .44982 .45178 .44042 .45942 Mtetra
.976 .921 .63 r
.44042 .45942 .44982 .45178 .46592 .41716 .45681 .42155 Mtetra
.966 .935 .688 r
.45681 .42155 .46592 .41716 .48172 .39067 .47286 .39069 Mtetra
.933 .935 .779 r
.47286 .39069 .48172 .39067 .49734 .37188 .48866 .36815 Mtetra
.868 .901 .854 r
.48866 .36815 .49734 .37188 .51289 .35868 .50433 .35235 Mtetra
.796 .85 .891 r
.50433 .35235 .51289 .35868 .52846 .34896 .51999 .34102 Mtetra
.741 .806 .904 r
.51999 .34102 .52846 .34896 .54408 .34123 .53568 .33237 Mtetra
.706 .778 .908 r
.53568 .33237 .54408 .34123 .55978 .3346 .55145 .3252 Mtetra
.686 .761 .908 r
.55145 .3252 .55978 .3346 .57557 .32854 .56729 .31882 Mtetra
.676 .752 .908 r
.56729 .31882 .57557 .32854 .59145 .32277 .58323 .31286 Mtetra
.67 .747 .908 r
.58323 .31286 .59145 .32277 .60742 .31714 .59926 .3071 Mtetra
.667 .744 .908 r
.59926 .3071 .60742 .31714 .62348 .31157 .61539 .30143 Mtetra
.665 .743 .908 r
.61539 .30143 .62348 .31157 .63963 .30602 .6316 .2958 Mtetra
.664 .742 .908 r
.6316 .2958 .63963 .30602 .65588 .30046 .64792 .29017 Mtetra
.64792 .29017 .65588 .30046 .67223 .29488 .66433 .28452 Mtetra
.66433 .28452 .67223 .29488 .68867 .28927 .68083 .27885 Mtetra
.664 .741 .908 r
.68083 .27885 .68867 .28927 .7052 .28364 .69743 .27316 Mtetra
.69743 .27316 .7052 .28364 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25588 Mtetra
.74783 .25588 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24419 Mtetra
.78193 .24419 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .763 .934 r
.19431 .64048 .2046 .64882 .2195 .6443 .20926 .63591 Mtetra
.20926 .63591 .2195 .6443 .23448 .63973 .22429 .63131 Mtetra
.647 .763 .934 r
.22429 .63131 .23448 .63973 .24955 .63512 .23941 .62665 Mtetra
.648 .764 .933 r
.23941 .62665 .24955 .63512 .26471 .63043 .25462 .62194 Mtetra
.65 .765 .933 r
.25462 .62194 .26471 .63043 .27996 .62562 .26992 .61713 Mtetra
.653 .767 .933 r
.26992 .61713 .27996 .62562 .29531 .6206 .28532 .61217 Mtetra
.66 .771 .932 r
.28532 .61217 .29531 .6206 .31077 .61523 .30082 .60694 Mtetra
.672 .778 .93 r
.30082 .60694 .31077 .61523 .32635 .60921 .31644 .60122 Mtetra
.693 .791 .925 r
.31644 .60122 .32635 .60921 .34207 .60199 .33219 .59462 Mtetra
.73 .813 .916 r
.33219 .59462 .34207 .60199 .35796 .59265 .3481 .58641 Mtetra
.785 .844 .896 r
.3481 .58641 .35796 .59265 .37407 .57965 .3642 .57539 Mtetra
.854 .879 .856 r
.3642 .57539 .37407 .57965 .39042 .56083 .38054 .55966 Mtetra
.921 .906 .791 r
.38054 .55966 .39042 .56083 .40702 .53408 .39714 .53695 Mtetra
.964 .916 .713 r
.39714 .53695 .40702 .53408 .42375 .49909 .41395 .50575 Mtetra
.979 .915 .648 r
.41395 .50575 .42375 .49909 .44042 .45942 .4308 .46755 Mtetra
.979 .917 .623 r
.4308 .46755 .44042 .45942 .45681 .42155 .44747 .42775 Mtetra
.973 .928 .653 r
.44747 .42775 .45681 .42155 .47286 .39069 .46381 .39281 Mtetra
.953 .939 .732 r
.46381 .39281 .47286 .39069 .48866 .36815 .47983 .36606 Mtetra
.903 .921 .821 r
.47983 .36606 .48866 .36815 .50433 .35235 .49566 .34705 Mtetra
.831 .875 .876 r
.49566 .34705 .50433 .35235 .51999 .34102 .51142 .33366 Mtetra
.766 .826 .899 r
.51142 .33366 .51999 .34102 .53568 .33237 .52719 .32377 Mtetra
.721 .79 .907 r
.52719 .32377 .53568 .33237 .55145 .3252 .54302 .31589 Mtetra
.695 .768 .908 r
.54302 .31589 .55145 .3252 .56729 .31882 .55893 .30911 Mtetra
.68 .756 .908 r
.55893 .30911 .56729 .31882 .58323 .31286 .57493 .3029 Mtetra
.672 .749 .908 r
.57493 .3029 .58323 .31286 .59926 .3071 .59102 .29698 Mtetra
.668 .745 .908 r
.59102 .29698 .59926 .3071 .61539 .30143 .60721 .2912 Mtetra
.666 .743 .908 r
.60721 .2912 .61539 .30143 .6316 .2958 .62349 .28548 Mtetra
.665 .742 .908 r
.62349 .28548 .6316 .2958 .64792 .29017 .63987 .27977 Mtetra
.664 .742 .908 r
.63987 .27977 .64792 .29017 .66433 .28452 .65634 .27406 Mtetra
.65634 .27406 .66433 .28452 .68083 .27885 .67291 .26833 Mtetra
.664 .741 .908 r
.67291 .26833 .68083 .27885 .69743 .27316 .68958 .26256 Mtetra
.68958 .26256 .69743 .27316 .71413 .26743 .70635 .25677 Mtetra
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25588 .74019 .24509 Mtetra
.74019 .24509 .74783 .25588 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24419 .77443 .23327 Mtetra
.77443 .23327 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.646 .763 .934 r
.18391 .63205 .19431 .64048 .20926 .63591 .19891 .62743 Mtetra
.19891 .62743 .20926 .63591 .22429 .63131 .21399 .62278 Mtetra
.647 .763 .934 r
.21399 .62278 .22429 .63131 .23941 .62665 .22916 .61809 Mtetra
.22916 .61809 .23941 .62665 .25462 .62194 .24442 .61335 Mtetra
.649 .764 .933 r
.24442 .61335 .25462 .62194 .26992 .61713 .25977 .60853 Mtetra
.651 .766 .933 r
.25977 .60853 .26992 .61713 .28532 .61217 .27522 .60359 Mtetra
.656 .769 .932 r
.27522 .60359 .28532 .61217 .30082 .60694 .29077 .59844 Mtetra
.665 .774 .931 r
.29077 .59844 .30082 .60694 .31644 .60122 .30643 .59293 Mtetra
.681 .784 .928 r
.30643 .59293 .31644 .60122 .33219 .59462 .32222 .58677 Mtetra
.709 .801 .922 r
.32222 .58677 .33219 .59462 .3481 .58641 .33815 .5794 Mtetra
.755 .827 .908 r
.33815 .5794 .3481 .58641 .3642 .57539 .35426 .5699 Mtetra
.818 .862 .879 r
.35426 .5699 .3642 .57539 .38054 .55966 .37059 .5567 Mtetra
.89 .895 .827 r
.37059 .5567 .38054 .55966 .39714 .53695 .38717 .53764 Mtetra
.946 .913 .752 r
.38717 .53764 .39714 .53695 .41395 .50575 .40401 .5106 Mtetra
.974 .916 .677 r
.40401 .5106 .41395 .50575 .4308 .46755 .421 .47527 Mtetra
.98 .915 .629 r
.421 .47527 .4308 .46755 .44747 .42775 .43791 .43524 Mtetra
.976 .921 .631 r
.43791 .43524 .44747 .42775 .46381 .39281 .45454 .39702 Mtetra
.966 .935 .688 r
.45454 .39702 .46381 .39281 .47983 .36606 .47082 .36588 Mtetra
.933 .934 .779 r
.47082 .36588 .47983 .36606 .49566 .34705 .48684 .34309 Mtetra
.868 .9 .853 r
.48684 .34309 .49566 .34705 .51142 .33366 .50273 .32709 Mtetra
.796 .849 .891 r
.50273 .32709 .51142 .33366 .52719 .32377 .5186 .31559 Mtetra
.741 .806 .904 r
.5186 .31559 .52719 .32377 .54302 .31589 .5345 .30676 Mtetra
.706 .778 .908 r
.5345 .30676 .54302 .31589 .55893 .30911 .55048 .29944 Mtetra
.686 .761 .908 r
.55048 .29944 .55893 .30911 .57493 .3029 .56654 .29291 Mtetra
.676 .752 .908 r
.56654 .29291 .57493 .3029 .59102 .29698 .58269 .28679 Mtetra
.67 .747 .908 r
.58269 .28679 .59102 .29698 .60721 .2912 .59894 .28088 Mtetra
.667 .744 .908 r
.59894 .28088 .60721 .2912 .62349 .28548 .61529 .27506 Mtetra
.665 .743 .908 r
.61529 .27506 .62349 .28548 .63987 .27977 .63173 .26927 Mtetra
.664 .742 .908 r
.63173 .26927 .63987 .27977 .65634 .27406 .64827 .26349 Mtetra
.64827 .26349 .65634 .27406 .67291 .26833 .66491 .25768 Mtetra
.66491 .25768 .67291 .26833 .68958 .26256 .68164 .25186 Mtetra
.664 .741 .908 r
.68164 .25186 .68958 .26256 .70635 .25677 .69848 .246 Mtetra
.69848 .246 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23419 Mtetra
.73246 .23419 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62352 .18391 .63205 .19891 .62743 .18844 .61886 Mtetra
.646 .763 .934 r
.18844 .61886 .19891 .62743 .21399 .62278 .20357 .61416 Mtetra
.20357 .61416 .21399 .62278 .22916 .61809 .21879 .60943 Mtetra
.647 .763 .934 r
.21879 .60943 .22916 .61809 .24442 .61335 .23411 .60465 Mtetra
.648 .764 .933 r
.23411 .60465 .24442 .61335 .25977 .60853 .24951 .59981 Mtetra
.65 .765 .933 r
.24951 .59981 .25977 .60853 .27522 .60359 .26501 .59487 Mtetra
.653 .767 .933 r
.26501 .59487 .27522 .60359 .29077 .59844 .28061 .58977 Mtetra
.66 .771 .932 r
.28061 .58977 .29077 .59844 .30643 .59293 .29632 .5844 Mtetra
.672 .778 .93 r
.29632 .5844 .30643 .59293 .32222 .58677 .31215 .57854 Mtetra
.693 .791 .925 r
.31215 .57854 .32222 .58677 .33815 .5794 .32811 .57179 Mtetra
.73 .813 .916 r
.32811 .57179 .33815 .5794 .35426 .5699 .34423 .56342 Mtetra
.785 .844 .896 r
.34423 .56342 .35426 .5699 .37059 .5567 .36056 .55222 Mtetra
.854 .879 .856 r
.36056 .55222 .37059 .5567 .38717 .53764 .37713 .53628 Mtetra
.921 .907 .791 r
.37713 .53628 .38717 .53764 .40401 .5106 .39397 .5133 Mtetra
.964 .916 .712 r
.39397 .5133 .40401 .5106 .421 .47527 .41103 .48178 Mtetra
.979 .915 .648 r
.41103 .48178 .421 .47527 .43791 .43524 .42814 .44322 Mtetra
.979 .917 .623 r
.42814 .44322 .43791 .43524 .45454 .39702 .44506 .40306 Mtetra
.973 .928 .653 r
.44506 .40306 .45454 .39702 .47082 .36588 .46163 .3678 Mtetra
.953 .938 .732 r
.46163 .3678 .47082 .36588 .48684 .34309 .47788 .34077 Mtetra
.903 .921 .821 r
.47788 .34077 .48684 .34309 .50273 .32709 .49393 .32155 Mtetra
.831 .875 .876 r
.49393 .32155 .50273 .32709 .5186 .31559 .5099 .30797 Mtetra
.766 .826 .899 r
.5099 .30797 .5186 .31559 .5345 .30676 .52589 .29791 Mtetra
.721 .79 .906 r
.52589 .29791 .5345 .30676 .55048 .29944 .54193 .28986 Mtetra
.695 .768 .908 r
.54193 .28986 .55048 .29944 .56654 .29291 .55806 .28292 Mtetra
.68 .756 .908 r
.55806 .28292 .56654 .29291 .58269 .28679 .57428 .27655 Mtetra
.672 .749 .908 r
.57428 .27655 .58269 .28679 .59894 .28088 .59059 .27048 Mtetra
.668 .745 .908 r
.59059 .27048 .59894 .28088 .61529 .27506 .607 .26454 Mtetra
.666 .743 .908 r
.607 .26454 .61529 .27506 .63173 .26927 .6235 .25866 Mtetra
.665 .742 .908 r
.6235 .25866 .63173 .26927 .64827 .26349 .64011 .2528 Mtetra
.664 .742 .908 r
.64011 .2528 .64827 .26349 .66491 .25768 .65681 .24693 Mtetra
.65681 .24693 .66491 .25768 .68164 .25186 .67362 .24103 Mtetra
.664 .741 .908 r
.67362 .24103 .68164 .25186 .69848 .246 .69052 .23511 Mtetra
.69052 .23511 .69848 .246 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23419 .72464 .22316 Mtetra
.72464 .22316 .73246 .23419 .7496 .22823 .74185 .21714 Mtetra
.74185 .21714 .7496 .22823 .76684 .22223 .75917 .21108 Mtetra
.75917 .21108 .76684 .22223 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .762 .934 r
.16277 .6149 .1734 .62352 .18844 .61886 .17787 .61019 Mtetra
.646 .763 .934 r
.17787 .61019 .18844 .61886 .20357 .61416 .19305 .60545 Mtetra
.19305 .60545 .20357 .61416 .21879 .60943 .20832 .60067 Mtetra
.647 .763 .934 r
.20832 .60067 .21879 .60943 .23411 .60465 .22368 .59585 Mtetra
.22368 .59585 .23411 .60465 .24951 .59981 .23914 .59097 Mtetra
.649 .764 .933 r
.23914 .59097 .24951 .59981 .26501 .59487 .25469 .58602 Mtetra
.651 .766 .933 r
.25469 .58602 .26501 .59487 .28061 .58977 .27035 .58094 Mtetra
.656 .769 .932 r
.27035 .58094 .28061 .58977 .29632 .5844 .2861 .57566 Mtetra
.665 .774 .931 r
.2861 .57566 .29632 .5844 .31215 .57854 .30197 .57001 Mtetra
.681 .784 .928 r
.30197 .57001 .31215 .57854 .32811 .57179 .31797 .5637 Mtetra
.709 .801 .922 r
.31797 .5637 .32811 .57179 .34423 .56342 .33412 .55618 Mtetra
.755 .827 .908 r
.33412 .55618 .34423 .56342 .36056 .55222 .35045 .54649 Mtetra
.818 .862 .88 r
.35045 .54649 .36056 .55222 .37713 .53628 .36701 .53309 Mtetra
.89 .895 .827 r
.36701 .53309 .37713 .53628 .39397 .5133 .38383 .5138 Mtetra
.946 .914 .752 r
.38383 .5138 .39397 .5133 .41103 .48178 .40092 .48646 Mtetra
.974 .916 .676 r
.40092 .48646 .41103 .48178 .42814 .44322 .41816 .45079 Mtetra
.98 .915 .629 r
.41816 .45079 .42814 .44322 .44506 .40306 .43534 .41039 Mtetra
.977 .921 .631 r
.43534 .41039 .44506 .40306 .46163 .3678 .45222 .37182 Mtetra
.966 .935 .688 r
.45222 .37182 .46163 .3678 .47788 .34077 .46874 .34038 Mtetra
.933 .934 .779 r
.46874 .34038 .47788 .34077 .49393 .32155 .48498 .31735 Mtetra
.868 .9 .853 r
.48498 .31735 .49393 .32155 .5099 .30797 .50109 .30113 Mtetra
.796 .849 .891 r
.50109 .30113 .5099 .30797 .52589 .29791 .51717 .28945 Mtetra
.741 .806 .904 r
.51717 .28945 .52589 .29791 .54193 .28986 .53329 .28046 Mtetra
.706 .778 .908 r
.53329 .28046 .54193 .28986 .55806 .28292 .54948 .27297 Mtetra
.686 .761 .908 r
.54948 .27297 .55806 .28292 .57428 .27655 .56577 .26628 Mtetra
.676 .752 .908 r
.56577 .26628 .57428 .27655 .59059 .27048 .58214 .26 Mtetra
.67 .747 .908 r
.58214 .26 .59059 .27048 .607 .26454 .59861 .25393 Mtetra
.667 .744 .908 r
.59861 .25393 .607 .26454 .6235 .25866 .61519 .24795 Mtetra
.665 .743 .908 r
.61519 .24795 .6235 .25866 .64011 .2528 .63186 .242 Mtetra
.664 .742 .908 r
.63186 .242 .64011 .2528 .65681 .24693 .64863 .23605 Mtetra
.64863 .23605 .65681 .24693 .67362 .24103 .6655 .23009 Mtetra
.6655 .23009 .67362 .24103 .69052 .23511 .68248 .22409 Mtetra
.664 .741 .908 r
.68248 .22409 .69052 .23511 .70753 .22915 .69956 .21807 Mtetra
.69956 .21807 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21714 .73402 .20592 Mtetra
.73402 .20592 .74185 .21714 .75917 .21108 .75141 .19979 Mtetra
.75141 .19979 .75917 .21108 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .6149 .17787 .61019 .16717 .60143 Mtetra
.16717 .60143 .17787 .61019 .19305 .60545 .18241 .59663 Mtetra
.646 .763 .934 r
.18241 .59663 .19305 .60545 .20832 .60067 .19773 .59181 Mtetra
.19773 .59181 .20832 .60067 .22368 .59585 .21315 .58694 Mtetra
.647 .763 .934 r
.21315 .58694 .22368 .59585 .23914 .59097 .22866 .58203 Mtetra
.648 .764 .933 r
.22866 .58203 .23914 .59097 .25469 .58602 .24426 .57705 Mtetra
.65 .765 .933 r
.24426 .57705 .25469 .58602 .27035 .58094 .25997 .57197 Mtetra
.653 .767 .933 r
.25997 .57197 .27035 .58094 .2861 .57566 .27577 .56674 Mtetra
.66 .771 .932 r
.27577 .56674 .2861 .57566 .30197 .57001 .29169 .56122 Mtetra
.672 .778 .93 r
.29169 .56122 .30197 .57001 .31797 .5637 .30773 .55522 Mtetra
.693 .791 .925 r
.30773 .55522 .31797 .5637 .33412 .55618 .32391 .54831 Mtetra
.729 .813 .916 r
.32391 .54831 .33412 .55618 .35045 .54649 .34025 .53978 Mtetra
.785 .844 .896 r
.34025 .53978 .35045 .54649 .36701 .53309 .35681 .52838 Mtetra
.855 .88 .856 r
.35681 .52838 .36701 .53309 .38383 .5138 .37362 .51222 Mtetra
.921 .907 .791 r
.37362 .51222 .38383 .5138 .40092 .48646 .39071 .48898 Mtetra
.964 .916 .712 r
.39071 .48898 .40092 .48646 .41816 .45079 .40802 .45713 Mtetra
.979 .915 .648 r
.40802 .45713 .41816 .45079 .43534 .41039 .4254 .4182 Mtetra
.979 .917 .623 r
.4254 .4182 .43534 .41039 .45222 .37182 .44257 .37768 Mtetra
.973 .928 .653 r
.44257 .37768 .45222 .37182 .46874 .34038 .45939 .34209 Mtetra
.953 .938 .733 r
.45939 .34209 .46874 .34038 .48498 .31735 .47587 .31479 Mtetra
.903 .921 .821 r
.47587 .31479 .48498 .31735 .50109 .30113 .49215 .29534 Mtetra
.831 .875 .876 r
.49215 .29534 .50109 .30113 .51717 .28945 .50834 .28156 Mtetra
.766 .826 .899 r
.50834 .28156 .51717 .28945 .53329 .28046 .52455 .27132 Mtetra
.721 .79 .906 r
.52455 .27132 .53329 .28046 .54948 .27297 .54081 .26311 Mtetra
.695 .768 .908 r
.54081 .26311 .54948 .27297 .56577 .26628 .55716 .256 Mtetra
.68 .756 .908 r
.55716 .256 .56577 .26628 .58214 .26 .5736 .24947 Mtetra
.672 .749 .908 r
.5736 .24947 .58214 .26 .59861 .25393 .59014 .24323 Mtetra
.668 .745 .908 r
.59014 .24323 .59861 .25393 .61519 .24795 .60678 .23714 Mtetra
.666 .743 .908 r
.60678 .23714 .61519 .24795 .63186 .242 .62352 .23109 Mtetra
.665 .742 .908 r
.62352 .23109 .63186 .242 .64863 .23605 .64036 .22506 Mtetra
.664 .742 .908 r
.64036 .22506 .64863 .23605 .6655 .23009 .6573 .21902 Mtetra
.6573 .21902 .6655 .23009 .68248 .22409 .67434 .21296 Mtetra
.664 .741 .908 r
.67434 .21296 .68248 .22409 .69956 .21807 .69149 .20687 Mtetra
.69149 .20687 .69956 .21807 .71674 .21201 .70874 .20074 Mtetra
.70874 .20074 .71674 .21201 .73402 .20592 .7261 .19458 Mtetra
.7261 .19458 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59663 .17165 .58772 Mtetra
.646 .763 .934 r
.17165 .58772 .18241 .59663 .19773 .59181 .18703 .58284 Mtetra
.18703 .58284 .19773 .59181 .21315 .58694 .2025 .57793 Mtetra
.647 .763 .934 r
.2025 .57793 .21315 .58694 .22866 .58203 .21806 .57297 Mtetra
.21806 .57297 .22866 .58203 .24426 .57705 .23372 .56796 Mtetra
.649 .764 .933 r
.23372 .56796 .24426 .57705 .25997 .57197 .24948 .56287 Mtetra
.651 .766 .933 r
.24948 .56287 .25997 .57197 .27577 .56674 .26533 .55765 Mtetra
.656 .769 .932 r
.26533 .55765 .27577 .56674 .29169 .56122 .2813 .55222 Mtetra
.665 .774 .931 r
.2813 .55222 .29169 .56122 .30773 .55522 .29738 .54643 Mtetra
.681 .784 .928 r
.29738 .54643 .30773 .55522 .32391 .54831 .3136 .53996 Mtetra
.709 .801 .922 r
.3136 .53996 .32391 .54831 .34025 .53978 .32997 .53228 Mtetra
.755 .827 .908 r
.32997 .53228 .34025 .53978 .35681 .52838 .34653 .52242 Mtetra
.819 .862 .88 r
.34653 .52242 .35681 .52838 .37362 .51222 .36332 .50881 Mtetra
.89 .895 .827 r
.36332 .50881 .37362 .51222 .39071 .48898 .3804 .48927 Mtetra
.946 .914 .752 r
.3804 .48927 .39071 .48898 .40802 .45713 .39774 .46162 Mtetra
.974 .916 .676 r
.39774 .46162 .40802 .45713 .4254 .4182 .41525 .4256 Mtetra
.98 .915 .629 r
.41525 .4256 .4254 .4182 .44257 .37768 .43269 .38483 Mtetra
.977 .921 .631 r
.43269 .38483 .44257 .37768 .45939 .34209 .44983 .34591 Mtetra
.966 .935 .689 r
.44983 .34591 .45939 .34209 .47587 .31479 .46659 .31417 Mtetra
.933 .934 .779 r
.46659 .31417 .47587 .31479 .49215 .29534 .48306 .29089 Mtetra
.868 .9 .853 r
.48306 .29089 .49215 .29534 .50834 .28156 .4994 .27446 Mtetra
.796 .849 .891 r
.4994 .27446 .50834 .28156 .52455 .27132 .5157 .26258 Mtetra
.741 .806 .904 r
.5157 .26258 .52455 .27132 .54081 .26311 .53204 .25342 Mtetra
.706 .778 .908 r
.53204 .25342 .54081 .26311 .55716 .256 .54846 .24576 Mtetra
.686 .761 .908 r
.54846 .24576 .55716 .256 .5736 .24947 .56497 .2389 Mtetra
.676 .752 .908 r
.56497 .2389 .5736 .24947 .59014 .24323 .58157 .23246 Mtetra
.67 .747 .908 r
.58157 .23246 .59014 .24323 .60678 .23714 .59828 .22622 Mtetra
.667 .744 .908 r
.59828 .22622 .60678 .23714 .62352 .23109 .61508 .22008 Mtetra
.665 .743 .908 r
.61508 .22008 .62352 .23109 .64036 .22506 .63199 .21396 Mtetra
.664 .742 .908 r
.63199 .21396 .64036 .22506 .6573 .21902 .649 .20784 Mtetra
.649 .20784 .6573 .21902 .67434 .21296 .66612 .2017 Mtetra
.66612 .2017 .67434 .21296 .69149 .20687 .68334 .19554 Mtetra
.664 .741 .908 r
.68334 .19554 .69149 .20687 .70874 .20074 .70066 .18934 Mtetra
.70066 .18934 .70874 .20074 .7261 .19458 .71809 .18311 Mtetra
.71809 .18311 .7261 .19458 .74357 .18838 .73563 .17684 Mtetra
.73563 .17684 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58772 .16077 .57871 Mtetra
.16077 .57871 .17165 .58772 .18703 .58284 .1762 .57378 Mtetra
.646 .763 .934 r
.1762 .57378 .18703 .58284 .2025 .57793 .19173 .56882 Mtetra
.19173 .56882 .2025 .57793 .21806 .57297 .20734 .56381 Mtetra
.647 .763 .934 r
.20734 .56381 .21806 .57297 .23372 .56796 .22306 .55876 Mtetra
.648 .764 .933 r
.22306 .55876 .23372 .56796 .24948 .56287 .23887 .55364 Mtetra
.65 .765 .933 r
.23887 .55364 .24948 .56287 .26533 .55765 .25478 .54842 Mtetra
.653 .767 .933 r
.25478 .54842 .26533 .55765 .2813 .55222 .2708 .54304 Mtetra
.66 .771 .932 r
.2708 .54304 .2813 .55222 .29738 .54643 .28693 .53738 Mtetra
.672 .778 .93 r
.28693 .53738 .29738 .54643 .3136 .53996 .30319 .53122 Mtetra
.693 .791 .925 r
.30319 .53122 .3136 .53996 .32997 .53228 .31959 .52415 Mtetra
.729 .813 .916 r
.31959 .52415 .32997 .53228 .34653 .52242 .33616 .51545 Mtetra
.785 .844 .897 r
.33616 .51545 .34653 .52242 .36332 .50881 .35295 .50386 Mtetra
.855 .88 .857 r
.35295 .50386 .36332 .50881 .3804 .48927 .37 .48747 Mtetra
.921 .907 .791 r
.37 .48747 .3804 .48927 .39774 .46162 .38735 .46394 Mtetra
.964 .917 .712 r
.38735 .46394 .39774 .46162 .41525 .4256 .40493 .43177 Mtetra
.979 .915 .648 r
.40493 .43177 .41525 .4256 .43269 .38483 .42258 .39246 Mtetra
.979 .917 .623 r
.42258 .39246 .43269 .38483 .44983 .34591 .44002 .35158 Mtetra
.973 .928 .653 r
.44002 .35158 .44983 .34591 .46659 .31417 .45709 .31566 Mtetra
.953 .938 .733 r
.45709 .31566 .46659 .31417 .48306 .29089 .47382 .28808 Mtetra
.903 .921 .821 r
.47382 .28808 .48306 .29089 .4994 .27446 .49032 .2684 Mtetra
.831 .875 .876 r
.49032 .2684 .4994 .27446 .5157 .26258 .50674 .25442 Mtetra
.766 .826 .899 r
.50674 .25442 .5157 .26258 .53204 .25342 .52317 .24399 Mtetra
.721 .79 .906 r
.52317 .24399 .53204 .25342 .54846 .24576 .53966 .2356 Mtetra
.695 .768 .908 r
.53966 .2356 .54846 .24576 .56497 .2389 .55624 .22832 Mtetra
.68 .756 .908 r
.55624 .22832 .56497 .2389 .58157 .23246 .57291 .22162 Mtetra
.672 .749 .908 r
.57291 .22162 .58157 .23246 .59828 .22622 .58968 .21522 Mtetra
.668 .745 .908 r
.58968 .21522 .59828 .22622 .61508 .22008 .60655 .20895 Mtetra
.666 .743 .908 r
.60655 .20895 .61508 .22008 .63199 .21396 .62353 .20274 Mtetra
.665 .742 .908 r
.62353 .20274 .63199 .21396 .649 .20784 .64061 .19653 Mtetra
.664 .742 .908 r
.64061 .19653 .649 .20784 .66612 .2017 .6578 .19032 Mtetra
.6578 .19032 .66612 .2017 .68334 .19554 .67509 .18408 Mtetra
.664 .741 .908 r
.67509 .18408 .68334 .19554 .70066 .18934 .69249 .17781 Mtetra
.69249 .17781 .70066 .18934 .71809 .18311 .70999 .1715 Mtetra
.70999 .1715 .71809 .18311 .73563 .17684 .72761 .16516 Mtetra
.72761 .16516 .73563 .17684 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57871 .14978 .5696 Mtetra
.14978 .5696 .16077 .57871 .1762 .57378 .16526 .56462 Mtetra
.646 .763 .934 r
.16526 .56462 .1762 .57378 .19173 .56882 .18083 .5596 Mtetra
.18083 .5596 .19173 .56882 .20734 .56381 .19651 .55455 Mtetra
.647 .763 .934 r
.19651 .55455 .20734 .56381 .22306 .55876 .21227 .54945 Mtetra
.21227 .54945 .22306 .55876 .23887 .55364 .22814 .54429 Mtetra
.649 .764 .933 r
.22814 .54429 .23887 .55364 .25478 .54842 .24411 .53905 Mtetra
.651 .766 .933 r
.24411 .53905 .25478 .54842 .2708 .54304 .26018 .53369 Mtetra
.656 .769 .932 r
.26018 .53369 .2708 .54304 .28693 .53738 .27636 .52811 Mtetra
.665 .774 .931 r
.27636 .52811 .28693 .53738 .30319 .53122 .29266 .52216 Mtetra
.681 .784 .928 r
.29266 .52216 .30319 .53122 .31959 .52415 .3091 .51554 Mtetra
.709 .801 .922 r
.3091 .51554 .31959 .52415 .33616 .51545 .3257 .50768 Mtetra
.755 .827 .908 r
.3257 .50768 .33616 .51545 .35295 .50386 .34249 .49764 Mtetra
.819 .862 .88 r
.34249 .49764 .35295 .50386 .37 .48747 .35953 .48382 Mtetra
.89 .896 .827 r
.35953 .48382 .37 .48747 .38735 .46394 .37686 .46402 Mtetra
.947 .914 .751 r
.37686 .46402 .38735 .46394 .40493 .43177 .39447 .43607 Mtetra
.974 .916 .676 r
.39447 .43607 .40493 .43177 .42258 .39246 .41225 .39969 Mtetra
.98 .915 .629 r
.41225 .39969 .42258 .39246 .44002 .35158 .42997 .35854 Mtetra
.977 .921 .631 r
.42997 .35854 .44002 .35158 .45709 .31566 .44737 .31926 Mtetra
.966 .935 .689 r
.44737 .31926 .45709 .31566 .47382 .28808 .46438 .28721 Mtetra
.933 .934 .779 r
.46438 .28721 .47382 .28808 .49032 .2684 .48109 .26368 Mtetra
.868 .9 .853 r
.48109 .26368 .49032 .2684 .50674 .25442 .49766 .24703 Mtetra
.796 .849 .891 r
.49766 .24703 .50674 .25442 .52317 .24399 .51419 .23496 Mtetra
.741 .806 .904 r
.51419 .23496 .52317 .24399 .53966 .2356 .53076 .22561 Mtetra
.706 .778 .908 r
.53076 .22561 .53966 .2356 .55624 .22832 .54741 .21777 Mtetra
.686 .761 .908 r
.54741 .21777 .55624 .22832 .57291 .22162 .56415 .21074 Mtetra
.676 .752 .908 r
.56415 .21074 .57291 .22162 .58968 .21522 .58099 .20413 Mtetra
.67 .747 .908 r
.58099 .20413 .58968 .21522 .60655 .20895 .59793 .19772 Mtetra
.667 .744 .908 r
.59793 .19772 .60655 .20895 .62353 .20274 .61497 .1914 Mtetra
.665 .743 .908 r
.61497 .1914 .62353 .20274 .64061 .19653 .63213 .18511 Mtetra
.664 .742 .908 r
.63213 .18511 .64061 .19653 .6578 .19032 .64938 .17881 Mtetra
.64938 .17881 .6578 .19032 .67509 .18408 .66675 .17249 Mtetra
.66675 .17249 .67509 .18408 .69249 .17781 .68422 .16615 Mtetra
.664 .741 .908 r
.68422 .16615 .69249 .17781 .70999 .1715 .7018 .15977 Mtetra
.7018 .15977 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56462 .15419 .55535 Mtetra
.15419 .55535 .16526 .56462 .18083 .5596 .16982 .55028 Mtetra
.646 .763 .934 r
.16982 .55028 .18083 .5596 .19651 .55455 .18555 .54517 Mtetra
.18555 .54517 .19651 .55455 .21227 .54945 .20137 .54002 Mtetra
.647 .763 .934 r
.20137 .54002 .21227 .54945 .22814 .54429 .21729 .53482 Mtetra
.648 .764 .933 r
.21729 .53482 .22814 .54429 .24411 .53905 .23331 .52956 Mtetra
.65 .765 .933 r
.23331 .52956 .24411 .53905 .26018 .53369 .24944 .52419 Mtetra
.653 .767 .933 r
.24944 .52419 .26018 .53369 .27636 .52811 .26568 .51865 Mtetra
.66 .771 .932 r
.26568 .51865 .27636 .52811 .29266 .52216 .28203 .51284 Mtetra
.672 .778 .93 r
.28203 .51284 .29266 .52216 .3091 .51554 .29851 .50652 Mtetra
.693 .791 .925 r
.29851 .50652 .3091 .51554 .3257 .50768 .31514 .49929 Mtetra
.729 .813 .916 r
.31514 .49929 .3257 .50768 .34249 .49764 .33195 .4904 Mtetra
.785 .844 .897 r
.33195 .4904 .34249 .49764 .35953 .48382 .34898 .47861 Mtetra
.855 .88 .857 r
.34898 .47861 .35953 .48382 .37686 .46402 .36628 .46198 Mtetra
.922 .907 .791 r
.36628 .46198 .37686 .46402 .39447 .43607 .38389 .43818 Mtetra
.964 .917 .712 r
.38389 .43818 .39447 .43607 .41225 .39969 .40175 .40566 Mtetra
.979 .915 .647 r
.40175 .40566 .41225 .39969 .42997 .35854 .41967 .36599 Mtetra
.979 .917 .623 r
.41967 .36599 .42997 .35854 .44737 .31926 .43739 .32472 Mtetra
.973 .928 .654 r
.43739 .32472 .44737 .31926 .46438 .28721 .45473 .28847 Mtetra
.953 .938 .733 r
.45473 .28847 .46438 .28721 .48109 .26368 .4717 .26061 Mtetra
.903 .921 .821 r
.4717 .26061 .48109 .26368 .49766 .24703 .48844 .24069 Mtetra
.831 .874 .876 r
.48844 .24069 .49766 .24703 .51419 .23496 .50509 .2265 Mtetra
.766 .826 .899 r
.50509 .2265 .51419 .23496 .53076 .22561 .52176 .21588 Mtetra
.721 .79 .906 r
.52176 .21588 .53076 .22561 .54741 .21777 .53848 .20731 Mtetra
.695 .768 .908 r
.53848 .20731 .54741 .21777 .56415 .21074 .55529 .19985 Mtetra
.68 .756 .908 r
.55529 .19985 .56415 .21074 .58099 .20413 .5722 .19298 Mtetra
.672 .749 .908 r
.5722 .19298 .58099 .20413 .59793 .19772 .58921 .18639 Mtetra
.668 .745 .908 r
.58921 .18639 .59793 .19772 .61497 .1914 .60632 .17995 Mtetra
.666 .743 .908 r
.60632 .17995 .61497 .1914 .63213 .18511 .62354 .17356 Mtetra
.665 .742 .908 r
.62354 .17356 .63213 .18511 .64938 .17881 .64087 .16717 Mtetra
.664 .742 .908 r
.64087 .16717 .64938 .17881 .66675 .17249 .65831 .16078 Mtetra
.65831 .16078 .66675 .17249 .68422 .16615 .67586 .15436 Mtetra
.664 .741 .908 r
.67586 .15436 .68422 .16615 .7018 .15977 .69351 .1479 Mtetra
.69351 .1479 .7018 .15977 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54597 Mtetra
.143 .54597 .15419 .55535 .16982 .55028 .15868 .54085 Mtetra
.646 .763 .934 r
.15868 .54085 .16982 .55028 .18555 .54517 .17446 .53569 Mtetra
.17446 .53569 .18555 .54517 .20137 .54002 .19034 .53048 Mtetra
.647 .763 .934 r
.19034 .53048 .20137 .54002 .21729 .53482 .20632 .52524 Mtetra
.20632 .52524 .21729 .53482 .23331 .52956 .2224 .51993 Mtetra
.649 .764 .933 r
.2224 .51993 .23331 .52956 .24944 .52419 .23858 .51454 Mtetra
.651 .766 .933 r
.23858 .51454 .24944 .52419 .26568 .51865 .25487 .50902 Mtetra
.656 .769 .932 r
.25487 .50902 .26568 .51865 .28203 .51284 .27127 .50329 Mtetra
.665 .774 .931 r
.27127 .50329 .28203 .51284 .29851 .50652 .2878 .49718 Mtetra
.681 .784 .928 r
.2878 .49718 .29851 .50652 .31514 .49929 .30447 .49039 Mtetra
.709 .801 .922 r
.30447 .49039 .31514 .49929 .33195 .4904 .3213 .48236 Mtetra
.755 .827 .908 r
.3213 .48236 .33195 .4904 .34898 .47861 .33834 .47212 Mtetra
.819 .862 .88 r
.33834 .47212 .34898 .47861 .36628 .46198 .35563 .45808 Mtetra
.89 .896 .827 r
.35563 .45808 .36628 .46198 .38389 .43818 .37322 .43802 Mtetra
.947 .914 .751 r
.37322 .43802 .38389 .43818 .40175 .40566 .3911 .40976 Mtetra
.974 .916 .676 r
.3911 .40976 .40175 .40566 .41967 .36599 .40917 .37302 Mtetra
.98 .915 .629 r
.40917 .37302 .41967 .36599 .43739 .32472 .42716 .33148 Mtetra
.977 .921 .631 r
.42716 .33148 .43739 .32472 .45473 .28847 .44484 .29185 Mtetra
.966 .935 .689 r
.44484 .29185 .45473 .28847 .4717 .26061 .46211 .25949 Mtetra
.932 .934 .779 r
.46211 .25949 .4717 .26061 .48844 .24069 .47907 .23569 Mtetra
.868 .899 .853 r
.47907 .23569 .48844 .24069 .50509 .2265 .49587 .21882 Mtetra
.796 .849 .891 r
.49587 .21882 .50509 .2265 .52176 .21588 .51264 .20654 Mtetra
.741 .806 .904 r
.51264 .20654 .52176 .21588 .53848 .20731 .52945 .197 Mtetra
.706 .778 .908 r
.52945 .197 .53848 .20731 .55529 .19985 .54633 .18898 Mtetra
.687 .761 .908 r
.54633 .18898 .55529 .19985 .5722 .19298 .56331 .18177 Mtetra
.676 .752 .908 r
.56331 .18177 .5722 .19298 .58921 .18639 .58039 .17498 Mtetra
.67 .747 .908 r
.58039 .17498 .58921 .18639 .60632 .17995 .59757 .16839 Mtetra
.667 .744 .908 r
.59757 .16839 .60632 .17995 .62354 .17356 .61486 .16189 Mtetra
.665 .743 .908 r
.61486 .16189 .62354 .17356 .64087 .16717 .63227 .15541 Mtetra
.664 .742 .908 r
.63227 .15541 .64087 .16717 .65831 .16078 .64978 .14893 Mtetra
.64978 .14893 .65831 .16078 .67586 .15436 .6674 .14243 Mtetra
.6674 .14243 .67586 .15436 .69351 .1479 .68513 .1359 Mtetra
.664 .741 .908 r
.68513 .1359 .69351 .1479 .71128 .14141 .70297 .12933 Mtetra
.70297 .12933 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54164 Mtetra
.11604 .54164 .12741 .55107 .143 .54597 .13168 .53649 Mtetra
.13168 .53649 .143 .54597 .15868 .54085 .14742 .53131 Mtetra
.14742 .53131 .15868 .54085 .17446 .53569 .16325 .52609 Mtetra
.646 .763 .934 r
.16325 .52609 .17446 .53569 .19034 .53048 .17919 .52083 Mtetra
.17919 .52083 .19034 .53048 .20632 .52524 .19522 .51554 Mtetra
.647 .763 .934 r
.19522 .51554 .20632 .52524 .2224 .51993 .21136 .51018 Mtetra
.648 .764 .933 r
.21136 .51018 .2224 .51993 .23858 .51454 .2276 .50476 Mtetra
.65 .765 .933 r
.2276 .50476 .23858 .51454 .25487 .50902 .24394 .49924 Mtetra
.653 .767 .933 r
.24394 .49924 .25487 .50902 .27127 .50329 .2604 .49355 Mtetra
.66 .771 .932 r
.2604 .49355 .27127 .50329 .2878 .49718 .27698 .48757 Mtetra
.672 .778 .93 r
.27698 .48757 .2878 .49718 .30447 .49039 .29369 .48109 Mtetra
.693 .791 .925 r
.29369 .48109 .30447 .49039 .3213 .48236 .31056 .47368 Mtetra
.729 .813 .916 r
.31056 .47368 .3213 .48236 .33834 .47212 .32761 .46461 Mtetra
.785 .844 .897 r
.32761 .46461 .33834 .47212 .35563 .45808 .34489 .4526 Mtetra
.855 .88 .857 r
.34489 .4526 .35563 .45808 .37322 .43802 .36245 .43574 Mtetra
.922 .908 .791 r
.36245 .43574 .37322 .43802 .3911 .40976 .38033 .41164 Mtetra
.964 .917 .712 r
.38033 .41164 .3911 .40976 .40917 .37302 .39848 .37878 Mtetra
.979 .915 .647 r
.39848 .37878 .40917 .37302 .42716 .33148 .41669 .33873 Mtetra
.979 .917 .623 r
.41669 .33873 .42716 .33148 .44484 .29185 .43469 .29709 Mtetra
.973 .928 .654 r
.43469 .29709 .44484 .29185 .46211 .25949 .45229 .26049 Mtetra
.953 .938 .733 r
.45229 .26049 .46211 .25949 .47907 .23569 .46952 .23235 Mtetra
.903 .92 .821 r
.46952 .23235 .47907 .23569 .49587 .21882 .48651 .21218 Mtetra
.831 .874 .876 r
.48651 .21218 .49587 .21882 .51264 .20654 .5034 .19777 Mtetra
.766 .826 .899 r
.5034 .19777 .51264 .20654 .52945 .197 .5203 .18696 Mtetra
.721 .79 .906 r
.5203 .18696 .52945 .197 .54633 .18898 .53726 .1782 Mtetra
.695 .768 .908 r
.53726 .1782 .54633 .18898 .56331 .18177 .55431 .17055 Mtetra
.68 .756 .908 r
.55431 .17055 .56331 .18177 .58039 .17498 .57146 .1635 Mtetra
.672 .749 .908 r
.57146 .1635 .58039 .17498 .59757 .16839 .58872 .15673 Mtetra
.668 .745 .908 r
.58872 .15673 .59757 .16839 .61486 .16189 .60608 .1501 Mtetra
.666 .743 .908 r
.60608 .1501 .61486 .16189 .63227 .15541 .62356 .14352 Mtetra
.665 .742 .908 r
.62356 .14352 .63227 .15541 .64978 .14893 .64114 .13695 Mtetra
.664 .742 .908 r
.64114 .13695 .64978 .14893 .6674 .14243 .65884 .13036 Mtetra
.65884 .13036 .6674 .14243 .68513 .1359 .67665 .12375 Mtetra
.664 .741 .908 r
.67665 .12375 .68513 .1359 .70297 .12933 .69457 .1171 Mtetra
.69457 .1171 .70297 .12933 .72093 .12272 .7126 .11042 Mtetra
.7126 .11042 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54164 .10454 .53211 Mtetra
.10454 .53211 .11604 .54164 .13168 .53649 .12023 .5269 Mtetra
.12023 .5269 .13168 .53649 .14742 .53131 .13603 .52166 Mtetra
.13603 .52166 .14742 .53131 .16325 .52609 .15192 .51638 Mtetra
.646 .763 .934 r
.15192 .51638 .16325 .52609 .17919 .52083 .16791 .51107 Mtetra
.16791 .51107 .17919 .52083 .19522 .51554 .184 .50572 Mtetra
.647 .763 .934 r
.184 .50572 .19522 .51554 .21136 .51018 .20019 .50031 Mtetra
.20019 .50031 .21136 .51018 .2276 .50476 .21649 .49485 Mtetra
.649 .764 .933 r
.21649 .49485 .2276 .50476 .24394 .49924 .23289 .4893 Mtetra
.651 .766 .933 r
.23289 .4893 .24394 .49924 .2604 .49355 .24941 .48363 Mtetra
.656 .769 .932 r
.24941 .48363 .2604 .49355 .27698 .48757 .26604 .47773 Mtetra
.665 .774 .931 r
.26604 .47773 .27698 .48757 .29369 .48109 .2828 .47145 Mtetra
.681 .784 .928 r
.2828 .47145 .29369 .48109 .31056 .47368 .2997 .46449 Mtetra
.709 .801 .922 r
.2997 .46449 .31056 .47368 .32761 .46461 .31678 .45628 Mtetra
.755 .828 .908 r
.31678 .45628 .32761 .46461 .34489 .4526 .33406 .44584 Mtetra
.819 .862 .88 r
.33406 .44584 .34489 .4526 .36245 .43574 .35161 .43157 Mtetra
.89 .896 .827 r
.35161 .43157 .36245 .43574 .38033 .41164 .36947 .41124 Mtetra
.947 .915 .751 r
.36947 .41124 .38033 .41164 .39848 .37878 .38763 .38266 Mtetra
.974 .917 .676 r
.38763 .38266 .39848 .37878 .41669 .33873 .40599 .34555 Mtetra
.98 .915 .629 r
.40599 .34555 .41669 .33873 .43469 .29709 .42428 .30362 Mtetra
.977 .921 .631 r
.42428 .30362 .43469 .29709 .45229 .26049 .44223 .26363 Mtetra
.966 .935 .689 r
.44223 .26363 .45229 .26049 .46952 .23235 .45977 .23095 Mtetra
.932 .933 .779 r
.45977 .23095 .46952 .23235 .48651 .21218 .47698 .20688 Mtetra
.868 .899 .853 r
.47698 .20688 .48651 .21218 .5034 .19777 .49403 .18978 Mtetra
.796 .849 .891 r
.49403 .18978 .5034 .19777 .5203 .18696 .51104 .1773 Mtetra
.741 .806 .904 r
.51104 .1773 .5203 .18696 .53726 .1782 .52809 .16757 Mtetra
.706 .778 .908 r
.52809 .16757 .53726 .1782 .55431 .17055 .54521 .15935 Mtetra
.687 .761 .908 r
.54521 .15935 .55431 .17055 .57146 .1635 .56244 .15196 Mtetra
.676 .752 .908 r
.56244 .15196 .57146 .1635 .58872 .15673 .57977 .14498 Mtetra
.67 .747 .908 r
.57977 .14498 .58872 .15673 .60608 .1501 .5972 .1382 Mtetra
.667 .744 .908 r
.5972 .1382 .60608 .1501 .62356 .14352 .61475 .1315 Mtetra
.665 .743 .908 r
.61475 .1315 .62356 .14352 .64114 .13695 .63241 .12484 Mtetra
.664 .742 .908 r
.63241 .12484 .64114 .13695 .65884 .13036 .65018 .11816 Mtetra
.65018 .11816 .65884 .13036 .67665 .12375 .66807 .11147 Mtetra
.66807 .11147 .67665 .12375 .69457 .1171 .68606 .10474 Mtetra
.664 .741 .908 r
.68606 .10474 .69457 .1171 .7126 .11042 .70418 .09797 Mtetra
.70418 .09797 .7126 .11042 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53211 .09291 .52247 Mtetra
.09291 .52247 .10454 .53211 .12023 .5269 .10866 .51721 Mtetra
.10866 .51721 .12023 .5269 .13603 .52166 .1245 .5119 Mtetra
.1245 .5119 .13603 .52166 .15192 .51638 .14045 .50657 Mtetra
.14045 .50657 .15192 .51638 .16791 .51107 .15649 .50119 Mtetra
.646 .763 .934 r
.15649 .50119 .16791 .51107 .184 .50572 .17264 .49578 Mtetra
.17264 .49578 .184 .50572 .20019 .50031 .18889 .49032 Mtetra
.647 .763 .934 r
.18889 .49032 .20019 .50031 .21649 .49485 .20525 .48481 Mtetra
.648 .764 .933 r
.20525 .48481 .21649 .49485 .23289 .4893 .22171 .47923 Mtetra
.65 .765 .933 r
.22171 .47923 .23289 .4893 .24941 .48363 .23828 .47354 Mtetra
.653 .767 .933 r
.23828 .47354 .24941 .48363 .26604 .47773 .25497 .46769 Mtetra
.66 .771 .932 r
.25497 .46769 .26604 .47773 .2828 .47145 .27178 .46154 Mtetra
.672 .778 .93 r
.27178 .46154 .2828 .47145 .2997 .46449 .28873 .45488 Mtetra
.693 .791 .926 r
.28873 .45488 .2997 .46449 .31678 .45628 .30584 .4473 Mtetra
.729 .813 .917 r
.30584 .4473 .31678 .45628 .33406 .44584 .32314 .43803 Mtetra
.785 .844 .897 r
.32314 .43803 .33406 .44584 .35161 .43157 .34067 .42581 Mtetra
.855 .88 .857 r
.34067 .42581 .35161 .43157 .36947 .41124 .35851 .4087 Mtetra
.922 .908 .791 r
.35851 .4087 .36947 .41124 .38763 .38266 .37667 .3843 Mtetra
.964 .917 .711 r
.37667 .3843 .38763 .38266 .40599 .34555 .3951 .35109 Mtetra
.979 .915 .647 r
.3951 .35109 .40599 .34555 .42428 .30362 .41361 .31065 Mtetra
.979 .917 .623 r
.41361 .31065 .42428 .30362 .44223 .26363 .43191 .26863 Mtetra
.973 .928 .654 r
.43191 .26863 .44223 .26363 .45977 .23095 .44979 .23169 Mtetra
.953 .938 .733 r
.44979 .23169 .45977 .23095 .47698 .20688 .46728 .20325 Mtetra
.903 .92 .821 r
.46728 .20325 .47698 .20688 .49403 .18978 .48452 .18283 Mtetra
.831 .874 .876 r
.48452 .18283 .49403 .18978 .51104 .1773 .50166 .16821 Mtetra
.766 .825 .899 r
.50166 .16821 .51104 .1773 .52809 .16757 .5188 .15719 Mtetra
.721 .79 .906 r
.5188 .15719 .52809 .16757 .54521 .15935 .53601 .14823 Mtetra
.695 .768 .908 r
.53601 .14823 .54521 .15935 .56244 .15196 .55331 .14039 Mtetra
.68 .756 .908 r
.55331 .14039 .56244 .15196 .57977 .14498 .57071 .13314 Mtetra
.672 .749 .908 r
.57071 .13314 .57977 .14498 .5972 .1382 .58822 .12618 Mtetra
.668 .745 .908 r
.58822 .12618 .5972 .1382 .61475 .1315 .60584 .11936 Mtetra
.666 .743 .908 r
.60584 .11936 .61475 .1315 .63241 .12484 .62357 .11259 Mtetra
.665 .742 .908 r
.62357 .11259 .63241 .12484 .65018 .11816 .64142 .10582 Mtetra
.664 .742 .908 r
.64142 .10582 .65018 .11816 .66807 .11147 .65938 .09904 Mtetra
.65938 .09904 .66807 .11147 .68606 .10474 .67746 .09222 Mtetra
.664 .741 .908 r
.67746 .09222 .68606 .10474 .70418 .09797 .69566 .08537 Mtetra
.69566 .08537 .70418 .09797 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10866 .51721 .09694 .50739 Mtetra
.09694 .50739 .10866 .51721 .1245 .5119 .11284 .50203 Mtetra
.11284 .50203 .1245 .5119 .14045 .50657 .12885 .49663 Mtetra
.12885 .49663 .14045 .50657 .15649 .50119 .14495 .4912 Mtetra
.646 .763 .934 r
.14495 .4912 .15649 .50119 .17264 .49578 .16115 .48573 Mtetra
.16115 .48573 .17264 .49578 .18889 .49032 .17746 .48021 Mtetra
.647 .763 .934 r
.17746 .48021 .18889 .49032 .20525 .48481 .19388 .47465 Mtetra
.19388 .47465 .20525 .48481 .22171 .47923 .2104 .46902 Mtetra
.649 .764 .933 r
.2104 .46902 .22171 .47923 .23828 .47354 .22703 .46331 Mtetra
.651 .766 .933 r
.22703 .46331 .23828 .47354 .25497 .46769 .24378 .45746 Mtetra
.656 .769 .932 r
.24378 .45746 .25497 .46769 .27178 .46154 .26064 .4514 Mtetra
.665 .774 .931 r
.26064 .4514 .27178 .46154 .28873 .45488 .27764 .44494 Mtetra
.681 .784 .928 r
.27764 .44494 .28873 .45488 .30584 .4473 .29479 .4378 Mtetra
.709 .801 .922 r
.29479 .4378 .30584 .4473 .32314 .43803 .31211 .42939 Mtetra
.755 .828 .909 r
.31211 .42939 .32314 .43803 .34067 .42581 .32965 .41875 Mtetra
.819 .863 .88 r
.32965 .41875 .34067 .42581 .35851 .4087 .34746 .40425 Mtetra
.89 .896 .827 r
.34746 .40425 .35851 .4087 .37667 .3843 .3656 .38365 Mtetra
.947 .915 .751 r
.3656 .38365 .37667 .3843 .3951 .35109 .38406 .35473 Mtetra
.975 .917 .676 r
.38406 .35473 .3951 .35109 .41361 .31065 .40272 .31725 Mtetra
.98 .915 .629 r
.40272 .31725 .41361 .31065 .43191 .26863 .42131 .27493 Mtetra
.977 .921 .632 r
.42131 .27493 .43191 .26863 .44979 .23169 .43955 .23457 Mtetra
.966 .934 .69 r
.43955 .23457 .44979 .23169 .46728 .20325 .45736 .20157 Mtetra
.932 .933 .779 r
.45736 .20157 .46728 .20325 .48452 .18283 .47484 .17723 Mtetra
.868 .899 .853 r
.47484 .17723 .48452 .18283 .50166 .16821 .49214 .15989 Mtetra
.796 .849 .891 r
.49214 .15989 .50166 .16821 .5188 .15719 .50939 .1472 Mtetra
.741 .806 .904 r
.50939 .1472 .5188 .15719 .53601 .14823 .52669 .13726 Mtetra
.706 .778 .907 r
.52669 .13726 .53601 .14823 .55331 .14039 .54407 .12885 Mtetra
.687 .761 .908 r
.54407 .12885 .55331 .14039 .57071 .13314 .56154 .12125 Mtetra
.676 .752 .908 r
.56154 .12125 .57071 .13314 .58822 .12618 .57913 .11407 Mtetra
.67 .747 .908 r
.57913 .11407 .58822 .12618 .60584 .11936 .59682 .1071 Mtetra
.667 .744 .908 r
.59682 .1071 .60584 .11936 .62357 .11259 .61463 .10021 Mtetra
.665 .743 .908 r
.61463 .10021 .62357 .11259 .64142 .10582 .63256 .09334 Mtetra
.664 .742 .908 r
.63256 .09334 .64142 .10582 .65938 .09904 .6506 .08647 Mtetra
.6506 .08647 .65938 .09904 .67746 .09222 .66875 .07957 Mtetra
.66875 .07957 .67746 .09222 .69566 .08537 .68703 .07263 Mtetra
.664 .741 .908 r
.68703 .07263 .69566 .08537 .71397 .07848 .70542 .06566 Mtetra
.70542 .06566 .71397 .07848 .7324 .07155 .72394 .05864 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49663 .11711 .48658 Mtetra
.11711 .48658 .12885 .49663 .14495 .4912 .13327 .48108 Mtetra
.13327 .48108 .14495 .4912 .16115 .48573 .14953 .47555 Mtetra
.646 .763 .934 r
.14953 .47555 .16115 .48573 .17746 .48021 .1659 .46997 Mtetra
.1659 .46997 .17746 .48021 .19388 .47465 .18237 .46435 Mtetra
.647 .763 .934 r
.18237 .46435 .19388 .47465 .2104 .46902 .19895 .45868 Mtetra
.648 .764 .933 r
.19895 .45868 .2104 .46902 .22703 .46331 .21565 .45293 Mtetra
.65 .765 .933 r
.21565 .45293 .22703 .46331 .24378 .45746 .23245 .44707 Mtetra
.653 .767 .933 r
.23245 .44707 .24378 .45746 .26064 .4514 .24937 .44104 Mtetra
.66 .771 .932 r
.24937 .44104 .26064 .4514 .27764 .44494 .26642 .43472 Mtetra
.672 .778 .93 r
.26642 .43472 .27764 .44494 .29479 .4378 .28362 .42788 Mtetra
.693 .791 .926 r
.28362 .42788 .29479 .4378 .31211 .42939 .30097 .4201 Mtetra
.729 .813 .917 r
.30097 .4201 .31211 .42939 .32965 .41875 .31853 .41063 Mtetra
.785 .845 .897 r
.31853 .41063 .32965 .41875 .34746 .40425 .33633 .39819 Mtetra
.855 .881 .857 r
.33633 .39819 .34746 .40425 .3656 .38365 .35444 .38082 Mtetra
.922 .908 .791 r
.35444 .38082 .3656 .38365 .38406 .35473 .37289 .35612 Mtetra
.964 .917 .711 r
.37289 .35612 .38406 .35473 .40272 .31725 .39163 .32256 Mtetra
.979 .915 .647 r
.39163 .32256 .40272 .31725 .42131 .27493 .41044 .28173 Mtetra
.979 .917 .623 r
.41044 .28173 .42131 .27493 .43955 .23457 .42904 .23932 Mtetra
.973 .928 .654 r
.42904 .23932 .43955 .23457 .45736 .20157 .44721 .20203 Mtetra
.953 .937 .733 r
.44721 .20203 .45736 .20157 .47484 .17723 .46497 .17329 Mtetra
.903 .92 .821 r
.46497 .17329 .47484 .17723 .49214 .15989 .48247 .15262 Mtetra
.831 .874 .876 r
.48247 .15262 .49214 .15989 .50939 .1472 .49986 .13776 Mtetra
.766 .825 .899 r
.49986 .13776 .50939 .1472 .52669 .13726 .51726 .12653 Mtetra
.721 .79 .906 r
.51726 .12653 .52669 .13726 .54407 .12885 .53472 .11737 Mtetra
.695 .768 .908 r
.53472 .11737 .54407 .12885 .56154 .12125 .55227 .10933 Mtetra
.68 .756 .908 r
.55227 .10933 .56154 .12125 .57913 .11407 .56993 .10188 Mtetra
.672 .749 .908 r
.56993 .10188 .57913 .11407 .59682 .1071 .5877 .09472 Mtetra
.668 .745 .908 r
.5877 .09472 .59682 .1071 .61463 .10021 .60559 .08769 Mtetra
.666 .743 .908 r
.60559 .08769 .61463 .10021 .63256 .09334 .62359 .08072 Mtetra
.665 .742 .908 r
.62359 .08072 .63256 .09334 .6506 .08647 .64171 .07375 Mtetra
.664 .742 .908 r
.64171 .07375 .6506 .08647 .66875 .07957 .65994 .06676 Mtetra
.65994 .06676 .66875 .07957 .68703 .07263 .6783 .05973 Mtetra
.664 .741 .908 r
.6783 .05973 .68703 .07263 .70542 .06566 .69678 .05267 Mtetra
.69678 .05267 .70542 .06566 .72394 .05864 .71537 .04557 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47641 Mtetra
.10523 .47641 .11711 .48658 .13327 .48108 .12145 .47085 Mtetra
.12145 .47085 .13327 .48108 .14953 .47555 .13777 .46525 Mtetra
.646 .763 .934 r
.13777 .46525 .14953 .47555 .1659 .46997 .1542 .45962 Mtetra
.1542 .45962 .1659 .46997 .18237 .46435 .17073 .45393 Mtetra
.647 .763 .934 r
.17073 .45393 .18237 .46435 .19895 .45868 .18737 .4482 Mtetra
.18737 .4482 .19895 .45868 .21565 .45293 .20413 .4424 Mtetra
.649 .764 .933 r
.20413 .4424 .21565 .45293 .23245 .44707 .22099 .43652 Mtetra
.651 .766 .933 r
.22099 .43652 .23245 .44707 .24937 .44104 .23797 .4305 Mtetra
.656 .769 .932 r
.23797 .4305 .24937 .44104 .26642 .43472 .25508 .42425 Mtetra
.665 .774 .931 r
.25508 .42425 .26642 .43472 .28362 .42788 .27232 .41762 Mtetra
.681 .784 .928 r
.27232 .41762 .28362 .42788 .30097 .4201 .28972 .41028 Mtetra
.709 .801 .922 r
.28972 .41028 .30097 .4201 .31853 .41063 .3073 .40168 Mtetra
.755 .828 .909 r
.3073 .40168 .31853 .41063 .33633 .39819 .3251 .39082 Mtetra
.819 .863 .88 r
.3251 .39082 .33633 .39819 .35444 .38082 .34319 .37608 Mtetra
.89 .896 .827 r
.34319 .37608 .35444 .38082 .37289 .35612 .36161 .35519 Mtetra
.947 .915 .751 r
.36161 .35519 .37289 .35612 .39163 .32256 .38037 .32595 Mtetra
.975 .917 .675 r
.38037 .32595 .39163 .32256 .41044 .28173 .39934 .28808 Mtetra
.98 .915 .629 r
.39934 .28808 .41044 .28173 .42904 .23932 .41824 .24537 Mtetra
.977 .921 .632 r
.41824 .24537 .42904 .23932 .44721 .20203 .43679 .20463 Mtetra
.966 .934 .69 r
.43679 .20463 .44721 .20203 .46497 .17329 .45488 .17131 Mtetra
.932 .933 .779 r
.45488 .17131 .46497 .17329 .48247 .15262 .47262 .14669 Mtetra
.868 .899 .853 r
.47262 .14669 .48247 .15262 .49986 .13776 .49018 .12911 Mtetra
.796 .848 .89 r
.49018 .12911 .49986 .13776 .51726 .12653 .5077 .11619 Mtetra
.741 .806 .904 r
.5077 .11619 .51726 .12653 .53472 .11737 .52525 .10604 Mtetra
.706 .778 .907 r
.52525 .10604 .53472 .11737 .55227 .10933 .54289 .09742 Mtetra
.687 .761 .908 r
.54289 .09742 .55227 .10933 .56993 .10188 .56062 .08962 Mtetra
.676 .752 .908 r
.56062 .08962 .56993 .10188 .5877 .09472 .57847 .08224 Mtetra
.67 .747 .908 r
.57847 .08224 .5877 .09472 .60559 .08769 .59643 .07506 Mtetra
.667 .744 .908 r
.59643 .07506 .60559 .08769 .62359 .08072 .61451 .06796 Mtetra
.665 .743 .908 r
.61451 .06796 .62359 .08072 .64171 .07375 .63271 .06088 Mtetra
.664 .742 .908 r
.63271 .06088 .64171 .07375 .65994 .06676 .65103 .0538 Mtetra
.65103 .0538 .65994 .06676 .6783 .05973 .66946 .04668 Mtetra
.66946 .04668 .6783 .05973 .69678 .05267 .68802 .03953 Mtetra
.664 .741 .908 r
.68802 .03953 .69678 .05267 .71537 .04557 .70671 .03234 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47641 .09322 .46612 Mtetra
.09322 .46612 .10523 .47641 .12145 .47085 .10949 .4605 Mtetra
.10949 .4605 .12145 .47085 .13777 .46525 .12587 .45483 Mtetra
.12587 .45483 .13777 .46525 .1542 .45962 .14236 .44913 Mtetra
.646 .763 .934 r
.14236 .44913 .1542 .45962 .17073 .45393 .15895 .44338 Mtetra
.15895 .44338 .17073 .45393 .18737 .4482 .17565 .43759 Mtetra
.647 .763 .934 r
.17565 .43759 .18737 .4482 .20413 .4424 .19247 .43174 Mtetra
.648 .764 .933 r
.19247 .43174 .20413 .4424 .22099 .43652 .20939 .42581 Mtetra
.65 .765 .933 r
.20939 .42581 .22099 .43652 .23797 .4305 .22644 .41978 Mtetra
.653 .767 .933 r
.22644 .41978 .23797 .4305 .25508 .42425 .2436 .41357 Mtetra
.66 .771 .932 r
.2436 .41357 .25508 .42425 .27232 .41762 .2609 .40706 Mtetra
.672 .778 .93 r
.2609 .40706 .27232 .41762 .28972 .41028 .27834 .40004 Mtetra
.693 .791 .926 r
.27834 .40004 .28972 .41028 .3073 .40168 .29596 .39206 Mtetra
.729 .813 .917 r
.29596 .39206 .3073 .40168 .3251 .39082 .31377 .38238 Mtetra
.785 .845 .897 r
.31377 .38238 .3251 .39082 .34319 .37608 .33185 .36971 Mtetra
.855 .881 .857 r
.33185 .36971 .34319 .37608 .36161 .35519 .35024 .35207 Mtetra
.922 .908 .791 r
.35024 .35207 .36161 .35519 .38037 .32595 .36899 .32707 Mtetra
.964 .917 .711 r
.36899 .32707 .38037 .32595 .39934 .28808 .38804 .29314 Mtetra
.979 .915 .647 r
.38804 .29314 .39934 .28808 .41824 .24537 .40718 .25191 Mtetra
.979 .917 .623 r
.40718 .25191 .41824 .24537 .43679 .20463 .42608 .20911 Mtetra
.973 .928 .655 r
.42608 .20911 .43679 .20463 .45488 .17131 .44455 .17147 Mtetra
.953 .937 .734 r
.44455 .17147 .45488 .17131 .47262 .14669 .46259 .14243 Mtetra
.903 .92 .821 r
.46259 .14243 .47262 .14669 .49018 .12911 .48035 .12149 Mtetra
.83 .874 .876 r
.48035 .12149 .49018 .12911 .5077 .11619 .49801 .1064 Mtetra
.766 .825 .899 r
.49801 .1064 .5077 .11619 .52525 .10604 .51567 .09495 Mtetra
.721 .79 .906 r
.51567 .09495 .52525 .10604 .54289 .09742 .53339 .08557 Mtetra
.695 .768 .908 r
.53339 .08557 .54289 .09742 .56062 .08962 .5512 .07733 Mtetra
.68 .756 .908 r
.5512 .07733 .56062 .08962 .57847 .08224 .56913 .06967 Mtetra
.672 .749 .908 r
.56913 .06967 .57847 .08224 .59643 .07506 .58717 .0623 Mtetra
.668 .745 .908 r
.58717 .0623 .59643 .07506 .61451 .06796 .60533 .05506 Mtetra
.666 .743 .908 r
.60533 .05506 .61451 .06796 .63271 .06088 .6236 .04787 Mtetra
.665 .742 .908 r
.6236 .04787 .63271 .06088 .65103 .0538 .642 .04068 Mtetra
.664 .742 .908 r
.642 .04068 .65103 .0538 .66946 .04668 .66052 .03348 Mtetra
.66052 .03348 .66946 .04668 .68802 .03953 .67917 .02623 Mtetra
.664 .741 .908 r
.67917 .02623 .68802 .03953 .70671 .03234 .69793 .01895 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46612 .08106 .45571 Mtetra
.08106 .45571 .09322 .46612 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45483 .11383 .44429 Mtetra
.11383 .44429 .12587 .45483 .14236 .44913 .13038 .43852 Mtetra
.646 .763 .934 r
.13038 .43852 .14236 .44913 .15895 .44338 .14703 .43271 Mtetra
.14703 .43271 .15895 .44338 .17565 .43759 .16379 .42685 Mtetra
.647 .763 .934 r
.16379 .42685 .17565 .43759 .19247 .43174 .18067 .42094 Mtetra
.18067 .42094 .19247 .43174 .20939 .42581 .19766 .41496 Mtetra
.649 .764 .933 r
.19766 .41496 .20939 .42581 .22644 .41978 .21476 .4089 Mtetra
.651 .766 .933 r
.21476 .4089 .22644 .41978 .2436 .41357 .23199 .40269 Mtetra
.656 .769 .932 r
.23199 .40269 .2436 .41357 .2609 .40706 .24934 .39626 Mtetra
.665 .774 .931 r
.24934 .39626 .2609 .40706 .27834 .40004 .26684 .38944 Mtetra
.681 .784 .928 r
.26684 .38944 .27834 .40004 .29596 .39206 .28449 .3819 Mtetra
.709 .801 .922 r
.28449 .3819 .29596 .39206 .31377 .38238 .30233 .37309 Mtetra
.755 .828 .909 r
.30233 .37309 .31377 .38238 .33185 .36971 .32041 .36201 Mtetra
.819 .863 .88 r
.32041 .36201 .33185 .36971 .35024 .35207 .33878 .34702 Mtetra
.89 .897 .827 r
.33878 .34702 .35024 .35207 .36899 .32707 .3575 .32584 Mtetra
.947 .915 .751 r
.3575 .32584 .36899 .32707 .38804 .29314 .37657 .29626 Mtetra
.975 .917 .675 r
.37657 .29626 .38804 .29314 .40718 .25191 .39586 .25801 Mtetra
.98 .915 .629 r
.39586 .25801 .40718 .25191 .42608 .20911 .41509 .21489 Mtetra
.977 .921 .632 r
.41509 .21489 .42608 .20911 .44455 .17147 .43394 .17378 Mtetra
.966 .934 .69 r
.43394 .17378 .44455 .17147 .46259 .14243 .45233 .14013 Mtetra
.932 .933 .779 r
.45233 .14013 .46259 .14243 .48035 .12149 .47035 .11522 Mtetra
.867 .899 .853 r
.47035 .11522 .48035 .12149 .49801 .1064 .48817 .09739 Mtetra
.796 .848 .89 r
.48817 .09739 .49801 .1064 .51567 .09495 .50595 .08424 Mtetra
.741 .806 .904 r
.50595 .08424 .51567 .09495 .53339 .08557 .52377 .07387 Mtetra
.706 .778 .907 r
.52377 .07387 .53339 .08557 .5512 .07733 .54167 .06504 Mtetra
.687 .761 .908 r
.54167 .06504 .5512 .07733 .56913 .06967 .55967 .05702 Mtetra
.676 .752 .908 r
.55967 .05702 .56913 .06967 .58717 .0623 .57779 .04942 Mtetra
.67 .747 .908 r
.57779 .04942 .58717 .0623 .60533 .05506 .59603 .04203 Mtetra
.667 .744 .908 r
.59603 .04203 .60533 .05506 .6236 .04787 .61439 .03471 Mtetra
.665 .743 .908 r
.61439 .03471 .6236 .04787 .642 .04068 .63287 .02742 Mtetra
.664 .742 .908 r
.63287 .02742 .642 .04068 .66052 .03348 .65147 .02011 Mtetra
.65147 .02011 .66052 .03348 .67917 .02623 .6702 .01277 Mtetra
.6702 .01277 .67917 .02623 .69793 .01895 .68905 .0054 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooe;lD]`0
07oo0000Egoo003EOol30003Ool00e;lD]aBo002D_`01000D_aoo`00EWoo003BOol30004Ool02e;L
E_aBg5;lD]aFo5;L001Bg5Kl0000EWoo003@Ool20003Ool00e;lD]aBo002D_`02e;LD_aBo5;lD]aB
o000D_aBg5;l0000EGoo003=Ool30003Ool04e;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;l
D]aoo`0005Aoo`00bgoo0P000goo00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01P00D_aB
o5;lD]`005Aoo`00b7oo0`0001aoo`00OomFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo000E_aBg5;lOol005=oo`00Igoo0P000Woo0P00FGoo0P000goo00=Bo000D_`015;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`00goo001oo`1AOol006Qoo`04001o
ogoo001GOol30003Ool07e;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aoo`00059oo`00JGoo0P00EWoo0P000Woo3e;l00EBg5;lD_aBo5;L00=Bo006
D]aBo5;lD_aBg0000U;l00EBg5;lD_aoo`00055oo`00JGoo0P00Dgoo0`000Woo02ABo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;L
E_`2Ool00`00Oomoo`1>Ool006Qoo`04001oogoo001@Ool20002Ool00e;lE_aBo002D_`00eKlD_aB
o006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`015;LD_ao
o`00D7oo001WOol20002Ool2001<Ool30002Ool0;EKlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlOol0
001?Ool00;Ioo`<0009oo`03001Bo5Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`00e;L0000001?Ool00;Aoo`80
00Aoo`0bEaaFo5KlD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LOol004ioo`00/Goo0`0017oo
1UKl00ABo5KlE_aFo0=Bo005E_aBo5;lD_aFo008D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
009Bo003001Bg5;l009Bo007D]aBo5;lD_aBg7oo0000CGoo002_Ool20005Ool0=eLLD_aG75KlEaaB
o5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aoo`00015oo`D003Moo`00[7oo0`001Goo
00=G75/LEa`01eKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00IB
g5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00=oo`00Ool03goo00D007ooOomoo`0003Moo`00
ZWoo0P001Goo00IFo5/LEaaK75KlFa`2Ea`0=U;lEaaFo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lOol0011oo`03001oogoo03Qoo`00Ygoo0`000Woo00@007ooOomoo`9O?007EaaK
75LLFaaG75/LEa`01eKl00IBo5KlD_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`00`00Oomoo`05Ool60004Ool00`00Oomoo`0g
Ool00:Eoo`8000Moo`0;GcaK6ellFaaO?5KlFaaG75/LE_aK7002E_`0=E;lEaaBo5KlD_aFo5;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`0
05;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo00004Goo00<007ooOol0=Woo002ROol30007Ool01E/l
GcaO?5llFc`00ell00IFo5LLE_aG75KlEa`6E_`3D_`01EKlD_aBo5;lE_`025;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo
011oo`03001oogoo03Eoo`00MGoo10009goo0P002Goo04ISFfMLFa]O?5/LGcaK6ellFaaK?5KlFaaF
o5LLE_aK75;lE_aBo5KlD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`000eoo`05
001oogooOol0000gOol007Aoo`03001oogoo009oo`03001oogoo025oo`<000Yoo`=SF`04IeaK?5ll
Gc`4Fa`01ELLE_aG75KlEa`015Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000=Ool3
000hOol007Aoo`03001oogoo009oo`03001oogoo01ioo`<000]oo`1;IgaSFfMLHe]WO6=KIeaK6e/l
FaaK?5/KFcaK75LLE_aK75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aoo`0004Moo`00M7oo00<007ooOol00Woo00<007ooOol077oo0P000Woo00<007ooOol0
27oo00EWG6=KHe]SFfML009SF`03GcaSG5/L00EK70YFo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`0
1E;LD_aBo5;lD]`00e;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]ao
o`0004Moo`00M7oo00<007ooOol00Woo00<007ooOol06Goo0`003Woo00e_Vf]jIeaSFfMlHe]SG5lk
HeaO>e/lFa]K?002Fa`0?eKlFaaFo5LLD_aG75KlEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LOol00016Ool007Aoo`03001oogoo009oo`03001oogoo01Moo`80011o
o`03KiY[VVnJ009_VP0>GcaS?5llHeaO?6<lGcaK75LLFaaG75/LEaaK70QFo006D_aFo5;lE_aBo5Kl
35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo09oo`03001oogoo04=oo`00M7oo00<007ooOol00Woo00<007ooOol057oo0`004Goo00e_
Vf]jKi][NVnKIg][NelkHeaO>f=LGc]O?002Fa`0@UKlFaaG75/LE_aK75;lE_aBo5LLD_aFo5;lE_aB
o5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol004Eoo`00MGoo10005Goo0P00
4goo00=_VV^JKiX00VnJ00IWNf]kIg]SG5llHc`2Gc`01U/lGcaO?5/LEaaK709G7003E_aG75Kl00EF
o004D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003
D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo0014Ool008]oo`<001Aoo`1EKi][NVnKJgY[NfMk
Jg]WFf]kIg]O?5/KGcaK75llFa]O?5/LEaaFo5/LE_aG75KlFaaBo5KlD_aG75;lE_aBg5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0000@goo0029Ool20002Ool00`00Oomo
o`0AOol2MkP2KiX01V]kIg][NfMkJg]WN`9SF`03GcaK?5ll009O?008FcaK75/LEaaFo5LLE_aG70QF
o0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo0000@goo0026Ool3000HOol06W>HMkQcUf]kIg][
NfMKJg]WNfMLHe]WO6=KGcaK6ellFaaK?5/KFcaK75LLE_aK75KlEa`2E_`0>e;lE_aBo5KlD_aFo5;L
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo0000@Woo0024Ool2000JOol3
MkP01G>iLiU[NfMkJg/00f=K00AWG6=KHe]SF`MK7004E_aG75KlEa`6E_`015;lE_aFo5Kl0e;l00=F
o5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`10Ool0085oo`<001]oo`1JLiQg^7>G
LkYcVG>jKiUc^V=KIeaSFfMlHe]WG6=KHeaO>e/lFa]K?5/LFcaK6e/lE_aG75;lEaaFo5LLD_aFo5;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`00@Goo001n
Ool3000MOol4MkP3LiT01G>iKiY_VV=KIe`00V=K00EO?6=LGcaS?5ll00EK7003EaaK75Kl00EFo008
D_aFo5;lE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo0010Ool007ao
o`80021oo`1MMkQcUgNhLiUc^VnILkY[NVnKJgY_Vf]jHeaO>f=LGc]SG5lkHeaO>e/LE_aK75LLFaaF
o5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aoo`0003moo`00NGoo0`000Woo0P007Goo0gNh0g>I00=c^FnJKiX00fnJ00M[NfMk
HeaO?6<lGcaSG003Gc`01U/LEaaK75LLFaaG70MFo004D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo003D]aoo`0003moo`00Mgoo0P008goo061k]GNENkEcVG>jKiUc^V]jKi][NVnKJgY[NfMKJg]W
Nf=LGc]SG5/LGcaK6ellEaaK75KlFaaFo5LLE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000nOol007Aoo`<002Eoo`9k]@=g
]P03NkM_VVnJ00=_VP08Jg]WNf]kIg][NfMkGcaK?0=O?008FcaO?5KlEaaFo5LLE_aG70QFo0=Bo003
E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo00000=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lD_aBo09oo`03001oogoo03]oo`00LWoo
0P009goo021gUG^eNkEk]gNFNkMcV7NhJgY_Vf]jJg]WFf]kIg][NfMKIgaSFellFa]O?5/LGcaK6e/l
E_aG75KlFaaFo5LL0UKl041Bo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lOol003eoo`00Kgoo0`00:Goo0W^e0WNf00=k]gNfMkP00gNh00U[
NfMkJg]WNf]kIg]WG6=KHe`00Ull00=K?5/LFa`00e/L00AFo5LLE_aG70IFo004D_aFo5KlE_`3D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l009oo`03001oogoo03Yoo`00KGoo
0P0000=oo`00Ool0:7oo0g^e05mgUW^gMkIg^7>GMkQcV7>jKiU[NfMkJg]SFfMlHe]WG6=KIgaK75/l
Fa]K?5/LFcaK6e/lE_aG75;lEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03001oogoo03Uoo`00JWoo0`00;7oo0g^e
00=g]W^gMkH017Nh0W>I00]c^G>ILiUSFfMLHe]SG6=KIeaO?6<l00IK7003EaaK75Kl00EFo008D_aF
o5KlE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`00
03]oo`00Igoo0`00;goo0W^e029gUW^gMkIg^7>GMkQcV7>jKiUc^W>ILkY[NVnKHe]WG6=KHeaO>f=L
Gc]SG5/LFcaK6e/LEaaK75KlFaaFo5LLD_aG709Fo011D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000jOol006Eoo`80035oo`=k
]@03NkMg]WNf00=g^09cV@03LkUcVG>I00E_VP0>HeaO?6<lGcaSG5llHcaG75/LEaaK75LLFaaG70MF
o006D_aFo5;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00Oomoo`0h
Ool0069oo`<003=oo`1YNkEgUG^gMkIk]g>GMkQcV7>jKiUc^W>ILkY[NVnKJgY_Vf]jJg]WNf=LGc]S
G5lkHeaK6ellEaaK75KlFaaG75/LE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg00003Uoo`00H7oo0P00=Goo
0W^C00=k/g^DNk@00g^e0WNf00=c^G>ILiT01FnJ00E[NfMkJg]O?6=L00AO?008FcaO?5LLFaaG75/L
E_aG70QFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;l
D_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
15;LD_aoo`00>7oo001MOol300000goo001oo`0dOol01G^COkAkU7^dNi<00g^e06=gUW^gMkIk]f]j
Ki][NVnKIe][NfMkJg]WFf]kFaaO?5/KGcaK75llFa]O?5KlEaaFo5/LE_aG75;lEaaBo5KlD_aFo5;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5Kl0000>7oo001KOol2000iOol00g^CNk=kT`02Nk@3NkD017NfNkMg]WNf17Nh00QWNf]kIg][
NfMkJg]SFf=L0Ull00=K?5llGc`00e/L00MFo5LLE_aG75KlEaaBo003E_`015;lE_aFo5Kl0e;l00=F
o5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000=goo000^
Ool4000VOol3000kOol01GndNi=k]7^COk@00W^e06MgUG^gMkIk]g>GMkQcV7NhKiUc^VMkJg]WFfMl
He]WG6=KIgaSFe/lFa]K?5/LFcaK6e/LE_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000R
Ool3000AOol002eoo`03001oogoo009oo`03001oogoo025oo`8003eoo`03Nk=kTg^C009k]0=k]@04
NkMg]WNfMkH3MkP03G>ILkUcVG>IHe]WG6=KHeaSFfMLHe]S?5ll00IK70MFo008D_aFo5KlE_aBo5Kl
D_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool0
07oo02=oo`03001oogoo00moo`00<Woo00<007ooOol07Goo1000?goo071kTgncNi=o]7^DNkEgUG^e
MkIk]gNFMkQcV7NhLiMc^W>ILkY[NVnKHe]WG6=KIgaO>f=LGc]SG5/LFcaK6e/lEaaK75KlEaaFo5LL
D_aG75KlEaaBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol002=oo`03001oogoo00moo`009Goo1P001goo00<007oo
Ool077oo0`00@7oo0g^C00=k]7^DNkD00W^e0gNf17Nh00=c^G>ILiT01FnJ00iSG5llHcaO?6=LGcaS
?5LLFaaG75/LEaaK75LL1eKl00IBo5KlD_aFo5;lE_`>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo006D]aBo5;lD_aoo`008Goo00<007oo000047oo000^Ool4000LOol30013Ool01WncNi=o
]7^DNkAgU@9k]@1ZNkMgUWNhLiQg^7>GLkYcVG>jKiU_Vf]jKi][NV]kIg]SG5lkHeaO>f=LFa]O?5LL
FaaFo5/LEaaK75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000QOol00`00Ool0000@Ool0
02ioo`03001oogoo01Yoo`<004Eoo`9kT`03Nk=kU7^d00=k]@=k]0=k]@04LkUcVG>ILiT4KiX01F]k
Ig][NfMkHe`015ll00QK?5llEaaK75LLFaaFo5LL25Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`2000OOol01@00Oomoogoo0000
3goo000^Ool00`00Oomoo`0HOol20018Ool02W^COkAkU7^dNi9o]7^COk=kTgnd0W^e06UgUG^gMkIk
]gNfKi][NVnKJgY[NfMkJg]WFf]kIg]O?5/KGcaK75llFa]O?5KlEaaFo5/LE_aG75;lEaaBo5KlD_aF
o5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg7oo00007Woo00D007ooOomoo`0000moo`00;Woo1@004goo0`00BGoo
00=kTg^cNi<00W^C00=k/g^CNi<00W^d00AkU7^eNkEk]@=g]P9g^09_VP0:Jg]WNf]kIg][NfMkHeaS
FellFc`3Gc`2Fa`01eKlEaaFo5LLE_aG75;l00=Fo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo000MOol3000017oo
000000003Woo0014Ool2001<Ool0MgndNi=o/g^BOk=kTgncNi=o]7^DNkEgUG^eMkIk]gNfNkMcV7Nh
LiM[NfMkJg]WFf]kHe]WG6=KIgaK75llFa]K?5/LFcaK6e/lE_aG75KlEaaFo5LLD_aFo5;lE_aBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo7oo00002Goo100097oo0011Ool300000goo001oo`1;Ool7Ni<00g^dNiAk
]003NkD2MkH01G^gMkQg^7NhLkT00g>I00MWG6=KHeaSFfMLHe]SG008Fa`6E_`025;lE_aFo5KlD_aF
o5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;L
D_aBo5;lD]aBo7oo0007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003moo`80051oo`0;Ni=o/g^C
Ok=kTgncNi=o]7^DNkAgU@02NkD05g^gMkIk]g>HMkQcUg>jLiUc^VnIKi][NVMLHe]WO6=KIeaO>f=L
FaaK?5/KFc`00U/L05=Fo5/LE_aG75;lEaaFo5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00
00Moo`03001oogoo009oo`03001oogoo025oo`00?7oo0`00DWoo1W^C00Ak/g^DNkAk]09k]@9g]P05
NkMg^7NhMkQc^@03LiT4KiX03VMLHe]S?5llHeaO?6<lGcaK75LLFaaG75/LEa`7E_`025;lE_aBo5Kl
D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01e;LD_aBo5;lD]ao
o`0000Ioo`03001oogoo009oo`03001oogoo025oo`00>Woo0P00E7oo00Yo/g^COkAkTgncNi=o]7^C
NkAkT`=k]@0FMkIk]gNfMkQcUg>jLiUc^VnIKi][NVnKJgY_Vf]jHeaO>f=LGc]SG5lkGc`2Fa`0E5Kl
FaaG75/LE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo09oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo025oo`00=goo0`00EWoo1G^C00=k/g^CNk@00W^d0W^e00=g]W^g
MkH00WNh00Ac^G>ILiUcV@I_VP05Jg]WNf=LGcaS?002Gc`025/lGcaG75/LEaaK75KlEa`8E_`3D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo009D]aBo5;lD_aBg5;l001B
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`00goo001oo`04Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003Eoo`800003Ool0
07oo05Eoo`1kNi=o]7^COk=kTWndNi=o/g^COkAkTgncNi=o]7^DNkEgUG^gMkIk]gNfKi][NVnKJgY_
Vf]jJg]WFf]kIg]O?5/KGcaK75llFa]O?5KlEaaFo5/LE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`0
05;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo025oo`00<Woo
0`00FWoo37^C00=k]7^DNk@00W^e0gNf0WNh0fnJ00UWNf]kIg][NfMkHeaSFellFc`00ell0U/L00IF
o5LLE_aG75KlEa`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l00<000Aoo`@002Aoo`00;goo0`00
G7oo081o]7^COk=kTWncNi=o/g^COk=kTgncNi=o]7^DNkAgUG^eMkIk]gNfNkMc^7NhLiMg^6MkJg]W
Ff]kHe]WG6=KIgaSFellFa]K?5/LFcaK6e/lE_aG75KlFaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001B
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aoo`00;7oo000]Ool2001OOol;Ni<017^cNiAk]7^d0W^e0WNf00=k]gNh
MkP00WNh0g>I00QWG6=KHeaSFfMLHe]SG6=K1e/L1UKl00QBo5KlE_aFo5;lE_aBo5Kl0e;l00=Fo5;l
D_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L000005;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo7ooOol0000[Ool002Yoo`<0061oo`0?Ni=o/g^COk=kTgndNi=o]7^COk=kTgndNi=k]7^C009k
]@0GNkMg]W^gLkQg^7>GMkQcVG>jKiU_Vf]jIeaSFfMlHe]WG6=KHeaO>e/lFa]K?002Fa`0:EKlFaaF
o5LLD_aG75KlEaaBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]`00`0002YBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`2Ool00`00Oomoo`0X
Ool002Qoo`800003Ool007oo061oo`AkT`03NiAkTg^C00=kT`03Nk=kTg^d009k]004NkEg]WNfNkL4
MkP3LiT4KiX03VMLHe]SG5llHeaO?6<lGcaK75LLFaaG75/LEa`7E_`01U;lE_aBo5KlD_aFo0iBo005
D]aBo5;lD_aBg003D_`01E;L00000000D]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`00
:Woo000VOol2001TOol03gncNi=o]G^DOkAkTgndNi=o/g^BOkAkTgncNi=o]002NkD05WNfNkMg]WNh
LiMg^7>ILkY_VG>jJgY_Vf]jKi][NV=LGc]SG5lkHeaO>ell0U/L02IFo5/LEaaK75KlEaaBo5KlD_aG
75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl0P00
035Bg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0WOol002Io
o`8006Aoo`03NiAkUG^D009kU0MkT`9k]005NiAk]GNfNkMg]P03MkP3LiT00g>iKiY_VP03KiX01F]k
Ig]SG5llHc`00Ull00QK?5llGcaK75LLFaaFo5LL25Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L
00=Bo003D]aBo000008000=Bo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]ao
ogoo000XOol002Ioo`<006=oo`19OkEkU7^eNi=o]7^COk=kTWncNi=o/g^COkAkU7ncNi=o]7^DNkEg
UG^eMkIk]gNfNkM[NVnKJgY_Vf]jJg]WFf]kIg][Ne/KGcaK75llFa]O?5/LEaaFo5/LE_aG75KlEaaB
o5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`00`0003YFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol002Qoo`009Woo00@0
07ooOol0065oo`03NiEkU7^E009kU0MkT`07NkAkU7^CNi=k]7^DNk@00g^e0WNf00=k]gNhMkP00VnJ
00UWNf]kIg][NfMkJg]SFfMLFc`00ell0e/L00EG75KlEaaFo5LL00AFo004D_aFo5KlE_`3D_`00eKl
D_aBo006D_`00e;LD_`000020003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005001B
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l0Woo00<007ooOol09Goo000UOol00`00Oomoo`02Ool00`00Oomoo`1NOol0
4g^DNkEkU7ndNi=o/g^COk=kTgncNi=o]7^COk=kTgndNiAk]7NE009k]@0_NkMg]W^gMkIg^7>GMkQW
Nf]kIe][NfMkIeaSFfMlHe]WG5/KFcaK75/lFa]K?5KlEaaFo5/LE_aG75;lE_aBo5KlD_aFo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo0030000@EKlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo00009goo000UOol00`00Oomoo`03Ool00`00
Oomoo`1LOol017^DNiEkU7^D2g^C00Ak/g^DNkAk]0=k]@03MkIk]gNf00=g^0=cV@09LkUSFf=LHe]W
G6=KHeaO?6=L00IK70IFo008D_aFo5KlE_aBo5KlD_aFo0=Bo003E_aBo5;l00<000=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00=oo`00Ool09Goo000UOol00`00Oomoo`04Ool00`00Oomoo`1KOol04W^eNiAo]G^COkAkTgndNi=o
/g^COkAkTgncNi9o]7^CNkAkT`=k]@0FMkIk]gNfMkQcUgNhLiUc^VnILkY[NVnKHe]WO6=KHeaO>f=L
Gc]SG5/KFc`2Fa`04UKlFaaFo5LLD_aG75KlEaaBg5KlD_aFo5;LE_aBg5KlD]aFo0<00016E_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]`2Ool00`00Oomoo`0SOol002Eoo`8000Ioo`8005Yoo`05NiEkU7^ENi=kU003
Ni<2Ni@6Ni<3Nk@2NkD00gNfNkMg]P04MkP2LiT00g>iKiY_VP02KiX03UllHcaO?6=LGcaS?5llHeaG
75/LEaaK75LLFa`6E_`01e;lE_aBo5KlD_aFo5;l008000]Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo00009Goo000U
Ool00`00Oomoo`07Ool00`00Oomoo`1GOol04W^DOkEkU7ndNi=o]7^DNkEkTgndNi=o/g^BOk=kTgnc
Ni=o]09k]@0WMiEk]gNfNkMcUgNhLkQc^VnILkY[NVnKJgY_VfMkJg]O>f=LGc]SG5lkHeaK75llE_aK
75LLFaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;l00<0001?D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg7oo000097oo000UOol00`00Oomoo`08Ool00`00Oomoo`1EOol00g^DNiEkU002Ni@00g^E
NiAkU@02Ni@6Ni<2Nk@017^DNkEk]G^g0WNf0gNh0W>I00=c^FnJKiX00VnJ00IWNf]kIg][NellHc`2
Gc`01U/lGcaO?5/LEaaK709G7003E_aG75Kl00AFo0<00003D_aFo5;l00MBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lOomoo`0002=oo`009Goo00<007ooOol02Goo00<007ooOol0E7oo01Qo]G^DNkEk
Tg^fNiAk]G^DOkAkTgncNi=o/g^COk=kTgndNiAo/g^COkAkU7^dMiD2NkD077^gMkIk]f]jKi][NVnK
Ig][NfMKJg]WNf]kFa]O?5/LGcaK6ellFaaG75KlFaaFo5LLE_aG75;l0`0005IBo5KlD]aFo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`008goo000TOol2000<Ool00`00Oomo
o`1BOol00g^ENiAkU@02NiH017^DNiEkU7^D1g^C00Ik]7^DNi=kTg^cNi@2Nk@3NkD00gNfNkMg^003
MkP02FMkJg]WNf]kIg][Nf=KIeaK?003Gc`3Fa`015LLE_aG75Kl0`000UKl00ABo5KlE_aFo0=Bo003
E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo009
D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`008Woo000TOol00`00Oomoo`0<Ool00`00
Oomoo`1@Ool067^gMiMk]gNENkIgUG^eNiAo]G^COkAkTgndNi=o/g^BOkAkTgncNi=o]7^CNkAkT`=k
]@0GMkIk]gNfMkQcUgNhLiUc^VMKJg]WNfMLHe]WO6=KIeaK6e/lFaaK?5/KFcaK70030000FeKlEaaB
o5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L009o
o`03001oogoo01moo`0097oo00<007ooOol03Goo00<007ooOol0Cgoo0gNG0W^F00EkUG^DNiEkTg^D
00EkT`06Nk=kTg^CNi=k/g^C0g^d0g^e00=k]gNfMkP00WNh0g>I00Uc^F=KHeaSFfMLHe]SG5llHe`0
0e/L0`0000=G75KlE_`01EKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00=Bg7oo00008Goo000TOol00`00Oomoo`0>Ool00`00Oomoo`1=Ool067NGNkMgUg^fMiEk]W^D
OkEkU7ndNi=o]7^COk=kTWncNi=o/g^BOkAkTgncNi=o]09k]@0DMiEk]gNfNkMcUgNhLkQc^VnILkY[
NVnKHe]WO6=KHeaO>f=LGc]SG0800004EaaK75KlFa`2Ea`0Ge;lEaaBo5KlD_aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000087oo000TOol00`00
Oomoo`0?Ool00`00Oomoo`1;Ool4MiL2NiH00g^DNiEkU002Ni@4Ni<00g^DNi=kT`04Ni<2Nk@017^D
NkEk]G^g0WNf0gNh0W>I00=c^FnJKiX00fnJ00=S?5llHe`00`0000QO?5/lFaaG75/LEaaK75LL1eKl
00ABo5KlD_aFo0YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03001oogoo01eoo`0097oo0P00
4Goo00<007ooOol0BWoo02Uk]gNGNkMgUG^fMiEo]G^DNkEkTgndNi=o/g^COkAkTgncNi9o/g^COk=k
TgndNiAk]GNENkEg]W^gMkIg^7>hLkY_VG>jJgY_Vf]jKi][NV]k00<0000;HeaK6ellFaaO?5KlFaaG
75/LE_aK7002E_`0GU;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`0
05;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aoo`007goo000SOol00`00Oomoo`0BOol00`00Oomoo`18Ool4MiL2NiH0
0g^ENiAkU@03Ni@2NiD00g^DNi=kU005Ni<00g^dNiAk]002NkD3MkH2MkP2LiT00g>iKiY_VP02KiX3
00000f]kIg]O?002Gc`02U/lGcaO?5llE_aG75KlEaaFo5LL1UKl0e;l00=Fo5;lD_`01U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006
D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aoo`007Woo000JOol40005Ool00`00Oomoo`0COol0
0`00Oomoo`16Ool07W^gMiMk]gNGNkIgUG^fNiAk]G^DOkAgUG^eNiAo]7^COkAkTgndNi=o/g^COkAk
U7^dNi=o]7^CNkAkT`=k]@04MkIk]g>hMkP30000L6]kIe][NfMkIeaSFellFaaO?5/KFcaK75/lE_aK
75KlEaaFo5/LD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001F
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L0Woo00<007ooOol06goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0DOol00`00Oomoo`15Ool4MiL2NiH00g^DNiEkU002NiH3NiD00g^CNiAkU004Ni<01W^c
NiAk]7^CNk=kT`=k]09k]@03MkIk]`000080000;MkQWNf]kIg][Nf=KHeaSFfMLHe]SG006Fa`00eKl
EaaFo005E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aoo`0001eoo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol05Goo00<007oo
Ool0@goo01igUg^gMiMk]gNENkIgUG^gMiMk]gNENkIkU7neNi=o]7^COkAkTgncNi9o]7^COk=kTWnd
Ni=o/g^COk@2NkD30000NWNhLiMg^7>ILkY_VG>jHe]WG6=KIgaSFfMLGc]SG5/LFcaK75/lFaaK?5;l
EaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg7oo000LOol001Uoo`03001oogoo009oo`03001oogoo009oo`8001Moo`80
049oo`07KiUcVVmiKiUcV7NHLiP00gNG0W^F0W^E17^D0g^C00=k/g^CNi<017^C0W^d00EkU000001k
]gNf00=g^0=cV@0:LkU_VVnJHe]WG6=KHcaO?6=LGc`5Fa`00eLLFaaFo005E_`01U;lE_aBo5KlD_aF
o0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000KOol001Uoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo01Qoo`03001oogoo03ioo`0MKgUcVVmiLiYcV7NILiQgVGNGNkMg
Ug^fMiEo]G^DOkAkTgndNi=o/g^BOk=kTgncNi9o/g^COk=kT`030000P7NENkEg]WNhLiMg^7>hLkY_
VG>jJgY_Vf]jKi]O>f=LGc]SG5lkHeaO>e/LEaaK75KlFaaG75/LD_aG75;lE_aBo5LLD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L000K
Ool001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo03eoo`07LiY_
NFnILiQgV7>HMiP00gNG0W^F00=kUG^DNiD00W^D2G^C0`0000AkU7^dNkEk]@9g]P=g^09cV@03LkU_
VVnJ009_VP06Ig][NellHeaO?6<l0Ull00AK?5/LEaaK709G7003E_aG75Kl00EFo003D_aFo5;l00]B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000JOol001Uoo`03001o
ogoo009oo`05001oogooOol0000MOol00`00Oomoo`0kOol067>JKgUcVVmiMiUcV7NILiQk]gNGNkMg
UG^fNiAk]G^COkAkTgncNi=o]7^COk=kT`<00005Ni=o]7^DNkAgU@02NkD06g^gLiMg^7>hLkY_VG>j
JgY_Vf]jKi]WNf]kIe][NfMkGcaK6ellFaaO?5/KGcaFo5LLE_aK7002E_`0I5;lEaaBo5KlD_aFo5;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aoo`001goo1@003Goo000JOol40004Ool2000MOol00`00Oomoo`0iOol027>JKgU_VFnIMiQcV7NH
LiP3MiL2NiH02G^DNiEkUG^DNi=kU7^CNiEkT`030003Ni<017^cNiAk]7^d0W^e00Ak]7^eNkEk]@9g
]P03NkM_VVnJ009_VP09Ig][NfMkJg]WNf=LHe]O?5/l00=O?09K7004E_aG75KlEa`2E_`015;lE_aF
o5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo
00001goo00D007ooOomoo`0000eoo`008Woo00<007ooOol07Goo00<007ooOol0=goo01AcVVmiLiY_
NGNILiQgVG>HNkMgUg^gMiMk]WNENkEkU7ndNi=o]7^D0`0000ekTgndNi=o/g^COkAkTg^dNi=o]7^C
Ok=kT`03NkD057NfNkMc^7NhLiMg^6MkJg]WFf]kHe]WG6=KIgaK75llFa]K?5/LFc`2Fa`015KlEaaB
o5LL0UKl06=Bo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol03Woo000ROol00`00Oomoo`0NOol0
0`00Oomoo`0eOol02FMkIe]WNfMKMiQcV7NHLiQgV003MiL2NiH3NiD017^F000000000g^D17^C00=k
/g^CNi<017^C00Mk]7^eNkEk]GNfNkMg]P03MkP3LiT01fMLHe]SG6=KIeaSFf=L00MK70MFo004D_aF
o5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03001o
ogoo00Eoo`03001oogoo00eoo`008Woo00<007ooOol07goo00<007ooOol0<goo015[O6MKIg]WFfnK
JgY_Nf]jKi]gUg^gMiMk]gNENkIgUg^g0080000BMiEo]G^DOkAkTgndNi=o/g^BOkAkTgncNi9o/g^C
Ok=kTgnd0W^e01igUG^gMkIg^7>GMkQcVG>jKiU_Vf]jIeaSFfMlHe]SG5lkHeaK75/lFaaK?5LLFaaF
o5LLE_aG75;lEa`2E_`0HU;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0008Ool00`00Oomoo`0<Ool0029oo`03001oogoo
021oo`03001oogoo031oo`06Ie]WNfMKIg]WFf]k0f]j00M[NfmiKiU_VG>JLiQgV0030003NiH017^D
NiEkU7^D2g^C00Ik]7^eNkEk]G^gMkH3MkP3LiT5KiX03EllHcaO?6=LGcaS?5llFaaG75/LEaaK75LL
00MFo004D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0Woo
00<007ooOol01Woo00<007ooOol02goo000QOol2000SOol00`00Oomoo`0^Ool03VMKJgaWFfMkIe]_
Vf]jKg][NVnKKgUcVVmiLiX30000;G^gMiMk]gNENkIkU7^eNi=o]7^COk=kTWncNi=o/g^COk=kTgnc
Ni=o]7^DNkEgUG^gMkIk]g>GMkQcVG>jKiUc^V]jKi][NVnKIg][NelkHeaO>f=LFa]O?002Fa`0JeKl
FaaFo5LLE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`00Woo00D007ooOomoo`0000=oo`03001oogoo
00]oo`008Goo00<007ooOol08goo00<007ooOol0;7oo00IO?5mLIe]WNfMKJg/3JgX00f]kKgU_V@03
00000gNHLiQgU`02MiL3NiH2NiD01G^DNi=kTg^CNi@01g^C00=k/g^DNkD00W^e0WNf0WNh0g>I00=c
^FnJKiX00VnJ00EWNf]kIg][Ne/l00=O?008FcaO?5llEaaFo5LLE_aG70AFo004D_aFo5KlE_`3D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l
008000Aoo`<000ioo`008Goo00<007ooOol097oo00<007ooOol0:Goo00]OG5llHeaO?5mLGca_Vf]j
Kg][NVnK00<0000PLiY_NGNILiQgVGNGNkMgUg^fMiEk]G^DOkAkTgncNi=o]G^COkAkTgndNi=o/g^C
OkAkTg^dMiEk]G^DNkAgU@9k]@0INkMg]W^gJgY_Vf]jJg]WNf]kIe][Nf=KIeaK6ellFaaO?5/LFcaK
75LLE_aK75KlEa`00UKl06MBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000DOol0025oo`03001oogoo
02Eoo`03001oogoo02Ioo`=O?007GeaO?5llGcaSG6=KJgX00`000VnI00EcVVmiMiQcV7NH00=gU`=k
UP9kU@06Ni=kU7^ENiEkTg^D1G^C00Ik/g^CNkAkTg^cNi<2Nk@2NkD2MkH03W^gMkQg^7NhJg]WNf]k
Ig]WG6=KHeaSFfMLHe/5Fa`015KlEaaFo5LL1UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo00004goo000QOol00`00
Oomoo`0VOol00`00Oomoo`0TOol025LLFceO?6=LGcaOG5llHe`3000096=LKgUcVVmiLiY_NGNILiQg
VGNGNkMgUg^gMiEk]W^DOkEkTgndMiEo]G^DOkAkTgndNi=o/g^BOkAkTgncNi9o]7^CNkAkT`=k]@24
MkIk]g>hMkQcUg>jLiUc^VnIIgaSFfMLHe]WO6=KHeaO>e/lFaaK?5/LFcaFo5LLD_aG75KlEaaBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aoo`004goo000QOol2000XOol2000ROol01E/mEaaK?E/lFcd00Ull
00=SG00000000f=L00UWFfMkIe]cVVmiKiUcV7NHLiP00gNG0g^F00EkUG^DNiIkUW^E00AkU0MkT`03
Nk=kTg^C009k]09k]@03MkIk]gNf009g^004LkUcVG>iLiT2KiX01f=LHe]WG5llHcaO?6=L00AK7003
EaaK75Kl00EFo008D_aFo5;lE_aBo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`015;LD_aoo`004Woo000QOol00`00Oomoo`0YOol00`00Oomoo`0MOol01eLLFceG
75/mEaaK?ELL00<0000XHe]SG6=KHeaWFfMkIe][O6MKIg]cV7NILiQk]gNGNkMgUg^fMiEk]gNGNkIg
UG^fNiAk]G^COkAkTgncNi9o/g^COk=kTgncNi=o/g^COk@2NkD0QgNENkMg]WNhLiMg^7>ILkY_VFnK
JgY_Vf]jHeaO>f=LGc]SG5lkHeaFo5/LEaaK75KlFaaG75KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_`0000BOol0021oo`03001oogoo02]oo`03001oogoo01Yoo`=G7@03EaaK?E/l00<0009K
?00=He]SG6=LIg]WFfMkIe]WNfMKIg][NV]kJgX00VnI00AcVVmiMiQcV0=gU`9kUP04NiAkUG^ENi@;
Ni<01W^dNiAk]G^eNkMg]P=g^003LiUc^G>I00A_VP05Jg]WNf<lGcaSG004Gc`01ULLFaaG75/LE_aG
70IFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00=Bg7oo00004Goo000POol00`00Oomoo`0/Ool00`00Oomoo`0FOol01ULM
DaaG7E<LEaeC70<0002iEaaO?E/lGceK?5lmFca[O6MKIg]WFf]lIe]WNf]jKi][NW>JKgUcVVmiMiUc
V7NIMiMk]gNENkIgUG^eNiAo]7^COk=kTgncNi=o]7^COkAkTgncNi=o]7^DNkEgUG^eMkIg^7>GMkQc
VG>jKiU_Vf]jKi][NV]kIg][NfMkJg]K75llFa]O?5/LGcaFo5/LE_aG75KlFaaBo5KlD_aFo5;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000@Ool0021oo`03001oo`0002eoo`03001oogoo01=oo`=C
7@9G7@<0009G7@MK?006GeaO?6MkIe]WNfMK0V]j00U[Nf]jJgY_VG>JKgU_VG>HMiP00gNG0W^F0g^E
00=kTg^DNi<00W^C00=kU7^CNi<00g^C00=k/g^DNk@00W^e00AkU7^dNkEk]@=g]PA_VP07Jg]WNf]k
Ig][Nf=KHe`00Ull00YK?5/LFaaK75KlEaaFo5LLE_aG709Fo004D_aFo5KlE_`3D_`00eKlD_aBo006
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo080
011oo`0087oo0P00;goo00<007ooOol03goo00EBo5LMD_aG7E;l00<0000gDaaG7E<LFceG75LmFcaO
?E/lGceK?6=LGcaOG5llJgaWFfmkJgY_Vf]jKg]_NG>JKgUcVW>HMiUcV7^gMiMk]WNENkIkU7neNi=o
]7^COkAkU7ndNi=o]7^COk=kTgndNiAk]7^COkAkTg^dMiD00W^e08Mk]gNfMkQc^7NhLiM[NfMkJg]W
NfMlHe]WG6=KIgaK75/lFaaK?5/LFcaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo7oo00003goo0005Ool50005Ool20005Ool40006Ool00`00Oomoo`0_Ool00`00Oomoo`0<
Ool015<MD_eC7E<M0`000e<M0eLM00AG75LMEaeG7@9K?003GcaOG5ll009O?005GeaO?6]jJgY[N`02
JgX01fnILiY_NFnILiQgV7>H00=gU`9kUP9kU@=kU004NiEkU7^DNi@4Ni<01W^cNi=k]7^CNk=kT`9k
]09k]@9g]P0?NkMg^7NhMkQc^G>ILkUSFfMLHe]SG6=KIeaO?6<l00IK70IFo006D_aFo5;lE_aBo5Kl
0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001B
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg002D_`2Ool00`00Oomoo`0<Ool000Aoo`800005Ool00000Ool00004Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool01E<MC_aC7E;lDad00P00
03]Bo5LMD_aG7E<LEaeBo5/mEaaG?ELLFceG75LmGcaSG5llGeaO?6=LGcaSG6=KHeaSFf=LKgUcVVmi
LiYcV7NILiQk]gNGNkMgUG^fMiEo]G^DOkAkTg^fNiAk]G^COkAkTgncNi9o/g^COk=kTWndNi=k/g^C
00=k]@0DMkIk]g>hMkQcUg>jLiUc^V]jKi]SFfMLHe]SG5lkHeaO>e/lFaaK?09K7004EaaK75;lEa`2
E_`0KE;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0000ioo`0017oo0P000Woo00<0
07oo00003goo00<007ooOol00goo00<007ooOol0<Goo00<007ooOol01Goo00ABoE<MD_eC7@<0000:
DaeBoE<MDaeG7E<MEaeC7ELMDad3Ead015LLFceK?5/m0ell00=OG6=KHe`00V=L00ESFf=LIe]WNfmi
009_V@03MiQcV7NH00=gU`9kUP03NiEkU7^E009kUP04NiAkUG^DNi@:Ni<2Nk@2NkD00gNfNkMg^002
MkP00g>iLiUc^@05KiX03F=LGcaS?5llHeaO?5/LEaaK75LLFaaG75/L00IFo004D_aFo5;lE_`:D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0U;l00=oo`00Ool037oo0004Ool20002Ool00`00Ool0000?Ool00`00Oomoo`02Ool2000dOol02000
OomoogooC_aC7DklDad30000?e<MC_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMD_aK?ELLFceG75/mEaaK
?ELLHeaSFf=LHe]SG6=KHeaWFf]lIe]WNfMKMiUcV7NIMiMk]gNGNkIgUG^fMiMkUgNENkIgUG^eNiAo
]7^COk=kTgncNi=o/g^BOk=kTg^cNi=o]002NkD0SGNfNkMg]WNhLiMc^W>ILkY_VFnKJgY_Vf]jJg]W
Nf=LGc]SG5/LGcaK6e/LEaaK75KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LOol0000<Ool000Aoo`80009oo`03001oo`0000]oo`@000Eoo`03001oogoo039oo`03
D_eC7E;m009Bo@0:Dad00000001C7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMDad00eLM00IG75/mFcaK
?ELLFcd4Fc`2He`026=KIg]WFfMkIe]WNfMKJg/2JgX01VnILiY_NGNHLiQgV0=gU`9kUP9kU@03NiAk
Tg^C00=kT`03NiAkTg^C00=kT`06NkAkU7^eNkEk]gNf0WNh00Ac^G>ILkUcV@A_VP06Jg]WNf]kIg]O
?5/l0ell00IK?5llE_aG75KlEa`6E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol000aoo`000goo
0`0000Eoo`00001oo`0000]oo`03001oogoo00Ioo`03001oogoo031oo`05Dae>o5<MC_aC7@030000
He<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7E<LFceG75/mFcaO?E/lGceK
?5lmFcaWNfMKJgaWFfMkIe]_Vf]jKg]_NG>JKgUcVW>HMiUcV7^GMiMk]WNENkIkU7neNi=o]7^COkAk
TgndNi=o]7^CNk=kTgndNiAk]GNEOkAkTg^eMiEk]GNfNkMg]VnKJgY_VfMkJg]WNf]kIg]WO6=KGcaK
6ellFaaK?5/LFcaFo5LLE_aK7002E_`0L5;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aoo`002goo0005Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`0]Ool01E<MC_eBoE;mDad00`0000iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m1E<M0ULM00EG
75LMEaeG7ELL00QK?09O?005Ig]WFfMkJgY[N`03JgX01W>JKgU_VG>HMiQcV0=gU`9kUP9kU@04Ni=k
U7^CNi<3Ni@4Ni<01g^cNiAk]7^CNk=kU7^d009k]@=g]P=g^009Ig][NfMkJg]SFfMLHe]SG6=K00MK
70IFo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg5;l0P002Woo0006Ool4000<Ool50004
Ool00`00Oomoo`0[Ool014klDae>oE<M0`0004iC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5LMD_aG7E;lEaeBo5LMDaaG7E<LEaeG75LmEaaK?E/lGceK?5lmGcaOG5llHeaO?5mLJgY_Vf]jKg][
NW>JKgUcVW>HMiUcV7NIMiMk]gNENkIgUGneNiAo]7^COkEkU7ndNi=o]7^COk=kTgndNi=k]7^BOkAk
Tg^dMiD2NkD04g^gMkIg^7>hMkQ_VG>jLiUc^F=KIgaSFfMLHe]SG5lkFcaK75/l009K7006E_aK75Kl
EaaBo5LL0UKl06mBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00002Woo000O
Ool00`00Oomoo`0XOol01DkmD_eBoE<MC_d00P0000IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeB
oE<MD_eC7E;mDaeBo@MC7@9G7@05EaaG7ELMEaeG7002Ead01EmLGcaO?5llGe`00Ull0V=L0f]j00Mc
VVmiKiUcV7NHLiQgV003MiL2NiH01g^ENiAkU7^DNiIkU7^E009kU0=kT`06Nk=kTg^CNi=k/g^C0W^d
0W^e0WNf00Mk]gNhMkQcVG>iLiUc^@02KiX03F=KHeaO?6=LGcaS?5llHeaG75/LEaaK75LL00MFo004
D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg0020009Ool001ioo`8002Eoo`07C_eC7DklDae>oE<MC_`00`00055>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG
75LmEaaK?ELLEceG75/mEaaOG5llHeaO?5mLHe]SG6=KHeaSFg>JKgUcVVmiMiUcV7NIMiMk]gNGNkIg
UG^fNiAk]GNENkIkU7^eNi=o]7^COk=kTWndNi=o/g^BOk=kTg^dNi<00g^e08ig]W^gLkQg^7>GLkYc
VG>iJgY_Vf]jKi]O>f=LGc]SG5lkGcaK75llE_aK75LLFaaFo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol000Uoo`007Woo00<007ooOol08Woo00IC7DkmD_eB
oE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eC7E;mDaeBoE<MD_eC
7E;mDaeBo@9C7@0@EaeC7ELMDaeG7E<MEaeG75LMFcaK?ELLFceK?5mLGc`3He`02f=KHeaSG6MkIe]W
NfMKMiQcV7NHLiP00gNG0W^F0WNG0g^F0W^E00=kU7^CNi<027^C0W^d0W^e00=g]W^gMkP00WNh00=c
^G>IKiX016nJ00=WNf]kIg/00ell00QK?5llGcaO?5KlEaaFo5LL25Kl0e;l00=Fo5;lD_`01U;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`0
0003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00<007ooOol01goo000NOol00`00Oomoo`0POol01DklDae>oE<MC_`00`0005I>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<M
D_aG7E<LEaeBo5LMDaaK?ELLFceG75/mEaaK?ELLHeaSFf=LHe]SG6=KJgaWFfMkIe]_Vf]jKg][NW^g
MiMkUg>HMiUgUg^GMiMk]WNENkEkU7ndNi=o]7^COk=kTgncNi=o/g^CNk=kTgnd0W^e01agUG^gLkQg
^7>GLkYcVFnKJgY_Vf]jJg]WNf]kIg]WG6=KGcaK75llFa]K?5/LFcaFo5/LE_aG709Fo01]D_aFo5;l
E_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`017oo00<007ooOol01goo000NOol00`00Oomo
o`0NOol2D_d00e<MC_d0000200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eB
oE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad015LMDaeG7ELL0ULM00IK?ELLFceK
?5/mEa`2Fc`02F=LHe]SG6MKIg]WFfMkIe][N`03JgX01W>JKgU_VG>HMiQcV09gU`=kUP9kU@03Ni=k
U7^C00QkT`06NkAkU7^eNkEk]7^D0W^e00=k]gNfMkP00gNh00U[NfMkJg]SFf=LHe]WG6=KHe`01E/L
00=G75KlEa`01UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l1goo00<007ooOol01Woo000NOol00`00Oomo
o`0KOol015<MC_eC7Dkl0`000>A>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7E<LFceG75/m
FcaO?E/lGceK?5lmIe][O6MKIg]WFfnKJgY_Nf]jLiY_NG>JKgUgVG>HNiMgUg^gMiEk]W^DOkEkTgnd
Ni=o]7^DOkAkTgndNi=o/g^COkAkTg^cNi=o]7^CNkEgU7^eMkIk]g>GMkQc^7>iKiUc^V=KIeaSFfMl
He]WG5lkHeaK75/lFaaK?5/LEaaBo5LLE_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`:Ool0
0`00Oomoo`06Ool001eoo`8001Qoo`06Dae>oE;mD_eC7Dkm0`0000E>oE;mD_eC7Dkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3
Dad01E;mDaeC7E<MEa`00eLM00=G75LMEad01e/l00IO?5mLIe]WNfMKJg/3JgX01f]kKgU_VFnIMiQc
V7NH009gU`=kUP05NiEkU7^DNiAkT`03Ni@4Ni<01g^cNiAkTg^CNk=kU7^d009k]@9g]P=g^003LkUc
VG>i009_VP07He]WG6=KHcaO?6=LGc`00e/L00=G75/LEa`01eKl00ABo5KlD_aFo0iBo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`>Ool00`00Oomoo`06Ool001ioo`03001oogoo
01Aoo`06C_aC7DkmDae>o5<M0P0006E>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E;lEaeC
75LMDaaG7ELLFceG75lmFcaO?E/lGeaO?6=LGcaOG5llKi][NVmkJgY_VfmiLiY_NGNILiQgVGNGNkMg
Ug^fMiEo]G^DOkAkTgndNiAk]G^COkAkTgncNi9o]7^COk=kTgndNi=k]7ND009k]@1jNkMg]WNhLkQc
^FnILkY[NVnKJgY_VelkHeaO>f=LGc]SG5lkFaaG75/LE_aK75LLE_aBo5LLD_aFo5;lE_aBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg1=oo`03
001oogoo00Ioo`007Goo00<007ooOol04goo0U;m00=C7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;m
D_eC7E;mDaeBoE<MD_d7Dad01ELLEaeG7ELMEa`00eLM0ell00IOG5llGcaO?6=LHe/2JgX01f]kKgU_
VFnIMiQcV7NH00=gU`=kUP03NiAkUG^F009kUP03NiEkU7^D00=kT`06Nk=kTg^CNi=k/g^C0W^d0W^e
0WNf0WNh00Ac^G>ILkUcV@=_VP06Ig][NellHeaO?6<l0Ull00IK?5/LEaaK75KlEa`7E_`2D_`00eKl
D_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01U;LD_aBo5;lD]aBo1Eoo`03001oogoo00Io
o`007Goo00<007ooOol04Goo00A>oE<MC_aC7@<0001XDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MD_aC7DklEaeBo5LMD_aG7E<LEaeG75/mEaaG?ELLFceG75/mGcaSG5llGeaSFf=LHe]SG6=KHea_
NG>JKgUcVW>HMiUcV7^gMiMkUgNENkIkU7^eMiEk]WNENkEkU7ndNi=o/g^BOk=kTgncNi9o/g^CNkAk
T`=k]@0JMkIk]g>hLkU_VG>jLiU_Vf]jKi]WNf]kIg][NfMkGcaK6ellFaaO?5/KFaaFo5LLE_aK709F
o01KD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aB
g5KlD]`05goo00<007ooOol01Woo000MOol2000?Ool015;mDae>oE;m0`000U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d08U<M
C_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBoELMDaeG7E<MEaeC7ELMDaeK?E/lFceG75/m
FcaK?ELL0f=L00]SFf=LHeaSG6MKIg]WFfMkLiQgV7>H00=gU`=kUP9gU`=kUP03NiEkU7^C00UkT`9k
]09k]@07MkIk]g^eNkEg]W^gMkH00fnJ00YWNf]kIg][NfMkHeaSFellFcaO?0=K7003EaaFo5LL00AF
o004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg00LOol00`00Oomoo`06
Ool001eoo`03001oogoo00Uoo`06C_aC7DkmDae>o5<M0`0006eC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeC75/mEaaK?ELLFceG75lm
FcaSG6=KHeaSFf=LIe]WNfMKJga[NVmkJgYcVVmiLiYcV7NILiQkUgNGNkIgUG^fNiAo]G^COkAkTgnd
Ni=o/g^COk=kTg^cNi=o]002NkD07W^COkAkTg^eMkIk]gNfMkQcUgNhIg][NfMkJg]SFfMLHe]WO6=K
FcaK75/lFaaK?5/LEaaFo5LLD_aG709Fo01BD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo7oo000OOol00`00Oomoo`05Ool001eoo`03001oogoo00Moo`9Bo@03Dae>oE;m00<0009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad0
1E;mDaeG7ELMEa`00eLM00AG75/mFcaK?@EK?09SG005Ig]WFfMkIe]WN`03JgX01G>JKgU_VFnIMiP0
0W>H0WNG0g^F00MkUG^CNiAkU7^ENi=kU005Ni<01W^dNiAkTg^CNkAkU09k]@03NkMg]W^f009g^00;
LiUc^G>IIeaSFf=LHe]WG5llHcaO?003Fa`00eLLFaaG7007E_`015;lE_aBo5Kl35;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg004Ool0
0`00Oomoo`0LOol00`00Oomoo`05Ool001eoo`03001oogoo00Eoo`04C_eC7DklDad30000h5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aG
7E;lEaeC75LMDaaG7E<LEaeC75lmFcaO?E/lGceK?5lmFca[O6MKIg]WFfnKJgY_Nf]jKi]_NG>JKgUg
VG>HMiUgUg^gMiEk]WNEOkEkU7ndNi=o]7^COkAkTgndNi=o/g^COk=kTgncNi=o]7^CNkAgU7^gMkIk
]g>GMkQcVG>iKiU_Vf]jKi][NV=LGc]SG5lkHeaO>e/LE_aK75LLFaaFo5LLD_aFo5;lEaaBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`8Ool00`00Oomoo`0KOol00`00Oomoo`05Ool001eoo`04001o
ogooC_d2D_d015<MC_eBoE;m0P000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00aC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_d7Dad2Ead01ELLEaeG75LMEa`01U/l00EOG5ll
GcaO?6]k00=[NP05Jg]_NFnIKiUgV003LiP2MiL3NiH7Ni@8Ni<00g^cNiAk]002NkD00gNfNkIg^002
MkP00g>iLiU_VP03KiX01V]kIg]S?5llHeaK?09O?005FaaG75/LE_aG7008E_`3D_`00eKlD_aBo006
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l37oo00<0
07ooOol06goo00<007ooOol01Goo000LOol02000OomC7DkmDae>o5<MC_d30000gDkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG
7E;lEaeBo5LMD_aG7ELLEceG75/mEaaG?ELLGceK?5lmGcaSG5llGeaO?6=LHe]_Nf]jKi]_NG>JKgUg
VG>HMiUcV7^gMiMk]WNENkIkU7^eMiEk]WNENkEkTgndNi=o/g^BOkAkTgncNi9o]7^CNkAkTg^eMkIk
]gNfMkQc^7>iKiU_Vf]jKi][NV]kIg][NfMkGcaK75llFa]O?5/LEaaFo5/LE_aG75KlEaaBo5KlD_aF
o5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]`04Goo00<007ooOol06Woo00<007ooOol01Goo000LOol00`00Dae>o@02D_d30000
0e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eB
oE;mDad00e;m00QC7E;mDaeBoE<MD_eC7E;m15<M00YG7E<MEaeG75LMEaaG7ELLEaeG709O?006GeaO
?5llGcaSG6=K0f=L00A_NFnIKiUcVP=cV0=gU`=kUP05NiEkUW^FNiIkU@02Ni@7Ni<017^cNi=k]7^d
0W^e00Ik]WNfMkQg^7>iLiT4KiX01V]kIg][NfMkIeaSF`=O?0=K7005EaaFo5LLE_aG7004E_`015;l
E_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`05goo00<0
07ooOol06Goo00<007ooOol01Goo000BOol50005Ool00`00C_d000020000PdkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lEaeG75LmEaaK?ELLFceG76=LGcaOG6=KHeaSFf=LHe]SG6MK
Ig]WFf]lLiQgVG>HMiUgUg^GMiEk]WNENiMgUg^fMiEk]W^DOkAkTgncNi9o/g^COk=kTWncNi=k/g^C
OkAk]G^dNi<00W^e05Mk]gNfMkQc^7NhLiM[NfMkJg]SFfMlHe]WG6=KFcaK75/lFaaK?5/LFcaBo5LL
E_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_`06Woo00<007ooOol067oo00<007ooOol01Goo000DOol00`00Oomoo`05Ool200000e;m
Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@AC7@0=EaeC7ELMDaeG7E/lFceG75/m
FcaK?ELLFcd00V=L00QSFf=LHeaSG6MKIg]WFfMk0f]j00I[NfmiKiUcV7NHLiP2MiL3NiH00g^ENiAk
T`02Ni<00g^DNi=kT`04Ni<2Nk@2Ni<2Nk@2NkD00gNfNkMg^002MkP02W>iLiUc^F=KIeaSFf=LGcaS
G5ll1E/L00=G75/LE_`01EKl00IBo5KlD_aFo5;lE_`8D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aB
o5;l01aoo`03001oogoo01Uoo`03001oogoo00Aoo`0057oo00<007ooOol01Woo08H007ooC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMEaaK?ELLFceG75lmFcaO?F=K
HeaSFf]lIe]WNfMKJga[NVmkJgY_VfmiLiY_NGNILiQgVGNGNkMgUG^fMiEo]G^COk=kTgneNi=o]7^C
Ok=kTg^cNi=o]7^CNk=kTgnd0W^e059g]W^gLkQg^7>GLkYcVG>iJgY_Vf]jHeaO>f=LGc]SG5lkFaaG
75/LE_aK75LLFaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo25oo`03001oogoo01Qoo`03001oogoo00Aoo`0057oo00<007ooOol01goo0P0000=BoE<M
C_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M
00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM00=G75LMEad025/l00EW
NfMKIg]WFfMk00=[NP05Jg]_NFnIKiUgV002LiP2MiL3NiH00g^ENiAkU002NiD00g^CNiAkT`08Ni<0
1G^dNiAk]G^eNkL00gNh00=c^G>ILkT00fnJ00E[NfMkHeaO?6<l009O?004FcaK75LLFa`2Ea`00eKl
EaaFo004E_`2D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L02Ioo`03001oogoo01Moo`03001o
ogoo00Aoo`0057oo00<007ooOol02Goo09d007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LM
D_aG7E<LEaeC75LMEaaK?ELLGceK?5lmFcaO?E/lHeaO?6MkIe][O6]jKg][NVnKKgUcVVmiMiUcV7NI
MiMk]gNGNkIgUG^fNiAo]7NEOkEkU7ndNi=o]7^COk=kTgndNi=o/g^COkAkTg^eMiAk]gNfMkQcUg>j
LiUc^F]jKi][NV]kIg][NfMkGcaK6ellFaaO?5/KGcaFo5LLE_aK7002E_`0<U;lEaaBo5KlD_aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`XOol00`00Oomoo`0GOol00`00Oomoo`04Ool001Aoo`03
001oogoo00Yoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@QC7@06EaeG75LMEaaG7ELL
0e/l00=O?5mLGc`00Ull00IOG6]jJgY[NV]kKgT2KiT00gNHLiQcV003MiL3NiH017^DNiEkUW^E0g^D
27^C00=k/g^DNkD00W^e00Ig]WNhMkQc^G>ILkT3KiX026]kIg][NfMkHeaSFellFc`2Gc`3Fa`015Kl
EaaFo5LL0UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg5;l;7oo00<007ooOol05Woo00<007ooOol0
17oo000BOol3000=Ool0W@00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeC75LMD_aK?ELL
EceG75/mEaaOG5llHeaO?5mLGcaSG6=KHeaSFf=LKgUcVVmiLiYcV7NILiQk]gNGNiMgUG^fMiEk]GNE
NkIkU7^eNi=o]7^COk=kTgndNi=o/g^BOkAkTg^dMiAk]G^CNkAgU7^gMkIk]g>GMkQc^6]kIg][Nf=K
IeaSFfMlHe]K?5/LFcaK75/lFaaK?5KlEaaBo5LL009Fo00YD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg00a
Ool00`00Oomoo`0EOol00`00Oomoo`04Ool001Aoo`03001oogoo00aoo`800006Oom>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC
7E;mDaeBoE<MD_eC7E;m0U<M00eG7E<MEaeC7ELMDaeG7ELLEaeG75/mFcaOG003Gc`00f=LHe]SG002
He`016MKIg]WFfMk0g>H0gNG0g^F0WNG00=kUW^DNiD00W^D1g^C00Mk/g^CNkAkTg^cNiAk]002NkD0
0gNfNkIg]P02MkP02W>iLiUc^F=KHeaSFfMLGcaS?5ll1E/L00=G75/LE_`01EKl00ABo5KlD_aFo0aB
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lD_aBo3Ioo`03001oogoo01Aoo`03
001oogoo00Aoo`009Goo0;d007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeC75LMD_aG7E<LEaeBo5/mEaaK
?ELLFceG75/mHe]SG6=KHeaSFf=LIe]WNfMKJga[NVmkJgYcVVmiLiYcV7NILiQkUgNGNkIgUG^eNiAo
]7^COk=kTgndNi=o/g^BOk=kTg^dNi9o]7^CNkAkTg^eMkIk]gNfMkQc^7>iKiUc^V]jKi][NV=LGc]S
G5lkHeaO>f=LE_aK75LLFaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`0>Woo00<007ooOol05Goo00<007ooOol0
0goo000VOol00`00Oomoo`02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d03U<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMDad00eLM00EG75/mFcaK
?ELL00=K?008He]SG6=LIg]WFfMkIe]WN`=[NP05LiY_NFnIKiUgV002LiP2MiL2NiH00g^ENiAkT`02
Ni<00g^ENi=kT`05Ni<017^cNi=k]7^d0W^e00=k]WNfMkP00WNh00=cVG>iKiX00VnJ00E[NfMkHcaO
?6=L00AO?006EaaK75LLEaaFo5LL1UKl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`mOol00`00Oomoo`0DOol00`00Oomoo`03Ool002Moo`2g001oogooDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC
7E;lDaeBo5<MDaaG7E<LEaeC75LMDaaG7E/lGceK?5lmFcaO?E/lJgaWFfMkIe][O6]jKg][NVnKKgUc
VVmiMiUcV7NIMiMk]gNENkIkU7neNi=o]7^DOkEkTgncNi=o/g^CNk=kTgncNi=k/g^CNkAk]G^gMkIk
]g>hMkQ_VG>jJgY_Vf]jJg]WNf]kIg][Ne/LGcaK6ellFaaO?5KlFaaFo5LLE_aK75;lE_aBo5KlD_aF
o5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L041oo`03001o
ogoo01=oo`03001oogoo00=oo`00:7oo0P0000Eooe;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@EC7@9G7@06EaaG7ELM
EaeG75LM1E/l00EOG5llIg]WFfMk00=[NP05Jg]_NFnIKiUgV002LiP3MiL2NiH01G^ENi=kU7^FNiD0
0W^D27^C0W^d0W^e00Ig]W^gMkQg^7>ILkT3KiX01f]kIg][NfMkJg]SFf=L009O?006FcaK75/LFaaF
o5LL1UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg002D_a6Ool00`00Oomoo`0B
Ool00`00Oomoo`03Ool002Yoo`1k001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aG7E;lEceG75/mEaaG?ELLFceK
?5lmGcaSG5llGeaO?6=LJgY_Nf]jKi]_NG>JKgUgVG>HMiUgUg^gMiMk]WNEOkEkU7^fMiEo]G^DOkAk
TgndNi=o/g^COkAkTg^cNi=k]7^CNkEkTg^d009k]@0^MkIk]g>hMkQcUf]kIg][NfMkIgaSFfMLHe]W
O5/LFcaK75/lFaaK?5;lEaaFo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_a:Ool00`00Oomoo`0BOol00`00Oomoo`03Ool002]oo`06001ooe;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eBoE;mDaeBoE<MD_d6Dad02eLM
DaeG7ELLEaeG75LMEaaG7EllGe`00ell00=OG6=KHe`00V=L00A_NFnIKiUcVP=cV0=gU`9kUP9gU`9k
UP03NiAkUG^D00=kT`03NiAkTg^C009kT`06NkAkU7^eNi=k]7^D0W^e00mk]gNfMkQg^7>iLiUc^G>I
IeaSFf=LHe]SG5llHc`015/L00=G75/LE_`01EKl00IBo5KlD_aFo5;lE_`9D_a?Ool00`00Oomoo`0A
Ool00`00Oomoo`03Ool002aoo`2Q001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeC75LMD_aG7E<LEceG75/mEaaK?ELLFceO
?5mLGcaSG6=KHeaSFf=LIe]WNfMKJgacV7NILiQk]gNGNiMcN7NIMiMkUgNENkIkU7^eNi=o]7^COk=k
TgndNi=o/g^COkAkTg^dNi=k]7^CNkEgU7^gMkIg^7>GLkYcVG>iKiU_Vf]jKi]O>f=LGc]SG5lkHeaG
75/LE_aK75LLFaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo01DOol00`00Oomoo`0@Ool0
0`00Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d4Dad045LMDaeG7E<MEaeC7E/mEaaK?E/lFceG75/mFcaS
G6=K0f=L00AWFfMkIe]WN`=[NP06LiY_NFnILiQgV7>H0WNG0W^F0W^E00EkU7^CNi=kUG^D00=kT`07
Nk=kTg^CNi=k/g^DNk@00W^e00Mg]WNhMkQg^7>ILkUcV@03KiX016MkJg]O?6<l0Ull00AK?5llEaaK
709G7003E_aG75Kl00AFo09Bo003E_aBo5;l00=Bo5Moo`03001oogoo011oo`03001oogoo009oo`00
;goo09X005<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LFceG75/mEaaK?E/lGceK?6=LHe][O6MKIg]WFf]lJgY_
Nf]jLiY_NG>JKgUgVG>HNiMgUg^fMiEk]G^DOkAkTg^eNiAo]7^COk=kTWncNi=o/g^BOkAkTg^dMiAk
]GNfNkMcUgNhLiUc^FnIKi][NVnKIg][NfMkJg]K6ellFaaO?5/KGcaFo5LLE_aK75KlEaaBo5KlD_aF
o5;lE_aBo5KlD]aFo5Uoo`03001oogoo011oo`03001oogoo009oo`00<7oo00D007ooD_eC7Dkm009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC
7ELL00=G7@04EaaG7ELMEad7Fc`01FMkIe]WNfMKJg/00f]j00E[NfmiKiU_VGNH009cV09gU`9kUP9k
U@04Ni=kUW^ENiD9Ni<01G^dNkEk]G^eNkH00WNh00=cVG>iLiT00fnJ00MWNf]kIg][Nf=KIeaSF`05
Fa`00eKlEaaFo003E_`01E;lE_aFo5KlD_`0GWoo00<007ooOol03goo00<007ooOol00Woo000aOol0
L@00Oomooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG
7E;lEaeBo5LMDaaG7E<LEaeC75/mEaaG?E/lGceK?5lmFcaSG5llGeaO?6nKJgY_Nf]jKi]_NG>JKgUg
VG>HMiUgUg^gMiEk]W^DOkEgUG^fNiAo]G^COkAkTgncNi=o/g^BOk=kTg^dNi<00W^e01ek]7^CNkEg
]W^gMkIg^7>hMkQWNf]kIg]WG6=KIgaSFf=LGc]K?5/LFcaK75/lE_aG75;lEaaFo5LL06=oo`03001o
ogoo00ioo`03001oogoo009oo`00<Woo00D007ooOomC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@IC7@07EaeG75LMEaaG7ELLEad00U/l00=O?5mL
Gc`00Ull00ISG6=KJgY[NV]kKgT2KiT00gNHLiQcV003MiL2NiH01G^EMiMkUW^FNiD00W^D0g^C00=k
U7^CNi<00W^C00=k]7^cNi<00W^d0W^e00=k]WNfMkP00WNh011cVG>iLiUSG6=KIeaO?6<lGcaSG5ll
FaaG75/LEaaK70=Fo6Eoo`03001oogoo00ioo`03001oogoo009oo`00<goo0P0008Qooe<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeC75LMD_aK?ELL
EceG75/mEaaG?EllHeaO?5mLGcaSG6=KHeaSFf=LKgUcVVmiLiYcV7NILgQk]gNGNkIgUG^gMiMk]WNE
OkEkU7ndNi=o]7^COkAkTgncNi=k/g^COk=kTg^cNi=k]7^eNkMg]W^gLkQg^6nILkYcVFnKJgY_Velk
HeaO>f=LFaaO?5/KFaaG75/LE_aK76Qoo`03001oogoo00eoo`03001oogoo009oo`00=Goo00@007oo
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d06E<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBoELM
DaeG7E<MEaeC7ELMEaaG7ELLFceK?5/m00=O?003HeaSFf=L009SG004Ie]WNfMKIg/3LiP3MiL017>H
MiMgUgNG0W^F00=kU7^ENi@017^D1g^C0W^d0W^e00Mg]W^gMkQg^7>ILkUcV@03KiX01FMkJg]WNell
Fc`00ell00=K?7ooOol0Jgoo00<007ooOol037oo00<007ooOol00Woo000fOol0P@00OomC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E;lFceG
75/mEaaK?ELLFceG76=LHe]SG6=KJgaWFfMkIe][O6]jKg][NW>JKgUcVW=hMiUgUg^GMiEk]W^DNkEk
TgndNi=o]7^COkAkTgncNi=o]7^CNk=kTg^dNi=k]GNfNkMc^7NhKiUc^W>IKi][NV]kIg][NfMkIgaS
FellFa]O?01`Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool003Moo`04001ooe<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7@03Ead01ULLFceK?5/m
EaaK?@EK?005Ig]WFfMkIe]WN`03JgX01G>JKgU_VG>HMiP00gNG0W^F0W^E00=kU7^CNiD00W^D1g^C
00Ek]7^DNkEk]G^g009k]@03MkIk]WNf009_VP08Jg]WNf]kHe]WG6=KHeaSFg9oo`03001oogoo00ao
o`03001oogoo005oo`00>7oo0P0007UC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeK?5lmFcaO?E/lGceK?6=LGcaWNfMKKi][NVmkJgYc
VVmiLiY_NGNILiQkUgNGNkIgUG^eNiAo]7^CNkEkU7ndNi=o/g^BOkAkTgncNi=o]7^CNkAgU7^dNi=k
]GNDNkMg]WNhLiMc^W>ILkUSFfMlHe]WG01eOol00`00Oomoo`0;Ool00`00Oomoo`01Ool003Yoo`03
001oodkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m1U<M00=G7ELLEad0
0ULM00=G75LMFc`00e/l00=O?5mLGc`00Ull00I[Nf]jJgY[NW>JKgT2KiT00gNHLiQgU`02MiL2NiH2
NiD2NiH00g^ENiAkU002Ni<02W^DNi=kTg^CNk=kU7^dNi=k/g^D0W^e00Mk]WNfMkQg^7>iLiUc^@03
KiYhOol00`00Oomoo`0:Ool00`00Oomoo`01Ool003]oo`1e001oogooDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E;lEaeG75/mEaaG?ELLFceG75mLGcaSG5llGeaO?6=L
He]SG6=KLiY_NG>JKgUgVG>HMiUgUg^gMiEk]WNGNkMgUG^fNiAo]G^COk=kTgndNi=o/g^BOkAkTg^d
Ni9o]7^CNkAgU7^eMkIk]g>GMkQcVG>iJgY_Vf^J07Yoo`03001oogoo00Uoo`03001oogoo005oo`00
?7oo00<007ooOol00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d4Dad02eLM
DaeG7ELLEaeG75LMEaaK?E/lGe`00Ull0V=L00QSFf=LHeaWNfMKIg]WFgNH0W>H0gNG0W>H0WNG0W^F
00IkUG^DNiAkTg^ENi@6Ni<00g^cNi=k]002NkD01WNfNkIg^7NhLiUc^@A_VWYoo`03001oogoo00Uo
o`03001oogoo005oo`00?Goo0P0006Eooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>
o5LMDaaG7E;lEaeC75LMEaaK?ELLFceG75/mEaaK?F=KHeaSFf=LHe][O6MKIg]WFfnKJgY_NfmiLiY_
NGNILgQk]gNGNkIgUGneNiAo]7^COkEkTgndNi=o/g^COk=kTWncNi=k]7^C009k]@09NkMcUgNhLiUc
^F]jKi][VVnK07aoo`03001oogoo00Qoo`03001oogoo005oo`00?goo00H007ooD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;m
DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mEaeC7ELMDad00eLM00IG75/mFcaK?ELLFcd2Fc`026=K
HeaSG6MkIe]WNfMKJg/2JgX00fmiLiY_N@02LiP00gNHMiMgU`02NiH017^DNiEkU7^E0W^D27^C00=k
]7^eNkD00W^d00=k]GNfNkH017NhOWoo00<007ooOol01goo00<007ooOol00Goo0010Ool0IP00OomC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7ELLFceG75lmFcaO
?E/lGceK?6]lIe]WNf]jKi][NVmkJgYcVVmiLiYcN7NIMiMkUgNENkIkU7^eNi=k]W^DOkAkTgndNi=o
/g^COk=kTg^cNi=k]7^eNk=kT`9k]@05NkMg]WNhLkMg^020Ool00`00Oomoo`07Ool10001Ool1Ool0
045oo`06001oogooD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m1E<M0ULM00AG75LMEaeG7@MK
?005GeaO?5llJgY[N`03JgX01g>JKgU_VG>HMiQcV7NG00=kUP9kU@04NiIkU7^ENi@3Ni<00g^DNi=k
T`02Ni<00g^dNi=k/`02Nk@00g^eNkIg]P03MkR1Ool00`00Oomoo`07Ool10001Ool1Ool0049oo`80
001QOom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E;lEaeBo5LmEaaK?ELLEceK?5lmFcaO
?EllHeaO?5mLHc]SG6]jKg][NW>JKgUcVW=hMiUcV7^GMiMk]WNENiMgUg^fMiEk]G^COkAkTgncNi=o
]7^COk=kTg^dNi=k/g^CNk@00W^e00Ag]WNhLkMg^8=oo`03001oogoo00Ioo`40005oo`5oo`00A7oo
00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@05DaeBoE;mD_eC7@03D_d015<MD_eC7E;m1U<M00QG7E<MEaeG75LMEaaG7ELL0Ull00=O
G5llGc`00V=L00QSFf=LHeacVVmiKiUcV7NH0W>H00=gUgNHLiP00gNG00=kUW^ENiD00W^D00=kTg^E
Ni@00g^C00Uk/g^CNk=kTg^dNiAk]GNfNkH00WNhQGoo00<007ooOol01Goo0@000Goo0Goo0015Ool0
HP00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lEaeC75LmEaaK?ELLFceG76=LGcaO
G6<kHeaSFf=LHc][O6MKIg][NVnKJgY_NfmiMiUcV7NIMiMk]gNENkIkU7ndNi=o/g^DOkAkTgncNi9o
]7^COk=kTgndNi=k]GNDNkL2NkF6Ool00`00Oomoo`05Ool10001Ool1Ool004Ioo`05001ooe;mDae>
o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<M
D_eC7E;mDaeBoE<MD_eC7E;m15<M00eG7E<MEaeC7ELMDaeK?ELLFceK?5/mEaaK?@02He`026=KHeaW
FfMkIe]WNf]jJg/2JgX016miLiYcV7>H0gNG00=kUW^ENiD00W^D0W^E00=kU7^CNi<017^C00Ik/g^C
NkAk]G^dNi@2NkF7Ool00`00Oomoo`04Ool10001Ool1Ool004Moo`80001OOomC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaK?ELLFceG75lmFcaO?E/lGceWFf]lIe]WNf]jKi][NVmkKgUc
VW>HMiUcN7^gMiMk]WNEOkEkTgndMiEo]G^COkAkTgncNi=o/g^BOkAkTg^dMiAo]7^CNkEgU029Ool0
0`00Oomoo`03Ool10001Ool1Ool004Uoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00=BoE<MDad00U<M0eLM
00=G75LMEad01e/l00IO?5mLIe]WNf]jJg/2JgX00fmiLiY_N@02LiP2MiL2NiH01G^ENiAkUW^FNiD0
0W^D0W^C00=kU7^CNi<00W^C00Ek/g^dNk=kU7^d009k]HYoo`03001oogoo00=oo`40005oo`00BWoo
05d007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E;lEaeC75LMEaaK?ELLGceK?5lmFcaOG5llHeaO?5mL
JgY_Vf]jKg]_NG>JKgUgVG=hNkMgUg^GMiEk]WNGNiMgUG^fNiAo]7^COkAkTgndNi=o/g^CNk=kTgnc
Ni=k]7NDNkD0Rgoo00<007ooOol00goo0@000Goo001;Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d6Dad0
1eLMEaaG7ELLEaeG75LM00=O?003GeaO?5ll009SG008He]SG6miLiY_NFnILiQgV09gU`04LiQgV7NG
MiL2NiH017^DNiEkU7^C0W^D0g^C00Ak/g^CNi=kT`9k]09k]Haoo`03001oogoo009oo`40005oo`00
C7oo0P0005IC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeC75LMD_aK?ELLEceG75/mEaaK?EllHeaO?6=LHc]SG6=K
HeaWFf]lIe]WNg=hMiU_NG>JLgQgVG>HNiMgUg^fMiEk]G^COkAkU7ndNi=o]7^CNk=kTgndNi=k/g^C
0W^eSWoo00D007ooOomoo`00005oo`00CWoo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@AC7@0<EaeC7ELMDaeG7E/l
FceG75/mFcaK?ELL0f=L00eSFfMkIe]WNfMKIg][NV]kKgU_VFmiMiQcV002MiL2NiH2NiD017^DNiIk
UG^D1W^C00Ek/g^dNkAk]G^c08moo`04001oogoo0001Ool004moo`1F001oodklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;l
EaeC75LMDaaG7ELLFceG75/mFcaO?E/LGceK?6MkIe][O6MKIg][NVnKKgUcVVmiMiUcV7NIMiMk]gNE
NkIkU7ndMiEk]G^COkAkTgncNi=o]7^COk=kTg^dNi=k/i1oo`04001oogoo0001Ool0051oo`03001o
odkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC
7E;m0e<M00EBoE<MDaeG7ELL00=G7@03EaaG7E/l00IK?09O?009Ig]WFf]jJgY[Nf]jKiU_NGNH009c
V09gU`9kUP9kU@9kUP03NiEkU7^C00IkT`04NkAkTg^cNi>AOol00`00Ool00001Ool0055oo`80001A
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aG7E;lEaeBo5LMDaaG7E<LEceG75/mFcaO?E/LGceO?5mLGcaSG5llKg][NVnKJgYcVVmiLiYcV7NI
MiMk]gNGNkIgUG^gMiMk]W^DOkEkTgncNi=o]7^COk=kTWndNi=k/g^C09=oo`40005oo`400000Dgoo
00H004kmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;m
DaeBo@MC7@08EaaG7ELLEaeG75LMEaaOG0=O?003GeaO?6=L009SG004He]_VFmiLiX3LiP2MiL2LiP2
MiL2NiH01W^ENiAkTg^CNiEkU0IkT`03Nk=oogoo099oo`800000E7oo04l007ooDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMDaaG7ELL
FceG75LmEaaK?ELLGeaO?6=LHe]SG6<kHeaSFfMkIe][O6]jKg][NW>JKgUgVG=hMiUgUg^GMiEo]G^D
OkAkU7neNi=o/g^COk=kTgncNi=o]02EOol2000005Eoo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad03ULMDaeG7E<MEaeC7E/mFcaK
?ELLFceK?5/mHe/3He`016MKIg]WFfMk0f]j00EcVVmiKiUcV7NH009gU`9kUP9kU004NiIkUG^DNi@5
Ni<00g^cNi=oo`2DOol2000005Ioo`1<001oogooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75/mEaaK?ELLGceK?5lmFaaO?FMK
Ig]WFf]lJgY_Nf]jLiY_NG>JLgQgVGNGNiMgUg^fNiAk]GNEOkEkU7nDNi=o]7^COiAkTWncNi>BOol4
0002Ool005Moo`800004OomBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeB
oE<MD_d3Dad01E;mDaeC7ELMEa`00eLM00=G75LMFc`01E/l0Ull00=WFfMkJgX00V]j00E[NfmiKiUc
V7NH00=gU`9kUP07NiEkUW^FNiAkUG^DNi<00W^D0g^C00=k/gooOol0S7oo10001Woo001IOol0B@00
Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E;l
EaeC75LMDaaG?ELLFceK?5lmFaaSG5llGeaO?6=LJgY_Nf]jKg]_NG>JKgUgVG>HNiMgUg^gMiEkUgNG
NkIkU7^eNi=o]7^DOiAkTgndNi=k/g^C08Yoo`@000Yoo`00FWoo00D007ooD_eC7Dkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@IC7@09EaeG75LMEaaG7ELLEaeO?5mL00=O
?003GeaSFf=L009SG005KgU_VFmiMiQcV003MiL00g>HMiMgU`02NiH2NiD017^DNi=kU7^D0W^C00=k
/g^COol0QWoo10003Woo001KOol0AP00Oom>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7DklDaeC75LMD_aG7E<LEceG75/mEaaK?ELLFceO?5mLGcaSG6=KHeaS>f=LIe]WNfMK
Kg][NW>JKgUcVW>HMiUgUg^gMiEk]G^DOkAkTg^eNi=o]7^COk=kTgndPgoo10004Woo001LOol20000
0gooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad03ULMDaaG
7E<MEaeG75/mFcaK?ELLFceK?6=LHe/2He`02FMkIe]WNfMKJg][NVnIKgUcVP02LiP2MiL2NiH2NiD0
0g^DNiIkU002Ni@017^CNiAkTg^CP7oo0`005Woo001NOol0@P00OomC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMEaaK?ELLFceK75lmFcaO?E/LJgaW
FfMkJgY_Nf]jKg]_NG>JKgUgVG=hNkMgUg^fNiAo]GNENkIkU7ndNi=oTg^COkAkTgeoo`@001Uoo`00
Ggoo00@007ooDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@IC7@03EaeG75LM009G
7@03EaaK?5/l00AK?005GeaO?5llJgY[N`02JgX00fmiLiY_N@02LiP2MiL2NiH2MiL2NiH01G^ENiAk
U7^ENi@00W^CNGoo10007Goo001POol0?`00OomC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E;lEaeBo5LMDaaG7E<LEaeG75LmEaaO?E/lGceO?6=LGcaOG6<kHeaSFf=LKgUcVVmiMiUc
N7NIMiMkUgNEMiUgUg^fMiEo]G^COiAkTgndNi=oT`1fOol4000QOol0065oo`800006Oom>oE;mD_eC
7Dkm0U;m00QC7E;mD_eBoE<MD_eC7E;m1e<M00MG75LMEaaG7ELLEaeG7002Gc`00emLGcaSG002He`0
1F=KHeaWFfMkIe/00W>H00EgV7NGMiMcV7NH009gU`9kUP=kU004NiEkU7^CNi=bOol4000UOol006=o
o`0l001oodklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E<LEaeBo5LMEaaG?ELLFceG
75/mEaaK?ELLHeaS>f=LHe]SG6MKJgaWFfmkJgY_NfmiLiYcN7NILiQkUgNENkIkU7nDNi=o]G^COiAk
TgndKgoo0`00:Goo001TOol00`00Oom>o@02D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00eBoELM
DaeG7E<LEaeC7E/mEaaK?5/LFceG7002Fc`01V=LHe]WNfMKIg]WF`9[NP06Jg]_NFnIKgUgV7>H0WNG
0W^F00=kUG^FNiH00W^D0W^CK7oo1000;7oo001UOol0>@00Oom>o5<MC_aC7DklDae>o5<MC_aC7E;l
DaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LFceG75/mFcaO?E/LGceK?6MkIe][O6MKKg][NVmkJgYcVVmi
MiUcV7NIMiMk]WNENkEgUg^fNiAk]G^COkAkT`1XOol4000`Ool006Ioo`8000=Bo@0:DaeBoE;mD_eC
7E;mDaeBoE<MD_d5Dad2Ead015LLEaeG7ELM15/l0ell00UOG5llJgY[NV]kJgY_VFmiMiP00W>H0WNG
0W^F00EgUg^FNiIkUG^D009kT`03NiEoogoo069oo`@003Aoo`00J7oo03D007ooDae>o5<MC_aC7E;l
Dae>o5<MD_aC7E;lEaeBo5LMD_aG7ELLEceG75/mEaaG?ELLHeaO?5mLGcaSG5llHeaS>f=LHe]cVVmi
LiYcV7NILgQk]g>HMiUgUg^gMiEk]G^DOkAkU7^e065oo`@003Qoo`00JGoo00D007ooD_eBoE<M00=B
o@04DaeBoE<MD_d4Dad02ULMDaaG7ELLEaeG75LMFaaK?ELL0Ull00=OG6=KHe`00V=L00ASFfMkIe]W
N`=cV005LiYcV7>HLiQgU`02NiH00g^ENiAkUP02NiEMOol4000lOol006Yoo`0b001ooe<MC_aC7Dkl
DaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lEaeC75/mEaaK?ELLFceG75/mHe]SG6<kHeaWFfMkIe][O6]j
Kg][NW>JKgUgVG=hNkMgUg^fNiAo]GNENkEkU5]oo`<0041oo`00Jgoo0P0000QC7E;mDaeBoE<MD_eC
7E;m0e<M00EC75LMDaeG7ELL009G7@04FceG75/lFa`4Fc`01FMkIe]WNfMKIg/00f]j00AcVVmiLiQc
V09gU`9kUP03NiEgUg^F009kUEMoo`@004=oo`00KGoo02H007ooD_aC7DklDaeBo5<MD_aC7E;lDaeB
o5LMDaaG7E<LEaeC75LMFaaO?E/lGceK76=LGcaWNfMKJga[NVmkKgUcVVmiMiUcN7^g0WNG00IgUG^g
MiMkUW^DOkEDOol40017Ool006ioo`07001ooe;mDaeBoE<MD_d01U<M0eLM00AG75LMEaaG7@9K?003
GcaOG5ll009O?009Gea[NV]jKgUcVVmiKiUcV7NH009gU`07LiQgUgNGMiMkUW^ENi@0D7oo1000Bgoo
001_Ool09P00Oomooe<MC_aC7E;lDaeBo5LMD_aG7E;lFceG75LmEaaK?ELLEceO?6=LGcaOG5llHeaS
Ff=LIe][O6MKIg]cN7NIKgUcVW=hMiT2MiL00gNEOkEkU01=Ool4001?Ool0071oo`80000DOomC7E;m
DaeBoE<MDaaG7E<MEaeC75LMEaaG7ELLFcaK75/mEaaK?09SG00<He]SG6MKIg]WFfMkJgY[NfmiKiU_
NGNH0gNG00=kUW^DNiD0BWoo0`00Dgoo001bOol08P00OomC7E;lDaeBo5<MD_aG7E<LEaeBo5LMEaaK
?ELLFceG75lmFaaO?F=KHeaWFf]lIe]WNf]jKg]_NG>JKgUgVG>H0WNG00=k]W^DNkD0Agoo1000EWoo
001cOol01000OomC7E;m0e<M00EBoELMEaeG7ELL00=G7@IK?00;Ie]WNfMKIg][NV]kJgY_VFmiMiQc
V003MiL00g^FMiMgU`13Ool4001JOol007Aoo`0R001oogooD_aG7E;lEaeBo5LMDaaG7E<LFceG75Lm
FaaO?E/lGeaO?6=LGcaOG6]jKg][NW>JKgUcVW>HMiUgUg^gLiP2MiM0Ool4001NOol007Eoo`800003
OomC7E<M00=C7@07EaeG75LMEaaG7ELLEad00ell00=OG5llGc`00V=L00ASFfnIKgUcVP9cV004KgUc
VW>HLiP2MiLlOol4001ROol007Moo`0P001ooe;lEaeC75LMD_aK?ELLEceG75/mEaaK?EllHeaO?6=L
Hc]SG6=KIg]WFf]lJgY_NfmiLiYcV7NIMiMk]cUoo`@006Ioo`00N7oo00l007ooDaaG7E<MEaeC75LM
FaaK?ELLFcaK75/mEa`00f=L00AWFfMkIe]WN`9[NP03KgUcVVmi009cV09gUcIoo`<006Yoo`00NGoo
01d007ooOomG7E<LEaeC75LMEaaK?ELLFceK?5lmFaaO?FMKIg]WFf]lJgY_Nf]jLiY_NGNILgQk]gNG
03=oo`@006eoo`00NWoo00<007ooOol00eLM00=G75LMEad015/l00EOG5llGcaO?5mL00=[NP05LiY_
NG>HLiQgV002MiL_Ool4001aOol007]oo`80000FOomK?ELLEceG75/mEaaG?EllHeaO?5mLGcaSG6=K
HeaS>g>JKgUgVG=hMiT2MiL/Ool4001eOol007eoo`09001ooeLMEaaG7ELLFcaK75/m00=O?006HeaS
Ff=LHeaWNfMK0V]j00=[NfmiKiT0:Goo1000NGoo001nOol05@00OomooeLLFceG75/mEaaK?F<kHeaS
Ff=LIe][O6MKKg][NVmkKgUcVP0VOol4001mOol007moo`06001oogooFaaK?ELL1E/l00=WFfMkIe/0
0V]j00A[Nf]jKiU_NB=oo`<0085oo`00P7oo0P00011ooe/lGceK75lmFcaOG5llHeaO?6mkJgY_Nf]j
LiY_NB1oo`@008Aoo`00PWoo00@007ooOomoo`=O?003GeaO?6=L009SG003He]_VFmi01eoo`@008Qo
o`00Pgoo00d007ooOomooellHeaSFf=LHc]SG6=KIg]WF`0JOol4002<Ool008Aoo`05001oogooOomS
F`03He`00fMKIg]WF`0GOol4002@Ool008Eoo`8000Aoo`03Ie]WNfMK01Eoo`<009Aoo`00Qgoo00<0
07ooOol00goo00<007ooOol03goo1000Ugoo0028Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool4002K
Ool008Uoo`05001oogooOol00009Ool4002OOol008Yoo`800003Ool007oo00Aoo`@00:=oo`00S7oo
0P0000=oo`0000000P00Ygoo002=Ool2002[Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]o
o`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo0000\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02905 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.767 .834 .903 r
.38994 .79335 .39833 .79806 .4124 .78789 .40403 .78478 Mtetra
.834 .869 .87 r
.40403 .78478 .4124 .78789 .42663 .77292 .41826 .7724 Mtetra
.904 .899 .811 r
.41826 .7724 .42663 .77292 .441 .75103 .43265 .75412 Mtetra
.955 .915 .734 r
.43265 .75412 .441 .75103 .45546 .72124 .44717 .72812 Mtetra
.977 .916 .662 r
.44717 .72812 .45546 .72124 .46987 .68572 .46172 .69479 Mtetra
.979 .916 .621 r
.46172 .69479 .46987 .68572 .48411 .65006 .47615 .65824 Mtetra
.974 .925 .633 r
.47615 .65824 .48411 .65006 .49813 .6199 .49037 .62465 Mtetra
.961 .94 .702 r
.49037 .62465 .49813 .6199 .51198 .59752 .50437 .59821 Mtetra
.921 .934 .797 r
.50437 .59821 .51198 .59752 .52575 .58201 .51825 .57941 Mtetra
.852 .893 .866 r
.51825 .57941 .52575 .58201 .53951 .57128 .5321 .56648 Mtetra
.782 .84 .897 r
.5321 .56648 .53951 .57128 .55332 .56348 .54596 .55735 Mtetra
.731 .8 .906 r
.54596 .55735 .55332 .56348 .56719 .55734 .55988 .55045 Mtetra
.701 .774 .908 r
.55988 .55045 .56719 .55734 .58113 .5521 .57386 .54477 Mtetra
.683 .759 .909 r
.57386 .54477 .58113 .5521 .59513 .54734 .58792 .53976 Mtetra
.674 .751 .908 r
.58792 .53976 .59513 .54734 .60922 .54282 .60204 .53508 Mtetra
.669 .746 .908 r
.60204 .53508 .60922 .54282 .62337 .53841 .61625 .53058 Mtetra
.666 .744 .908 r
.61625 .53058 .62337 .53841 .6376 .53406 .63052 .52616 Mtetra
.665 .743 .908 r
.63052 .52616 .6376 .53406 .6519 .52973 .64487 .52177 Mtetra
.664 .742 .908 r
.64487 .52177 .6519 .52973 .66627 .52539 .6593 .51738 Mtetra
.6593 .51738 .66627 .52539 .68072 .52105 .6738 .51299 Mtetra
.664 .741 .908 r
.6738 .51299 .68072 .52105 .69524 .51668 .68837 .50858 Mtetra
.68837 .50858 .69524 .51668 .70984 .5123 .70302 .50416 Mtetra
.70302 .50416 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.74 .818 .913 r
.38148 .78805 .38994 .79335 .40403 .78478 .39559 .7807 Mtetra
.799 .851 .889 r
.39559 .7807 .40403 .78478 .41826 .7724 .40983 .77039 Mtetra
.87 .886 .844 r
.40983 .77039 .41826 .7724 .43265 .75412 .42423 .75525 Mtetra
.933 .909 .774 r
.42423 .75525 .43265 .75412 .44717 .72812 .43878 .73314 Mtetra
.969 .916 .696 r
.43878 .73314 .44717 .72812 .46172 .69479 .45343 .70307 Mtetra
.98 .915 .636 r
.45343 .70307 .46172 .69479 .47615 .65824 .46803 .66724 Mtetra
.977 .919 .62 r
.46803 .66724 .47615 .65824 .49037 .62465 .48246 .63127 Mtetra
.969 .933 .662 r
.48246 .63127 .49037 .62465 .50437 .59821 .49665 .60085 Mtetra
.946 .941 .75 r
.49665 .60085 .50437 .59821 .51825 .57941 .51066 .57826 Mtetra
.889 .917 .837 r
.51066 .57826 .51825 .57941 .5321 .56648 .5246 .56258 Mtetra
.815 .866 .885 r
.5246 .56258 .5321 .56648 .54596 .55735 .53853 .55171 Mtetra
.754 .818 .903 r
.53853 .55171 .54596 .55735 .55988 .55045 .5525 .54379 Mtetra
.714 .785 .908 r
.5525 .54379 .55988 .55045 .57386 .54477 .56653 .53754 Mtetra
.691 .765 .909 r
.56653 .53754 .57386 .54477 .58792 .53976 .58063 .53219 Mtetra
.678 .754 .909 r
.58063 .53219 .58792 .53976 .60204 .53508 .59481 .52732 Mtetra
.671 .748 .908 r
.59481 .52732 .60204 .53508 .61625 .53058 .60906 .5227 Mtetra
.668 .745 .908 r
.60906 .5227 .61625 .53058 .63052 .52616 .62338 .51819 Mtetra
.666 .743 .908 r
.62338 .51819 .63052 .52616 .64487 .52177 .63778 .51374 Mtetra
.665 .742 .908 r
.63778 .51374 .64487 .52177 .6593 .51738 .65225 .5093 Mtetra
.664 .742 .908 r
.65225 .5093 .6593 .51738 .6738 .51299 .6668 .50486 Mtetra
.6668 .50486 .6738 .51299 .68837 .50858 .68143 .50041 Mtetra
.664 .741 .908 r
.68143 .50041 .68837 .50858 .70302 .50416 .69613 .49594 Mtetra
.69613 .49594 .70302 .50416 .71774 .49971 .71091 .49145 Mtetra
.71091 .49145 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.718 .805 .919 r
.37295 .78228 .38148 .78805 .39559 .7807 .38708 .77584 Mtetra
.767 .834 .903 r
.38708 .77584 .39559 .7807 .40983 .77039 .40134 .76714 Mtetra
.834 .869 .87 r
.40134 .76714 .40983 .77039 .42423 .75525 .41574 .75461 Mtetra
.904 .9 .811 r
.41574 .75461 .42423 .75525 .43878 .73314 .43032 .73612 Mtetra
.955 .915 .734 r
.43032 .73612 .43878 .73314 .45343 .70307 .44502 .70988 Mtetra
.977 .916 .662 r
.44502 .70988 .45343 .70307 .46803 .66724 .45976 .67625 Mtetra
.979 .916 .621 r
.45976 .67625 .46803 .66724 .48246 .63127 .47438 .63938 Mtetra
.974 .925 .633 r
.47438 .63938 .48246 .63127 .49665 .60085 .48878 .60549 Mtetra
.961 .94 .703 r
.48878 .60549 .49665 .60085 .51066 .57826 .50296 .57882 Mtetra
.921 .934 .797 r
.50296 .57882 .51066 .57826 .5246 .56258 .51701 .55983 Mtetra
.852 .893 .866 r
.51701 .55983 .5246 .56258 .53853 .55171 .53102 .54675 Mtetra
.782 .84 .896 r
.53102 .54675 .53853 .55171 .5525 .54379 .54504 .53749 Mtetra
.731 .799 .906 r
.54504 .53749 .5525 .54379 .56653 .53754 .55913 .53046 Mtetra
.701 .774 .908 r
.55913 .53046 .56653 .53754 .58063 .53219 .57328 .52468 Mtetra
.683 .759 .909 r
.57328 .52468 .58063 .53219 .59481 .52732 .5875 .51956 Mtetra
.674 .751 .908 r
.5875 .51956 .59481 .52732 .60906 .5227 .6018 .51478 Mtetra
.669 .746 .908 r
.6018 .51478 .60906 .5227 .62338 .51819 .61617 .51017 Mtetra
.666 .744 .908 r
.61617 .51017 .62338 .51819 .63778 .51374 .63062 .50564 Mtetra
.665 .743 .908 r
.63062 .50564 .63778 .51374 .65225 .5093 .64514 .50114 Mtetra
.664 .742 .908 r
.64514 .50114 .65225 .5093 .6668 .50486 .65974 .49665 Mtetra
.65974 .49665 .6668 .50486 .68143 .50041 .67442 .49215 Mtetra
.664 .741 .908 r
.67442 .49215 .68143 .50041 .69613 .49594 .68918 .48764 Mtetra
.68918 .48764 .69613 .49594 .71091 .49145 .70401 .4831 Mtetra
.70401 .4831 .71091 .49145 .72577 .48693 .71892 .47855 Mtetra
.71892 .47855 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.7 .795 .924 r
.36435 .77614 .37295 .78228 .38708 .77584 .3785 .77038 Mtetra
.74 .818 .913 r
.3785 .77038 .38708 .77584 .40134 .76714 .39278 .76291 Mtetra
.799 .851 .889 r
.39278 .76291 .40134 .76714 .41574 .75461 .40719 .75246 Mtetra
.87 .886 .844 r
.40719 .75246 .41574 .75461 .43032 .73612 .42177 .73714 Mtetra
.933 .91 .774 r
.42177 .73714 .43032 .73612 .44502 .70988 .43651 .7148 Mtetra
.969 .916 .696 r
.43651 .7148 .44502 .70988 .45976 .67625 .45135 .68445 Mtetra
.98 .915 .636 r
.45135 .68445 .45976 .67625 .47438 .63938 .46615 .6483 Mtetra
.977 .919 .62 r
.46615 .6483 .47438 .63938 .48878 .60549 .48076 .61203 Mtetra
.969 .933 .662 r
.48076 .61203 .48878 .60549 .50296 .57882 .49513 .58134 Mtetra
.946 .941 .75 r
.49513 .58134 .50296 .57882 .51701 .55983 .50932 .55853 Mtetra
.889 .916 .837 r
.50932 .55853 .51701 .55983 .53102 .54675 .52342 .54268 Mtetra
.815 .866 .885 r
.52342 .54268 .53102 .54675 .54504 .53749 .53752 .53167 Mtetra
.754 .818 .903 r
.53752 .53167 .54504 .53749 .55913 .53046 .55165 .52363 Mtetra
.714 .785 .908 r
.55165 .52363 .55913 .53046 .57328 .52468 .56585 .51726 Mtetra
.691 .765 .909 r
.56585 .51726 .57328 .52468 .5875 .51956 .58012 .5118 Mtetra
.678 .754 .909 r
.58012 .5118 .5875 .51956 .6018 .51478 .59447 .50683 Mtetra
.671 .748 .908 r
.59447 .50683 .6018 .51478 .61617 .51017 .60889 .50209 Mtetra
.668 .745 .908 r
.60889 .50209 .61617 .51017 .63062 .50564 .62339 .49748 Mtetra
.666 .743 .908 r
.62339 .49748 .63062 .50564 .64514 .50114 .63797 .49292 Mtetra
.665 .742 .908 r
.63797 .49292 .64514 .50114 .65974 .49665 .65262 .48837 Mtetra
.664 .742 .908 r
.65262 .48837 .65974 .49665 .67442 .49215 .66735 .48382 Mtetra
.66735 .48382 .67442 .49215 .68918 .48764 .68215 .47926 Mtetra
.664 .741 .908 r
.68215 .47926 .68918 .48764 .70401 .4831 .69704 .47468 Mtetra
.69704 .47468 .70401 .4831 .71892 .47855 .712 .47008 Mtetra
.712 .47008 .71892 .47855 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.686 .787 .927 r
.35567 .76972 .36435 .77614 .3785 .77038 .36985 .76444 Mtetra
.718 .806 .919 r
.36985 .76444 .3785 .77038 .39278 .76291 .38415 .75789 Mtetra
.767 .834 .903 r
.38415 .75789 .39278 .76291 .40719 .75246 .39858 .74906 Mtetra
.834 .869 .87 r
.39858 .74906 .40719 .75246 .42177 .73714 .41317 .73637 Mtetra
.904 .9 .811 r
.41317 .73637 .42177 .73714 .43651 .7148 .42792 .71768 Mtetra
.955 .915 .734 r
.42792 .71768 .43651 .7148 .45135 .68445 .44282 .69118 Mtetra
.977 .916 .662 r
.44282 .69118 .45135 .68445 .46615 .6483 .45775 .65724 Mtetra
.979 .916 .621 r
.45775 .65724 .46615 .6483 .48076 .61203 .47257 .62005 Mtetra
.974 .925 .634 r
.47257 .62005 .48076 .61203 .49513 .58134 .48715 .58588 Mtetra
.961 .94 .703 r
.48715 .58588 .49513 .58134 .50932 .55853 .50151 .55896 Mtetra
.921 .933 .797 r
.50151 .55896 .50932 .55853 .52342 .54268 .51573 .53978 Mtetra
.852 .892 .866 r
.51573 .53978 .52342 .54268 .53752 .53167 .52991 .52654 Mtetra
.782 .84 .896 r
.52991 .52654 .53752 .53167 .55165 .52363 .54411 .51714 Mtetra
.731 .799 .906 r
.54411 .51714 .55165 .52363 .56585 .51726 .55836 .51 Mtetra
.701 .774 .908 r
.55836 .51 .56585 .51726 .58012 .5118 .57268 .5041 Mtetra
.683 .759 .909 r
.57268 .5041 .58012 .5118 .59447 .50683 .58707 .49886 Mtetra
.674 .751 .908 r
.58707 .49886 .59447 .50683 .60889 .50209 .60154 .49398 Mtetra
.669 .746 .908 r
.60154 .49398 .60889 .50209 .62339 .49748 .61609 .48926 Mtetra
.666 .744 .908 r
.61609 .48926 .62339 .49748 .63797 .49292 .63072 .48462 Mtetra
.665 .743 .908 r
.63072 .48462 .63797 .49292 .65262 .48837 .64542 .48001 Mtetra
.664 .742 .908 r
.64542 .48001 .65262 .48837 .66735 .48382 .6602 .47541 Mtetra
.6602 .47541 .66735 .48382 .68215 .47926 .67506 .4708 Mtetra
.664 .741 .908 r
.67506 .4708 .68215 .47926 .69704 .47468 .69 .46617 Mtetra
.69 .46617 .69704 .47468 .712 .47008 .70502 .46152 Mtetra
.70502 .46152 .712 .47008 .72705 .46545 .72012 .45685 Mtetra
.72012 .45685 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.676 .78 .929 r
.34691 .76306 .35567 .76972 .36985 .76444 .36113 .75814 Mtetra
.7 .795 .924 r
.36113 .75814 .36985 .76444 .38415 .75789 .37545 .75226 Mtetra
.74 .819 .913 r
.37545 .75226 .38415 .75789 .39858 .74906 .3899 .74467 Mtetra
.799 .851 .889 r
.3899 .74467 .39858 .74906 .41317 .73637 .40449 .73408 Mtetra
.87 .886 .844 r
.40449 .73408 .41317 .73637 .42792 .71768 .41926 .71857 Mtetra
.933 .91 .774 r
.41926 .71857 .42792 .71768 .44282 .69118 .43419 .69601 Mtetra
.969 .917 .695 r
.43419 .69601 .44282 .69118 .45775 .65724 .44922 .66537 Mtetra
.98 .915 .636 r
.44922 .66537 .45775 .65724 .47257 .62005 .46421 .6289 Mtetra
.977 .919 .62 r
.46421 .6289 .47257 .62005 .48715 .58588 .47901 .59232 Mtetra
.97 .933 .662 r
.47901 .59232 .48715 .58588 .50151 .55896 .49357 .56135 Mtetra
.946 .941 .751 r
.49357 .56135 .50151 .55896 .51573 .53978 .50794 .53832 Mtetra
.889 .916 .837 r
.50794 .53832 .51573 .53978 .52991 .52654 .52221 .5223 Mtetra
.815 .866 .885 r
.52221 .5223 .52991 .52654 .54411 .51714 .53648 .51115 Mtetra
.754 .818 .903 r
.53648 .51115 .54411 .51714 .55836 .51 .55079 .50297 Mtetra
.714 .785 .908 r
.55079 .50297 .55836 .51 .57268 .5041 .56516 .49649 Mtetra
.691 .765 .909 r
.56516 .49649 .57268 .5041 .58707 .49886 .5796 .49092 Mtetra
.678 .754 .909 r
.5796 .49092 .58707 .49886 .60154 .49398 .59412 .48583 Mtetra
.671 .748 .908 r
.59412 .48583 .60154 .49398 .61609 .48926 .60872 .48098 Mtetra
.668 .745 .908 r
.60872 .48098 .61609 .48926 .63072 .48462 .6234 .47626 Mtetra
.666 .743 .908 r
.6234 .47626 .63072 .48462 .64542 .48001 .63816 .47158 Mtetra
.665 .742 .908 r
.63816 .47158 .64542 .48001 .6602 .47541 .65299 .46692 Mtetra
.664 .742 .908 r
.65299 .46692 .6602 .47541 .67506 .4708 .6679 .46226 Mtetra
.6679 .46226 .67506 .4708 .69 .46617 .6829 .45758 Mtetra
.664 .741 .908 r
.6829 .45758 .69 .46617 .70502 .46152 .69797 .45289 Mtetra
.69797 .45289 .70502 .46152 .72012 .45685 .71312 .44817 Mtetra
.71312 .44817 .72012 .45685 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42906 Mtetra
.77456 .42906 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.668 .776 .93 r
.33807 .75622 .34691 .76306 .36113 .75814 .35232 .75154 Mtetra
.686 .787 .927 r
.35232 .75154 .36113 .75814 .37545 .75226 .36667 .74616 Mtetra
.718 .806 .919 r
.36667 .74616 .37545 .75226 .3899 .74467 .38114 .73949 Mtetra
.767 .834 .903 r
.38114 .73949 .3899 .74467 .40449 .73408 .39575 .73053 Mtetra
.834 .869 .87 r
.39575 .73053 .40449 .73408 .41926 .71857 .41052 .71767 Mtetra
.904 .9 .811 r
.41052 .71767 .41926 .71857 .43419 .69601 .42547 .69877 Mtetra
.955 .915 .734 r
.42547 .69877 .43419 .69601 .44922 .66537 .44056 .67201 Mtetra
.977 .916 .662 r
.44056 .67201 .44922 .66537 .46421 .6289 .4557 .63776 Mtetra
.979 .916 .621 r
.4557 .63776 .46421 .6289 .47901 .59232 .47071 .60025 Mtetra
.974 .925 .634 r
.47071 .60025 .47901 .59232 .49357 .56135 .48548 .56578 Mtetra
.961 .94 .703 r
.48548 .56578 .49357 .56135 .50794 .53832 .50002 .53861 Mtetra
.921 .933 .797 r
.50002 .53861 .50794 .53832 .52221 .5223 .51442 .51923 Mtetra
.852 .892 .866 r
.51442 .51923 .52221 .5223 .53648 .51115 .52877 .50583 Mtetra
.782 .84 .896 r
.52877 .50583 .53648 .51115 .55079 .50297 .54314 .4963 Mtetra
.731 .799 .906 r
.54314 .4963 .55079 .50297 .56516 .49649 .55757 .48903 Mtetra
.701 .774 .908 r
.55757 .48903 .56516 .49649 .5796 .49092 .57206 .48301 Mtetra
.683 .759 .909 r
.57206 .48301 .5796 .49092 .59412 .48583 .58663 .47766 Mtetra
.674 .751 .908 r
.58663 .47766 .59412 .48583 .60872 .48098 .60128 .47266 Mtetra
.669 .746 .908 r
.60128 .47266 .60872 .48098 .6234 .47626 .61601 .46783 Mtetra
.666 .744 .908 r
.61601 .46783 .6234 .47626 .63816 .47158 .63082 .46308 Mtetra
.665 .743 .908 r
.63082 .46308 .63816 .47158 .65299 .46692 .64571 .45836 Mtetra
.664 .742 .908 r
.64571 .45836 .65299 .46692 .6679 .46226 .66067 .45364 Mtetra
.66067 .45364 .6679 .46226 .6829 .45758 .67572 .44891 Mtetra
.664 .741 .908 r
.67572 .44891 .6829 .45758 .69797 .45289 .69085 .44417 Mtetra
.69085 .44417 .69797 .45289 .71312 .44817 .70606 .4394 Mtetra
.70606 .4394 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42906 .76773 .42009 Mtetra
.76773 .42009 .77456 .42906 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.662 .772 .931 r
.32914 .74922 .33807 .75622 .35232 .75154 .34343 .74471 Mtetra
.676 .78 .929 r
.34343 .74471 .35232 .75154 .36667 .74616 .35782 .73968 Mtetra
.7 .795 .924 r
.35782 .73968 .36667 .74616 .38114 .73949 .37232 .73369 Mtetra
.74 .819 .913 r
.37232 .73369 .38114 .73949 .39575 .73053 .38694 .72597 Mtetra
.799 .851 .889 r
.38694 .72597 .39575 .73053 .41052 .71767 .40172 .71523 Mtetra
.87 .886 .844 r
.40172 .71523 .41052 .71767 .42547 .69877 .41668 .69954 Mtetra
.933 .91 .774 r
.41668 .69954 .42547 .69877 .44056 .67201 .4318 .67673 Mtetra
.97 .917 .695 r
.4318 .67673 .44056 .67201 .4557 .63776 .44704 .64581 Mtetra
.98 .915 .636 r
.44704 .64581 .4557 .63776 .47071 .60025 .46223 .60902 Mtetra
.977 .919 .62 r
.46223 .60902 .47071 .60025 .48548 .56578 .47723 .57211 Mtetra
.97 .933 .662 r
.47723 .57211 .48548 .56578 .50002 .53861 .49198 .54087 Mtetra
.946 .941 .751 r
.49198 .54087 .50002 .53861 .51442 .51923 .50652 .51762 Mtetra
.889 .916 .837 r
.50652 .51762 .51442 .51923 .52877 .50583 .52098 .50142 Mtetra
.815 .866 .885 r
.52098 .50142 .52877 .50583 .54314 .4963 .53542 .49011 Mtetra
.754 .818 .903 r
.53542 .49011 .54314 .4963 .55757 .48903 .5499 .48181 Mtetra
.714 .785 .908 r
.5499 .48181 .55757 .48903 .57206 .48301 .56445 .4752 Mtetra
.691 .765 .909 r
.56445 .4752 .57206 .48301 .58663 .47766 .57907 .46951 Mtetra
.678 .754 .908 r
.57907 .46951 .58663 .47766 .60128 .47266 .59377 .4643 Mtetra
.671 .748 .908 r
.59377 .4643 .60128 .47266 .61601 .46783 .60855 .45934 Mtetra
.668 .745 .908 r
.60855 .45934 .61601 .46783 .63082 .46308 .62341 .4545 Mtetra
.666 .743 .908 r
.62341 .4545 .63082 .46308 .64571 .45836 .63835 .44971 Mtetra
.665 .742 .908 r
.63835 .44971 .64571 .45836 .66067 .45364 .65337 .44494 Mtetra
.664 .742 .908 r
.65337 .44494 .66067 .45364 .67572 .44891 .66847 .44016 Mtetra
.66847 .44016 .67572 .44891 .69085 .44417 .68366 .43536 Mtetra
.664 .741 .908 r
.68366 .43536 .69085 .44417 .70606 .4394 .69892 .43055 Mtetra
.69892 .43055 .70606 .4394 .72135 .43461 .71427 .42571 Mtetra
.71427 .42571 .72135 .43461 .73673 .4298 .72971 .42085 Mtetra
.72971 .42085 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.658 .77 .932 r
.32013 .74208 .32914 .74922 .34343 .74471 .33446 .73769 Mtetra
.668 .776 .93 r
.33446 .73769 .34343 .74471 .35782 .73968 .34888 .7329 Mtetra
.686 .787 .927 r
.34888 .7329 .35782 .73968 .37232 .73369 .36341 .72741 Mtetra
.718 .806 .919 r
.36341 .72741 .37232 .73369 .38694 .72597 .37806 .72062 Mtetra
.767 .834 .903 r
.37806 .72062 .38694 .72597 .40172 .71523 .39285 .71152 Mtetra
.834 .869 .87 r
.39285 .71152 .40172 .71523 .41668 .69954 .40781 .69849 Mtetra
.904 .9 .811 r
.40781 .69849 .41668 .69954 .4318 .67673 .42295 .67938 Mtetra
.955 .915 .734 r
.42295 .67938 .4318 .67673 .44704 .64581 .43825 .65235 Mtetra
.977 .916 .661 r
.43825 .65235 .44704 .64581 .46223 .60902 .45359 .61779 Mtetra
.979 .916 .621 r
.45359 .61779 .46223 .60902 .47723 .57211 .4688 .57995 Mtetra
.974 .925 .634 r
.4688 .57995 .47723 .57211 .49198 .54087 .48377 .54517 Mtetra
.961 .939 .703 r
.48377 .54517 .49198 .54087 .50652 .51762 .4985 .51776 Mtetra
.921 .933 .797 r
.4985 .51776 .50652 .51762 .52098 .50142 .51308 .49817 Mtetra
.852 .892 .866 r
.51308 .49817 .52098 .50142 .53542 .49011 .52761 .48461 Mtetra
.782 .84 .896 r
.52761 .48461 .53542 .49011 .5499 .48181 .54216 .47494 Mtetra
.731 .799 .906 r
.54216 .47494 .5499 .48181 .56445 .4752 .55676 .46754 Mtetra
.701 .774 .908 r
.55676 .46754 .56445 .4752 .57907 .46951 .57143 .4614 Mtetra
.683 .759 .909 r
.57143 .4614 .57907 .46951 .59377 .4643 .58619 .45593 Mtetra
.674 .751 .908 r
.58619 .45593 .59377 .4643 .60855 .45934 .60102 .45081 Mtetra
.669 .746 .908 r
.60102 .45081 .60855 .45934 .62341 .4545 .61593 .44586 Mtetra
.666 .744 .908 r
.61593 .44586 .62341 .4545 .63835 .44971 .63092 .44099 Mtetra
.665 .743 .908 r
.63092 .44099 .63835 .44971 .65337 .44494 .646 .43615 Mtetra
.664 .742 .908 r
.646 .43615 .65337 .44494 .66847 .44016 .66116 .43132 Mtetra
.66116 .43132 .66847 .44016 .68366 .43536 .6764 .42647 Mtetra
.664 .741 .908 r
.6764 .42647 .68366 .43536 .69892 .43055 .69172 .4216 Mtetra
.69172 .4216 .69892 .43055 .71427 .42571 .70712 .41672 Mtetra
.70712 .41672 .71427 .42571 .72971 .42085 .72262 .4118 Mtetra
.72262 .4118 .72971 .42085 .74522 .41596 .73819 .40686 Mtetra
.73819 .40686 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.654 .768 .932 r
.31103 .73483 .32013 .74208 .33446 .73769 .3254 .7305 Mtetra
.662 .772 .931 r
.3254 .7305 .33446 .73769 .34888 .7329 .33987 .72589 Mtetra
.676 .781 .929 r
.33987 .72589 .34888 .7329 .36341 .72741 .35443 .72075 Mtetra
.7 .795 .924 r
.35443 .72075 .36341 .72741 .37806 .72062 .3691 .71464 Mtetra
.74 .819 .913 r
.3691 .71464 .37806 .72062 .39285 .71152 .38391 .70679 Mtetra
.799 .851 .889 r
.38391 .70679 .39285 .71152 .40781 .69849 .39888 .69589 Mtetra
.871 .887 .844 r
.39888 .69589 .40781 .69849 .42295 .67938 .41403 .68001 Mtetra
.933 .91 .774 r
.41403 .68001 .42295 .67938 .43825 .65235 .42936 .65697 Mtetra
.97 .917 .695 r
.42936 .65697 .43825 .65235 .45359 .61779 .44479 .62575 Mtetra
.98 .915 .636 r
.44479 .62575 .45359 .61779 .4688 .57995 .4602 .58863 Mtetra
.977 .919 .62 r
.4602 .58863 .4688 .57995 .48377 .54517 .4754 .5514 Mtetra
.97 .933 .663 r
.4754 .5514 .48377 .54517 .4985 .51776 .49034 .51987 Mtetra
.946 .941 .751 r
.49034 .51987 .4985 .51776 .51308 .49817 .50507 .4964 Mtetra
.889 .916 .837 r
.50507 .4964 .51308 .49817 .52761 .48461 .51971 .48001 Mtetra
.815 .865 .885 r
.51971 .48001 .52761 .48461 .54216 .47494 .53433 .46856 Mtetra
.754 .818 .903 r
.53433 .46856 .54216 .47494 .55676 .46754 .54899 .46011 Mtetra
.714 .785 .908 r
.54899 .46011 .55676 .46754 .57143 .4614 .56372 .45338 Mtetra
.691 .765 .909 r
.56372 .45338 .57143 .4614 .58619 .45593 .57853 .44757 Mtetra
.678 .754 .908 r
.57853 .44757 .58619 .45593 .60102 .45081 .59341 .44224 Mtetra
.671 .748 .908 r
.59341 .44224 .60102 .45081 .61593 .44586 .60837 .43716 Mtetra
.668 .745 .908 r
.60837 .43716 .61593 .44586 .63092 .44099 .62342 .4322 Mtetra
.666 .743 .908 r
.62342 .4322 .63092 .44099 .646 .43615 .63855 .42729 Mtetra
.665 .742 .908 r
.63855 .42729 .646 .43615 .66116 .43132 .65376 .42239 Mtetra
.664 .742 .908 r
.65376 .42239 .66116 .43132 .6764 .42647 .66906 .41749 Mtetra
.66906 .41749 .6764 .42647 .69172 .4216 .68444 .41257 Mtetra
.664 .741 .908 r
.68444 .41257 .69172 .4216 .70712 .41672 .6999 .40763 Mtetra
.6999 .40763 .70712 .41672 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40686 .73109 .39768 Mtetra
.73109 .39768 .73819 .40686 .75385 .4019 .74681 .39266 Mtetra
.74681 .39266 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.652 .766 .933 r
.30183 .72747 .31103 .73483 .3254 .7305 .31625 .72318 Mtetra
.658 .77 .932 r
.31625 .72318 .3254 .7305 .33987 .72589 .33076 .71868 Mtetra
.668 .776 .93 r
.33076 .71868 .33987 .72589 .35443 .72075 .34536 .71378 Mtetra
.686 .787 .927 r
.34536 .71378 .35443 .72075 .3691 .71464 .36007 .70817 Mtetra
.718 .806 .919 r
.36007 .70817 .3691 .71464 .38391 .70679 .3749 .70126 Mtetra
.767 .834 .903 r
.3749 .70126 .38391 .70679 .39888 .69589 .38988 .69201 Mtetra
.834 .87 .87 r
.38988 .69201 .39888 .69589 .41403 .68001 .40503 .67881 Mtetra
.905 .901 .811 r
.40503 .67881 .41403 .68001 .42936 .65697 .42037 .65949 Mtetra
.955 .916 .734 r
.42037 .65949 .42936 .65697 .44479 .62575 .43587 .63219 Mtetra
.977 .916 .661 r
.43587 .63219 .44479 .62575 .4602 .58863 .45142 .59731 Mtetra
.979 .916 .621 r
.45142 .59731 .4602 .58863 .4754 .5514 .46685 .55913 Mtetra
.974 .925 .634 r
.46685 .55913 .4754 .5514 .49034 .51987 .48202 .52405 Mtetra
.961 .939 .704 r
.48202 .52405 .49034 .51987 .50507 .4964 .49694 .49638 Mtetra
.921 .933 .797 r
.49694 .49638 .50507 .4964 .51971 .48001 .51171 .47659 Mtetra
.852 .892 .866 r
.51171 .47659 .51971 .48001 .53433 .46856 .52642 .46286 Mtetra
.782 .84 .896 r
.52642 .46286 .53433 .46856 .54899 .46011 .54115 .45304 Mtetra
.731 .799 .906 r
.54115 .45304 .54899 .46011 .56372 .45338 .55593 .44551 Mtetra
.701 .774 .908 r
.55593 .44551 .56372 .45338 .57853 .44757 .57079 .43924 Mtetra
.683 .759 .909 r
.57079 .43924 .57853 .44757 .59341 .44224 .58573 .43365 Mtetra
.674 .751 .908 r
.58573 .43365 .59341 .44224 .60837 .43716 .60074 .42841 Mtetra
.669 .746 .908 r
.60074 .42841 .60837 .43716 .62342 .4322 .61585 .42334 Mtetra
.666 .744 .908 r
.61585 .42334 .62342 .4322 .63855 .42729 .63103 .41834 Mtetra
.665 .743 .908 r
.63103 .41834 .63855 .42729 .65376 .42239 .6463 .41338 Mtetra
.664 .742 .908 r
.6463 .41338 .65376 .42239 .66906 .41749 .66165 .40842 Mtetra
.66165 .40842 .66906 .41749 .68444 .41257 .67709 .40345 Mtetra
.664 .741 .908 r
.67709 .40345 .68444 .41257 .6999 .40763 .69261 .39846 Mtetra
.69261 .39846 .6999 .40763 .71545 .40267 .70822 .39344 Mtetra
.70822 .39344 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39266 .73969 .38334 Mtetra
.73969 .38334 .74681 .39266 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.65 .765 .933 r
.29255 .72 .30183 .72747 .31625 .72318 .30701 .71574 Mtetra
.654 .768 .932 r
.30701 .71574 .31625 .72318 .33076 .71868 .32156 .7113 Mtetra
.662 .772 .931 r
.32156 .7113 .33076 .71868 .34536 .71378 .33621 .70658 Mtetra
.676 .781 .929 r
.33621 .70658 .34536 .71378 .36007 .70817 .35095 .70132 Mtetra
.7 .795 .924 r
.35095 .70132 .36007 .70817 .3749 .70126 .36581 .69509 Mtetra
.74 .819 .913 r
.36581 .69509 .3749 .70126 .38988 .69201 .3808 .68711 Mtetra
.799 .852 .889 r
.3808 .68711 .38988 .69201 .40503 .67881 .39596 .67605 Mtetra
.871 .887 .844 r
.39596 .67605 .40503 .67881 .42037 .65949 .41131 .65998 Mtetra
.933 .911 .774 r
.41131 .65998 .42037 .65949 .43587 .63219 .42684 .63669 Mtetra
.97 .917 .695 r
.42684 .63669 .43587 .63219 .45142 .59731 .4425 .60516 Mtetra
.98 .915 .636 r
.4425 .60516 .45142 .59731 .46685 .55913 .45811 .56771 Mtetra
.977 .919 .62 r
.45811 .56771 .46685 .55913 .48202 .52405 .47352 .53015 Mtetra
.97 .933 .663 r
.47352 .53015 .48202 .52405 .49694 .49638 .48866 .49835 Mtetra
.946 .94 .751 r
.48866 .49835 .49694 .49638 .51171 .47659 .50359 .47464 Mtetra
.889 .915 .837 r
.50359 .47464 .51171 .47659 .52642 .46286 .51841 .45807 Mtetra
.815 .865 .885 r
.51841 .45807 .52642 .46286 .54115 .45304 .53322 .44645 Mtetra
.754 .818 .903 r
.53322 .44645 .54115 .45304 .55593 .44551 .54806 .43787 Mtetra
.714 .785 .908 r
.54806 .43787 .55593 .44551 .57079 .43924 .56298 .431 Mtetra
.691 .765 .909 r
.56298 .431 .57079 .43924 .58573 .43365 .57797 .42506 Mtetra
.678 .754 .908 r
.57797 .42506 .58573 .43365 .60074 .42841 .59304 .41961 Mtetra
.671 .748 .908 r
.59304 .41961 .60074 .42841 .61585 .42334 .60819 .41441 Mtetra
.668 .745 .908 r
.60819 .41441 .61585 .42334 .63103 .41834 .62343 .40932 Mtetra
.666 .743 .908 r
.62343 .40932 .63103 .41834 .6463 .41338 .63876 .40429 Mtetra
.665 .742 .908 r
.63876 .40429 .6463 .41338 .66165 .40842 .65417 .39927 Mtetra
.664 .742 .908 r
.65417 .39927 .66165 .40842 .67709 .40345 .66966 .39424 Mtetra
.66966 .39424 .67709 .40345 .69261 .39846 .68524 .38919 Mtetra
.664 .741 .908 r
.68524 .38919 .69261 .39846 .70822 .39344 .70091 .38412 Mtetra
.70091 .38412 .70822 .39344 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38334 .7325 .37391 Mtetra
.7325 .37391 .73969 .38334 .75556 .37824 .74844 .36876 Mtetra
.74844 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.649 .764 .933 r
.28317 .71245 .29255 .72 .30701 .71574 .29768 .70818 Mtetra
.652 .766 .933 r
.29768 .70818 .30701 .71574 .32156 .7113 .31228 .70379 Mtetra
.658 .77 .932 r
.31228 .70379 .32156 .7113 .33621 .70658 .32696 .69918 Mtetra
.668 .776 .93 r
.32696 .69918 .33621 .70658 .35095 .70132 .34175 .69417 Mtetra
.686 .787 .927 r
.34175 .69417 .35095 .70132 .36581 .69509 .35664 .68844 Mtetra
.718 .806 .919 r
.35664 .68844 .36581 .69509 .3808 .68711 .37166 .68139 Mtetra
.767 .834 .903 r
.37166 .68139 .3808 .68711 .39596 .67605 .38683 .672 Mtetra
.835 .87 .87 r
.38683 .672 .39596 .67605 .41131 .65998 .40218 .65862 Mtetra
.905 .901 .811 r
.40218 .65862 .41131 .65998 .42684 .63669 .41772 .63908 Mtetra
.955 .916 .733 r
.41772 .63908 .42684 .63669 .4425 .60516 .43344 .6115 Mtetra
.977 .916 .661 r
.43344 .6115 .4425 .60516 .45811 .56771 .4492 .5763 Mtetra
.979 .916 .621 r
.4492 .5763 .45811 .56771 .47352 .53015 .46484 .53778 Mtetra
.974 .925 .634 r
.46484 .53778 .47352 .53015 .48866 .49835 .48022 .50239 Mtetra
.961 .939 .704 r
.48022 .50239 .48866 .49835 .50359 .47464 .49534 .47446 Mtetra
.921 .932 .798 r
.49534 .47446 .50359 .47464 .51841 .45807 .5103 .45446 Mtetra
.852 .891 .866 r
.5103 .45446 .51841 .45807 .53322 .44645 .5252 .44055 Mtetra
.782 .84 .896 r
.5252 .44055 .53322 .44645 .54806 .43787 .54011 .43058 Mtetra
.731 .799 .906 r
.54011 .43058 .54806 .43787 .56298 .431 .55508 .42291 Mtetra
.701 .774 .908 r
.55508 .42291 .56298 .431 .57797 .42506 .57013 .41652 Mtetra
.683 .759 .909 r
.57013 .41652 .57797 .42506 .59304 .41961 .58525 .4108 Mtetra
.674 .751 .908 r
.58525 .4108 .59304 .41961 .60819 .41441 .60046 .40543 Mtetra
.669 .746 .908 r
.60046 .40543 .60819 .41441 .62343 .40932 .61576 .40023 Mtetra
.666 .744 .908 r
.61576 .40023 .62343 .40932 .63876 .40429 .63114 .39511 Mtetra
.665 .743 .908 r
.63114 .39511 .63876 .40429 .65417 .39927 .64661 .39002 Mtetra
.664 .742 .908 r
.64661 .39002 .65417 .39927 .66966 .39424 .66216 .38493 Mtetra
.66216 .38493 .66966 .39424 .68524 .38919 .6778 .37983 Mtetra
.664 .741 .908 r
.6778 .37983 .68524 .38919 .70091 .38412 .69352 .37471 Mtetra
.69352 .37471 .70091 .38412 .71666 .37903 .70934 .36956 Mtetra
.70934 .36956 .71666 .37903 .7325 .37391 .72524 .36439 Mtetra
.72524 .36439 .7325 .37391 .74844 .36876 .74123 .35919 Mtetra
.74123 .35919 .74844 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.648 .764 .933 r
.2737 .7048 .28317 .71245 .29768 .70818 .28826 .70052 Mtetra
.65 .765 .933 r
.28826 .70052 .29768 .70818 .31228 .70379 .3029 .69615 Mtetra
.654 .768 .932 r
.3029 .69615 .31228 .70379 .32696 .69918 .31763 .6916 Mtetra
.662 .772 .931 r
.31763 .6916 .32696 .69918 .34175 .69417 .33245 .68676 Mtetra
.676 .781 .929 r
.33245 .68676 .34175 .69417 .35664 .68844 .34738 .68139 Mtetra
.7 .795 .924 r
.34738 .68139 .35664 .68844 .37166 .68139 .36243 .67503 Mtetra
.74 .819 .913 r
.36243 .67503 .37166 .68139 .38683 .672 .37761 .66691 Mtetra
.799 .852 .89 r
.37761 .66691 .38683 .672 .40218 .65862 .39297 .65569 Mtetra
.871 .887 .844 r
.39297 .65569 .40218 .65862 .41772 .63908 .40852 .63941 Mtetra
.934 .911 .773 r
.40852 .63941 .41772 .63908 .43344 .6115 .42427 .61587 Mtetra
.97 .917 .695 r
.42427 .61587 .43344 .6115 .4492 .5763 .44014 .58405 Mtetra
.98 .915 .636 r
.44014 .58405 .4492 .5763 .46484 .53778 .45597 .54625 Mtetra
.977 .919 .62 r
.45597 .54625 .46484 .53778 .48022 .50239 .4716 .50836 Mtetra
.97 .933 .663 r
.4716 .50836 .48022 .50239 .49534 .47446 .48694 .47627 Mtetra
.946 .94 .751 r
.48694 .47627 .49534 .47446 .5103 .45446 .50207 .45233 Mtetra
.889 .915 .837 r
.50207 .45233 .5103 .45446 .5252 .44055 .51708 .43556 Mtetra
.815 .865 .885 r
.51708 .43556 .5252 .44055 .54011 .43058 .53207 .42379 Mtetra
.754 .817 .902 r
.53207 .42379 .54011 .43058 .55508 .42291 .54711 .41506 Mtetra
.714 .785 .907 r
.54711 .41506 .55508 .42291 .57013 .41652 .56221 .40805 Mtetra
.691 .765 .908 r
.56221 .40805 .57013 .41652 .58525 .4108 .57739 .40198 Mtetra
.678 .754 .908 r
.57739 .40198 .58525 .4108 .60046 .40543 .59266 .3964 Mtetra
.671 .748 .908 r
.59266 .3964 .60046 .40543 .61576 .40023 .60801 .39107 Mtetra
.668 .745 .908 r
.60801 .39107 .61576 .40023 .63114 .39511 .62344 .38585 Mtetra
.666 .743 .908 r
.62344 .38585 .63114 .39511 .64661 .39002 .63897 .38069 Mtetra
.665 .742 .908 r
.63897 .38069 .64661 .39002 .66216 .38493 .65458 .37553 Mtetra
.664 .742 .908 r
.65458 .37553 .66216 .38493 .6778 .37983 .67028 .37037 Mtetra
.67028 .37037 .6778 .37983 .69352 .37471 .68606 .3652 Mtetra
.664 .741 .908 r
.68606 .3652 .69352 .37471 .70934 .36956 .70194 .35999 Mtetra
.70194 .35999 .70934 .36956 .72524 .36439 .7179 .35477 Mtetra
.7179 .35477 .72524 .36439 .74123 .35919 .73396 .34951 Mtetra
.73396 .34951 .74123 .35919 .75732 .35396 .75011 .34422 Mtetra
.75011 .34422 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.648 .763 .933 r
.26413 .69706 .2737 .7048 .28826 .70052 .27874 .69277 Mtetra
.649 .764 .933 r
.27874 .69277 .28826 .70052 .3029 .69615 .29342 .68839 Mtetra
.652 .766 .933 r
.29342 .68839 .3029 .69615 .31763 .6916 .3082 .68389 Mtetra
.658 .77 .932 r
.3082 .68389 .31763 .6916 .33245 .68676 .32307 .67916 Mtetra
.668 .776 .93 r
.32307 .67916 .33245 .68676 .34738 .68139 .33803 .67403 Mtetra
.686 .787 .927 r
.33803 .67403 .34738 .68139 .36243 .67503 .35311 .66818 Mtetra
.718 .806 .92 r
.35311 .66818 .36243 .67503 .37761 .66691 .36832 .661 Mtetra
.767 .834 .903 r
.36832 .661 .37761 .66691 .39297 .65569 .38369 .65145 Mtetra
.835 .87 .87 r
.38369 .65145 .39297 .65569 .40852 .63941 .39925 .63789 Mtetra
.905 .901 .811 r
.39925 .63789 .40852 .63941 .42427 .61587 .415 .61812 Mtetra
.955 .916 .733 r
.415 .61812 .42427 .61587 .44014 .58405 .43094 .59026 Mtetra
.977 .916 .661 r
.43094 .59026 .44014 .58405 .45597 .54625 .44693 .55473 Mtetra
.979 .916 .621 r
.44693 .55473 .45597 .54625 .4716 .50836 .46279 .51587 Mtetra
.974 .925 .635 r
.46279 .51587 .4716 .50836 .48694 .47627 .47838 .48016 Mtetra
.961 .939 .704 r
.47838 .48016 .48694 .47627 .50207 .45233 .4937 .45197 Mtetra
.921 .932 .798 r
.4937 .45197 .50207 .45233 .51708 .43556 .50885 .43175 Mtetra
.852 .891 .866 r
.50885 .43175 .51708 .43556 .53207 .42379 .52394 .41767 Mtetra
.782 .84 .896 r
.52394 .41767 .53207 .42379 .54711 .41506 .53905 .40755 Mtetra
.731 .799 .906 r
.53905 .40755 .54711 .41506 .56221 .40805 .55421 .39974 Mtetra
.701 .773 .908 r
.55421 .39974 .56221 .40805 .57739 .40198 .56945 .3932 Mtetra
.683 .759 .909 r
.56945 .3932 .57739 .40198 .59266 .3964 .58477 .38735 Mtetra
.674 .751 .908 r
.58477 .38735 .59266 .3964 .60801 .39107 .60018 .38185 Mtetra
.669 .746 .908 r
.60018 .38185 .60801 .39107 .62344 .38585 .61567 .37652 Mtetra
.666 .744 .908 r
.61567 .37652 .62344 .38585 .63897 .38069 .63125 .37127 Mtetra
.665 .743 .908 r
.63125 .37127 .63897 .38069 .65458 .37553 .64692 .36605 Mtetra
.664 .742 .908 r
.64692 .36605 .65458 .37553 .67028 .37037 .66268 .36082 Mtetra
.66268 .36082 .67028 .37037 .68606 .3652 .67853 .35559 Mtetra
.664 .741 .908 r
.67853 .35559 .68606 .3652 .70194 .35999 .69446 .35033 Mtetra
.69446 .35033 .70194 .35999 .7179 .35477 .71049 .34504 Mtetra
.71049 .34504 .7179 .35477 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34422 .74282 .33439 Mtetra
.74282 .33439 .75011 .34422 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.647 .763 .934 r
.25447 .68924 .26413 .69706 .27874 .69277 .26912 .68492 Mtetra
.648 .764 .933 r
.26912 .68492 .27874 .69277 .29342 .68839 .28385 .68053 Mtetra
.65 .765 .933 r
.28385 .68053 .29342 .68839 .3082 .68389 .29867 .67604 Mtetra
.654 .768 .932 r
.29867 .67604 .3082 .68389 .32307 .67916 .31359 .67138 Mtetra
.662 .772 .931 r
.31359 .67138 .32307 .67916 .33803 .67403 .3286 .66642 Mtetra
.676 .781 .929 r
.3286 .66642 .33803 .67403 .35311 .66818 .34371 .66093 Mtetra
.7 .795 .924 r
.34371 .66093 .35311 .66818 .36832 .661 .35895 .65444 Mtetra
.74 .819 .913 r
.35895 .65444 .36832 .661 .38369 .65145 .37434 .64617 Mtetra
.799 .852 .89 r
.37434 .64617 .38369 .65145 .39925 .63789 .3899 .63478 Mtetra
.871 .887 .844 r
.3899 .63478 .39925 .63789 .415 .61812 .40566 .6183 Mtetra
.934 .911 .773 r
.40566 .6183 .415 .61812 .43094 .59026 .42162 .5945 Mtetra
.97 .917 .694 r
.42162 .5945 .43094 .59026 .44693 .55473 .43772 .56237 Mtetra
.98 .915 .635 r
.43772 .56237 .44693 .55473 .46279 .51587 .45378 .52423 Mtetra
.977 .919 .621 r
.45378 .52423 .46279 .51587 .47838 .48016 .46963 .486 Mtetra
.97 .933 .663 r
.46963 .486 .47838 .48016 .4937 .45197 .48518 .45361 Mtetra
.946 .94 .751 r
.48518 .45361 .4937 .45197 .50885 .43175 .5005 .42943 Mtetra
.889 .915 .837 r
.5005 .42943 .50885 .43175 .52394 .41767 .51571 .41247 Mtetra
.815 .865 .885 r
.51571 .41247 .52394 .41767 .53905 .40755 .5309 .40053 Mtetra
.754 .817 .902 r
.5309 .40053 .53905 .40755 .55421 .39974 .54613 .39165 Mtetra
.714 .785 .907 r
.54613 .39165 .55421 .39974 .56945 .3932 .56143 .38451 Mtetra
.691 .765 .908 r
.56143 .38451 .56945 .3932 .58477 .38735 .5768 .3783 Mtetra
.678 .754 .908 r
.5768 .3783 .58477 .38735 .60018 .38185 .59227 .37258 Mtetra
.671 .748 .908 r
.59227 .37258 .60018 .38185 .61567 .37652 .60782 .36712 Mtetra
.668 .745 .908 r
.60782 .36712 .61567 .37652 .63125 .37127 .62346 .36177 Mtetra
.666 .743 .908 r
.62346 .36177 .63125 .37127 .64692 .36605 .63918 .35647 Mtetra
.665 .742 .908 r
.63918 .35647 .64692 .36605 .66268 .36082 .655 .35118 Mtetra
.664 .742 .908 r
.655 .35118 .66268 .36082 .67853 .35559 .67091 .34588 Mtetra
.67091 .34588 .67853 .35559 .69446 .35033 .68691 .34056 Mtetra
.664 .741 .908 r
.68691 .34056 .69446 .35033 .71049 .34504 .703 .33522 Mtetra
.703 .33522 .71049 .34504 .72661 .33973 .71918 .32985 Mtetra
.71918 .32985 .72661 .33973 .74282 .33439 .73545 .32446 Mtetra
.73545 .32446 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.647 .763 .934 r
.2447 .68133 .25447 .68924 .26912 .68492 .2594 .67697 Mtetra
.648 .763 .933 r
.2594 .67697 .26912 .68492 .28385 .68053 .27418 .67256 Mtetra
.649 .764 .933 r
.27418 .67256 .28385 .68053 .29867 .67604 .28905 .66807 Mtetra
.652 .766 .933 r
.28905 .66807 .29867 .67604 .31359 .67138 .30401 .66345 Mtetra
.658 .77 .932 r
.30401 .66345 .31359 .67138 .3286 .66642 .31907 .65861 Mtetra
.668 .776 .93 r
.31907 .65861 .3286 .66642 .34371 .66093 .33422 .65336 Mtetra
.686 .787 .927 r
.33422 .65336 .34371 .66093 .35895 .65444 .3495 .64737 Mtetra
.718 .806 .92 r
.3495 .64737 .35895 .65444 .37434 .64617 .3649 .64005 Mtetra
.767 .835 .904 r
.3649 .64005 .37434 .64617 .3899 .63478 .38047 .63035 Mtetra
.835 .87 .87 r
.38047 .63035 .3899 .63478 .40566 .6183 .39624 .61661 Mtetra
.905 .901 .811 r
.39624 .61661 .40566 .6183 .42162 .5945 .41221 .5966 Mtetra
.955 .916 .733 r
.41221 .5966 .42162 .5945 .43772 .56237 .42837 .56846 Mtetra
.977 .916 .661 r
.42837 .56846 .43772 .56237 .45378 .52423 .44459 .53259 Mtetra
.979 .916 .621 r
.44459 .53259 .45378 .52423 .46963 .486 .46068 .49338 Mtetra
.974 .925 .635 r
.46068 .49338 .46963 .486 .48518 .45361 .47649 .45735 Mtetra
.961 .939 .704 r
.47649 .45735 .48518 .45361 .5005 .42943 .49202 .42889 Mtetra
.921 .932 .798 r
.49202 .42889 .5005 .42943 .51571 .41247 .50737 .40846 Mtetra
.852 .891 .865 r
.50737 .40846 .51571 .41247 .5309 .40053 .52266 .3942 Mtetra
.782 .84 .896 r
.52266 .3942 .5309 .40053 .54613 .39165 .53796 .38391 Mtetra
.731 .799 .906 r
.53796 .38391 .54613 .39165 .56143 .38451 .55332 .37595 Mtetra
.701 .773 .908 r
.55332 .37595 .56143 .38451 .5768 .3783 .56875 .36928 Mtetra
.683 .759 .909 r
.56875 .36928 .5768 .3783 .59227 .37258 .58427 .36329 Mtetra
.674 .751 .908 r
.58427 .36329 .59227 .37258 .60782 .36712 .59988 .35765 Mtetra
.669 .746 .908 r
.59988 .35765 .60782 .36712 .62346 .36177 .61558 .35219 Mtetra
.666 .744 .908 r
.61558 .35219 .62346 .36177 .63918 .35647 .63137 .3468 Mtetra
.665 .743 .908 r
.63137 .3468 .63918 .35647 .655 .35118 .64724 .34144 Mtetra
.664 .742 .908 r
.64724 .34144 .655 .35118 .67091 .34588 .66321 .33607 Mtetra
.66321 .33607 .67091 .34588 .68691 .34056 .67927 .3307 Mtetra
.664 .741 .908 r
.67927 .3307 .68691 .34056 .703 .33522 .69543 .3253 Mtetra
.69543 .3253 .703 .33522 .71918 .32985 .71167 .31987 Mtetra
.71167 .31987 .71918 .32985 .73545 .32446 .72801 .31441 Mtetra
.72801 .31441 .73545 .32446 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.647 .763 .934 r
.23483 .67334 .2447 .68133 .2594 .67697 .24958 .66894 Mtetra
.24958 .66894 .2594 .67697 .27418 .67256 .26441 .6645 Mtetra
.648 .764 .933 r
.26441 .6645 .27418 .67256 .28905 .66807 .27933 .66 Mtetra
.65 .765 .933 r
.27933 .66 .28905 .66807 .30401 .66345 .29434 .65539 Mtetra
.654 .768 .932 r
.29434 .65539 .30401 .66345 .31907 .65861 .30944 .65061 Mtetra
.662 .772 .931 r
.30944 .65061 .31907 .65861 .33422 .65336 .32464 .64553 Mtetra
.676 .781 .929 r
.32464 .64553 .33422 .65336 .3495 .64737 .33995 .63991 Mtetra
.7 .795 .924 r
.33995 .63991 .3495 .64737 .3649 .64005 .35539 .63329 Mtetra
.74 .819 .913 r
.35539 .63329 .3649 .64005 .38047 .63035 .37097 .62487 Mtetra
.799 .852 .89 r
.37097 .62487 .38047 .63035 .39624 .61661 .38674 .6133 Mtetra
.871 .887 .844 r
.38674 .6133 .39624 .61661 .41221 .5966 .40272 .59661 Mtetra
.934 .911 .773 r
.40272 .59661 .41221 .5966 .42837 .56846 .41891 .57256 Mtetra
.97 .917 .694 r
.41891 .57256 .42837 .56846 .44459 .53259 .43523 .5401 Mtetra
.98 .915 .635 r
.43523 .5401 .44459 .53259 .46068 .49338 .45153 .50162 Mtetra
.977 .919 .621 r
.45153 .50162 .46068 .49338 .47649 .45735 .4676 .46305 Mtetra
.97 .933 .664 r
.4676 .46305 .47649 .45735 .49202 .42889 .48337 .43036 Mtetra
.946 .94 .752 r
.48337 .43036 .49202 .42889 .50737 .40846 .4989 .40594 Mtetra
.888 .915 .837 r
.4989 .40594 .50737 .40846 .52266 .3942 .51431 .38878 Mtetra
.815 .865 .884 r
.51431 .38878 .52266 .3942 .53796 .38391 .5297 .37666 Mtetra
.754 .817 .902 r
.5297 .37666 .53796 .38391 .55332 .37595 .54512 .36763 Mtetra
.714 .785 .907 r
.54512 .36763 .55332 .37595 .56875 .36928 .56062 .36034 Mtetra
.691 .765 .908 r
.56062 .36034 .56875 .36928 .58427 .36329 .5762 .35399 Mtetra
.678 .754 .908 r
.5762 .35399 .58427 .36329 .59988 .35765 .59186 .34814 Mtetra
.671 .748 .908 r
.59186 .34814 .59988 .35765 .61558 .35219 .60762 .34253 Mtetra
.668 .745 .908 r
.60762 .34253 .61558 .35219 .63137 .3468 .62347 .33704 Mtetra
.666 .743 .908 r
.62347 .33704 .63137 .3468 .64724 .34144 .63941 .3316 Mtetra
.665 .742 .908 r
.63941 .3316 .64724 .34144 .66321 .33607 .65544 .32617 Mtetra
.664 .742 .908 r
.65544 .32617 .66321 .33607 .67927 .3307 .67156 .32073 Mtetra
.67156 .32073 .67927 .3307 .69543 .3253 .68778 .31527 Mtetra
.664 .741 .908 r
.68778 .31527 .69543 .3253 .71167 .31987 .70409 .30978 Mtetra
.70409 .30978 .71167 .31987 .72801 .31441 .72049 .30426 Mtetra
.72049 .30426 .72801 .31441 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28754 Mtetra
.77027 .28754 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.646 .763 .934 r
.22486 .66526 .23483 .67334 .24958 .66894 .23966 .66082 Mtetra
.647 .763 .934 r
.23966 .66082 .24958 .66894 .26441 .6645 .25454 .65635 Mtetra
.648 .763 .933 r
.25454 .65635 .26441 .6645 .27933 .66 .2695 .65182 Mtetra
.649 .764 .933 r
.2695 .65182 .27933 .66 .29434 .65539 .28456 .64721 Mtetra
.652 .766 .933 r
.28456 .64721 .29434 .65539 .30944 .65061 .29971 .64247 Mtetra
.658 .77 .932 r
.29971 .64247 .30944 .65061 .32464 .64553 .31496 .6375 Mtetra
.668 .776 .93 r
.31496 .6375 .32464 .64553 .33995 .63991 .33031 .63212 Mtetra
.686 .787 .927 r
.33031 .63212 .33995 .63991 .35539 .63329 .34578 .626 Mtetra
.718 .806 .92 r
.34578 .626 .35539 .63329 .37097 .62487 .36139 .61854 Mtetra
.767 .835 .904 r
.36139 .61854 .37097 .62487 .38674 .6133 .37717 .60868 Mtetra
.835 .87 .87 r
.37717 .60868 .38674 .6133 .40272 .59661 .39315 .59474 Mtetra
.905 .902 .811 r
.39315 .59474 .40272 .59661 .41891 .57256 .40934 .5745 Mtetra
.956 .916 .733 r
.40934 .5745 .41891 .57256 .43523 .5401 .42573 .54606 Mtetra
.977 .916 .66 r
.42573 .54606 .43523 .5401 .45153 .50162 .44219 .50985 Mtetra
.979 .916 .621 r
.44219 .50985 .45153 .50162 .4676 .46305 .45851 .47029 Mtetra
.974 .925 .635 r
.45851 .47029 .4676 .46305 .48337 .43036 .47454 .43394 Mtetra
.961 .939 .705 r
.47454 .43394 .48337 .43036 .4989 .40594 .49029 .4052 Mtetra
.921 .932 .798 r
.49029 .4052 .4989 .40594 .51431 .38878 .50585 .38455 Mtetra
.852 .891 .865 r
.50585 .38455 .51431 .38878 .5297 .37666 .52134 .3701 Mtetra
.782 .839 .896 r
.52134 .3701 .5297 .37666 .54512 .36763 .53684 .35965 Mtetra
.731 .799 .906 r
.53684 .35965 .54512 .36763 .56062 .36034 .5524 .35154 Mtetra
.701 .773 .908 r
.5524 .35154 .56062 .36034 .5762 .35399 .56804 .34472 Mtetra
.683 .759 .908 r
.56804 .34472 .5762 .35399 .59186 .34814 .58376 .33859 Mtetra
.674 .751 .908 r
.58376 .33859 .59186 .34814 .60762 .34253 .59958 .33281 Mtetra
.669 .746 .908 r
.59958 .33281 .60762 .34253 .62347 .33704 .61549 .3272 Mtetra
.666 .744 .908 r
.61549 .3272 .62347 .33704 .63941 .3316 .63148 .32167 Mtetra
.665 .743 .908 r
.63148 .32167 .63941 .3316 .65544 .32617 .64758 .31616 Mtetra
.664 .742 .908 r
.64758 .31616 .65544 .32617 .67156 .32073 .66376 .31065 Mtetra
.66376 .31065 .67156 .32073 .68778 .31527 .68004 .30513 Mtetra
.664 .741 .908 r
.68004 .30513 .68778 .31527 .70409 .30978 .69642 .29958 Mtetra
.69642 .29958 .70409 .30978 .72049 .30426 .71289 .29401 Mtetra
.71289 .29401 .72049 .30426 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28277 Mtetra
.74611 .28277 .75358 .29314 .77027 .28754 .76287 .2771 Mtetra
.76287 .2771 .77027 .28754 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .763 .934 r
.21479 .65709 .22486 .66526 .23966 .66082 .22963 .65261 Mtetra
.647 .763 .934 r
.22963 .65261 .23966 .66082 .25454 .65635 .24456 .6481 Mtetra
.24456 .6481 .25454 .65635 .2695 .65182 .25958 .64354 Mtetra
.648 .764 .933 r
.25958 .64354 .2695 .65182 .28456 .64721 .27468 .63891 Mtetra
.65 .765 .933 r
.27468 .63891 .28456 .64721 .29971 .64247 .28988 .63418 Mtetra
.654 .768 .932 r
.28988 .63418 .29971 .64247 .31496 .6375 .30518 .62928 Mtetra
.662 .772 .931 r
.30518 .62928 .31496 .6375 .33031 .63212 .32057 .62407 Mtetra
.676 .781 .929 r
.32057 .62407 .33031 .63212 .34578 .626 .33608 .61832 Mtetra
.7 .795 .924 r
.33608 .61832 .34578 .626 .36139 .61854 .35172 .61155 Mtetra
.74 .819 .913 r
.35172 .61155 .36139 .61854 .37717 .60868 .36752 .60298 Mtetra
.799 .852 .89 r
.36752 .60298 .37717 .60868 .39315 .59474 .3835 .59124 Mtetra
.871 .888 .844 r
.3835 .59124 .39315 .59474 .40934 .5745 .3997 .57433 Mtetra
.934 .911 .773 r
.3997 .57433 .40934 .5745 .42573 .54606 .41611 .55001 Mtetra
.97 .918 .694 r
.41611 .55001 .42573 .54606 .44219 .50985 .43268 .51723 Mtetra
.98 .915 .635 r
.43268 .51723 .44219 .50985 .45851 .47029 .44921 .47839 Mtetra
.977 .919 .621 r
.44921 .47839 .45851 .47029 .47454 .43394 .46552 .43948 Mtetra
.97 .932 .664 r
.46552 .43948 .47454 .43394 .49029 .4052 .48151 .40649 Mtetra
.946 .94 .752 r
.48151 .40649 .49029 .4052 .50585 .38455 .49725 .38182 Mtetra
.888 .914 .837 r
.49725 .38182 .50585 .38455 .52134 .3701 .51287 .36445 Mtetra
.815 .865 .884 r
.51287 .36445 .52134 .3701 .53684 .35965 .52846 .35216 Mtetra
.754 .817 .902 r
.52846 .35216 .53684 .35965 .5524 .35154 .54409 .34297 Mtetra
.714 .785 .907 r
.54409 .34297 .5524 .35154 .56804 .34472 .55979 .33552 Mtetra
.691 .765 .908 r
.55979 .33552 .56804 .34472 .58376 .33859 .57558 .32903 Mtetra
.678 .754 .908 r
.57558 .32903 .58376 .33859 .59958 .33281 .59145 .32303 Mtetra
.671 .748 .908 r
.59145 .32303 .59958 .33281 .61549 .3272 .60742 .31728 Mtetra
.668 .745 .908 r
.60742 .31728 .61549 .3272 .63148 .32167 .62348 .31164 Mtetra
.666 .743 .908 r
.62348 .31164 .63148 .32167 .64758 .31616 .63963 .30606 Mtetra
.665 .742 .908 r
.63963 .30606 .64758 .31616 .66376 .31065 .65588 .30048 Mtetra
.664 .742 .908 r
.65588 .30048 .66376 .31065 .68004 .30513 .67223 .29489 Mtetra
.67223 .29489 .68004 .30513 .69642 .29958 .68867 .28928 Mtetra
.664 .741 .908 r
.68867 .28928 .69642 .29958 .71289 .29401 .7052 .28364 Mtetra
.7052 .28364 .71289 .29401 .72945 .2884 .72183 .27797 Mtetra
.72183 .27797 .72945 .2884 .74611 .28277 .73856 .27227 Mtetra
.73856 .27227 .74611 .28277 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .763 .934 r
.2046 .64883 .21479 .65709 .22963 .65261 .2195 .64431 Mtetra
.2195 .64431 .22963 .65261 .24456 .6481 .23448 .63976 Mtetra
.647 .763 .934 r
.23448 .63976 .24456 .6481 .25958 .64354 .24954 .63516 Mtetra
.648 .763 .933 r
.24954 .63516 .25958 .64354 .27468 .63891 .2647 .63051 Mtetra
.649 .764 .933 r
.2647 .63051 .27468 .63891 .28988 .63418 .27995 .62578 Mtetra
.652 .766 .933 r
.27995 .62578 .28988 .63418 .30518 .62928 .29529 .62091 Mtetra
.658 .77 .932 r
.29529 .62091 .30518 .62928 .32057 .62407 .31073 .61581 Mtetra
.668 .776 .93 r
.31073 .61581 .32057 .62407 .33608 .61832 .32629 .6103 Mtetra
.686 .787 .927 r
.32629 .6103 .33608 .61832 .35172 .61155 .34196 .60404 Mtetra
.718 .806 .92 r
.34196 .60404 .35172 .61155 .36752 .60298 .35778 .59643 Mtetra
.767 .835 .904 r
.35778 .59643 .36752 .60298 .3835 .59124 .37377 .5864 Mtetra
.835 .871 .87 r
.37377 .5864 .3835 .59124 .3997 .57433 .38997 .57226 Mtetra
.905 .902 .811 r
.38997 .57226 .3997 .57433 .41611 .55001 .4064 .55178 Mtetra
.956 .917 .733 r
.4064 .55178 .41611 .55001 .43268 .51723 .42302 .52304 Mtetra
.977 .917 .66 r
.42302 .52304 .43268 .51723 .44921 .47839 .43972 .48649 Mtetra
.979 .916 .621 r
.43972 .48649 .44921 .47839 .46552 .43948 .45628 .44657 Mtetra
.974 .925 .635 r
.45628 .44657 .46552 .43948 .48151 .40649 .47255 .40989 Mtetra
.961 .939 .705 r
.47255 .40989 .48151 .40649 .49725 .38182 .48851 .38088 Mtetra
.921 .931 .798 r
.48851 .38088 .49725 .38182 .51287 .36445 .50428 .36 Mtetra
.851 .891 .865 r
.50428 .36 .51287 .36445 .52846 .35216 .51998 .34536 Mtetra
.782 .839 .896 r
.51998 .34536 .52846 .35216 .54409 .34297 .53569 .33474 Mtetra
.731 .799 .906 r
.53569 .33474 .54409 .34297 .55979 .33552 .55146 .32647 Mtetra
.701 .773 .908 r
.55146 .32647 .55979 .33552 .57558 .32903 .5673 .3195 Mtetra
.683 .759 .908 r
.5673 .3195 .57558 .32903 .59145 .32303 .58324 .31322 Mtetra
.674 .751 .908 r
.58324 .31322 .59145 .32303 .60742 .31728 .59927 .30729 Mtetra
.669 .746 .908 r
.59927 .30729 .60742 .31728 .62348 .31164 .61539 .30153 Mtetra
.666 .744 .908 r
.61539 .30153 .62348 .31164 .63963 .30606 .63161 .29585 Mtetra
.665 .743 .908 r
.63161 .29585 .63963 .30606 .65588 .30048 .64792 .2902 Mtetra
.664 .742 .908 r
.64792 .2902 .65588 .30048 .67223 .29489 .66433 .28454 Mtetra
.66433 .28454 .67223 .29489 .68867 .28928 .68083 .27886 Mtetra
.664 .741 .908 r
.68083 .27886 .68867 .28928 .7052 .28364 .69743 .27316 Mtetra
.69743 .27316 .7052 .28364 .72183 .27797 .71413 .26743 Mtetra
.71413 .26743 .72183 .27797 .73856 .27227 .73093 .26167 Mtetra
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25588 Mtetra
.74783 .25588 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24419 Mtetra
.78193 .24419 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .763 .934 r
.19431 .64049 .2046 .64883 .2195 .64431 .20926 .63592 Mtetra
.20926 .63592 .2195 .64431 .23448 .63976 .22429 .63132 Mtetra
.647 .763 .934 r
.22429 .63132 .23448 .63976 .24954 .63516 .2394 .62669 Mtetra
.2394 .62669 .24954 .63516 .2647 .63051 .25461 .622 Mtetra
.648 .764 .933 r
.25461 .622 .2647 .63051 .27995 .62578 .26991 .61725 Mtetra
.65 .765 .933 r
.26991 .61725 .27995 .62578 .29529 .62091 .2853 .61239 Mtetra
.654 .768 .932 r
.2853 .61239 .29529 .62091 .31073 .61581 .3008 .60736 Mtetra
.662 .772 .931 r
.3008 .60736 .31073 .61581 .32629 .6103 .31639 .60202 Mtetra
.676 .781 .929 r
.31639 .60202 .32629 .6103 .34196 .60404 .33211 .59612 Mtetra
.7 .795 .924 r
.33211 .59612 .34196 .60404 .35778 .59643 .34796 .58922 Mtetra
.74 .819 .913 r
.34796 .58922 .35778 .59643 .37377 .5864 .36396 .58048 Mtetra
.799 .852 .89 r
.36396 .58048 .37377 .5864 .38997 .57226 .38016 .56856 Mtetra
.871 .888 .844 r
.38016 .56856 .38997 .57226 .4064 .55178 .39659 .55143 Mtetra
.934 .912 .773 r
.39659 .55143 .4064 .55178 .42302 .52304 .41325 .52683 Mtetra
.97 .918 .694 r
.41325 .52683 .42302 .52304 .43972 .48649 .43005 .49373 Mtetra
.98 .915 .635 r
.43005 .49373 .43972 .48649 .45628 .44657 .44683 .45453 Mtetra
.977 .919 .621 r
.44683 .45453 .45628 .44657 .47255 .40989 .46338 .41527 Mtetra
.97 .932 .664 r
.46338 .41527 .47255 .40989 .48851 .38088 .4796 .38197 Mtetra
.945 .939 .752 r
.4796 .38197 .48851 .38088 .50428 .36 .49556 .35705 Mtetra
.888 .914 .837 r
.49556 .35705 .50428 .36 .51998 .34536 .51139 .33947 Mtetra
.815 .864 .884 r
.51139 .33947 .51998 .34536 .53569 .33474 .52719 .327 Mtetra
.754 .817 .902 r
.52719 .327 .53569 .33474 .55146 .32647 .54303 .31764 Mtetra
.714 .784 .907 r
.54303 .31764 .55146 .32647 .5673 .3195 .55894 .31004 Mtetra
.691 .765 .908 r
.55894 .31004 .5673 .3195 .58324 .31322 .57494 .30339 Mtetra
.678 .754 .908 r
.57494 .30339 .58324 .31322 .59927 .30729 .59103 .29724 Mtetra
.671 .748 .908 r
.59103 .29724 .59927 .30729 .61539 .30153 .60721 .29134 Mtetra
.668 .745 .908 r
.60721 .29134 .61539 .30153 .63161 .29585 .62349 .28555 Mtetra
.666 .743 .908 r
.62349 .28555 .63161 .29585 .64792 .2902 .63987 .27981 Mtetra
.665 .742 .908 r
.63987 .27981 .64792 .2902 .66433 .28454 .65634 .27408 Mtetra
.664 .742 .908 r
.65634 .27408 .66433 .28454 .68083 .27886 .67291 .26834 Mtetra
.67291 .26834 .68083 .27886 .69743 .27316 .68958 .26257 Mtetra
.664 .741 .908 r
.68958 .26257 .69743 .27316 .71413 .26743 .70635 .25678 Mtetra
.70635 .25678 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25588 .74019 .24509 Mtetra
.74019 .24509 .74783 .25588 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24419 .77443 .23327 Mtetra
.77443 .23327 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.646 .762 .934 r
.18391 .63205 .19431 .64049 .20926 .63592 .1989 .62744 Mtetra
.646 .763 .934 r
.1989 .62744 .20926 .63592 .22429 .63132 .21398 .62279 Mtetra
.21398 .62279 .22429 .63132 .2394 .62669 .22915 .61811 Mtetra
.647 .763 .934 r
.22915 .61811 .2394 .62669 .25461 .622 .24441 .61339 Mtetra
.648 .763 .933 r
.24441 .61339 .25461 .622 .26991 .61725 .25976 .60861 Mtetra
.649 .764 .933 r
.25976 .60861 .26991 .61725 .2853 .61239 .27521 .60375 Mtetra
.652 .766 .933 r
.27521 .60375 .2853 .61239 .3008 .60736 .29075 .59875 Mtetra
.658 .77 .932 r
.29075 .59875 .3008 .60736 .31639 .60202 .3064 .59352 Mtetra
.668 .776 .93 r
.3064 .59352 .31639 .60202 .33211 .59612 .32215 .58787 Mtetra
.686 .787 .927 r
.32215 .58787 .33211 .59612 .34796 .58922 .33804 .58147 Mtetra
.718 .806 .92 r
.33804 .58147 .34796 .58922 .36396 .58048 .35407 .5737 Mtetra
.767 .835 .904 r
.35407 .5737 .36396 .58048 .38016 .56856 .37028 .5635 Mtetra
.835 .871 .87 r
.37028 .5635 .38016 .56856 .39659 .55143 .3867 .54916 Mtetra
.905 .902 .811 r
.3867 .54916 .39659 .55143 .41325 .52683 .40337 .52843 Mtetra
.956 .917 .733 r
.40337 .52843 .41325 .52683 .43005 .49373 .42024 .49939 Mtetra
.977 .917 .66 r
.42024 .49939 .43005 .49373 .44683 .45453 .43718 .46249 Mtetra
.979 .916 .621 r
.43718 .46249 .44683 .45453 .46338 .41527 .45399 .4222 Mtetra
.974 .925 .635 r
.45399 .4222 .46338 .41527 .4796 .38197 .4705 .38519 Mtetra
.961 .939 .705 r
.4705 .38519 .4796 .38197 .49556 .35705 .48669 .35589 Mtetra
.921 .931 .798 r
.48669 .35589 .49556 .35705 .51139 .33947 .50268 .33478 Mtetra
.851 .89 .865 r
.50268 .33478 .51139 .33947 .52719 .327 .51859 .31994 Mtetra
.782 .839 .896 r
.51859 .31994 .52719 .327 .54303 .31764 .53451 .30915 Mtetra
.731 .799 .906 r
.53451 .30915 .54303 .31764 .55894 .31004 .55049 .30072 Mtetra
.701 .773 .908 r
.55049 .30072 .55894 .31004 .57494 .30339 .56655 .29359 Mtetra
.683 .759 .908 r
.56655 .29359 .57494 .30339 .59103 .29724 .5827 .28715 Mtetra
.674 .751 .908 r
.5827 .28715 .59103 .29724 .60721 .29134 .59895 .28107 Mtetra
.669 .746 .908 r
.59895 .28107 .60721 .29134 .62349 .28555 .61529 .27516 Mtetra
.666 .744 .908 r
.61529 .27516 .62349 .28555 .63987 .27981 .63173 .26933 Mtetra
.665 .743 .908 r
.63173 .26933 .63987 .27981 .65634 .27408 .64827 .26351 Mtetra
.664 .742 .908 r
.64827 .26351 .65634 .27408 .67291 .26834 .66491 .2577 Mtetra
.66491 .2577 .67291 .26834 .68958 .26257 .68164 .25186 Mtetra
.664 .741 .908 r
.68164 .25186 .68958 .26257 .70635 .25678 .69848 .246 Mtetra
.69848 .246 .70635 .25678 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23419 Mtetra
.73246 .23419 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62352 .18391 .63205 .1989 .62744 .18844 .61886 Mtetra
.646 .763 .934 r
.18844 .61886 .1989 .62744 .21398 .62279 .20357 .61417 Mtetra
.20357 .61417 .21398 .62279 .22915 .61811 .21879 .60945 Mtetra
.647 .763 .934 r
.21879 .60945 .22915 .61811 .24441 .61339 .2341 .60468 Mtetra
.2341 .60468 .24441 .61339 .25976 .60861 .24951 .59987 Mtetra
.648 .764 .933 r
.24951 .59987 .25976 .60861 .27521 .60375 .265 .59498 Mtetra
.65 .765 .933 r
.265 .59498 .27521 .60375 .29075 .59875 .2806 .58999 Mtetra
.654 .768 .932 r
.2806 .58999 .29075 .59875 .3064 .59352 .29629 .58483 Mtetra
.662 .772 .931 r
.29629 .58483 .3064 .59352 .32215 .58787 .3121 .57935 Mtetra
.676 .781 .929 r
.3121 .57935 .32215 .58787 .33804 .58147 .32802 .57331 Mtetra
.7 .795 .924 r
.32802 .57331 .33804 .58147 .35407 .5737 .34408 .56625 Mtetra
.74 .819 .913 r
.34408 .56625 .35407 .5737 .37028 .5635 .36031 .55735 Mtetra
.799 .852 .89 r
.36031 .55735 .37028 .5635 .3867 .54916 .37674 .54523 Mtetra
.871 .888 .844 r
.37674 .54523 .3867 .54916 .40337 .52843 .3934 .52788 Mtetra
.934 .912 .773 r
.3934 .52788 .40337 .52843 .42024 .49939 .4103 .503 Mtetra
.97 .918 .694 r
.4103 .503 .42024 .49939 .43718 .46249 .42736 .46957 Mtetra
.98 .915 .635 r
.42736 .46957 .43718 .46249 .45399 .4222 .44439 .43 Mtetra
.977 .919 .621 r
.44439 .43 .45399 .4222 .4705 .38519 .46118 .39039 Mtetra
.97 .932 .665 r
.46118 .39039 .4705 .38519 .48669 .35589 .47764 .35678 Mtetra
.945 .939 .752 r
.47764 .35678 .48669 .35589 .50268 .33478 .49383 .3316 Mtetra
.888 .914 .837 r
.49383 .3316 .50268 .33478 .51859 .31994 .50987 .31381 Mtetra
.815 .864 .884 r
.50987 .31381 .51859 .31994 .53451 .30915 .52589 .30115 Mtetra
.754 .817 .902 r
.52589 .30115 .53451 .30915 .55049 .30072 .54194 .29162 Mtetra
.714 .784 .907 r
.54194 .29162 .55049 .30072 .56655 .29359 .55807 .28385 Mtetra
.691 .765 .908 r
.55807 .28385 .56655 .29359 .5827 .28715 .57428 .27705 Mtetra
.678 .754 .908 r
.57428 .27705 .5827 .28715 .59895 .28107 .59059 .27074 Mtetra
.671 .748 .908 r
.59059 .27074 .59895 .28107 .61529 .27516 .607 .26468 Mtetra
.668 .745 .908 r
.607 .26468 .61529 .27516 .63173 .26933 .62351 .25874 Mtetra
.666 .743 .908 r
.62351 .25874 .63173 .26933 .64827 .26351 .64011 .25284 Mtetra
.665 .742 .908 r
.64011 .25284 .64827 .26351 .66491 .2577 .65681 .24695 Mtetra
.664 .742 .908 r
.65681 .24695 .66491 .2577 .68164 .25186 .67362 .24104 Mtetra
.67362 .24104 .68164 .25186 .69848 .246 .69052 .23511 Mtetra
.664 .741 .908 r
.69052 .23511 .69848 .246 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23419 .72464 .22316 Mtetra
.72464 .22316 .73246 .23419 .7496 .22823 .74185 .21714 Mtetra
.74185 .21714 .7496 .22823 .76684 .22223 .75917 .21108 Mtetra
.75917 .21108 .76684 .22223 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .762 .934 r
.16277 .6149 .1734 .62352 .18844 .61886 .17787 .61019 Mtetra
.17787 .61019 .18844 .61886 .20357 .61417 .19305 .60545 Mtetra
.646 .763 .934 r
.19305 .60545 .20357 .61417 .21879 .60945 .20832 .60068 Mtetra
.20832 .60068 .21879 .60945 .2341 .60468 .22368 .59587 Mtetra
.647 .763 .934 r
.22368 .59587 .2341 .60468 .24951 .59987 .23914 .59102 Mtetra
.648 .763 .933 r
.23914 .59102 .24951 .59987 .265 .59498 .25469 .5861 Mtetra
.649 .764 .933 r
.25469 .5861 .265 .59498 .2806 .58999 .27033 .5811 Mtetra
.652 .766 .933 r
.27033 .5811 .2806 .58999 .29629 .58483 .28608 .57597 Mtetra
.658 .77 .932 r
.28608 .57597 .29629 .58483 .3121 .57935 .30193 .5706 Mtetra
.668 .776 .93 r
.30193 .5706 .3121 .57935 .32802 .57331 .3179 .56481 Mtetra
.686 .787 .927 r
.3179 .56481 .32802 .57331 .34408 .56625 .334 .55826 Mtetra
.718 .806 .92 r
.334 .55826 .34408 .56625 .36031 .55735 .35025 .55033 Mtetra
.767 .835 .904 r
.35025 .55033 .36031 .55735 .37674 .54523 .36669 .53994 Mtetra
.835 .871 .87 r
.36669 .53994 .37674 .54523 .3934 .52788 .38334 .52539 Mtetra
.905 .902 .811 r
.38334 .52539 .3934 .52788 .4103 .503 .40025 .50441 Mtetra
.956 .917 .733 r
.40025 .50441 .4103 .503 .42736 .46957 .41737 .47506 Mtetra
.977 .917 .66 r
.41737 .47506 .42736 .46957 .44439 .43 .43458 .4378 Mtetra
.979 .916 .621 r
.43458 .4378 .44439 .43 .46118 .39039 .45164 .39715 Mtetra
.974 .925 .636 r
.45164 .39715 .46118 .39039 .47764 .35678 .46839 .3598 Mtetra
.961 .938 .705 r
.46839 .3598 .47764 .35678 .49383 .3316 .48482 .33022 Mtetra
.921 .931 .798 r
.48482 .33022 .49383 .3316 .50987 .31381 .50103 .30887 Mtetra
.851 .89 .865 r
.50103 .30887 .50987 .31381 .52589 .30115 .51716 .29383 Mtetra
.782 .839 .896 r
.51716 .29383 .52589 .30115 .54194 .29162 .5333 .28285 Mtetra
.731 .799 .906 r
.5333 .28285 .54194 .29162 .55807 .28385 .54949 .27425 Mtetra
.701 .773 .908 r
.54949 .27425 .55807 .28385 .57428 .27705 .56577 .26696 Mtetra
.683 .759 .908 r
.56577 .26696 .57428 .27705 .59059 .27074 .58215 .26036 Mtetra
.674 .751 .908 r
.58215 .26036 .59059 .27074 .607 .26468 .59862 .25412 Mtetra
.669 .746 .908 r
.59862 .25412 .607 .26468 .62351 .25874 .61519 .24805 Mtetra
.666 .744 .908 r
.61519 .24805 .62351 .25874 .64011 .25284 .63186 .24206 Mtetra
.665 .743 .908 r
.63186 .24206 .64011 .25284 .65681 .24695 .64863 .23608 Mtetra
.664 .742 .908 r
.64863 .23608 .65681 .24695 .67362 .24104 .6655 .2301 Mtetra
.6655 .2301 .67362 .24104 .69052 .23511 .68248 .2241 Mtetra
.664 .741 .908 r
.68248 .2241 .69052 .23511 .70753 .22915 .69956 .21807 Mtetra
.69956 .21807 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21714 .73402 .20592 Mtetra
.73402 .20592 .74185 .21714 .75917 .21108 .75141 .19979 Mtetra
.75141 .19979 .75917 .21108 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .6149 .17787 .61019 .16717 .60143 Mtetra
.16717 .60143 .17787 .61019 .19305 .60545 .18241 .59664 Mtetra
.646 .763 .934 r
.18241 .59664 .19305 .60545 .20832 .60068 .19773 .59181 Mtetra
.19773 .59181 .20832 .60068 .22368 .59587 .21315 .58696 Mtetra
.647 .763 .934 r
.21315 .58696 .22368 .59587 .23914 .59102 .22866 .58206 Mtetra
.22866 .58206 .23914 .59102 .25469 .5861 .24426 .57711 Mtetra
.648 .764 .933 r
.24426 .57711 .25469 .5861 .27033 .5811 .25996 .57209 Mtetra
.65 .765 .933 r
.25996 .57209 .27033 .5811 .28608 .57597 .27576 .56696 Mtetra
.654 .768 .932 r
.27576 .56696 .28608 .57597 .30193 .5706 .29166 .56165 Mtetra
.662 .772 .931 r
.29166 .56165 .30193 .5706 .3179 .56481 .30768 .55603 Mtetra
.676 .781 .929 r
.30768 .55603 .3179 .56481 .334 .55826 .32382 .54984 Mtetra
.7 .795 .924 r
.32382 .54984 .334 .55826 .35025 .55033 .3401 .54262 Mtetra
.74 .819 .913 r
.3401 .54262 .35025 .55033 .36669 .53994 .35655 .53355 Mtetra
.799 .853 .89 r
.35655 .53355 .36669 .53994 .38334 .52539 .37321 .52124 Mtetra
.871 .888 .844 r
.37321 .52124 .38334 .52539 .40025 .50441 .39011 .50365 Mtetra
.934 .912 .773 r
.39011 .50365 .40025 .50441 .41737 .47506 .40726 .47849 Mtetra
.97 .918 .694 r
.40726 .47849 .41737 .47506 .43458 .4378 .42458 .44472 Mtetra
.98 .915 .635 r
.42458 .44472 .43458 .4378 .45164 .39715 .44188 .40479 Mtetra
.977 .919 .621 r
.44188 .40479 .45164 .39715 .46839 .3598 .45892 .36481 Mtetra
.97 .932 .665 r
.45892 .36481 .46839 .3598 .48482 .33022 .47562 .33089 Mtetra
.945 .939 .752 r
.47562 .33089 .48482 .33022 .50103 .30887 .49204 .30544 Mtetra
.888 .914 .837 r
.49204 .30544 .50103 .30887 .51716 .29383 .50831 .28743 Mtetra
.815 .864 .884 r
.50831 .28743 .51716 .29383 .5333 .28285 .52455 .27458 Mtetra
.754 .817 .902 r
.52455 .27458 .5333 .28285 .54949 .27425 .54082 .26487 Mtetra
.714 .784 .907 r
.54082 .26487 .54949 .27425 .56577 .26696 .55717 .25694 Mtetra
.691 .765 .908 r
.55717 .25694 .56577 .26696 .58215 .26036 .57361 .24997 Mtetra
.678 .754 .908 r
.57361 .24997 .58215 .26036 .59862 .25412 .59015 .2435 Mtetra
.671 .748 .908 r
.59015 .2435 .59862 .25412 .61519 .24805 .60678 .23727 Mtetra
.668 .745 .908 r
.60678 .23727 .61519 .24805 .63186 .24206 .62352 .23117 Mtetra
.666 .743 .908 r
.62352 .23117 .63186 .24206 .64863 .23608 .64036 .2251 Mtetra
.665 .742 .908 r
.64036 .2251 .64863 .23608 .6655 .2301 .6573 .21904 Mtetra
.664 .742 .908 r
.6573 .21904 .6655 .2301 .68248 .2241 .67434 .21297 Mtetra
.67434 .21297 .68248 .2241 .69956 .21807 .69149 .20687 Mtetra
.664 .741 .908 r
.69149 .20687 .69956 .21807 .71674 .21201 .70874 .20074 Mtetra
.70874 .20074 .71674 .21201 .73402 .20592 .7261 .19458 Mtetra
.7261 .19458 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59181 .18703 .58285 Mtetra
.646 .763 .934 r
.18703 .58285 .19773 .59181 .21315 .58696 .2025 .57794 Mtetra
.2025 .57794 .21315 .58696 .22866 .58206 .21806 .573 Mtetra
.647 .763 .934 r
.21806 .573 .22866 .58206 .24426 .57711 .23371 .56801 Mtetra
.648 .763 .933 r
.23371 .56801 .24426 .57711 .25996 .57209 .24947 .56295 Mtetra
.649 .764 .933 r
.24947 .56295 .25996 .57209 .27576 .56696 .26532 .55782 Mtetra
.652 .766 .933 r
.26532 .55782 .27576 .56696 .29166 .56165 .28128 .55254 Mtetra
.658 .77 .932 r
.28128 .55254 .29166 .56165 .30768 .55603 .29734 .54702 Mtetra
.668 .776 .93 r
.29734 .54702 .30768 .55603 .32382 .54984 .31353 .54108 Mtetra
.686 .787 .927 r
.31353 .54108 .32382 .54984 .3401 .54262 .32985 .53437 Mtetra
.718 .806 .92 r
.32985 .53437 .3401 .54262 .35655 .53355 .34632 .52628 Mtetra
.767 .835 .904 r
.34632 .52628 .35655 .53355 .37321 .52124 .36299 .51571 Mtetra
.835 .871 .87 r
.36299 .51571 .37321 .52124 .39011 .50365 .37989 .50094 Mtetra
.905 .903 .811 r
.37989 .50094 .39011 .50365 .40726 .47849 .39704 .4797 Mtetra
.956 .917 .732 r
.39704 .4797 .40726 .47849 .42458 .44472 .41443 .45003 Mtetra
.977 .917 .66 r
.41443 .45003 .42458 .44472 .44188 .40479 .4319 .41242 Mtetra
.979 .916 .621 r
.4319 .41242 .44188 .40479 .45892 .36481 .44922 .37139 Mtetra
.975 .925 .636 r
.44922 .37139 .45892 .36481 .47562 .33089 .46622 .3337 Mtetra
.961 .938 .706 r
.46622 .3337 .47562 .33089 .49204 .30544 .48289 .30383 Mtetra
.921 .931 .798 r
.48289 .30383 .49204 .30544 .50831 .28743 .49933 .28224 Mtetra
.851 .89 .865 r
.49933 .28224 .50831 .28743 .52455 .27458 .51569 .26699 Mtetra
.782 .839 .896 r
.51569 .26699 .52455 .27458 .54082 .26487 .53205 .25583 Mtetra
.731 .799 .906 r
.53205 .25583 .54082 .26487 .55717 .25694 .54847 .24705 Mtetra
.701 .773 .908 r
.54847 .24705 .55717 .25694 .57361 .24997 .56498 .23959 Mtetra
.683 .759 .908 r
.56498 .23959 .57361 .24997 .59015 .2435 .58158 .23282 Mtetra
.674 .751 .908 r
.58158 .23282 .59015 .2435 .60678 .23727 .59828 .22641 Mtetra
.669 .746 .908 r
.59828 .22641 .60678 .23727 .62352 .23117 .61508 .22018 Mtetra
.666 .744 .908 r
.61508 .22018 .62352 .23117 .64036 .2251 .63199 .21401 Mtetra
.665 .743 .908 r
.63199 .21401 .64036 .2251 .6573 .21904 .649 .20787 Mtetra
.664 .742 .908 r
.649 .20787 .6573 .21904 .67434 .21297 .66612 .20172 Mtetra
.66612 .20172 .67434 .21297 .69149 .20687 .68334 .19554 Mtetra
.664 .741 .908 r
.68334 .19554 .69149 .20687 .70874 .20074 .70066 .18934 Mtetra
.70066 .18934 .70874 .20074 .7261 .19458 .71809 .18311 Mtetra
.71809 .18311 .7261 .19458 .74357 .18838 .73563 .17684 Mtetra
.73563 .17684 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57871 Mtetra
.16077 .57871 .17165 .58773 .18703 .58285 .1762 .57379 Mtetra
.646 .763 .934 r
.1762 .57379 .18703 .58285 .2025 .57794 .19172 .56883 Mtetra
.19172 .56883 .2025 .57794 .21806 .573 .20734 .56383 Mtetra
.647 .763 .934 r
.20734 .56383 .21806 .573 .23371 .56801 .22305 .55879 Mtetra
.22305 .55879 .23371 .56801 .24947 .56295 .23886 .5537 Mtetra
.648 .764 .933 r
.23886 .5537 .24947 .56295 .26532 .55782 .25477 .54854 Mtetra
.65 .765 .933 r
.25477 .54854 .26532 .55782 .28128 .55254 .27078 .54327 Mtetra
.654 .768 .932 r
.27078 .54327 .28128 .55254 .29734 .54702 .2869 .53781 Mtetra
.662 .772 .931 r
.2869 .53781 .29734 .54702 .31353 .54108 .30313 .53204 Mtetra
.676 .781 .929 r
.30313 .53204 .31353 .54108 .32985 .53437 .31949 .52569 Mtetra
.7 .795 .924 r
.31949 .52569 .32985 .53437 .34632 .52628 .336 .51831 Mtetra
.74 .819 .913 r
.336 .51831 .34632 .52628 .36299 .51571 .35268 .50906 Mtetra
.799 .853 .89 r
.35268 .50906 .36299 .51571 .37989 .50094 .36958 .49655 Mtetra
.871 .889 .844 r
.36958 .49655 .37989 .50094 .39704 .4797 .38673 .47872 Mtetra
.934 .912 .773 r
.38673 .47872 .39704 .4797 .41443 .45003 .40414 .45327 Mtetra
.97 .918 .693 r
.40414 .45327 .41443 .45003 .4319 .41242 .42173 .41916 Mtetra
.98 .915 .635 r
.42173 .41916 .4319 .41242 .44922 .37139 .43929 .37885 Mtetra
.977 .919 .621 r
.43929 .37885 .44922 .37139 .46622 .3337 .4566 .33851 Mtetra
.97 .932 .665 r
.4566 .33851 .46622 .3337 .48289 .30383 .47355 .30427 Mtetra
.945 .939 .752 r
.47355 .30427 .48289 .30383 .49933 .28224 .49021 .27855 Mtetra
.888 .914 .837 r
.49021 .27855 .49933 .28224 .51569 .26699 .50671 .26031 Mtetra
.815 .864 .884 r
.50671 .26031 .51569 .26699 .53205 .25583 .52317 .24726 Mtetra
.754 .817 .902 r
.52317 .24726 .53205 .25583 .54847 .24705 .53967 .23737 Mtetra
.714 .784 .907 r
.53967 .23737 .54847 .24705 .56498 .23959 .55625 .22927 Mtetra
.691 .765 .908 r
.55625 .22927 .56498 .23959 .58158 .23282 .57292 .22212 Mtetra
.678 .754 .908 r
.57292 .22212 .58158 .23282 .59828 .22641 .58969 .21548 Mtetra
.671 .748 .908 r
.58969 .21548 .59828 .22641 .61508 .22018 .60656 .20909 Mtetra
.668 .745 .908 r
.60656 .20909 .61508 .22018 .63199 .21401 .62353 .20281 Mtetra
.666 .743 .908 r
.62353 .20281 .63199 .21401 .649 .20787 .64061 .19657 Mtetra
.665 .742 .908 r
.64061 .19657 .649 .20787 .66612 .20172 .6578 .19034 Mtetra
.664 .742 .908 r
.6578 .19034 .66612 .20172 .68334 .19554 .67509 .18409 Mtetra
.67509 .18409 .68334 .19554 .70066 .18934 .69249 .17782 Mtetra
.664 .741 .908 r
.69249 .17782 .70066 .18934 .71809 .18311 .70999 .17151 Mtetra
.70999 .17151 .71809 .18311 .73563 .17684 .72761 .16516 Mtetra
.72761 .16516 .73563 .17684 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57871 .14978 .5696 Mtetra
.14978 .5696 .16077 .57871 .1762 .57379 .16526 .56462 Mtetra
.16526 .56462 .1762 .57379 .19172 .56883 .18083 .55961 Mtetra
.646 .763 .934 r
.18083 .55961 .19172 .56883 .20734 .56383 .1965 .55456 Mtetra
.1965 .55456 .20734 .56383 .22305 .55879 .21227 .54947 Mtetra
.647 .763 .934 r
.21227 .54947 .22305 .55879 .23886 .5537 .22814 .54434 Mtetra
.648 .763 .933 r
.22814 .54434 .23886 .5537 .25477 .54854 .2441 .53914 Mtetra
.649 .764 .933 r
.2441 .53914 .25477 .54854 .27078 .54327 .26017 .53385 Mtetra
.652 .766 .933 r
.26017 .53385 .27078 .54327 .2869 .53781 .27634 .52843 Mtetra
.658 .77 .932 r
.27634 .52843 .2869 .53781 .30313 .53204 .29262 .52276 Mtetra
.668 .776 .93 r
.29262 .52276 .30313 .53204 .31949 .52569 .30903 .51666 Mtetra
.686 .787 .927 r
.30903 .51666 .31949 .52569 .336 .51831 .32557 .5098 Mtetra
.718 .806 .92 r
.32557 .5098 .336 .51831 .35268 .50906 .34228 .50152 Mtetra
.767 .835 .904 r
.34228 .50152 .35268 .50906 .36958 .49655 .35919 .49076 Mtetra
.835 .871 .871 r
.35919 .49076 .36958 .49655 .38673 .47872 .37633 .47577 Mtetra
.905 .903 .811 r
.37633 .47577 .38673 .47872 .40414 .45327 .39374 .45426 Mtetra
.956 .917 .732 r
.39374 .45426 .40414 .45327 .42173 .41916 .41139 .42428 Mtetra
.977 .917 .66 r
.41139 .42428 .42173 .41916 .43929 .37885 .42914 .3863 Mtetra
.979 .916 .621 r
.42914 .3863 .43929 .37885 .4566 .33851 .44674 .34489 Mtetra
.975 .925 .636 r
.44674 .34489 .4566 .33851 .47355 .30427 .464 .30685 Mtetra
.961 .938 .706 r
.464 .30685 .47355 .30427 .49021 .27855 .48091 .27669 Mtetra
.921 .931 .798 r
.48091 .27669 .49021 .27855 .50671 .26031 .49759 .25485 Mtetra
.851 .89 .865 r
.49759 .25485 .50671 .26031 .52317 .24726 .51418 .23939 Mtetra
.782 .839 .896 r
.51418 .23939 .52317 .24726 .53967 .23737 .53077 .22803 Mtetra
.731 .799 .905 r
.53077 .22803 .53967 .23737 .55625 .22927 .54742 .21907 Mtetra
.701 .773 .908 r
.54742 .21907 .55625 .22927 .57292 .22212 .56416 .21143 Mtetra
.683 .759 .908 r
.56416 .21143 .57292 .22212 .58969 .21548 .58099 .2045 Mtetra
.674 .751 .908 r
.58099 .2045 .58969 .21548 .60656 .20909 .59793 .19791 Mtetra
.669 .746 .908 r
.59793 .19791 .60656 .20909 .62353 .20281 .61498 .1915 Mtetra
.666 .744 .908 r
.61498 .1915 .62353 .20281 .64061 .19657 .63213 .18516 Mtetra
.665 .743 .908 r
.63213 .18516 .64061 .19657 .6578 .19034 .64938 .17884 Mtetra
.664 .742 .908 r
.64938 .17884 .6578 .19034 .67509 .18409 .66675 .17251 Mtetra
.66675 .17251 .67509 .18409 .69249 .17782 .68422 .16616 Mtetra
.664 .741 .908 r
.68422 .16616 .69249 .17782 .70999 .17151 .7018 .15977 Mtetra
.7018 .15977 .70999 .17151 .72761 .16516 .71949 .15336 Mtetra
.71949 .15336 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .14041 Mtetra
.7552 .14041 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56462 .15419 .55535 Mtetra
.15419 .55535 .16526 .56462 .18083 .55961 .16982 .55028 Mtetra
.646 .763 .934 r
.16982 .55028 .18083 .55961 .1965 .55456 .18555 .54518 Mtetra
.18555 .54518 .1965 .55456 .21227 .54947 .20137 .54004 Mtetra
.647 .763 .934 r
.20137 .54004 .21227 .54947 .22814 .54434 .21729 .53486 Mtetra
.21729 .53486 .22814 .54434 .2441 .53914 .23331 .52962 Mtetra
.648 .764 .933 r
.23331 .52962 .2441 .53914 .26017 .53385 .24943 .52431 Mtetra
.65 .765 .933 r
.24943 .52431 .26017 .53385 .27634 .52843 .26566 .51888 Mtetra
.654 .768 .932 r
.26566 .51888 .27634 .52843 .29262 .52276 .282 .51327 Mtetra
.662 .772 .931 r
.282 .51327 .29262 .52276 .30903 .51666 .29845 .50734 Mtetra
.676 .781 .929 r
.29845 .50734 .30903 .51666 .32557 .5098 .31504 .50084 Mtetra
.7 .796 .924 r
.31504 .50084 .32557 .5098 .34228 .50152 .33178 .49329 Mtetra
.74 .819 .914 r
.33178 .49329 .34228 .50152 .35919 .49076 .3487 .48385 Mtetra
.799 .853 .89 r
.3487 .48385 .35919 .49076 .37633 .47577 .36584 .47113 Mtetra
.871 .889 .844 r
.36584 .47113 .37633 .47577 .39374 .45426 .38325 .45306 Mtetra
.934 .913 .773 r
.38325 .45306 .39374 .45426 .41139 .42428 .40093 .42731 Mtetra
.97 .918 .693 r
.40093 .42731 .41139 .42428 .42914 .3863 .41879 .39285 Mtetra
.98 .915 .635 r
.41879 .39285 .42914 .3863 .44674 .34489 .43663 .35216 Mtetra
.977 .919 .621 r
.43663 .35216 .44674 .34489 .464 .30685 .45421 .31145 Mtetra
.97 .932 .665 r
.45421 .31145 .464 .30685 .48091 .27669 .47142 .27688 Mtetra
.945 .939 .753 r
.47142 .27688 .48091 .27669 .49759 .25485 .48832 .25089 Mtetra
.888 .913 .837 r
.48832 .25089 .49759 .25485 .51418 .23939 .50506 .23243 Mtetra
.815 .864 .884 r
.50506 .23243 .51418 .23939 .53077 .22803 .52175 .21917 Mtetra
.754 .817 .902 r
.52175 .21917 .53077 .22803 .54742 .21907 .53849 .20909 Mtetra
.714 .784 .907 r
.53849 .20909 .54742 .21907 .56416 .21143 .5553 .2008 Mtetra
.691 .765 .908 r
.5553 .2008 .56416 .21143 .58099 .2045 .5722 .19348 Mtetra
.678 .754 .908 r
.5722 .19348 .58099 .2045 .59793 .19791 .58921 .18666 Mtetra
.671 .748 .908 r
.58921 .18666 .59793 .19791 .61498 .1915 .60633 .18009 Mtetra
.668 .745 .908 r
.60633 .18009 .61498 .1915 .63213 .18516 .62355 .17363 Mtetra
.666 .743 .908 r
.62355 .17363 .63213 .18516 .64938 .17884 .64087 .16721 Mtetra
.665 .742 .908 r
.64087 .16721 .64938 .17884 .66675 .17251 .65831 .1608 Mtetra
.664 .742 .908 r
.65831 .1608 .66675 .17251 .68422 .16616 .67586 .15437 Mtetra
.67586 .15437 .68422 .16616 .7018 .15977 .69351 .14791 Mtetra
.664 .741 .908 r
.69351 .14791 .7018 .15977 .71949 .15336 .71128 .14141 Mtetra
.71128 .14141 .71949 .15336 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .14041 .74715 .12831 Mtetra
.74715 .12831 .7552 .14041 .77323 .13387 .76525 .1217 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55028 .15868 .54085 Mtetra
.15868 .54085 .16982 .55028 .18555 .54518 .17446 .53569 Mtetra
.646 .763 .934 r
.17446 .53569 .18555 .54518 .20137 .54004 .19034 .5305 Mtetra
.19034 .5305 .20137 .54004 .21729 .53486 .20632 .52526 Mtetra
.647 .763 .934 r
.20632 .52526 .21729 .53486 .23331 .52962 .22239 .51998 Mtetra
.648 .763 .933 r
.22239 .51998 .23331 .52962 .24943 .52431 .23857 .51463 Mtetra
.649 .764 .933 r
.23857 .51463 .24943 .52431 .26566 .51888 .25486 .50919 Mtetra
.652 .766 .933 r
.25486 .50919 .26566 .51888 .282 .51327 .27125 .50361 Mtetra
.658 .77 .932 r
.27125 .50361 .282 .51327 .29845 .50734 .28776 .49778 Mtetra
.668 .776 .93 r
.28776 .49778 .29845 .50734 .31504 .50084 .30439 .49152 Mtetra
.686 .787 .927 r
.30439 .49152 .31504 .50084 .33178 .49329 .32117 .48449 Mtetra
.718 .806 .92 r
.32117 .48449 .33178 .49329 .3487 .48385 .33812 .47604 Mtetra
.767 .835 .904 r
.33812 .47604 .3487 .48385 .36584 .47113 .35527 .46507 Mtetra
.835 .871 .871 r
.35527 .46507 .36584 .47113 .38325 .45306 .37267 .44986 Mtetra
.905 .903 .811 r
.37267 .44986 .38325 .45306 .40093 .42731 .39034 .42807 Mtetra
.956 .917 .732 r
.39034 .42807 .40093 .42731 .41879 .39285 .40827 .39776 Mtetra
.977 .917 .659 r
.40827 .39776 .41879 .39285 .43663 .35216 .4263 .35941 Mtetra
.979 .916 .621 r
.4263 .35941 .43663 .35216 .45421 .31145 .44417 .31762 Mtetra
.975 .925 .636 r
.44417 .31762 .45421 .31145 .47142 .27688 .46171 .27923 Mtetra
.961 .938 .706 r
.46171 .27923 .47142 .27688 .48832 .25089 .47887 .24877 Mtetra
.921 .93 .798 r
.47887 .24877 .48832 .25089 .50506 .23243 .4958 .22667 Mtetra
.851 .89 .865 r
.4958 .22667 .50506 .23243 .52175 .21917 .51262 .21099 Mtetra
.782 .839 .895 r
.51262 .21099 .52175 .21917 .53849 .20909 .52945 .19944 Mtetra
.731 .799 .905 r
.52945 .19944 .53849 .20909 .5553 .2008 .54634 .19029 Mtetra
.701 .773 .908 r
.54634 .19029 .5553 .2008 .5722 .19348 .56331 .18247 Mtetra
.683 .759 .908 r
.56331 .18247 .5722 .19348 .58921 .18666 .58039 .17535 Mtetra
.674 .751 .908 r
.58039 .17535 .58921 .18666 .60633 .18009 .59758 .16858 Mtetra
.669 .746 .908 r
.59758 .16858 .60633 .18009 .62355 .17363 .61487 .16199 Mtetra
.666 .744 .908 r
.61487 .16199 .62355 .17363 .64087 .16721 .63227 .15546 Mtetra
.665 .743 .908 r
.63227 .15546 .64087 .16721 .65831 .1608 .64978 .14896 Mtetra
.664 .742 .908 r
.64978 .14896 .65831 .1608 .67586 .15437 .6674 .14244 Mtetra
.6674 .14244 .67586 .15437 .69351 .14791 .68513 .1359 Mtetra
.664 .741 .908 r
.68513 .1359 .69351 .14791 .71128 .14141 .70297 .12933 Mtetra
.70297 .12933 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54085 .14742 .53131 Mtetra
.14742 .53131 .15868 .54085 .17446 .53569 .16325 .5261 Mtetra
.646 .763 .934 r
.16325 .5261 .17446 .53569 .19034 .5305 .17919 .52084 Mtetra
.17919 .52084 .19034 .5305 .20632 .52526 .19522 .51555 Mtetra
.647 .763 .934 r
.19522 .51555 .20632 .52526 .22239 .51998 .21135 .51022 Mtetra
.21135 .51022 .22239 .51998 .23857 .51463 .22759 .50483 Mtetra
.648 .764 .933 r
.22759 .50483 .23857 .51463 .25486 .50919 .24393 .49936 Mtetra
.65 .765 .933 r
.24393 .49936 .25486 .50919 .27125 .50361 .26038 .49378 Mtetra
.654 .768 .932 r
.26038 .49378 .27125 .50361 .28776 .49778 .27695 .48801 Mtetra
.662 .772 .931 r
.27695 .48801 .28776 .49778 .30439 .49152 .29363 .48192 Mtetra
.676 .781 .929 r
.29363 .48192 .30439 .49152 .32117 .48449 .31045 .47524 Mtetra
.7 .796 .924 r
.31045 .47524 .32117 .48449 .33812 .47604 .32743 .46751 Mtetra
.74 .82 .914 r
.32743 .46751 .33812 .47604 .35527 .46507 .3446 .45788 Mtetra
.799 .853 .89 r
.3446 .45788 .35527 .46507 .37267 .44986 .36199 .44495 Mtetra
.871 .889 .844 r
.36199 .44495 .37267 .44986 .39034 .42807 .37966 .42662 Mtetra
.934 .913 .773 r
.37966 .42662 .39034 .42807 .40827 .39776 .39762 .40057 Mtetra
.97 .918 .693 r
.39762 .40057 .40827 .39776 .4263 .35941 .41576 .36575 Mtetra
.98 .916 .634 r
.41576 .36575 .4263 .35941 .44417 .31762 .43389 .32468 Mtetra
.977 .919 .621 r
.43389 .32468 .44417 .31762 .46171 .27923 .45175 .28359 Mtetra
.97 .932 .666 r
.45175 .28359 .46171 .27923 .47887 .24877 .46922 .2487 Mtetra
.945 .938 .753 r
.46922 .2487 .47887 .24877 .4958 .22667 .48638 .22244 Mtetra
.888 .913 .837 r
.48638 .22244 .4958 .22667 .51262 .21099 .50336 .20373 Mtetra
.815 .864 .884 r
.50336 .20373 .51262 .21099 .52945 .19944 .5203 .19027 Mtetra
.754 .817 .902 r
.5203 .19027 .52945 .19944 .54634 .19029 .53727 .17999 Mtetra
.714 .784 .907 r
.53727 .17999 .54634 .19029 .56331 .18247 .55432 .17151 Mtetra
.691 .765 .908 r
.55432 .17151 .56331 .18247 .58039 .17535 .57147 .164 Mtetra
.678 .754 .908 r
.57147 .164 .58039 .17535 .59758 .16858 .58873 .157 Mtetra
.671 .748 .908 r
.58873 .157 .59758 .16858 .61487 .16199 .60609 .15024 Mtetra
.668 .745 .908 r
.60609 .15024 .61487 .16199 .63227 .15546 .62356 .14359 Mtetra
.666 .743 .908 r
.62356 .14359 .63227 .15546 .64978 .14896 .64114 .13699 Mtetra
.665 .742 .908 r
.64114 .13699 .64978 .14896 .6674 .14244 .65884 .13039 Mtetra
.664 .742 .908 r
.65884 .13039 .6674 .14244 .68513 .1359 .67665 .12376 Mtetra
.67665 .12376 .68513 .1359 .70297 .12933 .69457 .11711 Mtetra
.664 .741 .908 r
.69457 .11711 .70297 .12933 .72093 .12272 .7126 .11042 Mtetra
.7126 .11042 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53211 Mtetra
.10454 .53211 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53131 .13603 .52166 Mtetra
.13603 .52166 .14742 .53131 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52084 .16791 .51108 Mtetra
.646 .763 .934 r
.16791 .51108 .17919 .52084 .19522 .51555 .184 .50573 Mtetra
.184 .50573 .19522 .51555 .21135 .51022 .20019 .50034 Mtetra
.647 .763 .934 r
.20019 .50034 .21135 .51022 .22759 .50483 .21648 .4949 Mtetra
.648 .763 .933 r
.21648 .4949 .22759 .50483 .24393 .49936 .23288 .48939 Mtetra
.649 .764 .933 r
.23288 .48939 .24393 .49936 .26038 .49378 .24939 .48379 Mtetra
.652 .766 .933 r
.24939 .48379 .26038 .49378 .27695 .48801 .26601 .47805 Mtetra
.658 .77 .932 r
.26601 .47805 .27695 .48801 .29363 .48192 .28275 .47206 Mtetra
.668 .776 .93 r
.28275 .47206 .29363 .48192 .31045 .47524 .29962 .46563 Mtetra
.686 .787 .927 r
.29962 .46563 .31045 .47524 .32743 .46751 .31664 .45842 Mtetra
.718 .806 .92 r
.31664 .45842 .32743 .46751 .3446 .45788 .33383 .44978 Mtetra
.767 .835 .904 r
.33383 .44978 .3446 .45788 .36199 .44495 .35123 .43861 Mtetra
.835 .872 .871 r
.35123 .43861 .36199 .44495 .37966 .42662 .36889 .42316 Mtetra
.906 .903 .811 r
.36889 .42316 .37966 .42662 .39762 .40057 .38684 .4011 Mtetra
.956 .918 .732 r
.38684 .4011 .39762 .40057 .41576 .36575 .40506 .37045 Mtetra
.977 .917 .659 r
.40506 .37045 .41576 .36575 .43389 .32468 .42337 .33172 Mtetra
.979 .916 .621 r
.42337 .33172 .43389 .32468 .45175 .28359 .44154 .28955 Mtetra
.975 .925 .636 r
.44154 .28955 .45175 .28359 .46922 .2487 .45935 .2508 Mtetra
.961 .938 .706 r
.45935 .2508 .46922 .2487 .48638 .22244 .47677 .22003 Mtetra
.921 .93 .798 r
.47677 .22003 .48638 .22244 .50336 .20373 .49395 .19768 Mtetra
.851 .889 .865 r
.49395 .19768 .50336 .20373 .5203 .19027 .51102 .18177 Mtetra
.782 .839 .895 r
.51102 .18177 .5203 .19027 .53727 .17999 .52809 .17001 Mtetra
.731 .799 .905 r
.52809 .17001 .53727 .17999 .55432 .17151 .54522 .16067 Mtetra
.701 .773 .908 r
.54522 .16067 .55432 .17151 .57147 .164 .56245 .15265 Mtetra
.683 .759 .908 r
.56245 .15265 .57147 .164 .58873 .157 .57977 .14534 Mtetra
.674 .751 .908 r
.57977 .14534 .58873 .157 .60609 .15024 .59721 .13839 Mtetra
.669 .746 .908 r
.59721 .13839 .60609 .15024 .62356 .14359 .61475 .1316 Mtetra
.666 .744 .908 r
.61475 .1316 .62356 .14359 .64114 .13699 .63241 .12489 Mtetra
.665 .743 .908 r
.63241 .12489 .64114 .13699 .65884 .13039 .65018 .11819 Mtetra
.664 .742 .908 r
.65018 .11819 .65884 .13039 .67665 .12376 .66807 .11148 Mtetra
.66807 .11148 .67665 .12376 .69457 .11711 .68607 .10474 Mtetra
.664 .741 .908 r
.68607 .10474 .69457 .11711 .7126 .11042 .70418 .09797 Mtetra
.70418 .09797 .7126 .11042 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53211 .09291 .52247 Mtetra
.09291 .52247 .10454 .53211 .12023 .52691 .10866 .51721 Mtetra
.10866 .51721 .12023 .52691 .13603 .52166 .1245 .5119 Mtetra
.1245 .5119 .13603 .52166 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .16791 .51108 .15649 .5012 Mtetra
.646 .763 .934 r
.15649 .5012 .16791 .51108 .184 .50573 .17264 .49579 Mtetra
.17264 .49579 .184 .50573 .20019 .50034 .18889 .49034 Mtetra
.647 .763 .934 r
.18889 .49034 .20019 .50034 .21648 .4949 .20524 .48485 Mtetra
.20524 .48485 .21648 .4949 .23288 .48939 .2217 .4793 Mtetra
.648 .764 .933 r
.2217 .4793 .23288 .48939 .24939 .48379 .23827 .47367 Mtetra
.65 .765 .933 r
.23827 .47367 .24939 .48379 .26601 .47805 .25495 .46792 Mtetra
.654 .768 .932 r
.25495 .46792 .26601 .47805 .28275 .47206 .27175 .46198 Mtetra
.662 .772 .931 r
.27175 .46198 .28275 .47206 .29962 .46563 .28867 .45572 Mtetra
.676 .781 .929 r
.28867 .45572 .29962 .46563 .31664 .45842 .30573 .44887 Mtetra
.7 .796 .924 r
.30573 .44887 .31664 .45842 .33383 .44978 .32295 .44095 Mtetra
.74 .82 .914 r
.32295 .44095 .33383 .44978 .35123 .43861 .34037 .43113 Mtetra
.8 .853 .89 r
.34037 .43113 .35123 .43861 .36889 .42316 .35803 .41797 Mtetra
.871 .889 .844 r
.35803 .41797 .36889 .42316 .38684 .4011 .37597 .39938 Mtetra
.934 .913 .773 r
.37597 .39938 .38684 .4011 .40506 .37045 .39421 .37302 Mtetra
.97 .918 .693 r
.39421 .37302 .40506 .37045 .42337 .33172 .41265 .33784 Mtetra
.98 .916 .634 r
.41265 .33784 .42337 .33172 .44154 .28955 .43107 .29638 Mtetra
.977 .919 .621 r
.43107 .29638 .44154 .28955 .45935 .2508 .44922 .25492 Mtetra
.97 .932 .666 r
.44922 .25492 .45935 .2508 .47677 .22003 .46696 .21969 Mtetra
.945 .938 .753 r
.46696 .21969 .47677 .22003 .49395 .19768 .48438 .19314 Mtetra
.888 .913 .837 r
.48438 .19314 .49395 .19768 .51102 .18177 .50161 .17419 Mtetra
.815 .863 .884 r
.50161 .17419 .51102 .18177 .52809 .17001 .51879 .16051 Mtetra
.754 .817 .902 r
.51879 .16051 .52809 .17001 .54522 .16067 .53602 .15003 Mtetra
.714 .784 .907 r
.53602 .15003 .54522 .16067 .56245 .15265 .55332 .14135 Mtetra
.691 .765 .908 r
.55332 .14135 .56245 .15265 .57977 .14534 .57072 .13365 Mtetra
.678 .754 .908 r
.57072 .13365 .57977 .14534 .59721 .13839 .58822 .12645 Mtetra
.671 .748 .908 r
.58822 .12645 .59721 .13839 .61475 .1316 .60584 .1195 Mtetra
.668 .745 .908 r
.60584 .1195 .61475 .1316 .63241 .12489 .62358 .11266 Mtetra
.666 .743 .908 r
.62358 .11266 .63241 .12489 .65018 .11819 .64142 .10586 Mtetra
.665 .742 .908 r
.64142 .10586 .65018 .11819 .66807 .11148 .65938 .09906 Mtetra
.664 .742 .908 r
.65938 .09906 .66807 .11148 .68607 .10474 .67746 .09224 Mtetra
.67746 .09224 .68607 .10474 .70418 .09797 .69566 .08538 Mtetra
.664 .741 .908 r
.69566 .08538 .70418 .09797 .72241 .09116 .71397 .07849 Mtetra
.71397 .07849 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10866 .51721 .09694 .50739 Mtetra
.09694 .50739 .10866 .51721 .1245 .5119 .11284 .50203 Mtetra
.11284 .50203 .1245 .5119 .14045 .50657 .12885 .49663 Mtetra
.12885 .49663 .14045 .50657 .15649 .5012 .14495 .4912 Mtetra
.14495 .4912 .15649 .5012 .17264 .49579 .16115 .48573 Mtetra
.646 .763 .934 r
.16115 .48573 .17264 .49579 .18889 .49034 .17746 .48022 Mtetra
.17746 .48022 .18889 .49034 .20524 .48485 .19388 .47467 Mtetra
.647 .763 .934 r
.19388 .47467 .20524 .48485 .2217 .4793 .21039 .46907 Mtetra
.648 .763 .933 r
.21039 .46907 .2217 .4793 .23827 .47367 .22702 .4634 Mtetra
.649 .764 .933 r
.22702 .4634 .23827 .47367 .25495 .46792 .24376 .45763 Mtetra
.652 .766 .933 r
.24376 .45763 .25495 .46792 .27175 .46198 .26062 .45172 Mtetra
.658 .77 .932 r
.26062 .45172 .27175 .46198 .28867 .45572 .27759 .44555 Mtetra
.668 .776 .93 r
.27759 .44555 .28867 .45572 .30573 .44887 .2947 .43895 Mtetra
.686 .787 .927 r
.2947 .43895 .30573 .44887 .32295 .44095 .31197 .43155 Mtetra
.718 .806 .92 r
.31197 .43155 .32295 .44095 .34037 .43113 .32941 .42272 Mtetra
.767 .836 .904 r
.32941 .42272 .34037 .43113 .35803 .41797 .34707 .41134 Mtetra
.835 .872 .871 r
.34707 .41134 .35803 .41797 .37597 .39938 .365 .39564 Mtetra
.906 .904 .811 r
.365 .39564 .37597 .39938 .39421 .37302 .38324 .37329 Mtetra
.956 .918 .732 r
.38324 .37329 .39421 .37302 .41265 .33784 .40174 .3423 Mtetra
.977 .917 .659 r
.40174 .3423 .41265 .33784 .43107 .29638 .42036 .30319 Mtetra
.979 .916 .621 r
.42036 .30319 .43107 .29638 .44922 .25492 .43882 .26063 Mtetra
.975 .925 .637 r
.43882 .26063 .44922 .25492 .46696 .21969 .45692 .22152 Mtetra
.961 .938 .706 r
.45692 .22152 .46696 .21969 .48438 .19314 .47462 .19044 Mtetra
.921 .93 .798 r
.47462 .19044 .48438 .19314 .50161 .17419 .49205 .16783 Mtetra
.851 .889 .865 r
.49205 .16783 .50161 .17419 .51879 .16051 .50937 .15169 Mtetra
.782 .838 .895 r
.50937 .15169 .51879 .16051 .53602 .15003 .52669 .13971 Mtetra
.731 .799 .905 r
.52669 .13971 .53602 .15003 .55332 .14135 .54408 .13016 Mtetra
.701 .773 .908 r
.54408 .13016 .55332 .14135 .57072 .13365 .56155 .12195 Mtetra
.683 .759 .908 r
.56155 .12195 .57072 .13365 .58822 .12645 .57913 .11444 Mtetra
.674 .751 .908 r
.57913 .11444 .58822 .12645 .60584 .1195 .59683 .10729 Mtetra
.669 .746 .908 r
.59683 .10729 .60584 .1195 .62358 .11266 .61464 .10031 Mtetra
.666 .744 .908 r
.61464 .10031 .62358 .11266 .64142 .10586 .63256 .09339 Mtetra
.665 .743 .908 r
.63256 .09339 .64142 .10586 .65938 .09906 .6506 .08649 Mtetra
.664 .742 .908 r
.6506 .08649 .65938 .09906 .67746 .09224 .66876 .07958 Mtetra
.66876 .07958 .67746 .09224 .69566 .08538 .68703 .07264 Mtetra
.664 .741 .908 r
.68703 .07264 .69566 .08538 .71397 .07849 .70542 .06566 Mtetra
.70542 .06566 .71397 .07849 .7324 .07155 .72394 .05864 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49663 .11711 .48658 Mtetra
.11711 .48658 .12885 .49663 .14495 .4912 .13327 .48109 Mtetra
.13327 .48109 .14495 .4912 .16115 .48573 .14953 .47555 Mtetra
.646 .763 .934 r
.14953 .47555 .16115 .48573 .17746 .48022 .1659 .46998 Mtetra
.1659 .46998 .17746 .48022 .19388 .47467 .18237 .46437 Mtetra
.647 .763 .934 r
.18237 .46437 .19388 .47467 .21039 .46907 .19895 .45871 Mtetra
.19895 .45871 .21039 .46907 .22702 .4634 .21564 .45299 Mtetra
.648 .764 .933 r
.21564 .45299 .22702 .4634 .24376 .45763 .23244 .44719 Mtetra
.65 .765 .933 r
.23244 .44719 .24376 .45763 .26062 .45172 .24935 .44127 Mtetra
.654 .768 .933 r
.24935 .44127 .26062 .45172 .27759 .44555 .26639 .43516 Mtetra
.662 .772 .931 r
.26639 .43516 .27759 .44555 .2947 .43895 .28355 .42872 Mtetra
.676 .781 .929 r
.28355 .42872 .2947 .43895 .31197 .43155 .30086 .42169 Mtetra
.7 .796 .924 r
.30086 .42169 .31197 .43155 .32941 .42272 .31834 .41358 Mtetra
.74 .82 .914 r
.31834 .41358 .32941 .42272 .34707 .41134 .33602 .40354 Mtetra
.8 .853 .89 r
.33602 .40354 .34707 .41134 .365 .39564 .35394 .39015 Mtetra
.871 .889 .844 r
.35394 .39015 .365 .39564 .38324 .37329 .37216 .3713 Mtetra
.935 .913 .773 r
.37216 .3713 .38324 .37329 .40174 .3423 .39069 .34463 Mtetra
.97 .919 .693 r
.39069 .34463 .40174 .3423 .42036 .30319 .40943 .30908 Mtetra
.98 .916 .634 r
.40943 .30908 .42036 .30319 .43882 .26063 .42816 .26722 Mtetra
.977 .919 .622 r
.42816 .26722 .43882 .26063 .45692 .22152 .44661 .22538 Mtetra
.97 .932 .666 r
.44661 .22538 .45692 .22152 .47462 .19044 .46464 .18981 Mtetra
.945 .938 .753 r
.46464 .18981 .47462 .19044 .49205 .16783 .48232 .16298 Mtetra
.888 .913 .837 r
.48232 .16298 .49205 .16783 .50937 .15169 .49981 .14378 Mtetra
.815 .863 .884 r
.49981 .14378 .50937 .15169 .52669 .13971 .51725 .12987 Mtetra
.754 .817 .902 r
.51725 .12987 .52669 .13971 .54408 .13016 .53472 .11918 Mtetra
.714 .784 .907 r
.53472 .11918 .54408 .13016 .56155 .12195 .55228 .1103 Mtetra
.691 .765 .908 r
.55228 .1103 .56155 .12195 .57913 .11444 .56994 .10239 Mtetra
.678 .754 .908 r
.56994 .10239 .57913 .11444 .59683 .10729 .58771 .09499 Mtetra
.671 .748 .908 r
.58771 .09499 .59683 .10729 .61464 .10031 .60559 .08784 Mtetra
.668 .745 .908 r
.60559 .08784 .61464 .10031 .63256 .09339 .62359 .08079 Mtetra
.666 .743 .908 r
.62359 .08079 .63256 .09339 .6506 .08649 .64171 .07379 Mtetra
.665 .742 .908 r
.64171 .07379 .6506 .08649 .66876 .07958 .65994 .06678 Mtetra
.664 .742 .908 r
.65994 .06678 .66876 .07958 .68703 .07264 .6783 .05974 Mtetra
.6783 .05974 .68703 .07264 .70542 .06566 .69678 .05268 Mtetra
.664 .741 .908 r
.69678 .05268 .70542 .06566 .72394 .05864 .71537 .04557 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47641 Mtetra
.10523 .47641 .11711 .48658 .13327 .48109 .12145 .47085 Mtetra
.12145 .47085 .13327 .48109 .14953 .47555 .13777 .46526 Mtetra
.13777 .46526 .14953 .47555 .1659 .46998 .1542 .45962 Mtetra
.646 .763 .934 r
.1542 .45962 .1659 .46998 .18237 .46437 .17073 .45395 Mtetra
.17073 .45395 .18237 .46437 .19895 .45871 .18737 .44822 Mtetra
.647 .763 .934 r
.18737 .44822 .19895 .45871 .21564 .45299 .20412 .44245 Mtetra
.648 .763 .933 r
.20412 .44245 .21564 .45299 .23244 .44719 .22098 .43661 Mtetra
.649 .764 .933 r
.22098 .43661 .23244 .44719 .24935 .44127 .23796 .43067 Mtetra
.652 .766 .933 r
.23796 .43067 .24935 .44127 .26639 .43516 .25505 .42458 Mtetra
.658 .77 .932 r
.25505 .42458 .26639 .43516 .28355 .42872 .27227 .41823 Mtetra
.668 .776 .93 r
.27227 .41823 .28355 .42872 .30086 .42169 .28963 .41144 Mtetra
.686 .787 .927 r
.28963 .41144 .30086 .42169 .31834 .41358 .30715 .40385 Mtetra
.718 .806 .92 r
.30715 .40385 .31834 .41358 .33602 .40354 .32485 .39482 Mtetra
.767 .836 .904 r
.32485 .39482 .33602 .40354 .35394 .39015 .34278 .38321 Mtetra
.835 .872 .871 r
.34278 .38321 .35394 .39015 .37216 .3713 .36099 .36727 Mtetra
.906 .904 .811 r
.36099 .36727 .37216 .3713 .39069 .34463 .37952 .34462 Mtetra
.956 .918 .732 r
.37952 .34462 .39069 .34463 .40943 .30908 .39833 .31329 Mtetra
.977 .917 .659 r
.39833 .31329 .40943 .30908 .42816 .26722 .41726 .27379 Mtetra
.979 .916 .621 r
.41726 .27379 .42816 .26722 .44661 .22538 .43603 .23083 Mtetra
.975 .925 .637 r
.43603 .23083 .44661 .22538 .46464 .18981 .45441 .19136 Mtetra
.961 .938 .707 r
.45441 .19136 .46464 .18981 .48232 .16298 .47239 .15996 Mtetra
.92 .93 .798 r
.47239 .15996 .48232 .16298 .49981 .14378 .49009 .13708 Mtetra
.851 .889 .865 r
.49009 .13708 .49981 .14378 .51725 .12987 .50767 .1207 Mtetra
.782 .838 .895 r
.50767 .1207 .51725 .12987 .53472 .11918 .52525 .1085 Mtetra
.731 .798 .905 r
.52525 .1085 .53472 .11918 .55228 .1103 .5429 .09874 Mtetra
.701 .773 .908 r
.5429 .09874 .55228 .1103 .56994 .10239 .56063 .09032 Mtetra
.683 .759 .908 r
.56063 .09032 .56994 .10239 .58771 .09499 .57848 .08261 Mtetra
.674 .751 .908 r
.57848 .08261 .58771 .09499 .60559 .08784 .59644 .07525 Mtetra
.669 .746 .908 r
.59644 .07525 .60559 .08784 .62359 .08079 .61452 .06806 Mtetra
.666 .744 .908 r
.61452 .06806 .62359 .08079 .64171 .07379 .63271 .06094 Mtetra
.665 .743 .908 r
.63271 .06094 .64171 .07379 .65994 .06678 .65103 .05382 Mtetra
.664 .742 .908 r
.65103 .05382 .65994 .06678 .6783 .05974 .66947 .0467 Mtetra
.66947 .0467 .6783 .05974 .69678 .05268 .68802 .03954 Mtetra
.664 .741 .908 r
.68802 .03954 .69678 .05268 .71537 .04557 .70671 .03235 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47641 .09322 .46612 Mtetra
.09322 .46612 .10523 .47641 .12145 .47085 .10949 .4605 Mtetra
.10949 .4605 .12145 .47085 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45962 .14236 .44913 Mtetra
.646 .763 .934 r
.14236 .44913 .1542 .45962 .17073 .45395 .15895 .44339 Mtetra
.15895 .44339 .17073 .45395 .18737 .44822 .17565 .43761 Mtetra
.647 .763 .934 r
.17565 .43761 .18737 .44822 .20412 .44245 .19246 .43177 Mtetra
.19246 .43177 .20412 .44245 .22098 .43661 .20939 .42588 Mtetra
.648 .764 .933 r
.20939 .42588 .22098 .43661 .23796 .43067 .22643 .4199 Mtetra
.65 .765 .933 r
.22643 .4199 .23796 .43067 .25505 .42458 .24358 .41381 Mtetra
.654 .768 .933 r
.24358 .41381 .25505 .42458 .27227 .41823 .26086 .40751 Mtetra
.662 .772 .931 r
.26086 .40751 .27227 .41823 .28963 .41144 .27828 .40088 Mtetra
.676 .781 .929 r
.27828 .40088 .28963 .41144 .30715 .40385 .29584 .39366 Mtetra
.7 .796 .924 r
.29584 .39366 .30715 .40385 .32485 .39482 .31358 .38535 Mtetra
.74 .82 .914 r
.31358 .38535 .32485 .39482 .34278 .38321 .33152 .3751 Mtetra
.8 .854 .89 r
.33152 .3751 .34278 .38321 .36099 .36727 .34973 .36147 Mtetra
.871 .89 .844 r
.34973 .36147 .36099 .36727 .37952 .34462 .36823 .34234 Mtetra
.935 .914 .773 r
.36823 .34234 .37952 .34462 .39833 .31329 .38707 .31534 Mtetra
.97 .919 .692 r
.38707 .31534 .39833 .31329 .41726 .27379 .40612 .27942 Mtetra
.98 .916 .634 r
.40612 .27942 .41726 .27379 .43603 .23083 .42517 .23716 Mtetra
.977 .919 .622 r
.42517 .23716 .43603 .23083 .45441 .19136 .44392 .19493 Mtetra
.97 .932 .666 r
.44392 .19493 .45441 .19136 .47239 .15996 .46224 .15903 Mtetra
.945 .938 .753 r
.46224 .15903 .47239 .15996 .49009 .13708 .4802 .1319 Mtetra
.888 .912 .837 r
.4802 .1319 .49009 .13708 .50767 .1207 .49795 .11244 Mtetra
.815 .863 .884 r
.49795 .11244 .50767 .1207 .52525 .1085 .51566 .0983 Mtetra
.754 .816 .902 r
.51566 .0983 .52525 .1085 .5429 .09874 .53339 .08739 Mtetra
.714 .784 .907 r
.53339 .08739 .5429 .09874 .56063 .09032 .55121 .07829 Mtetra
.691 .765 .908 r
.55121 .07829 .56063 .09032 .57848 .08261 .56914 .07018 Mtetra
.678 .754 .908 r
.56914 .07018 .57848 .08261 .59644 .07525 .58717 .06257 Mtetra
.671 .748 .908 r
.58717 .06257 .59644 .07525 .61452 .06806 .60533 .0552 Mtetra
.668 .745 .908 r
.60533 .0552 .61452 .06806 .63271 .06094 .62361 .04794 Mtetra
.666 .743 .908 r
.62361 .04794 .63271 .06094 .65103 .05382 .642 .04072 Mtetra
.665 .742 .908 r
.642 .04072 .65103 .05382 .66947 .0467 .66052 .0335 Mtetra
.664 .742 .908 r
.66052 .0335 .66947 .0467 .68802 .03954 .67917 .02625 Mtetra
.67917 .02625 .68802 .03954 .70671 .03235 .69793 .01896 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46612 .08106 .45571 Mtetra
.08106 .45571 .09322 .46612 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44913 .13038 .43852 Mtetra
.13038 .43852 .14236 .44913 .15895 .44339 .14703 .43271 Mtetra
.646 .763 .934 r
.14703 .43271 .15895 .44339 .17565 .43761 .16379 .42686 Mtetra
.16379 .42686 .17565 .43761 .19246 .43177 .18067 .42096 Mtetra
.647 .763 .934 r
.18067 .42096 .19246 .43177 .20939 .42588 .19765 .41501 Mtetra
.648 .763 .933 r
.19765 .41501 .20939 .42588 .22643 .4199 .21475 .40899 Mtetra
.649 .764 .933 r
.21475 .40899 .22643 .4199 .24358 .41381 .23197 .40286 Mtetra
.652 .766 .933 r
.23197 .40286 .24358 .41381 .26086 .40751 .24932 .39659 Mtetra
.658 .77 .932 r
.24932 .39659 .26086 .40751 .27828 .40088 .26679 .39005 Mtetra
.668 .776 .93 r
.26679 .39005 .27828 .40088 .29584 .39366 .28441 .38307 Mtetra
.686 .787 .927 r
.28441 .38307 .29584 .39366 .31358 .38535 .30218 .37528 Mtetra
.718 .806 .92 r
.30218 .37528 .31358 .38535 .33152 .3751 .32015 .36603 Mtetra
.767 .836 .904 r
.32015 .36603 .33152 .3751 .34973 .36147 .33836 .3542 Mtetra
.835 .872 .871 r
.33836 .3542 .34973 .36147 .36823 .34234 .35685 .33799 Mtetra
.906 .904 .811 r
.35685 .33799 .36823 .34234 .38707 .31534 .37568 .31505 Mtetra
.956 .918 .732 r
.37568 .31505 .38707 .31534 .40612 .27942 .3948 .28336 Mtetra
.977 .917 .659 r
.3948 .28336 .40612 .27942 .42517 .23716 .41405 .24347 Mtetra
.979 .916 .621 r
.41405 .24347 .42517 .23716 .44392 .19493 .43314 .20011 Mtetra
.975 .925 .637 r
.43314 .20011 .44392 .19493 .46224 .15903 .45183 .16027 Mtetra
.961 .937 .707 r
.45183 .16027 .46224 .15903 .4802 .1319 .4701 .12855 Mtetra
.92 .929 .798 r
.4701 .12855 .4802 .1319 .49795 .11244 .48807 .10539 Mtetra
.851 .889 .865 r
.48807 .10539 .49795 .11244 .51566 .0983 .50592 .08877 Mtetra
.782 .838 .895 r
.50592 .08877 .51566 .0983 .53339 .08739 .52377 .07634 Mtetra
.731 .798 .905 r
.52377 .07634 .53339 .08739 .55121 .07829 .54168 .06636 Mtetra
.701 .773 .908 r
.54168 .06636 .55121 .07829 .56914 .07018 .55968 .05773 Mtetra
.683 .759 .908 r
.55968 .05773 .56914 .07018 .58717 .06257 .5778 .0498 Mtetra
.674 .751 .908 r
.5778 .0498 .58717 .06257 .60533 .0552 .59603 .04222 Mtetra
.669 .746 .908 r
.59603 .04222 .60533 .0552 .62361 .04794 .61439 .03481 Mtetra
.666 .744 .908 r
.61439 .03481 .62361 .04794 .642 .04072 .63287 .02747 Mtetra
.665 .743 .908 r
.63287 .02747 .642 .04072 .66052 .0335 .65147 .02014 Mtetra
.664 .742 .908 r
.65147 .02014 .66052 .0335 .67917 .02625 .6702 .01279 Mtetra
.6702 .01279 .67917 .02625 .69793 .01896 .68905 .00541 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooe;lD]`0
07oo0000Egoo003EOol30003Ool00e;lD]aBo002D_`01000D_aoo`00EWoo003BOol30004Ool02e;L
E_aBg5;lD]aFo5;L001Bg5Kl0000EWoo003@Ool20003Ool00e;lD]aBo002D_`02e;LD_aBo5;lD]aB
o000D_aBg5;l0000EGoo003=Ool30003Ool04e;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;l
D]aoo`0005Aoo`00bgoo0P000goo25;l00EBg5;lD_aBo5;L00=Bo006001Bo5;lD_aBg000E7oo0038
Ool3000077oo001ooeKlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_ao
o`00Dgoo001WOol20002Ool2001IOol20003Ool00e;l001Bo00<D_`01E;LD_aBo5;lD]`00U;l00<0
05;LD_`00U;l00=oo`00Ool0DGoo001XOol01000Oomoo`00Egoo0`000goo01mBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LOol0001BOol006Uoo`80
05Ioo`80009oo`9Bo005E_aBo5;lD_aFo008D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L0002
D_`01E;LD_aBo7oo0000DGoo001YOol2001COol30002Ool095;lE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo09oo`03001oogoo
04ioo`00J7oo00@007ooOol0051oo`80009oo`06D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`015;LD_aoo`00D7oo001WOol20002Ool2001<Ool3
0002Ool0;ELLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlOol0001?Ool00;Ioo`<0009oo`03001Fo5Kl
00AFo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aB
g003D_`00e;L0000001?Ool00;Aoo`8000Aoo`0bFaaFo5LLD_aG75;lEaaBo5KlD_aFo5;lE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5Kl
D]aBo5;LOol004ioo`00/Goo0`0017oo00=G75/LE_`00ULL1UKl0U;l00EFo5;lD_aBo5Kl00=Bo003
E_aBo5;l00YBo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01e;LD_aBo5;lD]aoo`0004eoo`00
[goo0P001Goo03MK75KlFaaFo5/LE_aK75;lEaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lOol0
000AOol5000gOol00:aoo`<000Ioo`04FcaK75/LE_`2Ea`00e/LE_aG7002E_`015;lE_aFo5Kl0e;l
00EFo5;lD_aBo5Kl00aBo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00IBg5;lD_aBo7oo
000@Ool01@00Oomoogoo0000=goo002ZOol20007Ool015/LGcaK6ell0U/L03IFo5/LE_aG75KlEaaB
o5KlD_aG75;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000@Ool00`00Oomoo`0hOol00:Moo`<0009o
o`03001oogoo009oo`09GcaK75/lFaaO?5/LFcaK75LL00=Fo003EaaFo5Kl009Fo004D_aFo5;lE_`3
D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003
D_`00`00Oomoo`05Ool60004Ool00`00Oomoo`0gOol00:Eoo`8000Uoo`09HeaS>ellFa]O?5/LGcaK
6e/L009G700eE_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000AOol0
0`00Oomoo`0fOol00:9oo`<000Uoo`9SG006He]SG6=LGcaK75/l15/L00=Fo5LLE_`00UKl00UG75;l
E_aBo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg000
0U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000AOol00`00Oomoo`0eOol007Eoo`@002Moo`80
00Yoo`15HeaS>f=LHc]SG6<kHeaS>e/LEaaK75LLFaaG75/LE_aG75KlEaaBo5LLD_aFo5;lE_aBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg00000eoo`05001oogooOol0000gOol007Aoo`03001oogoo009o
o`03001oogoo025oo`<000]oo`9[N`03HeaSFf=L009SG003He]O?5ll00IK70MFo004D_aFo5;lE_`3
D_`01EKlD_aBo5;lE_`025;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;l
D]`00e;l00ABg5;lOol000eoo`<003Qoo`00M7oo00<007ooOol00Woo00<007ooOol07Woo0`003Goo
04U[Vf]jKi][NV=LHc]SG5lkGcaO>f<lEaaK75LLFaaFo5/LE_aG75;lEaaBo5LLD_aG75;LE_aBo5Kl
D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol00017Ool007Aoo`03001oogoo009oo`03001oogoo01ao
o`80009oo`03001oogoo00Yoo`9[N`04Ji][NV]kJg/7Gc`00eLLFaaFo002Ea`00e/LE_aFo006E_`3
D_`01EKlD_aBo5;lE_`035;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;LD_aBo5;l
D]`00e;l00=Bg7oo0000Agoo001dOol00`00Oomoo`02Ool00`00Oomoo`0IOol3000@Ool0C6^KJgY_
Vf]jJi][NVMlIe]O?5lkHcaO>ellFa]O?5KlFaaFo5/LE_aK75KlEaaBo5KlD_aG75;lE_aBg5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00AWoo001dOol00`00Oomoo`02Ool00`00Oomoo`0GOol2
000BOol2Jg/01f^KJgY[Nf]kIg]WFfMk00=O?00;FcaK75llFaaK?5LLFaaFo5LLE_aG7004E_`015;l
E_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00D_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03001oogoo04=oo`00M7oo00<007ooOol00Woo00<0
07ooOol057oo0`004goo04mg^G>HKi][NV^KIe]WO6MKIgaWFfMlFaaO?5/KGcaK75llFa]O?5KlEaaF
o5LLE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol00015Ool0
07Eoo`@001Eoo`8001Ioo`0BLkQg^G>HLkUWFfMkIe]WNfMKIg]SFf=LFaaO?5/LFcaK75ll0U/L00=F
o5LLE_`00UKl00=G75;lE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003
D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo0014Ool0
08]oo`<001Moo`1BLiQg^G>HMkU_VG>jIe]WO6MKHeaS>f=LHc]SG5/LGcaK6e/LEaaK75LLFaaFo5LL
E_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0013Ool0
08Uoo`80009oo`03001oogoo01Aoo`06LkQg^G>HLkU_VW>J0VnJ0V=L00ISFf=LHeaSG6=KHe`7Fa`2
E_`00eLLE_aFo002E_`025;lE_aBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool0
@Woo0026Ool3000JOol067>HMkUcV7NiKiUc^VnILiY[NVnKHc]SG6<kHeaS>f=LGc]SG5LLFaaG75/L
EaaK709G700kD_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LOol00012Ool008Aoo`8001eoo`05MkUcV7>iKiYcVP02KiX016]kJi][NV]k0V=L00=SFellGc`0
0ell15/L00=G75/LE_`01eKl0e;l00EFo5;lD_aBo5Kl00=Bo003E_aBo5;l00IBo005D]aBo5;lD_aB
g003D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001o
o`10Ool0085oo`<001ioo`1GMkUcV7NiKiUc^VnILiY[NVnKJgY[Vf]jKi]O>ellGc]SG5lkGcaO>f=L
E_aK75KlFaaFo5/LD_aG75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aoo`00045oo`00OWoo0`0087oo00Ek]W^eNkI_VW>J009_VP03Jg][Vf]j009[N`03Ji]W
FfMk00IO?005FaaK?5LLFaaFo002Ea`00e/LD_aFo002E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo004D]aBo7oo0010Ool007aoo`8002=oo`04MkEk]WNgNkL2MkL0E6]jKi][NV^KJgY_VfMKIgaW
FfMlGc]O?5lkGcaK75llFa]K75KlFaaFo5LLE_aG75;lEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol003moo`00NGoo0`000Woo0P0087oo00=k]G^fNkD0
0gNg00=c^7NiJgX00V]k00iWNfMKIg]WFfMkIe]WNe/LGcaK75/lFaaO?5/L0UKl00IG75KlE_aFo5LL
D_`3E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo009D]aBo5;lD_aBg5;l
001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000?goo001gOol2
000VOol017NeNkIgUG^g0gNg015g^G>HMkUcV6MlIe]WO6MKIgaWFfMlHc]SG5/LGcaK6ell009K709G
7011E_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LOol0000nOol007Aoo`<002Qoo`03NkIk]GNg00=g]`0:MkUc^7>iLkQcVVnJIg]WFfMk
Ie/3He`016=KFcaK75ll1E/L0UKl00=G75KlE_`00UKl00QBo5KlD_aFo5;lE_aBo5Kl0e;l00=Fo5;l
D_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo004D]aBo5;lD_`2Ool00`00Oomoo`0kOol0079oo`8002Yoo`03NkIgUG^g00=g]`1I
MkUcV7NiLiQc^VnILiY_VG>jHc]SG6<kHeaS>f=LHc]K75LLFaaG75/LEaaK75KlEaaFo5LLD_aG75;l
E_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000m
Ool006moo`<002]oo`03NkIk]G^f00=g]`05MkUc^7>iLkQcVP03KiX00g>JJgY[N`02He`00f=KHeaS
G002Gc`7Fa`8E_`015;lE_aBo5Kl0e;l00EFo5;lD_aBo5Kl00QBo005D]aBo5;lD_aBg003D_`01E;L
D_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo002Ool00`00
Oomoo`0jOol006eoo`800003Ool007oo02]oo`03MiEk]WNg009g]`1JNkMcV7NiLiQc^VnILiY_VG>j
JgY[Vf]jHeaS>f=LGc]SG5lkGcaO>e/LEaaK75LLFaaFo5/LD_aG75;lEaaBo5LLD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00<007ooOol0>Goo001Z
Ool3000_Ool00g^CNkAkT`03Nk@017>hLkUc^7>J0fnJ00IcVV]jJg][Nf^KJgX8Gc`2Ea`015/LE_aG
75LL1EKl00ABo5KlD_aFo0=Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo0000>goo001WOol3000b
Ool08GndNi=k]G^DNkEg]G^fMkEk]gNgLiY_VG>jJgY[Vf]jKi][NVMlIe]SG5lkGcaO>f=LFaaO?5/K
FaaFo5/LE_aK7002E_`0@E;lEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo0000>Woo001UOol2000dOol00g^dNi=k/`03Nk@00g^fNkEk
]P04MkL04F]jJg][Nf^KJgYWNfMKIg]WFfMkFaaO?5/LFcaK75llFa`00ULL00=K75KlE_`00UKl00QB
o5KlE_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002
D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002
D_`00`00Oomoo`0hOol0069oo`<003Ioo`08Ni=k]7^DNkEkU7^fMkEk]P=g]`0INkMcV7NiJgY_Vf]j
IgaWFfMlIe]WO6<kHeaK75llFa]O?5/LGcaK6eLLE_aG75KlEa`00UKl041Bo5LLD_aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`003Uoo`00H7oo
0P00>7oo00=kTg^cNi<00g^d00=k]G^fNkD00gNg00Yc^7>iLkQg^G>hIg]WFfMkIe]WN`9SG006He]S
G5/LGcaK75/l0e/L0UKl00=G75KlE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;l
D_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo004D]aBo7oo000hOol005eoo`<00003Ool007oo03Moo`08NkAkTg^eNiAk]GNe
NkIg]@9g]`1NNkMg]gNiLiQg^G>HLiY_VFMlIe]SG6<kHeaS>f=LHc]SG5LLFaaG75/LEaaK75KlEaaF
o5LLD_aG75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5Kl000hOol005]oo`8003aoo`03Nk=kTg^d00=k]003NkIk]GNg00=g]`04LkUc
^7NiLkP2KiX00g>JKiYSG002He`016=KHeaSG6=L0Ull1U/L25Kl00ABo5KlD_aFo0=Bo003E_aBo5;l
00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000=goo000^Ool4000VOol3000nOol0Jg^COkAk
U7^eNiAk]WNeNkIg]g^gMkMg^G>HMkUcV7>JKiUc^VnIJi][NV=LHc]SG6<kHeaO>ellGc]K75LLFaaG
75/LE_aK75;lEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00008Woo0`004Goo000]Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol20010Ool00g^CNkAkT`03Nk@00g^eNkIg]`02MkL017>iLkQg^G>h0VnJ00McVVnJJg][
Nf^KJgY[N`07Gc`2Ea`01E/LE_aG75LLFa`015Kl00ABo5KlE_aFo0=Bo005E_aBo5;lD_aFo00<D_`0
1E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo02=oo`03001oogoo00moo`00<Woo00<007ooOol07Goo
1000@Woo06eo]7^CNkEkU7^eNi=k]7^CNkEkU7^fMkEk]WNeLiY_VG>jJgY[Vf]jKi][NV^KIe]WO5lk
GcaO>f=LGc]O?5/KFaaFo5/LE_aK75KlFaaBo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000SOol00`00Oomoo`0?
Ool002Eoo`H000Moo`03001oogoo01aoo`<004=oo`08NkAkTg^cNi=k/g^CNk=kT`=k]003NkEk]W^e
00=g]`06JgY[Nf]kJi][NV]k0VMk00UWFellGcaO?5/LFcaK75llFa`00ULL00IK75KlE_aFo5LLD_`3
E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`0
0`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1U;LD_aBo5;lOol0025oo`03001oo`00011oo`00;Woo100077oo0`00AWoo02QkTWncNi9o/g^CNkAk
TgndNiAk]GNeNkIg]G^fMkMk]g>HMkU[NVnKJgYWO6MKIgaWFfMlIe]O?5/LGcaK6ellFaaO?5/KEaaF
o5LLE_aG709Fo015D_aG75;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`00025oo`03001oo`00011oo`00;Woo00<007ooOol0
6Woo0`00BGoo0W^C00Ak/g^CNi=kT`Ak]003NkIk]G^f00=g]`04LkUc^7NiLkP3Ig/02VMKIg]WNf=L
He]K?5/LGcaK75/l0e/L0UKl00=G75KlE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00YBo005D]aB
o5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`2000OOol01@00Oomoogoo00003goo000^Ool0
0`00Oomoo`0HOol2001;Ool0LWncNi9o/g^COk=kTgndNi=k]G^DNkIg]G^fMkEk]gNgMkUcV7NiLiQc
VVnIIgaWFfMlHc]SG6<kHeaS>ellFaaO?5LLFaaG75/LE_aG75KlEaaBo5LLD_aFo5;lE_aBo5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LOol001ioo`05001oogooOol0000?Ool002ioo`D001=oo`<004eoo`EkT`03NkAkTg^d009k]003
NkEk]W^e009g]`04LkUc^7NiLkP2KiX00g>JKiY_VP02He`01F=KHeaSG6=LHe/01e/L25Kl00ABo5Kl
D_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QBg5;lD_aBo5;LD_aoo`007Goo
0`0000Aoo`00000000ioo`00A7oo0P00Cgoo07AkTWncNi9o/g^BOkAkTg^dNiAk]GNeNkIg]G^gMkMg
^G>HMkUcV7>JKiUc^VnILiY[NVnKHc]SG6<kHeaS>ellGc]K75LLFaaG75/LE_aK75;lEaaBo5LLD_aG
75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aoo`002Goo100097oo0011Ool300000goo001oo`1>Ool4Ni<00g^cNi=k
/`03Nk@00g^fNkEk]P02MkL00g>hMkUc^002KiX01W>JKiY_VV]kJi][NP=SG0IO?003EaaK75Kl009G
7003FaaFo5Kl009Fo004D_aFo5KlE_`3D_`01EKlD_aBo5;lE_`035;l00EBg5;lD_aBo5;L00=Bo005
D]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`025;LD_aBo5;lD]aBo7oo0007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003moo`8005Aoo`0<
Ni9o/g^BOk=kTg^dNi=k]G^DNkIg]G^f0WNg06McV7NiLiQcVVnILkY_VG>JJgY_Vf]jJi][NV=LGc]O
?5lkHeaO>ellFa]O?5KlFaaFo5/LE_aK75;lEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol00007Ool0
0`00Oomoo`02Ool00`00Oomoo`0QOol003aoo`<005Eoo`=kT`05Nk=kTg^cNi=k/`03Ni<01W^dNi=k
]7^dNkIk]@9g]`06LiY_VVnJJg][Vf]j0V]k00=WNfMKGc`00ell00AK?5/LGcaK709G7006FaaFo5Kl
E_aG75;l0eKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo007D]aBo5;lD_aBg7oo00001Woo00<007ooOol00Woo00<007ooOol08Goo000jOol2
001HOol04gncNi9o/g^CNkAkTgncNi=o/g^COkAkTg^eNiAk]WNeNkIg]g^g009g]`0FJgY_Vf]jJi]W
FfMlIe]WO6MKIgaK75llFa]O?5/LGcaK6eLLE_aG75KlEa`2E_`0B5;lEaaBo5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo09oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo025oo`00=goo0`00FGoo2W^C00=k
]7^CNk<00W^d00=k]G^fMkL00gNg00Ac^7NiLkQc^@9WN`0:Ie]WNfMkIg]SFf=LFaaO?5/LFc`3Fa`2
E_`00eLLE_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo009D]aB
o5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`04Ool00`00Oomoo`02Ool00`00Oomoo`0QOol0
03Eoo`800003Ool007oo05Uoo`0BNi9o/g^COk=kTgncNi9o/g^BOkAkTg^dNiAk]GNeNkIg]G^g0WNg
01AcV7NiLiQg^FnILkYWFfMlIe]SG6<kHeaS>ellFaaO?5LLFaaG75/L0ULL04eFo5LLD_aG75;lE_aB
o5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo025o
o`00<Woo0`00GGoo2G^C00Ak/g^CNk=kT`9k]003NkIk]GNg00=g]`05MkUc^7>iKiYcVP02KiX2He`0
1F=KHeaSG6=LHe/025/L1eKl00ABo5KlD_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l00<000Aoo`@002Aoo`00;goo0`00H7oo015o]7^DOkAk
TgndNi9o/g^BOk=kTg^dNi=k]G^DNkIg]G^g00=g]`1XMkUcV7NiLiQc^VnILiY[NVnKHc]SG6<kHeaS
>ellGc]K75LLFaaG75/LE_aK75KlEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0
02aoo`00;Goo0P00Hgoo0W^D1G^C00Ak/g^CNk=kT`=k]003NkEk]WNg009g]`05MkUc^7>iLkQcVP02
KiX016]kJi][NV]k0V=L1Ull00=G75/LE_`00ULL00=K75KlE_`00UKl00ABo5KlE_aFo0=Bo005E_aB
o5;lD_aFo00<D_`01E;LD_aBo5;lD]`00e;l00EBg000001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aoogoo0000
:goo000ZOol3001TOol047^DOkAkU7ndNi=o/g^BOk=kTg^dNi=o]7^DNkEg]G^f0gNg03ag^G>HMkUc
V7>jKiUcVV]jKi][NV^KJgY_VelkGcaO>f=LGc]O?5/KGcaFo5/LE_aK75KlFaaBo5LLD_aFo5;lEaaB
o5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]`30000:U;L
E_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo09oo`03001oogoo02Qoo`00:7oo0P0000=oo`00Ool0I7oo0W^D
27^C00Ik]7^CNkAk]7^cNi<2Nk@01G^fNkEk]W^eLiX00VnJ00=[Nf^KJgX00V]k00=[VfMKIg/00ell
00AK?5/LGcaK709G7006FaaFo5KlE_aG75;l0eKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aB
o5;lD_aBg003D_`01E;L00000000D]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`00:Woo
000VOol2001XOol05gndNiAo]7^COkAkTWncNi=o/g^COkAkTgncNi9o]7^CNkEkU7^eMkEk]WNeNkL0
0WNg039[NVnKJgY[Vf]jIgaWFfMlIe]WO5/LGcaK6ellFaaO?5/KEaaFo5LLE_aG75KlEaaBo5LLD_aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl0P00035Bg5KlD]aBo5;L
E_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0WOol002Ioo`8006Qoo`9kU0]k
T`03Nk=kTg^c009k]004NkEk]W^eNkH2MkL017>hMkUc^7>i0VMk00YWFfMkIg]WNf=KHeaK75llFaaK
?0=K709Fo00=EaaFo5KlE_aG75;lE_aBo5KlD_aFo5;lE_`035;l00=Bg5;l00000P000e;l00EBg5;l
D_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg7ooOol002Qoo`009Woo0`00IWoo01IkU7nd
NiAo]7^COk=kTWncNi9o]7^BOk=kTWncNi=k]7^DNkEkU7^fMkEk]P=g]`0CMkUcV7NiKiUc^VMKIgaW
Ff=LHc]SG6<kHeaK75llEaaK75LLFa`00ULL01QFo5LLE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_`30000>UKlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aoo`00:7oo000VOol01000Oomoo`00IGoo0W^D2W^C00Ak/g^CNk=kT`9k]003
NkIk]G^f00=g]`05MkUc^7>iKiYcVP03KiX00f=LHe]SG002He`00f=KHeaK7006Fa`7E_`015;lE_aB
o5Kl0e;l00=Fo5;lD_`015;l0`000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo09oo`03001oogoo02Eoo`009Goo00<007ooOol00Woo00<007ooOol0HGoo
01Eo]7^DOkAkTgndNi9o/g^DOkAkTgncNi9o/g^BNkAkTg^eNiAk]GNeNkH00gNg02Ug^G>HMkU_VG>j
KiUcVVnIKi][NV=LHc]SG6<kGcaO>f=LEaaK75LLFaaFo5/LE_aG75;lEaaBo5LLD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5Kl00<00011E_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000WOol002Eoo`03001oogoo00=oo`03001oogoo061o
o`9kU0=kT`9kU0QkT`06Nk=k]7^dNkEk]W^e0gNg00Ac^7>iKiYcVP=_VP04Ji][NV]kJg/7Gc`00eLL
FaaFo002Ea`00e/LE_aFo002E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`00`002e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo02Eoo`009Goo00<0
07ooOol017oo00<007ooOol0GWoo01EkU7ndNiAo]7^EOkAkU7ndNi=o]7^BOk=kTWncNi=o]7^DNkEk
U7^fMkD00WNg02Ek]g>HMkU_VG>jKiUcVV]jKi][NV^KJgYWO6MKGcaO>f=LGc]O?5/KGcaFo5/LE_aK
75KlFaaBo5LLD_aFo5;lEaaBo5KlD]aFo0030000AUKlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00<007oo
Ool08goo000UOol20006Ool2001NOol2Ni@00g^eNiEkU@02Ni@7Ni<01g^cNi=k]7^dNk=kTg^c009k
]003NkEk]W^e00=g]`03Jg][Vf]j009[N`04Ig]WFfMkIg/2Gc`01e/lFaaO?5/LFcaG75/L00=Fo003
EaaBo5Kl009Fo003D_aFo5;l0080009Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo00009Goo000U
Ool00`00Oomoo`07Ool00`00Oomoo`1JOol06g^gMiIk]g^ENkEkU7ndNiAo]7^COk=kTWncNi9o]7^C
Ok=kTWncNi=k]7^DNkEkU7^fMkEk]`02MkL06g>HMkU[NV^KIe]WO6MKIgaWFfMlIe]O?5/KGcaK75ll
Fa]O?5KlEaaFo5LLE_aG75;lEaaBo0030000Ce;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aoo`0002Aoo`009Goo00<007ooOol027oo00<007ooOol0F7oo00=kUWNFNkL00g^E0W^D1W^C00Qk
/g^CNi=kTg^cNi=k/g^C0W^d00=k]W^eNkH00gNg00=g^G>hLkT00VMk00EWFfMkIg]WNfMK009SG003
GcaK75/l00AK7003E_aG75Kl009Fo0<00006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo7ooOol0000SOol002Eoo`03001oogoo00Uoo`03001oogoo05Moo`0JMiIk]gNFNkEkUGndNiAo
]7^COkAkTWncNi9o/g^BOk=kTWncNi9k]7^CNkEkU7^eMkEk]P=g]`0CMkUcV7NiKiUc^VMKIgaWFfMl
Hc]SG6<kHeaS>e/LEaaK75LLFa`00ULL05YFo000000005;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000SOol002Aoo`8000aoo`03001oogoo05Eoo`03MiIk]gNF
009kU@03NkEkU7^D00EkT`09Nk=kTg^CNi=k/g^CNk=kTg^c009k]003NkEk]W^e009g]`05MkUc^7>i
KiYcVP03KiX00f=LHe]SG002He`00f=KGcaO?004Fa`30006E_`015;lE_aBo5Kl0e;l00EFo5;lD_aB
o5Kl00QBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00UBg5;lD_aBo5;LD_`005;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo004D]aBo7oo000ROol002Aoo`03001oogoo00aoo`03001oogoo05Aoo`0JNkMgUW^gNiEk
]W^DOkAkU7ndNi=o/g^BOkAkTgncNi9o/g^BOk=kTgndNiAk]GNeNkIg]@9g]`0BMkUcV7NiLiQc^VnI
LiY_VFnKJgYSG6<kHeaO>ellGc]SG5LL0`0005]Fo5/LE_aG75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0OOol002Aoo`03001oogoo
00eoo`03001oogoo059oo`06NkMgUW^FNiEk]G^E0W^D0W^C0g^D1g^C00Mk/g^CNkAk]7^fNkEk]P02
MkL017>hLkUc^7>J0fnJ00A[Vf]jJg][N`AO?0<00003EaaK75Kl009G7003FaaFo5Kl009Fo004D_aF
o5KlE_`3D_`00eKlD_aBo00>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo009D]aBo5;l
D_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`00e;LOol0000QOol002Aoo`03001oogoo00ioo`03001oogoo055o
o`0ZMiIk]gNFNkIkUGndNiAo]7^CNkEkU7ndNi=o]7^BOk=kTWncNi9o]7^CNkEkU7^fMkEk]WNgNkMc
V7NiLiQc^VnILiY[NVnKJgY[Vf]jIgaWFell0P0006EO>ellFa]O?5KlFaaFo5/LE_aK75;lEaaBo5Kl
D_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00021oo`00
97oo00<007ooOol03goo00<007ooOol0Cgoo00AgUW^FMiIk]@9kU@9kU09kU@=kU0IkT`0<Nk=kTg^c
NkAk/g^CNk=kTg^dNkEk]W^e0gNg00A[Nf^KJgY[N`9WN`<00009Ig]K75/lFaaO?5/LFcaK75LL00=F
o003EaaBo5Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l0Woo
00<007ooOol07Goo000TOol2000AOol00`00Oomoo`1>Ool07g^gMiIk]g^ENkEgUW^gMiIk]G^EOkAk
U7ndNi=o]7^BOk=kTWncNi=k]7^BOk=kTg^dNi=k]G^DNkIg]G^f009g]`04LiQg^G>HMkT300002fMl
Ie]WO6<kHeaK6ellFaaO?5/KFa`00ULL00AFo5LLE_aG709Fo01HD_aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000OOol002=oo`03001oogoo019oo`03001o
ogoo04aoo`08NiIgUW^gMiMgV7NFNkMgUP9kU@=kU0EkT`0=Nk=kTg^cNi=k/g^CNk=kTg^cNkAk]W^e
NkH00gNg00Ig^@00000007>JIe/2Ig/01f=LHe]SG6=LGcaK75/l00AK7003E_aG75Kl00EFo006D_aF
o5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo000NOol001Yoo`@000Eo
o`03001oogoo01=oo`03001oogoo04Yoo`0OLiU_N7>IMiMgV7>GNkMgUW^gNiEk]W^DOkAkTgndNi=o
/g^BOk=kTWncNi9o/g^BNkAkTgndNiAk]GNeNkH00WNg0`00071g^FnILkY_VG>JHc]SG6<kHeaS>f=L
Hc]K75LLFaaG75/LEaaK75;lEaaBo5LLD_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg09oo`03001oogoo01]oo`006Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol057oo00<007ooOol0B7oo17>I0WNH00Ik]gNFNiIkUG^eNiD2Ni@4Ni<00g^c
Ni=kT`05Ni<01G^cNi=k]7^eNkH00`0000Eg^G>hLkUc^7>J009_VP03Jg][Vf=K00=SG0=O?0EK7003
E_aG75Kl00EFo0=Bo005E_aBo5;lD_aFo003D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0
000MOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo04Ioo`0M
LiU_N7>ILiUgV7>GMkQgUW^gMiIk]W^EOkAkU7ndNi=o]7^BOk=kTgndNi9o/g^BOk=kTgndNi=k]@03
0002MkL0N7^gLiQg^G>HLkY_VG>JJgY_Vf]jJi][NV=LGc]O?5lkHeaO>ellE_aK75KlFaaFo5/LD_aG
75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LOol001aoo`006Goo00<007ooOol00Woo00<007ooOol00Woo0P005goo0P00AGoo1G>I0WNH00Ag
UW^FMiIk]@9kU@9kU0AkT`03NiAkTg^C00AkT`06Nk=kT`00001k]W^e0gNg00Ac^7>iLkQcVP9_VP03
Jg][Vf]j009[N`03Ig]WFell00=O?004FcaK75llE_`2Ea`00e/LE_aG7002E_`015;lE_aFo5Kl0e;l
00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool06Woo000IOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`11Ool00g>IKgQcV@02LiT05G>GMkQg
Ug^gMiIk]g^ENkEkU7ndNi=o]7^COkAkU7ndNi=o/g^BOk=kTP0300006W^DOkAkTg^dNiAk]GNeNkIg
]G>jKiUcVV]jKi][NV^KJgYWO6MKIgaWFellFaaO?5/KGc`2Fa`0I5KlFaaFo5LLE_aG75;lE_aBo5LL
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000
6goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`0oOol5LiT2
MiP017NGNiIgUW^g0g^E0W^D0W^E00=k]G^DNi@00g^C0`0000IkTg^cNi=k/g^CNk<3Nk@00g^fNkEg
]`02MkL017>hMkU[NV]k0VMk00aWFfMkIg]SG6=KFcaK75llFaaK?5/LEa`3E_`00eLLE_aFo002E_`0
15;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol001Yo
o`006Goo00<007ooOol00Woo00D007ooOomoo`0001eoo`03001oogoo03eoo`03Jg]WFV]k009cV@0A
KgQg^7NGMiQgUW^gMiIk]G^EOkAkU7^gNiEk]W^DOkAkT`0300003W^BOk=kTg^dNi=o/g^CNkAkTg^e
NiAk]WNeNkH2MkL04W>HMkUcV7NiIe]WO6MKIgaS>f=LHc]SG6<kGcaK75llEaaK709G7004E_aG75Kl
Ea`2E_`0GU;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aoo`001goo1@003Goo000JOol40004Ool2000MOol00`00Oomoo`0kOol3Jg/02FMk
Jg][NgNHMiMgV7NFNkMgUP02NiD01W^eMiIkUW^ENkEkU@<000=kT`03Nk=kTg^C00=kT`03Nk=kTg^d
009k]003NkEk]WNg009g]`05MkUc^7>iKiYcVP02KiX2He`01F=KHeaSG6=LHe/01U/L1eKl00IBo5Kl
D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol00007Ool0
1@00Oomoogoo00003Goo000ROol00`00Oomoo`0MOol00`00Oomoo`0iOol02V]kIeY[NfMjJg]WFVnJ
JgY_VVmh0W>I00IgV7>GMkQgUW^gMiH300004g^DOkAkTgncNi9o/g^BOkAkTWncNi9o/g^COkAkU7^e
MkEk]WNe009g]`1jMkUcV7NiKiUc^VnILiY[NVnKHc]SG6<kHeaO>ellGc]K75LLFaaFo5/LE_aG75;l
EaaBo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LOol000Moo`03001oogoo00ioo`008Woo00<007ooOol07Woo00<007ooOol0=goo
0f]k00AWNf]kJg]_VP9_NPAcV@9gV004MiL000000002NiD2Ni@;Ni<01W^cNkAk]7^dNkIk]@9g]`05
MkUc^7>iLkQcVP02KiX016]kJi][NV^K1ell0ULL00AK75KlEaaG70EFo0=Bo003E_aBo5;l00iBo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03001oogoo00Eoo`03001oogoo00eoo`008Woo00<007oo
Ool07goo00<007ooOol0=Goo00Y[NfMJJg]WNV]kJgY_VV]jKiY_N0=cV@0fLiMg^000001gUW^gNiEk
]G^DOkAkTgndNi9o/g^DOkAkTgncNi9o/g^BOkAkTg^eNiAk]WNeNkIg]gNiLiQg^G>HLkY_VG>JJgY_
Vf]jJi]WFfMlGc]O?5lkHeaO>ellFa]K75KlFaaFo5/L0UKl069Bo5LLD_aFo5;lE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0027oo00<0
07ooOol037oo000ROol00`00Oomoo`0POol00`00Oomoo`0cOol01f=LGea[NfMkJg]_NVnJ00=_NP=c
V@<00003MiQgUW^g00=kU@9kU09kT`9kU0IkT`03Nk=kTg^d009k]008NkEk]W^dNkAk]G^fNkEcVP9_
VP04Jg][Vf]jJi/2Ig/02FMKIg]O?5llFaaK?5/LGcaFo002Ea`00e/LE_aFo002E_`015;lE_aFo5Kl
0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo09oo`03
001oogoo00Ioo`03001oogoo00]oo`008Goo0P008goo00<007ooOol0<7oo00aO?6=LGc]SG5llHea[
NVnJJgY_VV]jLiT300008GNhMiMgV7NFNkMgUW^eNiEo]7^DOkAkTg^fNiAo]7^COkAkTWncNi9o/g^C
NkAkU7^eNi=k]7^DNkEg]G^fMkEk]`02MkL0Mf]jKi][NV^KIe]WO6MKIgaWFfMlFaaO?5/KGcaK75ll
E_aG75KlEaaFo5LLD_aFo5;lEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`00Woo00D007ooOomoo`0000=oo`03001oogoo00]oo`00
8Goo00<007ooOol08goo00<007ooOol0;Goo00USG5mLHeaOG6=LGeaSG6=KIe`00Vmj0`000W>I00Ig
V7NGMiQgUW^gMiH2NiD01G^eNiAkU7^ENkD00W^D1G^C00Qk/g^CNk=kTg^cNi=k/g^C0W^d00=k]W^e
NkH00WNg00Ac^7NiLkQc^@9WN`08Ie]WNfMkIg]SFf=LFaaO?0AK70=Fo009EaaFo5KlD_aFo5;lE_aB
o5Kl00=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`2
0004Ool3000>Ool0025oo`03001oogoo02Aoo`03001oogoo02]oo`09FceK76=LGc]SG5llHeaSFfMl
00<000=cV@0RKgQcVGNGMiQcUg^gMiIk]g^ENkIkU7ndMiIk]W^EOkAkU7ndNi=o/g^BOk=kTW^dNi9o
/g^BNkAkTg^eNiAk]WNeNkH3MkL04gNiLiQg^FnILkYWFfMlIe]SG6<kHeaS>f=LEaaK75LLFaaG75/L
009G701WD_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000057oo000QOol00`00Oomoo`0UOol00`00Oomo
o`0XOol00e/lFceK?002Fc`00f=LGeaWF`03000016MKHe][NfMk0f]k00egUgNHMiQk]gNFNiIkUG^e
NiEkUWNFNkEkU@03Ni@7Ni<01G^cNi=kTg^CNk<00W^d00=k]G^fMkL00WNg00Eg^G>hLkU_VW>J009_
VP9SG003He]SG6=L00=O?0AK7003EaaK75Kl00EFo003D_aFo5;l009Bo005E_aBo5;lD_aFo008D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool04Woo000QOol00`00
Oomoo`0VOol00`00Oomoo`0UOol01e/mEaaK?E/LFceG75/m00<0000<IgaSFfMlHe][NfMjJg]WFV]k
JgY_VV]j0g>I01YcUgNhMiMk]gNFNkMkUG^eNiAo]7^COkAkTWncNi9o/g^COk=kTWncNi=o]7^DNkEg
]G^f0gNg07mg^G>HMkU_VG>jKiUcVV]jKi][NVnKGc]SG5lkGcaO>f=LE_aK75KlFaaFo5/LD_aG75;l
E_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlOol0000COol0025oo`8002Qoo`8002=oo`04EaaG7ELMFcd3Fc`20002
Gc`00fMLHe]WF`02Jg/016MkJg][Nf]k0fmj00U_VW>ILiUcVGNHMiMgV7NFNkL00W^E0g^D2W^C00Ik
/g^CNkAk]7^fNkD3MkL017>hLkU_VW>J0VnJ00A[Nf^KJgY[V`9WN`AO?005FaaK?5LLFaaFo002Ea`0
0e/LD_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000BOol0025oo`03001oogoo02Uoo`03001oogoo01eoo`07
DaaG?ELLEaeC75LmEa`00`00011K?5llFcaOGE/lGcaWFV]kIgY[NfMJKiY[NVnJJgY_VP9cV@0KKgQg
^7NGMiQgUW^gMiIk]G^EOkAkU7ndNi=o/g^BOkAkTgndNi9o/g^BOkAkTg^eNiAk]WNe009g]`22NkMc
V7NiKiUc^VnILiY[NVnKJgY_VfMKIgaWFfMlFa]O?5/LGcaK6ellE_aK75KlEaaFo5LLD_aG75;lE_aB
o5LLD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`0
05KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5Kl000BOol0021oo`03001oogoo02]oo`03001oogoo01Yoo`9C7@04EaeG75LM
Ead300000eLMGcaK?003Gc`01E/lGcaOG6=LIg/00V]k00E_VVmjKgY_NVnJ00AcV@05MiMgV7NHNkMg
UP02NiD3Ni@2Ni<2Ni@5Ni<00g^cNi=k/`02Nk@01W^CNk=k]7^dNkEk]PAg]`03Jg][Vf]j00=WN`0<
Ie]WNf=LHeaK75/lFaaO?5/LFcaFo5LL0eKl00UG75;lE_aBo5KlD_aFo5;lE_`035;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`00015oo`0087oo00<007ooOol0;7oo
00<007ooOol05Woo00IG7E;lEaeBo5LMD_`3000055LLEaeG75/mEaaO?5/lGeeK?5llGc]SG5llHeaO
>fnJJgY_VV]jKiX2LiT0<VmhLiUgUgNHLiMk]gNFNkMkUG^fNiAo]7^COkAkUGndNiAo]7^COk=kTWnc
Ni=k]7^BOk=kTW^dNiAk]G^DNkIg]G^gMkMk]g>HMkUcV6MlIe]WO6MKHeaS>f=LHe]O?5/KGc`2Fa`0
KeLLFaaFo5LLE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000@Ool0021oo`03001oo`00
02eoo`03001oogoo01=oo`9C7@03D_eC7E<M00<0000GDaeG7ELLEaeG75/mEaaG7ELLGcaK?6=LGeaS
G5mLHeaOG6MLHe]WFfmjKiY_NP03LiT027NGMiQgV7^gMiIkUW^ENkD3Ni@017^eNiEkU7^D17^C00Qk
/g^CNk=kTg^cNi=k/g^C0W^d00=k]W^eMkL00WNg00=c^7NiLkP00VnJ00=cVVnJHe`00V=L00=SFf=L
He`01e/L1UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`2000@Ool0021oo`8002moo`03001oogoo00moo`05D_aC7E;lDaeBo0030000
6e;lEaeBo5LMDaaG7ELLFceG75/mEaaK?ELLHeaO>f=LGcaSG5lkIgaSFfMlHe]WO6=KLiU_N002LiT0
XgNHLiMg^7NFNkMgUW^fNiEk]gNFNkMkUG^eNiAo]7^COkAkTWncNi9o/g^BOk=kTWncNi=k]G^DNkAg
]G^fMkMk]gNgMkUcV7>jKiUc^VnIKi][NV=LHe]SG5lkHeaO>e/LEaaK75LLFaaFo5/LD_aG75;lEaaB
o5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0000moo`001Goo1@001Goo0P001Goo10001Woo00<007oo
Ool0;goo00<007ooOol037oo00AC7E;mDaeC7@<0009C7@05D_eG7ELMEaeC7003Ead015LLEaeG75/m
0e/l00YSG5mLHeaSFfMLHe]WFf=KIeaSF`=[N`0<Ig]gV7NHMiQgUW^FMiIgV7NGNiIgUW^G0W^E0g^D
2W^C00Ek/g^dNkAk]G^f00=g]`0:MkUc^7>iKiYcVVnJJi][Nf^KJgX7Gc`015KlEaaG75/L25Kl0e;l
00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l
0Woo00<007ooOol037oo0004Ool200001Goo000007oo000017oo0P0017oo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0<7oo00<007ooOol027oo00EC7DklDae>o5<M0080000TD_aC7E;lDaeB
o5<MD_aG7E<LEaeBo5LMDaaG7ELLFceK75/mEaaK?E/LFceSFfMlHe]WO6=KIgaWNV]kIeY[NfMjKiY[
NVnJ0W>I0:5_N7NhMiMgV7NFNkMgUW^eNiEo]7^DOkAkTgncNi9o]7^BOk=kTWncNi9o]7^DNkAg]G^f
MkEk]gNgMkUcV7NiKiUc^V]jKi][NVnKJgYWO6MKHeaO>ellGc]O?5/LGcaFo5/LE_aK75KlEaaBo5Kl
D_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0000ioo`0017oo0P000Woo00<007oo00003goo00<0
07ooOol00goo00<007ooOol0<Goo00<007ooOol01Goo0e;m00IC7@00000005<MD_d3Dad01E;mDaeC
7E<MD_d00eLM00AC75LMEaeG7@=K?003FceK?5/l009O?005He]WFf=KIeaWN`03Jg/01FMkKgY_NVnJ
KgX00g>I00EgUgNHMiIkUgNF009kU@=kU0=kT`03NiAkTg^C00=kT`06Nk=kTg^dNkAk]W^e0WNg00Yg
^G>hLkU_VW>JJgY[Vf]kJi][NP=WN`08Ie]K?5/LGcaK75/lFaaO?0=Fo003EaaFo5Kl009Fo004D_aF
o5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L009Bo003Ool007oo00aoo`0017oo0P000Woo00<007oo00003goo00<007ooOol0
0Woo0P00=7oo00P007ooOomoodklDae>o5<M0`00065C7DklDae>o5<MC_aC7E;lDaeBo5LMD_aC7E;l
EceG75LMDaaG?ELLEaeG75/mFaaO?5/lGeeK?5llFca[NfMjJg]WFV]kIgY_VV]jKiY[NW>IKgQcVGNG
MiQcUg^gMiIk]g^ENkIkU7ndNi=o]7^BOkAkTgncNi9o/g^BOk=kTg^dNiAo]7^CNkAkU7^eMkEk]WNg
NkMcV7NiJgY_Vf]jIgaWFfMlIe]SG6<kGcaK75llFa]K75LLFaaFo5LLE_aG7002E_`0Je;lE_aBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000037oo0004Ool20002Ool00`00Ool0000;Ool40005Ool0
0`00Oomoo`0bOol00e;mDae>o@02D_d01E<M00000000Dad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;m
DaeC7ELMDad00eLM00EG75LMEaeG7E/l00=O?006FcaO?5llHeaOG6=L0V]k00EWNfmjKgY_VVmj00Ac
V@9gV005NiMgUW^FNiEk]@03Ni@2Ni<2Ni@4Ni<01g^cNi=k/g^CNk=kTg^c009k]003NkEk]W^e009g
]`04LkUc^7NiLkP3Ig/01V=KHeaSG6=LHe]SG0EK7003EaaFo5Kl00AFo006D_aFo5;lE_aBo5Kl0e;l
00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;l
D_aBg5;lOol000aoo`000goo0`0000Eoo`00001oo`0000]oo`03001oogoo00Ioo`03001oogoo031o
o`05Dae>o5<MC_aC7@030000;U<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG
7E;lEceG75LMDaaK?ELLFceK?5mMFcaO?5/lHeaO?6=LGc]SG5llKiY[NVnJJgYcVFmh0W>I03=gV7>G
MkQgUW^gMiIk]W^EOkAkU7ndNi=k]G^DOkAkTgncNi9o/g^BNkAkTWncNi=k]7^DNkEkU7^fMkEk]gNg
MkUcV7NiLiQc^VnILkYSFf=LHc]SG6=KHeaO>f=LEaaK75LLFa`00ULL071Bo5LLD_aG75;lE_aBo5Kl
D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol000]oo`001Goo00<007ooOol00Woo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol0;Goo00EC7DkmD_eBoE<M00<00005Dae>oE;mD_eC7@03D_d02U<M
D_eBoE;mDaeBoE<MD_eC7E;m0U<M01UG7E<MDaeC7ELMDaeG7ELLFceG75LMEaaK?E/lGcaOG6=LGeaS
G5mLHeaOG6MKHe]_VP02KgX3LiT3MiP01GNFNiIgUW^eNiD00g^D0W^E0W^D0g^C00Qk/g^CNi=kTg^c
Ni=k/g^C0W^d00Qk]W^eMkMg]g>iLkQg^G>h0VnJ00=cVV]jJi/00V=L00=SFellGc`00Ull0e/L0eLL
1UKl0U;l00EFo5;lD_aBo5Kl00aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01U;LD_aBo5;lD]aBo08000Yoo`001Woo100037oo1@0017oo00<007ooOol0:goo00A>o5<MC_eC
7@<0000bDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LM
DaaG7E;lFceG75/mEaaK?ELLFceO>f=LGcaSG5lkHeaO?6MlHe]WO6=KIga_N0=cV@0fLiMg^7NGNkMg
UW^gNiEk]GNFNkMkUG^eNiEo]7^DOkAkTWncNi9o]7^BOk=kTW^dNi=k]G^DNkAg]G^gMkMk]g>HMkU_
VG>jKiUc^V]jKi][NVnKGc]O?5lkHeaO>ellGc]K75KlFaaFo5/L0UKl06mBo5LLD_aFo5;lE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00002Woo000OOol00`00Oomoo`0XOol01DkmD_eBoE<MC_d0
0P0000IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeG
7ELMDa`00eLM00EC75LMEaaK?ELL009K?00;FceK?6=LGeaSG6=KIe]SFfMLHe]WF`02Jg/03FMkJg]g
V7NHMiMkUWNFNiMgUgNHMiIkUgNF009kU@9kU0YkT`05Nk=k]7^dNkEk]P02MkL00g>hMkU_VP02KiX0
1g>JJgY[Vf]kJi]WFfMk00AO?003FaaO?5/L009G7003FaaFo5Kl009Fo004D_aFo5KlE_`3D_`00eKl
D_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg0020009Ool001ioo`8002Eoo`07C_eC7DklDae>oE<MC_`00`00079>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LM
D_aG7E<LEaeBo5/mFaaK?ELLFceK75/mEaaK?F=KIgaSFfMlHe]WO6MJJg]WNV]kJgY_VV]jLiU_N7>I
MiMgV7>GNkMgUW^eNiEk]W^DOkAkTgncNi9o]7^COk=kTWncNi9o]7^DNkAkU7^fNiAk]7NeNkIg]g^g
MkMk]f]jKi][NVMlIe]WO6MKIgaWFellFa]O?5/LGcaK6eLLE_aG75KlEa`2E_`0KU;lEaaBo5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0009Ool001ioo`03001oogoo029oo`06Dae>oE;mD_eC
7Dkm0`0000E>oE;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeB
oE<MD_eC7E;m0e<M00EBoE<MDaeG7E<L00=G7@04EaaK?5/lFcd3Fc`01U/mFcaO?6=KIeaSF`=[N`05
Ig][NfmjKiY_NP04LiT2MiP01G^GMiIkUW^ENkD00W^D0g^C00=kU7^CNi<00g^C00Ik/g^CNkAk]7^c
Ni<2Nk@00g^fNkEg]`02MkL01G>hLkUc^6MkIe/00fMk00IWFf=LHeaO?5/LFc`3Fa`2E_`00eLLE_aF
o002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00002Goo000NOol00`00Oomoo`0POol0
1DklDae>oE<MC_`00`00045>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMD_aG7E<LEceG75LMDaaG?E/LFceG75mMFcaO
?5/lGeeK?6]kIeY[NfMjJg][NVnJJgY_VVmh009cV@0aMiQcUgNhMiIk]g^ENkIkUGndNiAo]7^DOkAk
TgndNi9o/g^BOk=kTgncNi9o/g^CNkAkU7^fMkEk]gNgNkMcV7NiLiQc^VnIIgaWFfMlHe]SG6<kHeaS
Fe/LEaaK75LLFa`00ULL06eBo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg004Ool0
0`00Oomoo`07Ool001ioo`03001oogoo01ioo`9Bo@03Dae>o@0000800005C_eBoE;mDae>o@02D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC
7E;m1U<M00=G7ELLEad00ULM00EG75LMGcaO?5/l00=O?008FcaSG5mLJg]WNf]kKgY_VP9_NP=cV@=g
V005MiIkUWNFNkEkU@02Ni@017^CNiEkU7^D17^C00Mk/g^CNi=kTg^cNi=k/`02Nk@00g^eNkIg]`02
MkL00g>iLkQcVP03KiX00f=LHe]SG002He`3Gc`3Fa`00eLLFaaG7007E_`3D_`01EKlD_aBo5;lE_`0
25;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003001B
g5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo0Moo`03
001oogoo00Ioo`007Woo00<007ooOol06goo00AC7DkmDae>o0<00015C_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
DaeBo5LMD_aG7E;lEaeBo5LMDaaG?ELLFceG75/mFcaO?5/lGeeO?6=LGc]SG5llHea[NVnJJgY_VVmh
009cV@0[MiQcUgNhMiMk]gNFNkIkUG^eNiAo]7^EOkAkU7ndNi=o/g^BOk=kTWncNi9o/g^BNkAkU7^e
MkEk]WNgNkMg]gNiLiQg^FnILkY_VFnKJgY_Vf]jHe`00Ull071O>f=LGcaK75KlFaaFo5/LD_aG75;l
EaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo0Yoo`03001oogoo00Ioo`007Goo0P0067oo00IC7DkmD_eBoE<M
C_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@IC7@0GEaeC7E<MDaeK?ELLEaeG75/mEaaG
7ELLHeaO?6=LGeaSG5llHeaSFfMLHe]WF`04LiT2MiP017NGNiIgUW^G0W^E00AgUW^GNiEkU@9kU0Mk
T`08Nk=kTg^cNi=k]7^eNkIk]@9g]`03LkUc^7Ni00=_VP06Ji][NV^KJg]WNfMK0ell00AK75/lFaaK
70=G7003FaaBo5Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00U;l3Woo00<007ooOol01Woo000NOol00`00Oomoo`0DOol01TklDae>
oE<MC_aC7@80003QC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LM
DaaK?ELLFceG75/mEaaK?E/LHeaO>f=LGcaSG6=KIgaSFfMlIeY[NfMJJg]cUgNhMiMgV7NFNkMgUgNH
MiIk]gNFNkEkU7ndNi=o]7^BOk=kTWndNi9o/g^BOk=kTg^eNiAk]WNeNkMg]gNiLiQg^FnILkY_VFnK
JgY_Vf]jIgaWFfMlIe]O?5/LGcaK6ellFaaG75KlEaaFo5LLD_aG75;lE_aBo5LLD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L01=oo`03001oogoo00Ioo`00
7Goo00<007ooOol04goo0U;m00=C7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC
7E;m0e<M00EBoE<MDaeC7E<L00=G7@08DaaG7ELMFceG75LMFcaK?@=K?007HeaO?6MKHe]WG6=KIe/0
0V]k00AWNf]kKgY_VP9_NP9cV@05MiMgV7NHNiMgUP02NiD2Ni@:Ni<01G^cNkAk/g^CNk<00W^d00=k
]G^fMkL00WNg00=[Vf]jJi/00VMk00QWFfMkIg]SG6=KFcaK75ll0e/L00EG75KlE_aFo5LL009Fo006
D_aFo5;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo000D_aBg003D_`01U;LD_aBo5;lD]aBo1Eoo`03001oogoo00Ioo`007Goo00<0
07ooOol04Goo00A>oE<MC_aC7@<0001DDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MD_aG7E;lDaeBo5LMDaaG7E;lEaeC75/mEaaK?E/LFceG75/mFaaWO6=KIgaSFfMlIeY[NfMJ
Jg][NVnJJgY_VVmh0W>I08agV7>GNkMgUW^gNiEk]W^DOkAkTgncNi9o]7^COk=kTWncNi9o]7^DOk=k
TgndNiAk]7NeNkIg]G^gMkMg^G>HMkUWFfMlIe]WO6<kHeaSFf=LHc]K75LLFaaG75/LE_aG75KlEaaB
o5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;L5goo
00<007ooOol01Woo000MOol2000?Ool015;mDae>oE;m0`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad0
0e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeC7003Ead015LLEaeG7E/m0e/l00MK
?E/lGcaO?6MLHe]WF`02Jg/016MkJg]_NVnJ0Vmj0g>I0gNH00AgUW^FNiEk]@9kU09kT`9kU0EkT`06
Nk=kTg^CNi=k/g^C0W^d00Uk]W^eMkMg]gNiLkQc^FnJLiX00VnJ0V=L00=SFf=LHe`00Ull1E/L1eKl
0U;l00EFo5;lD_aBo5Kl00aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;L001Bo5;lD]`077oo00<007ooOol01Woo000MOol00`00Oomoo`09Ool01Tkl
Dae>oE<MC_aC7@<0001HDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDae>o5LMD_aC7E;lEaeBo5<MDaaG?ELLEaeC75LmEaaG7E/lGeeK?5llFcaOGE/lGcaWFV]kIeY[
Nf]jKiY[NVnJJgX2LiT0:gNHLiMg^7NFNkMgUW^fNiEo]7^COkAkUGndNiAo]7^COk=kTWncNi=o/g^B
OkAkTg^dNiAk]WNeNkMg]g^gLiQg^FnILkY_VG>jJgY_Vf=KHeaO>f=L009O?01JGc]K75KlFaaFo5/L
D_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`007goo00<007ooOol0
1Goo000MOol00`00Oomoo`07Ool2D_d00e<MC_eBo@030002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMEa`00eLM
00EG75LMEaaK?E/l00=O?008FcaO?5mLHeaO?6=LKgY_VP=_NP9cV@=gV005MiMkUWNFNkEkU@02Ni@0
17^eNiEkU7^D17^C00Mk/g^CNi=kTg^cNi=k/`02Nk@027^eMkMg]gNgLkQc^FnJLiX2KiX016]kJi][
NV^K15ll00=K75llFa`00ULL00IK75LLEaaG75KlD_`3E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00Aoo`03
001oogoo01aoo`03001oogoo00Eoo`007Goo00<007ooOol01Goo00A>oE<MC_aC7@<0001LDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
C_aG7E;lEaeBo5LMD_aG7E<LEceG75/mEaaK?ELLFceK?5mMFcaSG5lkHeaO?6=LHe]WO6]jKiY[NP=c
V@0fLiMg^7NGNkMgUW^gNiEk]GNFNkMkUG^eNiAo]7^COkAkTWncNi=o/g^BOk=kTg^dNiAk]GNeNkIg
]g^gLiQg^FnILkY_VFnKJgY_Vf]jKi]WFfMlIe]O?5/KGcaK75llFa]G75KlEaaFo5LL0UKl04UBo5LL
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg008Ool00`00Oomoo`0KOol00`00Oomoo`05Ool001eoo`04001o
ogooC_d2D_d015<MC_eBoE;m0P000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE;mD_eC7E;m0e<M00ABoE<MDaeG7@=C7@0DEaeG75LM
EaaK?ELLEaeG75/mGcaSG5mLHeaO?6=LHe]WG6=KIe]SF`=cV@9gV008MiMgV7NFNiMgUgNHMiIkU`9k
U@9kU0MkT`04Nk=kTg^cNi<2Nk@01G^fNkAk]7^eNkH00gNg00A[Vf]kJi][NP=WN`06Ie]SG6=LGcaK
75/l0e/L0UKl00=G75KlE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo5;lD_`<Ool00`00Oomoo`0KOol00`00Oomoo`05Ool0
01aoo`08001ooe<MC_eC7DklDae>o@<0002FC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MDaaG7E;lEaeC
75LMEaaK?ELLFceG75/mFaaK?ElkHeaO?6MlHe]WO6=KIgaSFf]kIeY[Nf]jKiY[NVnJKgQcVGNGMiQc
Ug^gMiIk]G^EOkAkU7ndNi=o/g^DOkAkTWncNi9k]7^CNkEkU7^dNi=k]G^DNkIg]G^gMkMg^G>HMkUc
V6MlIe]WO6=KHeaS>f=LHe]K75LLFaaG75/L0ULL04EFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`04Goo00<007oo
Ool06Woo00<007ooOol01Goo000LOol00`00Dae>o@02D_d300000e;mDae>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE<MD_eC
7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMDa`00eLM00AC75/lFcaK?@=K?00=FceK?6MKHe]WG6=KIe]S
Ff]kIg][NfmjKiX00Vmj0g>I0WNH00AkUgNFNiEkU@9kU0=kT`03NiAkTg^C00AkT`04Nk=k]7^CNi<2
Nk@00g^fNkEg]`02MkL00g>hMkUc^002KiX00g>JHe]SG002He`00f=KGcaO?006Fa`5E_`00e;lE_aB
o002D_`01EKlD_aBo5;lE_`025;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOomoo`0EOol00`00Oomo
o`0IOol00`00Oomoo`05Ool0019oo`D000Eoo`03001>o@000080001[C_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lEaeBo5<MD_aG7E<LEaeBo5LMEaaG7E<LFceK75/mEaaK?E/LGcaK?6MlHe]WO6MJ
Jg]WFV]kIeY_VV]jKiY_N002LiT09gNHLiMg^7NFNkMkUG^fNiAo]7^COkAkU7ndNi=o/g^BOk=kTWnd
Ni9o/g^COkAkU7^dMkEk]WNgNkMcV7NiLiQc^VnILkY[NVnKHc]SG002Gc`0AUlkHeaO?5llE_aK75Kl
FaaFo5LLD_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5Kl6Woo00<007ooOol067oo00<007ooOol01Goo000DOol00`00Oomoo`05Ool200000e;mDae>
o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7ELL00=G
7@05EaaK?5/lFceK?003Gc`01E/lGca[Nf]kIg/00V]k00A_VVmjKgY_NP=cV@9gV004MiIkUW^ENkD2
Ni@2Ni<00g^ENiAkT`04Ni<01G^cNi=kTg^CNk<00W^d00ik]G^fMkMg]g>hMkUc^7>iKiYcVV]jJi][
Nf^K1Ull00=K75llEa`00ULL00=K75LLE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00U;l77oo00<007ooOol06Goo00<007ooOol017oo000DOol00`00Oomoo`06Ool0
K@00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG75LMDaaG
?ELLEaeC75mMFcaO?5/lGeeK?5llGc]SG6MJJg]WFVnJJgY_VV]j00=cV@0ZLiMg^7NGNkMgUW^fNiEo
]7^DNkIkUGndNiAo]7^BOk=kTWncNi9o/g^BOkAkTg^dMkEk]WNeNkMg]gNiLiQg^FnILkY[NVnKJgY_
VfMKIgaO>f=L0Ull03iK6ellFaaK75KlFaaFo5LLE_aG75;lE_aBo5LLD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5Kl8Goo00<007ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07
Ool200000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d4Dad00eLMDaeC
7@02Ead01ELLEaeG75/mEa`00ell00QK?6=LGeaSG5llHeaOG6nJ0fmj0g>I0WNH00QgUg^FMiIk]G^E
NiIgUW^e0W^E00=kU7^CNi<00W^C00Ik/g^CNi=kTg^cNi<2Nk@03W^fNkEg]gNgMkUc^7>iKiYcVV]j
Ji][NfMkIe/3Ig/025/LFcaK75llFaaK?5/LEa`3E_`02ELLE_aFo5;lE_aBo5KlD_aFo008D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00=Bg7ooOol097oo00<007ooOol05goo00<007ooOol017oo000DOol00`00Oomoo`09Ool0J000OomC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaK
?EllHeaO>f=LGcaSG5lkIgaSFfMlHe/3LiT0<VmhMkQgUgNHMiIk]gNGMiQgUW^gNiEk]G^DOkAkTgnd
Ni9o]7^COk=kTWncNi=k]7^DOkAkTg^dNiAk]WNeNkIg]g^gLiQg^G>HIgaWFfMlIe]SG6=KHeaS>f=L
EaaK75LLFa`2Ea`0<UKlEaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`XOol00`00
Oomoo`0GOol00`00Oomoo`04Ool001Aoo`03001oogoo00Yoo`04001ooe<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC
7@03D_d00e<MD_eC7@02Dad00e;mDaeC7@04Dad02ELMDaaG7ELLFceG75LMEaaK?@02Fc`02emLHeaO
?6=LHe]WG6=KIe]SFf]kIg/00V]k00=gV7NGMiP00W>I00AgUgNHMiIkU`=kU@05NiAkTg^CNi=kU003
Ni<01g^cNi=k/g^dNk=kTg^c009k]003NkEk]WNg009g]`03LkUc^7>J009_VP9SG004He]SG6=LHe`2
Gc`5Fa`5E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00=Bg5;lOol0:goo00<007ooOol05Woo00<007ooOol017oo000B
Ool3000=Ool0U@00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LM
DaaK?ELLFceK75/mEaaK?E/LIgaSFfMlHe]WO6=KJg]WFV]kIeY_VV]jKiY_N7>ILgUgV7>GNkMgUW^e
NiEo]7^DOkAkTgndNi=o]7^BOk=kTW^dNi=o/g^CNkAkTg^eMkEk]WNeNkMg]gNiLiQc^VnILkY[NVnK
He]SG6<kHe`00Ull035O>f=LE_aK75KlFaaFo5LLD_aG75;lEaaBg5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg00aOol00`00
Oomoo`0EOol00`00Oomoo`04Ool001Aoo`03001oogoo00aoo`800006Oom>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeB
oE<MD_eC7E;m0e<M00EBoE<MDaeC7E<L00=G7@04EaaG7ELMFcd3Fc`01e/mFcaO?5llIeaSFfMK009[
N`04Ig][Nf]kKiX2KgX3LiT2MiP01W^GMiIkUG^ENkEkU09kT`03NkEkU7^C00MkT`06Nk=kTg^dNkAk
]W^e0WNg00=c^G>hMkT00VnJ00A[Nf^KJgY[V`IO?004FaaK?5LLFa`3Ea`00eKlD_aFo002E_`3D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo5;lD_`fOol00`00
Oomoo`0DOol00`00Oomoo`04Ool002Eoo`2L001oodklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeB
o5<MD_aG?ELLEaeC75LmEaaK?ELLFceK?5llFcaOGE/lGcaWFV]kIeY[NfMJKiY[NVnJJgYcVG=iLiUc
UgNhMiIk]g^ENkIkU7ndNiEk]W^DOkAkTgncNi9o/g^BOk=kTW^dNi=o]7^DNkIg]G^gMkMk]g>HMkU_
VG>jJgY_Vf]jKi]WFfMlIe]WO5/KGcaK75llFa]O?5KlEaaFo5LL0UKl01mBo5LLD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg00jOol00`00Oomoo`0E
Ool00`00Oomoo`03Ool002Ioo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC
7E<MEaeC7@03Ead01ELLEaeG7EllFc`00ell00EK?5llGeaSG6Mk009[N`04KiY_NVmjKgX3LiT2MiP0
2WNFNiIkUG^eNiEkU7NFNkEkUG^D2G^C00Ak/g^dNkAk]@=g]`07LkQg^FnJKiY[Nf^KJgX00fMk00IW
FfMkHeaSG5/LFc`4Fa`00eKlEaaFo003E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aB
o5;L00=Bo004D]aBo5;lD_`mOol00`00Oomoo`0DOol00`00Oomoo`03Ool002Moo`2F001oogooDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aG?ELLEaeG75/mEaaO?5/lGeeK?6=LGc]SG5llHeaO
>fnJJgY_VV]jLiUcNG>ILiMg^7NGNkMgUW^fNiEk]gNFNkIkUGndNiAo]7^BOk=kTgncNi9o/g^BOkAk
Tg^dNi=o]7^DNkAg]G^fMkMk]g>HMkUcV6MlIe]WO6MKHeaS>f=LHe]SG5LLFaaG75/L0ULL01mFo5LL
D_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg010
Ool00`00Oomoo`0COol00`00Oomoo`03Ool002Qoo`800005OomBoE;mDae>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<M
D_d2Dad065LMDaeC7E<MEaeC7ELMEaaK?ELLEaeG75/mGcaSG5mLHeaO?6=LGeaWG6=KIe]SF`AcV@09
MiQgUg^FMiIgV7NGNiIgUW^G009kU@05NiAkTg^CNi=kU004Ni<01G^cNi=k]7^CNk<00g^d00Ik]W^e
MkMg]gNiLkP2KiX00g>JKiYSG002He`016=KHeaO?5ll1E/L1eKl0e;l00EFo5;lD_aBo5Kl00QBo003
D]aBo5;l04Ioo`03001oogoo019oo`03001oogoo00=oo`00:Woo08l007ooDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeB
o5<MD_aG7E;lEaeC75LMD_aK?ELLFceG75/mFaaK?ElkHeaO?6=LHe]WO6=KIgaSFf]kIeY[NfMJMkQg
UgNHKgQg^7NGMiQgUW^gNiEk]G^DOkAkTgncNiAo]7^COk=kTWncNi=k]7^BOkAkTg^dNiAk]WNeNkMg
]gNiLiQc^VnILkY_VFnKJgYSG6=KGcaO>f=L009O?00JE_aK75KlFaaFo5LLD_aG75;lEaaBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo4Yoo`03001oogoo019oo`03001oogoo00=oo`00:goo00H0
07ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<M
C_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<L00=G7@04DaaG7E/lFcd3Fc`02U/mFcaWFf=K
IeaSFfMKHe][NfMk0V]k00=_VVmjKgX00W>I00EgUgNHMiIkUgNF009kU@9kU003Ni=kU7^D00=kT`06
Nk=kTg^cNi=k/g^C0W^d00Ik]W^eMkMg]gNiLkP2KiX01W>JKiY[Vf]kJi][NPAO?003FcaK75ll00=G
7003FaaG75Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo003D_a?Ool00`00Oomoo`0AOol00`00Oomo
o`03Ool002aoo`2S001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG7E<LEaeBo5LMDaaG7E<LEceK75/mEaaK?E/L
GcaK?6MlHe]WO6MJJg]WFV]kIeY_VV]jKiY_N7>IMiMgV7>GNkMgUW^eNiEo]7^DOkAkUGneNi=o]7^B
Ok=kTWncNi9o/g^CNkAkU7^fMkEk]WNgNkMcV7>jKiUc^VnIKi][NVnKJgYWO6MKIgaK75llFa]O?5/L
GcaFo5LLE_aG75KlEaaBo5KlD_aG75;LE_aBg5KlD]aFo5;LE_`0DWoo00<007ooOol047oo00<007oo
Ool00goo000]Ool20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MD_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMEa`00eLM00EG75LMFcaK?E/l
00=O?008FcaO?6]kJg]WNf]kKgY_VP=_NP9cV@9gV005NiMgUW^FNiEk]@02Ni@00g^ENiAkU008Ni<0
0g^cNkAk]002NkD2MkL00g^eMkMg]`02MkL016^KJg][VfMK0fMk00ASFf=LFaaO?0AK70=Fo009EaaF
o5KlD_aFo5;lE_aBo5Kl00=Bo5Eoo`03001oogoo011oo`03001oogoo009oo`00;goo09X005<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC
7E;lEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LEceK?5llFcaOGE/lGcaO>f=LGcaSG6]jKiY[NVnJJgYc
VG=iMiQcUg^gMiIk]g^ENkIkU7ndNiEk]W^DOkAkTgncNi9o/g^BOk=kTWncNi=k]G^CNkAkTg^eMkEk
]WNgNkMg]gNiLiQg^FMKIgaWFf=LHe]SG6<kHeaG75/LEaaK75LLFaaBo5LLD_aG75;lE_aBo5KlD_aF
o5Uoo`03001oogoo011oo`03001oogoo009oo`00<7oo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00QC7E;mD_eBoE<MD_eC7E;m15<M00IG7E<MDaeC
7ELMEa`2Ead00e/mEaaG7@02Gc`025/lHeaOG6=LGcaSG6=KIe`3KgX3LiT2MiP027NFNiIgUW^eNiEk
UWNFNiD2Ni@9Ni<017^dNi=k/g^C0W^d00Mk]GNgMkMg]g>iLkQg^@03KiX016=LHe]SG6=L0ell0e/L
0ULL00=K75KlE_`00eKlGWoo00<007ooOol03goo00<007ooOol00Woo000aOol0QP00Oomooe<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG
7E;lEaeBo5LMD_aK?ELLFceG75/mEaaK?EllHeaO>f=LGcaSG6=KIgaSFfMlHe]cVG=iLiUcUgNhMiIk
]gNFMkQgUg^gMiIk]W^EOkAkTgndNi9o/g^DOkAkTWncNi9o]7^BNkAkTgndNiAk]WNeNkMg]g^gLiQg
^FnILkY_VFnKJgY_VelkHe`2Gc`025lkHeaFo5/LE_aK75KlFaaSOol00`00Oomoo`0>Ool00`00Oomo
o`02Ool0039oo`05001oogooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eB
oE<M00=Bo@03DaeBoE;m009C7@03D_eC7E<M00AC7@09EaeC75LMEaeK?ELLEaeG75/m009K?00>GeaS
G5llIe]SFfMLHe]WFf=KJg]WNf]kKgY_VP=cV@05MiQgUgNHMiIkU`02NiD00g^DNi=kT`02Ni@4Ni<0
1G^cNi=kTg^CNk<00W^d00Ik]GNgMkMg]g>hMkT3KiX00f^KJgY[V`02Ig/4Gc`01E/LFcaG75/LEa`0
IGoo00<007ooOol03Woo00<007ooOol00Woo000cOol20000R7ooDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E;lEaeC75LMEaaK
?E/LFceG75/mFaaWO6=KIgaSFfMlHe][NfMJJg][NVnJJgYcVFmhLiUgUgNHMiIk]g^ENkEkU7ndNi=k
]G^DOkEkTgncNi9o/g^BOk=kTgndNi=k]7NeNkIg]g^gLiQg^FnILkY_VFnKJgYWO6MKIgaWFfMlFa]O
?5/LGcaK6ellJ7oo00<007ooOol03Goo00<007ooOol00Woo000eOol01000OomC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05DaaG7ELM
EaeC7003Ead3Fc`01e/mFcaO?5llIeaSFfMK009[N`05Ig][NfmjKiY_NP03LiT01GNGMiQgV7^GMiH0
0W^E00=kU7^ENiD00W^D0g^C00Ik/g^CNi=kTg^cNi<2Nk@01G^fNkAk]7^eNkH00gNg00=[Vf]jIg/0
0VMk00MWFfMkHeaSG5/LFcaK701[Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool003Ioo`23001ooe<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<M
D_aG?ELLEaeC75LmEaaG7E<LGeeK?5llFcaOGE/lGcaWFV]kIeY[Nf]jKiY[NW>IKgQcVG=iMiQcUg^g
MiIk]G^EOkEgUW^eNiEo]G^DOkAkTWncNi=o/g^BOk=kTg^dNiAo]7^CNkAkU7^fMkEk]gNfMkUc^7>j
KiUWO6MKHeaS>f=LHe]SG01^Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool003Moo`04001ooe<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M
00=G7E<MEad00ULM00EG75LMEaaK?ELL00=O?008FcaO?5mLHeaO?6=LKgY_VP9_NP=cV@9gV003NiMg
UW^F009kU@03MiIkUG^E009kU0IkT`06Nk=kTg^cNkAk/g^C0W^d00Ik]W^eMkMg]gNiLkP2KiX00g>J
KiYSG002He`00f=KOomoo`1^Ool00`00Oomoo`0<Ool00`00Oomoo`01Ool003Qoo`80001kDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeBo5LM
EaaK?ELLFceG75/mFcaOGE/lHeaO>f=LGcaSG6=KIgaSFfMlKgQcVG=iLiUcUgNhMiIk]g>GMkQgUW^g
NiEk]W^DOkAkTgncNiAo]7^BOk=kTW^dNi=o/g^CNkAkU7^eMkEk]WNfNkMc^7NiKiUc^VnIKi][NVnK
07=oo`03001oogoo00]oo`03001oogoo005oo`00>Woo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06DaeBoE;mD_eC7E;m0e<M00ABoE<MDaeG7@=C7@0CEaeC75LMEaaK?ELLEaeG75/m
GcaSG5mLHeaO?6=LHe]WG6=KIe/00V]k00AWNf]kMiQgV09cV@9gV004MiMkUW^ENiD2Ni@2Ni<00g^D
Ni=kT`02Ni<01G^cNi=kTg^CNk<00W^d0W^e0WNg00Qc^7>iKiYcVV]jJi][Nf^KMGoo00<007ooOol0
2Woo00<007ooOol00Goo000kOol0M`00Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LMEaaK?ELLFceK75/mGc]SG5llIgaSFfMlHe]WO6MJ
Jg]WFV]kJgY_VW=iLiU_N7NhMiMk]gNFNkIkUGndNiAo]7^EOkAkTgncNi9o/g^BOk=kTW^dNi=k]GNe
NkIg]G^gLkQg^FnILkY[NVnKJgX0N7oo00<007ooOol02Goo00<007ooOol00Goo000lOol00`00Oomo
o`02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MDa`0
0eLM00AC75LMFcaK?@=K?006FceK?6MKHe]WG6=K0f]k00EWNf]kKgY_VVmj009cV@04MiQgUgNHMiH2
NiD2Ni@017^CNiEkU7^D27^C0W^d0W^e0W^d00Ik]GNgMkMc^7>iLkQiOol00`00Oomoo`09Ool00`00
Oomoo`01Ool003eoo`80001aOomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aG7E;l
DaeBo5LMD_aG7E;lEaeC75LMDaaG?E/LFceG75/mFcaO?5/lGeeK?6]kIeY[NfMJJg][NVnJJgYcVFmh
MkQgUgNHMiIk]g^ENkEkU7neNiEk]G^DOkAkTWncNi9o/g^BOk=kTWndNiAk]7^COkAkU7^fMkEk]gNg
MkUcV01kOol00`00Oomoo`08Ool00`00Oomoo`01Ool003moo`06001ooe;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@05EaaG7ELMGcaK?003Gc`0
2E/lHeaOG6]kIg][NfmjKiY_NP02LiT01GNHMiMgV7NFNiL00W^E00AgUW^GMiIkU@9kU0MkT`05Nk=k
]7^CNi=k/`02Nk@01W^eMkMg]g>iLkQg^Gaoo`03001oogoo00Moo`03001oogoo005oo`00@7oo06l0
07ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeC75LmEaaG
7ELLFceG75llFcaOGEllHeaO>f=LGcaSG6]jKiY[NVnJKgQcVGNGMiQcUg^gMiIgV7>GNkMgUW^eNiEo
]G^COk=kTWneNi=o/g^BOk=kTgncNi=o]7^CNkAg]G^gMkMg^G>HMkT0OWoo00<007ooOol01goo0@00
0Goo0Goo0011Ool01P00Oomooe;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@9C
7@0GEaeC7E<MDaeG7ELLEaeG75/mEaaG7ELLFceO?6=LGeaSG5llHeaSFfMLHe]WF`02LiT00gNGMiQg
V002LiT2MiP017^GMiIkUW^E0W^D00=kTg^DNi@00g^C00Ik/g^CNi=kTg^cNi<2Nk@01G^fMkMg]g>h
MkT0Ogoo00<007ooOol01goo0@000Goo0Goo0012Ool20000JGooC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMEaaK?ELLFceG75/mFaaK?ElkHeaO?6MlHe]WO6=KIgaW
FV]kJgY_VV]jLiUcNG>ILiMg^7NFNkMkUG^fNiAo]7^EOkEkU7ndNi9o/g^BOk=kTWndNi=k]7^DNkIg
]g^gMkEk]P21Ool00`00Oomoo`06Ool10001Ool1Ool004Aoo`05001ooe;mDae>o@02D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06DaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<L00=G7@04DaaK?5/lFcd3Fc`01e/mHe]WFf=KIeaS
FfMK009[N`=_NP03KiYcVG>I009gV004MiIkUWNFNiD2Ni@00g^CNiAkU006Ni<00g^cNi=k/`02Nk@0
1G^CNkAk]G^fNkD0PWoo00<007ooOol01Goo0@000Goo0Goo0015Ool0I`00Oom>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeC75LMD_aG7ELLEaeC75/mFaaK?ELLGeeK?5llHe]WO6=KJg]W
FV]kIeY_VV]jKiYcNG>ILiMg^7NGNkMgUW^fNiEo]7^DNkIkU7ndNi=o/g^BOkAkTWncNi9k]7^CNkEk
Tg^dNiAk]WNe08=oo`03001oogoo00Eoo`40005oo`5oo`00AWoo00D007ooD_eC7Dkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03
D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeG7003Ead01ELLEaeO?5llFc`00ell00EK?6]kJg][
NfMk009_NP03KiYcVG>I009gV008MiMkUWNFNiMkUG^FMiIkU@9kU0MkT`07Nk=kTg^cNi=k/g^dNkH0
0W^eQ7oo00<007ooOol017oo0@000Goo0Goo0017Ool20000HWooDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC
7E;lEaeBo5<MD_aG7E;lEaeC75LmEaaK?ELLFceK?5llFcaOGEllHeaO>f=LGca_VV]jKiY[NW>IKgQg
^7NGMiQgUW^gNiEgV7NFNkMkUGndNiAo]7^BOkAkTgncNi9o/g^COk=kTW^dNiAk]GNeNkJ6Ool00`00
Oomoo`03Ool10001Ool1Ool004Uoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00AC7E;mDaeBo@AC7@0FEaeC
7E<MDaeK?ELLEaeG75/mEaaG7ELLHeaO?6=LGeaSG5llIe]SFfMLHe/2LiT02GNHMiMgV7NFNiMgUWNH
MiIkU`02NiD017^DNi=kTg^D2G^C00Ak]7^eNkEk]HMoo`03001oogoo00=oo`40005oo`00BWoo0600
07ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E<LFceG75/mEaaK?ELLFceK76=LGc]S
G6=KIgaSFfMlHe][NfMJKiY[NVnJKgQcVG=iMiQcUg^gMiIk]G^DOkEkTg^eNiAo]7^BOk=kTWncNi9o
/g^CNkEkU7^fMkF8Ool00`00Oomoo`03Ool10001Ool004]oo`04001ooe<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eC7E;mDaeBoE<MD_eC
7E;m0e<M00EBoELMEaeG7E<L00=G7@=K?00:FceK?5/lFcaWG6=KIe]SFfMLHe/2Jg/00fnJKgY_NP03
LiT2MiP01G^GMiIkUG^ENi@00W^E00=kU7^CNi<01W^C00Ek/g^dNk=kTg^c08Uoo`03001oogoo009o
o`40005oo`00C7oo0P0005]C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG7E<LEaeBo5LmEaaG7ELLFceK
75/mEaaOGE/lIgaSFfMlIeY[NfMJJg][NVnJJgYcVG=iLiUcUgNhMiIk]g^EOkEgUW^eNiEo]G^COk=k
TWndNi9o/g^BOkAkU7ncNi=o]02;Ool01@00Oomoogoo00000Goo001>Ool00`00Oom>o@02D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;m
DaeBoE<MD_d3Dad01E;mDaeG7ELMEa`00eLM0U/l0Ull00EK?5llGcaO?6Mk00=[N`=_NP=cV@9gV005
MiIkUW^ENiEgUP02NiD2Ni@2Ni<01G^DNi=kTg^CNk<00g^C00=k/g^COol0Rgoo00@007ooOol0005o
o`00Cgoo05T007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaG7E<LEceG75LMFcaOGE/lGcaK?6=L
GcaSG5lkHea[NVnJJgYcVG=iLiUcUgNhMiMk]gNFNkIgUW^gNiEk]W^DOkAkTWneNi=o/g^BOk=kTgnc
Ni9o]7^C08eoo`04001oogoo0001Ool0051oo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00UC7E;mDaeBoE<MD_eC7E;mEad00e<M01AG7E<M
DaeG75/mEaaG7ELLFceG75LMGeaSG5llHeaOG6=LHe]WFf=K0g>I0WNH00=gUg^FMiH00WNH00=kUW^E
NiD00W^D00=kTg^DNi@00W^C00Mk/g^CNi=kTg^cNi=k/`2>Ool00`00Ool00001Ool0055oo`80001D
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7E;lDaeBo5LMD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaK?EllHeaO>fMlHe]WO6=KJg]WFV]k
JgY_VV]jLiU_N7NhLiMk]gNFNkIkUGndNi=k]W^DOkAkTgncNi9o]7^BOk=kTg^dT7oo0@000Goo0@00
001COol01P00C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
D_eBoE;mDaeBo@=C7@05D_eC7E<MDaeC7003Ead01E<LEaeG75/mEa`00U/l00iK?E/lFcaSFfMLHe]W
Ff=KJg]WNf]kKgY_VVmj0g>I0WNH00=gUW^ENiD00W^D00=kUG^DNi@01G^C00Ak/g^CNk=kTi5oo`80
0000E7oo058007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeC75LMD_aG7E/LFceG75/mFaaK?E/lGeeSFfMlHe][NfMJ
Jg]WFVnJJgY_VVmhLiUcUgNHMiIk]g^ENkEkU7^gNiEo]7^DOkAkTWndNi=o/g^BNkAkTi9oo`800000
EGoo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC
7E;mDaeBoE<MD_eC7E;m0e<M00UBoELMEaeG7ELLEaeK?5/mFc`00ell00EK?5llGca[NfMk009[N`03
KiY_NVmj009cV@9gV007MiIkUg^ENiEgUW^GNiD00W^D0W^C00=kU7^CNi<017^CTWoo0P00001FOol0
C`00OomoodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>
o5<MD_aC7E;lEaeBo5LMD_aG?ELLEaeC75LmEaaO?5/lGeeK?5llGc]SG5llHeaO>fnJJgY_VVmhLiUc
NGNHLiMk]gNFMiQcUg^gMiIk]G^DOkEkTgndNi=o]7^BOk=kTgnc08moo`@0009oo`00Egoo0P0000Ao
oe;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@09DaeBoE<MD_eC7E;mDaeB
oELM00=C7@0CEaeC7E<MEaaK?ELLEaeG75/mEaaSG5mLHeaO?6=LGeaWG6=KIe/00g>I0WNH0W>I0WNH
00AkUgNFNiEkU@9kU003NiEkU7^C00EkTh]oo`@000Ioo`00FGoo04`007ooC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeBo5LMEaaK
?ELLFceG75/mEaaSG5llHeaSFfMlHe]WO6MJJg]WFVnJJgYcVG=iLiUcUgNHMiIk]g^EOkEkU7ndNiAo
]7^COk=kTWndNi9o/hMoo`@000Yoo`00FWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m
00YC7DkmD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7003Ead015<LEaeG75/m0e/l00MK?E/l
Ie]SFfMLHe]WF`02Jg/016MkKgY_NVnJ0W>I0WNH00AgUW^FNiEkU@9kU003NiEkU7^C00EkThAoo`@0
00ioo`00Fgoo04T007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MD_aC7E;lEaeBo5LMD_aG7E<LEaeBo5/mFaaK?ELLFceK?5llFcaWO6=KIgaWFV]kIeY_VV]jKiYc
NG>IKgQgV7>GNkMgUW^fNiAo]7^EOkEkU7ndNi=o]G^COk=kTP20Ool4000BOol005aoo`800003OomC
7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG
7003Ead01ELLEaeG7EllFc`00ell00EK?5llJg][NfMk009_NP04KiYcVG>ILiT2MiP027^FMiIkUG^E
NiIgUW^ENi@6Ni=nOol3000FOol005ioo`15001ooe<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeC75LmEaaG7ELLFceG75llFcaOGE/lHeaO>f=LGca_
VV]jKiY[NW>IKgQcVG>GMiQgUW^gLiMk]gNFNkIkUGndNi=o]7^DOkAkTWnc07Yoo`@001Uoo`00Ggoo
00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@9C7@0FEaeC
7E<MDaeG7E<MEaeG75/mEaaG7ELLFceO?6=LGeaSG5llIe]SFfMLHe/3LiT2MiP2LiT2MiP017NFNiMk
UG^D0W^C00=kU7^CNi<00W^CMWoo10007Goo001POol0@P00OomC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMD_aK?ELLFceG75/mFaaK?ElkHeaSFfMl
He]WO6=KJg]WFV]kJgY_VVmhLiUcUgNHMiIk]g^ENkEkU7^fNiEo]7^COk=kTW=oo`@0025oo`00HGoo
0P0000IC7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<L00=G
7@04DaaK?5/lFcd3Fc`01U/mHe]WFf=KIeaWN`=[N`9_NP=cV@9gV006NiMkUG^ENiAkUg^E0W^D0g^C
Kgoo10009Goo001SOol0?`00Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklEaeBo5<M
D_aG7E<LEaeBo5LMEaaG7E<LFceK75/mEaaOGE/lGcaK?5mMIeY[NfMJKiY[NVnJJgYcVG=iMiQcUg^g
MiIk]G^ENkMkUG^fNiAo]7^BOk=kU01/Ool3000YOol006Aoo`03001C7Dkm009Bo@05Dae>oE;mD_eC
7@03D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeG7003Ead01ELLEaeO?5llFc`015ll00=SG5mL
KiX00fmj0W>I0gNH00IgUWNHMiQgV7NFNiD2Ni@00g^CNiAkU01YOol4000/Ool006Eoo`0l001oodkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E<LEceG75/mEaaK?E/l
GcaK?6=LGcaSG5lkIgaSFfMLHe]cVG=iMiQcUgNHLgUgV7>GMiQgUW^fNiEo]G^CNkIkU7neIGoo1000
<7oo001VOol200001DkmD_eBoE<MC_d00U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@9C7@0FEaeC7E<M
DaeG7ELLEaeG75/mEaaG7EmLHeaO?6=LGeaWG6=KIe]SFf]kIg/3KgX2LiT3MiP01G^FNiEkU7^DNiD0
0W^DHWoo1000=7oo001XOol0>000OomC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MDaaG
7E;lEaeC75LMEaaK?ELLFceG75/mGcaSG5lkIgaSFfMLHe][NfMJKiY[NVnJJgYcVG>GMiQcUg^gNiEk
]W^DNkMkUGneNiANOol4000hOol006Uoo`06001ooe;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad0
1E;mDaeG7ELMDa`00eLM0e/l00]K?E/lFcaK?6MLHe]WFf=KJg]WNf]k00=_NP9cV@=gV005MiIkUGNF
NiIkU@02NiAKOol4000lOol006Yoo`0e001ooe<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;l
EaeC75LMD_aG?ELLEaeG75/mFaaK?E/lGeeK?5llFca[NfMJJg][NVnJJgYcVFmhMiQcUgNHMiIk]W>G
NkMgUW^fNiAo]01HOol30010Ool006]oo`80009Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;m
DaeG7ELMEa`00eLM00YG75llGcaO?5/lGcaOG6=LGcaSG0A_NP9cV@=gV004NiMgV7^FMiH2NiD00g^D
Oomoo`1COol40013Ool006eoo`0a001oodklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMD_aG
7ELLFceG75/mEaaK?EllHeaO>f=LGcaSG6=KIgaSFfMLKgQcVG>GMiQcUg>ILiMgV7NFNkMkUGndNi@0
DGoo1000Agoo001^Ool01000OomBoE<M0e;m00=C7E;mDad00U<M00EBoE<MDaeG7E<M00=G7@04EaaG
7ELLFcd2Fc`025mLHeaO?6MKHe]WG6=KIe/2Jg/3KgX2LiT00gNHMiIkU`02NiD00g^DOomoo`1<Ool4
001;Ool006moo`0^001oogooDae>o5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LMDaaG7ELLFceK75/m
EaaK?E/LIeaSFfMlHe][NfMJJg][NVnJJgYcVG=iMiQcUg^gMiIk]W^DNkM:Ool4001?Ool0071oo`80
0007OomC7E;mDaeBoE<MD_d00e<M00EBoELMEaeG7E<L00=G7@=K?003FceK?5ll009O?004Ig][Nf]k
Jg/3KgX2LiT2MiP01G^GMiIkUG^ENiL0B7oo0`00Dgoo001bOol0:P00C_aC7DklDaeBo5<MD_aG7E;l
DaeBo5LMEaaG7E<LEceG75LMDaaOGE/lGcaK?5mMGcaSG5lkHea[NVnJJgYcVG=iLiUcUgNHMiIk]g>G
NkMgUTAoo`@005Ioo`00Lgoo00P005;mDaeBoE<MD_eC7E;m0U<M00=G7E<MDad00ULM00EG75LMEaaK
?ELL009O?008HeaO?6=LGeaSG6=KIe]SF`=cV@9gV09cV@9gV003MiIoogoo03moo`@005Yoo`00M7oo
02L005;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7E;lFceG75/mEaaK?ELLHeaO?6=LGc]WO6=KIeaSFf]k
IeY[Nf]jKiYcNG>ILiMgV7NFNkL0?Goo1000GWoo001eOol200000e<MD_eC7@02Dad01E;mEaeG7ELM
Da`00ULM00EK?ELLEaeK?5/m00=K?007IeaSFfMKHe][NfMkJg/00Vmj0g>I0WNH00=kUWooOol0>7oo
1000HWoo001gOol08`00DaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LFceG75/mFaaK?E/lGeeK?6MLHe][
NfMJJg]WFVnJJgYcVFmhMiQcUg^gMiH0=Woo1000IWoo001hOol00`00DaeBo@03Dad01E;mDaeG7ELM
Ea`00eLM00EG75llGcaO?5/l009O?004Jg]WNf]kJg/2KgX2LiT3MiP00gNFOomoo`0bOol3001ZOol0
07Uoo`0O001C7E;lEaeBo5LMD_aG7ELLEaeC75LmEaaK?ELLGeeK?5llGc]SG5llHeaO>fnJJgYcVFmh
MiQcUgNHKgP0<Goo1000KGoo001jOol00`00OomC7@02Dad04ULMDaeC7E<MFceG75LMEaaK?ELLHeaO
G6=LGcaSG5mLIeaSF`9[N`=_NP9cVBeoo`@0075oo`00Ngoo0P0001YBo5LMD_aG7E;lEaeC75/mEaaK
?E/LFceG76=LGcaSG6=KIgaSFf]kIeY_VV]jKiY_N7>I:Woo1000MGoo001mOol00`00DaaG7@02Ead0
15<LEaeG7E/m0e/l00IK?E/lFcaSFfMLHe/3Jg/3KgX00g>IOomoo`0UOol4001iOol007ioo`0H001o
ogooEaaG7E<LEceG75/mEaaK?E/LGcaK?5mMFca[NfMJJg][NVnJJgYcVG=i8goo1000OGoo001oOol0
0`00Oomoo`02Ead01ELLEaeG7EllFc`015ll00=SG5mLHe`00fmj0W>I8Goo0`00PGoo0020Ool20000
4WooEaaK?ELLFceG75/mEaaSG5llHeaO>f=LHe]WG6=KJg]WFQioo`@008Aoo`00PWoo014007ooEaaK
?ELLEaeK?5/mFcaSG5mLIeaSFfMKHe][NfMk01]oo`@008Qoo`00Pgoo010007ooOomK?ELLFceK75/m
EaaWO6=KIeaSFf]kIeY[NaMoo`@008aoo`00Q7oo00@007ooOomK?@9K?09O?006FcaO?5llJg]WNf]k
57oo1000T7oo0025Ool200002WooGcaK?5mMFcaO?5lkHeaO?6=L4Woo0`00U7oo0027Ool02@00Oomo
ogooHeaOG6=LGcaSG00?Ool4002GOol008Qoo`06001oogooOomSG5ll3Goo1000Vgoo0029Ool01@00
Oomoogoo00002Goo1000Wgoo002:Ool200000goo001oo`04Ool4002SOol008aoo`800003Ool00000
00800:Moo`00SGoo0P00Zgoo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00
ogoo>goo003oOolkOol00?mooc]oo`00\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02905 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.727 .811 .917 r
.38986 .79554 .39822 .80102 .41223 .79325 .40389 .7888 Mtetra
.781 .842 .898 r
.40389 .7888 .41223 .79325 .42637 .78216 .41805 .77952 Mtetra
.851 .878 .859 r
.41805 .77952 .42637 .78216 .44065 .76578 .43234 .76598 Mtetra
.918 .906 .795 r
.43234 .76598 .44065 .76578 .45505 .74209 .44678 .74605 Mtetra
.963 .917 .715 r
.44678 .74605 .45505 .74209 .46948 .71063 .4613 .71821 Mtetra
.979 .916 .646 r
.4613 .71821 .46948 .71063 .48383 .67447 .4758 .68362 Mtetra
.978 .917 .615 r
.4758 .68362 .48383 .67447 .49798 .63959 .49014 .64715 Mtetra
.972 .929 .641 r
.49014 .64715 .49798 .63959 .51193 .61107 .50427 .61488 Mtetra
.955 .943 .722 r
.50427 .61488 .51193 .61107 .52575 .59035 .51823 .5902 Mtetra
.908 .929 .816 r
.51823 .5902 .52575 .59035 .53953 .57608 .53211 .57287 Mtetra
.835 .882 .876 r
.53211 .57287 .53953 .57608 .55334 .56612 .54598 .56094 Mtetra
.768 .83 .9 r
.54598 .56094 .55334 .56612 .56721 .55877 .5599 .5524 Mtetra
.723 .793 .907 r
.5599 .5524 .56721 .55877 .58114 .55286 .57388 .54582 Mtetra
.696 .77 .909 r
.57388 .54582 .58114 .55286 .59514 .54774 .58793 .54031 Mtetra
.681 .757 .909 r
.58793 .54031 .59514 .54774 .60922 .54303 .60205 .53538 Mtetra
.673 .749 .908 r
.60205 .53538 .60922 .54303 .62337 .53852 .61625 .53074 Mtetra
.668 .746 .908 r
.61625 .53074 .62337 .53852 .6376 .53412 .63053 .52624 Mtetra
.666 .744 .908 r
.63053 .52624 .6376 .53412 .6519 .52976 .64487 .52181 Mtetra
.665 .742 .908 r
.64487 .52181 .6519 .52976 .66627 .52541 .6593 .51741 Mtetra
.664 .742 .908 r
.6593 .51741 .66627 .52541 .68072 .52106 .6738 .513 Mtetra
.6738 .513 .68072 .52106 .69524 .51669 .68837 .50859 Mtetra
.664 .741 .908 r
.68837 .50859 .69524 .51669 .70984 .5123 .70302 .50416 Mtetra
.70302 .50416 .70984 .5123 .72452 .5079 .71775 .49971 Mtetra
.71775 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.707 .8 .922 r
.38142 .78966 .38986 .79554 .40389 .7888 .39548 .78369 Mtetra
.752 .825 .909 r
.39548 .78369 .40389 .7888 .41805 .77952 .40966 .77579 Mtetra
.815 .86 .882 r
.40966 .77579 .41805 .77952 .43234 .76598 .42397 .76455 Mtetra
.886 .894 .83 r
.42397 .76455 .43234 .76598 .44678 .74605 .43842 .74799 Mtetra
.944 .914 .755 r
.43842 .74799 .44678 .74605 .4613 .71821 .453 .72407 Mtetra
.974 .917 .678 r
.453 .72407 .4613 .71821 .4758 .68362 .46762 .69232 Mtetra
.98 .916 .625 r
.46762 .69232 .4758 .68362 .49014 .64715 .48215 .65584 Mtetra
.975 .922 .62 r
.48215 .65584 .49014 .64715 .50427 .61488 .49648 .62067 Mtetra
.966 .937 .676 r
.49648 .62067 .50427 .61488 .51823 .5902 .5106 .59189 Mtetra
.936 .941 .771 r
.5106 .59189 .51823 .5902 .53211 .57287 .5246 .57097 Mtetra
.873 .908 .851 r
.5246 .57097 .53211 .57287 .54598 .56094 .53855 .55654 Mtetra
.8 .855 .891 r
.53855 .55654 .54598 .56094 .5599 .5524 .55252 .54645 Mtetra
.743 .81 .905 r
.55252 .54645 .5599 .5524 .57388 .54582 .56655 .53897 Mtetra
.707 .78 .908 r
.56655 .53897 .57388 .54582 .58793 .54031 .58064 .53296 Mtetra
.687 .762 .909 r
.58064 .53296 .58793 .54031 .60205 .53538 .59481 .52773 Mtetra
.676 .752 .909 r
.59481 .52773 .60205 .53538 .61625 .53074 .60906 .52291 Mtetra
.67 .747 .908 r
.60906 .52291 .61625 .53074 .63053 .52624 .62338 .51831 Mtetra
.667 .744 .908 r
.62338 .51831 .63053 .52624 .64487 .52181 .63778 .5138 Mtetra
.665 .743 .908 r
.63778 .5138 .64487 .52181 .6593 .51741 .65226 .50933 Mtetra
.664 .742 .908 r
.65226 .50933 .6593 .51741 .6738 .513 .6668 .50488 Mtetra
.6668 .50488 .6738 .513 .68837 .50859 .68143 .50042 Mtetra
.68143 .50042 .68837 .50859 .70302 .50416 .69613 .49594 Mtetra
.664 .741 .908 r
.69613 .49594 .70302 .50416 .71775 .49971 .71091 .49145 Mtetra
.71091 .49145 .71775 .49971 .73255 .49524 .72577 .48694 Mtetra
.72577 .48694 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.692 .79 .926 r
.3729 .78346 .38142 .78966 .39548 .78369 .387 .77805 Mtetra
.727 .811 .917 r
.387 .77805 .39548 .78369 .40966 .77579 .4012 .77119 Mtetra
.781 .842 .898 r
.4012 .77119 .40966 .77579 .42397 .76455 .41553 .76177 Mtetra
.851 .878 .859 r
.41553 .76177 .42397 .76455 .43842 .74799 .43 .74807 Mtetra
.919 .906 .795 r
.43 .74807 .43842 .74799 .453 .72407 .44461 .72793 Mtetra
.963 .917 .715 r
.44461 .72793 .453 .72407 .46762 .69232 .45932 .69983 Mtetra
.979 .916 .646 r
.45932 .69983 .46762 .69232 .48215 .65584 .47401 .66493 Mtetra
.978 .917 .615 r
.47401 .66493 .48215 .65584 .49648 .62067 .48854 .62814 Mtetra
.972 .929 .641 r
.48854 .62814 .49648 .62067 .5106 .59189 .50285 .5956 Mtetra
.955 .943 .722 r
.50285 .5956 .5106 .59189 .5246 .57097 .51698 .57068 Mtetra
.908 .929 .816 r
.51698 .57068 .5246 .57097 .53855 .55654 .53103 .55317 Mtetra
.835 .882 .876 r
.53103 .55317 .53855 .55654 .55252 .54645 .54507 .54109 Mtetra
.768 .83 .9 r
.54507 .54109 .55252 .54645 .56655 .53897 .55915 .53243 Mtetra
.723 .793 .907 r
.55915 .53243 .56655 .53897 .58064 .53296 .57329 .52573 Mtetra
.696 .77 .909 r
.57329 .52573 .58064 .53296 .59481 .52773 .58751 .52011 Mtetra
.681 .757 .909 r
.58751 .52011 .59481 .52773 .60906 .52291 .6018 .51507 Mtetra
.673 .749 .908 r
.6018 .51507 .60906 .52291 .62338 .51831 .61617 .51033 Mtetra
.668 .746 .908 r
.61617 .51033 .62338 .51831 .63778 .5138 .63062 .50572 Mtetra
.666 .744 .908 r
.63062 .50572 .63778 .5138 .65226 .50933 .64515 .50119 Mtetra
.665 .742 .908 r
.64515 .50119 .65226 .50933 .6668 .50488 .65975 .49668 Mtetra
.664 .742 .908 r
.65975 .49668 .6668 .50488 .68143 .50042 .67442 .49217 Mtetra
.67442 .49217 .68143 .50042 .69613 .49594 .68918 .48764 Mtetra
.664 .741 .908 r
.68918 .48764 .69613 .49594 .71091 .49145 .70401 .48311 Mtetra
.70401 .48311 .71091 .49145 .72577 .48694 .71892 .47855 Mtetra
.71892 .47855 .72577 .48694 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.68 .783 .928 r
.36431 .777 .3729 .78346 .387 .77805 .37844 .772 Mtetra
.707 .8 .922 r
.37844 .772 .387 .77805 .4012 .77119 .39267 .76592 Mtetra
.752 .826 .909 r
.39267 .76592 .4012 .77119 .41553 .76177 .40701 .75789 Mtetra
.815 .86 .882 r
.40701 .75789 .41553 .76177 .43 .74807 .4215 .74651 Mtetra
.886 .894 .83 r
.4215 .74651 .43 .74807 .44461 .72793 .43614 .72976 Mtetra
.944 .914 .755 r
.43614 .72976 .44461 .72793 .45932 .69983 .45091 .7056 Mtetra
.974 .918 .677 r
.45091 .7056 .45932 .69983 .47401 .66493 .46572 .67356 Mtetra
.98 .916 .625 r
.46572 .67356 .47401 .66493 .48854 .62814 .48044 .63676 Mtetra
.975 .922 .62 r
.48044 .63676 .48854 .62814 .50285 .5956 .49495 .60128 Mtetra
.966 .937 .676 r
.49495 .60128 .50285 .5956 .51698 .57068 .50925 .57225 Mtetra
.936 .94 .771 r
.50925 .57225 .51698 .57068 .53103 .55317 .52342 .55113 Mtetra
.873 .908 .851 r
.52342 .55113 .53103 .55317 .54507 .54109 .53753 .53653 Mtetra
.8 .855 .891 r
.53753 .53653 .54507 .54109 .55915 .53243 .55167 .5263 Mtetra
.743 .809 .905 r
.55167 .5263 .55915 .53243 .57329 .52573 .56587 .5187 Mtetra
.707 .78 .908 r
.56587 .5187 .57329 .52573 .58751 .52011 .58014 .51257 Mtetra
.687 .762 .909 r
.58014 .51257 .58751 .52011 .6018 .51507 .59448 .50723 Mtetra
.676 .752 .909 r
.59448 .50723 .6018 .51507 .61617 .51033 .6089 .50231 Mtetra
.67 .747 .908 r
.6089 .50231 .61617 .51033 .63062 .50572 .62339 .49759 Mtetra
.667 .744 .908 r
.62339 .49759 .63062 .50572 .64515 .50119 .63797 .49298 Mtetra
.665 .743 .908 r
.63797 .49298 .64515 .50119 .65975 .49668 .65262 .4884 Mtetra
.664 .742 .908 r
.65262 .4884 .65975 .49668 .67442 .49217 .66735 .48384 Mtetra
.66735 .48384 .67442 .49217 .68918 .48764 .68215 .47927 Mtetra
.68215 .47927 .68918 .48764 .70401 .48311 .69704 .47468 Mtetra
.664 .741 .908 r
.69704 .47468 .70401 .48311 .71892 .47855 .712 .47008 Mtetra
.712 .47008 .71892 .47855 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .4608 Mtetra
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.671 .778 .93 r
.35564 .77035 .36431 .777 .37844 .772 .3698 .76563 Mtetra
.692 .79 .926 r
.3698 .76563 .37844 .772 .39267 .76592 .38406 .76011 Mtetra
.727 .811 .917 r
.38406 .76011 .39267 .76592 .40701 .75789 .39843 .75314 Mtetra
.781 .842 .898 r
.39843 .75314 .40701 .75789 .4215 .74651 .41294 .74359 Mtetra
.851 .878 .859 r
.41294 .74359 .4215 .74651 .43614 .72976 .42759 .72971 Mtetra
.919 .907 .795 r
.42759 .72971 .43614 .72976 .45091 .7056 .4424 .70936 Mtetra
.963 .918 .715 r
.4424 .70936 .45091 .7056 .46572 .67356 .4573 .68098 Mtetra
.979 .916 .646 r
.4573 .68098 .46572 .67356 .48044 .63676 .47218 .64577 Mtetra
.978 .917 .615 r
.47218 .64577 .48044 .63676 .49495 .60128 .4869 .60867 Mtetra
.972 .929 .641 r
.4869 .60867 .49495 .60128 .50925 .57225 .50139 .57584 Mtetra
.955 .942 .722 r
.50139 .57584 .50925 .57225 .52342 .55113 .5157 .5507 Mtetra
.908 .928 .816 r
.5157 .5507 .52342 .55113 .53753 .53653 .52992 .533 Mtetra
.835 .882 .876 r
.52992 .533 .53753 .53653 .55167 .5263 .54413 .52077 Mtetra
.768 .83 .9 r
.54413 .52077 .55167 .5263 .56587 .5187 .55838 .51197 Mtetra
.723 .793 .907 r
.55838 .51197 .56587 .5187 .58014 .51257 .57269 .50516 Mtetra
.696 .77 .909 r
.57269 .50516 .58014 .51257 .59448 .50723 .58708 .49943 Mtetra
.681 .757 .909 r
.58708 .49943 .59448 .50723 .6089 .50231 .60155 .49427 Mtetra
.673 .749 .908 r
.60155 .49427 .6089 .50231 .62339 .49759 .6161 .48942 Mtetra
.668 .746 .908 r
.6161 .48942 .62339 .49759 .63797 .49298 .63072 .4847 Mtetra
.666 .744 .908 r
.63072 .4847 .63797 .49298 .65262 .4884 .64542 .48006 Mtetra
.665 .742 .908 r
.64542 .48006 .65262 .4884 .66735 .48384 .6602 .47543 Mtetra
.664 .742 .908 r
.6602 .47543 .66735 .48384 .68215 .47927 .67506 .47081 Mtetra
.67506 .47081 .68215 .47927 .69704 .47468 .69 .46618 Mtetra
.664 .741 .908 r
.69 .46618 .69704 .47468 .712 .47008 .70502 .46153 Mtetra
.70502 .46153 .712 .47008 .72705 .46545 .72012 .45686 Mtetra
.72012 .45686 .72705 .46545 .74217 .4608 .7353 .45216 Mtetra
.7353 .45216 .74217 .4608 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.664 .774 .931 r
.34689 .76352 .35564 .77035 .3698 .76563 .36109 .75901 Mtetra
.68 .783 .928 r
.36109 .75901 .3698 .76563 .38406 .76011 .37538 .7539 Mtetra
.707 .8 .922 r
.37538 .7539 .38406 .76011 .39843 .75314 .38978 .7477 Mtetra
.752 .826 .909 r
.38978 .7477 .39843 .75314 .41294 .74359 .40431 .73955 Mtetra
.815 .86 .882 r
.40431 .73955 .41294 .74359 .42759 .72971 .41898 .72802 Mtetra
.887 .894 .83 r
.41898 .72802 .42759 .72971 .4424 .70936 .4338 .71108 Mtetra
.945 .914 .755 r
.4338 .71108 .4424 .70936 .4573 .68098 .44876 .68666 Mtetra
.974 .918 .677 r
.44876 .68666 .4573 .68098 .47218 .64577 .46377 .65433 Mtetra
.98 .916 .624 r
.46377 .65433 .47218 .64577 .4869 .60867 .47868 .61721 Mtetra
.975 .922 .621 r
.47868 .61721 .4869 .60867 .50139 .57584 .49338 .58142 Mtetra
.966 .937 .677 r
.49338 .58142 .50139 .57584 .5157 .5507 .50787 .55213 Mtetra
.936 .94 .771 r
.50787 .55213 .5157 .5507 .52992 .533 .52221 .5308 Mtetra
.873 .907 .851 r
.52221 .5308 .52992 .533 .54413 .52077 .5365 .51603 Mtetra
.8 .855 .891 r
.5365 .51603 .54413 .52077 .55838 .51197 .55081 .50566 Mtetra
.743 .809 .905 r
.55081 .50566 .55838 .51197 .57269 .50516 .56518 .49794 Mtetra
.707 .78 .908 r
.56518 .49794 .57269 .50516 .58708 .49943 .57962 .49169 Mtetra
.687 .762 .909 r
.57962 .49169 .58708 .49943 .60155 .49427 .59413 .48624 Mtetra
.676 .752 .909 r
.59413 .48624 .60155 .49427 .6161 .48942 .60873 .4812 Mtetra
.67 .747 .908 r
.60873 .4812 .6161 .48942 .63072 .4847 .6234 .47637 Mtetra
.667 .744 .908 r
.6234 .47637 .63072 .4847 .64542 .48006 .63816 .47164 Mtetra
.665 .743 .908 r
.63816 .47164 .64542 .48006 .6602 .47543 .65299 .46696 Mtetra
.664 .742 .908 r
.65299 .46696 .6602 .47543 .67506 .47081 .6679 .46228 Mtetra
.6679 .46228 .67506 .47081 .69 .46618 .6829 .45759 Mtetra
.6829 .45759 .69 .46618 .70502 .46153 .69797 .45289 Mtetra
.664 .741 .908 r
.69797 .45289 .70502 .46153 .72012 .45686 .71312 .44817 Mtetra
.71312 .44817 .72012 .45686 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43866 Mtetra
.74368 .43866 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42906 Mtetra
.77456 .42906 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.659 .771 .932 r
.33805 .75656 .34689 .76352 .36109 .75901 .35229 .75218 Mtetra
.671 .778 .93 r
.35229 .75218 .36109 .75901 .37538 .7539 .36662 .74736 Mtetra
.692 .79 .926 r
.36662 .74736 .37538 .7539 .38978 .7477 .38105 .74173 Mtetra
.727 .811 .917 r
.38105 .74173 .38978 .7477 .40431 .73955 .3956 .73463 Mtetra
.781 .842 .898 r
.3956 .73463 .40431 .73955 .41898 .72802 .41029 .72494 Mtetra
.851 .878 .859 r
.41029 .72494 .41898 .72802 .4338 .71108 .42513 .71089 Mtetra
.919 .907 .795 r
.42513 .71089 .4338 .71108 .44876 .68666 .44012 .69032 Mtetra
.963 .918 .715 r
.44012 .69032 .44876 .68666 .46377 .65433 .45522 .66167 Mtetra
.979 .916 .646 r
.45522 .66167 .46377 .65433 .47868 .61721 .4703 .62614 Mtetra
.978 .917 .615 r
.4703 .62614 .47868 .61721 .49338 .58142 .48522 .58871 Mtetra
.972 .929 .641 r
.48522 .58871 .49338 .58142 .50787 .55213 .4999 .5556 Mtetra
.955 .942 .722 r
.4999 .5556 .50787 .55213 .52221 .5308 .51439 .53022 Mtetra
.908 .928 .816 r
.51439 .53022 .52221 .5308 .5365 .51603 .52878 .51233 Mtetra
.835 .881 .876 r
.52878 .51233 .5365 .51603 .55081 .50566 .54316 .49995 Mtetra
.768 .83 .9 r
.54316 .49995 .55081 .50566 .56518 .49794 .55759 .49101 Mtetra
.723 .793 .907 r
.55759 .49101 .56518 .49794 .57962 .49169 .57208 .48408 Mtetra
.696 .77 .909 r
.57208 .48408 .57962 .49169 .59413 .48624 .58664 .47823 Mtetra
.681 .757 .909 r
.58664 .47823 .59413 .48624 .60873 .4812 .60129 .47296 Mtetra
.673 .749 .908 r
.60129 .47296 .60873 .4812 .6234 .47637 .61602 .46799 Mtetra
.668 .746 .908 r
.61602 .46799 .6234 .47637 .63816 .47164 .63082 .46316 Mtetra
.666 .744 .908 r
.63082 .46316 .63816 .47164 .65299 .46696 .64571 .4584 Mtetra
.665 .742 .908 r
.64571 .4584 .65299 .46696 .6679 .46228 .66067 .45366 Mtetra
.664 .742 .908 r
.66067 .45366 .6679 .46228 .6829 .45759 .67572 .44892 Mtetra
.67572 .44892 .6829 .45759 .69797 .45289 .69085 .44417 Mtetra
.664 .741 .908 r
.69085 .44417 .69797 .45289 .71312 .44817 .70606 .43941 Mtetra
.70606 .43941 .71312 .44817 .72836 .44343 .72135 .43461 Mtetra
.72135 .43461 .72836 .44343 .74368 .43866 .73673 .4298 Mtetra
.73673 .4298 .74368 .43866 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42906 .76773 .42009 Mtetra
.76773 .42009 .77456 .42906 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.656 .768 .932 r
.32913 .74946 .33805 .75656 .35229 .75218 .34341 .74517 Mtetra
.664 .774 .931 r
.34341 .74517 .35229 .75218 .36662 .74736 .35778 .74056 Mtetra
.68 .783 .928 r
.35778 .74056 .36662 .74736 .38105 .74173 .37225 .73534 Mtetra
.707 .8 .922 r
.37225 .73534 .38105 .74173 .3956 .73463 .38682 .72902 Mtetra
.752 .826 .909 r
.38682 .72902 .3956 .73463 .41029 .72494 .40153 .72074 Mtetra
.815 .86 .882 r
.40153 .72074 .41029 .72494 .42513 .71089 .41638 .70905 Mtetra
.887 .894 .83 r
.41638 .70905 .42513 .71089 .44012 .69032 .4314 .69191 Mtetra
.945 .915 .755 r
.4314 .69191 .44012 .69032 .45522 .66167 .44655 .66725 Mtetra
.974 .918 .677 r
.44655 .66725 .45522 .66167 .4703 .62614 .46176 .63461 Mtetra
.979 .916 .624 r
.46176 .63461 .4703 .62614 .48522 .58871 .47688 .59717 Mtetra
.975 .922 .621 r
.47688 .59717 .48522 .58871 .4999 .5556 .49178 .56107 Mtetra
.966 .937 .677 r
.49178 .56107 .4999 .5556 .51439 .53022 .50645 .53151 Mtetra
.936 .94 .771 r
.50645 .53151 .51439 .53022 .52878 .51233 .52097 .50997 Mtetra
.873 .907 .851 r
.52097 .50997 .52878 .51233 .54316 .49995 .53544 .49502 Mtetra
.8 .855 .891 r
.53544 .49502 .54316 .49995 .55759 .49101 .54992 .48452 Mtetra
.743 .809 .905 r
.54992 .48452 .55759 .49101 .57208 .48408 .56447 .47666 Mtetra
.707 .78 .908 r
.56447 .47666 .57208 .48408 .58664 .47823 .57908 .47029 Mtetra
.687 .762 .909 r
.57908 .47029 .58664 .47823 .60129 .47296 .59378 .46472 Mtetra
.676 .752 .909 r
.59378 .46472 .60129 .47296 .61602 .46799 .60856 .45956 Mtetra
.67 .747 .908 r
.60856 .45956 .61602 .46799 .63082 .46316 .62341 .45462 Mtetra
.667 .744 .908 r
.62341 .45462 .63082 .46316 .64571 .4584 .63835 .44977 Mtetra
.665 .743 .908 r
.63835 .44977 .64571 .4584 .66067 .45366 .65337 .44497 Mtetra
.664 .742 .908 r
.65337 .44497 .66067 .45366 .67572 .44892 .66848 .44017 Mtetra
.66848 .44017 .67572 .44892 .69085 .44417 .68366 .43537 Mtetra
.68366 .43537 .69085 .44417 .70606 .43941 .69893 .43055 Mtetra
.664 .741 .908 r
.69893 .43055 .70606 .43941 .72135 .43461 .71427 .42571 Mtetra
.71427 .42571 .72135 .43461 .73673 .4298 .72971 .42085 Mtetra
.72971 .42085 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.653 .767 .933 r
.32012 .74226 .32913 .74946 .34341 .74517 .33444 .73803 Mtetra
.659 .771 .932 r
.33444 .73803 .34341 .74517 .35778 .74056 .34885 .73354 Mtetra
.671 .778 .93 r
.34885 .73354 .35778 .74056 .37225 .73534 .36336 .72862 Mtetra
.692 .79 .926 r
.36336 .72862 .37225 .73534 .38682 .72902 .37797 .72287 Mtetra
.727 .811 .917 r
.37797 .72287 .38682 .72902 .40153 .72074 .3927 .71565 Mtetra
.781 .842 .898 r
.3927 .71565 .40153 .72074 .41638 .70905 .40757 .70581 Mtetra
.851 .878 .859 r
.40757 .70581 .41638 .70905 .4314 .69191 .4226 .69159 Mtetra
.919 .907 .795 r
.4226 .69159 .4314 .69191 .44655 .66725 .43779 .67079 Mtetra
.963 .918 .715 r
.43779 .67079 .44655 .66725 .46176 .63461 .45309 .64186 Mtetra
.979 .917 .646 r
.45309 .64186 .46176 .63461 .47688 .59717 .46837 .60601 Mtetra
.978 .917 .615 r
.46837 .60601 .47688 .59717 .49178 .56107 .48349 .56826 Mtetra
.972 .929 .642 r
.48349 .56826 .49178 .56107 .50645 .53151 .49837 .53485 Mtetra
.955 .942 .722 r
.49837 .53485 .50645 .53151 .52097 .50997 .51304 .50923 Mtetra
.908 .928 .816 r
.51304 .50923 .52097 .50997 .53544 .49502 .52762 .49115 Mtetra
.835 .881 .876 r
.52762 .49115 .53544 .49502 .54992 .48452 .54218 .47861 Mtetra
.768 .83 .9 r
.54218 .47861 .54992 .48452 .56447 .47666 .55678 .46954 Mtetra
.723 .793 .907 r
.55678 .46954 .56447 .47666 .57908 .47029 .57145 .46247 Mtetra
.696 .77 .909 r
.57145 .46247 .57908 .47029 .59378 .46472 .5862 .4565 Mtetra
.681 .757 .909 r
.5862 .4565 .59378 .46472 .60856 .45956 .60102 .45111 Mtetra
.673 .749 .908 r
.60102 .45111 .60856 .45956 .62341 .45462 .61593 .44602 Mtetra
.668 .746 .908 r
.61593 .44602 .62341 .45462 .63835 .44977 .63093 .44108 Mtetra
.666 .744 .908 r
.63093 .44108 .63835 .44977 .65337 .44497 .646 .4362 Mtetra
.665 .742 .908 r
.646 .4362 .65337 .44497 .66848 .44017 .66116 .43134 Mtetra
.664 .742 .908 r
.66116 .43134 .66848 .44017 .68366 .43537 .6764 .42648 Mtetra
.6764 .42648 .68366 .43537 .69893 .43055 .69172 .42161 Mtetra
.664 .741 .908 r
.69172 .42161 .69893 .43055 .71427 .42571 .70713 .41672 Mtetra
.70713 .41672 .71427 .42571 .72971 .42085 .72262 .4118 Mtetra
.72262 .4118 .72971 .42085 .74522 .41596 .73819 .40687 Mtetra
.73819 .40687 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.651 .766 .933 r
.31102 .73496 .32012 .74226 .33444 .73803 .32539 .73075 Mtetra
.656 .768 .932 r
.32539 .73075 .33444 .73803 .34885 .73354 .33984 .72636 Mtetra
.664 .774 .931 r
.33984 .72636 .34885 .73354 .36336 .72862 .35439 .72163 Mtetra
.68 .783 .928 r
.35439 .72163 .36336 .72862 .37797 .72287 .36903 .7163 Mtetra
.707 .8 .922 r
.36903 .7163 .37797 .72287 .3927 .71565 .38379 .70987 Mtetra
.752 .826 .909 r
.38379 .70987 .3927 .71565 .40757 .70581 .39868 .70145 Mtetra
.815 .86 .882 r
.39868 .70145 .40757 .70581 .4226 .69159 .41372 .68959 Mtetra
.887 .895 .83 r
.41372 .68959 .4226 .69159 .43779 .67079 .42894 .67225 Mtetra
.945 .915 .755 r
.42894 .67225 .43779 .67079 .45309 .64186 .44429 .64734 Mtetra
.974 .918 .677 r
.44429 .64734 .45309 .64186 .46837 .60601 .45971 .6144 Mtetra
.979 .916 .624 r
.45971 .6144 .46837 .60601 .48349 .56826 .47503 .57662 Mtetra
.975 .922 .621 r
.47503 .57662 .48349 .56826 .49837 .53485 .49013 .5402 Mtetra
.966 .937 .677 r
.49013 .5402 .49837 .53485 .51304 .50923 .50499 .51038 Mtetra
.936 .94 .771 r
.50499 .51038 .51304 .50923 .52762 .49115 .5197 .48861 Mtetra
.873 .907 .851 r
.5197 .48861 .52762 .49115 .54218 .47861 .53435 .4735 Mtetra
.8 .854 .891 r
.53435 .4735 .54218 .47861 .55678 .46954 .54901 .46284 Mtetra
.743 .809 .905 r
.54901 .46284 .55678 .46954 .57145 .46247 .56374 .45485 Mtetra
.707 .78 .908 r
.56374 .45485 .57145 .46247 .5862 .4565 .57854 .44835 Mtetra
.687 .762 .909 r
.57854 .44835 .5862 .4565 .60102 .45111 .59342 .44265 Mtetra
.676 .752 .908 r
.59342 .44265 .60102 .45111 .61593 .44602 .60838 .43738 Mtetra
.67 .747 .908 r
.60838 .43738 .61593 .44602 .63093 .44108 .62343 .43231 Mtetra
.667 .744 .908 r
.62343 .43231 .63093 .44108 .646 .4362 .63855 .42735 Mtetra
.665 .743 .908 r
.63855 .42735 .646 .4362 .66116 .43134 .65377 .42242 Mtetra
.664 .742 .908 r
.65377 .42242 .66116 .43134 .6764 .42648 .66906 .41751 Mtetra
.66906 .41751 .6764 .42648 .69172 .42161 .68444 .41258 Mtetra
.68444 .41258 .69172 .42161 .70713 .41672 .6999 .40764 Mtetra
.664 .741 .908 r
.6999 .40764 .70713 .41672 .72262 .4118 .71545 .40267 Mtetra
.71545 .40267 .72262 .4118 .73819 .40687 .73109 .39768 Mtetra
.73109 .39768 .73819 .40687 .75385 .4019 .74681 .39267 Mtetra
.74681 .39267 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.65 .765 .933 r
.30183 .72756 .31102 .73496 .32539 .73075 .31624 .72336 Mtetra
.653 .767 .933 r
.31624 .72336 .32539 .73075 .33984 .72636 .33074 .71902 Mtetra
.659 .771 .932 r
.33074 .71902 .33984 .72636 .35439 .72163 .34533 .71443 Mtetra
.671 .778 .93 r
.34533 .71443 .35439 .72163 .36903 .7163 .36001 .70939 Mtetra
.692 .79 .926 r
.36001 .70939 .36903 .7163 .38379 .70987 .3748 .70353 Mtetra
.727 .812 .917 r
.3748 .70353 .38379 .70987 .39868 .70145 .38972 .69618 Mtetra
.781 .842 .898 r
.38972 .69618 .39868 .70145 .41372 .68959 .40478 .68619 Mtetra
.851 .879 .859 r
.40478 .68619 .41372 .68959 .42894 .67225 .42 .67179 Mtetra
.919 .907 .795 r
.42 .67179 .42894 .67225 .44429 .64734 .4354 .65076 Mtetra
.963 .918 .714 r
.4354 .65076 .44429 .64734 .45971 .6144 .4509 .62155 Mtetra
.979 .917 .646 r
.4509 .62155 .45971 .6144 .47503 .57662 .4664 .58537 Mtetra
.978 .917 .615 r
.4664 .58537 .47503 .57662 .49013 .5402 .48172 .54728 Mtetra
.972 .929 .642 r
.48172 .54728 .49013 .5402 .50499 .51038 .4968 .51358 Mtetra
.955 .942 .723 r
.4968 .51358 .50499 .51038 .5197 .48861 .51166 .48771 Mtetra
.908 .928 .816 r
.51166 .48771 .5197 .48861 .53435 .4735 .52642 .46944 Mtetra
.835 .881 .876 r
.52642 .46944 .53435 .4735 .54901 .46284 .54117 .45673 Mtetra
.768 .83 .9 r
.54117 .45673 .54901 .46284 .56374 .45485 .55595 .44752 Mtetra
.723 .793 .907 r
.55595 .44752 .56374 .45485 .57854 .44835 .5708 .44032 Mtetra
.696 .77 .909 r
.5708 .44032 .57854 .44835 .59342 .44265 .58574 .43422 Mtetra
.681 .757 .909 r
.58574 .43422 .59342 .44265 .60838 .43738 .60075 .42871 Mtetra
.673 .749 .908 r
.60075 .42871 .60838 .43738 .62343 .43231 .61585 .4235 Mtetra
.668 .746 .908 r
.61585 .4235 .62343 .43231 .63855 .42735 .63103 .41843 Mtetra
.666 .744 .908 r
.63103 .41843 .63855 .42735 .65377 .42242 .6463 .41343 Mtetra
.665 .742 .908 r
.6463 .41343 .65377 .42242 .66906 .41751 .66165 .40844 Mtetra
.664 .742 .908 r
.66165 .40844 .66906 .41751 .68444 .41258 .67709 .40346 Mtetra
.67709 .40346 .68444 .41258 .6999 .40764 .69261 .39846 Mtetra
.664 .741 .908 r
.69261 .39846 .6999 .40764 .71545 .40267 .70822 .39345 Mtetra
.70822 .39345 .71545 .40267 .73109 .39768 .72391 .3884 Mtetra
.72391 .3884 .73109 .39768 .74681 .39267 .73969 .38334 Mtetra
.73969 .38334 .74681 .39267 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.649 .764 .933 r
.29255 .72007 .30183 .72756 .31624 .72336 .30701 .71587 Mtetra
.651 .766 .933 r
.30701 .71587 .31624 .72336 .33074 .71902 .32155 .71155 Mtetra
.656 .768 .932 r
.32155 .71155 .33074 .71902 .34533 .71443 .33618 .70705 Mtetra
.664 .774 .931 r
.33618 .70705 .34533 .71443 .36001 .70939 .35091 .70221 Mtetra
.68 .783 .928 r
.35091 .70221 .36001 .70939 .3748 .70353 .36573 .69677 Mtetra
.707 .8 .922 r
.36573 .69677 .3748 .70353 .38972 .69618 .38068 .69021 Mtetra
.752 .826 .909 r
.38068 .69021 .38972 .69618 .40478 .68619 .39576 .68165 Mtetra
.815 .861 .882 r
.39576 .68165 .40478 .68619 .42 .67179 .411 .66963 Mtetra
.887 .895 .83 r
.411 .66963 .42 .67179 .4354 .65076 .42641 .65208 Mtetra
.945 .915 .755 r
.42641 .65208 .4354 .65076 .4509 .62155 .44197 .62691 Mtetra
.974 .918 .677 r
.44197 .62691 .4509 .62155 .4664 .58537 .4576 .59365 Mtetra
.979 .916 .624 r
.4576 .59365 .4664 .58537 .48172 .54728 .47314 .55554 Mtetra
.975 .922 .621 r
.47314 .55554 .48172 .54728 .4968 .51358 .48844 .5188 Mtetra
.966 .937 .677 r
.48844 .5188 .4968 .51358 .51166 .48771 .5035 .4887 Mtetra
.936 .94 .772 r
.5035 .4887 .51166 .48771 .52642 .46944 .51839 .46672 Mtetra
.873 .907 .851 r
.51839 .46672 .52642 .46944 .54117 .45673 .53323 .45142 Mtetra
.8 .854 .891 r
.53323 .45142 .54117 .45673 .55595 .44752 .54808 .44061 Mtetra
.743 .809 .905 r
.54808 .44061 .55595 .44752 .5708 .44032 .56299 .43248 Mtetra
.707 .779 .908 r
.56299 .43248 .5708 .44032 .58574 .43422 .57798 .42585 Mtetra
.687 .762 .909 r
.57798 .42585 .58574 .43422 .60075 .42871 .59305 .42003 Mtetra
.676 .752 .908 r
.59305 .42003 .60075 .42871 .61585 .4235 .6082 .41463 Mtetra
.67 .747 .908 r
.6082 .41463 .61585 .4235 .63103 .41843 .62344 .40944 Mtetra
.667 .744 .908 r
.62344 .40944 .63103 .41843 .6463 .41343 .63876 .40435 Mtetra
.665 .743 .908 r
.63876 .40435 .6463 .41343 .66165 .40844 .65417 .3993 Mtetra
.664 .742 .908 r
.65417 .3993 .66165 .40844 .67709 .40346 .66966 .39425 Mtetra
.66966 .39425 .67709 .40346 .69261 .39846 .68524 .3892 Mtetra
.68524 .3892 .69261 .39846 .70822 .39345 .70091 .38413 Mtetra
.664 .741 .908 r
.70091 .38413 .70822 .39345 .72391 .3884 .71666 .37903 Mtetra
.71666 .37903 .72391 .3884 .73969 .38334 .7325 .37391 Mtetra
.7325 .37391 .73969 .38334 .75556 .37824 .74844 .36876 Mtetra
.74844 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.648 .764 .933 r
.28317 .7125 .29255 .72007 .30701 .71587 .29768 .70828 Mtetra
.65 .765 .933 r
.29768 .70828 .30701 .71587 .32155 .71155 .31227 .70397 Mtetra
.653 .767 .933 r
.31227 .70397 .32155 .71155 .33618 .70705 .32694 .69952 Mtetra
.659 .771 .932 r
.32694 .69952 .33618 .70705 .35091 .70221 .34171 .69482 Mtetra
.671 .778 .93 r
.34171 .69482 .35091 .70221 .36573 .69677 .35658 .68966 Mtetra
.692 .791 .926 r
.35658 .68966 .36573 .69677 .38068 .69021 .37155 .68368 Mtetra
.727 .812 .917 r
.37155 .68368 .38068 .69021 .39576 .68165 .38666 .6762 Mtetra
.781 .843 .898 r
.38666 .6762 .39576 .68165 .411 .66963 .40191 .66605 Mtetra
.851 .879 .86 r
.40191 .66605 .411 .66963 .42641 .65208 .41734 .65146 Mtetra
.919 .907 .795 r
.41734 .65146 .42641 .65208 .44197 .62691 .43294 .6302 Mtetra
.963 .918 .714 r
.43294 .6302 .44197 .62691 .4576 .59365 .44866 .6007 Mtetra
.979 .917 .645 r
.44866 .6007 .4576 .59365 .47314 .55554 .46437 .56419 Mtetra
.978 .917 .615 r
.46437 .56419 .47314 .55554 .48844 .5188 .47991 .52577 Mtetra
.972 .929 .642 r
.47991 .52577 .48844 .5188 .5035 .4887 .49519 .49176 Mtetra
.955 .942 .723 r
.49519 .49176 .5035 .4887 .51839 .46672 .51025 .46564 Mtetra
.908 .927 .816 r
.51025 .46564 .51839 .46672 .53323 .45142 .5252 .44717 Mtetra
.835 .881 .876 r
.5252 .44717 .53323 .45142 .54808 .44061 .54013 .4343 Mtetra
.768 .83 .9 r
.54013 .4343 .54808 .44061 .56299 .43248 .5551 .42493 Mtetra
.723 .792 .907 r
.5551 .42493 .56299 .43248 .57798 .42585 .57014 .4176 Mtetra
.696 .77 .909 r
.57014 .4176 .57798 .42585 .59305 .42003 .58526 .41137 Mtetra
.681 .757 .909 r
.58526 .41137 .59305 .42003 .6082 .41463 .60047 .40573 Mtetra
.673 .749 .908 r
.60047 .40573 .6082 .41463 .62344 .40944 .61576 .40039 Mtetra
.668 .746 .908 r
.61576 .40039 .62344 .40944 .63876 .40435 .63114 .3952 Mtetra
.666 .744 .908 r
.63114 .3952 .63876 .40435 .65417 .3993 .64661 .39007 Mtetra
.665 .742 .908 r
.64661 .39007 .65417 .3993 .66966 .39425 .66216 .38495 Mtetra
.664 .742 .908 r
.66216 .38495 .66966 .39425 .68524 .3892 .6778 .37984 Mtetra
.6778 .37984 .68524 .3892 .70091 .38413 .69352 .37471 Mtetra
.664 .741 .908 r
.69352 .37471 .70091 .38413 .71666 .37903 .70934 .36956 Mtetra
.70934 .36956 .71666 .37903 .7325 .37391 .72524 .36439 Mtetra
.72524 .36439 .7325 .37391 .74844 .36876 .74123 .35919 Mtetra
.74123 .35919 .74844 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.647 .763 .934 r
.2737 .70484 .28317 .7125 .29768 .70828 .28825 .70059 Mtetra
.649 .764 .933 r
.28825 .70059 .29768 .70828 .31227 .70397 .30289 .69628 Mtetra
.651 .766 .933 r
.30289 .69628 .31227 .70397 .32694 .69952 .31761 .69185 Mtetra
.656 .768 .932 r
.31761 .69185 .32694 .69952 .34171 .69482 .33243 .68724 Mtetra
.664 .774 .931 r
.33243 .68724 .34171 .69482 .35658 .68966 .34733 .68229 Mtetra
.68 .783 .928 r
.34733 .68229 .35658 .68966 .37155 .68368 .36235 .67672 Mtetra
.707 .8 .922 r
.36235 .67672 .37155 .68368 .38666 .6762 .37748 .67003 Mtetra
.752 .826 .91 r
.37748 .67003 .38666 .6762 .40191 .66605 .39276 .66133 Mtetra
.815 .861 .882 r
.39276 .66133 .40191 .66605 .41734 .65146 .4082 .64913 Mtetra
.887 .895 .83 r
.4082 .64913 .41734 .65146 .43294 .6302 .42381 .63138 Mtetra
.945 .915 .755 r
.42381 .63138 .43294 .6302 .44866 .6007 .43959 .60594 Mtetra
.974 .918 .676 r
.43959 .60594 .44866 .6007 .46437 .56419 .45544 .57237 Mtetra
.979 .916 .624 r
.45544 .57237 .46437 .56419 .47991 .52577 .47119 .53391 Mtetra
.975 .922 .621 r
.47119 .53391 .47991 .52577 .49519 .49176 .48671 .49685 Mtetra
.966 .937 .678 r
.48671 .49685 .49519 .49176 .51025 .46564 .50197 .46647 Mtetra
.936 .939 .772 r
.50197 .46647 .51025 .46564 .5252 .44717 .51706 .44427 Mtetra
.873 .906 .851 r
.51706 .44427 .5252 .44717 .54013 .4343 .53209 .42878 Mtetra
.799 .854 .891 r
.53209 .42878 .54013 .4343 .5551 .42493 .54713 .41781 Mtetra
.743 .809 .905 r
.54713 .41781 .5551 .42493 .57014 .4176 .56223 .40954 Mtetra
.707 .779 .908 r
.56223 .40954 .57014 .4176 .58526 .41137 .5774 .40277 Mtetra
.687 .762 .909 r
.5774 .40277 .58526 .41137 .60047 .40573 .59267 .39682 Mtetra
.676 .752 .908 r
.59267 .39682 .60047 .40573 .61576 .40039 .60801 .39129 Mtetra
.67 .747 .908 r
.60801 .39129 .61576 .40039 .63114 .3952 .62345 .38597 Mtetra
.667 .744 .908 r
.62345 .38597 .63114 .3952 .64661 .39007 .63897 .38075 Mtetra
.665 .743 .908 r
.63897 .38075 .64661 .39007 .66216 .38495 .65458 .37557 Mtetra
.664 .742 .908 r
.65458 .37557 .66216 .38495 .6778 .37984 .67028 .37039 Mtetra
.67028 .37039 .6778 .37984 .69352 .37471 .68606 .3652 Mtetra
.68606 .3652 .69352 .37471 .70934 .36956 .70194 .36 Mtetra
.664 .741 .908 r
.70194 .36 .70934 .36956 .72524 .36439 .7179 .35477 Mtetra
.7179 .35477 .72524 .36439 .74123 .35919 .73396 .34951 Mtetra
.73396 .34951 .74123 .35919 .75732 .35396 .75011 .34423 Mtetra
.75011 .34423 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.647 .763 .934 r
.26413 .69709 .2737 .70484 .28825 .70059 .27873 .69282 Mtetra
.648 .764 .933 r
.27873 .69282 .28825 .70059 .30289 .69628 .29342 .68849 Mtetra
.65 .765 .933 r
.29342 .68849 .30289 .69628 .31761 .69185 .30819 .68407 Mtetra
.653 .767 .933 r
.30819 .68407 .31761 .69185 .33243 .68724 .32305 .6795 Mtetra
.659 .771 .932 r
.32305 .6795 .33243 .68724 .34733 .68229 .338 .67469 Mtetra
.671 .778 .93 r
.338 .67469 .34733 .68229 .36235 .67672 .35305 .66941 Mtetra
.692 .791 .926 r
.35305 .66941 .36235 .67672 .37748 .67003 .36822 .66331 Mtetra
.727 .812 .917 r
.36822 .66331 .37748 .67003 .39276 .66133 .38352 .65568 Mtetra
.781 .843 .898 r
.38352 .65568 .39276 .66133 .4082 .64913 .39897 .64538 Mtetra
.851 .879 .86 r
.39897 .64538 .4082 .64913 .42381 .63138 .41461 .6306 Mtetra
.919 .908 .795 r
.41461 .6306 .42381 .63138 .43959 .60594 .43042 .60909 Mtetra
.963 .918 .714 r
.43042 .60909 .43959 .60594 .45544 .57237 .44636 .5793 Mtetra
.979 .917 .645 r
.44636 .5793 .45544 .57237 .47119 .53391 .46229 .54245 Mtetra
.978 .917 .615 r
.46229 .54245 .47119 .53391 .48671 .49685 .47805 .50369 Mtetra
.972 .929 .642 r
.47805 .50369 .48671 .49685 .50197 .46647 .49354 .46937 Mtetra
.955 .942 .723 r
.49354 .46937 .50197 .46647 .51706 .44427 .5088 .44301 Mtetra
.908 .927 .816 r
.5088 .44301 .51706 .44427 .53209 .42878 .52394 .42433 Mtetra
.835 .881 .876 r
.52394 .42433 .53209 .42878 .54713 .41781 .53907 .41128 Mtetra
.768 .83 .9 r
.53907 .41128 .54713 .41781 .56223 .40954 .55423 .40177 Mtetra
.723 .792 .907 r
.55423 .40177 .56223 .40954 .5774 .40277 .56946 .39429 Mtetra
.696 .77 .908 r
.56946 .39429 .5774 .40277 .59267 .39682 .58478 .38793 Mtetra
.681 .757 .909 r
.58478 .38793 .59267 .39682 .60801 .39129 .60018 .38216 Mtetra
.673 .749 .908 r
.60018 .38216 .60801 .39129 .62345 .38597 .61567 .37668 Mtetra
.668 .746 .908 r
.61567 .37668 .62345 .38597 .63897 .38075 .63125 .37136 Mtetra
.666 .744 .908 r
.63125 .37136 .63897 .38075 .65458 .37557 .64692 .36609 Mtetra
.665 .742 .908 r
.64692 .36609 .65458 .37557 .67028 .37039 .66268 .36085 Mtetra
.664 .742 .908 r
.66268 .36085 .67028 .37039 .68606 .3652 .67853 .3556 Mtetra
.67853 .3556 .68606 .3652 .70194 .36 .69446 .35033 Mtetra
.664 .741 .908 r
.69446 .35033 .70194 .36 .7179 .35477 .71049 .34505 Mtetra
.71049 .34505 .7179 .35477 .73396 .34951 .72661 .33973 Mtetra
.72661 .33973 .73396 .34951 .75011 .34423 .74282 .33439 Mtetra
.74282 .33439 .75011 .34423 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.647 .763 .934 r
.25447 .68926 .26413 .69709 .27873 .69282 .26911 .68495 Mtetra
.26911 .68495 .27873 .69282 .29342 .68849 .28385 .6806 Mtetra
.649 .764 .933 r
.28385 .6806 .29342 .68849 .30819 .68407 .29867 .67617 Mtetra
.651 .766 .933 r
.29867 .67617 .30819 .68407 .32305 .6795 .31357 .67163 Mtetra
.656 .768 .932 r
.31357 .67163 .32305 .6795 .338 .67469 .32857 .6669 Mtetra
.664 .774 .931 r
.32857 .6669 .338 .67469 .35305 .66941 .34367 .66183 Mtetra
.68 .783 .928 r
.34367 .66183 .35305 .66941 .36822 .66331 .35887 .65614 Mtetra
.707 .8 .922 r
.35887 .65614 .36822 .66331 .38352 .65568 .3742 .64931 Mtetra
.752 .826 .91 r
.3742 .64931 .38352 .65568 .39897 .64538 .38968 .64046 Mtetra
.815 .861 .882 r
.38968 .64046 .39897 .64538 .41461 .6306 .40532 .62809 Mtetra
.887 .895 .83 r
.40532 .62809 .41461 .6306 .43042 .60909 .42115 .61012 Mtetra
.945 .915 .755 r
.42115 .61012 .43042 .60909 .44636 .5793 .43715 .58441 Mtetra
.974 .918 .676 r
.43715 .58441 .44636 .5793 .46229 .54245 .45322 .55052 Mtetra
.979 .916 .624 r
.45322 .55052 .46229 .54245 .47805 .50369 .4692 .51171 Mtetra
.975 .922 .621 r
.4692 .51171 .47805 .50369 .49354 .46937 .48493 .47432 Mtetra
.966 .937 .678 r
.48493 .47432 .49354 .46937 .5088 .44301 .5004 .44366 Mtetra
.936 .939 .772 r
.5004 .44366 .5088 .44301 .52394 .42433 .51569 .42123 Mtetra
.873 .906 .851 r
.51569 .42123 .52394 .42433 .53907 .41128 .53091 .40556 Mtetra
.799 .854 .891 r
.53091 .40556 .53907 .41128 .55423 .40177 .54615 .39442 Mtetra
.743 .809 .904 r
.54615 .39442 .55423 .40177 .56946 .39429 .56144 .386 Mtetra
.707 .779 .908 r
.56144 .386 .56946 .39429 .58478 .38793 .57682 .3791 Mtetra
.687 .762 .909 r
.57682 .3791 .58478 .38793 .60018 .38216 .59227 .37301 Mtetra
.676 .752 .908 r
.59227 .37301 .60018 .38216 .61567 .37668 .60782 .36734 Mtetra
.67 .747 .908 r
.60782 .36734 .61567 .37668 .63125 .37136 .62346 .36189 Mtetra
.667 .744 .908 r
.62346 .36189 .63125 .37136 .64692 .36609 .63919 .35653 Mtetra
.665 .743 .908 r
.63919 .35653 .64692 .36609 .66268 .36085 .655 .35121 Mtetra
.664 .742 .908 r
.655 .35121 .66268 .36085 .67853 .3556 .67091 .3459 Mtetra
.67091 .3459 .67853 .3556 .69446 .35033 .68691 .34057 Mtetra
.68691 .34057 .69446 .35033 .71049 .34505 .703 .33523 Mtetra
.664 .741 .908 r
.703 .33523 .71049 .34505 .72661 .33973 .71918 .32986 Mtetra
.71918 .32986 .72661 .33973 .74282 .33439 .73545 .32446 Mtetra
.73545 .32446 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .763 .934 r
.2447 .68135 .25447 .68926 .26911 .68495 .2594 .677 Mtetra
.647 .763 .934 r
.2594 .677 .26911 .68495 .28385 .6806 .27418 .67261 Mtetra
.648 .764 .933 r
.27418 .67261 .28385 .6806 .29867 .67617 .28904 .66817 Mtetra
.65 .765 .933 r
.28904 .66817 .29867 .67617 .31357 .67163 .304 .66364 Mtetra
.653 .767 .933 r
.304 .66364 .31357 .67163 .32857 .6669 .31904 .65895 Mtetra
.659 .771 .932 r
.31904 .65895 .32857 .6669 .34367 .66183 .33419 .65402 Mtetra
.671 .778 .93 r
.33419 .65402 .34367 .66183 .35887 .65614 .34943 .64862 Mtetra
.692 .791 .926 r
.34943 .64862 .35887 .65614 .3742 .64931 .3648 .64238 Mtetra
.727 .812 .917 r
.3648 .64238 .3742 .64931 .38968 .64046 .3803 .63461 Mtetra
.781 .843 .898 r
.3803 .63461 .38968 .64046 .40532 .62809 .39595 .62414 Mtetra
.851 .879 .86 r
.39595 .62414 .40532 .62809 .42115 .61012 .4118 .60917 Mtetra
.919 .908 .795 r
.4118 .60917 .42115 .61012 .43715 .58441 .42783 .58742 Mtetra
.963 .919 .714 r
.42783 .58742 .43715 .58441 .45322 .55052 .444 .55732 Mtetra
.979 .917 .645 r
.444 .55732 .45322 .55052 .4692 .51171 .46016 .52014 Mtetra
.978 .917 .615 r
.46016 .52014 .4692 .51171 .48493 .47432 .47614 .48102 Mtetra
.972 .929 .643 r
.47614 .48102 .48493 .47432 .5004 .44366 .49184 .4464 Mtetra
.955 .942 .723 r
.49184 .4464 .5004 .44366 .51569 .42123 .50731 .41978 Mtetra
.908 .927 .816 r
.50731 .41978 .51569 .42123 .53091 .40556 .52265 .40089 Mtetra
.835 .88 .875 r
.52265 .40089 .53091 .40556 .54615 .39442 .53797 .38767 Mtetra
.768 .83 .9 r
.53797 .38767 .54615 .39442 .56144 .386 .55334 .378 Mtetra
.723 .792 .907 r
.55334 .378 .56144 .386 .57682 .3791 .56877 .37037 Mtetra
.696 .769 .908 r
.56877 .37037 .57682 .3791 .59227 .37301 .58428 .36387 Mtetra
.681 .756 .909 r
.58428 .36387 .59227 .37301 .60782 .36734 .59989 .35796 Mtetra
.673 .749 .908 r
.59989 .35796 .60782 .36734 .62346 .36189 .61558 .35235 Mtetra
.668 .746 .908 r
.61558 .35235 .62346 .36189 .63919 .35653 .63137 .34688 Mtetra
.666 .744 .908 r
.63137 .34688 .63919 .35653 .655 .35121 .64725 .34148 Mtetra
.665 .742 .908 r
.64725 .34148 .655 .35121 .67091 .3459 .66321 .3361 Mtetra
.664 .742 .908 r
.66321 .3361 .67091 .3459 .68691 .34057 .67928 .33071 Mtetra
.67928 .33071 .68691 .34057 .703 .33523 .69543 .3253 Mtetra
.664 .741 .908 r
.69543 .3253 .703 .33523 .71918 .32986 .71167 .31987 Mtetra
.71167 .31987 .71918 .32986 .73545 .32446 .72801 .31442 Mtetra
.72801 .31442 .73545 .32446 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .763 .934 r
.23483 .67335 .2447 .68135 .2594 .677 .24958 .66896 Mtetra
.647 .763 .934 r
.24958 .66896 .2594 .677 .27418 .67261 .26441 .66454 Mtetra
.26441 .66454 .27418 .67261 .28904 .66817 .27932 .66007 Mtetra
.649 .764 .933 r
.27932 .66007 .28904 .66817 .304 .66364 .29433 .65552 Mtetra
.651 .766 .933 r
.29433 .65552 .304 .66364 .31904 .65895 .30942 .65087 Mtetra
.656 .768 .932 r
.30942 .65087 .31904 .65895 .33419 .65402 .32461 .64602 Mtetra
.664 .774 .931 r
.32461 .64602 .33419 .65402 .34943 .64862 .3399 .64082 Mtetra
.68 .783 .928 r
.3399 .64082 .34943 .64862 .3648 .64238 .3553 .635 Mtetra
.707 .8 .922 r
.3553 .635 .3648 .64238 .3803 .63461 .37083 .62803 Mtetra
.752 .826 .91 r
.37083 .62803 .3803 .63461 .39595 .62414 .38651 .61902 Mtetra
.815 .861 .882 r
.38651 .61902 .39595 .62414 .4118 .60917 .40237 .60648 Mtetra
.887 .896 .83 r
.40237 .60648 .4118 .60917 .42783 .58742 .41842 .58828 Mtetra
.945 .916 .755 r
.41842 .58828 .42783 .58742 .444 .55732 .43464 .5623 Mtetra
.974 .918 .676 r
.43464 .5623 .444 .55732 .46016 .52014 .45094 .52808 Mtetra
.979 .916 .624 r
.45094 .52808 .46016 .52014 .47614 .48102 .46715 .48892 Mtetra
.975 .922 .621 r
.46715 .48892 .47614 .48102 .49184 .4464 .4831 .45119 Mtetra
.966 .937 .678 r
.4831 .45119 .49184 .4464 .50731 .41978 .49879 .42025 Mtetra
.936 .939 .772 r
.49879 .42025 .50731 .41978 .52265 .40089 .51428 .39758 Mtetra
.872 .906 .851 r
.51428 .39758 .52265 .40089 .53797 .38767 .52971 .38172 Mtetra
.799 .854 .891 r
.52971 .38172 .53797 .38767 .55334 .378 .54514 .37042 Mtetra
.743 .809 .904 r
.54514 .37042 .55334 .378 .56877 .37037 .56064 .36184 Mtetra
.707 .779 .908 r
.56064 .36184 .56877 .37037 .58428 .36387 .57621 .35479 Mtetra
.687 .762 .909 r
.57621 .35479 .58428 .36387 .59989 .35796 .59187 .34856 Mtetra
.676 .752 .908 r
.59187 .34856 .59989 .35796 .61558 .35235 .60763 .34275 Mtetra
.67 .747 .908 r
.60763 .34275 .61558 .35235 .63137 .34688 .62347 .33716 Mtetra
.667 .744 .908 r
.62347 .33716 .63137 .34688 .64725 .34148 .63941 .33166 Mtetra
.665 .743 .908 r
.63941 .33166 .64725 .34148 .66321 .3361 .65544 .3262 Mtetra
.664 .742 .908 r
.65544 .3262 .66321 .3361 .67928 .33071 .67156 .32074 Mtetra
.67156 .32074 .67928 .33071 .69543 .3253 .68778 .31527 Mtetra
.68778 .31527 .69543 .3253 .71167 .31987 .70409 .30978 Mtetra
.664 .741 .908 r
.70409 .30978 .71167 .31987 .72801 .31442 .72049 .30427 Mtetra
.72049 .30427 .72801 .31442 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29314 Mtetra
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28754 Mtetra
.77027 .28754 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.646 .763 .934 r
.22486 .66526 .23483 .67335 .24958 .66896 .23966 .66084 Mtetra
.23966 .66084 .24958 .66896 .26441 .66454 .25454 .65637 Mtetra
.647 .763 .934 r
.25454 .65637 .26441 .66454 .27932 .66007 .2695 .65187 Mtetra
.648 .764 .933 r
.2695 .65187 .27932 .66007 .29433 .65552 .28455 .64731 Mtetra
.65 .765 .933 r
.28455 .64731 .29433 .65552 .30942 .65087 .2997 .64265 Mtetra
.653 .767 .933 r
.2997 .64265 .30942 .65087 .32461 .64602 .31494 .63785 Mtetra
.659 .771 .932 r
.31494 .63785 .32461 .64602 .3399 .64082 .33027 .63279 Mtetra
.671 .778 .93 r
.33027 .63279 .3399 .64082 .3553 .635 .34572 .62726 Mtetra
.692 .791 .926 r
.34572 .62726 .3553 .635 .37083 .62803 .36128 .62088 Mtetra
.727 .812 .917 r
.36128 .62088 .37083 .62803 .38651 .61902 .37698 .61297 Mtetra
.781 .843 .898 r
.37698 .61297 .38651 .61902 .40237 .60648 .39285 .60233 Mtetra
.851 .879 .86 r
.39285 .60233 .40237 .60648 .41842 .58828 .40891 .58715 Mtetra
.919 .908 .795 r
.40891 .58715 .41842 .58828 .43464 .5623 .42517 .56515 Mtetra
.963 .919 .714 r
.42517 .56515 .43464 .5623 .45094 .52808 .44157 .53475 Mtetra
.979 .917 .645 r
.44157 .53475 .45094 .52808 .46715 .48892 .45796 .49722 Mtetra
.978 .917 .615 r
.45796 .49722 .46715 .48892 .4831 .45119 .47417 .45776 Mtetra
.972 .929 .643 r
.47417 .45776 .4831 .45119 .49879 .42025 .4901 .42282 Mtetra
.955 .941 .724 r
.4901 .42282 .49879 .42025 .51428 .39758 .50578 .39593 Mtetra
.908 .927 .816 r
.50578 .39593 .51428 .39758 .52971 .38172 .52133 .37683 Mtetra
.835 .88 .875 r
.52133 .37683 .52971 .38172 .54514 .37042 .53685 .36343 Mtetra
.768 .83 .9 r
.53685 .36343 .54514 .37042 .56064 .36184 .55242 .35359 Mtetra
.723 .792 .907 r
.55242 .35359 .56064 .36184 .57621 .35479 .56805 .34582 Mtetra
.696 .769 .908 r
.56805 .34582 .57621 .35479 .59187 .34856 .58377 .33917 Mtetra
.681 .756 .909 r
.58377 .33917 .59187 .34856 .60763 .34275 .59959 .33312 Mtetra
.673 .749 .908 r
.59959 .33312 .60763 .34275 .62347 .33716 .61549 .32736 Mtetra
.668 .746 .908 r
.61549 .32736 .62347 .33716 .63941 .33166 .63149 .32175 Mtetra
.666 .744 .908 r
.63149 .32175 .63941 .33166 .65544 .3262 .64758 .31621 Mtetra
.665 .742 .908 r
.64758 .31621 .65544 .3262 .67156 .32074 .66376 .31068 Mtetra
.664 .742 .908 r
.66376 .31068 .67156 .32074 .68778 .31527 .68004 .30514 Mtetra
.68004 .30514 .68778 .31527 .70409 .30978 .69642 .29959 Mtetra
.664 .741 .908 r
.69642 .29959 .70409 .30978 .72049 .30427 .71289 .29401 Mtetra
.71289 .29401 .72049 .30427 .73699 .29872 .72945 .2884 Mtetra
.72945 .2884 .73699 .29872 .75358 .29314 .74611 .28277 Mtetra
.74611 .28277 .75358 .29314 .77027 .28754 .76287 .2771 Mtetra
.76287 .2771 .77027 .28754 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .763 .934 r
.21479 .65709 .22486 .66526 .23966 .66084 .22963 .65262 Mtetra
.22963 .65262 .23966 .66084 .25454 .65637 .24456 .64812 Mtetra
.647 .763 .934 r
.24456 .64812 .25454 .65637 .2695 .65187 .25957 .64358 Mtetra
.25957 .64358 .2695 .65187 .28455 .64731 .27468 .63898 Mtetra
.649 .764 .933 r
.27468 .63898 .28455 .64731 .2997 .64265 .28987 .63432 Mtetra
.651 .766 .933 r
.28987 .63432 .2997 .64265 .31494 .63785 .30516 .62954 Mtetra
.656 .768 .932 r
.30516 .62954 .31494 .63785 .33027 .63279 .32054 .62456 Mtetra
.664 .774 .931 r
.32054 .62456 .33027 .63279 .34572 .62726 .33603 .61923 Mtetra
.68 .783 .928 r
.33603 .61923 .34572 .62726 .36128 .62088 .35163 .61328 Mtetra
.707 .8 .922 r
.35163 .61328 .36128 .62088 .37698 .61297 .36737 .60617 Mtetra
.752 .826 .91 r
.36737 .60617 .37698 .61297 .39285 .60233 .38326 .597 Mtetra
.815 .861 .882 r
.38326 .597 .39285 .60233 .40891 .58715 .39933 .58427 Mtetra
.887 .896 .83 r
.39933 .58427 .40891 .58715 .42517 .56515 .4156 .56584 Mtetra
.945 .916 .754 r
.4156 .56584 .42517 .56515 .44157 .53475 .43206 .53958 Mtetra
.974 .918 .676 r
.43206 .53958 .44157 .53475 .45796 .49722 .4486 .50503 Mtetra
.979 .916 .624 r
.4486 .50503 .45796 .49722 .47417 .45776 .46504 .46551 Mtetra
.975 .922 .622 r
.46504 .46551 .47417 .45776 .4901 .42282 .48123 .42745 Mtetra
.966 .937 .678 r
.48123 .42745 .4901 .42282 .50578 .39593 .49713 .39622 Mtetra
.936 .939 .772 r
.49713 .39622 .50578 .39593 .52133 .37683 .51284 .37331 Mtetra
.872 .906 .851 r
.51284 .37331 .52133 .37683 .53685 .36343 .52847 .35724 Mtetra
.799 .854 .891 r
.52847 .35724 .53685 .36343 .55242 .35359 .54411 .34577 Mtetra
.743 .809 .904 r
.54411 .34577 .55242 .35359 .56805 .34582 .55981 .33704 Mtetra
.707 .779 .908 r
.55981 .33704 .56805 .34582 .58377 .33917 .57559 .32983 Mtetra
.687 .762 .909 r
.57559 .32983 .58377 .33917 .59959 .33312 .59146 .32346 Mtetra
.676 .752 .908 r
.59146 .32346 .59959 .33312 .61549 .32736 .60742 .3175 Mtetra
.67 .747 .908 r
.60742 .3175 .61549 .32736 .63149 .32175 .62348 .31176 Mtetra
.667 .744 .908 r
.62348 .31176 .63149 .32175 .64758 .31621 .63964 .30612 Mtetra
.665 .743 .908 r
.63964 .30612 .64758 .31621 .66376 .31068 .65588 .30051 Mtetra
.664 .742 .908 r
.65588 .30051 .66376 .31068 .68004 .30514 .67223 .29491 Mtetra
.67223 .29491 .68004 .30514 .69642 .29959 .68867 .28929 Mtetra
.68867 .28929 .69642 .29959 .71289 .29401 .7052 .28365 Mtetra
.664 .741 .908 r
.7052 .28365 .71289 .29401 .72945 .2884 .72183 .27798 Mtetra
.72183 .27798 .72945 .2884 .74611 .28277 .73856 .27228 Mtetra
.73856 .27228 .74611 .28277 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64883 .21479 .65709 .22963 .65262 .2195 .64432 Mtetra
.646 .763 .934 r
.2195 .64432 .22963 .65262 .24456 .64812 .23448 .63977 Mtetra
.23448 .63977 .24456 .64812 .25957 .64358 .24954 .63519 Mtetra
.647 .763 .934 r
.24954 .63519 .25957 .64358 .27468 .63898 .2647 .63056 Mtetra
.648 .764 .933 r
.2647 .63056 .27468 .63898 .28987 .63432 .27994 .62587 Mtetra
.65 .765 .933 r
.27994 .62587 .28987 .63432 .30516 .62954 .29528 .62109 Mtetra
.653 .767 .933 r
.29528 .62109 .30516 .62954 .32054 .62456 .31071 .61616 Mtetra
.659 .771 .932 r
.31071 .61616 .32054 .62456 .33603 .61923 .32625 .61097 Mtetra
.671 .778 .93 r
.32625 .61097 .33603 .61923 .35163 .61328 .34189 .60531 Mtetra
.692 .791 .926 r
.34189 .60531 .35163 .61328 .36737 .60617 .35766 .59879 Mtetra
.727 .812 .917 r
.35766 .59879 .36737 .60617 .38326 .597 .37358 .59072 Mtetra
.781 .843 .898 r
.37358 .59072 .38326 .597 .39933 .58427 .38966 .57991 Mtetra
.851 .88 .86 r
.38966 .57991 .39933 .58427 .4156 .56584 .40595 .56452 Mtetra
.919 .908 .794 r
.40595 .56452 .4156 .56584 .43206 .53958 .42244 .54227 Mtetra
.963 .919 .713 r
.42244 .54227 .43206 .53958 .4486 .50503 .43907 .51156 Mtetra
.979 .917 .645 r
.43907 .51156 .4486 .50503 .46504 .46551 .45571 .47367 Mtetra
.978 .917 .616 r
.45571 .47367 .46504 .46551 .48123 .42745 .47216 .43385 Mtetra
.972 .929 .643 r
.47216 .43385 .48123 .42745 .49713 .39622 .48831 .3986 Mtetra
.955 .941 .724 r
.48831 .3986 .49713 .39622 .51284 .37331 .50421 .37145 Mtetra
.908 .926 .816 r
.50421 .37145 .51284 .37331 .52847 .35724 .51997 .35213 Mtetra
.835 .88 .875 r
.51997 .35213 .52847 .35724 .54411 .34577 .5357 .33854 Mtetra
.768 .829 .9 r
.5357 .33854 .54411 .34577 .55981 .33704 .55147 .32854 Mtetra
.723 .792 .907 r
.55147 .32854 .55981 .33704 .57559 .32983 .56732 .32061 Mtetra
.696 .769 .908 r
.56732 .32061 .57559 .32983 .59146 .32346 .58325 .3138 Mtetra
.681 .756 .909 r
.58325 .3138 .59146 .32346 .60742 .3175 .59927 .3076 Mtetra
.673 .749 .908 r
.59927 .3076 .60742 .3175 .62348 .31176 .61539 .3017 Mtetra
.668 .746 .908 r
.61539 .3017 .62348 .31176 .63964 .30612 .63161 .29594 Mtetra
.666 .744 .908 r
.63161 .29594 .63964 .30612 .65588 .30051 .64792 .29024 Mtetra
.665 .742 .908 r
.64792 .29024 .65588 .30051 .67223 .29491 .66433 .28456 Mtetra
.664 .742 .908 r
.66433 .28456 .67223 .29491 .68867 .28929 .68083 .27887 Mtetra
.68083 .27887 .68867 .28929 .7052 .28365 .69743 .27317 Mtetra
.664 .741 .908 r
.69743 .27317 .7052 .28365 .72183 .27798 .71413 .26744 Mtetra
.71413 .26744 .72183 .27798 .73856 .27228 .73093 .26167 Mtetra
.73093 .26167 .73856 .27228 .75539 .26654 .74783 .25588 Mtetra
.74783 .25588 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24419 Mtetra
.78193 .24419 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64883 .2195 .64432 .20925 .63593 Mtetra
.646 .763 .934 r
.20925 .63593 .2195 .64432 .23448 .63977 .22428 .63133 Mtetra
.22428 .63133 .23448 .63977 .24954 .63519 .2394 .62671 Mtetra
.647 .763 .934 r
.2394 .62671 .24954 .63519 .2647 .63056 .25461 .62204 Mtetra
.25461 .62204 .2647 .63056 .27994 .62587 .2699 .61732 Mtetra
.649 .764 .933 r
.2699 .61732 .27994 .62587 .29528 .62109 .28529 .61253 Mtetra
.651 .766 .933 r
.28529 .61253 .29528 .62109 .31071 .61616 .30078 .60762 Mtetra
.656 .768 .932 r
.30078 .60762 .31071 .61616 .32625 .61097 .31636 .60251 Mtetra
.664 .774 .931 r
.31636 .60251 .32625 .61097 .34189 .60531 .33205 .59705 Mtetra
.68 .783 .928 r
.33205 .59705 .34189 .60531 .35766 .59879 .34787 .59095 Mtetra
.707 .8 .923 r
.34787 .59095 .35766 .59879 .37358 .59072 .36381 .5837 Mtetra
.752 .826 .91 r
.36381 .5837 .37358 .59072 .38966 .57991 .37992 .57436 Mtetra
.815 .861 .882 r
.37992 .57436 .38966 .57991 .40595 .56452 .39621 .56143 Mtetra
.887 .896 .83 r
.39621 .56143 .40595 .56452 .42244 .54227 .41271 .54278 Mtetra
.945 .916 .754 r
.41271 .54278 .42244 .54227 .43907 .51156 .42941 .51623 Mtetra
.974 .919 .676 r
.42941 .51623 .43907 .51156 .45571 .47367 .44619 .48134 Mtetra
.979 .916 .624 r
.44619 .48134 .45571 .47367 .47216 .43385 .46288 .44146 Mtetra
.975 .922 .622 r
.46288 .44146 .47216 .43385 .48831 .3986 .4793 .40305 Mtetra
.966 .937 .679 r
.4793 .40305 .48831 .3986 .50421 .37145 .49543 .37153 Mtetra
.936 .938 .772 r
.49543 .37153 .50421 .37145 .51997 .35213 .51135 .34837 Mtetra
.872 .906 .851 r
.51135 .34837 .51997 .35213 .5357 .33854 .5272 .33211 Mtetra
.799 .854 .891 r
.5272 .33211 .5357 .33854 .55147 .32854 .54305 .32046 Mtetra
.743 .809 .904 r
.54305 .32046 .55147 .32854 .56732 .32061 .55896 .31156 Mtetra
.707 .779 .908 r
.55896 .31156 .56732 .32061 .58325 .3138 .57495 .3042 Mtetra
.687 .762 .909 r
.57495 .3042 .58325 .3138 .59927 .3076 .59104 .29767 Mtetra
.676 .752 .908 r
.59104 .29767 .59927 .3076 .61539 .3017 .60722 .29156 Mtetra
.67 .747 .908 r
.60722 .29156 .61539 .3017 .63161 .29594 .6235 .28567 Mtetra
.667 .744 .908 r
.6235 .28567 .63161 .29594 .64792 .29024 .63987 .27987 Mtetra
.665 .743 .908 r
.63987 .27987 .64792 .29024 .66433 .28456 .65634 .27411 Mtetra
.664 .742 .908 r
.65634 .27411 .66433 .28456 .68083 .27887 .67291 .26835 Mtetra
.67291 .26835 .68083 .27887 .69743 .27317 .68958 .26258 Mtetra
.68958 .26258 .69743 .27317 .71413 .26744 .70635 .25678 Mtetra
.664 .741 .908 r
.70635 .25678 .71413 .26744 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25588 .74019 .24509 Mtetra
.74019 .24509 .74783 .25588 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24419 .77443 .23327 Mtetra
.77443 .23327 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.646 .762 .934 r
.18391 .63205 .19431 .64049 .20925 .63593 .1989 .62744 Mtetra
.1989 .62744 .20925 .63593 .22428 .63133 .21398 .6228 Mtetra
.646 .763 .934 r
.21398 .6228 .22428 .63133 .2394 .62671 .22915 .61813 Mtetra
.22915 .61813 .2394 .62671 .25461 .62204 .24441 .61342 Mtetra
.647 .763 .934 r
.24441 .61342 .25461 .62204 .2699 .61732 .25976 .60866 Mtetra
.648 .764 .933 r
.25976 .60866 .2699 .61732 .28529 .61253 .2752 .60385 Mtetra
.65 .765 .933 r
.2752 .60385 .28529 .61253 .30078 .60762 .29074 .59894 Mtetra
.653 .767 .933 r
.29074 .59894 .30078 .60762 .31636 .60251 .30637 .59387 Mtetra
.659 .771 .932 r
.30637 .59387 .31636 .60251 .33205 .59705 .32211 .58855 Mtetra
.671 .778 .93 r
.32211 .58855 .33205 .59705 .34787 .59095 .33797 .58274 Mtetra
.692 .791 .926 r
.33797 .58274 .34787 .59095 .36381 .5837 .35395 .57608 Mtetra
.727 .812 .917 r
.35395 .57608 .36381 .5837 .37992 .57436 .37008 .56785 Mtetra
.781 .843 .899 r
.37008 .56785 .37992 .57436 .39621 .56143 .38639 .55686 Mtetra
.851 .88 .86 r
.38639 .55686 .39621 .56143 .41271 .54278 .4029 .54126 Mtetra
.919 .909 .794 r
.4029 .54126 .41271 .54278 .42941 .51623 .41963 .51874 Mtetra
.963 .919 .713 r
.41963 .51874 .42941 .51623 .44619 .48134 .43651 .48772 Mtetra
.979 .917 .645 r
.43651 .48772 .44619 .48134 .46288 .44146 .4534 .44947 Mtetra
.978 .917 .616 r
.4534 .44947 .46288 .44146 .4793 .40305 .47009 .40929 Mtetra
.972 .929 .643 r
.47009 .40929 .4793 .40305 .49543 .37153 .48648 .37371 Mtetra
.955 .941 .724 r
.48648 .37371 .49543 .37153 .51135 .34837 .5026 .34629 Mtetra
.907 .926 .816 r
.5026 .34629 .51135 .34837 .5272 .33211 .51858 .32675 Mtetra
.835 .88 .875 r
.51858 .32675 .5272 .33211 .54305 .32046 .53452 .31297 Mtetra
.768 .829 .899 r
.53452 .31297 .54305 .32046 .55896 .31156 .55051 .30279 Mtetra
.723 .792 .907 r
.55051 .30279 .55896 .31156 .57495 .3042 .56656 .2947 Mtetra
.696 .769 .908 r
.56656 .2947 .57495 .3042 .59104 .29767 .58271 .28774 Mtetra
.681 .756 .909 r
.58271 .28774 .59104 .29767 .60722 .29156 .59895 .28138 Mtetra
.673 .749 .908 r
.59895 .28138 .60722 .29156 .6235 .28567 .6153 .27532 Mtetra
.668 .746 .908 r
.6153 .27532 .6235 .28567 .63987 .27987 .63173 .26941 Mtetra
.666 .744 .908 r
.63173 .26941 .63987 .27987 .65634 .27411 .64827 .26356 Mtetra
.665 .742 .908 r
.64827 .26356 .65634 .27411 .67291 .26835 .66491 .25772 Mtetra
.664 .742 .908 r
.66491 .25772 .67291 .26835 .68958 .26258 .68164 .25188 Mtetra
.68164 .25188 .68958 .26258 .70635 .25678 .69848 .24601 Mtetra
.664 .741 .908 r
.69848 .24601 .70635 .25678 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23419 Mtetra
.73246 .23419 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22224 Mtetra
.76684 .22224 .77443 .23327 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62352 .18391 .63205 .1989 .62744 .18844 .61886 Mtetra
.18844 .61886 .1989 .62744 .21398 .6228 .20357 .61418 Mtetra
.646 .763 .934 r
.20357 .61418 .21398 .6228 .22915 .61813 .21879 .60946 Mtetra
.21879 .60946 .22915 .61813 .24441 .61342 .2341 .6047 Mtetra
.647 .763 .934 r
.2341 .6047 .24441 .61342 .25976 .60866 .2495 .5999 Mtetra
.2495 .5999 .25976 .60866 .2752 .60385 .265 .59506 Mtetra
.649 .764 .933 r
.265 .59506 .2752 .60385 .29074 .59894 .28059 .59013 Mtetra
.651 .766 .933 r
.28059 .59013 .29074 .59894 .30637 .59387 .29628 .58509 Mtetra
.656 .768 .932 r
.29628 .58509 .30637 .59387 .32211 .58855 .31207 .57984 Mtetra
.664 .774 .931 r
.31207 .57984 .32211 .58855 .33797 .58274 .32797 .57424 Mtetra
.68 .783 .928 r
.32797 .57424 .33797 .58274 .35395 .57608 .34399 .568 Mtetra
.707 .8 .923 r
.34399 .568 .35395 .57608 .37008 .56785 .36015 .56058 Mtetra
.752 .826 .91 r
.36015 .56058 .37008 .56785 .38639 .55686 .37648 .55108 Mtetra
.815 .862 .882 r
.37648 .55108 .38639 .55686 .4029 .54126 .393 .53795 Mtetra
.887 .896 .83 r
.393 .53795 .4029 .54126 .41963 .51874 .40974 .51906 Mtetra
.945 .916 .754 r
.40974 .51906 .41963 .51874 .43651 .48772 .42668 .49222 Mtetra
.974 .919 .675 r
.42668 .49222 .43651 .48772 .4534 .44947 .44372 .45699 Mtetra
.979 .916 .624 r
.44372 .45699 .4534 .44947 .47009 .40929 .46066 .41674 Mtetra
.975 .922 .622 r
.46066 .41674 .47009 .40929 .48648 .37371 .47732 .37798 Mtetra
.966 .936 .679 r
.47732 .37798 .48648 .37371 .5026 .34629 .49368 .34616 Mtetra
.936 .938 .772 r
.49368 .34616 .5026 .34629 .51858 .32675 .50983 .32276 Mtetra
.872 .905 .851 r
.50983 .32276 .51858 .32675 .53452 .31297 .52589 .30628 Mtetra
.799 .853 .891 r
.52589 .30628 .53452 .31297 .55051 .30279 .54196 .29445 Mtetra
.743 .809 .904 r
.54196 .29445 .55051 .30279 .56656 .2947 .55809 .28538 Mtetra
.707 .779 .908 r
.55809 .28538 .56656 .2947 .58271 .28774 .5743 .27786 Mtetra
.687 .762 .909 r
.5743 .27786 .58271 .28774 .59895 .28138 .5906 .27117 Mtetra
.676 .752 .908 r
.5906 .27117 .59895 .28138 .6153 .27532 .60701 .26491 Mtetra
.67 .747 .908 r
.60701 .26491 .6153 .27532 .63173 .26941 .62351 .25886 Mtetra
.667 .744 .908 r
.62351 .25886 .63173 .26941 .64827 .26356 .64011 .2529 Mtetra
.665 .743 .908 r
.64011 .2529 .64827 .26356 .66491 .25772 .65681 .24698 Mtetra
.665 .742 .908 r
.65681 .24698 .66491 .25772 .68164 .25188 .67362 .24106 Mtetra
.664 .742 .908 r
.67362 .24106 .68164 .25188 .69848 .24601 .69052 .23512 Mtetra
.69052 .23512 .69848 .24601 .71542 .24011 .70753 .22916 Mtetra
.664 .741 .908 r
.70753 .22916 .71542 .24011 .73246 .23419 .72464 .22316 Mtetra
.72464 .22316 .73246 .23419 .7496 .22823 .74185 .21714 Mtetra
.74185 .21714 .7496 .22823 .76684 .22224 .75917 .21108 Mtetra
.75917 .21108 .76684 .22224 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62352 .18844 .61886 .17787 .6102 Mtetra
.17787 .6102 .18844 .61886 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60946 .20832 .60069 Mtetra
.646 .763 .934 r
.20832 .60069 .21879 .60946 .2341 .6047 .22368 .59588 Mtetra
.22368 .59588 .2341 .6047 .2495 .5999 .23914 .59104 Mtetra
.647 .763 .934 r
.23914 .59104 .2495 .5999 .265 .59506 .25468 .58616 Mtetra
.648 .764 .933 r
.25468 .58616 .265 .59506 .28059 .59013 .27033 .5812 Mtetra
.65 .765 .933 r
.27033 .5812 .28059 .59013 .29628 .58509 .28607 .57616 Mtetra
.653 .767 .933 r
.28607 .57616 .29628 .58509 .31207 .57984 .30191 .57096 Mtetra
.659 .771 .932 r
.30191 .57096 .31207 .57984 .32797 .57424 .31786 .56549 Mtetra
.671 .778 .93 r
.31786 .56549 .32797 .57424 .34399 .568 .33393 .55954 Mtetra
.692 .791 .926 r
.33393 .55954 .34399 .568 .36015 .56058 .35013 .55272 Mtetra
.727 .812 .917 r
.35013 .55272 .36015 .56058 .37648 .55108 .36648 .54433 Mtetra
.781 .843 .899 r
.36648 .54433 .37648 .55108 .393 .53795 .38302 .53315 Mtetra
.851 .88 .86 r
.38302 .53315 .393 .53795 .40974 .51906 .39977 .51733 Mtetra
.92 .909 .794 r
.39977 .51733 .40974 .51906 .42668 .49222 .41674 .49455 Mtetra
.963 .919 .713 r
.41674 .49455 .42668 .49222 .44372 .45699 .43387 .4632 Mtetra
.979 .917 .644 r
.43387 .4632 .44372 .45699 .46066 .41674 .45102 .42459 Mtetra
.978 .917 .616 r
.45102 .42459 .46066 .41674 .47732 .37798 .46796 .38405 Mtetra
.972 .929 .644 r
.46796 .38405 .47732 .37798 .49368 .34616 .48459 .34814 Mtetra
.955 .941 .724 r
.48459 .34814 .49368 .34616 .50983 .32276 .50094 .32045 Mtetra
.907 .926 .816 r
.50094 .32045 .50983 .32276 .52589 .30628 .51714 .30067 Mtetra
.835 .88 .875 r
.51714 .30067 .52589 .30628 .54196 .29445 .53331 .28669 Mtetra
.768 .829 .899 r
.53331 .28669 .54196 .29445 .55809 .28538 .54951 .27634 Mtetra
.723 .792 .907 r
.54951 .27634 .55809 .28538 .5743 .27786 .56579 .26808 Mtetra
.696 .769 .908 r
.56579 .26808 .5743 .27786 .5906 .27117 .58216 .26096 Mtetra
.681 .756 .908 r
.58216 .26096 .5906 .27117 .60701 .26491 .59863 .25444 Mtetra
.673 .749 .908 r
.59863 .25444 .60701 .26491 .62351 .25886 .61519 .24822 Mtetra
.668 .746 .908 r
.61519 .24822 .62351 .25886 .64011 .2529 .63186 .24214 Mtetra
.666 .744 .908 r
.63186 .24214 .64011 .2529 .65681 .24698 .64863 .23613 Mtetra
.665 .742 .908 r
.64863 .23613 .65681 .24698 .67362 .24106 .6655 .23013 Mtetra
.664 .742 .908 r
.6655 .23013 .67362 .24106 .69052 .23512 .68248 .22411 Mtetra
.68248 .22411 .69052 .23512 .70753 .22916 .69956 .21808 Mtetra
.664 .741 .908 r
.69956 .21808 .70753 .22916 .72464 .22316 .71674 .21202 Mtetra
.71674 .21202 .72464 .22316 .74185 .21714 .73402 .20592 Mtetra
.73402 .20592 .74185 .21714 .75917 .21108 .75141 .19979 Mtetra
.75141 .19979 .75917 .21108 .77659 .20498 .76891 .19363 Mtetra
.76891 .19363 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .60069 .19773 .59182 Mtetra
.646 .763 .934 r
.19773 .59182 .20832 .60069 .22368 .59588 .21315 .58697 Mtetra
.21315 .58697 .22368 .59588 .23914 .59104 .22865 .58208 Mtetra
.647 .763 .934 r
.22865 .58208 .23914 .59104 .25468 .58616 .24426 .57715 Mtetra
.24426 .57715 .25468 .58616 .27033 .5812 .25995 .57216 Mtetra
.649 .764 .933 r
.25995 .57216 .27033 .5812 .28607 .57616 .27575 .5671 Mtetra
.651 .766 .933 r
.27575 .5671 .28607 .57616 .30191 .57096 .29164 .56191 Mtetra
.656 .768 .932 r
.29164 .56191 .30191 .57096 .31786 .56549 .30765 .55653 Mtetra
.664 .774 .931 r
.30765 .55653 .31786 .56549 .33393 .55954 .32376 .55078 Mtetra
.68 .783 .928 r
.32376 .55078 .33393 .55954 .35013 .55272 .34 .54438 Mtetra
.707 .8 .923 r
.34 .54438 .35013 .55272 .36648 .54433 .35639 .53681 Mtetra
.752 .827 .91 r
.35639 .53681 .36648 .54433 .38302 .53315 .37294 .52713 Mtetra
.815 .862 .882 r
.37294 .52713 .38302 .53315 .39977 .51733 .3897 .5138 Mtetra
.887 .897 .83 r
.3897 .5138 .39977 .51733 .41674 .49455 .40669 .49466 Mtetra
.945 .917 .754 r
.40669 .49466 .41674 .49455 .43387 .4632 .42388 .46752 Mtetra
.974 .919 .675 r
.42388 .46752 .43387 .4632 .45102 .42459 .44118 .43194 Mtetra
.979 .916 .624 r
.44118 .43194 .45102 .42459 .46796 .38405 .45837 .39133 Mtetra
.975 .922 .622 r
.45837 .39133 .46796 .38405 .48459 .34814 .47529 .35221 Mtetra
.966 .936 .679 r
.47529 .35221 .48459 .34814 .50094 .32045 .49189 .32008 Mtetra
.936 .938 .772 r
.49189 .32008 .50094 .32045 .51714 .30067 .50826 .29643 Mtetra
.872 .905 .851 r
.50826 .29643 .51714 .30067 .53331 .28669 .52455 .27974 Mtetra
.799 .853 .89 r
.52455 .27974 .53331 .28669 .54951 .27634 .54084 .26772 Mtetra
.743 .809 .904 r
.54084 .26772 .54951 .27634 .56579 .26808 .55719 .25848 Mtetra
.707 .779 .908 r
.55719 .25848 .56579 .26808 .58216 .26096 .57362 .25079 Mtetra
.687 .762 .909 r
.57362 .25079 .58216 .26096 .59863 .25444 .59015 .24393 Mtetra
.676 .752 .908 r
.59015 .24393 .59863 .25444 .61519 .24822 .60679 .2375 Mtetra
.67 .747 .908 r
.60679 .2375 .61519 .24822 .63186 .24214 .62352 .23129 Mtetra
.667 .744 .908 r
.62352 .23129 .63186 .24214 .64863 .23613 .64036 .22517 Mtetra
.665 .743 .908 r
.64036 .22517 .64863 .23613 .6655 .23013 .6573 .21908 Mtetra
.665 .742 .908 r
.6573 .21908 .6655 .23013 .68248 .22411 .67434 .21299 Mtetra
.664 .742 .908 r
.67434 .21299 .68248 .22411 .69956 .21808 .69149 .20688 Mtetra
.69149 .20688 .69956 .21808 .71674 .21202 .70874 .20075 Mtetra
.664 .741 .908 r
.70874 .20075 .71674 .21202 .73402 .20592 .7261 .19458 Mtetra
.7261 .19458 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19363 .76114 .18214 Mtetra
.76114 .18214 .76891 .19363 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59182 .18703 .58285 Mtetra
.18703 .58285 .19773 .59182 .21315 .58697 .20249 .57795 Mtetra
.646 .763 .934 r
.20249 .57795 .21315 .58697 .22865 .58208 .21806 .57301 Mtetra
.21806 .57301 .22865 .58208 .24426 .57715 .23371 .56803 Mtetra
.647 .763 .934 r
.23371 .56803 .24426 .57715 .25995 .57216 .24946 .56301 Mtetra
.648 .764 .933 r
.24946 .56301 .25995 .57216 .27575 .5671 .26531 .55792 Mtetra
.65 .765 .933 r
.26531 .55792 .27575 .5671 .29164 .56191 .28127 .55273 Mtetra
.653 .767 .933 r
.28127 .55273 .29164 .56191 .30765 .55653 .29732 .54738 Mtetra
.659 .771 .932 r
.29732 .54738 .30765 .55653 .32376 .55078 .31349 .54177 Mtetra
.671 .778 .93 r
.31349 .54177 .32376 .55078 .34 .54438 .32977 .53567 Mtetra
.692 .791 .926 r
.32977 .53567 .34 .54438 .35639 .53681 .34619 .52869 Mtetra
.727 .812 .918 r
.34619 .52869 .35639 .53681 .37294 .52713 .36278 .52012 Mtetra
.781 .843 .899 r
.36278 .52012 .37294 .52713 .3897 .5138 .37955 .50876 Mtetra
.851 .88 .86 r
.37955 .50876 .3897 .5138 .40669 .49466 .39654 .49271 Mtetra
.92 .909 .794 r
.39654 .49271 .40669 .49466 .42388 .46752 .41376 .46966 Mtetra
.963 .919 .713 r
.41376 .46966 .42388 .46752 .44118 .43194 .43116 .43798 Mtetra
.979 .917 .644 r
.43116 .43798 .44118 .43194 .45837 .39133 .44857 .399 Mtetra
.978 .917 .616 r
.44857 .399 .45837 .39133 .47529 .35221 .46577 .35809 Mtetra
.972 .929 .644 r
.46577 .35809 .47529 .35221 .49189 .32008 .48265 .32185 Mtetra
.955 .941 .724 r
.48265 .32185 .49189 .32008 .50826 .29643 .49924 .29387 Mtetra
.907 .926 .816 r
.49924 .29387 .50826 .29643 .52455 .27974 .51567 .27387 Mtetra
.835 .879 .875 r
.51567 .27387 .52455 .27974 .54084 .26772 .53206 .25968 Mtetra
.768 .829 .899 r
.53206 .25968 .54084 .26772 .55719 .25848 .54849 .24915 Mtetra
.723 .792 .907 r
.54849 .24915 .55719 .25848 .57362 .25079 .56499 .24071 Mtetra
.696 .769 .908 r
.56499 .24071 .57362 .25079 .59015 .24393 .58159 .23342 Mtetra
.681 .756 .908 r
.58159 .23342 .59015 .24393 .60679 .2375 .59829 .22673 Mtetra
.673 .749 .908 r
.59829 .22673 .60679 .2375 .62352 .23129 .61509 .22034 Mtetra
.668 .746 .908 r
.61509 .22034 .62352 .23129 .64036 .22517 .63199 .2141 Mtetra
.666 .744 .908 r
.63199 .2141 .64036 .22517 .6573 .21908 .649 .20791 Mtetra
.665 .742 .908 r
.649 .20791 .6573 .21908 .67434 .21299 .66612 .20174 Mtetra
.664 .742 .908 r
.66612 .20174 .67434 .21299 .69149 .20688 .68334 .19556 Mtetra
.68334 .19556 .69149 .20688 .70874 .20075 .70066 .18935 Mtetra
.664 .741 .908 r
.70066 .18935 .70874 .20075 .7261 .19458 .71809 .18311 Mtetra
.71809 .18311 .7261 .19458 .74357 .18838 .73563 .17684 Mtetra
.73563 .17684 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58285 .1762 .57379 Mtetra
.1762 .57379 .18703 .58285 .20249 .57795 .19172 .56883 Mtetra
.646 .763 .934 r
.19172 .56883 .20249 .57795 .21806 .57301 .20734 .56384 Mtetra
.20734 .56384 .21806 .57301 .23371 .56803 .22305 .55881 Mtetra
.647 .763 .934 r
.22305 .55881 .23371 .56803 .24946 .56301 .23886 .55374 Mtetra
.23886 .55374 .24946 .56301 .26531 .55792 .25476 .54861 Mtetra
.649 .764 .933 r
.25476 .54861 .26531 .55792 .28127 .55273 .27077 .54341 Mtetra
.651 .766 .933 r
.27077 .54341 .28127 .55273 .29732 .54738 .28688 .53807 Mtetra
.656 .768 .932 r
.28688 .53807 .29732 .54738 .31349 .54177 .3031 .53254 Mtetra
.664 .774 .931 r
.3031 .53254 .31349 .54177 .32977 .53567 .31943 .52664 Mtetra
.68 .783 .928 r
.31943 .52664 .32977 .53567 .34619 .52869 .3359 .52009 Mtetra
.707 .8 .923 r
.3359 .52009 .34619 .52869 .36278 .52012 .35251 .51235 Mtetra
.752 .827 .91 r
.35251 .51235 .36278 .52012 .37955 .50876 .3693 .50248 Mtetra
.815 .862 .883 r
.3693 .50248 .37955 .50876 .39654 .49271 .3863 .48894 Mtetra
.887 .897 .83 r
.3863 .48894 .39654 .49271 .41376 .46966 .40354 .46955 Mtetra
.945 .917 .754 r
.40354 .46955 .41376 .46966 .43116 .43798 .421 .44211 Mtetra
.974 .919 .675 r
.421 .44211 .43116 .43798 .44857 .399 .43856 .40617 Mtetra
.979 .916 .624 r
.43856 .40617 .44857 .399 .46577 .35809 .45602 .36518 Mtetra
.976 .922 .622 r
.45602 .36518 .46577 .35809 .48265 .32185 .4732 .32571 Mtetra
.966 .936 .679 r
.4732 .32571 .48265 .32185 .49924 .29387 .49004 .29327 Mtetra
.936 .938 .773 r
.49004 .29327 .49924 .29387 .51567 .27387 .50665 .26936 Mtetra
.872 .905 .851 r
.50665 .26936 .51567 .27387 .53206 .25968 .52317 .25246 Mtetra
.799 .853 .89 r
.52317 .25246 .53206 .25968 .54849 .24915 .53969 .24023 Mtetra
.743 .809 .904 r
.53969 .24023 .54849 .24915 .56499 .24071 .55626 .23081 Mtetra
.707 .779 .908 r
.55626 .23081 .56499 .24071 .58159 .23342 .57293 .22295 Mtetra
.687 .762 .908 r
.57293 .22295 .58159 .23342 .59829 .22673 .58969 .21592 Mtetra
.676 .752 .908 r
.58969 .21592 .59829 .22673 .61509 .22034 .60656 .20932 Mtetra
.67 .747 .908 r
.60656 .20932 .61509 .22034 .63199 .2141 .62354 .20293 Mtetra
.667 .744 .908 r
.62354 .20293 .63199 .2141 .649 .20791 .64061 .19664 Mtetra
.665 .743 .908 r
.64061 .19664 .649 .20791 .66612 .20174 .6578 .19037 Mtetra
.665 .742 .908 r
.6578 .19037 .66612 .20174 .68334 .19556 .67509 .18411 Mtetra
.664 .742 .908 r
.67509 .18411 .68334 .19556 .70066 .18935 .69249 .17782 Mtetra
.69249 .17782 .70066 .18935 .71809 .18311 .70999 .17151 Mtetra
.664 .741 .908 r
.70999 .17151 .71809 .18311 .73563 .17684 .72761 .16517 Mtetra
.72761 .16517 .73563 .17684 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56462 Mtetra
.16526 .56462 .1762 .57379 .19172 .56883 .18083 .55961 Mtetra
.18083 .55961 .19172 .56883 .20734 .56384 .1965 .55457 Mtetra
.646 .763 .934 r
.1965 .55457 .20734 .56384 .22305 .55881 .21227 .54948 Mtetra
.21227 .54948 .22305 .55881 .23886 .55374 .22813 .54436 Mtetra
.647 .763 .934 r
.22813 .54436 .23886 .55374 .25476 .54861 .24409 .53919 Mtetra
.648 .764 .933 r
.24409 .53919 .25476 .54861 .27077 .54341 .26016 .53395 Mtetra
.65 .765 .933 r
.26016 .53395 .27077 .54341 .28688 .53807 .27632 .52862 Mtetra
.653 .767 .933 r
.27632 .52862 .28688 .53807 .3031 .53254 .2926 .52312 Mtetra
.659 .771 .932 r
.2926 .52312 .3031 .53254 .31943 .52664 .30898 .51735 Mtetra
.671 .778 .93 r
.30898 .51735 .31943 .52664 .3359 .52009 .3255 .5111 Mtetra
.692 .791 .926 r
.3255 .5111 .3359 .52009 .35251 .51235 .34215 .50395 Mtetra
.727 .812 .918 r
.34215 .50395 .35251 .51235 .3693 .50248 .35896 .49521 Mtetra
.781 .844 .899 r
.35896 .49521 .3693 .50248 .3863 .48894 .37598 .48364 Mtetra
.852 .881 .86 r
.37598 .48364 .3863 .48894 .40354 .46955 .39322 .46736 Mtetra
.92 .909 .794 r
.39322 .46736 .40354 .46955 .421 .44211 .4107 .44403 Mtetra
.964 .919 .713 r
.4107 .44403 .421 .44211 .43856 .40617 .42837 .41202 Mtetra
.979 .917 .644 r
.42837 .41202 .43856 .40617 .45602 .36518 .44605 .37267 Mtetra
.978 .917 .616 r
.44605 .37267 .45602 .36518 .4732 .32571 .46352 .33138 Mtetra
.972 .929 .644 r
.46352 .33138 .4732 .32571 .49004 .29327 .48065 .29481 Mtetra
.955 .941 .725 r
.48065 .29481 .49004 .29327 .50665 .26936 .49749 .26655 Mtetra
.907 .925 .816 r
.49749 .26655 .50665 .26936 .52317 .25246 .51415 .2463 Mtetra
.835 .879 .875 r
.51415 .2463 .52317 .25246 .53969 .24023 .53078 .23191 Mtetra
.768 .829 .899 r
.53078 .23191 .53969 .24023 .55626 .23081 .54744 .22118 Mtetra
.723 .792 .907 r
.54744 .22118 .55626 .23081 .57293 .22295 .56417 .21256 Mtetra
.696 .769 .908 r
.56417 .21256 .57293 .22295 .58969 .21592 .58101 .2051 Mtetra
.681 .756 .908 r
.58101 .2051 .58969 .21592 .60656 .20932 .59794 .19823 Mtetra
.673 .749 .908 r
.59794 .19823 .60656 .20932 .62354 .20293 .61498 .19167 Mtetra
.668 .746 .908 r
.61498 .19167 .62354 .20293 .64061 .19664 .63213 .18525 Mtetra
.666 .744 .908 r
.63213 .18525 .64061 .19664 .6578 .19037 .64939 .17888 Mtetra
.665 .742 .908 r
.64939 .17888 .6578 .19037 .67509 .18411 .66675 .17253 Mtetra
.664 .742 .908 r
.66675 .17253 .67509 .18411 .69249 .17782 .68422 .16617 Mtetra
.68422 .16617 .69249 .17782 .70999 .17151 .7018 .15978 Mtetra
.664 .741 .908 r
.7018 .15978 .70999 .17151 .72761 .16517 .71949 .15336 Mtetra
.71949 .15336 .72761 .16517 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .14041 Mtetra
.7552 .14041 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56462 .15419 .55535 Mtetra
.15419 .55535 .16526 .56462 .18083 .55961 .16982 .55028 Mtetra
.16982 .55028 .18083 .55961 .1965 .55457 .18555 .54518 Mtetra
.646 .763 .934 r
.18555 .54518 .1965 .55457 .21227 .54948 .20137 .54005 Mtetra
.20137 .54005 .21227 .54948 .22813 .54436 .21729 .53488 Mtetra
.647 .763 .934 r
.21729 .53488 .22813 .54436 .24409 .53919 .2333 .52966 Mtetra
.2333 .52966 .24409 .53919 .26016 .53395 .24942 .52438 Mtetra
.649 .764 .933 r
.24942 .52438 .26016 .53395 .27632 .52862 .26565 .51902 Mtetra
.651 .766 .933 r
.26565 .51902 .27632 .52862 .2926 .52312 .28198 .51354 Mtetra
.656 .768 .932 r
.28198 .51354 .2926 .52312 .30898 .51735 .29842 .50785 Mtetra
.664 .774 .931 r
.29842 .50785 .30898 .51735 .3255 .5111 .31498 .50179 Mtetra
.68 .783 .928 r
.31498 .50179 .3255 .5111 .34215 .50395 .33167 .49507 Mtetra
.707 .8 .923 r
.33167 .49507 .34215 .50395 .35896 .49521 .34852 .48716 Mtetra
.752 .827 .91 r
.34852 .48716 .35896 .49521 .37598 .48364 .36555 .4771 Mtetra
.815 .862 .883 r
.36555 .4771 .37598 .48364 .39322 .46736 .3828 .46334 Mtetra
.887 .897 .83 r
.3828 .46334 .39322 .46736 .4107 .44403 .4003 .4437 Mtetra
.946 .917 .754 r
.4003 .4437 .4107 .44403 .42837 .41202 .41803 .41595 Mtetra
.974 .919 .675 r
.41803 .41595 .42837 .41202 .44605 .37267 .43587 .37965 Mtetra
.979 .916 .623 r
.43587 .37965 .44605 .37267 .46352 .33138 .4536 .33828 Mtetra
.976 .922 .622 r
.4536 .33828 .46352 .33138 .48065 .29481 .47105 .29845 Mtetra
.966 .936 .68 r
.47105 .29845 .48065 .29481 .49749 .26655 .48814 .26569 Mtetra
.936 .938 .773 r
.48814 .26569 .49749 .26655 .51415 .2463 .505 .24152 Mtetra
.872 .905 .851 r
.505 .24152 .51415 .2463 .53078 .23191 .52175 .22439 Mtetra
.799 .853 .89 r
.52175 .22439 .53078 .23191 .54744 .22118 .5385 .21197 Mtetra
.743 .809 .904 r
.5385 .21197 .54744 .22118 .56417 .21256 .55531 .20235 Mtetra
.707 .779 .908 r
.55531 .20235 .56417 .21256 .58101 .2051 .57222 .19431 Mtetra
.687 .762 .908 r
.57222 .19431 .58101 .2051 .59794 .19823 .58922 .1871 Mtetra
.676 .752 .908 r
.58922 .1871 .59794 .19823 .61498 .19167 .60633 .18032 Mtetra
.67 .747 .908 r
.60633 .18032 .61498 .19167 .63213 .18525 .62355 .17375 Mtetra
.667 .744 .908 r
.62355 .17375 .63213 .18525 .64939 .17888 .64088 .16728 Mtetra
.665 .743 .908 r
.64088 .16728 .64939 .17888 .66675 .17253 .65831 .16083 Mtetra
.665 .742 .908 r
.65831 .16083 .66675 .17253 .68422 .16617 .67586 .15439 Mtetra
.664 .742 .908 r
.67586 .15439 .68422 .16617 .7018 .15978 .69351 .14792 Mtetra
.69351 .14792 .7018 .15978 .71949 .15336 .71128 .14142 Mtetra
.664 .741 .908 r
.71128 .14142 .71949 .15336 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .14041 .74715 .12831 Mtetra
.74715 .12831 .7552 .14041 .77323 .13387 .76525 .1217 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55028 .15868 .54085 Mtetra
.15868 .54085 .16982 .55028 .18555 .54518 .17446 .5357 Mtetra
.17446 .5357 .18555 .54518 .20137 .54005 .19034 .5305 Mtetra
.646 .763 .934 r
.19034 .5305 .20137 .54005 .21729 .53488 .20632 .52528 Mtetra
.20632 .52528 .21729 .53488 .2333 .52966 .22239 .52 Mtetra
.647 .763 .934 r
.22239 .52 .2333 .52966 .24942 .52438 .23857 .51468 Mtetra
.648 .764 .933 r
.23857 .51468 .24942 .52438 .26565 .51902 .25485 .50929 Mtetra
.65 .765 .933 r
.25485 .50929 .26565 .51902 .28198 .51354 .27124 .5038 Mtetra
.653 .767 .933 r
.27124 .5038 .28198 .51354 .29842 .50785 .28773 .49815 Mtetra
.659 .771 .932 r
.28773 .49815 .29842 .50785 .31498 .50179 .30435 .49222 Mtetra
.671 .778 .93 r
.30435 .49222 .31498 .50179 .33167 .49507 .32109 .4858 Mtetra
.692 .791 .926 r
.32109 .4858 .33167 .49507 .34852 .48716 .33798 .47848 Mtetra
.727 .812 .918 r
.33798 .47848 .34852 .48716 .36555 .4771 .35504 .46955 Mtetra
.781 .844 .899 r
.35504 .46955 .36555 .4771 .3828 .46334 .3723 .45778 Mtetra
.852 .881 .86 r
.3723 .45778 .3828 .46334 .4003 .4437 .3898 .44126 Mtetra
.92 .91 .794 r
.3898 .44126 .4003 .4437 .41803 .41595 .40755 .41764 Mtetra
.964 .92 .713 r
.40755 .41764 .41803 .41595 .43587 .37965 .4255 .38529 Mtetra
.979 .917 .644 r
.4255 .38529 .43587 .37965 .4536 .33828 .44346 .34557 Mtetra
.978 .917 .616 r
.44346 .34557 .4536 .33828 .47105 .29845 .4612 .3039 Mtetra
.972 .929 .644 r
.4612 .3039 .47105 .29845 .48814 .26569 .4786 .26698 Mtetra
.955 .94 .725 r
.4786 .26698 .48814 .26569 .505 .24152 .49568 .23843 Mtetra
.907 .925 .816 r
.49568 .23843 .505 .24152 .52175 .22439 .51259 .21794 Mtetra
.835 .879 .875 r
.51259 .21794 .52175 .22439 .5385 .21197 .52945 .20333 Mtetra
.768 .829 .899 r
.52945 .20333 .5385 .21197 .55531 .20235 .54635 .19241 Mtetra
.723 .792 .907 r
.54635 .19241 .55531 .20235 .57222 .19431 .56333 .1836 Mtetra
.696 .769 .908 r
.56333 .1836 .57222 .19431 .58922 .1871 .5804 .17595 Mtetra
.681 .756 .908 r
.5804 .17595 .58922 .1871 .60633 .18032 .59758 .1689 Mtetra
.673 .749 .908 r
.59758 .1689 .60633 .18032 .62355 .17375 .61487 .16216 Mtetra
.668 .746 .908 r
.61487 .16216 .62355 .17375 .64088 .16728 .63227 .15555 Mtetra
.666 .744 .908 r
.63227 .15555 .64088 .16728 .65831 .16083 .64978 .14901 Mtetra
.665 .742 .908 r
.64978 .14901 .65831 .16083 .67586 .15439 .6674 .14247 Mtetra
.664 .742 .908 r
.6674 .14247 .67586 .15439 .69351 .14792 .68513 .13592 Mtetra
.68513 .13592 .69351 .14792 .71128 .14142 .70297 .12934 Mtetra
.664 .741 .908 r
.70297 .12934 .71128 .14142 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54085 .14742 .53131 Mtetra
.14742 .53131 .15868 .54085 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .5305 .17919 .52085 Mtetra
.646 .763 .934 r
.17919 .52085 .19034 .5305 .20632 .52528 .19522 .51556 Mtetra
.19522 .51556 .20632 .52528 .22239 .52 .21135 .51024 Mtetra
.647 .763 .934 r
.21135 .51024 .22239 .52 .23857 .51468 .22759 .50486 Mtetra
.22759 .50486 .23857 .51468 .25485 .50929 .24393 .49943 Mtetra
.649 .764 .933 r
.24393 .49943 .25485 .50929 .27124 .5038 .26037 .49392 Mtetra
.651 .766 .933 r
.26037 .49392 .27124 .5038 .28773 .49815 .27693 .48828 Mtetra
.656 .768 .932 r
.27693 .48828 .28773 .49815 .30435 .49222 .2936 .48242 Mtetra
.664 .774 .931 r
.2936 .48242 .30435 .49222 .32109 .4858 .31039 .4762 Mtetra
.68 .784 .928 r
.31039 .4762 .32109 .4858 .33798 .47848 .32732 .46931 Mtetra
.707 .8 .923 r
.32732 .46931 .33798 .47848 .35504 .46955 .34442 .46121 Mtetra
.752 .827 .91 r
.34442 .46121 .35504 .46955 .3723 .45778 .3617 .45096 Mtetra
.815 .862 .883 r
.3617 .45096 .3723 .45778 .3898 .44126 .3792 .43698 Mtetra
.888 .897 .83 r
.3792 .43698 .3898 .44126 .40755 .41764 .39696 .41707 Mtetra
.946 .917 .754 r
.39696 .41707 .40755 .41764 .4255 .38529 .41497 .389 Mtetra
.974 .919 .675 r
.41497 .389 .4255 .38529 .44346 .34557 .43309 .35234 Mtetra
.979 .916 .623 r
.43309 .35234 .44346 .34557 .4612 .3039 .45111 .31058 Mtetra
.976 .922 .623 r
.45111 .31058 .4612 .3039 .4786 .26698 .46883 .27038 Mtetra
.966 .936 .68 r
.46883 .27038 .4786 .26698 .49568 .23843 .48619 .23731 Mtetra
.936 .937 .773 r
.48619 .23731 .49568 .23843 .51259 .21794 .50329 .21287 Mtetra
.872 .904 .851 r
.50329 .21287 .51259 .21794 .52945 .20333 .52029 .19551 Mtetra
.799 .853 .89 r
.52029 .19551 .52945 .20333 .54635 .19241 .53728 .18288 Mtetra
.743 .808 .904 r
.53728 .18288 .54635 .19241 .56333 .1836 .55434 .17307 Mtetra
.707 .779 .908 r
.55434 .17307 .56333 .1836 .5804 .17595 .57148 .16483 Mtetra
.687 .762 .908 r
.57148 .16483 .5804 .17595 .59758 .1689 .58873 .15743 Mtetra
.676 .752 .908 r
.58873 .15743 .59758 .1689 .61487 .16216 .60609 .15047 Mtetra
.67 .747 .908 r
.60609 .15047 .61487 .16216 .63227 .15555 .62356 .14372 Mtetra
.667 .744 .908 r
.62356 .14372 .63227 .15555 .64978 .14901 .64115 .13705 Mtetra
.665 .743 .908 r
.64115 .13705 .64978 .14901 .6674 .14247 .65884 .13042 Mtetra
.665 .742 .908 r
.65884 .13042 .6674 .14247 .68513 .13592 .67665 .12378 Mtetra
.664 .742 .908 r
.67665 .12378 .68513 .13592 .70297 .12934 .69457 .11712 Mtetra
.69457 .11712 .70297 .12934 .72093 .12272 .7126 .11042 Mtetra
.664 .741 .908 r
.7126 .11042 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53211 Mtetra
.10454 .53211 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53131 .13603 .52166 Mtetra
.13603 .52166 .14742 .53131 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52085 .16791 .51108 Mtetra
.16791 .51108 .17919 .52085 .19522 .51556 .184 .50574 Mtetra
.646 .763 .934 r
.184 .50574 .19522 .51556 .21135 .51024 .20019 .50035 Mtetra
.20019 .50035 .21135 .51024 .22759 .50486 .21648 .49493 Mtetra
.647 .763 .934 r
.21648 .49493 .22759 .50486 .24393 .49943 .23288 .48945 Mtetra
.648 .764 .933 r
.23288 .48945 .24393 .49943 .26037 .49392 .24938 .4839 Mtetra
.65 .765 .933 r
.24938 .4839 .26037 .49392 .27693 .48828 .266 .47824 Mtetra
.653 .767 .933 r
.266 .47824 .27693 .48828 .2936 .48242 .28273 .47243 Mtetra
.659 .771 .932 r
.28273 .47243 .2936 .48242 .31039 .4762 .29957 .46633 Mtetra
.671 .778 .93 r
.29957 .46633 .31039 .4762 .32732 .46931 .31656 .45974 Mtetra
.692 .791 .926 r
.31656 .45974 .32732 .46931 .34442 .46121 .33369 .45224 Mtetra
.727 .812 .918 r
.33369 .45224 .34442 .46121 .3617 .45096 .35099 .44312 Mtetra
.781 .844 .899 r
.35099 .44312 .3617 .45096 .3792 .43698 .36851 .43114 Mtetra
.852 .881 .86 r
.36851 .43114 .3792 .43698 .39696 .41707 .38628 .41437 Mtetra
.92 .91 .794 r
.38628 .41437 .39696 .41707 .41497 .389 .4043 .39046 Mtetra
.964 .92 .712 r
.4043 .39046 .41497 .389 .43309 .35234 .42254 .35777 Mtetra
.979 .917 .644 r
.42254 .35777 .43309 .35234 .45111 .31058 .44079 .31765 Mtetra
.978 .917 .616 r
.44079 .31765 .45111 .31058 .46883 .27038 .45882 .2756 Mtetra
.972 .929 .645 r
.45882 .2756 .46883 .27038 .48619 .23731 .47648 .23834 Mtetra
.955 .94 .725 r
.47648 .23834 .48619 .23731 .50329 .21287 .49383 .20949 Mtetra
.907 .925 .816 r
.49383 .20949 .50329 .21287 .52029 .19551 .51099 .18875 Mtetra
.835 .879 .875 r
.51099 .18875 .52029 .19551 .53728 .18288 .5281 .17392 Mtetra
.768 .829 .899 r
.5281 .17392 .53728 .18288 .55434 .17307 .54524 .1628 Mtetra
.723 .792 .907 r
.54524 .1628 .55434 .17307 .57148 .16483 .56246 .15379 Mtetra
.696 .769 .908 r
.56246 .15379 .57148 .16483 .58873 .15743 .57978 .14595 Mtetra
.681 .756 .908 r
.57978 .14595 .58873 .15743 .60609 .15047 .59722 .13871 Mtetra
.673 .749 .908 r
.59722 .13871 .60609 .15047 .62356 .14372 .61476 .13177 Mtetra
.668 .746 .908 r
.61476 .13177 .62356 .14372 .64115 .13705 .63241 .12498 Mtetra
.666 .744 .908 r
.63241 .12498 .64115 .13705 .65884 .13042 .65018 .11824 Mtetra
.665 .742 .908 r
.65018 .11824 .65884 .13042 .67665 .12378 .66807 .11151 Mtetra
.664 .742 .908 r
.66807 .11151 .67665 .12378 .69457 .11712 .68607 .10476 Mtetra
.68607 .10476 .69457 .11712 .7126 .11042 .70418 .09798 Mtetra
.664 .741 .908 r
.70418 .09798 .7126 .11042 .73075 .10369 .72241 .09117 Mtetra
.72241 .09117 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53211 .09291 .52247 Mtetra
.09291 .52247 .10454 .53211 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52166 .1245 .5119 Mtetra
.1245 .5119 .13603 .52166 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .16791 .51108 .15649 .5012 Mtetra
.15649 .5012 .16791 .51108 .184 .50574 .17264 .49579 Mtetra
.646 .763 .934 r
.17264 .49579 .184 .50574 .20019 .50035 .18889 .49035 Mtetra
.18889 .49035 .20019 .50035 .21648 .49493 .20524 .48487 Mtetra
.647 .763 .934 r
.20524 .48487 .21648 .49493 .23288 .48945 .2217 .47933 Mtetra
.2217 .47933 .23288 .48945 .24938 .4839 .23827 .47374 Mtetra
.649 .764 .933 r
.23827 .47374 .24938 .4839 .266 .47824 .25494 .46806 Mtetra
.651 .766 .933 r
.25494 .46806 .266 .47824 .28273 .47243 .27173 .46225 Mtetra
.656 .768 .932 r
.27173 .46225 .28273 .47243 .29957 .46633 .28863 .45623 Mtetra
.664 .774 .931 r
.28863 .45623 .29957 .46633 .31656 .45974 .30567 .44983 Mtetra
.68 .784 .928 r
.30567 .44983 .31656 .45974 .33369 .45224 .32284 .44277 Mtetra
.707 .8 .923 r
.32284 .44277 .33369 .45224 .35099 .44312 .34018 .43448 Mtetra
.752 .827 .91 r
.34018 .43448 .35099 .44312 .36851 .43114 .35772 .42402 Mtetra
.815 .862 .883 r
.35772 .42402 .36851 .43114 .38628 .41437 .37549 .40981 Mtetra
.888 .898 .83 r
.37549 .40981 .38628 .41437 .4043 .39046 .39353 .38963 Mtetra
.946 .917 .754 r
.39353 .38963 .4043 .39046 .42254 .35777 .41182 .36124 Mtetra
.974 .919 .674 r
.41182 .36124 .42254 .35777 .44079 .31765 .43023 .32421 Mtetra
.979 .916 .623 r
.43023 .32421 .44079 .31765 .45882 .2756 .44855 .28205 Mtetra
.976 .922 .623 r
.44855 .28205 .45882 .2756 .47648 .23834 .46655 .24149 Mtetra
.967 .936 .68 r
.46655 .24149 .47648 .23834 .49383 .20949 .48418 .20809 Mtetra
.936 .937 .773 r
.48418 .20809 .49383 .20949 .51099 .18875 .50154 .18338 Mtetra
.872 .904 .851 r
.50154 .18338 .51099 .18875 .5281 .17392 .51878 .16578 Mtetra
.799 .853 .89 r
.51878 .16578 .5281 .17392 .54524 .1628 .53603 .15293 Mtetra
.743 .808 .904 r
.53603 .15293 .54524 .1628 .56246 .15379 .55333 .14292 Mtetra
.708 .779 .908 r
.55333 .14292 .56246 .15379 .57978 .14595 .57073 .13448 Mtetra
.687 .762 .908 r
.57073 .13448 .57978 .14595 .59722 .13871 .58823 .12689 Mtetra
.676 .752 .908 r
.58823 .12689 .59722 .13871 .61476 .13177 .60585 .11973 Mtetra
.67 .747 .908 r
.60585 .11973 .61476 .13177 .63241 .12498 .62358 .11278 Mtetra
.667 .744 .908 r
.62358 .11278 .63241 .12498 .65018 .11824 .64142 .10592 Mtetra
.665 .743 .908 r
.64142 .10592 .65018 .11824 .66807 .11151 .65939 .09909 Mtetra
.665 .742 .908 r
.65939 .09909 .66807 .11151 .68607 .10476 .67746 .09225 Mtetra
.664 .742 .908 r
.67746 .09225 .68607 .10476 .70418 .09798 .69566 .08539 Mtetra
.69566 .08539 .70418 .09798 .72241 .09117 .71397 .07849 Mtetra
.664 .741 .908 r
.71397 .07849 .72241 .09117 .74076 .08431 .7324 .07156 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .5119 .11284 .50203 Mtetra
.11284 .50203 .1245 .5119 .14045 .50657 .12885 .49663 Mtetra
.12885 .49663 .14045 .50657 .15649 .5012 .14495 .4912 Mtetra
.14495 .4912 .15649 .5012 .17264 .49579 .16115 .48574 Mtetra
.16115 .48574 .17264 .49579 .18889 .49035 .17746 .48023 Mtetra
.646 .763 .934 r
.17746 .48023 .18889 .49035 .20524 .48487 .19387 .47469 Mtetra
.19387 .47469 .20524 .48487 .2217 .47933 .21039 .4691 Mtetra
.647 .763 .934 r
.21039 .4691 .2217 .47933 .23827 .47374 .22702 .46345 Mtetra
.648 .764 .933 r
.22702 .46345 .23827 .47374 .25494 .46806 .24375 .45773 Mtetra
.65 .765 .933 r
.24375 .45773 .25494 .46806 .27173 .46225 .2606 .45191 Mtetra
.653 .767 .933 r
.2606 .45191 .27173 .46225 .28863 .45623 .27756 .44593 Mtetra
.659 .771 .932 r
.27756 .44593 .28863 .45623 .30567 .44983 .29465 .43965 Mtetra
.671 .778 .93 r
.29465 .43965 .30567 .44983 .32284 .44277 .31188 .43288 Mtetra
.692 .791 .926 r
.31188 .43288 .32284 .44277 .34018 .43448 .32926 .4252 Mtetra
.727 .812 .918 r
.32926 .4252 .34018 .43448 .35772 .42402 .34682 .41588 Mtetra
.781 .844 .899 r
.34682 .41588 .35772 .42402 .37549 .40981 .3646 .40367 Mtetra
.852 .881 .86 r
.3646 .40367 .37549 .40981 .39353 .38963 .38264 .38666 Mtetra
.92 .91 .794 r
.38264 .38666 .39353 .38963 .41182 .36124 .40096 .36244 Mtetra
.964 .92 .712 r
.40096 .36244 .41182 .36124 .43023 .32421 .41948 .3294 Mtetra
.979 .917 .644 r
.41948 .3294 .43023 .32421 .44855 .28205 .43804 .2889 Mtetra
.978 .917 .616 r
.43804 .2889 .44855 .28205 .46655 .24149 .45636 .24646 Mtetra
.972 .929 .645 r
.45636 .24646 .46655 .24149 .48418 .20809 .47431 .20884 Mtetra
.955 .94 .725 r
.47431 .20884 .48418 .20809 .50154 .18338 .49192 .1797 Mtetra
.907 .925 .816 r
.49192 .1797 .50154 .18338 .51878 .16578 .50933 .1587 Mtetra
.835 .879 .875 r
.50933 .1587 .51878 .16578 .53603 .15293 .5267 .14364 Mtetra
.768 .829 .899 r
.5267 .14364 .53603 .15293 .55333 .14292 .54409 .1323 Mtetra
.723 .792 .907 r
.54409 .1323 .55333 .14292 .57073 .13448 .56157 .1231 Mtetra
.696 .769 .908 r
.56157 .1231 .57073 .13448 .58823 .12689 .57915 .11505 Mtetra
.681 .756 .908 r
.57915 .11505 .58823 .12689 .60585 .11973 .59684 .10761 Mtetra
.673 .749 .908 r
.59684 .10761 .60585 .11973 .62358 .11278 .61464 .10048 Mtetra
.668 .746 .908 r
.61464 .10048 .62358 .11278 .64142 .10592 .63256 .09348 Mtetra
.666 .744 .908 r
.63256 .09348 .64142 .10592 .65939 .09909 .6506 .08654 Mtetra
.665 .742 .908 r
.6506 .08654 .65939 .09909 .67746 .09225 .66876 .0796 Mtetra
.664 .742 .908 r
.66876 .0796 .67746 .09225 .69566 .08539 .68703 .07265 Mtetra
.68703 .07265 .69566 .08539 .71397 .07849 .70542 .06567 Mtetra
.664 .741 .908 r
.70542 .06567 .71397 .07849 .7324 .07156 .72394 .05864 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49663 .11711 .48658 Mtetra
.11711 .48658 .12885 .49663 .14495 .4912 .13327 .48109 Mtetra
.13327 .48109 .14495 .4912 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48023 .1659 .46999 Mtetra
.646 .763 .934 r
.1659 .46999 .17746 .48023 .19387 .47469 .18237 .46438 Mtetra
.18237 .46438 .19387 .47469 .21039 .4691 .19895 .45873 Mtetra
.647 .763 .934 r
.19895 .45873 .21039 .4691 .22702 .46345 .21564 .45303 Mtetra
.21564 .45303 .22702 .46345 .24375 .45773 .23243 .44727 Mtetra
.649 .764 .933 r
.23243 .44727 .24375 .45773 .2606 .45191 .24934 .44142 Mtetra
.651 .766 .933 r
.24934 .44142 .2606 .45191 .27756 .44593 .26637 .43543 Mtetra
.656 .768 .932 r
.26637 .43543 .27756 .44593 .29465 .43965 .28352 .42924 Mtetra
.664 .774 .931 r
.28352 .42924 .29465 .43965 .31188 .43288 .3008 .42266 Mtetra
.68 .784 .928 r
.3008 .42266 .31188 .43288 .32926 .4252 .31822 .4154 Mtetra
.707 .8 .923 r
.31822 .4154 .32926 .4252 .34682 .41588 .33582 .40692 Mtetra
.752 .827 .91 r
.33582 .40692 .34682 .41588 .3646 .40367 .35362 .39625 Mtetra
.815 .863 .883 r
.35362 .39625 .3646 .40367 .38264 .38666 .37166 .3818 Mtetra
.888 .898 .83 r
.37166 .3818 .38264 .38666 .40096 .36244 .38998 .36134 Mtetra
.946 .918 .754 r
.38998 .36134 .40096 .36244 .41948 .3294 .40857 .33262 Mtetra
.974 .919 .674 r
.40857 .33262 .41948 .3294 .43804 .2889 .42729 .29521 Mtetra
.979 .916 .623 r
.42729 .29521 .43804 .2889 .45636 .24646 .44591 .25266 Mtetra
.976 .922 .623 r
.44591 .25266 .45636 .24646 .47431 .20884 .4642 .21172 Mtetra
.967 .936 .681 r
.4642 .21172 .47431 .20884 .49192 .1797 .4821 .178 Mtetra
.936 .937 .773 r
.4821 .178 .49192 .1797 .50933 .1587 .49973 .153 Mtetra
.872 .904 .851 r
.49973 .153 .50933 .1587 .5267 .14364 .51724 .13516 Mtetra
.799 .853 .89 r
.51724 .13516 .5267 .14364 .54409 .1323 .53473 .12209 Mtetra
.743 .808 .904 r
.53473 .12209 .54409 .1323 .56157 .1231 .5523 .11187 Mtetra
.708 .779 .908 r
.5523 .11187 .56157 .1231 .57915 .11505 .56995 .10323 Mtetra
.687 .762 .908 r
.56995 .10323 .57915 .11505 .59684 .10761 .58772 .09543 Mtetra
.676 .752 .908 r
.58772 .09543 .59684 .10761 .61464 .10048 .6056 .08807 Mtetra
.67 .747 .908 r
.6056 .08807 .61464 .10048 .63256 .09348 .62359 .08092 Mtetra
.667 .744 .908 r
.62359 .08092 .63256 .09348 .6506 .08654 .64171 .07385 Mtetra
.665 .743 .908 r
.64171 .07385 .6506 .08654 .66876 .0796 .65995 .06681 Mtetra
.665 .742 .908 r
.65995 .06681 .66876 .0796 .68703 .07265 .6783 .05976 Mtetra
.664 .742 .908 r
.6783 .05976 .68703 .07265 .70542 .06567 .69678 .05269 Mtetra
.69678 .05269 .70542 .06567 .72394 .05864 .71537 .04558 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47641 Mtetra
.10523 .47641 .11711 .48658 .13327 .48109 .12145 .47085 Mtetra
.12145 .47085 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .46999 .1542 .45963 Mtetra
.1542 .45963 .1659 .46999 .18237 .46438 .17073 .45395 Mtetra
.646 .763 .934 r
.17073 .45395 .18237 .46438 .19895 .45873 .18737 .44824 Mtetra
.18737 .44824 .19895 .45873 .21564 .45303 .20412 .44248 Mtetra
.647 .763 .934 r
.20412 .44248 .21564 .45303 .23243 .44727 .22098 .43666 Mtetra
.648 .764 .933 r
.22098 .43666 .23243 .44727 .24934 .44142 .23795 .43077 Mtetra
.65 .765 .933 r
.23795 .43077 .24934 .44142 .26637 .43543 .25504 .42477 Mtetra
.653 .767 .933 r
.25504 .42477 .26637 .43543 .28352 .42924 .27225 .41861 Mtetra
.659 .771 .932 r
.27225 .41861 .28352 .42924 .3008 .42266 .28958 .41215 Mtetra
.671 .778 .93 r
.28958 .41215 .3008 .42266 .31822 .4154 .30706 .40519 Mtetra
.692 .791 .926 r
.30706 .40519 .31822 .4154 .33582 .40692 .3247 .39731 Mtetra
.727 .812 .918 r
.3247 .39731 .33582 .40692 .35362 .39625 .34252 .38779 Mtetra
.781 .844 .899 r
.34252 .38779 .35362 .39625 .37166 .3818 .36058 .37535 Mtetra
.852 .881 .86 r
.36058 .37535 .37166 .3818 .38998 .36134 .3789 .35807 Mtetra
.92 .91 .794 r
.3789 .35807 .38998 .36134 .40857 .33262 .39751 .33355 Mtetra
.964 .92 .712 r
.39751 .33355 .40857 .33262 .42729 .29521 .41634 .30015 Mtetra
.979 .917 .643 r
.41634 .30015 .42729 .29521 .44591 .25266 .4352 .25925 Mtetra
.978 .917 .616 r
.4352 .25925 .44591 .25266 .4642 .21172 .45383 .21642 Mtetra
.972 .928 .645 r
.45383 .21642 .4642 .21172 .4821 .178 .47207 .17845 Mtetra
.955 .94 .726 r
.47207 .17845 .4821 .178 .49973 .153 .48995 .14901 Mtetra
.907 .924 .816 r
.48995 .14901 .49973 .153 .51724 .13516 .50763 .12775 Mtetra
.835 .879 .875 r
.50763 .12775 .51724 .13516 .53473 .12209 .52525 .11245 Mtetra
.768 .829 .899 r
.52525 .11245 .53473 .12209 .5523 .11187 .54291 .10089 Mtetra
.723 .792 .906 r
.54291 .10089 .5523 .11187 .56995 .10323 .56065 .09147 Mtetra
.696 .769 .908 r
.56065 .09147 .56995 .10323 .58772 .09543 .57849 .08322 Mtetra
.681 .756 .908 r
.57849 .08322 .58772 .09543 .6056 .08807 .59645 .07557 Mtetra
.673 .749 .908 r
.59645 .07557 .6056 .08807 .62359 .08092 .61452 .06823 Mtetra
.668 .746 .908 r
.61452 .06823 .62359 .08092 .64171 .07385 .63272 .06103 Mtetra
.666 .744 .908 r
.63272 .06103 .64171 .07385 .65995 .06681 .65103 .05387 Mtetra
.665 .742 .908 r
.65103 .05387 .65995 .06681 .6783 .05976 .66947 .04672 Mtetra
.664 .742 .908 r
.66947 .04672 .6783 .05976 .69678 .05269 .68803 .03955 Mtetra
.68803 .03955 .69678 .05269 .71537 .04558 .70671 .03235 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47641 .09322 .46612 Mtetra
.09322 .46612 .10523 .47641 .12145 .47085 .10949 .4605 Mtetra
.10949 .4605 .12145 .47085 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45395 .15895 .4434 Mtetra
.646 .763 .934 r
.15895 .4434 .17073 .45395 .18737 .44824 .17565 .43762 Mtetra
.17565 .43762 .18737 .44824 .20412 .44248 .19246 .4318 Mtetra
.647 .763 .934 r
.19246 .4318 .20412 .44248 .22098 .43666 .20938 .42592 Mtetra
.20938 .42592 .22098 .43666 .23795 .43077 .22642 .41998 Mtetra
.649 .764 .933 r
.22642 .41998 .23795 .43077 .25504 .42477 .24357 .41395 Mtetra
.651 .766 .933 r
.24357 .41395 .25504 .42477 .27225 .41861 .26084 .40778 Mtetra
.656 .768 .932 r
.26084 .40778 .27225 .41861 .28958 .41215 .27824 .4014 Mtetra
.664 .774 .931 r
.27824 .4014 .28958 .41215 .30706 .40519 .29577 .39463 Mtetra
.68 .784 .928 r
.29577 .39463 .30706 .40519 .3247 .39731 .31346 .38718 Mtetra
.707 .8 .923 r
.31346 .38718 .3247 .39731 .34252 .38779 .33132 .3785 Mtetra
.752 .827 .91 r
.33132 .3785 .34252 .38779 .36058 .37535 .34939 .3676 Mtetra
.815 .863 .883 r
.34939 .3676 .36058 .37535 .3789 .35807 .36771 .3529 Mtetra
.888 .898 .83 r
.36771 .3529 .3789 .35807 .39751 .33355 .38633 .33216 Mtetra
.946 .918 .753 r
.38633 .33216 .39751 .33355 .41634 .30015 .40522 .3031 Mtetra
.974 .919 .674 r
.40522 .3031 .41634 .30015 .4352 .25925 .42425 .26531 Mtetra
.979 .916 .623 r
.42425 .26531 .4352 .25925 .45383 .21642 .44318 .22236 Mtetra
.976 .922 .623 r
.44318 .22236 .45383 .21642 .47207 .17845 .46178 .18104 Mtetra
.967 .936 .681 r
.46178 .18104 .47207 .17845 .48995 .14901 .47997 .14699 Mtetra
.936 .937 .773 r
.47997 .14699 .48995 .14901 .50763 .12775 .49787 .12171 Mtetra
.872 .904 .851 r
.49787 .12171 .50763 .12775 .52525 .11245 .51564 .10361 Mtetra
.799 .852 .89 r
.51564 .10361 .52525 .11245 .54291 .10089 .5334 .09031 Mtetra
.743 .808 .904 r
.5334 .09031 .54291 .10089 .56065 .09147 .55123 .07987 Mtetra
.708 .779 .908 r
.55123 .07987 .56065 .09147 .57849 .08322 .56915 .07102 Mtetra
.687 .762 .908 r
.56915 .07102 .57849 .08322 .59645 .07557 .58718 .06301 Mtetra
.676 .752 .908 r
.58718 .06301 .59645 .07557 .61452 .06823 .60534 .05544 Mtetra
.67 .747 .908 r
.60534 .05544 .61452 .06823 .63272 .06103 .62361 .04807 Mtetra
.667 .744 .908 r
.62361 .04807 .63272 .06103 .65103 .05387 .64201 .04079 Mtetra
.665 .743 .908 r
.64201 .04079 .65103 .05387 .66947 .04672 .66052 .03353 Mtetra
.665 .742 .908 r
.66052 .03353 .66947 .04672 .68803 .03955 .67917 .02626 Mtetra
.664 .742 .908 r
.67917 .02626 .68803 .03955 .70671 .03235 .69793 .01897 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46612 .08106 .45571 Mtetra
.08106 .45571 .09322 .46612 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43852 Mtetra
.13038 .43852 .14236 .44914 .15895 .4434 .14703 .43272 Mtetra
.14703 .43272 .15895 .4434 .17565 .43762 .16379 .42687 Mtetra
.646 .763 .934 r
.16379 .42687 .17565 .43762 .19246 .4318 .18066 .42098 Mtetra
.18066 .42098 .19246 .4318 .20938 .42592 .19765 .41504 Mtetra
.647 .763 .934 r
.19765 .41504 .20938 .42592 .22642 .41998 .21475 .40904 Mtetra
.648 .764 .933 r
.21475 .40904 .22642 .41998 .24357 .41395 .23196 .40297 Mtetra
.65 .765 .933 r
.23196 .40297 .24357 .41395 .26084 .40778 .2493 .39678 Mtetra
.653 .767 .933 r
.2493 .39678 .26084 .40778 .27824 .4014 .26676 .39043 Mtetra
.659 .771 .932 r
.26676 .39043 .27824 .4014 .29577 .39463 .28435 .38379 Mtetra
.671 .778 .93 r
.28435 .38379 .29577 .39463 .31346 .38718 .30209 .37663 Mtetra
.692 .791 .926 r
.30209 .37663 .31346 .38718 .33132 .3785 .31999 .36855 Mtetra
.727 .812 .918 r
.31999 .36855 .33132 .3785 .34939 .3676 .33809 .3588 Mtetra
.781 .844 .899 r
.33809 .3588 .34939 .3676 .36771 .3529 .35642 .34613 Mtetra
.852 .882 .86 r
.35642 .34613 .36771 .3529 .38633 .33216 .37503 .32858 Mtetra
.92 .911 .794 r
.37503 .32858 .38633 .33216 .40522 .3031 .39395 .30375 Mtetra
.964 .92 .712 r
.39395 .30375 .40522 .3031 .42425 .26531 .41309 .26998 Mtetra
.979 .917 .643 r
.41309 .26998 .42425 .26531 .44318 .22236 .43227 .22869 Mtetra
.978 .917 .616 r
.43227 .22869 .44318 .22236 .46178 .18104 .45122 .18546 Mtetra
.972 .928 .645 r
.45122 .18546 .46178 .18104 .47997 .14699 .46975 .14713 Mtetra
.955 .94 .726 r
.46975 .14713 .47997 .14699 .49787 .12171 .48792 .11737 Mtetra
.907 .924 .816 r
.48792 .11737 .49787 .12171 .51564 .10361 .50588 .09585 Mtetra
.835 .878 .875 r
.50588 .09585 .51564 .10361 .5334 .09031 .52377 .08031 Mtetra
.768 .829 .899 r
.52377 .08031 .5334 .09031 .55123 .07987 .54169 .06852 Mtetra
.723 .792 .906 r
.54169 .06852 .55123 .07987 .56915 .07102 .5597 .05888 Mtetra
.696 .769 .908 r
.5597 .05888 .56915 .07102 .58718 .06301 .57781 .05041 Mtetra
.681 .756 .908 r
.57781 .05041 .58718 .06301 .60534 .05544 .59604 .04255 Mtetra
.673 .749 .908 r
.59604 .04255 .60534 .05544 .62361 .04807 .6144 .03498 Mtetra
.668 .746 .908 r
.6144 .03498 .62361 .04807 .64201 .04079 .63287 .02756 Mtetra
.666 .744 .908 r
.63287 .02756 .64201 .04079 .66052 .03353 .65147 .02019 Mtetra
.665 .742 .908 r
.65147 .02019 .66052 .03353 .67917 .02626 .6702 .01281 Mtetra
.664 .742 .908 r
.6702 .01281 .67917 .02626 .69793 .01897 .68905 .00542 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooe;lD]`0
07oo0000Egoo003EOol30003Ool00e;lD]aBo002D_`01000D_aoo`00EWoo003BOol30004Ool02e;L
E_aBg5;lD]aFo5;L001Bg5Kl0000EWoo003@Ool20003Ool00e;lD]aBo002D_`02e;LD_aBo5;lD]aB
o000D_aBg5;l0000EGoo003=Ool30003Ool04e;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L001Bg5;l
D]aoo`0005Aoo`00bgoo0P000goo25;l00EBg5;lD_aBo5;L00=Bo006001Bo5;lD_aBg000E7oo0038
Ool3000077oo001ooeKlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_ao
o`00Dgoo001WOol20002Ool2001IOol20003Ool00e;l001Fo003D_`00eKlD_aBo006D_`01E;LD_aB
o5;lD]`00U;l00<005;LD_`00U;l00=oo`00Ool0DGoo001XOol01000Oomoo`00Egoo0`000goo01mB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`005;lD]aFo5;LOol0
001BOol006Uoo`8005Ioo`80009oo`07E_aBo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`02U;l00IBg5;l
D_aBo5;L0002D_`01E;LD_aBo7oo0000DGoo001YOol2001COol30002Ool095;lE_aBo5KlD_aFo5;L
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo09o
o`03001oogoo04ioo`00J7oo00@007ooOol0051oo`80009oo`QFo004D_aFo5;lE_`>D_`01E;LD_aB
o5;lD]`00U;l00<005;LD_`00U;l00ABg5;lOol0051oo`00Igoo0P000Woo0P00C7oo0`000goo02aF
o5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo000D_aBg5KlD]aBo5;LE_aoo`00Cgoo002fOol30002Ool01`00OomG75KlEaaFo5LL00IF
o0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00=Bg0000000Cgoo
002dOol20005Ool0<EKlFaaFo5/LE_aK75KlEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aoo`0004ioo`00/Goo
0`001Woo0U/L00IFo5LLE_aG75KlEa`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aB
o5;L009Bo003001Bg5;l009Bo007D]aBo5;lD_aBg7oo0000CGoo002_Ool20007Ool0=EllFaaK?5/K
GcaFo5/LE_aK75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo7oo00004Goo1@00=goo002/Ool30007Ool8
Fa`00eKlEaaFo002E_`00eLLE_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00IBg5;lD_aB
o5;L0002D_`01E;LD_aBo5;lD]`00e;l00=oo`00Ool03goo00D007ooOomoo`0003Moo`00ZWoo0P00
2Goo03YO>f=LFaaK?5/KGcaK75/lE_aK75KlEaaBo5LLE_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0
011oo`03001oogoo03Qoo`00Ygoo0`000Woo00<007ooOol017oo00ESG5llHeaO?6=L00IK7004EaaF
o5KlEa`3E_`02ELLD_aFo5;lE_aBo5KlD_aFo00<D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l
00EBg5;lD_aBo5;L00=Bo003001oogoo00Eoo`H000Aoo`03001oogoo03Moo`00YGoo0P002Woo03mO
>f=LGc]SG5lkHeaO>f=LEaaK75KlFaaG75/LE_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g7oo00004Goo00<007ooOol0=Woo002ROol3000;Ool026MkJg]O?6=LGcaSG5llHe`2Gc`2Fa`015LL
FaaK75/L25Kl00ABo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00EBg5;l
D_aBo5;L009Bo003Ool007oo011oo`03001oogoo03Eoo`00MGoo10009goo0P003Goo049WNf]kIgY[
NelkHeaO>ellFaaO?5/KFaaG75/LE_aK75KlFaaBo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;L000=Ool01@00Oomoogoo0000=goo001dOol00`00Oomoo`02Ool00`00Oomoo`0QOol3000=Ool0
0f]kIg][N`02Jg/00fMkJg]O?006Gc`01eLLE_aG75KlEaaFo5LL00AFo004D_aFo5KlE_`3D_`00eKl
D_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`015;L
D_aoo`003Goo0`00>7oo001dOol00`00Oomoo`02Ool00`00Oomoo`0NOol3000?Ool0Af]kIg][NfMj
Jg]WNf]kHe]WO5/LGcaK6ellFaaK?5/KFaaFo5/LE_aK75KlFaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo7oo0000Agoo001dOol00`00Oomoo`02Ool00`00Oomoo`0LOol20002Ool00`00Oomo
o`0<Ool00g>iLiU[N`02Jg/01FMkJg]SFfMLHe/00ell1E/L00=G75KlEa`00eKl00=G75;lE_`00UKl
00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo003D]aoo`0004Moo`00M7oo00<007ooOol00Woo00<007ooOol06Goo0`004Woo
04Yc^G>ILkUcVF]kIg]WO6=KIgaSFfMlHe]O?5/LFcaK6ellFaaK?5/KEaaFo5LLD_aG75KlEaaBo5Kl
D_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L001Bg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00AWoo001dOol00`00Oomoo`02Ool00`00Oomoo`0G
Ool2000EOol03G>ILkUcVG>iLiUWFf=KIeaSFfMKHe]SG5ll00MK7004EaaFo5KlEa`4E_`025;lE_aF
o5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`13Ool007Aoo`03001oogoo009oo`03001oogoo01Aoo`<0
01Ioo`0LLiUc^G>ILkUcVFnJJgYWO6=KIgaO>f=LGc]SG5lkGcaK75/lE_aK75LLFaaFo5LLE_aG75;l
Ea`2E_`0;U;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`00AGoo001eOol4000EOol2000HOol0
1G>ILkUcVG>iLiT016nJ00QSG5llHeaO?6=LGcaSG5ll0e/L00AG75/LFaaK70=Fo003EaaFo5Kl009F
o004D_aFo5;lE_`@D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;l
D_aBo7oo0014Ool008]oo`<001Uoo`04LiUc^G>ILkT2KiX0BV]jKi]_VV]kIgYSG5lkHeaO>f=LGc]O
?5/KFaaG75/LE_aK75LLFaaBo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o7oo0013Ool008Uoo`80009oo`03001oogoo01Ioo`04MkIk]W>ILkT5KiX3Jg/016MkHeaO?6=L1Ell
0e/L0ULL00=Fo5LLE_`01EKl00=Bo5KlD_`00U;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo049oo`00
QWoo0`007Goo00=k]WNfNkL00VnJ01I[NVnKIg][NfMjJi]WNf]kIgYO?5/LGcaK6ellFaaO?5/KFaaF
o5/LE_aK709Fo00eD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol00012
Ool008Aoo`8001moo`04NkIg]W^fMkL3MkP01FMkJg][Nf]kIg/00V]k00=WG6=KGc`01Ell0U/L00EG
75KlEaaFo5LL009Fo008D_aFo5KlE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003
D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`10
Ool0085oo`<0021oo`0ONkIg]W^gMkIg^7>GMkQcVG>iIgY[VfMkJg]WNVMlHe]WO6=KGcaK75llFaaO
?5/LFcaFo5/LE_aK75;lEa`00UKl03ABo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlOol0045oo`00OWoo0`008goo00=g]W^fMkH00gNh00eg]g>iLiUc^FMkJg]SFfMLHe]WFf=KIeaS
F`07Fa`3E_`00eLLE_aFo002E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=B
o005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QBg5;lD_aBo5;LD_aoo`00@7oo001lOol2
000UOol0F7NfNkMg]WNhLiMg^7NgLkUcVG>iLiUc^F=KIgaSFfMlHe]WO6=KHeaO>ellFaaK?5/LGcaG
75/LD_aG75KlEaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_ao
o`00?goo001iOol30002Ool2000ROol00gNfNkIg]P03MkP01WNgLkUcVG>iLiUc^@9_VP08He]WFf=K
IeaO?6=LGcaSG0AK7004EaaK75/LFa`3E_`02ELLE_aFo5;lE_aBo5KlD_aFo003D_`00eKlD_aBo00:
D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003
D]aoo`0003moo`00Mgoo0P00:Goo00ek]gNfNkIcUgNhMkMc^G>ILkUcVG>iJgY_V`02KiX03V]jHeaO
>f=LGc]SG5lkHeaFo5/LEaaK75KlFa`2Ea`0>e;lEaaFo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo0000?Woo001dOol3000ZOol00g^fMkIk]P02MkP01WNgMkQc
VG>iLiUc^@E_VP07Jg]WNf=LGcaSG5llHe`00Ull00EG75/LFaaK75LL009K70MFo003D_aFo5;l009B
o003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`0kOol0079oo`8002eoo`0<Ni=k]7^CNkEk]7^eLiUc
^G>ILkU[NVnK0VnJ019[NV^KIg][NelkHeaO>ellFa]O?5/LGcaFo5/LEaaK75KlFa`2E_`0>U;lEaaB
o5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L001B
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`00?Goo001_Ool3
000^Ool00g^CNkAk]003NkD017NfNkIg]W^f16nJ0V]k00AWNf]kJg][N`QO?006E_aG75KlEaaFo5LL
1UKl0e;l00EFo5;lD_aBo5Kl00QBo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo002Ool00`00Oomoo`0jOol006eoo`800003
Ool007oo02ioo`1LNkAkTg^dNkAk]GNDNkMg]W^fLiMg^7NgMkQWNV^KIg][NfMjJi]SFfMlFa]O?5/L
GcaK6ellFaaK?5KlFaaFo5/LE_aK75;lE_aBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg09oo`03001oogoo03Uoo`00JWoo0`00<Woo0g^d0g^e00Yk]WNfNkIg]WNh
MkMg^7>ILkUWN`9[N`06IeaSFfMKHe]WG6=K1U/L00EG75KlEaaFo5LL00AFo004D_aFo5KlE_`3D_`0
0eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0003]oo`00Igoo0`00=Goo065kTg^dNi=k]GNDNkEg]W^f
MkIg^7NgMkQcVG>iLiUc^F=KIgaSFfMlHe]WO6=KHeaO>ellFaaK?5/LGcaK75LLD_aG75KlEaaBo5LL
D_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000j
Ool006Eoo`8003Moo`9k]009Ni=k]G^eNkEg]W^fMkIg^7Ng009g^003LkUcVG>i009_VP09He]WFf=K
IeaSFf=LGcaSG5ll00=K7004EaaK75LLEa`3E_`02ELLE_aFo5;lE_aBo5KlD_aFo003D_`00eKlD_aB
o00:D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00U;l00<007ooOol0>7oo001ROol3000iOol04G^dNi=k]7NDNkEg]W^f
MkIg^7NgMkQcUg>iLiUc^F]jKi/00VnJ00iSFfMlGc]SG5lkHeaO>f=LGc]K75LLFaaFo5/L0ULL041B
o5LLE_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`003Uoo`00H7oo0P00>goo00=k]7^CNk@00g^e00Ak]WNfNkIg]`9g^004LkUcVG>iLiT5KiX0
1UllHeaO?6=LGcaSG0=O?006FaaG75/LEaaK75LL1eKl00ABo5KlD_aFo0iBo005D]aBo5;lD_aBg003
D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;l
D]aBo7oo000hOol005eoo`<00003Ool007oo03Yoo`0@Ni=k]7^CNkEk]7^fMkIk]gNgMkQcUg>iLiUc
^G>IKi/2KiX04V]jKi]WNf]kGc]SG5lkHeaK6ellFaaO?5KlFaaG75/LE_aK709Fo00oD_aG75;lE_aB
o5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo000E_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo00003Qo
o`00Fgoo0P00?goo00IkTg^dNkAk/g^CNk<2Nk@3NkD017^fMkIk]WNf1FnJ00EWNf]kJg][NfMk00MO
?006E_aG75KlEaaFo5LL1UKl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001B
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol0
000gOol002ioo`@002Ioo`<0045oo`0WOk=kTWncNi=k/g^CNkAkTg^eMiAk]GNfNkIg]WNhMkM_VV]j
Ji]WNf]kIgY[VfMkIgaSFellFaaO?5/KGcaK75/lE_aK75KlFaaFo5/L009Fo00oD_aFo5;lE_aBo5Kl
D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00029oo`<0
015oo`00;Goo00<007ooOol00Woo00<007ooOol08Goo0P00A7oo0g^C00Ak/g^CNkAkT`=k]@05MkIk
]WNfNkIg]`02MkP00f]kIg][N`02Jg/016MkIe]SFfML0ell1E/L00AFo5LLE_aG70AFo004D_aFo5Kl
E_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo02=oo`03001oogoo00mo
o`00<Woo00<007ooOol07Goo1000AGoo06YkTWncNi9k/g^BNkAkTg^dMiAk]G^dNkIg]W^gMkMg^7>G
LkUcVF]kIgY[Vf=KIgaSFfMlHe]WO5/LGcaK75/lFaaO?5/LFcaBo5LLE_aG75;lEaaBo5KlD_aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol002=o
o`03001oogoo00moo`009Goo1P001goo00<007ooOol077oo0`00Agoo00MkTg^BNk=kTg^cNi=k]003
NkD017^fMkIk]WNg0WNh00ec^G>ILkUcVG>iHe]WFf=KIeaSFfMKGcaSG006Fa`00eLLFaaFo002E_`0
0eLLE_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;L
D_aBo5;lOol0025oo`03001oo`00011oo`00;Woo100077oo0`00BGoo01Eo/g^BOk=kTWncNi=k]7^C
NkEk]7^eMkIk]gNgMkQcUgNhLiUc^G>ILkT00VnJ00YSFfMlHe]SG5lkHeaO>f=LFaaO?09K7019E_aK
75LLEaaBo5LLE_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg7oo00008Goo00<007oo000047oo000^Ool00`00Oomoo`0JOol3001<
Ool01G^BNi=kTg^cNi<00W^d0g^e00=g]W^fMkH00gNh00AcVG>iLiUc^@A_VP0?GcaSG5llHeaO?6=L
GcaSG5LLFaaG75/LEaaK75LL00MFo004D_aFo5;lE_`>D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aB
o5;l008001moo`05001oogooOol0000?Ool002ioo`03001oogoo01Qoo`8004moo`06Ok=kTWncNi=k
]7^C0W^d00]k]GNDNkMg]WNhLiMg^7>ILkUcVG>i009_VP0BJgY_VfMkJg]O>f=LGc]SG5lkGcaK?5ll
E_aK75LLFaaFo5/L0UKl04EBo5LLD_aFo5;LE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo00007Woo00D007ooOomoo`0000moo`00;Woo
1@004goo0`00D7oo0W^C00=k/g^CNk<00W^d0g^e00=k]7^CNk@00W^e00AcVG>iLiUc^@A_VP05Ig][
Nf]kJg]WN`06Gc`01e/LEaaK75KlEaaFo5LL00IFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00QBg5;lD_aBo5;LD_aoo`007Goo0`0000Aoo`00000000ioo`00A7oo0P00Dgoo019kTWnc
Ni=k/g^CNkAkTW^cNi9o/g^CNkAgU7^eMkIk]WNfNkL2KiX0G6]jKi]WNf]kIgY[VfMkIgaSFellFcaO
?5/KGcaK?5/LE_aK75KlFaaFo5/LD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0009Ool4000TOol0045oo`<00003
Ool007oo055oo`=kT`08Nk=kTg^CNi9k/g^CNk=kT`9k]09k]@04NkIg]W^fMkL3MkP02FMkJg][Nf]k
Ig]WFf=KIeaSF`03Gc`3Fa`01eLLE_aG75KlEaaFo5LL009Fo004D_aFo5KlE_`3D_`00eKlD_aBo00:
D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol000Moo`03001oogoo009oo`03001o
ogoo025oo`00?goo0P00Egoo02Eo/g^BOk=kTWncNi9o/g^BOk=kTg^dNi=k]G^dNkIg]W^gMkIg^7>G
MkQcVG>iIgY[Vf=KIgaSFfMlHe]WO6=KGcaK75/lFaaO?002Fa`0BeKlFaaFo5LLD_aG75;lE_aBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LOol00007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003aoo`<005Qoo`03Ni=kTW^D009k
T`05Ni9kTg^CNk=kT`03Nk@2NkD00gNfNkIg]P03MkP03G>ILkUcVG>iHe]WFf=KIeaSFfMKHe]SG5ll
00IK7005EaaFo5KlE_aG7004E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00001Woo00<007ooOol00Woo00<007ooOol08Goo000j
Ool2001KOol02g^COkAkTWncNi=o/g^BOk=kTg^cNi<00W^d00]k]GNfNkMg]WNhLiMg^7NgLkUcVG>i
009_VP0>He]WO6=KIgaO>f=LGc]SG5/LGcaK75/lE_aK709G7018D_aG75KlEaaBo5KlD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;l0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol08Goo000gOol3001MOol00g^DNi=k
T`05Ni<027^cNkAk]7^CNkEg]W^fMkH3MkP017NgLkUcVG>i1FnJ00mSG5llHeaO?6=LGcaSG5LLFaaG
75/LEaaK75KlEa`01UKl00ABo5KlD_aFo0iBo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo003Ool007oo00Aoo`03001oogoo009oo`03001oogoo025oo`00=Goo0P0000=oo`00Ool0G7oo
07Ao]7^COk=kTgncNi9o/g^CNk=kTW^dNi=k]GNDNkMg]W^fLiMg^7NgLkUcVG>iLiU_VV]jKi]_VV]k
IgYSG5lkHeaO>f=LFcaO?5KlFaaG75/LE_aK75;lE_aBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol08Goo000bOol3001QOol00g^CNiAkT`03Ni<02W^B
Nk=kTg^dNi=k]7^eNkIg]W^f0WNh00Eg]g>iLiUc^G>I00A_VP=[N`03GcaSG5ll00EO?006EaaK75LL
EaaFo5LL1eKl0U;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00=Bg5;lD_`00`0017oo100097oo000_Ool3001SOol0NG^COkAkTgncNi9o/g^BNk=kTWncNi=k]7^B
Ok=kTg^dMiAk]G^dNkIg]W^gMkI_VV]jKi]WNf]kIgY[VfMkJg]K6ellFcaO?5/KGcaK?5llE_aK75Kl
FaaFo5/LD_aFo5;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002aoo`00;Goo0P00IWoo00=kU7^CNi<0
0W^C00EkTW^CNi=k/g^B009kT`04Nk=kTg^dNk@3NkD00gNfNkIg]P03MkP026MkJg][Nf]kIg][Nf=K
Ie`5Gc`3Fa`01UKlEaaFo5LLE_aG709Fo004D_aFo5KlE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;l
D]`00e;l00EBg000001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aoogoo0000:goo000ZOol3001WOol0:GndNi=o
/g^BOk=kTWncNi9o/g^COk=kTWncNi=k]7^CNkEk]7^eMkIk]gNfNkIc]gNhLiUc^FMjJi]WNfMlHe]W
O6=KIgaSFellFaaK?5/LGc`00U/L025Fo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]`00`0002YBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`2
Ool00`00Oomoo`0XOol002Qoo`800003Ool007oo06Moo`03Ni=kU7^C00QkT`03Nk=kTg^d009k]0=k
]@03NkIg]W^f009g^00=LiUc^G>ILkUcVFMKHe]WG6=KIe]SFf=LGc`01U/L00EG75KlE_aFo5LL00AF
o004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00`0000IBg5;lD_aBo5;L0002D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00QBg5;lD_aBo5;LD_aoo`00:Woo000VOol2001[Ool03g^COkAkTWncNi=o/g^BOkAkTgncNi9o
/g^CNk=kT`02Nk@06g^eMiAk]gNfNkIc]gNhMkMc^G>ILkUcVFnJJgYWO6=KIgaO>f=LGc]SG5/LGcaK
75/lE_aK7002Ea`06U;lEaaFo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_`20000<E;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L009oo`03001oogoo
02Moo`009Woo0P00Jgoo00=kU7^CNi<00g^C00=kU7^CNi<00g^C00Ak/g^dNkAkT`9k]@03NkIg]W^f
009g^005MkMc^G>ILkUcV@04KiX03f=LGcaSG5llHeaO?6=LEaaK75LLFaaG75/LEaaK7006E_`015;l
E_aBo5Kl35;l0`000e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg7ooOol0
02Qoo`009Woo0`00JGoo04=o]7^COk=kTg^eNiAo]7^COk=kTWncNi9k/g^BNkAkTg^eMiAk]GNfNkIg
]WNhMkMc^G>ILkUcVFnJJgY_VfnJJg]WNV=LGc]SG5lkGcaK?5llE_aK75LLFaaFo5/LE_aK75;lEaaB
o5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo0030000>UKlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00:7oo000VOol01000Oomoo`00J7oo00AkTg^D
NiAkU@9kU0AkT`06Ni9k/g^CNkAkTg^d0W^e00Ug]W^fMkIg^7NgLkUcVG>iLiT016nJ0f]k00=WNf]k
Gc`01Ull00EG75KlEaaFo5LL00MFo09Bo003E_aBo5;l00ABo0<000=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`0UOol002Eoo`03001o
ogoo009oo`03001oogoo06Aoo`0ZMiEk]WNENkEkU7neNi=o]7^BOk=kTWncNi9o/g^CNkAkTWncNi=k
]7^CNkEk]7^eMkIk]gNfKiY[NVnKKiY[NfMjJi]WNf]kHe]WO5/lGcaK6ell0U/l0U/L00AFo5/LE_aK
709Fo00:D_aFo5;lE_aBo5KlD_aFo5;LE_`30000@EKlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo00009goo000UOol00`00Oomoo`03
Ool00`00Oomoo`1SOol01g^fNiIkUG^DNkEkTg^D009kT`0<Ni9kTg^CNk=kTg^dNi=k/g^CNkAk/g^d
0W^e00=g]W^fMkH00gNh00Ug]f]kJg][NfMkJg]SFfMLHe/00ell15/L00AFo5LLE_aG70AFo004D_aF
o5KlE_`2D_`3000;D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00=oo`00Ool09Goo000UOol00`00Oomoo`04Ool00`00Oomoo`1QOol057^fMiEk]W^DOkEk
U7ndNi=o/g^COk=kTWncNi=o/g^BOk=kTg^cNi<2Nk@08g^eMiAk]gNfNkIc]gNhMkMc^G>IJi]WNfMl
He]WO6=KIgaSFellFaaK?5/LGcaK75/lD_aG75KlEaaBo5LLD_aFo5;lE_`00`0004IFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg09oo`03001oogoo02=oo`009Goo0P001Woo0P00HGoo0W^F00AkU7^eNiAkU0]kT`9k
/`07NkAkTg^eNkEk]WNfNkH00WNh00eg]g>iLkUc^G>IIe]SFfMLHe]WFf=KHeaO?005Fa`00eLLFaaF
o002E_`015LLE_aFo5;l0P0000=Fo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000UOol002Eoo`03001o
ogoo00Moo`03001oogoo05eoo`0eMiEk]WNEOkEkU7^eNi=o]7^COk=kTWndNi=o/g^BOk=kTg^cNi9k
]7^CNkEgU7^eMkIk]W>gMkQg]gNhLiUc^G>IKiY[NVMlHe]WO5lkHeaO>f=LGc]SG5LLFaaFo5/LEaaK
75;lEaaFo0030000Ce;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002Aoo`009Goo
00<007ooOol027oo00<007ooOol0G7oo0W^F00Ek]G^DNiEkTg^D00=kT`03NiAkTg^C009kT`06Ni9k
/g^CNkAkTg^d0W^e00Ig]W^fMkQg^7NgMkP2LkT00g>IKiY_VP03KiX01UllHeaO?6=LGcaSG09O?005
EaaK75LLFaaG70030004E_`00e;lE_aBo002D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`0002=oo`009Goo00<007oo
Ool02Goo00<007ooOol0FWoo02=k]WNENkIkU7^eNiAo]7^COk=kU7ndNi=o/g^BOk=kTWncNi9o/g^C
NkAgU7^eNkAk]WNfMkQg]gNhLiUc^G>IKiY[NVnK009_VP0;IgY[VelkHeaO>ellFcaO?5/KFaaG7003
0000EUKlFaaBo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000SOol0
02Aoo`8000aoo`03001oogoo05Uoo`04NiIk]W^DNiD2Ni@017^CNiEkU7^D17^C00MkTW^CNi=k/g^C
NkAk/`02NkD01G^fMkIg^7NgMkP00W>i00=cVFnJKiX00fnJ0V]k00=WNf]kGc`015ll0`0000AFo5LL
E_aG70IFo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo009D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`008Woo000TOol00`00Oomoo`0<
Ool00`00Oomoo`1GOol0:gNENkIgUG^eNiAo]G^CNkIkU7neNi=o]7^BOk=kTgncNi9o/g^CNkAkTgnc
Ni=k/g^CNkEk]7^eMkIk]gNfKiY[NVnKKiY[NfMjJi]WNf]kHe]WO5/l00<00008FaaK?5/LFaaFo5/L
E_aK709Fo01AD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L009oo`03001o
ogoo01moo`0097oo00<007ooOol03Goo00<007ooOol0EWoo00Ek]W^FNiEkU7^e009kUP04NiAk]G^C
Ni@5Ni<017^cNi=k]7^c0W^C0W^c0W^d0W^e00=k]WNfMkP00WNh00Mg]f]kJg][NfMkIeaSF`030006
Fa`015KlEaaFo5LL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`00025oo`0097oo00<0
07ooOol03Woo00<007ooOol0E7oo01Qg^G>HNkMgUg^gMiEk]WNEOkEkU7ndNi=o/g^COk=kTWncNi=k
/g^BOk=kTg^cNi82Nk@03G^eMiAk]gNfNkIc]gNhMkMc^G>ILkUSFfMl0080001UHe]WO5lkHeaK75/l
FaaO?5/LFcaBo5LLE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LOol0000POol002Aoo`03001oogoo00moo`03001oogoo059oo`06MiUcV7>HMiMg]gNG0W^F
00Ek]G^DNiEkTg^D00EkT`08Nk=kTg^CNi9k/g^CNkAkT`=k]@05MkIk]WNhMkQg]`03LkT300001fML
He]SG5llHeaO?6=L00AK7003EaaK75Kl009Fo009EaaFo5KlD_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l0Woo00<007ooOol07Goo000TOol2000AOol00`00Oomoo`1@Ool08gNiLiQgVGNG
NkMgUg^fMiEk]W^DNkEkTgndNi=o/g^BOk=kTWncNi9o/g^BNk=kTWncNi=k]GNDNkEg]W^fLkMg^7Ng
LkT00`0006]_VV]jKi]_VV=LGc]SG5lkHeaO>f=LEaaK75KlFaaG75/LE_aG75;lE_aBo5LLD_aFo5;L
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0001moo`008goo00<007ooOol0
4Woo00<007ooOol0CWoo00EgVG>HLiQcV7Ng009gU`04NiIk]W^DNiD2Ni@4Ni<01G^BNiAkTg^CNi80
0W^C00=k/g^CNk@00W^e00Ag]W^fMkIg^0<00003LkUcVFnJ00=_VP9[N`03HeaO?6=L00AO?006EaaK
75LLFaaFo5LL1UKl00=Bo5KlD_`00U;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo000N
Ool001Yoo`@000Eoo`03001oogoo01=oo`03001oogoo04eoo`0NLiQgVG>HNkMgUg^gMiEk]WNENkEk
U7ndNi=o/g^BOk=kTgndNi9o/g^BOk=kTWncNi=k]7NDNkEk]7^f0`00071c^G>ILkUcVFnJJgY_VfnJ
Jg]WNV^KIg]O?5/KGcaK?5llFa]O?5KlFaaFo5/LE_aK75;lEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg09oo`03001oogoo01]oo`006Goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol057oo00<007ooOol0Bgoo0g>H00YgVGNGMiMgUg^fNiIkUG^DNkEk
T`9kU003NkEkU7^D00EkT`05Nk=kTg^dNk=k]@0300001W^eNkAk]GNfNkIg]P=_VP07Ig][Nf]kJg]W
NfMLHe/01Ell0U/L00MFo5LLE_aG75KlEaaBo003E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo00000=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo7oo00007Goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0E
Ool00`00Oomoo`19Ool06W>HMiUcV7NiMiMk]gNGNkIgUG^fNiAo]G^COkAgUGneNiAo]7^COk=kTgnc
Ni9o/g^CNk<30000NW^cNi=k]7^dNkEg]W^gMkIg^7>gMkQWNf]kIgY[VfMkIgaSFfMlHe]O?5/KGcaK
75/lFaaO?5KlFaaFo5LLE_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg7oo000LOol001Uoo`03001oogoo009oo`03001oogoo009oo`8001Moo`8004Qo
o`=cV005MiUcV7NGMiMg]`02NiH00g^DNkEkU002NiH01G^eNiAkUG^CNi@01G^C0P000W^C0W^c0W^d
0W^e00=k]WNfNkH00WNh00]cVG>iJg][NfMkIeaSFfMLHe]WG6=K00MK7003E_aG75Kl00=Fo008D_aF
o5KlE_aBo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0001]oo`006Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol067oo00<007ooOol0A7oo01M[NVmkJgY_Vf]jNkMgUg^gMiEk]WNENkQg
Ug^fMiEk]W^DNkEkTgndNi=o/g^B00<0000NNi9o/g^CNk=kTW^dNi=k]GNDNkMg]W^fLkMg^7NgLkUc
VG>iLiUWO6=KIgaSFfMlHe]SG5lkFcaK75ll0U/L00IFo5/LE_aG75;lEa`2E_`0F5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg0006goo000IOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`12Ool026]jJg][NV]kJgY_VVnILiX3
LiP01gNgMiMgUg^FNkIkU7^E009kU005Ni<00000001kTP03Ni<01G^BNk=kTg^dNi<00g^e00Eg]W^f
MkQg^7Ng00=c^@0ALiU_VVnJIeaSFfMLGcaSG5llHeaO?5/LEaaK75LLFaaG7002E_`00eLLE_aFo002
E_`015;lE_aBo5Kl45;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`006Woo000IOol00`00Oomoo`02Ool01@00Oomo
ogoo00007Goo00<007ooOol0@7oo01=[NVmkJgY_Vf]jLiY_NG>JKgUgVG>HMiUgUg^gMiEk]WNENkEk
U0030000R7^BOk=kTWndNi9o/g^BOk=kTWncNi=k]7NDNkEg]W^fLkMg^7NgLkUcVG>iLiU_VV]jKi]_
VV=LGc]SG5lkHeaO>ellFcaK75KlFaaG75/LE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`001goo1@003Goo000JOol40004Ool2
000MOol00`00Oomoo`0nOol02F]jJg][NV]kJgY_VVnILiY_N@02LiP01WNIMiMgUgNGNkIkUP<00006
Ni=kU7^CNi=kTW^D0W^C00IkTW^CNi=k/g^CNk@2NkD01W^dNkIg]WNhMkMg^09c^@E_VP9[N`03HeaO
?6=L00AO?006EaaK75LLFaaFo5LL25Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00=Bg7oo00001goo00D007ooOomoo`0000eoo`008Woo00<007ooOol07Goo00<007ooOol0?7oo
00m[NVmkJgY_Vf]jLiY_NG>JKgUgVG>HMiUcV7^gMiL00`0001YkU7neNi=o]7^BOk=kTgndNi=o/g^C
Ok=kTWncNi=k]7^CNkEk]7^fMkIg^7NgMkQcVG>i0VnJ01A[NVnKIg][NfMjJi]WNf]kFa]O?5/lGcaK
6ellE_aK75KlFaaFo5/L0UKl05eBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol03Woo000ROol00`00Oomoo`0NOol0
0`00Oomoo`0jOol2He`01f]jJg][NVnJKiUcVVmi009cV003MiUcV0000080009kUP08NiAk]G^DNiAk
Tg^eNiAkU@EkT`03Nk=kTg^d009k/`03Ni=k/g^c009k]004NkEg]W^fMkL3MkP026MkJg][Nf]kIg][
Nf=KIe`3Gc`3Fa`01UKlEaaFo5LLE_aG70AFo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool0029oo`03001oogoo01mo
o`03001oogoo03Moo`0=HeaSFf=LGe]SG6=KLiY_NG>JKgUcVW>HMiT00P0001UgUg^hMiEk]WNEOkEk
U7ndNi=k]W^DNkEkTgndNi=o/g^BOk=kTg^cNi=o/g^CNk=kT`02Nk@0Ng^eMiAk]gNfMkQc]gNhLiUc
^FMjJi]WNfMlHe]WO6=KIgaK75llFaaK?5/LGcaK75LLD_aG75KlEaaBo5KlD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol00008Ool00`00Oomo
o`0<Ool0029oo`03001oogoo021oo`03001oogoo03Aoo`MSG005Ig]WFfMkIe]WN`03000017>HMiMg
]gNG0W^F00Mk]G^DNiEkUW^fNiAkU@02Ni@4Ni<00g^BNk=kT`02Ni<017^cNi=k]7^C0W^e00=k]WNf
MkP00WNh00acVG>iLkUc^F=KIeaSFfMLHe]WG5llHe`4Fa`015LLFaaG75LL0eKl00UG75KlE_aBo5Kl
D_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0Woo00<007ooOol0
1Woo00<007ooOol02goo000QOol2000SOol00`00Oomoo`0bOol02U/LGceSFf=LGe]SG6=KIgaWFfMl
0`0002U_Vf]jKg]gUg^hMiMk]WNENkIgUg^gMiEk]WNENkEkU7ndNi=o/g^BOk=kTW^cNi9o/g^BNk=k
TW^dNi=k]GNDNkEg]W^fLkMg^7NgLkUcVG>i009_VP1_He]WO6=KHeaO>f=LGc]SG5KlFaaG75/LE_aK
75KlEaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`0
05;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L009oo`05001oogooOol00003Ool00`00Oomoo`0;Ool0025oo`03001oogoo
02=oo`03001oogoo02moo`9K?003FceK?5/l009SG003Ie]WN`0000800008Ig][NV]kJgY[NfnILiY_
N@9cV00;MiUgUgNGMiMk]W^FNiEkU7^eNi=kU002Ni<02W^BNi=kTg^CNi9k/g^CNk=kTg^d0W^e00Eg
]W^fMkQg^7Ng00=c^@E_VP05HeaO?6=LGcaSG002Gc`01ULLFaaG75/LEaaK70IFo004D_aFo5;lE_`8
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0P0017oo0`003Woo000QOol0
0`00Oomoo`0TOol00`00Oomoo`0/Ool025/lGceK75lmFcaO?E/LGcd30000;FMlIe]_Nf]jKi][NVmk
KgUcVVmiLiYcV7NILiQk]gNGNkIgUG^fNiAo]G^COkAkTWncNi9o/g^COk=kTWncNi9o/g^CNkAgU7^e
MkIk]WNfMkQg]g>iLiUc^@02KiX0MF]jKi]_VV]kIgYSG5lkGcaK6ellFcaO?5KlFaaG75/LE_aK75;l
E_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LOol0000DOol0025oo`03001oogoo02Eoo`03001oogoo02Uoo`05EaeG75LMFcaK
?@02Fc`3000045llIe]WNfMKJg][NV]kJgY[Nf]jLiY_NFnJLiQgVG>H0gNG0W^F00AkU7^eNiAkU0=k
T`04NiAkTg^CNi82Ni<02W^cNi=k]7^cNkEk]7^fMkIg^7Ng0g>i16nJ00EWNf]kJg][NfMk00MO?006
E_aG75KlEaaFo5LL0UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0BOol0025oo`03001oogoo02Ioo`03001oogoo02Eo
o`07EceG75/mEaaG?ELLFcd00`0002UOG5llGeaO?5mLGca_Nf]jKi][NVmkJgYcVVmiLiYcV7NILiQg
VGNGNkQgUG^fMiEo]G^DOkAkTgncNi=k]G^COkAkTgncNi9o/g^CNkAkTg^e009k]020Ni=k]G^dNkEg
]W^gMkMg^7>gJi]WNf]kIgY[VfMkIgaSFellFcaO?5/KGcaK75/lE_aK75KlEaaBo5LLD_aFo5;lE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlOol001=oo`008Goo0P00:7oo0P008goo0e<M00AG7ELLEaeG7@800003EaeO?5mL00=O?003GeaO
?6=L009SG008JgY[Nf]jLiY_NFnJLiQgV@9cV0=gU`9kUP04NkEkU7^ENi<2Ni@00g^ENi=kU005Ni<2
Nk<017^dNi=k/g^c0W^d00Ak]GNfNkIg]P9g^003LkUcVF]k009[N`05He]WG6=KIeaSF`07Fa`3E_`0
0eLLE_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00QBg5;lD_aBo5;LD_aoo`004Woo000QOol00`00Oomoo`0YOol00`00Oomoo`0MOol01e;lEaeC75LM
D_aG7E<L00<0000_EaaK?ELLFceO?5mLGcaOG5llHeaOFf=LHe]SG5mKLiY_NG>JKgUgVG>HMiUgUg^h
MiMk]WNENkIkU7^eNi=o]7NENkEkU7ndNi=o/g^BOk=kTg^cNi=k]7^BNk=kT`02Nk@05G^eMiAk]gNf
MkQc]gNhLiUc^G>ILkUSFfMlHe]WO6=KHeaO>ellFaaK?002Fa`0JELLFaaBo5LLE_aG75;lEaaBo5Kl
D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_`0000BOol0021oo`03001oogoo02]oo`03001oogoo01Yoo`IC7@<0000:DaeK?ELLFceG
75/mEaaK?EllGe`7He`01FMkIe]WNfMKMiT00g>H0gNG00QkUW^fNiAkUG^DNkIkUW^E0W^D00IkTg^D
Ni=kTg^BNk<2Ni<01G^BNk=kTg^dNi<00W^e00=k]WNfMkP00WNh00AcVG>iLkUc^@9_VP0<He]WG5ll
HeaO?6=LGcaSG5LLFaaG75/L0ULL1UKl00ABo5KlD_aFo0iBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<0
05;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo003D]aoo`00015oo`0087oo00<007ooOol0;7oo00<007ooOol05Woo00IC7E;l
DaeBo5<MD_`30000@5<LEaeBo5LMDaaK?ELLFceG75/mEaaK?F=KHeaOFf=LHe]SG6MKIgaWFfMlIe]_
Vf]jKg][NW^hMiMk]gNENkIgUG^gMiMk]WNENkIkU7neNi=o]7^BOk=kTW^cNi9o/g^BOk=kTW^dNi=k
]GNDNkEg]WNhLkMg^7>ILkUcVG>i0VnJ07M[NVnKGc]SG5lkHeaO>ellFa]O?5LLFaaFo5/LEaaFo5;l
EaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00011oo`0087oo00<007oo0000;Goo00<007ooOol04goo00=B
oE<MD_d00U<M0`0000AC7ELMDaeC7@9G7@08EaaG7ELMFceG75/mEaaK?@9K?0ASG00?Ie]WNfMKIg]W
Ff]kJgY[Nf]jLiY_NFnJLiQgVG>H00=gU`9kUP04NiAk]G^CNi@2Ni<01G^BNi=kTg^CNi800W^C00=k
/g^CNk@00W^e00Eg]W^fMkQg^7Ng009c^@E_VP03Ig][Nf]k00MO?09G7003E_aG75LL00IFo09Bo003
E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2000@Ool0021o
o`8002moo`03001oogoo00moo`05D_aC7DklDaeBo0030000A5;lDaeBo5<MD_aG7E<LEaeC75LMDaaG
7E<LGceK75lmFcaO?E/LGceK?6MlIe]WO6MKIga[NVnKJgY_Nf]jLiY_NG>JKgUgVG>HMiUgUg^hMiEk
]WNEOkEkU7ndNi=o/g^BOk=kTgncNi=o/g^BOk=kTg^dMiAk]G^dNkIc]gNhMkMc^G>IKi/2KiX0NV]j
Ji]WNf]kIgYWO6=KGcaK6ellFcaO?5/LGcaFo5/LE_aK75KlFaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo
000?Ool000Eoo`D000Eoo`8000Eoo`@000Ioo`03001oogoo02moo`03001oogoo00aoo`04DaeBoE;m
D_d300000e;mDaeBo@06Dad00eLMEaaG7@02Ead015LLEaeG7E/m0e/l015K?E/lGcaO?6MkIe]WNf]j
Jg][NV]kJgY[NfmiKiY_VGNI009cV0=gU`9kUP07NkEkU7^DNi=kU7^CNi@01G^C00Ek/g^CNkAk/g^e
009k]007Nk=k]G^dNkIg]WNhMkL00WNh00Q[NfMkJg][NfMLHe]WG6=K0Ull15/L0eLL0eKl00=G75;l
E_`00UKl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`02E;LD_aBo5;lD]aBo000D_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00U;l0Woo00<007ooOol037oo0004Ool200001Goo000007oo000017oo0P0017oo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0<7oo00<007ooOol027oo00EC7DklDae>o5<M0080001P
D_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG7E<LEaeG75LmEaaK?ELLGceK75lmGcaOG5llGeaO?5mL
JgY_Vf]jKg][NVnKKgUcVVmiMiUcV7NILiQk^7NGNkIgUG^fNiAk]G^COkAkTg^eNi=o]7^COk=kTWnc
Ni=k/g^COk=kTg^cNi=k]G^dNkEg]W^gMkMg^7>gLkUcVF]kIgYWO6=KIgaSFfMlHe]K?5/LGcaK75/l
FaaG75KlEaaBo5LL0UKl06EBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0000ioo`0017oo0P000Woo00<007oo
00003goo00<007ooOol00goo00<007ooOol0<Goo00<007ooOol01Goo00A>oE;mD_eC7@<0000:DaeB
oE;mD_eC7E;mDaeBoE<MD_d6Dad00eLMEaaG7@02Ead015LLEaeG7EmL0ell00=OG5llGc`00f=L00M[
Nf]jJg]_NFnJKiUgV@03LiP3MiL02W^FNkIkU7^ENi=kU7^CNiEkTg^D1G^C0W^c0W^C0W^c0W^d00Ak
]GNfNkIg]`9g^00<LkUcVG>iLkUWG6=KIeaSFfMLGcaSG5ll0e/L00=G75/LEa`00UKl00=G75KlE_`0
0UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00UBg5;lD_aBo5;L
D_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L009Bo003Ool007oo00aoo`0017oo0P000Woo00<007oo00003goo00<007ooOol0
0Woo0P00=7oo00P007ooOomoodklDae>o5<M0`0004IC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;l
EaeBo5<MD_aG7E<LEceG75/mEaaG?ELLFceG75mLGcaOG5llGeaOFf=LHe]SG5mKHea_NG>JKgUcVW>H
MiUcV7^hMiMk]gNENkIgUG^eNiAk]WNENkIkU7ndNi=o/g^BOk=kTW^cNi9o/g^CNk=kTP9k]00;NkEg
U7^gMkIg^7>gMkQcVG>iLiU_V`02KiX0NElkHeaO>f=LGc]SG5lkFaaFo5/LEaaK75KlEaaBo5KlD_aG
75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0000aoo`0017oo0P000Woo00<007oo00002goo10001Goo
00<007ooOol0<Woo00=BoE<MC_d00U;m00IC7@00000005<MC_d2D_d035<MD_eC7E;mDaeBoE<MD_eC
7E;mDaeBo@AC7@0>EaeC7E<MDaeG7ELLFceG75/mEaaK?ELLGeaO?0MSG004Ie]WNfMKIg/3LiP02GNI
MiMgUgNGNkIkUW^ENiAgU`02NiH2Ni@4Ni<02G^BNk=kTg^CNi9k/g^CNkAkT`02NkD00g^fMkIg^002
MkP00g>ILkUc^@03KiX2Jg/015llHeaO?6=L0ell00=K75LLFa`00ULL25Kl0e;l00=Fo5;lD_`01U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol000ao
o`000goo0`0000Eoo`00001oo`0000]oo`03001oogoo00Ioo`03001oogoo031oo`05Dae>o5<MC_eC
7@030000Ee<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMD_aG
7E<LEaeG75/mEaaK?ELLFceG76=LGe]SG6=KHeaOFf=LIe]WO6MKIga[NVmkJgY_VgNGNkMgUg^fMiEk
]WNGNkQgUG^fMiEo]G^COkAkTWncNi9o/g^BOk=kTWncNi9o/g^CNkEgU7^gMkIk]W>gMkQcVG>iLiU_
V`02KiX0O6MkJi]WNf]kIg]O?5/lGcaK6ellFcaK75KlFaaFo5/LE_aG75;lE_aBo5KlD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001B
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aoo`002goo0005Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`06Ool0
0`00Oomoo`0]Ool01E<MC_eBoE;mDad00`0000EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeB
oE<MD_d3Dad00e;mDaeC7@04Dad00eLMEaaG7@02Ead015LLFceG75/m0e/l015K?F=LHeaSG6MkIe]W
NfMKIg][NV]kJgY[NfmiKiY_VGNI009cV0=gU`9kUP03NkEkTg^D009kT`03Ni9kTg^C00AkT`03Nk=k
Tg^d009k]@05MkIk]WNhMkQcV@02LkT3KiX2Jg/01FMkJg][NfMLHe/00ell0e/L00=G75KlEa`00ULL
15Kl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01U;LD_aBo5;lD]aBo08000Yoo`001Woo100037oo1@0017oo00<007ooOol0:goo00A>
o5<MC_eC7@<0003LDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
DaeBo5<MD_aC7E<LEaeC75LMDaaG7E<LEaeK75lmFcaO?E/LGceK?5lmFaaWO6MKIgaWFfMlJgY_Nf]j
Ki]_NG>JKgUcVW>HMiUcV7^hMiMk]WNENkIkU7ndNi=o/g^COkAkTgncNi=o/g^BOk=kTg^dMiAk]G^C
NkAgU7^eMkIk]WNfMkQg]gNhIg][VfMkJg]SFfMlHe]WO6=KGcaK75/lFaaO?5/LEaaBo5LLE_aG75;l
E_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000:Ool001moo`03001oogoo02Qoo`05C_eBoE;m
Dae>o@0200001U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC
7E;m1e<M00EG75LMEaeG7ELL00=G7@=K?00AFceK?5/lFcaOG5llIg]WFfMkJgY[Nf]jJg][NVnJKiUc
VP03LiP3MiL017^FNkIkU7^D0g^C00=kUG^CNi@00g^C00=k/g^CNk@00W^c00YkTg^dNk=k]G^dNkIg
]WNhMkMg^09c^@09LiUWG6=KIeaSFfMLHe]SG5ll00=K7004EaaK75LLEa`3E_`02ELLE_aFo5;lE_aB
o5KlD_aFo003D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L008000Uoo`007Woo0P009Goo00M>oE<MC_aC7DkmDae>o0030000LTklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeB
o5LMD_aC7E;lFceG75LmEaaK?ELLEceG75lmFcaO?EllGeaO?5mLGcaOG6]jKg][NVnKJgYcVVmiLiYc
V7NILiQgVGNGNkMgUG^fMiEk]G^COkAkU7^eNi=o]7^COk=kTWncNi=k/g^COk=kTg^dNi=k]G^dNkIg
]W_GMkMg^7>ILkUcVFnJJgYWO6=KIgaO>f=LGc]SG5lkFaaG75/LE_aK709G701^D_aG75;lE_aBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol000Uoo`007Woo00<007ooOol08Woo00IC7DkmD_eBoE<M
C_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00aC7E;m
D_eBoE<MD_eC7E;mDaeBoE<MD_d4Dad00eLMDaeG7@02Ead01ELLEaeG7ELMEa`00Ull00EOG5llGcaO
?5mL009SG006JgY[Nf]jKiY_VG>J0g>H00]gVGNGMiMgUg^fNiIkUG^CNiAkUW^E009kU0AkT`03Ni9k
/g^C009kT`9k/`9k]004NkEg]W^fMkL2MkP00g>iLiU_VP04KiX015llHeaO?6=L0ell00IK75LLFaaG
75/LEa`5E_`015;lE_aBo5Kl25;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00002Goo000NOol00`00Oomoo`0POol01DklDae>oE<M
C_`00`0005e>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeC75LMD_aG7ELLEceG75/mEaaK?ELLGeaO?5mL
GcaSG6=KHeaOFf=LHe]cVVmiLiY_NGNILiQgVGNGNkMgUg^fMiEk]W^DNkIgUG^eNiAo]7^COk=kTWnc
Ni9k/g^BOk=kTW^cNi<00W^d00]k]GNfNmMg]gNhLkMc^G>ILkU[NVnK009_VP0>Ig][VelkHeaK6ell
FcaO?5KlFaaG75/LE_aK709Fo01WD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`017oo00<007ooOol0
1goo000NOol00`00Oomoo`0NOol2D_d00e<MC_d0000200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0BDae>oE;mD_eC7DkmDaeBoE<MD_eC7E;mDaeBoE<MD_eC
7E;m0U<M00EG7E<MDaeC7ELM009C7@08EaaK?ELLFceG75/mEaaK?@MSG004Ig]WFfMkIe/2LiP00gNI
LiQgU`02MiL2NiH2MiL2NiH017^DNkEkTg^D0W^C00UkTW^CNi=kTg^BNk=kTg^dNi<00W^e00Mk]WNg
MkQg^7>iLiUc^@03KiX3Jg/00fMkJg]O?005Gc`01EKlEaaG75LLE_`00ULL00=Fo5;lE_`00UKl0e;l
00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo0Moo`03001oogoo00Ioo`007Woo00<007ooOol06goo00AC7DkmDae>o0<00022C_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75LMEaaK?ELLFceG75/mFaaO?F=KHeaO
Ff=LHe]WO6MKIgaWFfmkJgY_Vf]jNkMgUg^hLiQgVGNGNkQgUG^fNiAo]G^COkAkTWncNi9o/g^COk=k
TWncNi9o/g^CNkEgU7^dNi=k]GNDNmMg]W^fJgY_VfMkJg]WNf^KIg][Nf=KIgaK?5llFa]O?5/LFcaF
o5/LE_aK75;lEa`2E_`0H5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo0Yoo`03001oogoo00Ioo`007Goo0P0067oo00IC7Dkm
D_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG
7ELL00=G7@05EaaG7ELLFceG7002Fc`00e/mFcaK?002He`036MKIg]WFfMkIe][Nf]jJg][NVnJKiUc
VP=cV09gU`9kUP03NkEkU7^D00=kT`9kU00:Ni=kTW^CNi=k/g^CNkAk]G^cNi<3NkD01WNfNkIg^7Nh
LiUc^@9[N`08Ig]WG6=KIeaSFfMLFaaK?0=K7005FcaFo5KlE_aG7004E_`015;lE_aBo5Kl0e;l00=F
o5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009B
o003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l3Woo00<007ooOol01Woo
000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@800020C_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75LMDaaG7E/lGceK75lmFcaO?E/LGceWFfMl
Ie]WO6MKKg][NVnKJgYcVVmiLiYcV7NILiQk^7NGNkIgUGneNiAo]7^COk=kTg^eNi=o]7^COk=kTWnc
Ni=k]7^BOk=kTg^dMiAk]GNfNkIg]WNhMkMc^G>ILkUcVFMlHe]WO6=KHeaO>f=LFaaK?09K701OEaaK
75;lEaaFo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg00COol00`00Oomoo`06Ool001eoo`03001oogoo01=oo`9Bo@03Dae>oE;m00<0009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@QC7@03EaeG75LM009G7@04EaaG
7E/lFcd3Fc`03U/mGcaO?6MKIg]WFf]kJgY[Nf]jKiY_VG>JKgT2LiP027NIMiMgUg^FNkIkU7^ENi<2
Ni@00g^ENiAkU003Ni<01g^cNi=k]7^CNk=kTg^d009k]@05NkAk]WNfMkQg]`03LkT04G>IKiY_VVnJ
GcaSG5llHeaO?6=LEaaK75LLFaaG75/LEa`01EKl00ABo5KlD_aFo0YBo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00IBg5;lD_aB
o5;LD_`EOol00`00Oomoo`06Ool001eoo`03001oogoo015oo`04C_eC7DklDad30000hU<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMD_aG?ELL
FceG75LmEaaK?E/lGceK75mLGcaOG5llGeaO?6mkJgY_Vf]jLiY_NG>JKgUgVG>HMiUgUgNgMiEk]W^D
NkEkTgndMiEk]G^DOkAkTgncNi9o/g^CNk=kTWncNi9k]7^CNkEk]7^fMkIg^7NgLkUcVG>iLiU_VV^J
Ki]WNf]kGc]SG5lkGcaK6ellEaaK75KlFaaFo5/LE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;L5goo00<007ooOol01Woo000MOol2000?Ool015;mDae>oE;m
0`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeB
oE<MD_d8Dad00eLMEaaG7@02Ead015LLEaeO?5mL0ell00=OG5llHe`00f=L00A_VVnILiY_N@9cV00;
MiUgUgNGMiMk]W^FNiEkU7^fNiIkU@02Ni@5Ni<017^cNi=kTg^C0W^c00Mk]G^dNkIg]W^fMkMg^002
LkT4KiX016MkJg][Nf]k1Ull0ULL00AFo5LLEaaG70AFo004D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L01aoo`03001o
ogoo00Ioo`007Goo00<007ooOol02Goo00I>o5<MC_eC7DklDad30000M5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeC75LMD_aG
7E<LEceG75/mEaaK?ELLFceO?5mLGcaOG6=KHeaOFf=LHe]WO6MKIgaWFgNILiQgVG>HMkMgUg^fMiEg
]gNGNkIgUG^fNiAo]G^COkAkTWncNi9o/g^BOk=kTW^cNi<2Nk@01g^eMkIkegNgMkQcVG>i009_VP0:
JiY_VfMkJg]WNf^KHe]WO5/KGc`2Fc`0EU/LGcaFo5/LE_aK75KlFaaBo5KlD_aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo7oo000OOol00`00Oomoo`05Ool001eoo`03001oogoo00Moo`9Bo@03Dae>oE;m
00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>DaeBoE;mD_eC
7E;mDaeBoE<MD_eC7E;mDaeBo@IC7@0<EaeC7E<MDaeK?ELLFceG75/mEaaK?ELL1V=L00QWNfMKIg]W
Ff]kJgY[Nf]j0gNG00AcV7NGMiMgU`9kUP04NiAk]G^CNi@2Ni<01g^BNiAkTg^CNi9k/g^C009k]008
NkEk/g^dNkAk]GNfNkIg]`=g^008Ig][Nf]kIeaSFfMLHe]WG0=K7005FcaK75/LFaaG7003E_`00eLL
D_aFo002E_`015;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00Aoo`03001oogoo01aoo`03001oogoo00Eoo`007Goo00<007ooOol01Goo00A>oE<M
C_aC7@<0002EDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LFceG75/mEaaK?E/LGceK
?6=LGe]SG6MKIgaWFfMlIe]_Nf]jKi][NW>JKgUcVW>HMiUgUg^hMiEk]WNEOkEkU7ndNi=o/g^COkAk
TWncNi9o/g^BNkAkTg^cNi9k]7^CNkEgU7_GMkIg^7>gMkQcVG>iLiUWO6=KIgaSFf=LGc]SG5/LGcaK
75/lE_aK7002Ea`0BE;lEaaFo5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L00Qoo`03001oogoo01]oo`03001o
ogoo00Eoo`007Goo00@007ooOom>o@9Bo@04Dae>oE;mD_d20002D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC7E;mDaeB
o@=C7@05D_eC7E<MDaeG7003Ead015LLEaeG7ELM0e/l015K?E/lFcaK?5/mIe]WNfMKIg]WFf]kJgY[
Nf]jKiY_VG>J009cV0=gU`9kUP05NkEkU7^DNiAkT`03Ni@4Ni<01W^cNi=kTg^CNkAkT`9k]@03NkIg
]WNh009g^003LiUc^G>i00=_VP0=GcaSG5llHeaO?6=LEaaK75LLFaaG75/LEa`01EKl00ABo5KlD_aF
o0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo0aoo`03001oogoo01]oo`03001o
ogoo00Eoo`0077oo00P007ooDae>oE<MC_aC7Dkm0`0008a>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E;lDaeC75LMDaaG7E<LEaeG75LmFaaO?E/lGceK75lmGcaOG6MKIgaWFfmkJgY_Vf]jLiY_
NG>JKgUgVG>HNkQgUg^fMiEk]W^DNkEkTgndNiAo]7^COk=kTgncNi9o/g^BOk=kTWncNi=k]7NDNkEg
]WNhLkMg^7>ILkUcVFnK0VnJ00iWNf^KGc]SG5lkGcaK?5llE_aK75LLFaaFo5/L0UKl03mBo5LLD_aF
o5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`0
4Goo00<007ooOol06Woo00<007ooOol01Goo000LOol00`00Dae>o@02D_d300000e;mDae>o@02D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05
Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@MC7@05EaaG7ELMEaeG7003Ead3Fc`03UmLGcaO?5ll
GeaO?6]kJgY[Nf]jKiY_VG>JKgT2LiP3MiL017^FNkIkU7^E0W^D00AkUW^ENiAkU0=kT`07Nk=kTg^C
Ni=k/g^CNk@00W^e00Eg]W^fMkQg^7>I009c^@=_VP9[N`03Ig][Nell00IO?0=G7003E_aG75Kl00EF
o0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7ooOol05Goo00<007ooOol06Goo
00<007ooOol01Goo000BOol50005Ool00`00C_d000020000T4kmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lDaeG75/mEaaG?ELLFceG75LmGcaOG5llGeaO?5mLGcaS
G5mKHeaSFg>JKgUcVVmiMiUcV7^hMiMg]gNENkIgUG^eNiAk]WNENkEkU7ndNi=o/g^BOk=kTgncNi9o
/g^BNkAkTg^eNkAk]W>gMkQcVG>iLiU_V`9_VP0<Ig][VfMkJg]SFfMlFcaO?5/KGcaK75/l0U/L03aF
o5/LE_aK75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`J
Ool00`00Oomoo`0HOol00`00Oomoo`05Ool001Aoo`03001oogoo00Eoo`800003D_eC7Dkm009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad01ULMDaeC7E<MEaeG
70=G7@04EaaK?ELLFcd3Gc`00emLHeaSG003He`016MkIe]WNfMK0W>H00IgVGNGMiMgUg^fNiH2MiL0
1G^fNiIkUW^ENi@02G^C0W^c00]k]G^dNkAk/g^eMkIk]WNfMkQg]gNh009[N`08Ig]WG6=KIeaSFfML
He]K?0=K7005FcaK75KlE_aG7004E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l
01aoo`03001oogoo01Uoo`03001oogoo00Aoo`0057oo00<007ooOol01Woo08T007ooC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMD_aK?ELLFceG
75/mEaaK?ELLHeaSFf=LGe]SG6=KIgaWFfMlIe][Nf]jKi]gUgNgMiMgVG>HMkMgUg^hMiEk]W^DOkEk
TgncNi9o/g^COk=kTWncNi9k/g^C009k]01?Nk=kTg^eNkAk]WNfNmMg]gNhLiUc^G>IIgaSFfMlHe]W
O6=KHeaO>e/lFaaO?5LLFaaFo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_`08Goo00<007ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07Ool200000e;mDae>
o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@9C7@9G
7@09EaaK?ELLFceG75/mEaaK?E/l00=SG00<Ie]WNfMKIg]WFf]kJgY[NfmiKiY_VGNI0W>H0WNG0g^F
00=k]G^CNi@00g^C00QkU7^CNi=kTW^cNi=k]7^C0W^c0W^d00Ek]WNfNkIg]gNh009c^@0ALiU_VVnJ
IeaSFfMLGcaSG5llHeaO?5/LEaaK75LLFaaG7005E_`015;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7ooOol097oo00<007ooOol05goo00<0
07ooOol017oo000DOol00`00Oomoo`09Ool0R000OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MD_aC7E;lDaeBo5<MDaaG7E<LEaeC75LMDaaK?ELLFceK75lmFcaO?E/LGceWFfMlIe]WO6MK
Jg][NVnKKgUcVVmiLiYcV7NIMiMk^7NGNkIgUGneNiAo]7^BOk=kU7ndNi9o/g^BNk=kTW^dNi9k/g^B
0W^d04Mk]GNfNmMg]WNhLkMc^G>IKiY[VVnKKiYSG5lkHeaO>f=LFa]O?5/lFaaFo5/LE_aK75KlEaaB
o5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl02Qoo`03001oogoo01Moo`03001oogoo00Aoo`0057oo
00<007ooOol02Woo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<M
D_d5Dad2Ead01ELLEaeG7ELMEa`00U/l00EK?E/lFcaK?5/m009O?00:Ie]WNfMKJg][NV]kJgY_VVnI
LiX3LiP2MiL2NiH01G^fNiAkUG^DNkD00g^D00ikTg^BNi=kTg^cNi9k/g^CNkAkTg^eMkIk]WNf0WNh
00=c^G>IKiX00fnJ0f]k00=WNellGc`015ll00=G75KlEa`00ULL15Kl00ABo5KlD_aFo0QBo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo7oo02]oo`03001o
ogoo01Ioo`03001oogoo00Aoo`004Woo0`003Goo09d007ooDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;l
Dae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEaeC75LMEaaG?ELLGceK?5lmFaaOG5llGeaO?5mLGca[Nf]j
Ki][NW>JKgUcVVmiMiUcV7^hMiMg]gNENkIkU7^eNi=k]W^DNkEkTgndNi=o/g^BOk=kTgncNi9o/g^C
NkEgU7_GMkIk]W>gLkUcVFnJJiY_VfMkJg]WNf^KIg]WO6=KGcaK?5llFaaO?002Fa`0:EKlFaaFo5/L
D_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]`0<Goo00<007ooOol05Goo00<007ooOol017oo000DOol00`00Oomoo`0<Ool2
00001WooC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@04DaeBoE<MD_d7Dad2Ead025LLEaeG7ELM
EaaG7EllGe`3Gc`00emLGcaSG003He`016nJKiUcVVmi0W>H0gNG00=kUW^fNiH00W^E00=k]W^DNiD0
0W^D1g^C00Yk/g^CNkAk]G^fMkIk]W^eNkIg]P=g^009Ig][Nf]kJg]SFfMLHe]WG6=K009K7005FcaK
75/LFaaG7003E_`00eLLD_aFo002E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo3Ioo`03001oogoo01Aoo`03001oogoo00Aoo`009Goo09`007ooC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG75LmEaaK?ELLFceG75/mGcaOG5llGeaSFf=L
Gc]SG6=KIg]WFg>JKgUcVW>HMiUgUgNgMiMk]WNEMkMgUg^fMiEk]G^DOkAkTgncNi9o]7^COk=kTWnc
Ni9k]7NDOk=kTg^dMiAk]GNfNkIc]gNhLiUc^G>IIgaSFfMlHe]WO5lkHeaO>ellFaaK?5KlFa`2Ea`0
7e;lEaaFo5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;L03Yoo`03001oogoo01Eoo`03001oogoo00=oo`009Woo00<007ooOol00U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d045<MC_eBoE;mDaeB
oE<MD_eC7E;mDaeBoE<MD_eC7E;m15<M00aG7E<MDaeC7E/mEaaK?ELLFceG75/mEa`6He`01fMkIe]W
NfMKIg]cV7NI00=gU`03MiUcV7NG009gU`04NiIkUG^ENi@3Ni<00g^DNi=kT`03Ni<02G^dNk=k/g^C
NkAk/g^eMkIk]P02MkP00g>ILkUc^@04KiX036=LGcaSG5llHeaO?5/LEaaK75LLFaaG70EFo004D_aF
o5;lE_`<D_`01E;LD_aBo5;lD]`00e;l?Goo00<007ooOol057oo00<007ooOol00goo000WOol0S000
Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LFceG75/mEaaK?ELL
GceK?6=LGc]SG6MKIg]WFfMlIe]WNf]jKi]_NG>JKgUgVG>HMiUgUg^hMiEk]W^DOkEkTgndNi9o]G^C
Ok=kTWncNi9k/g^COk=kTW^dNi=k]G^dNkIg]WNhMkMc^G>IKi/2KiX03V^JJi]WNf=LGc]SG5/lGcaK
6e/LEaaK75KlFa`2E_`06E;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;L041oo`03001oogoo01=oo`03001oogoo00=oo`00:7oo0P0000Eooe;mD_eC7Dkm009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<M
D_eC7E;mDaeBo@=C7@05D_eC7E<MDaeBo@03Ead025LLEaeG7E/mEaaK?E/lFcd3Fc`03E/mIe]WNfMK
Ig]WFfMkJgY[NfmiKiY_VGNI009cV0=gU`9kUP07NkEkTg^DNi=k]G^CNi@00W^C00=kTW^cNi<00W^C
00Qk]7^cNkAk]7^fMkIg^7Ng0W>i16nJ00A[NfMkJg][N`IO?0=G7005E_aG75LLE_aBo003E_`3D_`0
0eKlD_aBo006D_`00e;LD_aBo016Ool00`00Oomoo`0BOol00`00Oomoo`03Ool002Yoo`1n001ooe<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LGceK75lmFcaO?E/LGceO?5mL
Ie]WO6MKJg][NVnKJgYcVVmiLiYcV7NILiQk^7NGNkIgUGneNiAo]7^COkEkU7ndNi9o/g^BNk=kTWnc
Ni9k/g^C0W^d00Mk]GNfNmIg]g>iLiU_V`02KiX036^JJi]WNf]kIg]WO6=KGcaK6ellFaaK?09K7004
E_aK75;lEa`2E_`03U;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_a:Ool00`00Oomoo`0BOol00`00
Oomoo`03Ool002]oo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m25<M0eLM00AG75LMEaeK?@=K
?00=GeaO?5llGcaOG5llJg][NV]kJgY_VVnILiX00g>H0gNG00=kUW^fNi@00W^F00Ik]G^DNiAkU7^C
Ni83Ni<00g^BNk=kT`02Nk@027^eMkIk]W^dNkIg]WNhMkL2MkP02F]kIg][Nf=KIeaSFfMLHe]K?003
Fa`01E/lFaaFo5KlEa`015Kl00ABo5KlD_aFo0=Bo003E_aBo7oo04ioo`03001oogoo015oo`03001o
ogoo00=oo`00;7oo0:<007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aK?ELLEceG75/m
EaaG?EllGeaO?5mLGcaOG5llHeaO>f=LHe]cVVmiLiYcV7NILiQk^7NGMkMgUG^fNiAg]gNENkIkU7^e
Ni=o/g^COk=kTgncNi9o/g^BNkAkTg^eNi9k]7^CNkEg]W_FMkMg^7>gLkUcVG>iHe]WO6=KIgaO>f=L
Gc]K?5/LGcaG75/LE_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo01BOol00`00Oomoo`0@Ool00`00
Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eG7@03Dad00eLMDaeG7@02
Ead015LLFceG75/m0ell00=OG6=LHe`00f=L00=WNfMKIg/00g>H00]gVGNGMiMgUg^fNiIgUg^FNkIk
U7^E009kU09kT`03NiAkTg^C009kT`0:Nk=kTg^cNi=k]7^CNkEg]W^fMkL2MkP00g>iLiUc^@03KiX0
36=LGcaSG5llHeaO?5/LEaaK75LLFaaG70EFo005D_aFo5;lE_aBo01EOol00`00Oomoo`0@Ool00`00
Oomoo`02Ool002moo`2J001C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeBo5/mEaaK?ELLFceG
75/mEaaSG6=KHeaO>f=LHe]WNfMKIga[NV]kJgY_VgNGMkMgUgNILiQg]gNGNkIgUG^eNiAo]7^COk=k
TgndNi=o/g^BOk=kTgncNi9o/g^CNkAgU7_FMkMg^7>gMkQcVG>iJiY_VfnJJg]WNf=LGc]SG5/KGcaK
?5/LE_aK75KlFaaFo5LLD_aFo5;lEaaIOol00`00Oomoo`0@Ool00`00Oomoo`02Ool0031oo`05001o
oe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;m
D_eC7E;mDaeBoE<MD_d3Dad015;mDaeC7ELM0U<M0ULM00MG75/mEaaK?ELLFceG7002Fc`3He`036MK
Ig]WFfMkJgY[Nf]jJg]_NFnJKiUgV@9cV003MiMk]W^F009kU@05NiAkTg^CNiEkU003Ni<02W^cNi=k
Tg^CNk=kTg^dNkEk]WNf0gNh00=cVG>iKiX00VnJ0f]k00=WNellGc`015ll00=G75KlEa`00ULL00=F
o7ooOol0G7oo00<007ooOol03goo00<007ooOol00Woo000aOol0SP00Oomooe<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5<M
D_aG7E<LEaeC75LMDaaK?ELLFceK75lmFcaO?E/LGceWFfMkIe]WO6MKJg][NVnKKgUcVVmiMiUcV7NI
MiMk^7NENkIkU7neNi=o]7^DOkAkTgncNi9o/g^BOk=kTWncNi9k]7^CNkEg]WNhLkMg^7>ILkU[VVnK
KiY[NfMkJi]WNfMlHe]WO5/LFcaK75ll0U/L00=Fo5/LOol0H7oo00<007ooOol03Woo00<007ooOol0
0Woo000bOol01@00Oomooe<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC
7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1U<M00=G7ELLEad00ULM00=G75/lFc`01E/l0Ull00YW
FfMkIe][Nf]jJg][NVnJKiUcVP9cV09gU`9kUP06NiEk]G^CNiAkUW^e1g^C00Mk/g^CNkAk/g^eNi=k
]002NkD01GNfNkIg^7NhMkL00f]k00QSFfMLHe]WG5llHeaK75/l0e/LHgoo00<007ooOol03Woo00<0
07ooOol00Woo000cOol20000R7ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeBo5LMDaaG7ELLEceG75lmFcaO?E/LGeaO
?5mLGcaOG5llJg][NVnKJgYcVVmiLiYcV7NIMiMk^7NGNkIgUGneNiAk]WNEOkEkTgndNi9o/g^COk=k
TWncNi9k/g^CNkAkTW^dMiAk]G^dNkIg]WNhMkMc^G>ILkUSFfMlHe]SG5lkHeaO>f=LJ7oo00<007oo
Ool03Goo00<007ooOol00Woo000eOol01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@05Dae>oE;mD_eC7@03D_d025<MD_eBoE;mDaeBoE<MD_d8Dad00eLMEaaG7@02Ead015LLEaeO?5mL
0ell00=OG5llHe`00f=L00=_VVnILiX00g>H0WNG0W^F0gNG00AkUW^fNiAkU09kT`05Ni9kTg^CNi=k
TP02Nk<02W^dNi=k]7^cNkEk]7^fMkIg^7Ng0g>i0fnJ00ASG5llHeaO?6]oo`03001oogoo00aoo`03
001oogoo009oo`00=Woo07d007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMDaaG7E;lEaeC75LmEaaK?ELLFceG75/mGcaOG5llGeaS
Ff=LGc]SG6=KIg]WFfMlLiQgVG>HNkQgUgNgLiQgVGNGMkMgUG^fNiAk]G^COk=kTgndNi9o/g^BNk=k
TW^dNi9k/g^CNkEk]7^fMkIg^7NgMkQcVG>i009_VP04JiY[VfMkJg]^Ool00`00Oomoo`0;Ool00`00
Oomoo`02Ool003Moo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eB
oE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@08EaeG75/mEaaK?ELLFceG70ISG00;
Ig]WFfMkJgY[Nf]jLiY_NFnJLiQgV@03MiL017^fNiIkUG^D0W^C00=kUG^DNi<017^C00=kTW^cNk<0
0W^d00Ek]WNfNkIg]gNh009c^@9_VP9[N`03Ig][Ngoo06ioo`03001oogoo00aoo`03001oogoo005o
o`00>7oo0P0006iC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK?E/LGceK?6=LGc]SG6MKIg]WFfMlJgY[
Nf]jLiY_NG>JLiQgVG>HMkMgUg^fMiEk]G^DOkAkU7^eNi=o/g^COk=kTWncNi9o/g^B0W^d00Mk]GNf
NmIg]gNhLiUc^@02KiX00fMkJi]WN`1bOol00`00Oomoo`0;Ool00`00Oomoo`01Ool003Yoo`03001o
odkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<M
D_d3Dad01E;mEaeG7ELMEa`00eLM25/l00eWFfMkIe]WNf]jJg][NV]kKgU_VVnIMiUcV003MiL2NiH0
0g^ENiAkUP02NiD00g^DNi=kT`02Ni<03W^BNi=kTg^cNi=k]G^cNkAkTg^eMkIk]WNgMkP2LkT00g>I
Oomoo`1bOol00`00Oomoo`0:Ool00`00Oomoo`01Ool003]oo`1i001oogooDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75LMDaaK?ELLEceK
75lmFcaO?E/LGeaO?5mLGcaOG6]jJg][NVnKKgUcVVmiMiUcV7NIMiMk^7NENkIkU7neMiEk]G^DOkAk
TgncNi9o]7^COk=kTWncNi=k]G^BNkAkTg^eMiAkeWNfMkQcVG>iLiT0MWoo00<007ooOol02Goo00<0
07ooOol00Goo000lOol00`00Oomoo`02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eB
oE<MD_eC7E;mDaeBoE<MD_d7Dad2Ead01ELLEaeG7ELMEa`00Ull00eOG5llGcaO?5mLHe]SG6]jJg]_
NFnJKiUgV@02LiP3MiL2NiH01G^eNiIkUW^ENkD02G^C00Qk]7^CNkAkTg^dNkEk]WNf0WNh00=c^G>I
Ool0MWoo00<007ooOol02Goo00<007ooOol00Goo000mOol20000LgooDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG75LmEaaK?ELLFceG75mL
GcaOG5llHeaSFf=LGc]SG6miLiY_NGNILiQgVG>HNkQgUg^fMiEk^7NGNkIkU7neNi=o]7^BOk=kTgnc
Ni9o/g^BNkAkTWncNi=k]7NDNkEg]WNhLkMc^G>I07Uoo`03001oogoo00Qoo`03001oogoo005oo`00
?goo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0ADae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<M
D_eG7@03Dad02eLMDaeC7E<MFceG75/mEaaK?ELLFcd00V=L00eSFf=LHeaSG6MKIg]WFf]kJgY[Nf]j
LiY_N@02LiP2MiL2NiH00g^eNiAkU002Ni<2Ni@2Ni<03G^BNk=kTg^cNi=k]7^cNkEg]W^fMkQc^G>I
07]oo`03001oogoo00Moo`03001oogoo005oo`00@7oo070007ooDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E<LEaeC75/mEaaK?ELLFceK75lmHe]S
G5lkIgaWFfMkIe]_Vf]jJg][NW>JKgUcVW>HMiUgUgNgMiEk]W^DOkAkTgneNiAo]7^BOk=kTW^cNi9o
/g^BNkAkTg^eNkAk]WNDNmIg]Weoo`03001oogoo00Moo`40005oo`5oo`00@Goo00H007ooOomBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM00EG75LM
EaeK?ELL00IK?00=Ig]WFfMkIe]WNf]jJg][NW>JKgU_VW>HMiT00WNG00]kUW^fNiAkUG^DNkIkU7^E
NiAkTg^B00AkT`9k/`=k]004Nk=k]GNfNkImOol00`00Oomoo`07Ool10001Ool1Ool0049oo`80001[
Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeC75LMDaaG7E<L
EaeC75lmFaaO?E/lGceK75mLGcaWNfMKIga[NV]kJgYcVVmiLiYcV7NILiQg]gNGNkIgUG^eMiEk]W^D
NkEkTgncNi=o/g^COk=kTW^cNi=k]7^BNk=kTg^eMkIk]P1oOol00`00Oomoo`06Ool10001Ool1Ool0
04Aoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d7Dad01ELLEaeG
7ELMEa`00ULM0e/l00=O?5mLGc`00Ull00YOG6]jJg][NW>JKgU_VW>HMiUcV09gU`06NkIkUW^EMiMk
]W^F0W^E00AkU7^CNi=kU0AkT`04NkAkTW^cNk<2Nk@00g^fOomoo`1oOol00`00Oomoo`05Ool10001
Ool1Ool004Eoo`1U001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LM
D_aC7ELLFceG75LmEaaK?ELLGeaO?5mLGcaOG5llGeaSFf=LGc]cVVmiLiY_NGNILiQgVGNGNkQgUG^f
MiMk]WNENkEkU7ndNi=o/g^COkAkTgncNi9k]7^BNk=kTP02Nk@00g^fMkIoo`20Ool00`00Oomoo`05
Ool10001Ool1Ool004Ioo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0=DaeBoE<MD_eC7E;mDaeBoE<M
D_eC7E;mEad00e<M00=G7ELLEad00ULM00AG75/mEaaOG0=O?009HeaSFf=LHeaWNfMKIg]WFgNI009c
V09gU`9cV09gU`9kUP06NiEk]G^CNi=kUG^D0g^C00Qk/g^BNi=kTg^dNi=k]GNfPgoo00<007ooOol0
17oo0@000Goo0Goo0017Ool20000I7ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;l
EaeBo5LMDaaG7E;lFceG75/mEaaK?ELLFceO>f=LHe]SG6MKIgaWFfMkIe]_Vf]jJg]_NG>JLiQgVG>H
NkQgUG^fMiEo]G^COkAkU7ndNi=o/g^BOk=kTgncNi9o/g^CNkEkTg^dQ7oo00<007ooOol00goo0@00
0Goo0Goo0019Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@9C
7@9G7@05EaaK?ELLFceG7005Fc`02fMKIg]WFfMkIe][Nf]jJg]_VG>JKgT00W>H0WNG0W^F00Ek]G^D
NiAkUW^e00MkT`05Nk=kTg^dNi=k]026Ool00`00Oomoo`03Ool10001Ool004Yoo`1R001ooe<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeC75LMFcaO?E/LGceK?5lmGcaO
G6MKIg][NVnKJgY[NfmiLiY_NGNILiQk^7NGNkIgUG^fNiAk]WNEOkEkTgndNi9o/g^COk=kTWncNi9k
]7^BNkAkThIoo`03001oogoo00=oo`40005oo`00Bgoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC
7E;mDaeBo@EC7@9G7@06EaaG7ELMEaeG75LM0e/l0Ull00YOG5llGca[NV]kJgY[NfnILiY_N@9cV0=g
U`06NiIk]W^DMiMkUW^f0W^D0W^C00=kTW^CNi<00W^C00Ek]7^CNk=kTg^d08Moo`03001oogoo009o
o`40005oo`00C7oo0P0005eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG?ELLFceG
75LmEaaK?EllGeaO?5mLGcaOG5lkHeaSFf=LKgUcVVmiLiYcV7NIMiMg]gNENkIgUGNgMiEk]W^DNkEk
TgncNi=o]7^BOk=kTW^cNi9o/g^CNk@0RGoo00D007ooOomoo`00005oo`00CWoo00<007ooC_d00U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eB
oE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00IG7E<MDaeC7ELMEa`2Ead01U/mEaaK?EllGeaO?0=SG008
He]SG6MKIg]WFfMkLiQgV@=gU`08MiUcV7NGMiMk]W^FNiEkU09kT`04NiEkU7^CNi84Ni<00g^dNk=o
o`29Ool01000Oomoo`000Goo001?Ool0F`00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeC75LMD_aG
7E<LEaeG75/mEaaK?ELLFceG76=LGc]SG6=KHeaWFfMlIe]WNf]jKi]_NG>JKgUgVG>HMiUgUg^fMiEk
]G^DOkAkU7^eNi=o/g^BOk=kTWncNi9k/g^C08]oo`04001oogoo0001Ool0051oo`03001oodkm009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mDaeB
oE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7@03Ead015LLFceG75/m0e/l00eSG6=KHeaWFfMkIe]W
Nf]jJg]_NFnJKiUcVP02LiP2MiL2NiH00g^ENiAkUP02NiD00g^DNi=kT`02Ni<017^BNk=k/g^dS7oo
00<007oo00000Goo001AOol20000EdklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7E<L
GceK?5lmFaaO?E/lGceWFfMlIe][Nf]jKi][NW>JKgUcVW>HMiUgUg^hMiEk]W^DOkEgUW^eNiAo]7^C
Ok=kTWndNi=o/g^BNkAkTP2=Ool10001Ool1000005=oo`06001>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d015<MD_eC7E;m1U<M0eLM00EG
75LMEaeG7ELL00AK?09O?009GeaO?6]kJgY[Nf]jKiY_VG>J009cV0=gU`9kUP05NkEkUW^FNiEk]@02
Ni<2Ni@3Ni<00g^dNi9oo`2>Ool2000005Aoo`1E001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeG75Lm
EaaK?ELLEceG75mLGcaOG5llGeaO?6=LGc]SG6=KLiY_NG>JKgUgVG>HNkQgUg^fMiEk^7NGNkIkU7ne
Ni=o]7^DOkAkTgncNi9o/g^BOk<0Sgoo0P00001EOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d2Dad00eLM
DaeC7@02Ead01ELLEaeG75/mEa`00Ull00=OG6=KHe`00V=L00ESFfMkIe]WNfMK009cV0=gU`03LiQg
UgNG009kUP05NkEkU7^DNi=kU003Ni<00g^cNi=kT`2@Ool2000005Ioo`1B001oogooC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeB
o5LMDaaG7E;lEaeC75/mEaaK?ELLFceG75/mHe]SG5lkHeaSFfMkIe]WO6MKJg][NW>JKgUcVW>HMiUg
UgNgMiEo]G^DOkAkTgneNi=o]7^BOk=kTgncNi:<Ool40002Ool005Moo`800004OomBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EB
oE<MDaeG7ELL009G7@04FceG75/mEa`3Fc`2He`036=KIg]WFfMkIe][Nf]jLiY_NFnJLiQgV@9gU`08
NiIk]W^DNiEkU7^eNi=kU0EkThUoo`@000Ioo`00FGoo04h007ooC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC
75LMFaaO?E/lGceK75lmFcaWNfMKIga[NV]kJgY_VfmiLiY_NGNILiQg]gNENkIkU7^eMiEk]W^DOkAk
TgncNi9o/g^BOk>5Ool4000:Ool005Yoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@05
Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d6Dad3Ead015LLEaeG7ELM15/l0ell00YOG6]j
Jg][NV]kKgU_VVnIMiUcV09gU`08NkIkUWNGMiMk]W^DNiEkU09kT`03NiAkTg^C089oo`@000ioo`00
Fgoo04/007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7DklDaeBo5<MD_aG7E;lDaeBo5/mEaaG?ELLFceG75LmGcaOG5llGeaO?5mLHe]SG5lkHea_NG>JKgUg
VG>HMiUgUgNILiQg]gNGNkIgUW^eNi=o]7^CNkEkTWncNi80OWoo10004Woo001LOol200000gooDae>
o@02D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d4Dad0
0eLMDaeG7@02Ead015LLFceG75/m0ell00=SG6=KHe`00V=L00AWFfMkIe]gV@9cV004KiUgVG>HLiP2
MiL00g^FNiEkU@02Ni@017^ENiAkTg^BO7oo0`005Woo001NOol0A`00OomC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E<LEaeBo5LMEaaK?ELL
FceG75/mEaaSG6=KHeaO>fMlIe]WNfMKKi][NV]kKgUcVW>HMiUgUg^hMiIk]W^DOkAgUW^eNiAo]7^C
Ok@0N7oo10006Goo001OOol01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeB
oE<MD_eC7E;m0e<M00=BoE<MDad015<M00MG7ELLEaeG75/mEaaK?@04Fc`01VMKIg]WFfMkIe][N`9[
NP03KiUcVW>H009cV09gU`04NiIkUG^eNiH2NiD00g^DNi=kT`1eOol4000MOol0061oo`14001ooe<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeC75LM
DaaG7E<LEaeK?5lmFaaO?E/lGceO?5mLIe]WNfMKKi][NV]kKgUcVW>HMiUcV7^hMiMk]WNEOkEgUg^f
NiAo]G^COk=kTg5oo`@0025oo`00HGoo0P0000IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m
00IC7E;mDaeBoE<MD_d7Dad01ULLEaeG7ELMEaaG7@=K?09O?005GeaO?5llGca[N`02JgX00fnILiY_
N@02LiP017NIMiMgUg^F0WNG00=kUW^ENkD00W^C00=kUG^DOol0K7oo10009Goo001SOol0>000Dae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7ELLFceG
75LmEaaK?ELLGeaO?5mLGcaOG5lkHeaSFf=LKgUcVVmiMiUcV7NIMiMg]g>HNkP2MiL01WNEOkEkU7nd
NiAo]6]oo`<002Uoo`00I7oo00<005<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d03E<MD_eBoE;mDaeB
oE<MD_eC7E;mDaeBoELM00=C7@03EaeG75LM009G7@05EaaK?ELLFceG7003He`01F=KHeaWFfMkIe/0
0V]j00E[NfmiKiYcV7NI009gU`07NiIk]G^DNiAkUW^ENi<0Igoo1000;7oo001UOol0=000Oom>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E;lFceG75/m
EaaK?ELLGceK76=LHe]WNfMKIgaWFf]kJgY_NfmiLiY_NGNI0gNG00Ik]W^DNkEgUGneNi=TOol4000`
Ool006Ioo`800005C_eBoE;mDae>o@02D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC
7ELL00=G7@04EaaK?ELLFcd5Fc`016MkIe]WNfMK0V]j00I[NfmiKiY_NGNILiP2MiL00g^fNiAkU@02
NiH2NiAPOol4000dOol006Qoo`0`001ooe<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E;lDaeC75LMDaaG7E<LGceK?5lmFaaO?EllGeaO?5mLGca[Nf]jKg]_NG>JKgUgVG>H0WNG
00Qk^7NFMiMgUg^fNiAk]G^CG7oo1000>7oo001YOol01P00OomBoE;mDae>o@9Bo@0:DaeBoE;mD_eC
7E;mDaeBoE<MD_d7Dad01ELLEaeG7ELMEa`00ULM00IOG5llGcaO?5mLGc`3He`016miKiY_NG>J0W>H
0WNG00=cV7NGMiL00W^F00=kUG^DOol0F7oo1000?7oo001ZOol0=`00OomC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeC75LMEaaK?ELLEceG75/mEaaOG5llGeaSFf=LGc]SG6MK
Ig]WFfMlLiQgVFmiLiYcV7NIMiMk^7NFNkEkU7nd05Ioo`<0041oo`00Jgoo0P000U;m00iC7DkmD_eB
oE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00iG7E<MDaeC7ELMDaeK?ELLFceG75/mEaaK?F=K0V=L00EW
NfMKIg]WFfMk009[NP04KgUcVW>HLiP2MiL2NiH00g^ENiAkUP1BOol40013Ool006eoo`0c001oodkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMDaaK?ELLFceG75lmFcaO?E/L
IgaWFfMkIe]WO6]jJg]_NG>JKgUgVG>HNkQgUg^fNiAo]GNF04moo`@004Moo`00KWoo00@007ooD_eC
7@=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@03EaaK?5/l00AK?005GeaO?6MkIe]W
N`03JgX017>JKgUcV7>H0WNG0W^F0WNG00=kUWooOol0BGoo1000Bgoo001_Ool0:P00Oomooe<MC_aC
7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lEaeC75LMEaaG?ELLGceK?5lmGcaOG5llGeaO?5mLJgY[
Nf]jLiY_NGNILiQgV@9gU`04MiEk^7NGNkI8Ool4001?Ool0071oo`800003OomC7E;m009Bo@06DaeB
oE<MD_eC7E;m1U<M00=G7ELLEad00ULM00AG75LMGcaOG0=O?006HeaSFf=LHeacVVmi0W>H00EgVGNG
MiMcV7NI009gU`03NiIoogoo04=oo`<005=oo`00LWoo02T004klDae>o5<MC_aC7DklDaeBo5<MC_aC
7E<LEaeBo5LMDaaG?ELLFceG75/mEaaK?ELLHeaO>f=LHe]SG5lkIgaWFf]kJgY_NfmiLiYcN7NI009g
U`03MiEoogoo041oo`@005Ioo`00Lgoo00P005;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@05
EaeG75/mEaaK?@03Fc`01V=LHe]SG6MKIg]WF`9[NP06Jg]_NFnJLiQgVG>H0WNG00=kUWooOol0?7oo
1000FWoo001dOol09P00C_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaO?E/lGceK
75lmFcaO?FMKIgaWFf]kJgY_Nf]jLiY_NGNILiP2MiL00g^fOomoo`0iOol4001NOol007Eoo`800006
DaeBoE<MD_eC7E;m1U<M00=G7ELLEad00ULM00=G75/lFc`00U/l0Ull00UOG5llJgY[NV]kJgY_VVmi
MiT00W>H0WNG00=kUWooOol0=Goo1000HWoo001gOol09@00Dae>o5<MD_aC7DklEaeBo5<MD_aG7E;l
EceG75/mEaaG?ELLFceO?5mLGcaOG5llHeaO>f=LHe]cVVmiMiUcV7NIMiMk^7>H03Aoo`@006Ioo`00
N7oo00L005<MD_eC7E;mDaeBo@02Dad01ULMDaeC7E<MEaeG709G7@06FceG75/mGcaOG6=K0f=L00AS
FfMkIe][N`9[NP04KgU_VW>HLiPaOol3001ZOol007Uoo`0R001C7DklDaeBo5<MD_aC7E<LEaeBo5LM
DaaG7ELLFceG75/mEaaK?F=KHeaO>f=LIe]WNfMKKg][NV]kKgUcVW>HMiT^Ool4001]Ool007Yoo`03
001ooe;m00=C7@05D_eC7ELMEaeG7003Ead00eLLFceG7005Fc`016MKIg]WFf]k0V]j00A_NFnJKgUc
V2]oo`@0075oo`00Ngoo0P0001eBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeK75lmFcaO?E/LGeaO?5mL
Gca_Nf]jJg]_NG>JKgUgVG=h02Moo`@007Eoo`00OGoo00<005<MDad01E<M00=G7ELLEad00ULM00AG
75llGcaOG0=O?006HeaSFf=LKgU_VVmi0W>H97oo1000NGoo001nOol06P00D_aG7E;lDaeBo5LMDaaG
?ELLFceG75/mEaaOG5llGeaO>f=LHe]SG6MKIgaWFf]kJgXQOol4001mOol007moo`05001ooe<MDaeG
7@03Dad01e/mEaaK?ELLFceG75/m009SG005He]WNfMKIg]WF`02JgXOOol30021Ool0081oo`80000E
EaeC75LMDaaG7E<LFceG75/mEaaO?E/LGceK?6MkIe]WO6MKJg][NVmk01]oo`@008Aoo`00PWoo00D0
05LMEaeG7ELL00=G7@AK?0=O?005GeaO?6]jJgY[N`0HOol40028Ool008=oo`0B001oogooEceG75/m
EaaG?ELLGeaO?5mLGcaOG5llHeaO>f=L5Goo1000S7oo0024Ool02@00OomooeLMEaaG7ELLFceG7002
Gc`00emLHe]SG002He`BOol4002@Ool008Eoo`80000;OomK?ELLFceG75/mEaaK?F=KHeaO>`0AOol3
002DOol008Moo`06001ooe/mEaaK?ELL15/l3Woo1000Ugoo0028Ool01`00Oomooe/LGceK?5lm00ao
o`@009]oo`00RGoo00D007ooOomoo`0000Uoo`@009moo`00RWoo0P0000=oo`00Ool017oo1000Xgoo
002<Ool200000goo00000002002WOol008eoo`800:]oo`00ogoo>goo003oOolkOol00?mooc]oo`00
ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00001\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02905 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.698 .794 .924 r
.38981 .7969 .39816 .80287 .41213 .79665 .40381 .79132 Mtetra
.738 .818 .914 r
.40381 .79132 .41213 .79665 .42621 .78825 .41791 .78411 Mtetra
.796 .851 .892 r
.41791 .78411 .42621 .78825 .44041 .77614 .43214 .77402 Mtetra
.867 .886 .847 r
.43214 .77402 .44041 .77614 .45473 .75825 .44649 .75921 Mtetra
.932 .912 .777 r
.44649 .75921 .45473 .75825 .46914 .73271 .46095 .73754 Mtetra
.969 .919 .696 r
.46095 .73754 .46914 .73271 .48353 .69974 .47546 .70791 Mtetra
.979 .917 .632 r
.47546 .70791 .48353 .69974 .49779 .66326 .48989 .67231 Mtetra
.976 .919 .612 r
.48989 .67231 .49779 .66326 .51186 .62942 .50415 .63625 Mtetra
.969 .934 .652 r
.50415 .63625 .51186 .62942 .52575 .60262 .5182 .60549 Mtetra
.948 .944 .742 r
.5182 .60549 .52575 .60262 .53957 .58349 .53213 .58253 Mtetra
.893 .922 .833 r
.53213 .58253 .53957 .58349 .55338 .57034 .54602 .56657 Mtetra
.819 .871 .884 r
.54602 .56657 .55338 .57034 .56724 .56107 .55993 .55553 Mtetra
.756 .821 .903 r
.55993 .55553 .56724 .56107 .58116 .5541 .5739 .54752 Mtetra
.715 .787 .908 r
.5739 .54752 .58116 .5541 .59516 .5484 .58794 .54122 Mtetra
.691 .766 .909 r
.58794 .54122 .59516 .5484 .60923 .54338 .60206 .53586 Mtetra
.678 .755 .909 r
.60206 .53586 .60923 .54338 .62338 .53871 .61626 .53099 Mtetra
.671 .748 .908 r
.61626 .53099 .62338 .53871 .6376 .53422 .63053 .52637 Mtetra
.668 .745 .908 r
.63053 .52637 .6376 .53422 .6519 .52981 .64488 .52188 Mtetra
.666 .743 .908 r
.64488 .52188 .6519 .52981 .66628 .52544 .6593 .51744 Mtetra
.665 .742 .908 r
.6593 .51744 .66628 .52544 .68072 .52107 .6738 .51302 Mtetra
.664 .742 .908 r
.6738 .51302 .68072 .52107 .69525 .5167 .68837 .5086 Mtetra
.68837 .5086 .69525 .5167 .70984 .51231 .70302 .50417 Mtetra
.664 .741 .908 r
.70302 .50417 .70984 .51231 .72452 .5079 .71775 .49972 Mtetra
.71775 .49972 .72452 .5079 .73926 .50347 .73255 .49525 Mtetra
.73255 .49525 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.685 .786 .927 r
.38138 .79065 .38981 .7969 .40381 .79132 .39541 .78554 Mtetra
.716 .805 .92 r
.39541 .78554 .40381 .79132 .41791 .78411 .40955 .77921 Mtetra
.764 .833 .905 r
.40955 .77921 .41791 .78411 .43214 .77402 .4238 .77069 Mtetra
.831 .869 .873 r
.4238 .77069 .43214 .77402 .44649 .75921 .43817 .75843 Mtetra
.902 .901 .815 r
.43817 .75843 .44649 .75921 .46095 .73754 .45267 .74034 Mtetra
.954 .918 .736 r
.45267 .74034 .46095 .73754 .47546 .70791 .46726 .71455 Mtetra
.977 .918 .66 r
.46726 .71455 .47546 .70791 .48989 .67231 .48184 .68129 Mtetra
.978 .917 .615 r
.48184 .68129 .48989 .67231 .50415 .63625 .49629 .64449 Mtetra
.973 .925 .624 r
.49629 .64449 .50415 .63625 .5182 .60549 .51053 .61036 Mtetra
.962 .942 .693 r
.51053 .61036 .5182 .60549 .53213 .58253 .5246 .58332 Mtetra
.925 .938 .791 r
.5246 .58332 .53213 .58253 .54602 .56657 .53858 .564 Mtetra
.856 .898 .864 r
.53858 .564 .54602 .56657 .55993 .55553 .55255 .55069 Mtetra
.785 .844 .896 r
.55255 .55069 .55993 .55553 .5739 .54752 .56658 .5413 Mtetra
.733 .802 .906 r
.56658 .5413 .5739 .54752 .58794 .54122 .58066 .53421 Mtetra
.702 .775 .909 r
.58066 .53421 .58794 .54122 .60206 .53586 .59483 .52839 Mtetra
.684 .76 .909 r
.59483 .52839 .60206 .53586 .61626 .53099 .60907 .52326 Mtetra
.674 .751 .909 r
.60907 .52326 .61626 .53099 .63053 .52637 .62339 .51849 Mtetra
.669 .746 .908 r
.62339 .51849 .63053 .52637 .64488 .52188 .63778 .5139 Mtetra
.667 .744 .908 r
.63778 .5139 .64488 .52188 .6593 .51744 .65226 .50938 Mtetra
.665 .743 .908 r
.65226 .50938 .6593 .51744 .6738 .51302 .66681 .5049 Mtetra
.664 .742 .908 r
.66681 .5049 .6738 .51302 .68837 .5086 .68143 .50043 Mtetra
.68143 .50043 .68837 .5086 .70302 .50417 .69613 .49595 Mtetra
.69613 .49595 .70302 .50417 .71775 .49972 .71091 .49145 Mtetra
.664 .741 .908 r
.71091 .49145 .71775 .49972 .73255 .49525 .72577 .48694 Mtetra
.72577 .48694 .73255 .49525 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.675 .78 .929 r
.37287 .78418 .38138 .79065 .39541 .78554 .38694 .77941 Mtetra
.698 .794 .924 r
.38694 .77941 .39541 .78554 .40955 .77921 .40111 .77373 Mtetra
.738 .818 .914 r
.40111 .77373 .40955 .77921 .4238 .77069 .41538 .76639 Mtetra
.796 .851 .892 r
.41538 .76639 .4238 .77069 .43817 .75843 .42978 .75617 Mtetra
.867 .887 .847 r
.42978 .75617 .43817 .75843 .45267 .74034 .44431 .74118 Mtetra
.932 .912 .777 r
.44431 .74118 .45267 .74034 .46726 .71455 .45896 .71929 Mtetra
.969 .919 .696 r
.45896 .71929 .46726 .71455 .48184 .68129 .47365 .68938 Mtetra
.979 .917 .632 r
.47365 .68938 .48184 .68129 .49629 .64449 .48827 .65347 Mtetra
.976 .919 .612 r
.48827 .65347 .49629 .64449 .51053 .61036 .50271 .6171 Mtetra
.969 .934 .652 r
.50271 .6171 .51053 .61036 .5246 .58332 .51695 .58607 Mtetra
.948 .944 .742 r
.51695 .58607 .5246 .58332 .53858 .564 .53104 .56289 Mtetra
.893 .922 .833 r
.53104 .56289 .53858 .564 .55255 .55069 .5451 .54676 Mtetra
.819 .871 .884 r
.5451 .54676 .55255 .55069 .56658 .5413 .55918 .53558 Mtetra
.756 .821 .903 r
.55918 .53558 .56658 .5413 .58066 .53421 .57332 .52744 Mtetra
.715 .787 .908 r
.57332 .52744 .58066 .53421 .59483 .52839 .58753 .52103 Mtetra
.691 .766 .909 r
.58753 .52103 .59483 .52839 .60907 .52326 .60181 .51556 Mtetra
.678 .755 .909 r
.60181 .51556 .60907 .52326 .62339 .51849 .61618 .51058 Mtetra
.671 .748 .908 r
.61618 .51058 .62339 .51849 .63778 .5139 .63063 .50586 Mtetra
.668 .745 .908 r
.63063 .50586 .63778 .5139 .65226 .50938 .64515 .50126 Mtetra
.666 .743 .908 r
.64515 .50126 .65226 .50938 .66681 .5049 .65975 .49671 Mtetra
.665 .742 .908 r
.65975 .49671 .66681 .5049 .68143 .50043 .67442 .49218 Mtetra
.664 .742 .908 r
.67442 .49218 .68143 .50043 .69613 .49595 .68918 .48765 Mtetra
.68918 .48765 .69613 .49595 .71091 .49145 .70401 .48311 Mtetra
.664 .741 .908 r
.70401 .48311 .71091 .49145 .72577 .48694 .71892 .47855 Mtetra
.71892 .47855 .72577 .48694 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46937 Mtetra
.74897 .46937 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.667 .775 .93 r
.36429 .77753 .37287 .78418 .38694 .77941 .3784 .773 Mtetra
.685 .786 .927 r
.3784 .773 .38694 .77941 .40111 .77373 .3926 .76779 Mtetra
.716 .805 .92 r
.3926 .76779 .40111 .77373 .41538 .76639 .4069 .76134 Mtetra
.764 .833 .905 r
.4069 .76134 .41538 .76639 .42978 .75617 .42132 .75269 Mtetra
.831 .869 .873 r
.42132 .75269 .42978 .75617 .44431 .74118 .43588 .74027 Mtetra
.902 .902 .815 r
.43588 .74027 .44431 .74118 .45896 .71929 .45056 .72198 Mtetra
.954 .918 .736 r
.45056 .72198 .45896 .71929 .47365 .68938 .46534 .69595 Mtetra
.977 .918 .66 r
.46534 .69595 .47365 .68938 .48827 .65347 .48011 .66238 Mtetra
.978 .917 .615 r
.48011 .66238 .48827 .65347 .50271 .6171 .49474 .62526 Mtetra
.973 .925 .624 r
.49474 .62526 .50271 .6171 .51695 .58607 .50917 .59084 Mtetra
.962 .941 .693 r
.50917 .59084 .51695 .58607 .53104 .56289 .52341 .56355 Mtetra
.925 .938 .791 r
.52341 .56355 .53104 .56289 .5451 .54676 .53756 .54403 Mtetra
.856 .898 .864 r
.53756 .54403 .5451 .54676 .55918 .53558 .55171 .53057 Mtetra
.785 .844 .896 r
.55171 .53057 .55918 .53558 .57332 .52744 .5659 .52104 Mtetra
.733 .802 .906 r
.5659 .52104 .57332 .52744 .58753 .52103 .58016 .51383 Mtetra
.702 .775 .909 r
.58016 .51383 .58753 .52103 .60181 .51556 .59449 .5079 Mtetra
.684 .76 .909 r
.59449 .5079 .60181 .51556 .61618 .51058 .60891 .50266 Mtetra
.674 .751 .909 r
.60891 .50266 .61618 .51058 .63063 .50586 .6234 .49778 Mtetra
.669 .746 .908 r
.6234 .49778 .63063 .50586 .64515 .50126 .63797 .49308 Mtetra
.667 .744 .908 r
.63797 .49308 .64515 .50126 .65975 .49671 .65262 .48845 Mtetra
.665 .743 .908 r
.65262 .48845 .65975 .49671 .67442 .49218 .66735 .48387 Mtetra
.664 .742 .908 r
.66735 .48387 .67442 .49218 .68918 .48765 .68216 .47928 Mtetra
.68216 .47928 .68918 .48765 .70401 .48311 .69704 .47469 Mtetra
.69704 .47469 .70401 .48311 .71892 .47855 .712 .47008 Mtetra
.664 .741 .908 r
.712 .47008 .71892 .47855 .73391 .47397 .72705 .46546 Mtetra
.72705 .46546 .73391 .47397 .74897 .46937 .74217 .46081 Mtetra
.74217 .46081 .74897 .46937 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.661 .772 .931 r
.35562 .77073 .36429 .77753 .3784 .773 .36977 .76636 Mtetra
.675 .78 .929 r
.36977 .76636 .3784 .773 .3926 .76779 .38401 .76149 Mtetra
.698 .794 .924 r
.38401 .76149 .3926 .76779 .4069 .76134 .39834 .7557 Mtetra
.738 .818 .914 r
.39834 .7557 .4069 .76134 .42132 .75269 .41279 .74824 Mtetra
.796 .851 .892 r
.41279 .74824 .42132 .75269 .43588 .74027 .42737 .73787 Mtetra
.867 .887 .847 r
.42737 .73787 .43588 .74027 .45056 .72198 .44208 .72271 Mtetra
.932 .912 .777 r
.44208 .72271 .45056 .72198 .46534 .69595 .45692 .70059 Mtetra
.969 .919 .696 r
.45692 .70059 .46534 .69595 .48011 .66238 .4718 .6704 Mtetra
.979 .917 .632 r
.4718 .6704 .48011 .66238 .49474 .62526 .48662 .63417 Mtetra
.976 .919 .612 r
.48662 .63417 .49474 .62526 .50917 .59084 .50124 .59748 Mtetra
.969 .934 .652 r
.50124 .59748 .50917 .59084 .52341 .56355 .51566 .56618 Mtetra
.948 .944 .743 r
.51566 .56618 .52341 .56355 .53756 .54403 .52993 .54278 Mtetra
.893 .921 .833 r
.52993 .54278 .53756 .54403 .55171 .53057 .54416 .52647 Mtetra
.819 .87 .884 r
.54416 .52647 .55171 .53057 .5659 .52104 .55841 .51515 Mtetra
.756 .821 .903 r
.55841 .51515 .5659 .52104 .58016 .51383 .57272 .50688 Mtetra
.715 .787 .908 r
.57272 .50688 .58016 .51383 .59449 .5079 .5871 .50035 Mtetra
.691 .766 .909 r
.5871 .50035 .59449 .5079 .60891 .50266 .60156 .49476 Mtetra
.678 .755 .909 r
.60156 .49476 .60891 .50266 .6234 .49778 .6161 .48967 Mtetra
.671 .748 .908 r
.6161 .48967 .6234 .49778 .63797 .49308 .63072 .48484 Mtetra
.668 .745 .908 r
.63072 .48484 .63797 .49308 .65262 .48845 .64543 .48013 Mtetra
.666 .743 .908 r
.64543 .48013 .65262 .48845 .66735 .48387 .66021 .47547 Mtetra
.665 .742 .908 r
.66021 .47547 .66735 .48387 .68216 .47928 .67507 .47083 Mtetra
.664 .742 .908 r
.67507 .47083 .68216 .47928 .69704 .47469 .69 .46619 Mtetra
.69 .46619 .69704 .47469 .712 .47008 .70502 .46153 Mtetra
.664 .741 .908 r
.70502 .46153 .712 .47008 .72705 .46546 .72012 .45686 Mtetra
.72012 .45686 .72705 .46546 .74217 .46081 .7353 .45216 Mtetra
.7353 .45216 .74217 .46081 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.657 .769 .932 r
.34687 .7638 .35562 .77073 .36977 .76636 .36106 .75954 Mtetra
.667 .775 .93 r
.36106 .75954 .36977 .76636 .38401 .76149 .37534 .7549 Mtetra
.685 .786 .927 r
.37534 .7549 .38401 .76149 .39834 .7557 .38971 .74959 Mtetra
.716 .805 .92 r
.38971 .74959 .39834 .7557 .41279 .74824 .40419 .74303 Mtetra
.764 .833 .905 r
.40419 .74303 .41279 .74824 .42737 .73787 .41879 .73424 Mtetra
.831 .869 .873 r
.41879 .73424 .42737 .73787 .44208 .72271 .43353 .72166 Mtetra
.902 .902 .815 r
.43353 .72166 .44208 .72271 .45692 .70059 .4484 .70317 Mtetra
.954 .918 .736 r
.4484 .70317 .45692 .70059 .4718 .6704 .46337 .67687 Mtetra
.977 .918 .66 r
.46337 .67687 .4718 .6704 .48662 .63417 .47833 .643 Mtetra
.978 .917 .615 r
.47833 .643 .48662 .63417 .50124 .59748 .49316 .60555 Mtetra
.973 .925 .624 r
.49316 .60555 .50124 .59748 .51566 .56618 .50777 .57084 Mtetra
.962 .941 .694 r
.50777 .57084 .51566 .56618 .52993 .54278 .5222 .5433 Mtetra
.925 .938 .792 r
.5222 .5433 .52993 .54278 .54416 .52647 .53652 .52358 Mtetra
.856 .897 .864 r
.53652 .52358 .54416 .52647 .55841 .51515 .55084 .50995 Mtetra
.785 .844 .896 r
.55084 .50995 .55841 .51515 .57272 .50688 .56521 .50029 Mtetra
.733 .802 .906 r
.56521 .50029 .57272 .50688 .5871 .50035 .57964 .49295 Mtetra
.702 .775 .909 r
.57964 .49295 .5871 .50035 .60156 .49476 .59415 .48691 Mtetra
.684 .759 .909 r
.59415 .48691 .60156 .49476 .6161 .48967 .60874 .48155 Mtetra
.674 .751 .908 r
.60874 .48155 .6161 .48967 .63072 .48484 .62341 .47656 Mtetra
.669 .746 .908 r
.62341 .47656 .63072 .48484 .64543 .48013 .63816 .47174 Mtetra
.667 .744 .908 r
.63816 .47174 .64543 .48013 .66021 .47547 .65299 .46701 Mtetra
.665 .743 .908 r
.65299 .46701 .66021 .47547 .67507 .47083 .66791 .4623 Mtetra
.664 .742 .908 r
.66791 .4623 .67507 .47083 .69 .46619 .6829 .45761 Mtetra
.6829 .45761 .69 .46619 .70502 .46153 .69797 .4529 Mtetra
.69797 .4529 .70502 .46153 .72012 .45686 .71312 .44818 Mtetra
.664 .741 .908 r
.71312 .44818 .72012 .45686 .7353 .45216 .72836 .44343 Mtetra
.72836 .44343 .7353 .45216 .75056 .44744 .74368 .43867 Mtetra
.74368 .43867 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42906 Mtetra
.77456 .42906 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.654 .767 .933 r
.33804 .75676 .34687 .7638 .36106 .75954 .35227 .75256 Mtetra
.661 .772 .931 r
.35227 .75256 .36106 .75954 .37534 .7549 .36659 .74809 Mtetra
.675 .78 .929 r
.36659 .74809 .37534 .7549 .38971 .74959 .381 .74311 Mtetra
.698 .794 .924 r
.381 .74311 .38971 .74959 .40419 .74303 .39551 .73721 Mtetra
.738 .818 .914 r
.39551 .73721 .40419 .74303 .41879 .73424 .41014 .72963 Mtetra
.796 .851 .892 r
.41014 .72963 .41879 .73424 .43353 .72166 .4249 .71911 Mtetra
.868 .887 .847 r
.4249 .71911 .43353 .72166 .4484 .70317 .4398 .70376 Mtetra
.932 .912 .777 r
.4398 .70376 .4484 .70317 .46337 .67687 .45482 .68141 Mtetra
.969 .919 .695 r
.45482 .68141 .46337 .67687 .47833 .643 .46991 .65093 Mtetra
.979 .917 .632 r
.46991 .65093 .47833 .643 .49316 .60555 .48492 .61438 Mtetra
.976 .919 .612 r
.48492 .61438 .49316 .60555 .50777 .57084 .49974 .57737 Mtetra
.969 .934 .652 r
.49974 .57737 .50777 .57084 .5222 .5433 .51434 .54579 Mtetra
.948 .944 .743 r
.51434 .54579 .5222 .5433 .53652 .52358 .52879 .52217 Mtetra
.893 .921 .833 r
.52879 .52217 .53652 .52358 .55084 .50995 .5432 .50569 Mtetra
.819 .87 .884 r
.5432 .50569 .55084 .50995 .56521 .50029 .55762 .49421 Mtetra
.756 .821 .903 r
.55762 .49421 .56521 .50029 .57964 .49295 .5721 .48581 Mtetra
.715 .787 .908 r
.5721 .48581 .57964 .49295 .59415 .48691 .58666 .47915 Mtetra
.692 .766 .909 r
.58666 .47915 .59415 .48691 .60874 .48155 .6013 .47345 Mtetra
.678 .755 .909 r
.6013 .47345 .60874 .48155 .62341 .47656 .61602 .46825 Mtetra
.671 .748 .908 r
.61602 .46825 .62341 .47656 .63816 .47174 .63083 .4633 Mtetra
.668 .745 .908 r
.63083 .4633 .63816 .47174 .65299 .46701 .64571 .45847 Mtetra
.666 .743 .908 r
.64571 .45847 .65299 .46701 .66791 .4623 .66068 .4537 Mtetra
.665 .742 .908 r
.66068 .4537 .66791 .4623 .6829 .45761 .67572 .44894 Mtetra
.664 .742 .908 r
.67572 .44894 .6829 .45761 .69797 .4529 .69085 .44418 Mtetra
.69085 .44418 .69797 .4529 .71312 .44818 .70606 .43941 Mtetra
.664 .741 .908 r
.70606 .43941 .71312 .44818 .72836 .44343 .72135 .43462 Mtetra
.72135 .43462 .72836 .44343 .74368 .43867 .73673 .4298 Mtetra
.73673 .4298 .74368 .43867 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42906 .76773 .42009 Mtetra
.76773 .42009 .77456 .42906 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.652 .766 .933 r
.32912 .74961 .33804 .75676 .35227 .75256 .34339 .74546 Mtetra
.657 .769 .932 r
.34339 .74546 .35227 .75256 .36659 .74809 .35775 .74109 Mtetra
.667 .775 .93 r
.35775 .74109 .36659 .74809 .381 .74311 .3722 .73635 Mtetra
.685 .786 .927 r
.3722 .73635 .381 .74311 .39551 .73721 .38675 .73092 Mtetra
.716 .805 .92 r
.38675 .73092 .39551 .73721 .41014 .72963 .40141 .72424 Mtetra
.764 .833 .905 r
.40141 .72424 .41014 .72963 .4249 .71911 .41619 .71532 Mtetra
.831 .87 .873 r
.41619 .71532 .4249 .71911 .4398 .70376 .43111 .70257 Mtetra
.902 .902 .815 r
.43111 .70257 .4398 .70376 .45482 .68141 .44618 .68387 Mtetra
.954 .918 .736 r
.44618 .68387 .45482 .68141 .46991 .65093 .46135 .65731 Mtetra
.977 .918 .659 r
.46135 .65731 .46991 .65093 .48492 .61438 .47651 .62313 Mtetra
.978 .917 .615 r
.47651 .62313 .48492 .61438 .49974 .57737 .49154 .58535 Mtetra
.973 .925 .624 r
.49154 .58535 .49974 .57737 .51434 .54579 .50634 .55033 Mtetra
.962 .941 .694 r
.50634 .55033 .51434 .54579 .52879 .52217 .52095 .52254 Mtetra
.925 .937 .792 r
.52095 .52254 .52879 .52217 .5432 .50569 .53546 .50262 Mtetra
.856 .897 .864 r
.53546 .50262 .5432 .50569 .55762 .49421 .54996 .48883 Mtetra
.785 .844 .896 r
.54996 .48883 .55762 .49421 .5721 .48581 .5645 .47902 Mtetra
.733 .802 .906 r
.5645 .47902 .5721 .48581 .58666 .47915 .5791 .47156 Mtetra
.702 .775 .909 r
.5791 .47156 .58666 .47915 .6013 .47345 .59379 .46539 Mtetra
.684 .759 .909 r
.59379 .46539 .6013 .47345 .61602 .46825 .60857 .45992 Mtetra
.674 .751 .908 r
.60857 .45992 .61602 .46825 .63083 .4633 .62342 .45481 Mtetra
.669 .746 .908 r
.62342 .45481 .63083 .4633 .64571 .45847 .63836 .44987 Mtetra
.667 .744 .908 r
.63836 .44987 .64571 .45847 .66068 .4537 .65338 .44502 Mtetra
.665 .743 .908 r
.65338 .44502 .66068 .4537 .67572 .44894 .66848 .4402 Mtetra
.664 .742 .908 r
.66848 .4402 .67572 .44894 .69085 .44418 .68366 .43538 Mtetra
.68366 .43538 .69085 .44418 .70606 .43941 .69893 .43056 Mtetra
.69893 .43056 .70606 .43941 .72135 .43462 .71427 .42572 Mtetra
.664 .741 .908 r
.71427 .42572 .72135 .43462 .73673 .4298 .72971 .42085 Mtetra
.72971 .42085 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .42009 .76082 .41104 Mtetra
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.65 .765 .933 r
.32011 .74237 .32912 .74961 .34339 .74546 .33443 .73823 Mtetra
.654 .767 .933 r
.33443 .73823 .34339 .74546 .35775 .74109 .34883 .73393 Mtetra
.661 .772 .931 r
.34883 .73393 .35775 .74109 .3722 .73635 .36332 .72936 Mtetra
.675 .78 .929 r
.36332 .72936 .3722 .73635 .38675 .73092 .37791 .72427 Mtetra
.698 .795 .925 r
.37791 .72427 .38675 .73092 .40141 .72424 .3926 .71825 Mtetra
.738 .818 .914 r
.3926 .71825 .40141 .72424 .41619 .71532 .40741 .71054 Mtetra
.796 .851 .892 r
.40741 .71054 .41619 .71532 .43111 .70257 .42236 .69986 Mtetra
.868 .887 .847 r
.42236 .69986 .43111 .70257 .44618 .68387 .43745 .68433 Mtetra
.932 .913 .777 r
.43745 .68433 .44618 .68387 .46135 .65731 .45268 .66174 Mtetra
.969 .92 .695 r
.45268 .66174 .46135 .65731 .47651 .62313 .46796 .63097 Mtetra
.979 .917 .631 r
.46796 .63097 .47651 .62313 .49154 .58535 .48318 .59409 Mtetra
.976 .919 .612 r
.48318 .59409 .49154 .58535 .50634 .55033 .49819 .55676 Mtetra
.969 .934 .653 r
.49819 .55676 .50634 .55033 .52095 .52254 .51299 .5249 Mtetra
.948 .944 .743 r
.51299 .5249 .52095 .52254 .53546 .50262 .52762 .50105 Mtetra
.893 .921 .833 r
.52762 .50105 .53546 .50262 .54996 .48883 .54221 .48438 Mtetra
.819 .87 .884 r
.54221 .48438 .54996 .48883 .5645 .47902 .55681 .47275 Mtetra
.756 .821 .903 r
.55681 .47275 .5645 .47902 .5791 .47156 .57147 .46421 Mtetra
.715 .787 .908 r
.57147 .46421 .5791 .47156 .59379 .46539 .58621 .45743 Mtetra
.692 .766 .909 r
.58621 .45743 .59379 .46539 .60857 .45992 .60104 .4516 Mtetra
.678 .755 .909 r
.60104 .4516 .60857 .45992 .62342 .45481 .61594 .44628 Mtetra
.671 .748 .908 r
.61594 .44628 .62342 .45481 .63836 .44987 .63093 .44121 Mtetra
.668 .745 .908 r
.63093 .44121 .63836 .44987 .65338 .44502 .646 .43627 Mtetra
.666 .743 .908 r
.646 .43627 .65338 .44502 .66848 .4402 .66116 .43138 Mtetra
.665 .742 .908 r
.66116 .43138 .66848 .4402 .68366 .43538 .6764 .4265 Mtetra
.664 .742 .908 r
.6764 .4265 .68366 .43538 .69893 .43056 .69172 .42162 Mtetra
.69172 .42162 .69893 .43056 .71427 .42572 .70713 .41672 Mtetra
.664 .741 .908 r
.70713 .41672 .71427 .42572 .72971 .42085 .72262 .41181 Mtetra
.72262 .41181 .72971 .42085 .74522 .41596 .73819 .40687 Mtetra
.73819 .40687 .74522 .41596 .76082 .41104 .75385 .4019 Mtetra
.75385 .4019 .76082 .41104 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.649 .764 .933 r
.31101 .73504 .32011 .74237 .33443 .73823 .32538 .7309 Mtetra
.652 .766 .933 r
.32538 .7309 .33443 .73823 .34883 .73393 .33983 .72664 Mtetra
.657 .769 .932 r
.33983 .72664 .34883 .73393 .36332 .72936 .35436 .72217 Mtetra
.667 .775 .931 r
.35436 .72217 .36332 .72936 .37791 .72427 .36899 .71732 Mtetra
.685 .786 .927 r
.36899 .71732 .37791 .72427 .3926 .71825 .38371 .71178 Mtetra
.716 .805 .92 r
.38371 .71178 .3926 .71825 .40741 .71054 .39855 .70497 Mtetra
.764 .834 .905 r
.39855 .70497 .40741 .71054 .42236 .69986 .41352 .69591 Mtetra
.831 .87 .873 r
.41352 .69591 .42236 .69986 .43745 .68433 .42864 .68299 Mtetra
.902 .902 .815 r
.42864 .68299 .43745 .68433 .45268 .66174 .4439 .66408 Mtetra
.954 .918 .736 r
.4439 .66408 .45268 .66174 .46796 .63097 .45928 .63725 Mtetra
.977 .918 .659 r
.45928 .63725 .46796 .63097 .48318 .59409 .47465 .60275 Mtetra
.978 .917 .615 r
.47465 .60275 .48318 .59409 .49819 .55676 .48988 .56464 Mtetra
.973 .925 .625 r
.48988 .56464 .49819 .55676 .51299 .5249 .50488 .52931 Mtetra
.962 .941 .694 r
.50488 .52931 .51299 .5249 .52762 .50105 .51968 .50126 Mtetra
.925 .937 .792 r
.51968 .50126 .52762 .50105 .54221 .48438 .53437 .48114 Mtetra
.856 .897 .864 r
.53437 .48114 .54221 .48438 .55681 .47275 .54905 .46718 Mtetra
.785 .844 .896 r
.54905 .46718 .55681 .47275 .57147 .46421 .56377 .45722 Mtetra
.733 .802 .906 r
.56377 .45722 .57147 .46421 .58621 .45743 .57856 .44963 Mtetra
.702 .775 .909 r
.57856 .44963 .58621 .45743 .60104 .4516 .59343 .44333 Mtetra
.684 .759 .909 r
.59343 .44333 .60104 .4516 .61594 .44628 .60839 .43774 Mtetra
.674 .751 .908 r
.60839 .43774 .61594 .44628 .63093 .44121 .62343 .4325 Mtetra
.669 .746 .908 r
.62343 .4325 .63093 .44121 .646 .43627 .63856 .42745 Mtetra
.667 .744 .908 r
.63856 .42745 .646 .43627 .66116 .43138 .65377 .42248 Mtetra
.665 .743 .908 r
.65377 .42248 .66116 .43138 .6764 .4265 .66906 .41753 Mtetra
.664 .742 .908 r
.66906 .41753 .6764 .4265 .69172 .42162 .68444 .41259 Mtetra
.68444 .41259 .69172 .42162 .70713 .41672 .6999 .40764 Mtetra
.6999 .40764 .70713 .41672 .72262 .41181 .71545 .40268 Mtetra
.664 .741 .908 r
.71545 .40268 .72262 .41181 .73819 .40687 .73109 .39768 Mtetra
.73109 .39768 .73819 .40687 .75385 .4019 .74681 .39267 Mtetra
.74681 .39267 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.648 .764 .933 r
.30182 .72762 .31101 .73504 .32538 .7309 .31624 .72347 Mtetra
.65 .765 .933 r
.31624 .72347 .32538 .7309 .33983 .72664 .33073 .71923 Mtetra
.654 .767 .933 r
.33073 .71923 .33983 .72664 .35436 .72217 .34531 .71482 Mtetra
.661 .772 .931 r
.34531 .71482 .35436 .72217 .36899 .71732 .35998 .71014 Mtetra
.675 .78 .929 r
.35998 .71014 .36899 .71732 .38371 .71178 .37474 .70494 Mtetra
.698 .795 .925 r
.37474 .70494 .38371 .71178 .39855 .70497 .38962 .69879 Mtetra
.737 .818 .914 r
.38962 .69879 .39855 .70497 .41352 .69591 .40461 .69095 Mtetra
.796 .851 .892 r
.40461 .69095 .41352 .69591 .42864 .68299 .41975 .68012 Mtetra
.868 .888 .847 r
.41975 .68012 .42864 .68299 .4439 .66408 .43504 .6644 Mtetra
.932 .913 .777 r
.43504 .6644 .4439 .66408 .45928 .63725 .45047 .64156 Mtetra
.969 .92 .695 r
.45047 .64156 .45928 .63725 .47465 .60275 .46597 .6105 Mtetra
.979 .917 .631 r
.46597 .6105 .47465 .60275 .48988 .56464 .48139 .57329 Mtetra
.976 .919 .612 r
.48139 .57329 .48988 .56464 .50488 .52931 .49661 .53563 Mtetra
.969 .933 .653 r
.49661 .53563 .50488 .52931 .51968 .50126 .5116 .50348 Mtetra
.948 .943 .743 r
.5116 .50348 .51968 .50126 .53437 .48114 .52643 .4794 Mtetra
.893 .921 .833 r
.52643 .4794 .53437 .48114 .54905 .46718 .5412 .46254 Mtetra
.819 .87 .884 r
.5412 .46254 .54905 .46718 .56377 .45722 .55598 .45075 Mtetra
.756 .821 .903 r
.55598 .45075 .56377 .45722 .57856 .44963 .57083 .44207 Mtetra
.715 .786 .908 r
.57083 .44207 .57856 .44963 .59343 .44333 .58575 .43516 Mtetra
.692 .766 .909 r
.58575 .43516 .59343 .44333 .60839 .43774 .60076 .4292 Mtetra
.678 .755 .909 r
.60076 .4292 .60839 .43774 .62343 .4325 .61586 .42376 Mtetra
.671 .748 .908 r
.61586 .42376 .62343 .4325 .63856 .42745 .63104 .41857 Mtetra
.668 .745 .908 r
.63104 .41857 .63856 .42745 .65377 .42248 .6463 .4135 Mtetra
.666 .743 .908 r
.6463 .4135 .65377 .42248 .66906 .41753 .66165 .40848 Mtetra
.665 .742 .908 r
.66165 .40848 .66906 .41753 .68444 .41259 .67709 .40348 Mtetra
.664 .742 .908 r
.67709 .40348 .68444 .41259 .6999 .40764 .69261 .39847 Mtetra
.69261 .39847 .6999 .40764 .71545 .40268 .70822 .39345 Mtetra
.664 .741 .908 r
.70822 .39345 .71545 .40268 .73109 .39768 .72391 .38841 Mtetra
.72391 .38841 .73109 .39768 .74681 .39267 .73969 .38334 Mtetra
.73969 .38334 .74681 .39267 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.648 .763 .933 r
.29254 .72011 .30182 .72762 .31624 .72347 .307 .71595 Mtetra
.649 .764 .933 r
.307 .71595 .31624 .72347 .33073 .71923 .32154 .7117 Mtetra
.652 .766 .933 r
.32154 .7117 .33073 .71923 .34531 .71482 .33617 .70734 Mtetra
.657 .769 .932 r
.33617 .70734 .34531 .71482 .35998 .71014 .35088 .70276 Mtetra
.667 .775 .931 r
.35088 .70276 .35998 .71014 .37474 .70494 .36569 .6978 Mtetra
.685 .786 .927 r
.36569 .6978 .37474 .70494 .38962 .69879 .3806 .69214 Mtetra
.716 .805 .92 r
.3806 .69214 .38962 .69879 .40461 .69095 .39563 .6852 Mtetra
.764 .834 .905 r
.39563 .6852 .40461 .69095 .41975 .68012 .41079 .67599 Mtetra
.831 .87 .873 r
.41079 .67599 .41975 .68012 .43504 .6644 .4261 .6629 Mtetra
.902 .903 .815 r
.4261 .6629 .43504 .6644 .45047 .64156 .44157 .64377 Mtetra
.955 .918 .735 r
.44157 .64377 .45047 .64156 .46597 .6105 .45715 .61667 Mtetra
.977 .918 .659 r
.45715 .61667 .46597 .6105 .48139 .57329 .47273 .58185 Mtetra
.978 .917 .615 r
.47273 .58185 .48139 .57329 .49661 .53563 .48817 .5434 Mtetra
.973 .925 .625 r
.48817 .5434 .49661 .53563 .5116 .50348 .50338 .50776 Mtetra
.962 .941 .694 r
.50338 .50776 .5116 .50348 .52643 .4794 .51837 .47945 Mtetra
.925 .937 .792 r
.51837 .47945 .52643 .4794 .5412 .46254 .53325 .45911 Mtetra
.856 .897 .864 r
.53325 .45911 .5412 .46254 .55598 .45075 .54811 .44497 Mtetra
.785 .844 .896 r
.54811 .44497 .55598 .45075 .57083 .44207 .56302 .43487 Mtetra
.733 .802 .906 r
.56302 .43487 .57083 .44207 .58575 .43516 .578 .42714 Mtetra
.702 .775 .908 r
.578 .42714 .58575 .43516 .60076 .4292 .59306 .42071 Mtetra
.684 .759 .909 r
.59306 .42071 .60076 .4292 .61586 .42376 .60821 .41499 Mtetra
.674 .751 .908 r
.60821 .41499 .61586 .42376 .63104 .41857 .62344 .40963 Mtetra
.669 .746 .908 r
.62344 .40963 .63104 .41857 .6463 .4135 .63876 .40445 Mtetra
.667 .744 .908 r
.63876 .40445 .6463 .4135 .66165 .40848 .65417 .39935 Mtetra
.665 .743 .908 r
.65417 .39935 .66165 .40848 .67709 .40348 .66966 .39428 Mtetra
.664 .742 .908 r
.66966 .39428 .67709 .40348 .69261 .39847 .68524 .38921 Mtetra
.68524 .38921 .69261 .39847 .70822 .39345 .70091 .38413 Mtetra
.70091 .38413 .70822 .39345 .72391 .38841 .71666 .37904 Mtetra
.664 .741 .908 r
.71666 .37904 .72391 .38841 .73969 .38334 .7325 .37391 Mtetra
.7325 .37391 .73969 .38334 .75556 .37824 .74844 .36876 Mtetra
.74844 .36876 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.647 .763 .934 r
.28317 .71253 .29254 .72011 .307 .71595 .29767 .70833 Mtetra
.648 .764 .933 r
.29767 .70833 .307 .71595 .32154 .7117 .31226 .70408 Mtetra
.65 .765 .933 r
.31226 .70408 .32154 .7117 .33617 .70734 .32693 .69973 Mtetra
.654 .767 .933 r
.32693 .69973 .33617 .70734 .35088 .70276 .34169 .69521 Mtetra
.661 .772 .931 r
.34169 .69521 .35088 .70276 .36569 .6978 .35654 .69042 Mtetra
.675 .78 .929 r
.35654 .69042 .36569 .6978 .3806 .69214 .37149 .6851 Mtetra
.698 .795 .925 r
.37149 .6851 .3806 .69214 .39563 .6852 .38656 .67883 Mtetra
.737 .818 .914 r
.38656 .67883 .39563 .6852 .41079 .67599 .40175 .67085 Mtetra
.796 .851 .892 r
.40175 .67085 .41079 .67599 .4261 .6629 .41708 .65986 Mtetra
.868 .888 .848 r
.41708 .65986 .4261 .6629 .44157 .64377 .43257 .64393 Mtetra
.932 .913 .777 r
.43257 .64393 .44157 .64377 .45715 .61667 .44821 .62086 Mtetra
.969 .92 .695 r
.44821 .62086 .45715 .61667 .47273 .58185 .46392 .58949 Mtetra
.979 .917 .631 r
.46392 .58949 .47273 .58185 .48817 .5434 .47956 .55194 Mtetra
.976 .919 .612 r
.47956 .55194 .48817 .5434 .50338 .50776 .49499 .51395 Mtetra
.969 .933 .653 r
.49499 .51395 .50338 .50776 .51837 .47945 .51018 .48151 Mtetra
.948 .943 .743 r
.51018 .48151 .51837 .47945 .53325 .45911 .5252 .45719 Mtetra
.893 .92 .833 r
.5252 .45719 .53325 .45911 .54811 .44497 .54016 .44014 Mtetra
.819 .87 .884 r
.54016 .44014 .54811 .44497 .56302 .43487 .55513 .42818 Mtetra
.756 .821 .903 r
.55513 .42818 .56302 .43487 .578 .42714 .57017 .41936 Mtetra
.715 .786 .908 r
.57017 .41936 .578 .42714 .59306 .42071 .58528 .41231 Mtetra
.692 .766 .909 r
.58528 .41231 .59306 .42071 .60821 .41499 .60048 .40623 Mtetra
.678 .755 .909 r
.60048 .40623 .60821 .41499 .62344 .40963 .61577 .40065 Mtetra
.671 .748 .908 r
.61577 .40065 .62344 .40963 .63876 .40445 .63115 .39533 Mtetra
.668 .745 .908 r
.63115 .39533 .63876 .40445 .65417 .39935 .64661 .39014 Mtetra
.666 .743 .908 r
.64661 .39014 .65417 .39935 .66966 .39428 .66216 .38499 Mtetra
.665 .742 .908 r
.66216 .38499 .66966 .39428 .68524 .38921 .6778 .37986 Mtetra
.664 .742 .908 r
.6778 .37986 .68524 .38921 .70091 .38413 .69353 .37472 Mtetra
.69353 .37472 .70091 .38413 .71666 .37904 .70934 .36957 Mtetra
.664 .741 .908 r
.70934 .36957 .71666 .37904 .7325 .37391 .72524 .36439 Mtetra
.72524 .36439 .7325 .37391 .74844 .36876 .74123 .35919 Mtetra
.74123 .35919 .74844 .36876 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.647 .763 .934 r
.2737 .70486 .28317 .71253 .29767 .70833 .28825 .70063 Mtetra
.648 .763 .933 r
.28825 .70063 .29767 .70833 .31226 .70408 .30289 .69636 Mtetra
.649 .764 .933 r
.30289 .69636 .31226 .70408 .32693 .69973 .3176 .692 Mtetra
.652 .766 .933 r
.3176 .692 .32693 .69973 .34169 .69521 .33241 .68753 Mtetra
.657 .769 .932 r
.33241 .68753 .34169 .69521 .35654 .69042 .34731 .68284 Mtetra
.667 .775 .931 r
.34731 .68284 .35654 .69042 .37149 .6851 .3623 .67776 Mtetra
.685 .786 .927 r
.3623 .67776 .37149 .6851 .38656 .67883 .3774 .67197 Mtetra
.716 .805 .921 r
.3774 .67197 .38656 .67883 .40175 .67085 .39262 .6649 Mtetra
.764 .834 .905 r
.39262 .6649 .40175 .67085 .41708 .65986 .40798 .65554 Mtetra
.831 .87 .873 r
.40798 .65554 .41708 .65986 .43257 .64393 .4235 .64227 Mtetra
.902 .903 .815 r
.4235 .64227 .43257 .64393 .44821 .62086 .43917 .62292 Mtetra
.955 .919 .735 r
.43917 .62292 .44821 .62086 .46392 .58949 .45497 .59554 Mtetra
.977 .919 .659 r
.45497 .59554 .46392 .58949 .47956 .55194 .47077 .56039 Mtetra
.978 .917 .615 r
.47077 .56039 .47956 .55194 .49499 .51395 .48642 .5216 Mtetra
.973 .925 .625 r
.48642 .5216 .49499 .51395 .51018 .48151 .50183 .48565 Mtetra
.962 .941 .695 r
.50183 .48565 .51018 .48151 .5252 .45719 .51703 .45707 Mtetra
.925 .937 .792 r
.51703 .45707 .5252 .45719 .54016 .44014 .5321 .43651 Mtetra
.856 .896 .864 r
.5321 .43651 .54016 .44014 .55513 .42818 .54716 .4222 Mtetra
.785 .843 .896 r
.54716 .4222 .55513 .42818 .57017 .41936 .56226 .41194 Mtetra
.733 .801 .906 r
.56226 .41194 .57017 .41936 .58528 .41231 .57743 .40407 Mtetra
.702 .775 .908 r
.57743 .40407 .58528 .41231 .60048 .40623 .59268 .39751 Mtetra
.684 .759 .909 r
.59268 .39751 .60048 .40623 .61577 .40065 .60802 .39165 Mtetra
.674 .751 .908 r
.60802 .39165 .61577 .40065 .63115 .39533 .62345 .38616 Mtetra
.669 .746 .908 r
.62345 .38616 .63115 .39533 .64661 .39014 .63897 .38085 Mtetra
.667 .744 .908 r
.63897 .38085 .64661 .39014 .66216 .38499 .65458 .37562 Mtetra
.665 .743 .908 r
.65458 .37562 .66216 .38499 .6778 .37986 .67028 .37042 Mtetra
.664 .742 .908 r
.67028 .37042 .6778 .37986 .69353 .37472 .68607 .36522 Mtetra
.68607 .36522 .69353 .37472 .70934 .36957 .70194 .36001 Mtetra
.70194 .36001 .70934 .36957 .72524 .36439 .7179 .35477 Mtetra
.664 .741 .908 r
.7179 .35477 .72524 .36439 .74123 .35919 .73396 .34951 Mtetra
.73396 .34951 .74123 .35919 .75732 .35396 .75011 .34423 Mtetra
.75011 .34423 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .763 .934 r
.26413 .69711 .2737 .70486 .28825 .70063 .27873 .69285 Mtetra
.647 .763 .934 r
.27873 .69285 .28825 .70063 .30289 .69636 .29341 .68854 Mtetra
.648 .764 .933 r
.29341 .68854 .30289 .69636 .3176 .692 .30818 .68418 Mtetra
.65 .765 .933 r
.30818 .68418 .3176 .692 .33241 .68753 .32303 .67971 Mtetra
.654 .767 .933 r
.32303 .67971 .33241 .68753 .34731 .68284 .33798 .67509 Mtetra
.661 .772 .931 r
.33798 .67509 .34731 .68284 .3623 .67776 .35302 .67017 Mtetra
.675 .78 .929 r
.35302 .67017 .3623 .67776 .3774 .67197 .36816 .66473 Mtetra
.698 .795 .925 r
.36816 .66473 .3774 .67197 .39262 .6649 .38341 .65833 Mtetra
.737 .818 .914 r
.38341 .65833 .39262 .6649 .40798 .65554 .3988 .65021 Mtetra
.796 .852 .892 r
.3988 .65021 .40798 .65554 .4235 .64227 .41434 .63905 Mtetra
.868 .888 .848 r
.41434 .63905 .4235 .64227 .43917 .62292 .43004 .62293 Mtetra
.932 .913 .777 r
.43004 .62293 .43917 .62292 .45497 .59554 .44589 .5996 Mtetra
.969 .92 .695 r
.44589 .5996 .45497 .59554 .47077 .56039 .46182 .56792 Mtetra
.979 .917 .631 r
.46182 .56792 .47077 .56039 .48642 .5216 .47768 .53003 Mtetra
.976 .919 .612 r
.47768 .53003 .48642 .5216 .50183 .48565 .49332 .4917 Mtetra
.969 .933 .654 r
.49332 .4917 .50183 .48565 .51703 .45707 .50872 .45897 Mtetra
.948 .943 .744 r
.50872 .45897 .51703 .45707 .5321 .43651 .52394 .43441 Mtetra
.893 .92 .833 r
.52394 .43441 .5321 .43651 .54716 .4222 .53909 .41716 Mtetra
.819 .87 .884 r
.53909 .41716 .54716 .4222 .56226 .41194 .55426 .40504 Mtetra
.756 .82 .903 r
.55426 .40504 .56226 .41194 .57743 .40407 .56949 .39606 Mtetra
.715 .786 .908 r
.56949 .39606 .57743 .40407 .59268 .39751 .5848 .38888 Mtetra
.692 .766 .909 r
.5848 .38888 .59268 .39751 .60802 .39165 .6002 .38266 Mtetra
.678 .755 .909 r
.6002 .38266 .60802 .39165 .62345 .38616 .61568 .37695 Mtetra
.671 .748 .908 r
.61568 .37695 .62345 .38616 .63897 .38085 .63126 .37149 Mtetra
.668 .745 .908 r
.63126 .37149 .63897 .38085 .65458 .37562 .64693 .36616 Mtetra
.666 .743 .908 r
.64693 .36616 .65458 .37562 .67028 .37042 .66268 .36089 Mtetra
.665 .742 .908 r
.66268 .36089 .67028 .37042 .68607 .36522 .67853 .35562 Mtetra
.664 .742 .908 r
.67853 .35562 .68607 .36522 .70194 .36001 .69446 .35034 Mtetra
.69446 .35034 .70194 .36001 .7179 .35477 .71049 .34505 Mtetra
.664 .741 .908 r
.71049 .34505 .7179 .35477 .73396 .34951 .72661 .33974 Mtetra
.72661 .33974 .73396 .34951 .75011 .34423 .74282 .33439 Mtetra
.74282 .33439 .75011 .34423 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.646 .763 .934 r
.25447 .68927 .26413 .69711 .27873 .69285 .26911 .68497 Mtetra
.647 .763 .934 r
.26911 .68497 .27873 .69285 .29341 .68854 .28384 .68064 Mtetra
.648 .763 .933 r
.28384 .68064 .29341 .68854 .30818 .68418 .29866 .67625 Mtetra
.649 .764 .933 r
.29866 .67625 .30818 .68418 .32303 .67971 .31356 .67178 Mtetra
.652 .766 .933 r
.31356 .67178 .32303 .67971 .33798 .67509 .32855 .66719 Mtetra
.657 .769 .932 r
.32855 .66719 .33798 .67509 .35302 .67017 .34364 .66238 Mtetra
.667 .775 .931 r
.34364 .66238 .35302 .67017 .36816 .66473 .35882 .65718 Mtetra
.685 .786 .927 r
.35882 .65718 .36816 .66473 .38341 .65833 .37412 .65127 Mtetra
.716 .805 .921 r
.37412 .65127 .38341 .65833 .3988 .65021 .38953 .64406 Mtetra
.764 .834 .905 r
.38953 .64406 .3988 .65021 .41434 .63905 .4051 .63455 Mtetra
.831 .87 .873 r
.4051 .63455 .41434 .63905 .43004 .62293 .42082 .62109 Mtetra
.903 .903 .815 r
.42082 .62109 .43004 .62293 .44589 .5996 .43671 .60151 Mtetra
.955 .919 .735 r
.43671 .60151 .44589 .5996 .46182 .56792 .45273 .57385 Mtetra
.977 .919 .659 r
.45273 .57385 .46182 .56792 .47768 .53003 .46875 .53837 Mtetra
.978 .917 .615 r
.46875 .53837 .47768 .53003 .49332 .4917 .48463 .49923 Mtetra
.973 .925 .625 r
.48463 .49923 .49332 .4917 .50872 .45897 .50025 .46295 Mtetra
.962 .941 .695 r
.50025 .46295 .50872 .45897 .52394 .43441 .51565 .4341 Mtetra
.925 .936 .792 r
.51565 .4341 .52394 .43441 .53909 .41716 .53093 .41333 Mtetra
.856 .896 .864 r
.53093 .41333 .53909 .41716 .55426 .40504 .54618 .39884 Mtetra
.785 .843 .896 r
.54618 .39884 .55426 .40504 .56949 .39606 .56147 .38842 Mtetra
.733 .801 .906 r
.56147 .38842 .56949 .39606 .5848 .38888 .57684 .38039 Mtetra
.702 .775 .908 r
.57684 .38039 .5848 .38888 .6002 .38266 .59229 .3737 Mtetra
.684 .759 .909 r
.59229 .3737 .6002 .38266 .61568 .37695 .60783 .36771 Mtetra
.674 .751 .908 r
.60783 .36771 .61568 .37695 .63126 .37149 .62347 .36208 Mtetra
.669 .746 .908 r
.62347 .36208 .63126 .37149 .64693 .36616 .63919 .35663 Mtetra
.667 .744 .908 r
.63919 .35663 .64693 .36616 .66268 .36089 .65501 .35126 Mtetra
.665 .743 .908 r
.65501 .35126 .66268 .36089 .67853 .35562 .67091 .34592 Mtetra
.664 .742 .908 r
.67091 .34592 .67853 .35562 .69446 .35034 .68691 .34059 Mtetra
.68691 .34059 .69446 .35034 .71049 .34505 .703 .33523 Mtetra
.703 .33523 .71049 .34505 .72661 .33974 .71918 .32986 Mtetra
.664 .741 .908 r
.71918 .32986 .72661 .33974 .74282 .33439 .73545 .32446 Mtetra
.73545 .32446 .74282 .33439 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .763 .934 r
.2447 .68135 .25447 .68927 .26911 .68497 .2594 .67702 Mtetra
.2594 .67702 .26911 .68497 .28384 .68064 .27418 .67264 Mtetra
.647 .763 .934 r
.27418 .67264 .28384 .68064 .29866 .67625 .28904 .66823 Mtetra
.648 .764 .933 r
.28904 .66823 .29866 .67625 .31356 .67178 .30399 .66375 Mtetra
.65 .765 .933 r
.30399 .66375 .31356 .67178 .32855 .66719 .31903 .65917 Mtetra
.654 .767 .933 r
.31903 .65917 .32855 .66719 .34364 .66238 .33416 .65442 Mtetra
.661 .772 .931 r
.33416 .65442 .34364 .66238 .35882 .65718 .34939 .64938 Mtetra
.675 .78 .929 r
.34939 .64938 .35882 .65718 .37412 .65127 .36473 .64382 Mtetra
.698 .795 .925 r
.36473 .64382 .37412 .65127 .38953 .64406 .38018 .63728 Mtetra
.737 .818 .915 r
.38018 .63728 .38953 .64406 .4051 .63455 .39577 .62901 Mtetra
.796 .852 .892 r
.39577 .62901 .4051 .63455 .42082 .62109 .41152 .61768 Mtetra
.868 .888 .848 r
.41152 .61768 .42082 .62109 .43671 .60151 .42743 .60135 Mtetra
.932 .914 .776 r
.42743 .60135 .43671 .60151 .45273 .57385 .44351 .57777 Mtetra
.969 .92 .694 r
.44351 .57777 .45273 .57385 .46875 .53837 .45966 .54578 Mtetra
.979 .917 .631 r
.45966 .54578 .46875 .53837 .48463 .49923 .47575 .50754 Mtetra
.976 .919 .612 r
.47575 .50754 .48463 .49923 .50025 .46295 .49161 .46887 Mtetra
.969 .933 .654 r
.49161 .46887 .50025 .46295 .51565 .4341 .50722 .43583 Mtetra
.948 .943 .744 r
.50722 .43583 .51565 .4341 .53093 .41333 .52265 .41103 Mtetra
.893 .92 .833 r
.52265 .41103 .53093 .41333 .54618 .39884 .538 .39358 Mtetra
.819 .869 .884 r
.538 .39358 .54618 .39884 .56147 .38842 .55337 .38128 Mtetra
.756 .82 .903 r
.55337 .38128 .56147 .38842 .57684 .38039 .56879 .37216 Mtetra
.715 .786 .908 r
.56879 .37216 .57684 .38039 .59229 .3737 .5843 .36482 Mtetra
.692 .766 .909 r
.5843 .36482 .59229 .3737 .60783 .36771 .5999 .35846 Mtetra
.678 .755 .909 r
.5999 .35846 .60783 .36771 .62347 .36208 .61559 .35261 Mtetra
.671 .748 .908 r
.61559 .35261 .62347 .36208 .63919 .35663 .63137 .34702 Mtetra
.668 .745 .908 r
.63137 .34702 .63919 .35663 .65501 .35126 .64725 .34155 Mtetra
.666 .743 .908 r
.64725 .34155 .65501 .35126 .67091 .34592 .66322 .33614 Mtetra
.665 .742 .908 r
.66322 .33614 .67091 .34592 .68691 .34059 .67928 .33073 Mtetra
.664 .742 .908 r
.67928 .33073 .68691 .34059 .703 .33523 .69543 .32531 Mtetra
.69543 .32531 .703 .33523 .71918 .32986 .71167 .31988 Mtetra
.664 .741 .908 r
.71167 .31988 .71918 .32986 .73545 .32446 .72801 .31442 Mtetra
.72801 .31442 .73545 .32446 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .763 .934 r
.23483 .67335 .2447 .68135 .2594 .67702 .24958 .66897 Mtetra
.24958 .66897 .2594 .67702 .27418 .67264 .26441 .66456 Mtetra
.647 .763 .934 r
.26441 .66456 .27418 .67264 .28904 .66823 .27932 .66011 Mtetra
.648 .763 .933 r
.27932 .66011 .28904 .66823 .30399 .66375 .29432 .65561 Mtetra
.649 .764 .933 r
.29432 .65561 .30399 .66375 .31903 .65917 .30941 .65102 Mtetra
.652 .766 .933 r
.30941 .65102 .31903 .65917 .33416 .65442 .32459 .64631 Mtetra
.657 .769 .932 r
.32459 .64631 .33416 .65442 .34939 .64938 .33987 .64138 Mtetra
.667 .775 .931 r
.33987 .64138 .34939 .64938 .36473 .64382 .35525 .63605 Mtetra
.685 .786 .927 r
.35525 .63605 .36473 .64382 .38018 .63728 .37074 .63 Mtetra
.716 .805 .921 r
.37074 .63 .38018 .63728 .39577 .62901 .38636 .62266 Mtetra
.764 .834 .906 r
.38636 .62266 .39577 .62901 .41152 .61768 .40213 .61298 Mtetra
.831 .87 .873 r
.40213 .61298 .41152 .61768 .42743 .60135 .41807 .59933 Mtetra
.903 .903 .815 r
.41807 .59933 .42743 .60135 .44351 .57777 .43418 .57952 Mtetra
.955 .919 .735 r
.43418 .57952 .44351 .57777 .45966 .54578 .45042 .55157 Mtetra
.977 .919 .658 r
.45042 .55157 .45966 .54578 .47575 .50754 .46668 .51575 Mtetra
.978 .917 .615 r
.46668 .51575 .47575 .50754 .49161 .46887 .48278 .47626 Mtetra
.973 .925 .625 r
.48278 .47626 .49161 .46887 .50722 .43583 .49863 .43966 Mtetra
.962 .941 .695 r
.49863 .43966 .50722 .43583 .52265 .41103 .51424 .41053 Mtetra
.925 .936 .792 r
.51424 .41053 .52265 .41103 .538 .39358 .52972 .38954 Mtetra
.856 .896 .864 r
.52972 .38954 .538 .39358 .55337 .38128 .54517 .37485 Mtetra
.785 .843 .896 r
.54517 .37485 .55337 .38128 .56879 .37216 .56066 .36427 Mtetra
.733 .801 .906 r
.56066 .36427 .56879 .37216 .5843 .36482 .57623 .3561 Mtetra
.702 .775 .908 r
.57623 .3561 .5843 .36482 .5999 .35846 .59189 .34925 Mtetra
.684 .759 .909 r
.59189 .34925 .5999 .35846 .61559 .35261 .60764 .34312 Mtetra
.674 .751 .908 r
.60764 .34312 .61559 .35261 .63137 .34702 .62348 .33735 Mtetra
.669 .746 .908 r
.62348 .33735 .63137 .34702 .64725 .34155 .63941 .33176 Mtetra
.667 .744 .908 r
.63941 .33176 .64725 .34155 .66322 .33614 .65544 .32625 Mtetra
.665 .743 .908 r
.65544 .32625 .66322 .33614 .67928 .33073 .67156 .32077 Mtetra
.664 .742 .908 r
.67156 .32077 .67928 .33073 .69543 .32531 .68778 .31529 Mtetra
.68778 .31529 .69543 .32531 .71167 .31988 .70409 .30979 Mtetra
.70409 .30979 .71167 .31988 .72801 .31442 .72049 .30427 Mtetra
.664 .741 .908 r
.72049 .30427 .72801 .31442 .74444 .30893 .73699 .29872 Mtetra
.73699 .29872 .74444 .30893 .76097 .30341 .75358 .29315 Mtetra
.75358 .29315 .76097 .30341 .7776 .29786 .77027 .28754 Mtetra
.77027 .28754 .7776 .29786 .79432 .29228 .78706 .28189 Mtetra
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.646 .763 .934 r
.22486 .66527 .23483 .67335 .24958 .66897 .23966 .66084 Mtetra
.23966 .66084 .24958 .66897 .26441 .66456 .25453 .65639 Mtetra
.25453 .65639 .26441 .66456 .27932 .66011 .2695 .6519 Mtetra
.647 .763 .934 r
.2695 .6519 .27932 .66011 .29432 .65561 .28455 .64736 Mtetra
.648 .764 .933 r
.28455 .64736 .29432 .65561 .30941 .65102 .29969 .64276 Mtetra
.65 .765 .933 r
.29969 .64276 .30941 .65102 .32459 .64631 .31492 .63806 Mtetra
.654 .767 .933 r
.31492 .63806 .32459 .64631 .33987 .64138 .33025 .63319 Mtetra
.661 .772 .931 r
.33025 .63319 .33987 .64138 .35525 .63605 .34568 .62803 Mtetra
.675 .78 .929 r
.34568 .62803 .35525 .63605 .37074 .63 .36121 .62233 Mtetra
.698 .795 .925 r
.36121 .62233 .37074 .63 .38636 .62266 .37687 .61566 Mtetra
.737 .818 .915 r
.37687 .61566 .38636 .62266 .40213 .61298 .39266 .60723 Mtetra
.796 .852 .892 r
.39266 .60723 .40213 .61298 .41807 .59933 .40862 .59573 Mtetra
.868 .888 .848 r
.40862 .59573 .41807 .59933 .43418 .57952 .42476 .57919 Mtetra
.932 .914 .776 r
.42476 .57919 .43418 .57952 .45042 .55157 .44106 .55534 Mtetra
.969 .92 .694 r
.44106 .55534 .45042 .55157 .46668 .51575 .45744 .52303 Mtetra
.979 .917 .631 r
.45744 .52303 .46668 .51575 .48278 .47626 .47376 .48444 Mtetra
.976 .919 .612 r
.47376 .48444 .48278 .47626 .49863 .43966 .48986 .44542 Mtetra
.969 .933 .654 r
.48986 .44542 .49863 .43966 .51424 .41053 .50568 .41208 Mtetra
.948 .943 .744 r
.50568 .41208 .51424 .41053 .52972 .38954 .52132 .38702 Mtetra
.893 .92 .833 r
.52132 .38702 .52972 .38954 .54517 .37485 .53688 .36937 Mtetra
.819 .869 .884 r
.53688 .36937 .54517 .37485 .56066 .36427 .55245 .3569 Mtetra
.756 .82 .902 r
.55245 .3569 .56066 .36427 .57623 .3561 .56808 .34761 Mtetra
.715 .786 .908 r
.56808 .34761 .57623 .3561 .59189 .34925 .58379 .34013 Mtetra
.692 .766 .909 r
.58379 .34013 .59189 .34925 .60764 .34312 .5996 .33362 Mtetra
.678 .755 .909 r
.5996 .33362 .60764 .34312 .62348 .33735 .6155 .32763 Mtetra
.671 .748 .908 r
.6155 .32763 .62348 .33735 .63941 .33176 .63149 .32189 Mtetra
.668 .745 .908 r
.63149 .32189 .63941 .33176 .65544 .32625 .64758 .31628 Mtetra
.666 .743 .908 r
.64758 .31628 .65544 .32625 .67156 .32077 .66377 .31072 Mtetra
.665 .742 .908 r
.66377 .31072 .67156 .32077 .68778 .31529 .68004 .30516 Mtetra
.664 .742 .908 r
.68004 .30516 .68778 .31529 .70409 .30979 .69642 .2996 Mtetra
.69642 .2996 .70409 .30979 .72049 .30427 .71289 .29402 Mtetra
.664 .741 .908 r
.71289 .29402 .72049 .30427 .73699 .29872 .72945 .28841 Mtetra
.72945 .28841 .73699 .29872 .75358 .29315 .74611 .28277 Mtetra
.74611 .28277 .75358 .29315 .77027 .28754 .76287 .2771 Mtetra
.76287 .2771 .77027 .28754 .78706 .28189 .77973 .27139 Mtetra
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23966 .66084 .22963 .65263 Mtetra
.646 .763 .934 r
.22963 .65263 .23966 .66084 .25453 .65639 .24456 .64813 Mtetra
.24456 .64813 .25453 .65639 .2695 .6519 .25957 .6436 Mtetra
.647 .763 .934 r
.25957 .6436 .2695 .6519 .28455 .64736 .27467 .63903 Mtetra
.648 .763 .933 r
.27467 .63903 .28455 .64736 .29969 .64276 .28987 .6344 Mtetra
.649 .764 .933 r
.28987 .6344 .29969 .64276 .31492 .63806 .30515 .62969 Mtetra
.652 .766 .933 r
.30515 .62969 .31492 .63806 .33025 .63319 .32053 .62485 Mtetra
.657 .769 .932 r
.32053 .62485 .33025 .63319 .34568 .62803 .336 .61979 Mtetra
.667 .776 .931 r
.336 .61979 .34568 .62803 .36121 .62233 .35158 .61434 Mtetra
.685 .787 .927 r
.35158 .61434 .36121 .62233 .37687 .61566 .36728 .60815 Mtetra
.715 .805 .921 r
.36728 .60815 .37687 .61566 .39266 .60723 .38311 .60066 Mtetra
.764 .834 .906 r
.38311 .60066 .39266 .60723 .40862 .59573 .39909 .59081 Mtetra
.831 .871 .873 r
.39909 .59081 .40862 .59573 .42476 .57919 .41525 .57698 Mtetra
.903 .904 .815 r
.41525 .57698 .42476 .57919 .44106 .55534 .43158 .55692 Mtetra
.955 .919 .735 r
.43158 .55692 .44106 .55534 .45744 .52303 .44806 .52868 Mtetra
.977 .919 .658 r
.44806 .52868 .45744 .52303 .47376 .48444 .46455 .49252 Mtetra
.978 .917 .615 r
.46455 .49252 .47376 .48444 .48986 .44542 .48089 .45267 Mtetra
.973 .925 .626 r
.48089 .45267 .48986 .44542 .50568 .41208 .49696 .41573 Mtetra
.962 .94 .696 r
.49696 .41573 .50568 .41208 .52132 .38702 .51279 .38633 Mtetra
.925 .936 .792 r
.51279 .38633 .52132 .38702 .53688 .36937 .52848 .36511 Mtetra
.856 .896 .863 r
.52848 .36511 .53688 .36937 .55245 .3569 .54414 .35023 Mtetra
.785 .843 .896 r
.54414 .35023 .55245 .3569 .56808 .34761 .55984 .33948 Mtetra
.733 .801 .906 r
.55984 .33948 .56808 .34761 .58379 .34013 .57561 .33115 Mtetra
.702 .775 .908 r
.57561 .33115 .58379 .34013 .5996 .33362 .59148 .32415 Mtetra
.684 .759 .909 r
.59148 .32415 .5996 .33362 .6155 .32763 .60743 .31787 Mtetra
.674 .751 .908 r
.60743 .31787 .6155 .32763 .63149 .32189 .62349 .31196 Mtetra
.669 .746 .908 r
.62349 .31196 .63149 .32189 .64758 .31628 .63964 .30622 Mtetra
.667 .744 .908 r
.63964 .30622 .64758 .31628 .66377 .31072 .65589 .30056 Mtetra
.665 .743 .908 r
.65589 .30056 .66377 .31072 .68004 .30516 .67223 .29493 Mtetra
.664 .742 .908 r
.67223 .29493 .68004 .30516 .69642 .2996 .68867 .2893 Mtetra
.68867 .2893 .69642 .2996 .71289 .29402 .7052 .28365 Mtetra
.7052 .28365 .71289 .29402 .72945 .28841 .72183 .27798 Mtetra
.664 .741 .908 r
.72183 .27798 .72945 .28841 .74611 .28277 .73857 .27228 Mtetra
.73857 .27228 .74611 .28277 .76287 .2771 .75539 .26655 Mtetra
.75539 .26655 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65263 .2195 .64432 Mtetra
.646 .763 .934 r
.2195 .64432 .22963 .65263 .24456 .64813 .23447 .63978 Mtetra
.23447 .63978 .24456 .64813 .25957 .6436 .24954 .6352 Mtetra
.24954 .6352 .25957 .6436 .27467 .63903 .26469 .63059 Mtetra
.647 .763 .934 r
.26469 .63059 .27467 .63903 .28987 .6344 .27994 .62593 Mtetra
.648 .764 .933 r
.27994 .62593 .28987 .6344 .30515 .62969 .29527 .62121 Mtetra
.65 .765 .933 r
.29527 .62121 .30515 .62969 .32053 .62485 .3107 .61638 Mtetra
.654 .767 .933 r
.3107 .61638 .32053 .62485 .336 .61979 .32622 .61138 Mtetra
.661 .772 .931 r
.32622 .61138 .336 .61979 .35158 .61434 .34185 .60608 Mtetra
.675 .78 .929 r
.34185 .60608 .35158 .61434 .36728 .60815 .35759 .60025 Mtetra
.698 .795 .925 r
.35759 .60025 .36728 .60815 .38311 .60066 .37346 .59343 Mtetra
.737 .818 .915 r
.37346 .59343 .38311 .60066 .39909 .59081 .38947 .58485 Mtetra
.796 .852 .892 r
.38947 .58485 .39909 .59081 .41525 .57698 .40565 .57316 Mtetra
.868 .889 .848 r
.40565 .57316 .41525 .57698 .43158 .55692 .42201 .5564 Mtetra
.932 .914 .776 r
.42201 .5564 .43158 .55692 .44806 .52868 .43854 .53228 Mtetra
.969 .92 .694 r
.43854 .53228 .44806 .52868 .46455 .49252 .45517 .49965 Mtetra
.979 .917 .631 r
.45517 .49965 .46455 .49252 .48089 .45267 .47172 .4607 Mtetra
.976 .919 .613 r
.47172 .4607 .48089 .45267 .49696 .41573 .48805 .42133 Mtetra
.969 .933 .654 r
.48805 .42133 .49696 .41573 .51279 .38633 .5041 .38769 Mtetra
.948 .943 .744 r
.5041 .38769 .51279 .38633 .52848 .36511 .51996 .36238 Mtetra
.893 .919 .833 r
.51996 .36238 .52848 .36511 .54414 .35023 .53572 .34451 Mtetra
.819 .869 .884 r
.53572 .34451 .54414 .35023 .55984 .33948 .5515 .33186 Mtetra
.756 .82 .902 r
.5515 .33186 .55984 .33948 .57561 .33115 .56734 .32241 Mtetra
.715 .786 .908 r
.56734 .32241 .57561 .33115 .59148 .32415 .58327 .31477 Mtetra
.692 .766 .909 r
.58327 .31477 .59148 .32415 .60743 .31787 .59929 .30811 Mtetra
.678 .755 .909 r
.59929 .30811 .60743 .31787 .62349 .31196 .6154 .30197 Mtetra
.671 .748 .908 r
.6154 .30197 .62349 .31196 .63964 .30622 .63161 .29608 Mtetra
.668 .745 .908 r
.63161 .29608 .63964 .30622 .65589 .30056 .64792 .29032 Mtetra
.666 .743 .908 r
.64792 .29032 .65589 .30056 .67223 .29493 .66433 .2846 Mtetra
.665 .742 .908 r
.66433 .2846 .67223 .29493 .68867 .2893 .68083 .2789 Mtetra
.664 .742 .908 r
.68083 .2789 .68867 .2893 .7052 .28365 .69744 .27318 Mtetra
.69744 .27318 .7052 .28365 .72183 .27798 .71413 .26744 Mtetra
.664 .741 .908 r
.71413 .26744 .72183 .27798 .73857 .27228 .73093 .26168 Mtetra
.73093 .26168 .73857 .27228 .75539 .26655 .74783 .25588 Mtetra
.74783 .25588 .75539 .26655 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24419 Mtetra
.78193 .24419 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64432 .20925 .63593 Mtetra
.20925 .63593 .2195 .64432 .23447 .63978 .22428 .63134 Mtetra
.646 .763 .934 r
.22428 .63134 .23447 .63978 .24954 .6352 .2394 .62672 Mtetra
.2394 .62672 .24954 .6352 .26469 .63059 .25461 .62206 Mtetra
.647 .763 .934 r
.25461 .62206 .26469 .63059 .27994 .62593 .2699 .61736 Mtetra
.648 .763 .933 r
.2699 .61736 .27994 .62593 .29527 .62121 .28529 .61261 Mtetra
.649 .764 .933 r
.28529 .61261 .29527 .62121 .3107 .61638 .30077 .60777 Mtetra
.652 .766 .933 r
.30077 .60777 .3107 .61638 .32622 .61138 .31634 .60281 Mtetra
.657 .769 .932 r
.31634 .60281 .32622 .61138 .34185 .60608 .33202 .59761 Mtetra
.667 .776 .931 r
.33202 .59761 .34185 .60608 .35759 .60025 .34781 .59202 Mtetra
.685 .787 .927 r
.34781 .59202 .35759 .60025 .37346 .59343 .36372 .58569 Mtetra
.715 .805 .921 r
.36372 .58569 .37346 .59343 .38947 .58485 .37976 .57804 Mtetra
.764 .834 .906 r
.37976 .57804 .38947 .58485 .40565 .57316 .39596 .56803 Mtetra
.831 .871 .873 r
.39596 .56803 .40565 .57316 .42201 .5564 .41234 .55399 Mtetra
.903 .904 .815 r
.41234 .55399 .42201 .5564 .43854 .53228 .42891 .53369 Mtetra
.955 .919 .735 r
.42891 .53369 .43854 .53228 .45517 .49965 .44563 .50515 Mtetra
.977 .919 .658 r
.44563 .50515 .45517 .49965 .47172 .4607 .46236 .46864 Mtetra
.978 .917 .615 r
.46236 .46864 .47172 .4607 .48805 .42133 .47894 .42843 Mtetra
.973 .925 .626 r
.47894 .42843 .48805 .42133 .5041 .38769 .49525 .39116 Mtetra
.962 .94 .696 r
.49525 .39116 .5041 .38769 .51996 .36238 .5113 .36148 Mtetra
.925 .936 .792 r
.5113 .36148 .51996 .36238 .53572 .34451 .5272 .34002 Mtetra
.856 .896 .863 r
.5272 .34002 .53572 .34451 .5515 .33186 .54307 .32494 Mtetra
.785 .843 .896 r
.54307 .32494 .5515 .33186 .56734 .32241 .55899 .31402 Mtetra
.733 .801 .906 r
.55899 .31402 .56734 .32241 .58327 .31477 .57497 .30552 Mtetra
.702 .775 .908 r
.57497 .30552 .58327 .31477 .59929 .30811 .59105 .29837 Mtetra
.684 .759 .909 r
.59105 .29837 .59929 .30811 .6154 .30197 .60723 .29194 Mtetra
.674 .751 .908 r
.60723 .29194 .6154 .30197 .63161 .29608 .6235 .28587 Mtetra
.669 .746 .908 r
.6235 .28587 .63161 .29608 .64792 .29032 .63987 .27998 Mtetra
.667 .744 .908 r
.63987 .27998 .64792 .29032 .66433 .2846 .65635 .27417 Mtetra
.665 .743 .908 r
.65635 .27417 .66433 .2846 .68083 .2789 .67292 .26838 Mtetra
.664 .742 .908 r
.67292 .26838 .68083 .2789 .69744 .27318 .68958 .26259 Mtetra
.68958 .26259 .69744 .27318 .71413 .26744 .70635 .25679 Mtetra
.70635 .25679 .71413 .26744 .73093 .26168 .72322 .25096 Mtetra
.664 .741 .908 r
.72322 .25096 .73093 .26168 .74783 .25588 .74019 .24509 Mtetra
.74019 .24509 .74783 .25588 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24419 .77443 .23327 Mtetra
.77443 .23327 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.646 .762 .934 r
.18391 .63205 .19431 .64049 .20925 .63593 .1989 .62744 Mtetra
.1989 .62744 .20925 .63593 .22428 .63134 .21398 .62281 Mtetra
.646 .763 .934 r
.21398 .62281 .22428 .63134 .2394 .62672 .22915 .61814 Mtetra
.22915 .61814 .2394 .62672 .25461 .62206 .24441 .61344 Mtetra
.24441 .61344 .25461 .62206 .2699 .61736 .25976 .6087 Mtetra
.647 .763 .934 r
.25976 .6087 .2699 .61736 .28529 .61261 .2752 .60391 Mtetra
.648 .764 .933 r
.2752 .60391 .28529 .61261 .30077 .60777 .29073 .59905 Mtetra
.65 .765 .933 r
.29073 .59905 .30077 .60777 .31634 .60281 .30636 .59409 Mtetra
.654 .767 .933 r
.30636 .59409 .31634 .60281 .33202 .59761 .32209 .58896 Mtetra
.661 .772 .931 r
.32209 .58896 .33202 .59761 .34781 .59202 .33792 .58352 Mtetra
.675 .78 .929 r
.33792 .58352 .34781 .59202 .36372 .58569 .35387 .57755 Mtetra
.698 .795 .925 r
.35387 .57755 .36372 .58569 .37976 .57804 .36995 .57058 Mtetra
.737 .819 .915 r
.36995 .57058 .37976 .57804 .39596 .56803 .38618 .56183 Mtetra
.796 .852 .892 r
.38618 .56183 .39596 .56803 .41234 .55399 .40259 .54996 Mtetra
.868 .889 .848 r
.40259 .54996 .41234 .55399 .42891 .53369 .41918 .53298 Mtetra
.933 .914 .776 r
.41918 .53298 .42891 .53369 .44563 .50515 .43595 .50858 Mtetra
.969 .92 .694 r
.43595 .50858 .44563 .50515 .46236 .46864 .45283 .47563 Mtetra
.979 .917 .63 r
.45283 .47563 .46236 .46864 .47894 .42843 .46963 .43631 Mtetra
.976 .919 .613 r
.46963 .43631 .47894 .42843 .49525 .39116 .4862 .39659 Mtetra
.969 .933 .655 r
.4862 .39659 .49525 .39116 .5113 .36148 .50248 .36263 Mtetra
.948 .942 .744 r
.50248 .36263 .5113 .36148 .5272 .34002 .51856 .33706 Mtetra
.893 .919 .833 r
.51856 .33706 .5272 .34002 .54307 .32494 .53454 .31897 Mtetra
.819 .869 .883 r
.53454 .31897 .54307 .32494 .55899 .31402 .55053 .30614 Mtetra
.756 .82 .902 r
.55053 .30614 .55899 .31402 .57497 .30552 .56659 .29651 Mtetra
.715 .786 .908 r
.56659 .29651 .57497 .30552 .59105 .29837 .58273 .28871 Mtetra
.692 .766 .909 r
.58273 .28871 .59105 .29837 .60723 .29194 .59897 .28189 Mtetra
.678 .755 .909 r
.59897 .28189 .60723 .29194 .6235 .28587 .6153 .2756 Mtetra
.671 .748 .908 r
.6153 .2756 .6235 .28587 .63987 .27998 .63174 .26955 Mtetra
.668 .745 .908 r
.63174 .26955 .63987 .27998 .65635 .27417 .64827 .26363 Mtetra
.666 .743 .908 r
.64827 .26363 .65635 .27417 .67292 .26838 .66491 .25776 Mtetra
.665 .742 .908 r
.66491 .25776 .67292 .26838 .68958 .26259 .68165 .2519 Mtetra
.664 .742 .908 r
.68165 .2519 .68958 .26259 .70635 .25679 .69848 .24602 Mtetra
.69848 .24602 .70635 .25679 .72322 .25096 .71542 .24012 Mtetra
.664 .741 .908 r
.71542 .24012 .72322 .25096 .74019 .24509 .73246 .23419 Mtetra
.73246 .23419 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22224 Mtetra
.76684 .22224 .77443 .23327 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63205 .1989 .62744 .18844 .61887 Mtetra
.18844 .61887 .1989 .62744 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61814 .21879 .60946 Mtetra
.646 .763 .934 r
.21879 .60946 .22915 .61814 .24441 .61344 .2341 .60471 Mtetra
.2341 .60471 .24441 .61344 .25976 .6087 .2495 .59993 Mtetra
.647 .763 .934 r
.2495 .59993 .25976 .6087 .2752 .60391 .26499 .5951 Mtetra
.648 .763 .933 r
.26499 .5951 .2752 .60391 .29073 .59905 .28058 .59021 Mtetra
.649 .764 .933 r
.28058 .59021 .29073 .59905 .30636 .59409 .29626 .58524 Mtetra
.652 .766 .933 r
.29626 .58524 .30636 .59409 .32209 .58896 .31205 .58014 Mtetra
.657 .769 .932 r
.31205 .58014 .32209 .58896 .33792 .58352 .32793 .57481 Mtetra
.667 .776 .931 r
.32793 .57481 .33792 .58352 .35387 .57755 .34393 .56907 Mtetra
.685 .787 .928 r
.34393 .56907 .35387 .57755 .36995 .57058 .36005 .5626 Mtetra
.715 .805 .921 r
.36005 .5626 .36995 .57058 .38618 .56183 .37631 .55479 Mtetra
.764 .834 .906 r
.37631 .55479 .38618 .56183 .40259 .54996 .39274 .5446 Mtetra
.831 .871 .874 r
.39274 .5446 .40259 .54996 .41918 .53298 .40935 .53035 Mtetra
.903 .904 .815 r
.40935 .53035 .41918 .53298 .43595 .50858 .42616 .5098 Mtetra
.955 .92 .734 r
.42616 .5098 .43595 .50858 .45283 .47563 .44313 .48096 Mtetra
.977 .919 .658 r
.44313 .48096 .45283 .47563 .46963 .43631 .46012 .44409 Mtetra
.978 .917 .615 r
.46012 .44409 .46963 .43631 .4862 .39659 .47695 .40352 Mtetra
.973 .925 .626 r
.47695 .40352 .4862 .39659 .50248 .36263 .49349 .36591 Mtetra
.962 .94 .696 r
.49349 .36591 .50248 .36263 .51856 .33706 .50977 .33593 Mtetra
.925 .936 .792 r
.50977 .33593 .51856 .33706 .53454 .31897 .52589 .31423 Mtetra
.856 .895 .863 r
.52589 .31423 .53454 .31897 .55053 .30614 .54198 .29896 Mtetra
.785 .843 .896 r
.54198 .29896 .55053 .30614 .56659 .29651 .55811 .28785 Mtetra
.733 .801 .906 r
.55811 .28785 .56659 .29651 .58273 .28871 .57432 .27919 Mtetra
.702 .775 .908 r
.57432 .27919 .58273 .28871 .59897 .28189 .59062 .27188 Mtetra
.684 .759 .909 r
.59062 .27188 .59897 .28189 .6153 .2756 .60702 .26528 Mtetra
.674 .751 .908 r
.60702 .26528 .6153 .2756 .63174 .26955 .62352 .25905 Mtetra
.669 .746 .908 r
.62352 .25905 .63174 .26955 .64827 .26363 .64012 .253 Mtetra
.667 .744 .908 r
.64012 .253 .64827 .26363 .66491 .25776 .65682 .24703 Mtetra
.665 .743 .908 r
.65682 .24703 .66491 .25776 .68165 .2519 .67362 .24109 Mtetra
.664 .742 .908 r
.67362 .24109 .68165 .2519 .69848 .24602 .69052 .23514 Mtetra
.69052 .23514 .69848 .24602 .71542 .24012 .70753 .22917 Mtetra
.70753 .22917 .71542 .24012 .73246 .23419 .72464 .22317 Mtetra
.664 .741 .908 r
.72464 .22317 .73246 .23419 .7496 .22823 .74185 .21714 Mtetra
.74185 .21714 .7496 .22823 .76684 .22224 .75917 .21108 Mtetra
.75917 .21108 .76684 .22224 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60946 .20832 .60069 Mtetra
.646 .763 .934 r
.20832 .60069 .21879 .60946 .2341 .60471 .22368 .59589 Mtetra
.22368 .59589 .2341 .60471 .2495 .59993 .23913 .59106 Mtetra
.23913 .59106 .2495 .59993 .26499 .5951 .25468 .58619 Mtetra
.647 .763 .934 r
.25468 .58619 .26499 .5951 .28058 .59021 .27032 .58126 Mtetra
.648 .764 .933 r
.27032 .58126 .28058 .59021 .29626 .58524 .28606 .57627 Mtetra
.65 .765 .933 r
.28606 .57627 .29626 .58524 .31205 .58014 .3019 .57117 Mtetra
.654 .767 .933 r
.3019 .57117 .31205 .58014 .32793 .57481 .31784 .5659 Mtetra
.661 .772 .932 r
.31784 .5659 .32793 .57481 .34393 .56907 .33388 .56032 Mtetra
.675 .78 .929 r
.33388 .56032 .34393 .56907 .36005 .5626 .35005 .5542 Mtetra
.698 .795 .925 r
.35005 .5542 .36005 .5626 .37631 .55479 .36635 .54708 Mtetra
.737 .819 .915 r
.36635 .54708 .37631 .55479 .39274 .5446 .3828 .53816 Mtetra
.796 .852 .892 r
.3828 .53816 .39274 .5446 .40935 .53035 .39944 .52609 Mtetra
.868 .889 .848 r
.39944 .52609 .40935 .53035 .42616 .5098 .41627 .50888 Mtetra
.933 .915 .776 r
.41627 .50888 .42616 .5098 .44313 .48096 .43329 .48421 Mtetra
.969 .921 .694 r
.43329 .48421 .44313 .48096 .46012 .44409 .45042 .45091 Mtetra
.979 .917 .63 r
.45042 .45091 .46012 .44409 .47695 .40352 .46748 .41123 Mtetra
.976 .919 .613 r
.46748 .41123 .47695 .40352 .49349 .36591 .4843 .37115 Mtetra
.969 .933 .655 r
.4843 .37115 .49349 .36591 .50977 .33593 .50082 .33687 Mtetra
.948 .942 .745 r
.50082 .33687 .50977 .33593 .52589 .31423 .51712 .31104 Mtetra
.893 .919 .833 r
.51712 .31104 .52589 .31423 .54198 .29896 .53332 .29273 Mtetra
.819 .869 .883 r
.53332 .29273 .54198 .29896 .55811 .28785 .54954 .2797 Mtetra
.756 .82 .902 r
.54954 .2797 .55811 .28785 .57432 .27919 .56581 .2699 Mtetra
.715 .786 .908 r
.56581 .2699 .57432 .27919 .59062 .27188 .58218 .26193 Mtetra
.692 .766 .909 r
.58218 .26193 .59062 .27188 .60702 .26528 .59864 .25495 Mtetra
.678 .755 .909 r
.59864 .25495 .60702 .26528 .62352 .25905 .6152 .24849 Mtetra
.671 .748 .908 r
.6152 .24849 .62352 .25905 .64012 .253 .63187 .24229 Mtetra
.668 .745 .908 r
.63187 .24229 .64012 .253 .65682 .24703 .64864 .2362 Mtetra
.666 .743 .908 r
.64864 .2362 .65682 .24703 .67362 .24109 .66551 .23016 Mtetra
.665 .742 .908 r
.66551 .23016 .67362 .24109 .69052 .23514 .68248 .22414 Mtetra
.664 .742 .908 r
.68248 .22414 .69052 .23514 .70753 .22917 .69956 .21809 Mtetra
.69956 .21809 .70753 .22917 .72464 .22317 .71674 .21202 Mtetra
.664 .741 .908 r
.71674 .21202 .72464 .22317 .74185 .21714 .73402 .20593 Mtetra
.73402 .20593 .74185 .21714 .75917 .21108 .75141 .19979 Mtetra
.75141 .19979 .75917 .21108 .77659 .20498 .76891 .19363 Mtetra
.76891 .19363 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .60069 .19773 .59182 Mtetra
.19773 .59182 .20832 .60069 .22368 .59589 .21315 .58697 Mtetra
.646 .763 .934 r
.21315 .58697 .22368 .59589 .23913 .59106 .22865 .58209 Mtetra
.22865 .58209 .23913 .59106 .25468 .58619 .24425 .57717 Mtetra
.647 .763 .934 r
.24425 .57717 .25468 .58619 .27032 .58126 .25995 .57221 Mtetra
.648 .763 .933 r
.25995 .57221 .27032 .58126 .28606 .57627 .27574 .56718 Mtetra
.649 .764 .933 r
.27574 .56718 .28606 .57627 .3019 .57117 .29163 .56207 Mtetra
.652 .766 .933 r
.29163 .56207 .3019 .57117 .31784 .5659 .30763 .55683 Mtetra
.657 .769 .932 r
.30763 .55683 .31784 .5659 .33388 .56032 .32373 .55135 Mtetra
.667 .776 .931 r
.32373 .55135 .33388 .56032 .35005 .5542 .33994 .54547 Mtetra
.685 .787 .928 r
.33994 .54547 .35005 .5542 .36635 .54708 .35628 .53884 Mtetra
.715 .805 .921 r
.35628 .53884 .36635 .54708 .3828 .53816 .37277 .53086 Mtetra
.764 .834 .906 r
.37277 .53086 .3828 .53816 .39944 .52609 .38943 .52049 Mtetra
.831 .871 .874 r
.38943 .52049 .39944 .52609 .41627 .50888 .40628 .50603 Mtetra
.903 .904 .815 r
.40628 .50603 .41627 .50888 .43329 .48421 .42334 .48522 Mtetra
.955 .92 .734 r
.42334 .48522 .43329 .48421 .45042 .45091 .44056 .45607 Mtetra
.977 .919 .658 r
.44056 .45607 .45042 .45091 .46748 .41123 .4578 .41885 Mtetra
.978 .917 .615 r
.4578 .41885 .46748 .41123 .4843 .37115 .47489 .3779 Mtetra
.973 .925 .626 r
.47489 .3779 .4843 .37115 .50082 .33687 .49168 .33994 Mtetra
.962 .94 .696 r
.49168 .33994 .50082 .33687 .51712 .31104 .50819 .30968 Mtetra
.924 .935 .792 r
.50819 .30968 .51712 .31104 .53332 .29273 .52455 .28774 Mtetra
.856 .895 .863 r
.52455 .28774 .53332 .29273 .54954 .2797 .54086 .27225 Mtetra
.785 .843 .895 r
.54086 .27225 .54954 .2797 .56581 .2699 .55721 .26096 Mtetra
.733 .801 .906 r
.55721 .26096 .56581 .2699 .58218 .26193 .57364 .25212 Mtetra
.702 .775 .908 r
.57364 .25212 .58218 .26193 .59864 .25495 .59017 .24464 Mtetra
.684 .759 .909 r
.59017 .24464 .59864 .25495 .6152 .24849 .6068 .23788 Mtetra
.674 .751 .908 r
.6068 .23788 .6152 .24849 .63187 .24229 .62353 .23148 Mtetra
.669 .746 .908 r
.62353 .23148 .63187 .24229 .64864 .2362 .64036 .22527 Mtetra
.667 .744 .908 r
.64036 .22527 .64864 .2362 .66551 .23016 .6573 .21913 Mtetra
.665 .743 .908 r
.6573 .21913 .66551 .23016 .68248 .22414 .67435 .21302 Mtetra
.664 .742 .908 r
.67435 .21302 .68248 .22414 .69956 .21809 .69149 .2069 Mtetra
.69149 .2069 .69956 .21809 .71674 .21202 .70874 .20076 Mtetra
.70874 .20076 .71674 .21202 .73402 .20593 .7261 .19459 Mtetra
.664 .741 .908 r
.7261 .19459 .73402 .20593 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19363 .76114 .18214 Mtetra
.76114 .18214 .76891 .19363 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59182 .18703 .58286 Mtetra
.18703 .58286 .19773 .59182 .21315 .58697 .20249 .57795 Mtetra
.646 .763 .934 r
.20249 .57795 .21315 .58697 .22865 .58209 .21806 .57302 Mtetra
.21806 .57302 .22865 .58209 .24425 .57717 .23371 .56805 Mtetra
.23371 .56805 .24425 .57717 .25995 .57221 .24946 .56304 Mtetra
.647 .763 .934 r
.24946 .56304 .25995 .57221 .27574 .56718 .26531 .55798 Mtetra
.648 .764 .933 r
.26531 .55798 .27574 .56718 .29163 .56207 .28126 .55284 Mtetra
.65 .765 .933 r
.28126 .55284 .29163 .56207 .30763 .55683 .29731 .5476 Mtetra
.654 .768 .933 r
.29731 .5476 .30763 .55683 .32373 .55135 .31346 .54218 Mtetra
.661 .772 .932 r
.31346 .54218 .32373 .55135 .33994 .54547 .32973 .53646 Mtetra
.675 .78 .929 r
.32973 .53646 .33994 .54547 .35628 .53884 .34611 .53018 Mtetra
.698 .795 .925 r
.34611 .53018 .35628 .53884 .37277 .53086 .36264 .52289 Mtetra
.737 .819 .915 r
.36264 .52289 .37277 .53086 .38943 .52049 .37933 .5138 Mtetra
.796 .852 .893 r
.37933 .5138 .38943 .52049 .40628 .50603 .3962 .50154 Mtetra
.868 .889 .848 r
.3962 .50154 .40628 .50603 .42334 .48522 .41328 .48408 Mtetra
.933 .915 .776 r
.41328 .48408 .42334 .48522 .44056 .45607 .43055 .45912 Mtetra
.969 .921 .693 r
.43055 .45912 .44056 .45607 .4578 .41885 .44794 .42549 Mtetra
.979 .917 .63 r
.44794 .42549 .4578 .41885 .47489 .3779 .46526 .38544 Mtetra
.976 .919 .613 r
.46526 .38544 .47489 .3779 .49168 .33994 .48234 .34499 Mtetra
.97 .933 .655 r
.48234 .34499 .49168 .33994 .50819 .30968 .4991 .31039 Mtetra
.948 .942 .745 r
.4991 .31039 .50819 .30968 .52455 .28774 .51564 .28429 Mtetra
.893 .919 .833 r
.51564 .28429 .52455 .28774 .54086 .27225 .53207 .26575 Mtetra
.819 .869 .883 r
.53207 .26575 .54086 .27225 .55721 .26096 .54851 .25252 Mtetra
.756 .82 .902 r
.54851 .25252 .55721 .26096 .57364 .25212 .56502 .24254 Mtetra
.715 .786 .908 r
.56502 .24254 .57364 .25212 .59017 .24464 .58161 .2344 Mtetra
.692 .766 .909 r
.58161 .2344 .59017 .24464 .6068 .23788 .5983 .22725 Mtetra
.678 .755 .909 r
.5983 .22725 .6068 .23788 .62353 .23148 .6151 .22062 Mtetra
.671 .748 .908 r
.6151 .22062 .62353 .23148 .64036 .22527 .632 .21424 Mtetra
.668 .745 .908 r
.632 .21424 .64036 .22527 .6573 .21913 .64901 .20799 Mtetra
.666 .743 .908 r
.64901 .20799 .6573 .21913 .67435 .21302 .66612 .20178 Mtetra
.665 .742 .908 r
.66612 .20178 .67435 .21302 .69149 .2069 .68334 .19558 Mtetra
.664 .742 .908 r
.68334 .19558 .69149 .2069 .70874 .20076 .70066 .18936 Mtetra
.70066 .18936 .70874 .20076 .7261 .19459 .71809 .18312 Mtetra
.664 .741 .908 r
.71809 .18312 .7261 .19459 .74357 .18838 .73563 .17684 Mtetra
.73563 .17684 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57795 .19172 .56884 Mtetra
.19172 .56884 .20249 .57795 .21806 .57302 .20734 .56385 Mtetra
.646 .763 .934 r
.20734 .56385 .21806 .57302 .23371 .56805 .22305 .55882 Mtetra
.22305 .55882 .23371 .56805 .24946 .56304 .23886 .55376 Mtetra
.647 .763 .934 r
.23886 .55376 .24946 .56304 .26531 .55798 .25476 .54866 Mtetra
.648 .763 .933 r
.25476 .54866 .26531 .55798 .28126 .55284 .27076 .54349 Mtetra
.649 .764 .933 r
.27076 .54349 .28126 .55284 .29731 .5476 .28687 .53823 Mtetra
.652 .766 .933 r
.28687 .53823 .29731 .5476 .31346 .54218 .30308 .53284 Mtetra
.657 .769 .932 r
.30308 .53284 .31346 .54218 .32973 .53646 .3194 .52722 Mtetra
.667 .776 .931 r
.3194 .52722 .32973 .53646 .34611 .53018 .33584 .52118 Mtetra
.685 .787 .928 r
.33584 .52118 .34611 .53018 .36264 .52289 .35241 .51439 Mtetra
.715 .805 .921 r
.35241 .51439 .36264 .52289 .37933 .5138 .36913 .50624 Mtetra
.764 .835 .906 r
.36913 .50624 .37933 .5138 .3962 .50154 .38602 .49568 Mtetra
.832 .871 .874 r
.38602 .49568 .3962 .50154 .41328 .48408 .40312 .481 Mtetra
.903 .905 .815 r
.40312 .481 .41328 .48408 .43055 .45912 .42043 .45993 Mtetra
.955 .92 .734 r
.42043 .45993 .43055 .45912 .44794 .42549 .43791 .43046 Mtetra
.977 .919 .657 r
.43791 .43046 .44794 .42549 .46526 .38544 .45543 .39287 Mtetra
.978 .917 .615 r
.45543 .39287 .46526 .38544 .48234 .34499 .47277 .35155 Mtetra
.973 .925 .627 r
.47277 .35155 .48234 .34499 .4991 .31039 .48982 .31324 Mtetra
.962 .94 .697 r
.48982 .31324 .4991 .31039 .51564 .28429 .50657 .28268 Mtetra
.924 .935 .792 r
.50657 .28268 .51564 .28429 .53207 .26575 .52316 .26049 Mtetra
.856 .895 .863 r
.52316 .26049 .53207 .26575 .54851 .25252 .53971 .24479 Mtetra
.785 .843 .895 r
.53971 .24479 .54851 .25252 .56502 .24254 .55629 .23331 Mtetra
.733 .801 .906 r
.55629 .23331 .56502 .24254 .58161 .2344 .57295 .22429 Mtetra
.702 .775 .908 r
.57295 .22429 .58161 .2344 .5983 .22725 .58971 .21663 Mtetra
.684 .759 .909 r
.58971 .21663 .5983 .22725 .6151 .22062 .60657 .2097 Mtetra
.674 .751 .908 r
.60657 .2097 .6151 .22062 .632 .21424 .62354 .20313 Mtetra
.669 .746 .908 r
.62354 .20313 .632 .21424 .64901 .20799 .64062 .19674 Mtetra
.667 .744 .908 r
.64062 .19674 .64901 .20799 .66612 .20178 .6578 .19043 Mtetra
.665 .743 .908 r
.6578 .19043 .66612 .20178 .68334 .19558 .67509 .18414 Mtetra
.664 .742 .908 r
.67509 .18414 .68334 .19558 .70066 .18936 .69249 .17784 Mtetra
.69249 .17784 .70066 .18936 .71809 .18312 .70999 .17152 Mtetra
.70999 .17152 .71809 .18312 .73563 .17684 .72761 .16517 Mtetra
.664 .741 .908 r
.72761 .16517 .73563 .17684 .75328 .17053 .74533 .15879 Mtetra
.74533 .15879 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56462 Mtetra
.16526 .56462 .1762 .57379 .19172 .56884 .18083 .55961 Mtetra
.18083 .55961 .19172 .56884 .20734 .56385 .1965 .55457 Mtetra
.646 .763 .934 r
.1965 .55457 .20734 .56385 .22305 .55882 .21227 .54949 Mtetra
.21227 .54949 .22305 .55882 .23886 .55376 .22813 .54438 Mtetra
.22813 .54438 .23886 .55376 .25476 .54866 .24409 .53922 Mtetra
.647 .763 .934 r
.24409 .53922 .25476 .54866 .27076 .54349 .26015 .53402 Mtetra
.648 .764 .933 r
.26015 .53402 .27076 .54349 .28687 .53823 .27631 .52873 Mtetra
.65 .765 .933 r
.27631 .52873 .28687 .53823 .30308 .53284 .29258 .52334 Mtetra
.654 .768 .933 r
.29258 .52334 .30308 .53284 .3194 .52722 .30896 .51777 Mtetra
.661 .772 .932 r
.30896 .51777 .3194 .52722 .33584 .52118 .32545 .51189 Mtetra
.675 .78 .929 r
.32545 .51189 .33584 .52118 .35241 .51439 .34206 .50545 Mtetra
.698 .795 .925 r
.34206 .50545 .35241 .51439 .36913 .50624 .35882 .498 Mtetra
.737 .819 .915 r
.35882 .498 .36913 .50624 .38602 .49568 .37575 .48872 Mtetra
.796 .853 .893 r
.37575 .48872 .38602 .49568 .40312 .481 .39286 .47625 Mtetra
.868 .89 .848 r
.39286 .47625 .40312 .481 .42043 .45993 .4102 .45856 Mtetra
.933 .915 .776 r
.4102 .45856 .42043 .45993 .43791 .43046 .42773 .43331 Mtetra
.969 .921 .693 r
.42773 .43331 .43791 .43046 .45543 .39287 .44539 .39933 Mtetra
.979 .917 .63 r
.44539 .39933 .45543 .39287 .47277 .35155 .46298 .35889 Mtetra
.976 .919 .613 r
.46298 .35889 .47277 .35155 .48982 .31324 .48032 .31808 Mtetra
.97 .933 .655 r
.48032 .31808 .48982 .31324 .50657 .28268 .49734 .28315 Mtetra
.948 .942 .745 r
.49734 .28315 .50657 .28268 .52316 .26049 .51412 .25677 Mtetra
.893 .918 .833 r
.51412 .25677 .52316 .26049 .53971 .24479 .53079 .23801 Mtetra
.819 .868 .883 r
.53079 .23801 .53971 .24479 .55629 .23331 .54746 .22458 Mtetra
.756 .82 .902 r
.54746 .22458 .55629 .23331 .57295 .22429 .5642 .2144 Mtetra
.715 .786 .907 r
.5642 .2144 .57295 .22429 .58971 .21663 .58102 .20608 Mtetra
.692 .766 .909 r
.58102 .20608 .58971 .21663 .60657 .2097 .59795 .19875 Mtetra
.678 .754 .908 r
.59795 .19875 .60657 .2097 .62354 .20313 .61499 .19194 Mtetra
.671 .748 .908 r
.61499 .19194 .62354 .20313 .64062 .19674 .63214 .18539 Mtetra
.668 .745 .908 r
.63214 .18539 .64062 .19674 .6578 .19043 .64939 .17896 Mtetra
.666 .743 .908 r
.64939 .17896 .6578 .19043 .67509 .18414 .66675 .17257 Mtetra
.665 .742 .908 r
.66675 .17257 .67509 .18414 .69249 .17784 .68422 .16619 Mtetra
.664 .742 .908 r
.68422 .16619 .69249 .17784 .70999 .17152 .7018 .15979 Mtetra
.7018 .15979 .70999 .17152 .72761 .16517 .71949 .15337 Mtetra
.664 .741 .908 r
.71949 .15337 .72761 .16517 .74533 .15879 .73729 .14691 Mtetra
.73729 .14691 .74533 .15879 .76317 .15236 .7552 .14041 Mtetra
.7552 .14041 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56462 .15419 .55535 Mtetra
.15419 .55535 .16526 .56462 .18083 .55961 .16982 .55029 Mtetra
.16982 .55029 .18083 .55961 .1965 .55457 .18555 .54519 Mtetra
.18555 .54519 .1965 .55457 .21227 .54949 .20137 .54006 Mtetra
.646 .763 .934 r
.20137 .54006 .21227 .54949 .22813 .54438 .21729 .53489 Mtetra
.21729 .53489 .22813 .54438 .24409 .53922 .2333 .52968 Mtetra
.647 .763 .934 r
.2333 .52968 .24409 .53922 .26015 .53402 .24942 .52442 Mtetra
.648 .763 .933 r
.24942 .52442 .26015 .53402 .27631 .52873 .26564 .51911 Mtetra
.649 .764 .933 r
.26564 .51911 .27631 .52873 .29258 .52334 .28196 .5137 Mtetra
.652 .766 .933 r
.28196 .5137 .29258 .52334 .30896 .51777 .2984 .50815 Mtetra
.657 .769 .932 r
.2984 .50815 .30896 .51777 .32545 .51189 .31494 .50237 Mtetra
.667 .776 .931 r
.31494 .50237 .32545 .51189 .34206 .50545 .33161 .49617 Mtetra
.685 .787 .928 r
.33161 .49617 .34206 .50545 .35882 .498 .34841 .48921 Mtetra
.715 .806 .921 r
.34841 .48921 .35882 .498 .37575 .48872 .36537 .48089 Mtetra
.764 .835 .906 r
.36537 .48089 .37575 .48872 .39286 .47625 .38251 .47013 Mtetra
.832 .872 .874 r
.38251 .47013 .39286 .47625 .4102 .45856 .39986 .45523 Mtetra
.903 .905 .815 r
.39986 .45523 .4102 .45856 .42773 .43331 .41743 .43389 Mtetra
.955 .92 .734 r
.41743 .43389 .42773 .43331 .44539 .39933 .43519 .40409 Mtetra
.977 .919 .657 r
.43519 .40409 .44539 .39933 .46298 .35889 .45298 .36614 Mtetra
.978 .917 .614 r
.45298 .36614 .46298 .35889 .48032 .31808 .4706 .32443 Mtetra
.973 .925 .627 r
.4706 .32443 .48032 .31808 .49734 .28315 .4879 .28577 Mtetra
.962 .94 .697 r
.4879 .28577 .49734 .28315 .51412 .25677 .50491 .25491 Mtetra
.924 .935 .793 r
.50491 .25491 .51412 .25677 .53079 .23801 .52174 .23246 Mtetra
.856 .895 .863 r
.52174 .23246 .53079 .23801 .54746 .22458 .53852 .21655 Mtetra
.785 .843 .895 r
.53852 .21655 .54746 .22458 .5642 .2144 .55534 .20486 Mtetra
.733 .801 .906 r
.55534 .20486 .5642 .2144 .58102 .20608 .57224 .19565 Mtetra
.702 .775 .908 r
.57224 .19565 .58102 .20608 .59795 .19875 .58924 .18781 Mtetra
.684 .759 .909 r
.58924 .18781 .59795 .19875 .61499 .19194 .60634 .1807 Mtetra
.674 .751 .908 r
.60634 .1807 .61499 .19194 .63214 .18539 .62356 .17395 Mtetra
.669 .746 .908 r
.62356 .17395 .63214 .18539 .64939 .17896 .64088 .16738 Mtetra
.667 .744 .908 r
.64088 .16738 .64939 .17896 .66675 .17257 .65831 .16089 Mtetra
.665 .743 .908 r
.65831 .16089 .66675 .17257 .68422 .16619 .67586 .15441 Mtetra
.664 .742 .908 r
.67586 .15441 .68422 .16619 .7018 .15979 .69351 .14793 Mtetra
.69351 .14793 .7018 .15979 .71949 .15337 .71128 .14143 Mtetra
.71128 .14143 .71949 .15337 .73729 .14691 .72916 .13489 Mtetra
.664 .741 .908 r
.72916 .13489 .73729 .14691 .7552 .14041 .74715 .12831 Mtetra
.74715 .12831 .7552 .14041 .77323 .13387 .76525 .1217 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54085 Mtetra
.15868 .54085 .16982 .55029 .18555 .54519 .17446 .5357 Mtetra
.17446 .5357 .18555 .54519 .20137 .54006 .19034 .53051 Mtetra
.646 .763 .934 r
.19034 .53051 .20137 .54006 .21729 .53489 .20631 .52528 Mtetra
.20631 .52528 .21729 .53489 .2333 .52968 .22239 .52002 Mtetra
.22239 .52002 .2333 .52968 .24942 .52442 .23857 .51471 Mtetra
.647 .763 .934 r
.23857 .51471 .24942 .52442 .26564 .51911 .25484 .50935 Mtetra
.648 .764 .933 r
.25484 .50935 .26564 .51911 .28196 .5137 .27123 .50392 Mtetra
.65 .765 .933 r
.27123 .50392 .28196 .5137 .2984 .50815 .28772 .49837 Mtetra
.654 .768 .933 r
.28772 .49837 .2984 .50815 .31494 .50237 .30432 .49264 Mtetra
.661 .772 .932 r
.30432 .49264 .31494 .50237 .33161 .49617 .32104 .4866 Mtetra
.675 .78 .929 r
.32104 .4866 .33161 .49617 .34841 .48921 .33789 .47999 Mtetra
.698 .795 .925 r
.33789 .47999 .34841 .48921 .36537 .48089 .35489 .47236 Mtetra
.737 .819 .915 r
.35489 .47236 .36537 .48089 .38251 .47013 .37206 .4629 Mtetra
.796 .853 .893 r
.37206 .4629 .38251 .47013 .39986 .45523 .38943 .45021 Mtetra
.868 .89 .848 r
.38943 .45021 .39986 .45523 .41743 .43389 .40702 .43227 Mtetra
.933 .915 .776 r
.40702 .43227 .41743 .43389 .43519 .40409 .42483 .40672 Mtetra
.969 .921 .693 r
.42483 .40672 .43519 .40409 .45298 .36614 .44277 .37239 Mtetra
.979 .917 .63 r
.44277 .37239 .45298 .36614 .4706 .32443 .46064 .33157 Mtetra
.976 .919 .613 r
.46064 .33157 .4706 .32443 .4879 .28577 .47825 .29038 Mtetra
.97 .933 .656 r
.47825 .29038 .4879 .28577 .50491 .25491 .49552 .25512 Mtetra
.948 .942 .745 r
.49552 .25512 .50491 .25491 .52174 .23246 .51255 .22847 Mtetra
.892 .918 .833 r
.51255 .22847 .52174 .23246 .53852 .21655 .52946 .20946 Mtetra
.819 .868 .883 r
.52946 .20946 .53852 .21655 .55534 .20486 .54638 .19582 Mtetra
.756 .82 .902 r
.54638 .19582 .55534 .20486 .57224 .19565 .56335 .18545 Mtetra
.715 .786 .907 r
.56335 .18545 .57224 .19565 .58924 .18781 .58042 .17694 Mtetra
.692 .766 .908 r
.58042 .17694 .58924 .18781 .60634 .1807 .5976 .16942 Mtetra
.678 .754 .908 r
.5976 .16942 .60634 .1807 .62356 .17395 .61488 .16243 Mtetra
.671 .748 .908 r
.61488 .16243 .62356 .17395 .64088 .16738 .63228 .1557 Mtetra
.668 .745 .908 r
.63228 .1557 .64088 .16738 .65831 .16089 .64978 .14908 Mtetra
.666 .743 .908 r
.64978 .14908 .65831 .16089 .67586 .15441 .6674 .14251 Mtetra
.665 .742 .908 r
.6674 .14251 .67586 .15441 .69351 .14793 .68513 .13594 Mtetra
.664 .742 .908 r
.68513 .13594 .69351 .14793 .71128 .14143 .70297 .12935 Mtetra
.70297 .12935 .71128 .14143 .72916 .13489 .72093 .12273 Mtetra
.664 .741 .908 r
.72093 .12273 .72916 .13489 .74715 .12831 .739 .11608 Mtetra
.739 .11608 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54085 .14742 .53131 Mtetra
.14742 .53131 .15868 .54085 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53051 .17919 .52085 Mtetra
.17919 .52085 .19034 .53051 .20631 .52528 .19522 .51557 Mtetra
.646 .763 .934 r
.19522 .51557 .20631 .52528 .22239 .52002 .21135 .51025 Mtetra
.21135 .51025 .22239 .52002 .23857 .51471 .22759 .50489 Mtetra
.647 .763 .934 r
.22759 .50489 .23857 .51471 .25484 .50935 .24392 .49948 Mtetra
.648 .763 .934 r
.24392 .49948 .25484 .50935 .27123 .50392 .26037 .494 Mtetra
.649 .764 .933 r
.26037 .494 .27123 .50392 .28772 .49837 .27692 .48844 Mtetra
.652 .766 .933 r
.27692 .48844 .28772 .49837 .30432 .49264 .29358 .48273 Mtetra
.657 .769 .932 r
.29358 .48273 .30432 .49264 .32104 .4866 .31035 .47678 Mtetra
.667 .776 .931 r
.31035 .47678 .32104 .4866 .33789 .47999 .32726 .47042 Mtetra
.685 .787 .928 r
.32726 .47042 .33789 .47999 .35489 .47236 .3443 .46329 Mtetra
.715 .806 .921 r
.3443 .46329 .35489 .47236 .37206 .4629 .3615 .45478 Mtetra
.764 .835 .906 r
.3615 .45478 .37206 .4629 .38943 .45021 .3789 .44381 Mtetra
.832 .872 .874 r
.3789 .44381 .38943 .45021 .40702 .43227 .39651 .42867 Mtetra
.903 .905 .815 r
.39651 .42867 .40702 .43227 .42483 .40672 .41435 .40706 Mtetra
.955 .92 .734 r
.41435 .40706 .42483 .40672 .44277 .37239 .43238 .37693 Mtetra
.977 .919 .657 r
.43238 .37693 .44277 .37239 .46064 .33157 .45045 .33861 Mtetra
.978 .917 .614 r
.45045 .33861 .46064 .33157 .47825 .29038 .46836 .29651 Mtetra
.974 .925 .627 r
.46836 .29651 .47825 .29038 .49552 .25512 .48593 .2575 Mtetra
.962 .94 .697 r
.48593 .2575 .49552 .25512 .51255 .22847 .5032 .22633 Mtetra
.924 .935 .793 r
.5032 .22633 .51255 .22847 .52946 .20946 .52028 .20362 Mtetra
.856 .895 .863 r
.52028 .20362 .52946 .20946 .54638 .19582 .5373 .18748 Mtetra
.785 .842 .895 r
.5373 .18748 .54638 .19582 .56335 .18545 .55436 .17559 Mtetra
.733 .801 .906 r
.55436 .17559 .56335 .18545 .58042 .17694 .57151 .16618 Mtetra
.702 .775 .908 r
.57151 .16618 .58042 .17694 .5976 .16942 .58875 .15815 Mtetra
.684 .759 .909 r
.58875 .15815 .5976 .16942 .61488 .16243 .6061 .15085 Mtetra
.674 .751 .908 r
.6061 .15085 .61488 .16243 .63228 .1557 .62357 .14392 Mtetra
.669 .746 .908 r
.62357 .14392 .63228 .1557 .64978 .14908 .64115 .13716 Mtetra
.667 .744 .908 r
.64115 .13716 .64978 .14908 .6674 .14251 .65884 .13047 Mtetra
.665 .743 .908 r
.65884 .13047 .6674 .14251 .68513 .13594 .67665 .12381 Mtetra
.664 .742 .908 r
.67665 .12381 .68513 .13594 .70297 .12935 .69457 .11713 Mtetra
.69457 .11713 .70297 .12935 .72093 .12273 .7126 .11043 Mtetra
.7126 .11043 .72093 .12273 .739 .11608 .73075 .1037 Mtetra
.664 .741 .908 r
.73075 .1037 .739 .11608 .75719 .10938 .74902 .09692 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53211 Mtetra
.10454 .53211 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53131 .13603 .52167 Mtetra
.13603 .52167 .14742 .53131 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52085 .16791 .51108 Mtetra
.16791 .51108 .17919 .52085 .19522 .51557 .18399 .50574 Mtetra
.646 .763 .934 r
.18399 .50574 .19522 .51557 .21135 .51025 .20019 .50036 Mtetra
.20019 .50036 .21135 .51025 .22759 .50489 .21648 .49494 Mtetra
.21648 .49494 .22759 .50489 .24392 .49948 .23288 .48948 Mtetra
.647 .763 .934 r
.23288 .48948 .24392 .49948 .26037 .494 .24938 .48396 Mtetra
.648 .764 .933 r
.24938 .48396 .26037 .494 .27692 .48844 .26599 .47836 Mtetra
.65 .765 .933 r
.26599 .47836 .27692 .48844 .29358 .48273 .28271 .47265 Mtetra
.654 .768 .933 r
.28271 .47265 .29358 .48273 .31035 .47678 .29955 .46676 Mtetra
.661 .772 .932 r
.29955 .46676 .31035 .47678 .32726 .47042 .3165 .46054 Mtetra
.675 .78 .929 r
.3165 .46054 .32726 .47042 .3443 .46329 .3336 .45376 Mtetra
.698 .795 .925 r
.3336 .45376 .3443 .46329 .3615 .45478 .35084 .44595 Mtetra
.737 .819 .915 r
.35084 .44595 .3615 .45478 .3789 .44381 .36826 .43629 Mtetra
.796 .853 .893 r
.36826 .43629 .3789 .44381 .39651 .42867 .38589 .42338 Mtetra
.868 .89 .848 r
.38589 .42338 .39651 .42867 .41435 .40706 .40375 .40518 Mtetra
.933 .915 .776 r
.40375 .40518 .41435 .40706 .43238 .37693 .42184 .37933 Mtetra
.969 .921 .693 r
.42184 .37933 .43238 .37693 .45045 .33861 .44006 .34464 Mtetra
.979 .917 .63 r
.44006 .34464 .45045 .33861 .46836 .29651 .45822 .30343 Mtetra
.976 .919 .613 r
.45822 .30343 .46836 .29651 .48593 .2575 .47611 .26186 Mtetra
.97 .933 .656 r
.47611 .26186 .48593 .2575 .5032 .22633 .49366 .22627 Mtetra
.948 .941 .745 r
.49366 .22627 .5032 .22633 .52028 .20362 .51094 .19933 Mtetra
.892 .918 .833 r
.51094 .19933 .52028 .20362 .5373 .18748 .5281 .18008 Mtetra
.819 .868 .883 r
.5281 .18008 .5373 .18748 .55436 .17559 .54526 .16622 Mtetra
.756 .82 .902 r
.54526 .16622 .55436 .17559 .57151 .16618 .56248 .15565 Mtetra
.715 .786 .907 r
.56248 .15565 .57151 .16618 .58875 .15815 .5798 .14694 Mtetra
.692 .766 .908 r
.5798 .14694 .58875 .15815 .6061 .15085 .59723 .13923 Mtetra
.678 .754 .908 r
.59723 .13923 .6061 .15085 .62357 .14392 .61477 .13205 Mtetra
.671 .748 .908 r
.61477 .13205 .62357 .14392 .64115 .13716 .63242 .12512 Mtetra
.668 .745 .908 r
.63242 .12512 .64115 .13716 .65884 .13047 .65019 .11831 Mtetra
.666 .743 .908 r
.65019 .11831 .65884 .13047 .67665 .12381 .66807 .11155 Mtetra
.665 .742 .908 r
.66807 .11155 .67665 .12381 .69457 .11713 .68607 .10478 Mtetra
.664 .742 .908 r
.68607 .10478 .69457 .11713 .7126 .11043 .70418 .09799 Mtetra
.70418 .09799 .7126 .11043 .73075 .1037 .72241 .09117 Mtetra
.664 .741 .908 r
.72241 .09117 .73075 .1037 .74902 .09692 .74076 .08432 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53211 .09291 .52247 Mtetra
.09291 .52247 .10454 .53211 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .16791 .51108 .15649 .5012 Mtetra
.15649 .5012 .16791 .51108 .18399 .50574 .17264 .4958 Mtetra
.17264 .4958 .18399 .50574 .20019 .50036 .18889 .49036 Mtetra
.646 .763 .934 r
.18889 .49036 .20019 .50036 .21648 .49494 .20524 .48488 Mtetra
.20524 .48488 .21648 .49494 .23288 .48948 .2217 .47936 Mtetra
.647 .763 .934 r
.2217 .47936 .23288 .48948 .24938 .48396 .23826 .47378 Mtetra
.648 .763 .934 r
.23826 .47378 .24938 .48396 .26599 .47836 .25493 .46815 Mtetra
.649 .764 .933 r
.25493 .46815 .26599 .47836 .28271 .47265 .27171 .46242 Mtetra
.652 .766 .933 r
.27171 .46242 .28271 .47265 .29955 .46676 .28861 .45654 Mtetra
.657 .769 .932 r
.28861 .45654 .29955 .46676 .3165 .46054 .30563 .45042 Mtetra
.667 .776 .931 r
.30563 .45042 .3165 .46054 .3336 .45376 .32277 .44388 Mtetra
.685 .787 .928 r
.32277 .44388 .3336 .45376 .35084 .44595 .34006 .43657 Mtetra
.715 .806 .921 r
.34006 .43657 .35084 .44595 .36826 .43629 .35752 .42786 Mtetra
.764 .835 .906 r
.35752 .42786 .36826 .43629 .38589 .42338 .37517 .41669 Mtetra
.832 .872 .874 r
.37517 .41669 .38589 .42338 .40375 .40518 .39305 .40131 Mtetra
.903 .905 .815 r
.39305 .40131 .40375 .40518 .42184 .37933 .41117 .37941 Mtetra
.955 .921 .734 r
.41117 .37941 .42184 .37933 .44006 .34464 .42949 .34895 Mtetra
.977 .919 .657 r
.42949 .34895 .44006 .34464 .45822 .30343 .44786 .31024 Mtetra
.978 .917 .614 r
.44786 .31024 .45822 .30343 .47611 .26186 .46605 .26776 Mtetra
.974 .925 .627 r
.46605 .26776 .47611 .26186 .49366 .22627 .4839 .22838 Mtetra
.962 .94 .697 r
.4839 .22838 .49366 .22627 .51094 .19933 .50143 .1969 Mtetra
.924 .934 .793 r
.50143 .1969 .51094 .19933 .5281 .18008 .51877 .17393 Mtetra
.856 .894 .863 r
.51877 .17393 .5281 .18008 .54526 .16622 .53604 .15755 Mtetra
.785 .842 .895 r
.53604 .15755 .54526 .16622 .56248 .15565 .55336 .14545 Mtetra
.733 .801 .906 r
.55336 .14545 .56248 .15565 .5798 .14694 .57075 .13584 Mtetra
.702 .775 .908 r
.57075 .13584 .5798 .14694 .59723 .13923 .58825 .12762 Mtetra
.684 .759 .909 r
.58825 .12762 .59723 .13923 .61477 .13205 .60586 .12012 Mtetra
.674 .751 .908 r
.60586 .12012 .61477 .13205 .63242 .12512 .62359 .11299 Mtetra
.669 .746 .908 r
.62359 .11299 .63242 .12512 .65019 .11831 .64143 .10603 Mtetra
.667 .744 .908 r
.64143 .10603 .65019 .11831 .66807 .11155 .65939 .09915 Mtetra
.665 .743 .908 r
.65939 .09915 .66807 .11155 .68607 .10478 .67746 .09228 Mtetra
.664 .742 .908 r
.67746 .09228 .68607 .10478 .70418 .09799 .69566 .08541 Mtetra
.69566 .08541 .70418 .09799 .72241 .09117 .71397 .0785 Mtetra
.71397 .0785 .72241 .09117 .74076 .08432 .7324 .07156 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .4912 Mtetra
.14495 .4912 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49036 .17746 .48024 Mtetra
.646 .763 .934 r
.17746 .48024 .18889 .49036 .20524 .48488 .19387 .47469 Mtetra
.19387 .47469 .20524 .48488 .2217 .47936 .21039 .46911 Mtetra
.21039 .46911 .2217 .47936 .23826 .47378 .22701 .46348 Mtetra
.647 .763 .934 r
.22701 .46348 .23826 .47378 .25493 .46815 .24375 .4578 Mtetra
.648 .764 .933 r
.24375 .4578 .25493 .46815 .27171 .46242 .26059 .45203 Mtetra
.65 .765 .933 r
.26059 .45203 .27171 .46242 .28861 .45654 .27755 .44615 Mtetra
.654 .768 .933 r
.27755 .44615 .28861 .45654 .30563 .45042 .29462 .44008 Mtetra
.661 .772 .932 r
.29462 .44008 .30563 .45042 .32277 .44388 .31183 .43369 Mtetra
.675 .78 .929 r
.31183 .43369 .32277 .44388 .34006 .43657 .32917 .42673 Mtetra
.698 .795 .925 r
.32917 .42673 .34006 .43657 .35752 .42786 .34667 .41873 Mtetra
.737 .819 .915 r
.34667 .41873 .35752 .42786 .37517 .41669 .36435 .40886 Mtetra
.796 .853 .893 r
.36435 .40886 .37517 .41669 .39305 .40131 .38224 .39573 Mtetra
.868 .89 .848 r
.38224 .39573 .39305 .40131 .41117 .37941 .40038 .37726 Mtetra
.933 .916 .776 r
.40038 .37726 .41117 .37941 .42949 .34895 .41876 .35109 Mtetra
.97 .921 .693 r
.41876 .35109 .42949 .34895 .44786 .31024 .43728 .31604 Mtetra
.979 .917 .63 r
.43728 .31604 .44786 .31024 .46605 .26776 .45573 .27444 Mtetra
.976 .919 .613 r
.45573 .27444 .46605 .26776 .4839 .22838 .47391 .23249 Mtetra
.97 .933 .656 r
.47391 .23249 .4839 .22838 .50143 .1969 .49173 .19656 Mtetra
.948 .941 .745 r
.49173 .19656 .50143 .1969 .51877 .17393 .50928 .16933 Mtetra
.892 .918 .833 r
.50928 .16933 .51877 .17393 .53604 .15755 .5267 .14983 Mtetra
.819 .868 .883 r
.5267 .14983 .53604 .15755 .55336 .14545 .54411 .13574 Mtetra
.756 .82 .902 r
.54411 .13574 .55336 .14545 .57075 .13584 .56159 .12496 Mtetra
.715 .786 .907 r
.56159 .12496 .57075 .13584 .58825 .12762 .57916 .11605 Mtetra
.692 .766 .908 r
.57916 .11605 .58825 .12762 .60586 .12012 .59685 .10814 Mtetra
.678 .754 .908 r
.59685 .10814 .60586 .12012 .62359 .11299 .61465 .10076 Mtetra
.671 .748 .908 r
.61465 .10076 .62359 .11299 .64143 .10603 .63257 .09363 Mtetra
.668 .745 .908 r
.63257 .09363 .64143 .10603 .65939 .09915 .6506 .08662 Mtetra
.666 .743 .908 r
.6506 .08662 .65939 .09915 .67746 .09228 .66876 .07965 Mtetra
.665 .742 .908 r
.66876 .07965 .67746 .09228 .69566 .08541 .68703 .07267 Mtetra
.664 .742 .908 r
.68703 .07267 .69566 .08541 .71397 .0785 .70542 .06568 Mtetra
.70542 .06568 .71397 .0785 .7324 .07156 .72394 .05865 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .4912 .13327 .48109 Mtetra
.13327 .48109 .14495 .4912 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .46999 Mtetra
.1659 .46999 .17746 .48024 .19387 .47469 .18237 .46439 Mtetra
.646 .763 .934 r
.18237 .46439 .19387 .47469 .21039 .46911 .19895 .45874 Mtetra
.19895 .45874 .21039 .46911 .22701 .46348 .21563 .45305 Mtetra
.647 .763 .934 r
.21563 .45305 .22701 .46348 .24375 .4578 .23243 .44731 Mtetra
.648 .763 .934 r
.23243 .44731 .24375 .4578 .26059 .45203 .24933 .4415 Mtetra
.649 .764 .933 r
.24933 .4415 .26059 .45203 .27755 .44615 .26635 .4356 Mtetra
.652 .766 .933 r
.26635 .4356 .27755 .44615 .29462 .44008 .28349 .42955 Mtetra
.657 .769 .932 r
.28349 .42955 .29462 .44008 .31183 .43369 .30075 .42325 Mtetra
.667 .776 .931 r
.30075 .42325 .31183 .43369 .32917 .42673 .31815 .41652 Mtetra
.685 .787 .928 r
.31815 .41652 .32917 .42673 .34667 .41873 .3357 .40902 Mtetra
.715 .806 .921 r
.3357 .40902 .34667 .41873 .36435 .40886 .35341 .40012 Mtetra
.764 .835 .906 r
.35341 .40012 .36435 .40886 .38224 .39573 .37133 .38872 Mtetra
.832 .872 .874 r
.37133 .38872 .38224 .39573 .40038 .37726 .38948 .3731 Mtetra
.903 .905 .815 r
.38948 .3731 .40038 .37726 .41876 .35109 .40789 .35091 Mtetra
.955 .921 .734 r
.40789 .35091 .41876 .35109 .43728 .31604 .42651 .3201 Mtetra
.977 .919 .657 r
.42651 .3201 .43728 .31604 .45573 .27444 .44518 .28101 Mtetra
.978 .917 .614 r
.44518 .28101 .45573 .27444 .47391 .23249 .46367 .23813 Mtetra
.974 .925 .627 r
.46367 .23813 .47391 .23249 .49173 .19656 .48181 .19839 Mtetra
.962 .94 .698 r
.48181 .19839 .49173 .19656 .50928 .16933 .49962 .16659 Mtetra
.924 .934 .793 r
.49962 .16659 .50928 .16933 .5267 .14983 .51721 .14335 Mtetra
.856 .894 .863 r
.51721 .14335 .5267 .14983 .54411 .13574 .53475 .12673 Mtetra
.785 .842 .895 r
.53475 .12673 .54411 .13574 .56159 .12496 .55232 .11441 Mtetra
.733 .801 .906 r
.55232 .11441 .56159 .12496 .57916 .11605 .56997 .10459 Mtetra
.702 .774 .908 r
.56997 .10459 .57916 .11605 .59685 .10814 .58773 .09616 Mtetra
.684 .759 .909 r
.58773 .09616 .59685 .10814 .61465 .10076 .60561 .08845 Mtetra
.674 .751 .908 r
.60561 .08845 .61465 .10076 .63257 .09363 .6236 .08112 Mtetra
.669 .746 .908 r
.6236 .08112 .63257 .09363 .6506 .08662 .64172 .07396 Mtetra
.667 .744 .908 r
.64172 .07396 .6506 .08662 .66876 .07965 .65995 .06687 Mtetra
.665 .743 .908 r
.65995 .06687 .66876 .07965 .68703 .07267 .6783 .05979 Mtetra
.664 .742 .908 r
.6783 .05979 .68703 .07267 .70542 .06568 .69678 .0527 Mtetra
.69678 .0527 .70542 .06568 .72394 .05865 .71538 .04559 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47641 Mtetra
.10523 .47641 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .46999 .1542 .45963 Mtetra
.1542 .45963 .1659 .46999 .18237 .46439 .17073 .45396 Mtetra
.646 .763 .934 r
.17073 .45396 .18237 .46439 .19895 .45874 .18737 .44825 Mtetra
.18737 .44825 .19895 .45874 .21563 .45305 .20412 .4425 Mtetra
.20412 .4425 .21563 .45305 .23243 .44731 .22097 .43669 Mtetra
.647 .763 .934 r
.22097 .43669 .23243 .44731 .24933 .4415 .23794 .43083 Mtetra
.648 .764 .933 r
.23794 .43083 .24933 .4415 .26635 .4356 .25503 .42489 Mtetra
.65 .765 .933 r
.25503 .42489 .26635 .4356 .28349 .42955 .27223 .41883 Mtetra
.654 .768 .933 r
.27223 .41883 .28349 .42955 .30075 .42325 .28955 .41258 Mtetra
.661 .772 .932 r
.28955 .41258 .30075 .42325 .31815 .41652 .30701 .40601 Mtetra
.675 .78 .929 r
.30701 .40601 .31815 .41652 .3357 .40902 .3246 .39886 Mtetra
.698 .795 .925 r
.3246 .39886 .3357 .40902 .35341 .40012 .34236 .39065 Mtetra
.737 .819 .915 r
.34236 .39065 .35341 .40012 .37133 .38872 .36031 .38057 Mtetra
.796 .853 .893 r
.36031 .38057 .37133 .38872 .38948 .3731 .37848 .3672 Mtetra
.869 .89 .848 r
.37848 .3672 .38948 .3731 .40789 .35091 .39691 .34847 Mtetra
.933 .916 .776 r
.39691 .34847 .40789 .35091 .42651 .3201 .41558 .32198 Mtetra
.97 .921 .692 r
.41558 .32198 .42651 .3201 .44518 .28101 .4344 .28656 Mtetra
.979 .917 .629 r
.4344 .28656 .44518 .28101 .46367 .23813 .45317 .24456 Mtetra
.976 .919 .613 r
.45317 .24456 .46367 .23813 .48181 .19839 .47165 .20222 Mtetra
.97 .933 .656 r
.47165 .20222 .48181 .19839 .49962 .16659 .48975 .16595 Mtetra
.948 .941 .746 r
.48975 .16595 .49962 .16659 .51721 .14335 .50757 .13842 Mtetra
.892 .918 .833 r
.50757 .13842 .51721 .14335 .53475 .12673 .52525 .11867 Mtetra
.819 .868 .883 r
.52525 .11867 .53475 .12673 .55232 .11441 .54293 .10435 Mtetra
.756 .819 .902 r
.54293 .10435 .55232 .11441 .56997 .10459 .56067 .09335 Mtetra
.715 .786 .907 r
.56067 .09335 .56997 .10459 .58773 .09616 .57851 .08422 Mtetra
.692 .766 .908 r
.57851 .08422 .58773 .09616 .60561 .08845 .59646 .0761 Mtetra
.678 .754 .908 r
.59646 .0761 .60561 .08845 .6236 .08112 .61453 .06851 Mtetra
.671 .748 .908 r
.61453 .06851 .6236 .08112 .64172 .07396 .63272 .06117 Mtetra
.668 .745 .908 r
.63272 .06117 .64172 .07396 .65995 .06687 .65103 .05395 Mtetra
.666 .743 .908 r
.65103 .05395 .65995 .06687 .6783 .05979 .66947 .04676 Mtetra
.665 .742 .908 r
.66947 .04676 .6783 .05979 .69678 .0527 .68803 .03958 Mtetra
.664 .742 .908 r
.68803 .03958 .69678 .0527 .71538 .04559 .70671 .03236 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47641 .09322 .46613 Mtetra
.09322 .46613 .10523 .47641 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45396 .15895 .4434 Mtetra
.15895 .4434 .17073 .45396 .18737 .44825 .17565 .43763 Mtetra
.646 .763 .934 r
.17565 .43763 .18737 .44825 .20412 .4425 .19246 .43181 Mtetra
.19246 .43181 .20412 .4425 .22097 .43669 .20938 .42594 Mtetra
.647 .763 .934 r
.20938 .42594 .22097 .43669 .23794 .43083 .22641 .42002 Mtetra
.648 .763 .934 r
.22641 .42002 .23794 .43083 .25503 .42489 .24356 .41404 Mtetra
.649 .764 .933 r
.24356 .41404 .25503 .42489 .27223 .41883 .26083 .40795 Mtetra
.652 .766 .933 r
.26083 .40795 .27223 .41883 .28955 .41258 .27821 .40171 Mtetra
.657 .769 .932 r
.27821 .40171 .28955 .41258 .30701 .40601 .29573 .39523 Mtetra
.667 .776 .931 r
.29573 .39523 .30701 .40601 .3246 .39886 .31338 .38831 Mtetra
.685 .787 .928 r
.31338 .38831 .3246 .39886 .34236 .39065 .33119 .38061 Mtetra
.715 .806 .921 r
.33119 .38061 .34236 .39065 .36031 .38057 .34917 .3715 Mtetra
.764 .835 .906 r
.34917 .3715 .36031 .38057 .37848 .3672 .36737 .35988 Mtetra
.832 .872 .874 r
.36737 .35988 .37848 .3672 .39691 .34847 .38581 .34399 Mtetra
.903 .906 .815 r
.38581 .34399 .39691 .34847 .41558 .32198 .40451 .32151 Mtetra
.955 .921 .733 r
.40451 .32151 .41558 .32198 .4344 .28656 .42344 .29035 Mtetra
.977 .919 .656 r
.42344 .29035 .4344 .28656 .45317 .24456 .44242 .25087 Mtetra
.978 .917 .614 r
.44242 .25087 .45317 .24456 .47165 .20222 .46122 .20759 Mtetra
.974 .925 .628 r
.46122 .20759 .47165 .20222 .48975 .16595 .47966 .16748 Mtetra
.962 .939 .698 r
.47966 .16748 .48975 .16595 .50757 .13842 .49774 .13536 Mtetra
.924 .934 .793 r
.49774 .13536 .50757 .13842 .52525 .11867 .51561 .11184 Mtetra
.856 .894 .863 r
.51561 .11184 .52525 .11867 .54293 .10435 .53342 .09498 Mtetra
.785 .842 .895 r
.53342 .09498 .54293 .10435 .56067 .09335 .55125 .08243 Mtetra
.733 .801 .906 r
.55125 .08243 .56067 .09335 .57851 .08422 .56917 .07239 Mtetra
.702 .774 .908 r
.56917 .07239 .57851 .08422 .59646 .0761 .5872 .06374 Mtetra
.684 .759 .908 r
.5872 .06374 .59646 .0761 .61453 .06851 .60535 .05582 Mtetra
.674 .751 .908 r
.60535 .05582 .61453 .06851 .63272 .06117 .62362 .04827 Mtetra
.669 .746 .908 r
.62362 .04827 .63272 .06117 .65103 .05395 .64201 .04089 Mtetra
.667 .744 .908 r
.64201 .04089 .65103 .05395 .66947 .04676 .66053 .03359 Mtetra
.665 .743 .908 r
.66053 .03359 .66947 .04676 .68803 .03958 .67917 .02629 Mtetra
.664 .742 .908 r
.67917 .02629 .68803 .03958 .70671 .03236 .69793 .01898 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43852 Mtetra
.13038 .43852 .14236 .44914 .15895 .4434 .14703 .43272 Mtetra
.14703 .43272 .15895 .4434 .17565 .43763 .16379 .42687 Mtetra
.646 .763 .934 r
.16379 .42687 .17565 .43763 .19246 .43181 .18066 .42099 Mtetra
.18066 .42099 .19246 .43181 .20938 .42594 .19765 .41506 Mtetra
.19765 .41506 .20938 .42594 .22641 .42002 .21475 .40907 Mtetra
.647 .763 .934 r
.21475 .40907 .22641 .42002 .24356 .41404 .23196 .40303 Mtetra
.648 .764 .933 r
.23196 .40303 .24356 .41404 .26083 .40795 .24929 .39691 Mtetra
.65 .765 .933 r
.24929 .39691 .26083 .40795 .27821 .40171 .26674 .39066 Mtetra
.654 .768 .933 r
.26674 .39066 .27821 .40171 .29573 .39523 .28432 .38422 Mtetra
.661 .772 .932 r
.28432 .38422 .29573 .39523 .31338 .38831 .30203 .37745 Mtetra
.675 .78 .929 r
.30203 .37745 .31338 .38831 .33119 .38061 .31989 .3701 Mtetra
.698 .795 .925 r
.31989 .3701 .33119 .38061 .34917 .3715 .33792 .36169 Mtetra
.737 .819 .915 r
.33792 .36169 .34917 .3715 .36737 .35988 .35614 .35139 Mtetra
.796 .853 .893 r
.35614 .35139 .36737 .35988 .38581 .34399 .3746 .33777 Mtetra
.869 .891 .848 r
.3746 .33777 .38581 .34399 .40451 .32151 .39332 .31876 Mtetra
.933 .916 .776 r
.39332 .31876 .40451 .32151 .42344 .29035 .4123 .29194 Mtetra
.97 .922 .692 r
.4123 .29194 .42344 .29035 .44242 .25087 .43144 .25615 Mtetra
.979 .917 .629 r
.43144 .25615 .44242 .25087 .46122 .20759 .45052 .21375 Mtetra
.976 .919 .613 r
.45052 .21375 .46122 .20759 .47966 .16748 .46931 .17102 Mtetra
.97 .933 .657 r
.46931 .17102 .47966 .16748 .49774 .13536 .48771 .13439 Mtetra
.948 .941 .746 r
.48771 .13439 .49774 .13536 .51561 .11184 .50581 .10657 Mtetra
.892 .917 .833 r
.50581 .10657 .51561 .11184 .53342 .09498 .52377 .08655 Mtetra
.819 .868 .883 r
.52377 .08655 .53342 .09498 .55125 .08243 .54171 .07199 Mtetra
.756 .819 .902 r
.54171 .07199 .55125 .08243 .56917 .07239 .55972 .06076 Mtetra
.715 .786 .907 r
.55972 .06076 .56917 .07239 .5872 .06374 .57783 .05141 Mtetra
.692 .766 .908 r
.57783 .05141 .5872 .06374 .60535 .05582 .59606 .04308 Mtetra
.678 .754 .908 r
.59606 .04308 .60535 .05582 .62362 .04827 .6144 .03527 Mtetra
.671 .748 .908 r
.6144 .03527 .62362 .04827 .64201 .04089 .63288 .02771 Mtetra
.668 .745 .908 r
.63288 .02771 .64201 .04089 .66053 .03359 .65148 .02026 Mtetra
.666 .743 .908 r
.65148 .02026 .66053 .03359 .67917 .02629 .6702 .01285 Mtetra
.665 .742 .908 r
.6702 .01285 .67917 .02629 .69793 .01898 .68905 .00544 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooeKlD]`0
07oo0000Egoo003EOol30003Ool00e;lD]aBo002D_`01000D_aoo`00EWoo003BOol30004Ool02e;L
E_aBg5KlD]aFo5;L001Bg5Kl0000EWoo003@Ool20003Ool9D_`01e;LD_`005;lD]aBo00005Eoo`00
cGoo0`000goo01=Bg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aBo5;LOol0001DOol00<]oo`80
00=oo`=Bo003E_aBo5;l00YBo006001Bo5;lD_aBg000E7oo0038Ool3000077oo001ooeKlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aoo`00Dgoo001WOol20002Ool2001I
Ool20003Ool00e;l001Fo003D_`01EKlD_aBo5;lE_`02e;l00<005;LD_`00U;l00=oo`00Ool0DGoo
001XOol01000Oomoo`00Egoo0`000goo01mBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_`005;lD]aFo5;LOol0001BOol006Uoo`8005Ioo`80009oo`=Fo004D_aFo5Kl
E_`3D_`00eKlD_aBo00>D_`01E;L001Bo5;lD]`00U;l00=oo`00Ool0D7oo001YOol2001COol30003
Ool08eLLE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_`005KlD]aBo5;LE_`00Woo00<007ooOol0CWoo001XOol01000Oomoo`00D7oo0P0017oo00AFo5LL
E_aG70AFo004D_aFo5KlE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo000D]`00e;l00ABg5;lOol0051o
o`00Igoo0P000Woo0P00C7oo0`0017oo02]K75KlEaaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`005;lD]aFo5;LD_aBg5KlOol0001?Ool00;Io
o`<0009oo`03001oogoo00=K700?EaaFo5LLE_aG75KlEaaBo5KlD_aFo5;lE_aBo5Kl00=Bo003E_aB
o5;l00IBo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L008004moo`00]7oo0P001Goo0U/L02mG
75/lFaaK75LLFaaFo5LLE_aG75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aoo`0004ioo`00/Goo0`001Woo0Ull1e/L1eKl00AB
o5KlD_aFo0=Bo005E_aBo5;lD_aFo008D_`01E;LD_aBo000D]`00e;l00MBg5;lD_aBo5;LOol0001=
Ool00:moo`8000Qoo`04Gc]O?5lkHe`2Fa`02ULLFcaK75/LE_aG75KlEaaBo5LL0UKl029Bo5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lOol0
015oo`D003Moo`00[7oo0`0027oo1Ull0e/L0eLL00=K75LLE_`01UKl0e;l00EFo5;lD_aBo5Kl00aB
o005D]`005;lD_aBg003D_`01U;LD_aBo5;lOol0011oo`05001oogooOol0000gOol00:Yoo`8000Yo
o`0iHeaO>ellGc]SG5lkGcaO>e/LE_aK75KlFaaFo5/LD_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`00011o
o`03001oogoo03Qoo`00Ygoo0`000Woo00<007ooOol01Woo0VMk1ell00AK75LLEaaK70=G7003FaaB
o5Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L
00=Bo003001oogoo00Eoo`H000Aoo`03001oogoo03Moo`00YGoo0P003Goo03a[O6MKIgaWFf=LGc]O
?5/KGcaK75llE_aK75KlFaaFo5/LE_aG75;lEaaBo5KlD_aG75;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000AOol00`00Oomoo`0f
Ool00:9oo`<000eoo`MWN`9K?00;GcaK75/lFcaO?5KlEaaFo5LLE_aG7002E_`025;lE_aFo5KlD_aF
o5;lE_`3D_`00eKlD_aBo006D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o7oo00004Goo00<007ooOol0=Goo001eOol4000WOol2000?Ool03VMKJgaWFfMlIe][O6MKHeaS>ell
FaaO?5/KGc`2Fa`01UKlFaaFo5LLE_aK709Fo00XD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L000=Ool01@00Oomo
ogoo0000=goo001dOol00`00Oomoo`02Ool00`00Oomoo`0QOol3000@Ool00fnJLiYWN`03Ig/01F=K
HeaSG6=LFa`00U/l1E/L00AFo5LLE_aG70AFo004D_aFo5;lE_`3D_`01EKlD_aBo5;lE_`025;l00EB
g5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`003Goo0`00>7oo001dOol00`00Oomo
o`02Ool00`00Oomoo`0NOol3000BOol03VnILkY_VG>jKiUSG6=KHeaS>f=LHe]SG5LLFc`2Fa`02ULL
FcaK75/LD_aG75KlEaaBo5LL0UKl02QBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol004Moo`00M7oo00<007ooOol0
0Woo00<007ooOol077oo0P000Woo00<007ooOol03goo00M_VW>JKiUcVVnJKi][NP03He`016=KHeaO
?5ll1U/L00=G75/LE_`01EKl00IBo5KlD_aFo5;lE_`3D_`01EKlD_aBo5;lE_`025;l00EBg5;l001B
o5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol00017Ool007Aoo`03001oogoo009oo`03001oogoo
01Uoo`<001Eoo`0BKiUc^VnILkY_VFnKJgY_Vf<kHeaSFellGc]SG5lkGcaG75/l0U/L03=Fo5/LE_aK
75;lEaaFo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]`0
05;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo0000AWoo001dOol00`00Oomoo`02Ool00`00
Oomoo`0GOol2000GOol02VnJLiY_VG>JKiY_Vf]jJi][NVnK25ll0eLL00AK75LLEaaG70EFo004D_aF
o5;lE_`3D_`00eKlD_aBo00>D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03001o
ogoo04=oo`00M7oo00<007ooOol00Woo00<007ooOol057oo0`0067oo01Yg]W^gKiUc^VnIKi][NVnK
JgY_VfMKIgaO>f=LGc]O?5lkHeaK75llE_aK75KlFaaFo5/L0UKl02iBo5LLD_aFo5;lE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lOol004Eoo`00MGoo10005Goo0P006goo17Ng00E_Vf]jJi][NVnK00AWN`AO?004FaaK
?5/lGc`3Ea`00e/LE_aG7002E_`015;lE_aFo5Kl0e;l00EFo5;lD_aBo5Kl00QBo009D]aBo5;lD_aB
g5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol004Aoo`00Rgoo0`0077oo04ek
]gNfNkMg]WNiLkQ_Vf]jJgaWFfMlIe][O6MKIgaK6ellFaaO?5/KGcaK75llE_aK75KlEaaFo5/LD_aF
o5;lEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0004=oo`00RGoo0P000Woo00<007ooOol06Woo
0gNg00Ag^G>hMkQc^0MWN`9SG006FaaK?5/lGcaK75/l0U/L00aFo5LLE_aG75KlEaaBo5KlD_aFo5;l
E_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g002D_`00goo001oo`12Ool008Ioo`<0021oo`0DMkIk]gNfMkUc^7NiLiQc^VnIIgaWFf]lIe]SG6<k
HeaSFf=LFa]O?09K700iEaaK?5/LEaaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aoo`00049oo`00Q7oo0P008Woo17Ng00Uc^7NhLkQc^VnILiY_VW>jHe/00f=L00ASFf=LHeaS
G0MK70MFo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;l001Bo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool0@7oo0021Ool3000TOol05g^gMkIk]g>hMkUc
V7>jKiUc^VnILkY[NVnKHc]SG6=KHeaS>f=LGc]O?5LLFc`00U/L03QG75/LE_aG75;lEaaFo5LLD_aF
o5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]`005;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`00@Goo001nOol3000VOol3MkL03G>hMkQc^7>j
KiUcVVnJLkY[NV^KJgY_Vf=K009SG0AO?0=K7003EaaK75LL009G70IFo09Bo005E_aBo5;lD_aFo00<
D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`00
@7oo001lOol2000XOol0EG^dNiAk]7>hMkUcV7>jKiUc^VnILkY[NVnKJgY_Vf]jKi]O>f=LGc]O?5lk
HeaO>e/LE_aK75KlFaaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aoo`0003moo`00NGoo0`000Woo0P009Woo0W^d0g^e0WNg00UcVVnJLkY[NV^KJgY_Vf]jJi/00VMk
15ll00AK75/lFcaK70=G7003FaaG75LL009Fo004D_aFo5KlE_`3D_`00eKlD_aBo00>D_`01E;LD_`0
05;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol0000oOol007Moo`80
02aoo`0JNiAk]7^DNkIg]G^fMkIk]gNfNkM[NVnKJgY_Vf]jKi]WFf]lIe]WO5/KGcaK75llFa]O?09K
700kE_aK75KlEaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0
000nOol007Aoo`<002ioo`9k]0=k]@Ag]`05LkQg^6]jKi][NP05Ig/2He`01E/LFcaK?5llFa`00U/l
00EG75KlEaaFo5LL00AFo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;l00000e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol0>goo001bOol2
000`Ool08g^dNiAk]7NeNkIg]G^gMkIk]gNfMkUcV7NiLkQWO6MKJgaWFfMlHc]SG6=KHeaK6ellFaaO
?5LLFcaK75LLE_aK75KlEa`00UKl03ABo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lOol003eoo`00Kgoo0`00<Woo0W^d0g^e17Ng00Ig^7>hMkUc^7>JKiX2Ig/3He`016=KHeaSG6=L
1U/L00AFo5LLE_aG70AFo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L009B
o003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg5;lD_`00Woo00<0
07ooOol0>Woo001]Ool200000goo001oo`0aOol077^DNkAkU7^fMkEk]gNfNkMg]WNiLiQg^G>hLkY_
VG>jKiUSG6<kHeaSFf=LHc]SG5lkGcaG75/l0U/L03]G75/lE_aG75;lEaaFo5LLD_aFo5;lE_aBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03001oogoo03Uoo`00JWoo0`00=Woo0W^d
0g^e0gNg00ag^7>hMkUc^7>JKiYc^VnIJi][NV=LHe/2He`4Gc`5Fa`2Ea`7E_`2D_`01EKlD_aBo5;l
E_`00e;l00=Fo5;lD_`01U;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0jOol006Moo`<003Qoo`1NNkAkU7^dMkEk]WNf
NkMg]W^gLiQg^G>hLkY_VG>jKiU_Vf]jKi][NVnKGc]SG5lkGcaO>f=LGc]K75KlFaaFo5/LE_aK75Kl
EaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo000
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000jOol0
06Eoo`8003]oo`9k]003Ni=k/g^C00=k]00<LkQg^G>hLiY_VW>jKiU[Vf]jKi][NV^K0VMk1Ell0U/l
00EK75LLEaaG75/L009G709Fo004D_aFo5KlE_`3D_`00eKlD_aBo00>D_`01E;LD_aBo000D]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<007ooOol0>7oo
001ROol3000lOol07W^BOk=kTW^cNi=k]7^DNkAg]G^fMkEk]gNfLkY_VFnKJgY_Vf]jKi]WFf]lIe]W
O5lkHeaK75llFa]O?09K7010E_aK75KlEaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L000iOol0061oo`8003moo`05Nk=kTW^cNi=k/`03Nk@3NkD3
MkL016^KJgY_Vf]j1fMk00EK75/lFcaO?5/L009K?005EaaFo5LLE_aG7004E_`015;lE_aFo5Kl0e;l
00=Fo5;lD_`02U;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`015;LD_aoo`00>7oo001MOol300000goo001oo`0mOol0HWncNi9k/g^C
Ok=kU7^dNi=k]WNeNkIg]W^gMkIg^G>HMkUc^6MlIe][O6MKIgaWFf]lHe]SG5/KGcaK75llFa]K?5/L
EaaFo5/LE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5Kl000hOol005]oo`8004=oo`05Ni9kTg^CNk=kT`03Nk@3NkD3MkL01G>hMkUc^7>JKiX016Mk
00MSG6=KHeaSG5llFaaK?005Fa`03ELLE_aG75KlEaaBo5KlD_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`00e;LOol0000gOol002ioo`@002Ioo`<004Aoo`0PNi9k/g^BOk=k
Tg^dNi=k]7NeNkIg]G^gMkIk]g>HMkUc^7>jKiUc^VnILkYS>f=LHe]SG6<kHeaSFe/LEaaK?09K7013
EaaK?5KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg7oo00008Woo0`004Goo000]Ool00`00Oomoo`02Ool00`00Oomoo`0QOol20017Ool0
1G^CNi9k/g^CNk<00g^d0W^e0gNg00]c^7NiLkQg^6nJLkY_VG>JJiY_Vf=K00=SG003He]O?5ll00MK
70IFo004D_aFo5;lE_`3D_`01EKlD_aBo5;lE_`025;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol002Aoo`03001o
ogoo00moo`00<Woo00<007ooOol07Goo1000BGoo029kTWncNi=k/g^CNkAkU7^fMkEk]WNfNkMg]WNi
LkQg^FnILkY_VG>jJgY_Vf]jHeaS>f=LGc]O?5lkHeaO>e/LEaaK?09K7012E_aK75KlEaaBo5LLE_aG
75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`008goo
00<007ooOol03goo000UOol60007Ool00`00Oomoo`0LOol3001:Ool01G^BNk=kTg^cNi<00g^d0W^e
0gNg00ag^G>hMkQ_VW>jKiUcVV^JKi][NV^KJiX8Gc`01U/LEaaG75LLFaaG70MFo0=Bo003E_aBo5;l
00iBo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01U;LD_aBo5;lOol0025oo`03001oo`00011oo`00;Woo100077oo0`00CGoo025o/g^B
Nk=kTg^dNiAk]7^COk=kTg^dNi=k]WNeNkI_VG>jKiUc^V]jKi][NVnKJgY[O6MKGcaO>f=LGc]O?5/K
Gc`00U/L04EFo5/LE_aK75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo00008Goo00<007oo000047oo000^Ool00`00Oomoo`0JOol3
001?Ool02W^cNi9k/g^CNk=kTW^CNi9k/g^C0g^d0W^e17Ng00E[VVnKJgY[Vf^J00EWN`08FaaK?5/l
GcaK75/lEaaK709G7003E_aG75Kl00=Fo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;l
D]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo003D]aBo5;l008001moo`05001oogooOol0000?Ool002ioo`03001oogoo01Qoo`80
059oo`1[Ni9k/g^BOk=kTW^cNi9o/g^CNk=kTg^dMkEk]WNeNkMg]W^gLiQg^F]jKi]WFf]lIe]WO6MK
JgaSFf=LFa]O?5/LGcaK6ellE_aG75KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000NOol01@00Oomoogoo00003goo
000^Ool5000COol3001COol02W^BNi=kTg^CNi9kTg^BNk=kTg^c0g^d0W^e17Ng00=g^G>hMkP01VMk
00ESFf=LHeaO?5/L009K?0=K700>E_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD_aFo0=Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo000MOol3000017oo000000003Woo0014
Ool2001FOol08gncNi=o/g^BOk=kTWncNi=k/g^CNkAkU7^fMkEk]WNfNkMg]WNiLkQg^FnILkYWFfMl
Ie]SG6=KHeaS>f=LHe]K75LLFc`00U/L04QG75/lE_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0009Ool4000TOol0
045oo`<00003Ool007oo05Eoo`9kT`07Ni9kTg^BNk=kTW^cNi<00g^d0W^e0gNg00Yg^G>hMkQ_VW>j
KiUcVVnJHeaSF`=SG003He]O?5ll00MK70IFo004D_aFo5;lE_`3D_`01EKlD_aBo5;lE_`025;l00UB
g5;lD_aBo5;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00QBg5;lD_aBo5;LD_aoo`001goo00<007ooOol00Woo00<007ooOol08Goo000oOol2
001JOol09W^COkAkTWncNi9o/g^BNk=kTgncNiAk]7NeNkIg]W^gMkIg^G>hMkUcV7>jKiUc^VnIKi][
NV=LHc]SG5lkGcaO>f=LGc]K75LLFc`2Fa`0AeKlFaaFo5LLD_aG75KlEaaBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007oo
Ool00Woo00<007ooOol08Goo000lOol3001LOol5Ni<017^BNi=kTg^c0g^d0W^e0gNg00ac^7NhLkQc
^VnILiY_VVnKJgY[Vf^JKi/7Gc`01U/LEaaG75LLFaaG70MFo0=Bo003E_aBo5;l00iBo005D]aBo5;l
D_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00=Bg7oo00001Woo00<007ooOol00Woo00<007ooOol08Goo000jOol2001NOol0
9GndNi=o/g^BOk=kTW^cNi=o/g^CNkAkTg^fMkEk]gNfNkMc^7NiLiQc^VnILkY[NVnKJgY_Vf]jKi]W
FfMlGc]SG5lkGcaO>ell009K7018E_aK75KlFaaFo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l0Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol08Goo000gOol3001POol4Ni<017^BNi=kTW^c0W^C00AkTW^cNi=k
/`9k]0=k]@=g]`06JiY_Vf]jJi][VVnK0fMk0ell00IK?5llFaaK?5LLFa`2Ea`00eKlEaaFo003E_`0
15;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00=oo`00Ool017oo00<007ooOol00Woo00<007ooOol08Goo000eOol200000goo001oo`1POol0L7nc
Ni=o/g^BNk=kTWncNi=o/g^BOk=kTg^cNi=k]7^DNkIg]G^fMkIk]g>HMkU[NVnKJgY[O6MKIgaWFf]l
Ie]O?5/KGcaK75llFa]O?5KlEaaFo5/LE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol08Goo000bOol3001TOol3Ni<02g^BNi=kTW^cNi9kTg^BNk=kTg^cNi<0
0W^d0g^e0gNg00Ag^G>hMkQc^0IWN`9SG004GcaK75/lFc`3Fa`01UKlEaaFo5LLE_aG709Fo006D_aF
o5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l
0`0017oo100097oo000_Ool3001WOol09W^COkAkTWncNi9o/g^COk=kTWncNi9k/g^CNkAkU7^dMkEk
]WNeNkMg]WNiLkQg^G>HLkY_VFMlIe][O6=KHeaS>f=LHe]SG5LLFc`2Fa`0CELLFcaFo5LLE_aK75Kl
EaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg7oo0000;7oo000]Ool2001YOol9Ni<01G^cNi9k/g^CNk<00W^d0g^e0WNg
00Yg^G>hMkQc^7>jKiUcVVnJHeaSF`=SG004He]SG5llGc`6Fa`6E_`015;lE_aBo5Kl0e;l00EFo5;l
D_aBo5Kl00QBo005D]aBo5;lD_aBg00200000e;lD]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`0002]oo`00
:Woo0`00Jgoo02Uo]7^COk=kTWndNi=o/g^BOk=kTW^cNi=o/g^DNkAg]G^fMkEk]gNfMkUc^7NiLiQc
^VnILkY_VFnKJgYSG6<kHeaSFellGc]SG5lkFaaG75/l009K700ME_aK75KlEaaBo5LLE_aG75;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg0030000:U;LE_`005;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo09oo`03001oogoo02Qoo`00:7oo0P0000=oo`00Ool0JWoo0g^C00=kU7^dNi<00g^C00Ek
TW^CNi=k/g^C009k]0=k]@9g]`0<LkQg^7>hLkY_VG>JKiY_Vf]jJi][VVnK1ell00IK75LLEaaG75/L
Ea`7E_`3D_`00eKlD_aBo00;D_`300001U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo
000ZOol002Ioo`8006moo`0XNiEk]G^COkAkU7ncNi=o/g^BNk=kTWncNi=k]7^CNkIg]G^fMkIkeg>h
MkUcV7>jKiUc^VnIKi][NVnKJgY_VfMKIgaO>f=LGc]O?5/KGc`2Fa`06UKlFaaFo5/LE_aG75;lE_aB
o5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`20000<E;LE_aBg5;lD]aFo5;LD_aBg000
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;L009oo`03001oogoo02Moo`009Woo0P00KWoo00EkUG^eNiEk]7^D00=k
T`0;Ni9kTg^BNk=kTg^cNkAk/g^CNk=kT`02Nk@2NkD4MkL01FnKJgY[Vf^JKi/016Mk00EK75/lFcaO
?5/L009K?005FaaG75LLE_aG7004E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`015;l0`000e;l00EBg5;l
D_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg7ooOol002Qoo`009Woo0`00KGoo03mk]G^E
OkAkU7ndNi=o]7^BOk=kTWncNi=k/g^BOk=kTg^cNi=k]7^DNkIg]G^fMkIk]gNfMkUc^6nKJgY[O6MK
IgaWFf]lHe]SG5/KGcaK75llFa]O?5/LEaaFo5/LE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;L
E_`00`0003YFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
Ool002Qoo`009Woo00@007ooOol006]oo`03NkEkUG^e009kU09kT`05Ni9kTg^BNk=kTP02Ni<01G^c
Ni9k/g^CNk<00W^d0W^e17Ng00=c^7NhLkP01FMk00ESFf=LHeaSG5/L009K?009GcaK75/LFaaG75Kl
EaaFo5LL009Fo006D_aFo5;lE_aBo5Kl0U;l0`001e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`0
0003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00ABg5;lD_aBo09oo`03001oogoo02Eoo`009Goo00<007ooOol00Woo00<007ooOol0
J7oo02YkUG^fNiAo]7^COkAkTgncNi9o/g^COk=kTWncNi9k/g^COk=kU7^dMkEk]WNeNkMg]W_GLkQg
^G>HLkY_VFMlIe][O6=KHeaS>f=LHe]SG5LLFc`2Fa`03ULLFcaFo5LLE_aK75KlEaaBo5KlD_aFo5;l
E_`30000@EKlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo7oo00009goo000UOol00`00Oomoo`03Ool00`00Oomoo`1VOol00g^ENkEkU@02
Ni@9Ni<01G^BNi=kTg^cNi<00W^d0W^e0gNg00Uc^7NhLkQc^VnILiY_VW>jHe/00f=L00ASFf=LGcaO
?0IK70IFo003D_aFo0000080009Bo005E_aBo5;lD_aFo008D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol002Ioo`009Goo00<007ooOol017oo00<007ooOol0I7oo
02ikUG^fNiEo]7^COkAkTgncNi9o]7^COk=kTWncNi9k/g^BOk=kTg^dNi=k]WNeNkMg]W_GLkQg^G>H
MkU_VG>jKiUc^V]jKi]S>f=LHe]O?5lkHeaO>e/LEaaK?09K7006E_aK75KlEaaBo5LL0`0004IFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg09oo`03001oogoo02=oo`009Goo0P001Woo0P00I7oo00Ek]G^ENkEkU7^d
009kT`03NiAk]7^C00=kT`06Ni9kTg^BNk=kTg^c0W^d0W^e0gNg00]g^7>hMkQ_VG>JKiYc^V]jJi][
VVnK00MO?005FaaG75LLEaaK7002Ea`00eKl00000003E_`3D_`00eKlD_aBo00>D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo00009Goo000UOol00`00Oomoo`07Ool0
0`00Oomoo`1POol0;G^fNiEk]G^COkAkU7ncNiEo]7^DOk=kTgncNi9o/g^BOk=kTg^cNi=k]7NeNkIg
]W_GMkIg^G>HMkU_VG>jKiU_Vf]jKi][NVnKIe]WO5lkHeaO>ellFa]O?002Fa`00eKlFaaFo0030000
Ce;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002Aoo`009Goo00<007ooOol027oo
00<007ooOol0Ggoo00EkUG^eNiEk]7^D009kU@03NkAkU7^C009kT`0;Ni9kTg^BNk=kTg^cNi=k]7^B
Nk=kT`02Nk@3NkD3MkL016nKJgY[Vf^J1VMk0U/l00AO?5/LFcaK?0<00004E_aG75KlEa`2E_`015;l
E_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo7ooOol0000SOol002Eoo`03001oogoo00Uoo`03001oogoo05eoo`0]
NiEk]G^ENkMgUW^gNiEk]W^DOkAkTgndNi9o/g^BOk=kTW^cNi=o/g^BNk=kTg^dNiAk]7NeNkIg]G^g
MkIg^G>hMkUcV6]lIe]WO6MKJgaWFf=LHc]O?5/L00<0009K701DE_aK75KlEaaFo5/LD_aFo5;lE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`008goo000TOol2000<Ool00`00Oomoo`1KOol3MiP01G^g
MiIkUW^ENkD00g^D17^C00=k/g^BNk<00W^C00AkTW^CNi=k/`9k]0=k]@9g]`06MkQc^7NhLkQc^VnI
0fMk00=SFf=LHe`00`0000=K?5/LFa`00U/L00=G75KlEa`015Kl00IBo5KlD_aFo5;lE_`3D_`00eKl
D_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00ABg5;lOol0029oo`0097oo00<007ooOol037oo00<007ooOol0FWoo02Qg^7>GMkQgUW^gMiIk]W^E
OkAkU7ndNi=o/g^BOk=kTW^cNi9o/g^BNk=kTgncNiAk]7^CNkIg]G^fMkIkeg>hMkUcV7>jKiUc^VnI
HeaSF`<00004He]SG5LLFc`2Fa`0EELLFcaK75LLD_aG75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;L009oo`03001oogoo01moo`0097oo00<007ooOol03Goo00<007ooOol0F7oo0gNH
00EgUW^FMiIk]G^E009kU003NkAkTg^C009kT`09Ni9kTg^CNi=kTW^CNi9k/g^C009k]0=k]@9g]`07
LkQg^7>hMkQ_VG>JKiX00`000V=L00ASFellGcaO?0AK70=G70IFo09Bo005E_aBo5;lD_aFo003D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00=Bg7oo00008Goo000TOol00`00Oomoo`0>Ool00`00Oomoo`1GOol097>GMkQcUg^gMiIk]g^E
NkEkU7ndNi=o/g^BOk=kTWncNi=o/g^BNk=kTWncNi=k]7^CNkIg]G^fMkIkeg>hMkUcV7NiKiUc^P80
001UJgY_Vf]jHeaO>ellGc]SG5lkGcaFo5/LE_aK75KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000POol002Aoo`03001oogoo00moo`03001oogoo05Eoo`=g
V003NiIgUW^g009kU@03NiAk]7^D009kT`03NkAkU7^D009kT`06Ni9kTg^BNk=kTg^c0W^d0g^e00Eg
]g>hMkQc^7Nh00<00004Ki][NV^KJiX2Ig/5Gc`00e/lGcaG7002Ea`00e/LEaaG7002E_`015;lE_aF
o5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;l
D]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol07Goo000TOol2000AOol00`00Oomoo`1COol0
87>GMkQcUgNhMiIk]gNFNkEkUGndNiAo/g^CNkIkU7ndNi=o]7^BOk=kTWncNi9k/g^CNkAg]G^fMkEk
]7^DNkH30000Jg>jKiU_Vf]jKi][NV]lIe]WO6MKHeaO>ellFa]O?5/LGcaFo5/LE_aG75KlFaaBo5Kl
D_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo00007goo000SOol00`00Oomo
o`0BOol00`00Oomoo`1BOol3MiP00gNFNkMgUP02NiD01G^dNiAkU7^ENkD00g^D17^C00Uk/g^BNk=k
Tg^dNi9k/g^CNk@00`0000Qk]GNgMkMg]fnKJgY[Vf^J1VMk0U/l00]O?5/LFcaK?5llE_aG75KlEaaF
o5LL009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo01eoo`006Woo1000
1Goo00<007ooOol04goo00<007ooOol0D7oo01]g^7>GMkQcUg^gMiIk]g^ENkIgUW^gMiIk]W^EOkAk
U7ndNi=o/g^BOk=kTW^cNi=o/g^BNk<00`0001Mk]7NeNkIg]G^gMkIg^G>hMkUcV6]lIe]WO6MKJgaW
Ff=LHc]O?5/LGcaK6e/l009K701GE_aK75KlEaaFo5/LD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001F
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L009oo`03001oogoo01]oo`006Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol057oo00<007ooOol0CWoo00M_VVmjKiY_NW^gMiIkUP02MiP01GNFNiIgUW^eNiD00W^D
00=k]7^CNi<00W^C00AkTW^CNi=kT`<00003Nk=k]7^d00=k]@=g]`05LkQg^7>hLkY_V@03Ig/01F=K
HeaSG6=LHe/01e/L1UKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo
01aoo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0C7oo00A_
Vf]jKiY[NP=cV@0@LiMg^7>GNkMgUW^gNiEk]G^DOkAkTgncNi=o/g^BNk<300006g^cNi=o/g^CNkAk
Tg^fMkEk]gNfNmMc^7NiLiQc^VnILkY_VF=LHe]SG6<kHeaSFellGc]K?002Fa`0GELLFaaFo5/LD_aG
75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000LOol0
01Uoo`03001oogoo009oo`03001oogoo009oo`8001Moo`8004Yoo`05KgY_VVmjKiY_NP04LiT2MiP0
0g^FMiIk]`03NiD00g^dNiAkT`02Ni<02G^B000007^CNi9kTg^BNk=kT`02Nk@2NkD3MkL02G>hMkQc
^7>jKiUcVVnJKi][NP03He`6Gc`00eLLFaaG7002Ea`5E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg002D_`00goo001oo`0JOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Qo
o`03001oogoo04Ioo`06JgY_Vf]jKiY[NVnK0W>I00e_NGNhLiMg^7NFNkMgUW^eNiEo]7^DOk=kT`03
00009W^COkAkTWncNi9o/g^CNk=kTg^dMkEk]WNfNmMg]WNiLiQc^VnILkY_VFnKJgY_Vf]jKi]O>ell
Gc]SG5lkGcaK6ellE_aK75KlFa`2E_`0F5;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`0
05;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg0006goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0IOol00`00Oomoo`14Ool01VmjKiY_NVnJKgY_VP=cV@=gV003MiIk]gNF009kU@03NkEkU0000080
0003Ni9kTg^D00=kT`04Ni9k/g^CNk<2Nk@2NkD3MkL02gNhLkQc^VnILiY_VVnKJgY[Vf^JKi/00VMk
0ell0U/l00MO?5/LEaaG75/LE_aG7002E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
15;LD_aoo`006Woo000IOol00`00Oomoo`02Ool01@00Oomoogoo00007Goo00<007ooOol0@Woo00IS
FfMlHe]_VV]jKi/2LiT02FmiMkQcUgNhLiMk]gNFNkMkU@030000;W^COkAkTgndNiAo]7^COk=kTWnc
Ni=k/g^CNkAkU7^cNi=k]7^DNkIg]G_GMkIk]gNfKi][NVnKJgY[O6MKIgaWFf]lFaaO?5/KGcaK75ll
Fa]K75KlEaaFo5/L0UKl05QBo5LLD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlOol000Moo`D000eoo`006Woo100017oo0P007Goo00<007ooOol0@7oo00ISFfMLHe]S
G6=KIe`4LiT3MiP00g^gMiH00002000017^ENiAkU7^e0W^E00=kU7^dNi<00W^C00Ik/g^BNk=kTg^c
Ni82Ni<3Nk@2NkD3MkL00gNhLkQg^006Ig/01V=KHeaK?5llFaaK?0=K7005EaaFo5LLE_aG7002E_`0
15;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol00007Ool01@00
Oomoogoo00003Goo000ROol00`00Oomoo`0MOol00`00Oomoo`0mOol03VMlHe]WO6=KIgaSFfMlIg][
NfMJJg]cUgNhLiL30000:WNFNkIkUGndNiAk]g^ENkEkU7ndNi=o/g^BOk=kTW^cNi=o/g^BNk=kTgnc
NiAk]7NeNkIg]W^gMkIg^G>hMkU_VG>jIe]WO6MKHeaSFf=LHc]SG09K700:EaaK?5/LFaaFo5/LE_aG
75;lEa`2E_`0Ee;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
Ool00007Ool00`00Oomoo`0>Ool0029oo`03001oogoo01ioo`03001oogoo03]oo`0<HeaSFfMLHe]S
G6=KIeaWNf]kIg][Nfmj0`0000AgUW^FMiIk]@9kU@03MiIk]g^E009kU@03NkAkU7^C009kT`08Ni9k
Tg^CNi=kTW^CNi9k/`=k]09k]@=g]`09LkQg^6nJLkY_VG>JKiYSG6=K00=SG09O?0IK70IFo006D_aF
o5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03001oogoo00Eoo`03001o
ogoo00eoo`008Woo00<007ooOol07goo00<007ooOol0>Goo00]O?E/lIgaSFfMlHe][NfMkJg]WFV]k
0080000bJgY_Vg>ILiU_NGNhLiMg^7NFNkMgUW^eNiEo]7^DOk=kTgncNi9k/g^COk=kTW^cNi9o/g^C
NkAkTg^fMkEk]gNfNmMc^7NiLiQc^VnILkY_VFnKJgYSG6<kHeaO>ellGc]SG09K701REaaK75KlFaaB
o5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lOol000Qoo`03001oogoo00aoo`008Woo00<007ooOol087oo00<007ooOol0=Woo00YK?5llFcaO
?5/lHeaSFf]kIg][N`<0009_NP03KiYcVG>I009cV@=gV005NkMgUW^ENiEk]@02Ni@2Ni<02g^BNi=k
Tg^CNi9kTg^BNk=kTg^cNk@00g^e0WNg00]c^7NhLkQc^VnILiY_VVnKJgY[Vf^J00MO?003EaaK75LL
009G7003FaaG75Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo002
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0025oo`8002=oo`03001oogoo03=oo`09GeeK?5lmFcaO
GE/lGceK?6]k00<0002JJg][NVnJJgY_Vf]jLiU_NG>ILiMg^7>GNkMgUW^gNiEk]W^DOkAkTgndNi9o
/g^DOkAkTWncNi9o/g^CNk=kTg^dMkEk]WNfNmMc^7NiLiQc^VnILkY[NVnKJgY_Vf]jJgaWFellGc]S
G5lkGcaK6ellE_aK75KlFaaFo5LLE_aG75;lE_aBo5LLD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`2Ool01@00Oomoogoo00000goo00<007ooOol02goo000QOol0
0`00Oomoo`0SOol00`00Oomoo`0aOol01eLmEaaO?5/lGcaK?5ll00<00003Jg]WNf]k00=_NP03KiY_
NW>I00=cV@=gV005MiIkUW^ENkEkU@02Ni@2Ni<2Ni@037^CNi9kTg^CNk=kTW^cNi=k]7^CNk=kT`9k
]09k]@=g]`04JiY_Vf]jJi/5Ig/03UllFaaK?5/lGcaK75/lE_aG75KlEaaFo5LLD_`3E_`015;lE_aB
o5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0P0017oo0`003Woo000QOol0
0`00Oomoo`0TOol00`00Oomoo`0^Ool01ULLFceG75/mEaaOG@<0000<HeaO?6=LGc]SG6]jKiY[NVnK
JgYcVFmi0W>I02mg^7>GMkQgUW^gMiIk]W^EOkAkU7ndNi=k]G^DOkAkTgncNi9o/g^BNk=kTg^dNi9k
/g^CNkAkU7^fMkEk]WNfNkMcV7NiLkQg^FMKJgaWFfMlIe]SG6=KGcaK6ell009K701UEaaK?5KlEaaF
o5/LE_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LOol0000DOol0025oo`03001oogoo02Eoo`03001oogoo02]oo`05EaeG75LmEaaG7@03
0002Ge`02V=LGcaOG5mLHeaSFf=LHe]WG6=K17>I0gNH00AgUW^FMiIk]@9kU@06NiAk]7^ENiEkU7^d
17^C00QkTW^CNi=k/g^BNk=kTg^c0W^d0W^e0gNg00Eg^7>hMkQ_VW>j009WN`9SG004He]SG6=LHe`5
Fa`00eLLE_aG7004E_`025;lE_aBo5KlD_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`0
0goo001oo`0BOol0025oo`03001oogoo02Ioo`03001oogoo02Qoo`04DaaG7E;lFcd3000045/mEaaK
?ELLHeaO?6=LGc]SG6=KIgaSFfMlHe][NfMJ0g>I02icUgNhLiMk]gNFNkMkUG^eMiIk]gNFNkEkUGnd
NiAo/g^BOk=kTW^cNi=o/g^BNk=kTgncNiAk]7NeNkIg]G^gMkIg^G>hMkU_VG>jKiUc^V<kHeaSFf=L
Hc]SG09O?004EaaK?5/LFa`2Ea`0HUKlEaaBo5LLE_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000COol0025oo`8002Qoo`8002Eoo`05
DaeG7E<LEaeC7@0200000eLMEaaG?@03Fc`03e/mFcaOG5mLIeaSFf=LHe]WG6=KJg]WNf]kIg][N`03
MiP00g^FMiIk]`02MiP00gNFNkMgUP02NiD00g^dNiAkU002Ni<02G^BNi=kTW^CNi9kTg^BNk=kT`02
Nk@2NkD2MkL02WNhLkQg^6nJLkY_VG>JJi]_Vf=K0V=L1Ell0eLL00=K75LLE_`01UKl0e;l00EFo5;l
D_aBo5Kl00aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00QBg5;lD_aBo5;LD_aoo`004Woo000QOol00`00Oomoo`0YOol00`00
Oomoo`0POol015<MD_aG7E<L0`0004AC75LMD_aK?E/LFceG75/mFaaK?ELLIgaSFfMlHe]WO6MkJg]W
FV]kIg][Nf]jKi][NW>IKgUcVG>GMkQcUg^gMiIk]g^ENkIkU7ndNi=o/g^BNk=kTWndNi9o/g^BOk=k
Tg^dNi=k]WNeNkMg]W_GLkQg^FnILkY_VG>jJgY_Vf]jKi]O>f=L0Ull06]O>f=LFaaO?5KlFaaFo5/L
E_aK75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo000019oo`0087oo00<007ooOol0:goo00<007ooOol077oo00AC7E;mDaeC
7@<00003DaeG7E<L00=G7@04EaaK?5/lFcd3Fc`03UllFcaSG6=KIeaWNf]kIg][NfMkJg]_NVnJKgX4
LiT2MiP01G^gMiIkUW^ENkD00g^D00=kTg^BNi<00W^C00IkTW^CNi9k/g^CNk<2Nk@2NkD2MkL02W>h
MkQ_VW>jKiUcVV^KKi][NV^K0VMk15ll00AK75/lFcaK70AG7005E_aG75KlE_aBo003E_`3D_`00eKl
D_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol0000AOol0021o
o`03001oogoo02aoo`03001oogoo01Ioo`06DaeBo5<MC_aC7E;l0`0001mBo5<MD_aG7ELLEaeC75Lm
EaaG7E<LEceK?5lmFcaOGE/lGceK?5mMIg][NfMJJg]WNf]kJgY_Vf]jKiY_N@02LiT0V7NhLiMg^7NF
NkMgUW^fNiEo]7^DOkAkTWncNiAo]7^COk=kTWncNi=k/g^CNkAg]G^fNi=k]7NeNkIg]W_GMkIk]f]j
Ki][NVMlIe][O6MKIgaWFellFaaO?5/KGcaK75LLE_aK75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000@Ool0
021oo`03001oo`0002eoo`03001oogoo01=oo`05D_eC7E;mDaeBo@0300000e;mDaeBo@05Dad2Ead0
2eLLEaeG7ELMEaaG7E/lGcaK?5llFc`00Ull0UmL00E[NfMkJg]_NVnJ009_NPAcV@9gV005MiIkUWNF
NkEkU@02Ni@017^dNi=kU7^D17^C00Ak/g^BNk=kT`9k]004Nk=kTg^dNk@2NkD3MkL00g>hMkQc^006
Ig/01F=LHe]K?5/lGc`00e/L00EG75KlEaaFo5LL009Fo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`0
1U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l0P0047oo000POol2000_Ool00`00
Oomoo`0?Ool01DklDae>o5<MC_`00`0002=Bo5<MC_aC7E;lEaeBo5LMD_aG7E;lEaeG75LMDaaK?ELL
FceG75/mFcaO?E/lHeaO?6=LGc]SG5llHea[NVnKJgY_VVmi00=cV@0^LiMg^7>GNkMgUW^gNiEk]G^D
OkAkTg^eNiAo]7^COk=kTWncNi9k/g^COk=kTW^cNi=k]7^DNkIg]G_GMkIk]g>HMkUc^7>jKiU[O6MK
IgaS>f=LHe]SG6<kFc`2Fa`0JULLFcaK75/LD_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`003goo0005Ool5
0005Ool20005Ool40006Ool00`00Oomoo`0_Ool00`00Oomoo`0<Ool015<MC_eBoE;m0`0000UBoE<M
D_eC7E;mDaeBoE<MD_d01e<M00]G75LmEaaG7ELLEceG75LMGeaSG5ll009OG007HeaO?5mLHe]WG6=K
He`017>I0gNH00=kUWNFNkL00W^E00IkU7^dNiAkUG^DNk@4Ni<01G^BNi=kTg^CNi800W^C00=k/g^d
Nk@00W^e0gNg00Ig^7>hLiY_VW>jKiT3He`00f=KHeaO?002Gc`4Fa`2Ea`00e/LE_aFo003E_`2D_`0
1EKlD_aBo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo009D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`2
Ool00`00Oomoo`0<Ool000Aoo`800005Ool00000Ool00004Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool01E<MC_aC7DklDad00P0002Q>o5<MC_aC7Dkl
DaeBo5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaK?EllHeaO>f=LGcaWO6=K
IgaSFfMlIeY[N`9cV@0^KgUg^7>GMkQgUW^gMiIk]G^ENkMgUW^eNiEo]7^DOk=kTgncNi9k/g^BOk=k
TW^cNi9o/g^DNkAg]G^fMkIk]gNfMkUc^7NiKiUc^VnIKi][NVnKJgYO?5lkHe`2Gc`0KElkFaaFo5/L
E_aK75KlEaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0000ioo`0017oo0P000Woo00<007oo00003goo00<0
07ooOol00goo00<007ooOol0<Goo00<007ooOol01Goo00A>oE;mD_eC7@<0000JDae>oE;mD_eC7E;m
DaeBoE<MD_eC7E;mDaeBoE<MD_eG7E<LEaeC7ELMDaaG7ELLEceG709K?00@FceK?5/lGeaSG5llHeaS
FfMLHe]SG6MkJg]WNf]kIg/3MiP00gNFNkMgUP02MiP01W^gMiIkUW^ENkAkU0=kT`09Ni9kTg^BNi=k
TW^CNi9k/g^C009k]09k]@9g]`06MkQc^7NhKiYc^VnI0V^K00A_Vf]jIg]WN`=O?003FcaO?5/L009G
7006FaaG75LLEaaFo5;l0eKl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`02E;LD_aB
o5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool037oo0004Ool20002Ool00`00Ool0000?Ool00`00
Oomoo`02Ool2000dOol02000OomoogooC_aC7DkmDad30000<U<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMD_aG7E/LFceG75/mFaaK?ELLFceSFfMlHe]WO6=KIgaW
FV]kIg][NfMJKi][NVnJKgT2LiT0<gNhLiMg^7NFNkMkUG^fNiAo]7^COkAkTWncNi=o]7^BNk=kTWnc
Ni=k]7^CNkIg]G^gMkIg^G>hMkU_VG>jKiU_Vf]jKi][NVMlIe][O6MKGcaK6ellFaaO?5KlFaaFo5/L
E_aK7002E_`0IE;lEaaBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000037oo0004Ool20002Ool00`00Ool0000;Ool4
0005Ool00`00Oomoo`0bOol00e;mDae>o@02D_d01U<M00000000Dae>o@9Bo@05DaeBoE;mD_eC7@03
D_d01U<MD_eC7E;mDaeBo@=C7@0<D_eC7E<MEaeC75LMDaeG7ELLEaeK?5/m0e/l00eO?5/lGcaK?6ML
He]SG6MkJg]WNf]kIg]_VP02KgX4LiT2MiP017NFNiIgUW^e0W^D0W^C00=kTW^CNi@00g^C00AkTW^c
Ni=k/`9k]004NkEk/g^dNk@2NkD3MkL2Ji/00fnKIg]WN`03Ig/2He`02ellFaaK?5/lGcaFo5LLE_aG
75KlEa`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;l
D_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00ABg5;lOol000aoo`000goo0`0000Eoo`00001oo`0000]oo`03001oogoo
00Ioo`03001oogoo031oo`05Dae>o5<MC_eC7@030000=U<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LEceG75lmFcaOGE/lGceK?5mM
FcaO?FMJJg]WNf]kIeY_Vf]jKiY[NP=cV@0^LiMg^7>GNkMgUW^fNiEo]7^DOkAkTgndNiAo]7^COk=k
TWncNi9k/g^CNkAkTg^cNi=k]7NeNkEg]G_GMkIg^G>HMkUWFfMlIe][O6=KHeaS>f=LFaaO?5/KFc`2
Fa`01UKlFaaFo5LLD_aG709Fo01TD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000;Ool000Eoo`03001oogoo009o
o`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo02eoo`05Dae>oE;mD_eC7@0300001U<MC_eB
oE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1U<M00=G7ELLEad0
0ULM00UG75LMEaaO?5/lGcaK?5llFc`00UmL00ESG6MkJg]WNfnJ00=_NP=cV@=gV004NiIgUW^eNiD2
Ni@2Ni<00g^ENiAk]003Ni<027^cNi9k/g^CNk=kTW^cNi<2Nk@2NkD3MkL01g>hMkQ_VG>JKiYc^V=K
00=SG003He]SG5/L00IK70EFo003D_aFo5;l009Bo005E_aBo5;lD_aFo008D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo000000:Ool000Ioo`@000aoo`D000Aoo`03
001oogoo02]oo`04C_aC7DkmDad30000>U<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeBo5LMDaaG?ELLFceG75/mEaaO?E/lGeeO
?6=LGc]SG5llHeaO>fnKJgY_VV]j0g>I02icUgNhLiMg^7NFNkMkUG^eNiAo]7^ENkEkU7ndNi=o/g^C
Ok=kTW^cNi=o/g^BNk=kTg^dNiAk]GNeNmMg]W^gLiQg^FnILkY_VG>jJgY_Vf<kHeaSFemLGc]SG09K
701_EaaK?5KlFaaFo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0000Yoo`007goo00<007oo
Ool0:7oo00E>oE;mD_eC7Dkm00800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<M
C_eBoE;mDad00e;m00QC7E;mD_eBoE<MD_eC7E;m25<M00YG?ELLEaeG75LmEaaG7ELLHeaO?09OG008
HeaO?5mLGeaWG6=KHeaSF`AcV@=gV007MiIk]g^ENiEkU7^dMiH00W^E00=k]7^DNi<00W^C00EkTW^C
Ni=kTg^B009kT`04Nk=k]7^dNkD3MkL01g>hMkQc^7>JKiYc^V]j009[V`03Ki]O?5ll00AO?003EaaK
75LL009G7003FaaG75Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg00000002Goo000NOol2000UOol01dkmDae>o5<MC_eC
7Dkl00<0001^C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMDaaK?ELLFceG75/mEaaK?E/LFceO>f=LGcaS
G6=KIgaSFfMlHe][NfMkJg]WFWNhLiMg^7>GNkMgUW^eNiEk]gNFNkEkUGndNiAo]7^COkAkTW^cNi=o
/g^BNk=kTgncNiAk]7NeNkIg]W^gMkIg^G>hLkY_VFnKJgY_Vf]jKi]WFfMlGc]SG09O?01bFa]O?5Kl
FaaFo5/LE_aG75KlEaaBo5KlD_aG75;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`002Goo000NOol00`00Oomoo`0R
Ool01U<MC_eBoE;mDae>o@<00005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m01UC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MDaaG7E<MEaeC75LMDaeG
7@03Fc`04E/mFcaK?5/lFceK?6=LHe]WG6=KHeaSFf]kIg][NfMkKiX00fmj00Uk]gNFMiQgV7^gMiIk
UW^ENkD00W^D0W^C00UkTW^CNi=kTg^BNi=kTW^cNi<00W^d00Yk]GNgMkMg]gNhLkQcVVnJKi][NP9[
V`EWN`05FaaK?5/lGcaK7002Fc`01ULLE_aG75KlEaaBo0=Fo004D_aFo5;lE_`3D_`00eKlD_aBo006
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo00000Uoo`00
7Woo00<007ooOol087oo00E>o5<MC_eC7Dkl00<00019C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC
7E;lEaeC75LMD_aG7ELLEaeG75/mFaaK?ELLFceK75lmFcaWO6=KIgaSFf]kIg][NfMJKi][NVnJJgX0
0W>I09Qg^7>GMkQgUW^gNiEk]W^DOkAkU7ndNi=o]7^COkAkTWncNi9o/g^CNkAkTgncNi=k]7^CNkIg
]G^gMkIg^G>hMkUcV6]lIe]WO6MKJgaSFf=LFa]O?5/LGcaG75/lFaaG75KlFaaFo5LLD_aFo5;lE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;L17oo00<007ooOol01goo000NOol00`00Oomoo`0NOol2D_d00e<MC_d0000200001Dkm
D_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoELMDaeG7ELL00=G7@0@EaaK?5/l
FceK?5llFcaO?5/lHeaSFf]kIg][NfMkKiX3KgX3LiT2MiP01GNFNiIgUW^eNiD00W^D1G^C00UkTW^C
Ni9k/g^CNk=k]7^cNi<00g^d0W^e0WNg00Ec^7NhLkQc^VnI009WN`03HeaSFf=L009SG0MK70EFo004
D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l1goo00<007ooOol01Woo000NOol00`00Oomoo`0KOol015<MC_eC7Dkl0`0004i>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEceG75LMDaaG?ELLEaeC75mMFcaO?E/l
GeeK?5lmFca[NfMkJg]WFVnKJgY_VV]jKi/2LiT0;W>GMkQcUg^gMiIk]W^EOkAkU7ndNi=o/g^DOkAk
TgncNi9o/g^BNk=kTWncNi=k/g^CNkAg]G^eMkIkeg>hMkUcV7>jKiUc^VnIHeaSFf=LHe]SG5llGeaG
75/l0U/L06AFo5/LE_aG75;lEaaFo5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo0Yoo`03001oogoo00Ioo`007Goo0P0067oo00IC7Dkm
D_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeB
o@IC7@=G7@0=EaaG7ELLEceG75llFcaO?5/lGcaK?6=LGc`00UmL00E_VVmjKgY_NVnJ009cV@=gV003
NiIgUW^g009kU@06NiAk]7^CNi=kUG^d0g^C00Mk/g^BNk=kTg^cNi9k/`03Nk@2NkD02WNgLkQg^7>h
LkY_VG>JKiY_Vf]j0V=L1Ell0eLL00=K75LLEa`01UKl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00U;l3Woo00<007ooOol01Woo000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@80
001BC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeB
o5LMD_aG7ELLFceG75/mEaaK?ELLGeeK?5lmGc]SG5llHeaO>fMlHe]_VV]jKi/2LiT0SG>GMkQcUg^g
MiIk]g^ENkEkU7ndNiAk]G^EOkAkTgncNi9o/g^BNk=kTWncNi9k/g^BNkAkU7^eMkEkegNfMkUcV7>j
KiUc^VnIKi][NVnKJgYSG5llGeaO>ellFaaO?5KlFaaFo5/LE_aK75;lE_aBo5LLD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg00COol00`00Oomoo`06Ool001eoo`03001o
ogoo01=oo`9Bo@03Dae>oE;m00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;m
Dad00e;m00QC7E;mDaeBoE<MD_eC7E;m15<M00YG7E<LEaeG75LmEaaG7ELLEceG709OG009HeaO?5mL
GeaWG6=KHeaSFfML00=cV@=gV003MiIk]gNF009kU@06NkMgUW^ENiEk]G^D0g^C00EkTW^CNi=kTg^B
009kT`03Nk=k]7^e009k]@09MkMg^7>hLkY_VG>JKiY_Vf]j009[V`=WN`03FcaO?5/L009K?007GcaK
75LLE_aG75KlEa`00UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo009D]aBo5;lD_aBg5;l001Bo5;L00=Bo006D]aBo5;lD_aBg5;l5Goo00<0
07ooOol01Woo000MOol00`00Oomoo`0AOol014kmDae>o5<M0`0008UC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E;lEaeG
75/mEaaK?E/LFceG76=LGcaSG6=KIgaSFfMlHe]WO6MkJg]WFWNhLiMg^7NFNkMgUWNhLiMk]gNFNkMk
UG^fNiAo]7^COk=kTWncNi=o/g^BNk=kTWncNiAk]7NeNkIkU7^dMkEkegNfNkMg]VnKJgY_VfMKJgaW
FfMlHe]SG5/LGcaK6ell009K701GEaaK75KlEaaFo5/LD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001B
o5;LE_aBg5;lD]aFo5;L01Moo`03001oogoo00Ioo`007Goo0P003goo00ABoE<MC_eBo@<0009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE<MD_eC7E;mDaeBoE<M
D_eC7E;mDaeBo@9C7@09EaeC75LMDaeG7E<LEaeK?5/m00=K?00=FceK?5/lHe]WG6=KHeaSFfMLIg][
NfMkKiX00Vmj0g>I0gNH00IgUW^FNiEk]G^ENi@2Ni<037^BNiAkTg^CNi9kTg^BNk=kTg^dNi=k/`9k
]09k]@=g]`03MkQc^7Nh00=WN`=SG003He]SG5/L00EK7003E_aG75Kl00=Fo006D_aFo5;lE_aBo5Kl
0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aB
o5;L0002D_`00e;LOomoo`0JOol00`00Oomoo`06Ool001eoo`03001oogoo00Uoo`06C_aC7DkmDae>
o5<M0`00061C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeBo5LMD_aG7E<LEaeC75LmFaaK?ELLFceK75/mFcaOGF=K
IgaSFf]kIg][NfMJKi][NVnJKgT3LiT0:W>GMkQgUW^gMiIk]W^EOkAkU7ndNi9o]7^COkAkTWncNi9o
/g^CNkAkTWncNi=k]7^CNkIg]W^gMkIg^G>hMkU_VG>jKiUSG6=KHeaSFf=LGc]SG09K701BEaaK?5/L
FaaBo5LLE_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000OOol00`00Oomoo`05Ool001eoo`03
001oogoo00Moo`9Bo@03Dae>oE;m00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG
7ELL00=G7@0@EaaG7E/lFceK?5llFcaO?5/lGcaK?6]kIg][NfMkJg/3KgX3LiT3MiP00g^FMiIk]@02
NiD00g^DNkAkT`02Ni@3Ni<01g^BNk=kTg^cNi9k/g^C009k]09k]@=g]`05LkQg^6nJLkY_V@02Ji/0
0f=LHe]O?005Gc`01E/LEaaG75LLFa`01EKl0U;l00EFo5;lD_aBo5Kl00aBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoogoo009oo`03001oogoo01aoo`03001oogoo00Eoo`00
7Goo00<007ooOol01Goo00A>oE<MC_aC7@<0001TDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<M
D_aG7E;lEaeC75LmEaaG7E<LEceK?5lmFcaOGE/lGceK?6=LGca[NfMJJg][NVnJJgX3LiT0;W>GMkQc
Ug^gMiIk]g^ENkEkU7ndNi=k]G^DOkAkTgncNi9o/g^CNk=kTWncNi=k/g^CNkAg]G^gMkIkeg>hMkUc
V7>jKiU_Vf]jKi][NUmLGc]SG5llGeaO>ell0U/L04UFo5/LE_aK75;lEaaBo5KlD_aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg008
Ool00`00Oomoo`0KOol00`00Oomoo`05Ool001eoo`04001oogooC_d2D_d015<MC_eBoE;m0P000U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MC_eBoE;mDad00e;m00QC7E;mDaeBoE<MD_eC7E;m25<M00iG7ELLEaeG7ELmEaaG7E/lGcaK?5ll
GeaSG5ll0UmL00ASG6mjKgY_NP=cV@=gV003NiIgUW^g00=kU@05NkAkU7^ENiAk]004Ni<01W^BNi=k
Tg^cNi=k/`9k]09k]@9g]`05LkQg^7>hLkY_V@02Ji/016nKJgYWNfMk0ell00IK?5llFaaK?5LLFa`2
Ea`00eKlEaaBo003E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`<Ool00`00Oomoo`0KOol00`00Oomoo`05Ool001aoo`08001ooe<MC_eC7DklDae>o@<0001W
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/m
EaaK?ELLHeaO>f=LGcaSG5lkHeaSFfMlHe/00g>I07=_NGNhLiMg^7NFNkMgUW^eNiEk]gNFNkEkUGnd
Ni=o/g^BOk=kTWncNi9o/g^BNk=kTW^dNiAk]GNfNmMc^7NiLiQc^VnIKi][NVnKIe]WO6MKJgaWFell
Fa]O?5/LGcaK6ellE_aG75KlFaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg00AOol00`00Oomoo`0JOol00`00Oomoo`05Ool001aoo`03001C
7Dkm009Bo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;m
DaeBo@EC7@08DaaG7E<MEceG75LMEaaG?@=K?00<HeaO?5mLGeaWG6=KHeaSFf]kIg][NfMk0gNH00=g
UW^gMiH00WNH00Ik]gNFNiIkUG^dNi@3Ni<01G^BNi=kTg^CNi800W^C0W^d00Ak/g^CNkAk]09k]@9g
]`03MkQc^7Nh00AWN`05He]SG6=LGcaK7002Fc`3Fa`00eKlEaaFo003E_`015;lE_aBo5Kl0e;l00=F
o5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg00GOol00`00Oomoo`0IOol00`00Oomoo`05Ool0019oo`D0
00Eoo`03001>o@000080001cC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
DaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mFaaK?ELLFceK75/mHe]WO6=KIgaSFf]kIe][NfMJ
Ki][NVnJKgT00W>I02]g^7>GMkQgUW^gNiEk]W^DOk=kTgncNi9o]7^COk=kTW^cNi9o/g^DNk=kTW^d
NiAk]GNeNkIg]W^gLiQg^FnILkY_VF=LHe]SG6=KHeaSFf=LEaaK?002Fa`01ULLFcaFo5LLD_aG709F
o00bD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo1Yoo`03001oogoo01Qoo`03
001oogoo00Eoo`0057oo00<007ooOol01Goo0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05
Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@09D_eC7E<MDaeC75LMDaeG7E<L00=G7@=K?00=
FceK?5/lFcaO?6=KHeaSFf]kIg][NfMkKiX00Vmj17>I0WNH00IgUW^FMiIk]G^ENi@2Ni<2Ni@2Ni<0
1G^BNi=kTW^cNi800W^C00=k/g^dNk@00W^e0WNg00Mc^7NhKiUcVVnJKi][NP03He`016=KGcaO?5ll
15/L0ULL1UKl0e;l00EFo5;lD_aBo5Kl00QBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`LOol00`00Oomoo`0IOol00`00Oomoo`04Ool0
01Aoo`03001oogoo00Ioo`1e001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDaeBo5LMD_aC7E;lEceG75LMDaaG?ELLEaeG75/mFaaO?E/lGeeK?5lmFca[NfMK
Jg]WFV]kJgY_VV]j00=cV@1RLiMg^7>GNkMgUW^fNiEo]7^COkAkUGndNiAo]7^BOk=kTWncNi9k/g^B
Ok=kU7^dMkEk]WNfNkMcV7NiLkQc^VnIKi][NVnKJgY_VellGeaO>f=LGcaOG5KlFaaFo5/LE_aK75;l
E_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo25oo`03001oogoo01Qoo`03001oogoo00Ao
o`0057oo00<007ooOol01goo0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC
7@03D_d01U<MD_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@=G7@0@EaaG7ELMEaeK?5llFcaO?5/lGcaK
?6=LGca[NfMkJg/3KgX3LiT3MiP00g^FMiIk]`02NiD00g^DNkEkU@02Ni@3Ni<01g^BNk=kTW^CNi9k
/g^C009k]00:NkEg]gNgMkMg^7>hLiY_VVnKJgX2Ji/00fnKIg]WN`03Gc`2Fc`00ellEaaG7002Ea`0
1EKlEaaFo5KlD_`00eKl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00=Bg7ooOol097oo00<007ooOol05goo00<007ooOol017oo000DOol0
0`00Oomoo`09Ool0L000OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>
o5<MD_aG7E;lEaeBo5LMD_aG?ELLEaeC75/mEaaK?E/lGeeK?5lmGc]SG5llHeaO>f=LJgY_VV]j0g>I
05icUgNhLiMk]gNFNkMkUG^eNiAk]g^ENkEkU7ndNi=o/g^BOk=kTgncNi9o/g^CNk=kTg^fMkEk]gNf
MkUc^7>jKiU_Vf]jKi][NV]lIe]WO6MKJgaK75llFa]O?5/LGcaFo5LLE_aG75KlEaaBo5KlD_aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo2Qoo`03001oogoo01Moo`03001oogoo00Aoo`0057oo00<007ooOol02Woo00@007oo
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d8Dad025LM
EaaG?ELLEaeG75LmEa`2Ge`026=LGcaOG5mLHeaSFf=LHe/4LiT3MiP00gNFNkMgUP02NiD01G^gNiEk
UG^DNk@00g^C00Mk/g^CNi=kTg^cNi=k/`02Nk@00g^eNkAk]002NkD2MkL00gNhLkQg^005Ig/01F=L
He]SG5/lGc`015/L00=Fo5LLE_`00eKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo7oo02]oo`03001oogoo01Ioo`03001oogoo00Ao
o`004Woo0`003Goo09d007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<M
D_aC7E;lEaeBo5LMDaaG7E;lFceG75/mEaaK?ELLFceG76=LGcaSG5lkIgaSFfMlHe][NfMKJg]WFWNh
LiMg^7NFNkMgUWNHLiMk]gNFNkEkUGndNiAo/g^COk=kTgncNi9o/g^BNk=kTW^dNi=k/g^CNkAg]G^e
MkIkeg>hMkU_VG>jKiUc^V=KHeaSFf=LHe]SG002Fa`0:ELLFcaK75/LD_aG75KlEaaBo5KlD_aFo5;L
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`0<Goo
00<007ooOol05Goo00<007ooOol017oo000DOol00`00Oomoo`0<Ool200001WooC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00UG7E<LEaeC7ELMDaaG7ELL
Ecd00e/l00eK?E/lFcaSFfMLHe]SG6=KJg]WNf]kIg]_VP02KgX3LiT3MiP01GNFNiEkUG^dNi@00g^C
00YkU7^CNi=kTg^BNk=kTg^dNi9k/`9k]09k]@9g]`09LkQg^6nJLkY_VG>JJi]_Vf=K009SG0=O?0=K
709G7003FaaFo5Kl00=Fo09Bo005E_aBo5;lD_aFo00<D_`01E;LD_aBo5;lD]`00e;l=Woo00<007oo
Ool057oo00<007ooOol017oo000UOol0K`00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDaeBo5<MD_aG7E<LEaeBo5LMDaaG7E;lFceK75/mEaaK?E/LFceK?5mMHe]WO6=KJg]WFf]kIeY_
Vf]jKiY_N@03LiT0Bg>GMkQgUW^gNiEk]W^DOkAkTgndNiAo/g^COk=kTW^cNi9o/g^BNk=kTW^dNiAk
]GNeNmMc^7NiLiQc^VnILkY[NVnKJgY_VelkHeaO?5mLGc]SG5KlFaaFo5/LE_aK75;lEaaBo5KlD_aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg00jOol00`00Oomoo`0EOol0
0`00Oomoo`03Ool002Ioo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeB
oE<MD_d3Dad01E;mDaeC7ELMDa`00eLM011G75/lFcaK?E/lGcaK?5llFcaO?5/lJg]WNf]kIg]_VP=_
NP=cV@=gV003NiMgUW^e009kU09kT`05NiEkU7^CNi=kTP02Ni<017^cNi9kTg^C0W^d0W^e0WNg00Ug
^7>hLkY_VG>JJi]_Vf]jJi/00VMk15ll00AK75/lEaaK709G7003E_aG75;l00=Fo0=Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg003D_`mOol00`00Oomoo`0DOol00`00Oomoo`03Ool002Moo`1[001oogoo
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMEaaG7E<LEceG75LMDaaG?E/l
GceK?5mMFcaO?E/lHeaO?6]kIeY_Vf]jKiY[NP03LiT0BG>GMkQcUg^gMiIk]W^EOkAkU7^fNiEo]7^D
OkAkTWncNi9o/g^BNk=kTWncNiAk]GNeNkIg]WNiLiQc^VnILkY[NVnKJgYWO6MKJgaWFfMlFa]O?5/L
GcaK6ellE_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
041oo`03001oogoo01=oo`03001oogoo00=oo`00:7oo0P0000Eooe;mD_eC7Dkm009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eB
oE<M00=Bo@06DaeBoE<MD_eC7E;m1E<M0ULM00eG75LMEaeG?ELLEaeK?5llFcaO?5mLHeaO?002Ge`0
16nJKgY_NVmj0g>I0gNH00AkUgNFNkMkU@9kU00=NkEkUG^ENiAkTg^BNi=kTW^CNi9kTg^BNk<00W^d
0W^e0W^d00Mk]GNgMkMg]g>hMkQc^004Ig/3He`00f=KFaaK7003Fa`00eKlEaaFo003E_`015;lE_aB
o5Kl0e;l00=Fo5;lD_`01E;lAWoo00<007ooOol04Woo00<007ooOol00goo000ZOol0IP00OomC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeBo5/mEaaK?ELLFceG75/mEaaSG5lk
HeaO?6=LGc]WO6=KIgaSF`=cV@0^KgUg^7>GMiQgUW^gNiEk]GNFNkMkUG^eNiAo]7^COk=kTWndNi9o
/g^BOk=kTg^dNi9o/g^CNkAg]G^fMkIk]g>hMkUc^7>jKiUc^V=KHeaSFf=LHe]OG5lkFc`2Fa`04ULL
FcaFo5LLD_aG75KlEaaBg5KlD_aFo5;LE_aBg5KlD]aFo4Yoo`03001oogoo019oo`03001oogoo00=o
o`00:goo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@09DaaG
7E<MEceG75LMEaaG?ELL009K?00<HeaO?5mLHe]WG6=KHeaSFf]kIg][NfMk0gNH00=gUW^gMiH00WNH
00Ek]g^ENiEkUG^d00=kT`0:NkAkTg^CNi=k/g^CNkAkTW^cNi<2Nk@02g^eMkMg]gNgMkQc^7>JKiYc
^V]jJi/00V=L1Ell0ULL00=K75LLEa`01UKl0e;l00=Fo5;lOol0CWoo00<007ooOol04Goo00<007oo
Ool00goo000/Ool0JP00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E;lEaeC
75/mEaaK?E/LFceG75/mFaaK?F=KIgaSFfMlHe][NfMKJg]WFVnKJgY_VVmi0W>I03MgV7>GNkMgUW^e
NiEo]7^DOk=kU7ndNi=o/g^BOk=kTW^cNi9o/g^CNk=kTg^fMkEk]gNfMkUc^7NiKiUc^V]jKi][NVnK
GcaOG5lkHeaK75llFa]K75KlFaaFo5/LD_aFo5;lEaaBo5KlD]aFo01BOol00`00Oomoo`0@Ool00`00
Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00QBoELMDaeG
7E<LEaeC7E/m0e/l00eK?E/lFcaK?5llHe]SG6=KJg]WNf]kIg]_VP02KgX4LiT2MiP017NFNiEkUG^e
0W^D00=kUG^dNi@00g^C00IkTW^cNi=k/g^CNk<2Nk@02G^eMkMg]gNhLkQg^6nJLkY[NP02Ji/01VnK
Ig]WNfMkGcaK709K?007GcaK75LLE_aG75KlEa`00UKl00=Bo5KlE_`0EGoo00<007ooOol047oo00<0
07ooOol00Woo000_Ool0I@00Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEaeC75Lm
EaaK?ELLFceK75lmFcaOGE/lGceK?6]kIe][NfMJKi][NVnJJgX00g>I02YcUgNhMiIk]g^ENkIkU7nd
Ni=o]7^DOk=kTgncNi9k/g^BOk=kTg^cNi9k]7NeNkEg]WNiLkQg^FnILkY[NVnKJgY[O6MKIgaWFf=L
He]O?5/KGc`2Fa`2Ea`015KlEaaFo5LLFGoo00<007ooOol047oo00<007ooOol00Woo000`Ool01@00
OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7Dkm
D_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@0@EaaG7ELMEaeK?5llFcaO
?5/lGcaK?6=LGca[NfMkKiX3KgX3LiT3MiP017^GNiEk]G^E0W^D00=k]G^DNi@00W^C00MkTW^CNi=k
Tg^BNk=kT`02Nk@00g^eNkAk]002NkD2MkL00g>hMkQc^003Ig/2He`00f=KHeaSG006FaaNOol00`00
Oomoo`0?Ool00`00Oomoo`02Ool0035oo`1Q001oogooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeC
75LmEaaG7E<LFceG75/mFcaOGE/lGceO>f=LGcaSG5lkKi][NVnJJgX00g>I02icUgNhLiMk]gNFNkIk
UG^gMiIk]W^EOkAkTgndNi9o/g^COk=kTW^cNi9o/g^dNk=kTW^dMkEk]GNeNmMg]WNiLkQc^VnILkYS
Ff=LHe]SG5lkHeaO?5/LEaaK?65oo`03001oogoo00ioo`03001oogoo009oo`00<Woo00D007ooOomC
7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC
7@03D_d025<MD_eC7E;mDaeBoE<MD_d6Dad025LMEaaG?ELLEaeG75LmEa`2Ge`026=LGcaOG5mLIeaS
Ff=LHe/4LiT3MiP01gNFMiQgV7^GMiIk]g^E009kU09kT`04NiAkTg^CNi82Ni<017^cNkAkTg^C0W^d
0W^e0WNg00Qg^7>hLkY_VG>jJi]_Vf]j1UllHgoo00<007ooOol03Woo00<007ooOol00Woo000cOol2
0000RWooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeBo5/mEaaK?ELLFceK75/mEaaSG5llHeaSFfMl
He]WO6=KJg]WFf]kIeYg^7>GMiQ_NGNhLiMgV7NFNkMkUG^eNiAo]7^COk=kTgndNi9o/g^BOk=kTg^c
Ni9o/g^cNkEg]G_GMkIg^G>hLkY_VG>jJgY_Vf]jIgaWFf=LGcaOG6Ioo`03001oogoo00eoo`03001o
ogoo009oo`00=Goo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@0IDae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eG7E<LEaeC7ELMDaaG7E/lFcd0
0e/l00eK?E/lFcaSFfMLHe]SG6=KJg]WNf]kIg]_VP02KgX2LiT2MiP01WNFNkMgUW^ENiAk]09kT`06
NiAkTg^CNi=kTW^c0W^C00AkTW^cNkAk]09k]@9g]`07LkQc^VnILkY[VfnKJgX016MkJGoo00<007oo
Ool037oo00<007ooOol00Woo000fOol0QP00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklEaeBo5<MD_aG7E;lEaeBo5LMDaaG7E<LEceK
75/mEaaK?E/LFceK?5mMHe]WO6MJJg]WFf]kIeY_Vf]jKiY_NG>ILiMgV7>GNkMgUW^eNiEo]7^COk=k
UGndNi=o/g^BOk=kTWncNi9o/g^CNkAg]G^fMkIk]gNeNmMg]W^gJgY_Vf]jIgaWFf]lIe][Ool00`00
Oomoo`0;Ool00`00Oomoo`02Ool003Moo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM
011G75LMFcaK?E/lGcaK?5llFcaO?6MkJg]WNf]kKgY_VP=_NP9cV@9gV006NkMgUW^GNiEk]G^D0W^E
00Ek]7^CNi=kTg^c00=kT`05Nk=kTg^dNkAk]@02Nk@2NkD01GNfMkMc^7NhLkP00fMkKGoo00<007oo
Ool037oo00<007ooOol00Goo000hOol20000FU<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG7E<LEceG75LMDaaG?E/l
GceK?5mMFcaO?ElkHeaO?6=LJgY_Vf]jKiY[NP9cV@0SMiQcUg^gMiIk]g^ENkIkU7^gNiEk]W^DOk=k
TWncNi=o/g^BOk=kTW^cNi=o/g^CNkAkTg^fMkIk]g>hMkUc^7>jKiUc^P1_Ool00`00Oomoo`0;Ool0
0`00Oomoo`01Ool003Yoo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d6Dad02ULMEaaG7ELMEceG75LMFcaO?5/l0UmL
00ESG5llGeaSFfML00=_NP=cV@9gV009MiIkUgNFNkEkUG^GNiEk]G^D00=kT`09NiAkTg^CNi=kTW^c
NkAk/g^C009k]09k]@9g]`05MkQc^7>jKiYc^P1aOol00`00Oomoo`0:Ool00`00Oomoo`01Ool003]o
o`1G001oogooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MD_aC7E;lEaeBo5LMD_aG7E;lFceG75/mEaaK?ELLFceG76=LGc]SG5llHeaSFfMlHe]WO6=K00=c
V@0QLiMg^7NFNkMgUWNhLiMk]gNFNkIkUGndNi=o/g^DOk=kTgncNi9k/g^BOk=kTg^cNi=k]7NeNkMg
]WNiLkQc^VnI07Aoo`03001oogoo00Uoo`03001oogoo005oo`00?7oo00<007ooOol00U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@9C
7@09EaeC75LMDaeG?ELLEaeG75Lm00=K?00=HeaO?5mLHe]WG6=KHeaSFf]kIg][NfmjKiX00g>I0gNH
00=gUW^eNiD00W^D00=kTg^DNi@00W^C00IkTW^CNi=kTg^BNk<2Nk@2NkD01GNgMkQc^7>jKiX0MGoo
00<007ooOol02Goo00<007ooOol00Goo000mOol20000MGooDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mFaaK?ELL
FceK75/mHe]WO6=KIgaWFV]kIe][Nf]jKi][NW>IKgUg^7>GMiQgUW^gNiEk]G^DOkAkUGndNi=o]7^B
Nk=kTWncNi9k/g^BNkAk/g^eNi=k]7NeNkMg]P1gOol00`00Oomoo`08Ool00`00Oomoo`01Ool003mo
o`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mDaeBoE<MD_eC7E;m
DaeBo@=C7@05D_eC7E<MEaeC7003Ead3Fc`03U/mFcaO?5/lGcaK?6]kIg][NfMkJg]_NVnJKgX3LiT2
MiP01gNFNkMkUG^ENiAk]7^E009kU006Ni=kTW^CNi9kTg^B0W^C0W^d00=k/g^CNk@00W^e0WNgN7oo
00<007ooOol01goo00<007ooOol00Goo0010Ool0J`00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7ELLEaeC75LmEaaG7E<LGeeK?5lmFcaO
GE/lHeaO>f]kIe][Nf]jKi][NW>IKgUcVG>GMiQgUW^gMiIk]G^EOkAkUG^eNiAo]7^COk=kTgndNi9k
/g^BOk<00W^c00IkTW^dNk=k]GNfNmMjOol00`00Oomoo`07Ool10001Ool1Ool0045oo`06001oogoo
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00QC7E;mD_eBoE<MD_eC7E;m1e<M0ULM00MG
75LMEaaG?ELLGcaK?002Gc`2Ge`01F=LGcaOG6mjKiX00Vmj0W>I0gNH00Uk]gNFNiEkUG^gMiIkUG^D
Nk@00W^C00MkU7^CNi=kTg^BNk=kTP02Ni<01G^cNkAk]G^eMkL0Ngoo00<007ooOol01goo0@000Goo
0Goo0012Ool20000KWooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaK?EllHeaO>f=LGcaSG6=KIgaSFfMlKgUcVG>GMiQc
Ug^gMiIk]g>GMkQgUW^eNiEo]7^COk=kTWndNi=o/g^BOk=kTW^cNi9o/g^cNkAg]G_GMkIlOol00`00
Oomoo`06Ool10001Ool1Ool004Aoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03
D_d025<MD_eBoE;mDaeBoE<MD_d4Dad02ELMDaaG7ELLEceG75LMEaaK?@02Fc`02UmLHeaO?6=LHe]W
G6=KHeaWNf]k0fmj0g>I0WNH00EgUW^GNiEk]G^D009kT`05NkAkTg^CNi=k/`02Ni<017^BNk=kTg^d
0W^e00=g]WooOol0O7oo00<007ooOol01Goo0@000Goo0Goo0015Ool0DP00Oom>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E;lEaeC75/mEaaK?E/LFceG
75/mHe]WO6=KIgaSFfMlIeY[Nf]jKiY[NVnK0W>I01M_NGNhLiMk]g^ENkIkU7ncNi=k]W^DOk=kTWnc
Ni9o/g^BOk=kTg^dNi=keW^c07moo`03001oogoo00Eoo`40005oo`5oo`00AWoo00D007ooD_eC7Dkm
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EC75LMDaeG7ELL009G
7@0>FceK?5/lFcaK?E/lGcaSFfMLHe][NfMkJg]WN`9_NP04KiYcVG>ILiT2MiP027^GMiIk]G^ENiAk
UG^eNi@3Ni<02W^BNi=kTg^cNi9k/g^dNk=kTg^dP7oo00<007ooOol017oo0@000Goo0Goo0017Ool2
0000C7ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aC7E;lEceG75LM
DaaG?ELLFceG75mMFcaO?E/lGeeK?6]kIeY[NfMKKiY[NVnK0W>I01Q_NGNhLiMgV7NFNkIkUGndMiIk
]W^EOkAkTgncNi9o/g^BOk=kTW^cNi=o/g^CNkB2Ool00`00Oomoo`03Ool10001Ool1Ool004Uoo`04
001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad3Ead0
2ELLEaeG7EllFcaO?5/lGcaK?002Ge`01V=LGca_NVmjKiY_NP9cV@=gV008MiIk]g^ENiEgUW^eNiEk
U09kT`05Ni9kU7^CNi=kTP02Ni<017^cNi=k/g^dPgoo00<007ooOol00goo0@000Goo001:Ool0I000
OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aG7ELLFceG75/m
EaaO?E/lGeeO?6=LGc]SG5llIgaSFfMlHe]cVFmiLiUcUgNHLiMk]g>GMiQgUW^gNiEk]G^DOkAkTWnd
Ni=o/g^BNk=kTWncNi9k/g^CQ7oo00<007ooOol00goo0@000Goo001;Ool01000OomC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1U<M00YG7E<LEaeG75LmEaaG7ELLEceO?09OG009HeaS
Ff=LHe]WG6=KJg]WNf]k00=gV005LiUgV7NHMiQk]`02NiD00g^DNkAkT`02Ni@02G^CNi9kTg^BNi=k
TW^cNi=k]025Ool00`00Oomoo`02Ool10001Ool004aoo`80001ODae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E;lFceG75/mEaaK?E/LFceG76MlHe]WO6=KIgaSFf]kIeY[
Nf]jKiY[NW>IKiUgV7>GNkMgUW^eNiEo]7^CNkEkU7ndNi=o/g^BOkAkTW^cNi9k]027Ool01@00Oomo
ogoo00000Goo001>Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad0
1ULMDaaG7E<MEaeC709K?00=FceK?5/lFcaO?5/lHeaSFfMLIg][NfMkJg/00fmj0W>I0gNH00QgUW^E
NiEk]7^DNiEkU7^d0W^C00MkTW^CNi9kTg^BNk=kTP28Ool01000Oomoo`000Goo001?Ool0G@00Oom>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7DklEaeBo5<MD_aG7E;lDaeC75LmEaaG7E<LFceK75/mFcaOGE/lGceK
?5mMIe][NfMJJg][NVnJJgYcVFnILiUcUgNhMiIk]g^ENkIkU7^gNiEo]7^DOk=kTWndNi=o/g^BOk=k
TP29Ool01000Oomoo`000Goo001@Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad0
1E;mDaeC7E<MEa`00eLM00MG75LMFcaO?5/lGcaK?002Gc`2Ge`016=LKgY_NVmj0g>I0WNH00UgUW^G
NiEk]GNFNiMkUG^dNi@00W^C00Mk]7^CNi=kTg^cNi9kT`2:Ool00`00Ool00001Ool0055oo`80001H
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aG7E;lEaeBo5LMDaaG?ELLFceG75/mFcaO?E/lHeaO?6=L
Gc]SG6=KIgaSFg>IKiUcVFmiMkQcUg^gMiIg^7NFNkMgUW^fNiAo]7^COkAkTgncNi9o/g^CNk><Ool1
0001Ool1000005=oo`06001>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@MC7@09EaaG7ELLEceG75LM
EaaSG5ll009OG008IeaSFf=LHe][NfMkJg]WN`9gV09cV@9gV003NiMgUW^e00=kU003NkEkU7^C009k
T`03Ni9kTg^B08eoo`800000E7oo05L007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeBo5LMDaaG
7ELLFceG75/mEaaK?E/LFceSFfMlHe]WO6=KJg]WFf]kIeY_Vf]jLiU_NG>ILiMk]gNFNkMkUGndNiAo
]7^DOk=kTgncNi9o/g^BOk<0SGoo0P00001EOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d2
Dad01ELMDaaG7E<MEad00e/l00iK?E/lFcaK?5llHe]SG6=KJg]WNf]kIg]_VVmj0g>I0WNH00=gUW^g
NiD00W^D00=k]7^ENi@00W^C00AkTW^CNi=k/hioo`800000EWoo05@007ooOom>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeB
o5<MD_aG7E;lEaeC75LmEaaG7ELLFceK75llFcaOGE/lGcaK?6]kIe][Nf]jKi][NVnJKgUcVG>GMiQg
UW^gMiIk]GNFNkMkUGndNiAo]7^BOkAkTgncNi::Ool40002Ool005Moo`800004OomBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC
7E;m1U<M00=G7ELLEad00ULM00aG75llFcaO?5/lGcaK?6=LGcaOG6mjKiX2KgX3LiT2MiP02g^gMiIk
UGNHNkMgUW^ENiAkTg^BNi@00W^C00=kTWooOol0QGoo10001Woo001IOol0D000Oom>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7Dkl
EaeBo5LMD_aG7E;lEaeC75LmEaaK?ELLGeeK?5llGc]SG5llHeaSFfMlHe]WG6miLiU_VGNHLiMk]gNF
NkMcUg^gMiIk]G^EOkAkTgndNiAo]7^BNk>3Ool4000:Ool005Yoo`05001ooe;mDae>o@02D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m
1U<M00IG?ELLEaeG75LmEa`2Ge`02V=LGcaSG6=KIeaSFf=LIg][NfMk0Vmj0g>I0WNH00QgUW^GNiEk
]7^CNiEkU7^d0g^COgoo10003Woo001KOol0C@00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LFceG75/m
FaaK?ELLFceK76MLHe]WO6=KIeaWFV]kIe]_VV]jKiY_NG>ILiMg^7NFNkMkUG^fNiAk]W^DOkAkTgnc
Ni80O7oo10004Woo001LOol200000gooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00YC7DkmDaeBoE<MD_eC7E;mDaeBo@=C7@08D_eG7E<MEaeC75LMDaeK?@=K?00:FceK?5ll
FcaWG6=KHeaWNf]kIg/2KgX016nJLiUcVG>I0WNH00QkUg^ENkEkU7^GNiEk]7^D0g^CNGoo0`005Woo
001NOol0B@00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5<MD_aG7E;lDaeBo5LMEaaG7E<LEceG75/mEaaK?E/lGcaK?5mMFcaO?6MJJg]WFfnJJgY_
VVmiLiU_NGNhLiMk]gNFNkIkUG^gNiEo]7^DOk=kTWnd07Ioo`@001Uoo`00Ggoo00@007ooDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d5Dad2
Ead02ELLEaeG7ELMFcaO?5/lGcaK?002Ge`01V=LGca_NVmjKiY_NP9cV@=gV006MiIgV7NHNiMgUW^e
0W^D00=kTg^dNi<0LWoo10007Goo001POol0A`00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaSG5ll
HeaO>f=LGcaWG6=KIgaSFg>IKgUg^7>GMiQ_NGNhLiMgV7NFNkIkU7ndNiAk]W^DOk<0KWoo10008Goo
001QOol200001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@04
DaeBoE<MD_d4Dad02ULMDaaG7ELLEceG75LMFcaK?E/l0UmL00USG6=KHeaSFfMLHe][NfMkKiX00Vmj
0W>I0WNH00=gUW^gNiD00W^D00=kTg^DNi<0Jgoo10009Goo001SOol0@`00Dae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LFceG
75/mFaaK?ELLFceSFfMLHe]WO6MKJg]WFVnJJgY_VVmiLiUcUgNHMiIk]g^EOkAkU7ndNiEo]7^C06Qo
o`<002Uoo`00I7oo00<005<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC
7E;mDaeBoE<MD_d3Dad01E<LEaeC7ELMEa`00ULM00eK?E/lFcaK?5llFcaO?5/lJg]WNf]kIg][N`02
KgX3LiT027NHMiIk]gNFNiEgUW^gNiD2NiAUOol4000/Ool006Eoo`10001oodklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG?ELLEaeC75LmEaaG7E/l
GeeK?5llFcaSG5llJg]WFV]kJgY_VVmiLiU_NGNHLiMk]gNFNkIcUg^gMiIk]W^DOkAQOol4000`Ool0
06Ioo`800005C_eBoE;mDae>o@02D_d01E<MC_eBoE;mDad00e;m00QC7E;mD_eBoE<MD_eC7E;m1U<M
0eLM00UG75LMEaaG?E/lGcaOG6=LGc`00UmL00=SG6mjKgX017>I00MgV7^gMiIkUgNHNkMgUP02NiD0
0g^dNiEoo`1LOol4000dOol006Qoo`0l001ooe<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lFceG75/mEaaK?ELLFceO>f=LGcaSG5lkHeaSFfMLIeY[NfMK
Jg][NW>IKgUcVG>GMkQgUW^gNiEo]7^CFWoo1000>7oo001YOol01P00OomBoE;mDae>o@9Bo@05Dae>
oE;mD_eC7@03D_d04U<MD_eC7E;mDaeBoE<MD_eC7E<LEaeC7ELMDaaG7ELLEceG709K?00=FceO?5mL
GeaWG6=KHeaWNf]kIg][NfmjKiX00g>I00MgV7NFNiMkUG^eNiAkU@1FOol4000lOol006Yoo`0i001o
oe<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMDaaG7E;lEaeK
75/mEaaK?E/LFceG76MlHe]WG6MJJg]WFf]kJgY_VVmiLiU_NGNhLiMk]g^ENkIkU7^g05Aoo`<0041o
o`00Jgoo0P000U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00aBoE<MDaeC7E<LEaeC
7ELMEaaG7E/lFcd3Fc`02EllFcaO?6MkJg]WNf]kKgY_VP03LiT2MiP01W^GMiIk]G^ENiMkUE1oo`@0
04=oo`00KGoo03H007ooC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeC
75LmEaaG7E<LEceK?5llFcaOGE/lHeaO>f=LGcaSG6]jKiY[NW>IKgUcVG>GMiQgUWNhLiMk]gNFNkI<
Ool40017Ool006ioo`05001ooe;mDae>o@02D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@IC7@08
EaeG75LmEaaG7ELLEceO?09OG006HeaO?5mLHe]WG6=K0g>I0WNH00IcVGNHMiQgV7NFNkE9Ool4001;
Ool006moo`0c001oogooDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMD_aK
?ELLFceG75/mFaaK?ElkHeaO?6MLHe]WO6=KJg]WFV]kJgY_VVmiLiUcUgNHMiIk]g^E04Eoo`@004mo
o`00L7oo0P0000=ooe<MC_d00U;m01EC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eG7E<LEaeC7ELMDaaG
7E/lFcd00e/l00]K?F=KHeaSFfMLIg][NfMkJg][NVmj009cV@=gV003NkMkUGoo049oo`<005=oo`00
LWoo02l004klDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMDaaG?E/LFceG
75mMFcaO?5/lGeeWFf]kIeY_VV]jKiY[NW>ILiMgV7>GNkMgUW^f03moo`@005Ioo`00Lgoo00<005;m
Dad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM00MG75LMFcaO?5/lGcaK?002Gc`2
Ge`016nJJgY_NVmj0W>I0gNH00=gUWNHOol0>goo1000FWoo001dOol0;000C_aC7DklDae>o5<MC_aC
7E;lDae>o5<MD_aG7E;lEaeBo5LMDaaG?ELLFceG75/mFcaO?5/lHeaO?6=LGc]WO6=KIeaSFg>IKgUg
V7>GMkQ_NGNHLiLhOol4001NOol007Eoo`80000<DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;m1E<M015G
75LMEaaG?ELLEaeG76=LGcaOG6=KIeaSFf=LHe][NfMk009_NP04KiYcVG>IMiPeOol4001ROol007Mo
o`0X001C7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMEaaK?ELLFceG75/mFaaK?F=KIgaS
FfMLHe][NfMKKiY[NVnJKgUcVG>GMkPaOol4001VOol007Qoo`0;001C7E;mDaeBoE<MD_eC7E;mDaeB
o@02Dad01ULMDaaG7E<MEaeC709K?00=FceK?5llFcaO?6=KHeaSFf]kIg][NfmjKiX00W>I0WNH;goo
0`00JWoo001iOol09@00Dae>o5<MC_aC7DklEaeBo5<MD_aG7E;lDaeC75LmEaaG7E<LEceK?5llFcaO
GE/lGcaK?6]kIe][Nf]jKiY_NG>IKgUg^7>G02]oo`@006eoo`00NWoo00L007ooD_eC7E;mDaeBo@03
Dad01E;mDaeC7E<MEa`00ULM00eG?ELLEaeK?5llFcaO?5mLHeaO?5mLKgY_VP03LiT2MiPXOol4001a
Ool007]oo`80000OC_aC7E;lDae>o5LMD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaSG5lkHeaO?6ML
He]WO6MKJg]WFVnJJgX09Goo1000MGoo001mOol04@00D_eC7E;mDaeBoE<MD_eG7E<LEaeC7ELMEaaG
7ELLEcd00e/l00YK?F=KHeaSFfMLIg][NfMkKgY[NR9oo`@007Uoo`00OWoo01d005;lDaeBo5<MD_aG
7E;lEaeBo5LMDaaG7ELLFceK75/mEaaK?E/lGcaSFfMlIe][NfMJJg][NVnJ01ioo`@007eoo`00Ogoo
00<007ooDad00U<M00EBoE<MDaeG7ELL00=G7@=K?00;GcaK?5llFcaO?6MkJg]WNf]kJgY_NP0LOol3
0021Ool0081oo`80000GEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LGeeK?5llFcaSG5llHeaO>f=LJgY_
VP0IOol40024Ool0089oo`03001C7E<M00EC7@09EaaG7ELLEceG75LMGeaSG5ll009OG003HeaSFf=L
01Ioo`@008Qoo`00Pgoo01@005LMD_aG7E;lEaeC75LMEaaK?ELLFceG75/mGcaSG5lkIgaSFfML4goo
1000S7oo0024Ool02000OomC7ELMDaaG7E<MEad3Fc`01e/mFcaK?5/lIeaSFf=L011oo`@0091oo`00
QGoo0P0000iooeLMDaaG?ELLEaeG75/mFaaK?E/lGeeK?5ll3Woo0`00U7oo0027Ool01000OomG7ELL
0eLM00EG75llFcaO?5/l00aoo`@009Moo`00R7oo00T007ooOomG75/mEaaK?ELLFcd02Woo1000Vgoo
0029Ool01P00OomooeLLEaeG70Qoo`@009moo`00RWoo0P0000=oo`00Ool017oo1000Xgoo002<Ool2
00000goo00000002002WOol008eoo`800:]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo
003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00001\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02905 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.679 .783 .928 r
.38978 .79773 .39812 .804 .41206 .79877 .40375 .79288 Mtetra
.705 .799 .923 r
.40375 .79288 .41206 .79877 .4261 .79214 .41783 .787 Mtetra
.749 .825 .911 r
.41783 .787 .4261 .79214 .44025 .78304 .432 .77925 Mtetra
.811 .86 .884 r
.432 .77925 .44025 .78304 .45451 .76981 .44629 .76826 Mtetra
.884 .895 .834 r
.44629 .76826 .45451 .76981 .46886 .75029 .46069 .75206 Mtetra
.943 .916 .758 r
.46069 .75206 .46886 .75029 .48326 .72291 .47517 .72859 Mtetra
.973 .92 .677 r
.47517 .72859 .48326 .72291 .4976 .68863 .48964 .69725 Mtetra
.979 .917 .619 r
.48964 .69725 .4976 .68863 .51177 .65215 .504 .66094 Mtetra
.974 .922 .611 r
.504 .66094 .51177 .65215 .52576 .6196 .51816 .62559 Mtetra
.966 .938 .666 r
.51816 .62559 .52576 .6196 .53961 .59454 .53216 .59646 Mtetra
.939 .944 .764 r
.53216 .59646 .53961 .59454 .55343 .5769 .54607 .57519 Mtetra
.877 .913 .848 r
.54607 .57519 .55343 .5769 .56728 .56477 .55998 .5605 Mtetra
.803 .859 .891 r
.55998 .5605 .56728 .56477 .58119 .55611 .57394 .55026 Mtetra
.745 .812 .905 r
.57394 .55026 .58119 .55611 .59518 .54948 .58797 .5427 Mtetra
.709 .781 .909 r
.58797 .5427 .59518 .54948 .60924 .54395 .60208 .53665 Mtetra
.688 .763 .909 r
.60208 .53665 .60924 .54395 .62339 .53901 .61627 .53141 Mtetra
.676 .753 .909 r
.61627 .53141 .62339 .53901 .63761 .53438 .63054 .52659 Mtetra
.67 .747 .908 r
.63054 .52659 .63761 .53438 .65191 .52989 .64488 .522 Mtetra
.667 .745 .908 r
.64488 .522 .65191 .52989 .66628 .52548 .6593 .5175 Mtetra
.665 .743 .908 r
.6593 .5175 .66628 .52548 .68072 .52109 .6738 .51305 Mtetra
.665 .742 .908 r
.6738 .51305 .68072 .52109 .69525 .51671 .68837 .50862 Mtetra
.664 .742 .908 r
.68837 .50862 .69525 .51671 .70984 .51231 .70302 .50418 Mtetra
.70302 .50418 .70984 .51231 .72452 .5079 .71775 .49972 Mtetra
.664 .741 .908 r
.71775 .49972 .72452 .5079 .73926 .50348 .73255 .49525 Mtetra
.73255 .49525 .73926 .50348 .75409 .49903 .74743 .49075 Mtetra
.74743 .49075 .75409 .49903 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.67 .777 .93 r
.38136 .79126 .38978 .79773 .40375 .79288 .39537 .78669 Mtetra
.69 .79 .926 r
.39537 .78669 .40375 .79288 .41783 .787 .40948 .78135 Mtetra
.725 .811 .918 r
.40948 .78135 .41783 .787 .432 .77925 .42369 .77461 Mtetra
.778 .841 .9 r
.42369 .77461 .432 .77925 .44629 .76826 .438 .76538 Mtetra
.848 .878 .863 r
.438 .76538 .44629 .76826 .46069 .75206 .45244 .75198 Mtetra
.917 .908 .798 r
.45244 .75198 .46069 .75206 .47517 .72859 .46697 .73226 Mtetra
.962 .92 .716 r
.46697 .73226 .47517 .72859 .48964 .69725 .48155 .70461 Mtetra
.978 .918 .643 r
.48155 .70461 .48964 .69725 .504 .66094 .49608 .67003 Mtetra
.976 .918 .608 r
.49608 .67003 .504 .66094 .51816 .62559 .51043 .63323 Mtetra
.97 .929 .631 r
.51043 .63323 .51816 .62559 .53216 .59646 .52459 .6004 Mtetra
.957 .945 .713 r
.52459 .6004 .53216 .59646 .54607 .57519 .53862 .57511 Mtetra
.912 .933 .811 r
.53862 .57511 .54607 .57519 .55998 .5605 .55261 .55729 Mtetra
.84 .887 .875 r
.55261 .55729 .55998 .5605 .57394 .55026 .56662 .54501 Mtetra
.771 .834 .9 r
.56662 .54501 .57394 .55026 .58797 .5427 .5807 .53623 Mtetra
.725 .795 .907 r
.5807 .53623 .58797 .5427 .60208 .53665 .59485 .52948 Mtetra
.697 .771 .909 r
.59485 .52948 .60208 .53665 .61627 .53141 .60908 .52384 Mtetra
.681 .757 .909 r
.60908 .52384 .61627 .53141 .63054 .52659 .6234 .5188 Mtetra
.673 .75 .908 r
.6234 .5188 .63054 .52659 .64488 .522 .63779 .51406 Mtetra
.668 .746 .908 r
.63779 .51406 .64488 .522 .6593 .5175 .65226 .50947 Mtetra
.666 .744 .908 r
.65226 .50947 .6593 .5175 .6738 .51305 .66681 .50495 Mtetra
.665 .743 .908 r
.66681 .50495 .6738 .51305 .68837 .50862 .68143 .50045 Mtetra
.664 .742 .908 r
.68143 .50045 .68837 .50862 .70302 .50418 .69613 .49596 Mtetra
.69613 .49596 .70302 .50418 .71775 .49972 .71091 .49146 Mtetra
.664 .741 .908 r
.71091 .49146 .71775 .49972 .73255 .49525 .72577 .48694 Mtetra
.72577 .48694 .73255 .49525 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.664 .773 .931 r
.37286 .78462 .38136 .79126 .39537 .78669 .38691 .78025 Mtetra
.679 .783 .928 r
.38691 .78025 .39537 .78669 .40948 .78135 .40106 .7753 Mtetra
.705 .799 .923 r
.40106 .7753 .40948 .78135 .42369 .77461 .4153 .76931 Mtetra
.749 .825 .911 r
.4153 .76931 .42369 .77461 .438 .76538 .42964 .76143 Mtetra
.811 .86 .884 r
.42964 .76143 .438 .76538 .45244 .75198 .44411 .7503 Mtetra
.884 .895 .834 r
.44411 .7503 .45244 .75198 .46697 .73226 .45869 .73391 Mtetra
.943 .917 .758 r
.45869 .73391 .46697 .73226 .48155 .70461 .47335 .71021 Mtetra
.973 .92 .677 r
.47335 .71021 .48155 .70461 .49608 .67003 .48801 .67858 Mtetra
.979 .917 .619 r
.48801 .67858 .49608 .67003 .51043 .63323 .50255 .64195 Mtetra
.974 .922 .611 r
.50255 .64195 .51043 .63323 .52459 .6004 .5169 .6063 Mtetra
.966 .938 .666 r
.5169 .6063 .52459 .6004 .53862 .57511 .53107 .57692 Mtetra
.939 .944 .764 r
.53107 .57692 .53862 .57511 .55261 .55729 .54515 .55544 Mtetra
.877 .913 .848 r
.54515 .55544 .55261 .55729 .56662 .54501 .55923 .54058 Mtetra
.803 .859 .891 r
.55923 .54058 .56662 .54501 .5807 .53623 .57336 .5302 Mtetra
.745 .812 .905 r
.57336 .5302 .5807 .53623 .59485 .52948 .58755 .52252 Mtetra
.709 .781 .909 r
.58755 .52252 .59485 .52948 .60908 .52384 .60183 .51635 Mtetra
.688 .763 .909 r
.60183 .51635 .60908 .52384 .6234 .5188 .61619 .511 Mtetra
.676 .753 .909 r
.61619 .511 .6234 .5188 .63779 .51406 .63063 .50608 Mtetra
.67 .747 .908 r
.63063 .50608 .63779 .51406 .65226 .50947 .64515 .50138 Mtetra
.667 .745 .908 r
.64515 .50138 .65226 .50947 .66681 .50495 .65975 .49677 Mtetra
.665 .743 .908 r
.65975 .49677 .66681 .50495 .68143 .50045 .67442 .49222 Mtetra
.665 .742 .908 r
.67442 .49222 .68143 .50045 .69613 .49596 .68918 .48767 Mtetra
.664 .742 .908 r
.68918 .48767 .69613 .49596 .71091 .49146 .70401 .48312 Mtetra
.70401 .48312 .71091 .49146 .72577 .48694 .71892 .47856 Mtetra
.664 .741 .908 r
.71892 .47856 .72577 .48694 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46937 Mtetra
.74897 .46937 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.659 .77 .932 r
.36427 .77786 .37286 .78462 .38691 .78025 .37837 .77361 Mtetra
.67 .777 .93 r
.37837 .77361 .38691 .78025 .40106 .7753 .39255 .76894 Mtetra
.69 .79 .926 r
.39255 .76894 .40106 .7753 .4153 .76931 .40683 .76349 Mtetra
.725 .811 .918 r
.40683 .76349 .4153 .76931 .42964 .76143 .42121 .75664 Mtetra
.778 .842 .9 r
.42121 .75664 .42964 .76143 .44411 .7503 .4357 .74728 Mtetra
.848 .878 .863 r
.4357 .74728 .44411 .7503 .45869 .73391 .45032 .73371 Mtetra
.917 .909 .798 r
.45032 .73371 .45869 .73391 .47335 .71021 .46504 .71378 Mtetra
.962 .92 .716 r
.46504 .71378 .47335 .71021 .48801 .67858 .47981 .68587 Mtetra
.978 .918 .643 r
.47981 .68587 .48801 .67858 .50255 .64195 .49452 .65097 Mtetra
.976 .918 .608 r
.49452 .65097 .50255 .64195 .5169 .6063 .50906 .61386 Mtetra
.97 .929 .631 r
.50906 .61386 .5169 .6063 .53107 .57692 .5234 .58074 Mtetra
.957 .945 .713 r
.5234 .58074 .53107 .57692 .54515 .55544 .53761 .55522 Mtetra
.912 .933 .811 r
.53761 .55522 .54515 .55544 .55923 .54058 .55176 .53721 Mtetra
.84 .887 .875 r
.55176 .53721 .55923 .54058 .57336 .5302 .56594 .52478 Mtetra
.771 .834 .9 r
.56594 .52478 .57336 .5302 .58755 .52252 .58019 .51587 Mtetra
.725 .795 .907 r
.58019 .51587 .58755 .52252 .60183 .51635 .59451 .50899 Mtetra
.697 .771 .909 r
.59451 .50899 .60183 .51635 .61619 .511 .60892 .50324 Mtetra
.681 .757 .909 r
.60892 .50324 .61619 .511 .63063 .50608 .62341 .49809 Mtetra
.673 .75 .908 r
.62341 .49809 .63063 .50608 .64515 .50138 .63798 .49324 Mtetra
.668 .746 .908 r
.63798 .49324 .64515 .50138 .65975 .49677 .65262 .48854 Mtetra
.666 .744 .908 r
.65262 .48854 .65975 .49677 .67442 .49222 .66735 .48391 Mtetra
.665 .743 .908 r
.66735 .48391 .67442 .49222 .68918 .48767 .68216 .47931 Mtetra
.664 .742 .908 r
.68216 .47931 .68918 .48767 .70401 .48312 .69704 .4747 Mtetra
.69704 .4747 .70401 .48312 .71892 .47856 .712 .47009 Mtetra
.664 .741 .908 r
.712 .47009 .71892 .47856 .73391 .47397 .72705 .46546 Mtetra
.72705 .46546 .73391 .47397 .74897 .46937 .74217 .46081 Mtetra
.74217 .46081 .74897 .46937 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Mtetra
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.655 .768 .932 r
.35561 .77097 .36427 .77786 .37837 .77361 .36975 .76681 Mtetra
.664 .773 .931 r
.36975 .76681 .37837 .77361 .39255 .76894 .38397 .76233 Mtetra
.679 .783 .929 r
.38397 .76233 .39255 .76894 .40683 .76349 .39829 .75728 Mtetra
.705 .799 .923 r
.39829 .75728 .40683 .76349 .42121 .75664 .4127 .75118 Mtetra
.749 .825 .911 r
.4127 .75118 .42121 .75664 .4357 .74728 .42722 .74318 Mtetra
.811 .86 .884 r
.42722 .74318 .4357 .74728 .45032 .73371 .44187 .73189 Mtetra
.884 .895 .834 r
.44187 .73189 .45032 .73371 .46504 .71378 .45663 .71532 Mtetra
.943 .917 .758 r
.45663 .71532 .46504 .71378 .47981 .68587 .47148 .69137 Mtetra
.973 .92 .676 r
.47148 .69137 .47981 .68587 .49452 .65097 .48634 .65945 Mtetra
.978 .917 .619 r
.48634 .65945 .49452 .65097 .50906 .61386 .50107 .6225 Mtetra
.974 .922 .611 r
.50107 .6225 .50906 .61386 .5234 .58074 .5156 .58654 Mtetra
.966 .938 .666 r
.5156 .58654 .5234 .58074 .53761 .55522 .52995 .55689 Mtetra
.939 .944 .764 r
.52995 .55689 .53761 .55522 .55176 .53721 .54421 .5352 Mtetra
.877 .913 .848 r
.54421 .5352 .55176 .53721 .56594 .52478 .55846 .52017 Mtetra
.803 .859 .891 r
.55846 .52017 .56594 .52478 .58019 .51587 .57276 .50965 Mtetra
.745 .812 .905 r
.57276 .50965 .58019 .51587 .59451 .50899 .58713 .50184 Mtetra
.709 .781 .908 r
.58713 .50184 .59451 .50899 .60892 .50324 .60158 .49556 Mtetra
.688 .763 .909 r
.60158 .49556 .60892 .50324 .62341 .49809 .61611 .4901 Mtetra
.676 .753 .909 r
.61611 .4901 .62341 .49809 .63798 .49324 .63073 .48506 Mtetra
.67 .747 .908 r
.63073 .48506 .63798 .49324 .65262 .48854 .64543 .48025 Mtetra
.667 .745 .908 r
.64543 .48025 .65262 .48854 .66735 .48391 .66021 .47553 Mtetra
.665 .743 .908 r
.66021 .47553 .66735 .48391 .68216 .47931 .67507 .47086 Mtetra
.665 .742 .908 r
.67507 .47086 .68216 .47931 .69704 .4747 .69 .46621 Mtetra
.664 .742 .908 r
.69 .46621 .69704 .4747 .712 .47009 .70502 .46154 Mtetra
.70502 .46154 .712 .47009 .72705 .46546 .72012 .45686 Mtetra
.664 .741 .908 r
.72012 .45686 .72705 .46546 .74217 .46081 .7353 .45216 Mtetra
.7353 .45216 .74217 .46081 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Mtetra
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.653 .767 .933 r
.34686 .76397 .35561 .77097 .36975 .76681 .36105 .75986 Mtetra
.659 .77 .932 r
.36105 .75986 .36975 .76681 .38397 .76233 .37531 .75552 Mtetra
.67 .777 .93 r
.37531 .75552 .38397 .76233 .39829 .75728 .38967 .75075 Mtetra
.69 .79 .926 r
.38967 .75075 .39829 .75728 .4127 .75118 .40412 .74519 Mtetra
.725 .811 .918 r
.40412 .74519 .4127 .75118 .42722 .74318 .41867 .73822 Mtetra
.778 .842 .9 r
.41867 .73822 .42722 .74318 .44187 .73189 .43334 .72872 Mtetra
.848 .879 .863 r
.43334 .72872 .44187 .73189 .45663 .71532 .44814 .71498 Mtetra
.917 .909 .798 r
.44814 .71498 .45663 .71532 .47148 .69137 .46305 .69483 Mtetra
.962 .92 .716 r
.46305 .69483 .47148 .69137 .48634 .65945 .47802 .66665 Mtetra
.978 .918 .643 r
.47802 .66665 .48634 .65945 .50107 .6225 .49292 .63144 Mtetra
.976 .918 .608 r
.49292 .63144 .50107 .6225 .5156 .58654 .50766 .594 Mtetra
.971 .929 .631 r
.50766 .594 .5156 .58654 .52995 .55689 .52218 .56059 Mtetra
.957 .945 .713 r
.52218 .56059 .52995 .55689 .54421 .5352 .53656 .53483 Mtetra
.912 .933 .811 r
.53656 .53483 .54421 .5352 .55846 .52017 .5509 .51664 Mtetra
.84 .886 .874 r
.5509 .51664 .55846 .52017 .57276 .50965 .56525 .50405 Mtetra
.771 .834 .9 r
.56525 .50405 .57276 .50965 .58713 .50184 .57967 .495 Mtetra
.725 .795 .907 r
.57967 .495 .58713 .50184 .60158 .49556 .59417 .48801 Mtetra
.697 .771 .909 r
.59417 .48801 .60158 .49556 .61611 .4901 .60875 .48214 Mtetra
.681 .757 .909 r
.60875 .48214 .61611 .4901 .63073 .48506 .62342 .47687 Mtetra
.673 .75 .908 r
.62342 .47687 .63073 .48506 .64543 .48025 .63817 .4719 Mtetra
.668 .746 .908 r
.63817 .4719 .64543 .48025 .66021 .47553 .653 .46709 Mtetra
.666 .744 .908 r
.653 .46709 .66021 .47553 .67507 .47086 .66791 .46235 Mtetra
.665 .743 .908 r
.66791 .46235 .67507 .47086 .69 .46621 .6829 .45763 Mtetra
.664 .742 .908 r
.6829 .45763 .69 .46621 .70502 .46154 .69797 .45291 Mtetra
.69797 .45291 .70502 .46154 .72012 .45686 .71312 .44818 Mtetra
.664 .741 .908 r
.71312 .44818 .72012 .45686 .7353 .45216 .72836 .44344 Mtetra
.72836 .44344 .7353 .45216 .75056 .44744 .74368 .43867 Mtetra
.74368 .43867 .75056 .44744 .7659 .4427 .75908 .43387 Mtetra
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42906 Mtetra
.77456 .42906 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.651 .765 .933 r
.33803 .75688 .34686 .76397 .36105 .75986 .35226 .7528 Mtetra
.655 .768 .932 r
.35226 .7528 .36105 .75986 .37531 .75552 .36657 .74854 Mtetra
.664 .773 .931 r
.36657 .74854 .37531 .75552 .38967 .75075 .38096 .74396 Mtetra
.679 .783 .929 r
.38096 .74396 .38967 .75075 .40412 .74519 .39545 .7388 Mtetra
.705 .799 .923 r
.39545 .7388 .40412 .74519 .41867 .73822 .41004 .73258 Mtetra
.749 .825 .911 r
.41004 .73258 .41867 .73822 .43334 .72872 .42474 .72445 Mtetra
.812 .86 .885 r
.42474 .72445 .43334 .72872 .44814 .71498 .43957 .71301 Mtetra
.884 .896 .834 r
.43957 .71301 .44814 .71498 .46305 .69483 .45453 .69624 Mtetra
.944 .917 .758 r
.45453 .69624 .46305 .69483 .47802 .66665 .46957 .67205 Mtetra
.973 .92 .676 r
.46957 .67205 .47802 .66665 .49292 .63144 .48462 .63984 Mtetra
.978 .917 .619 r
.48462 .63984 .49292 .63144 .50766 .594 .49955 .60256 Mtetra
.974 .922 .612 r
.49955 .60256 .50766 .594 .52218 .56059 .51427 .56628 Mtetra
.966 .938 .667 r
.51427 .56628 .52218 .56059 .53656 .53483 .52881 .53637 Mtetra
.939 .944 .764 r
.52881 .53637 .53656 .53483 .5509 .51664 .54324 .51446 Mtetra
.877 .912 .848 r
.54324 .51446 .5509 .51664 .56525 .50405 .55767 .49926 Mtetra
.803 .859 .891 r
.55767 .49926 .56525 .50405 .57967 .495 .57214 .4886 Mtetra
.745 .812 .905 r
.57214 .4886 .57967 .495 .59417 .48801 .58669 .48066 Mtetra
.709 .781 .908 r
.58669 .48066 .59417 .48801 .60875 .48214 .60132 .47425 Mtetra
.688 .763 .909 r
.60132 .47425 .60875 .48214 .62342 .47687 .61603 .46867 Mtetra
.676 .753 .909 r
.61603 .46867 .62342 .47687 .63817 .4719 .63083 .46352 Mtetra
.67 .747 .908 r
.63083 .46352 .63817 .4719 .653 .46709 .64572 .45859 Mtetra
.667 .745 .908 r
.64572 .45859 .653 .46709 .66791 .46235 .66068 .45376 Mtetra
.665 .743 .908 r
.66068 .45376 .66791 .46235 .6829 .45763 .67572 .44898 Mtetra
.665 .742 .908 r
.67572 .44898 .6829 .45763 .69797 .45291 .69085 .4442 Mtetra
.664 .742 .908 r
.69085 .4442 .69797 .45291 .71312 .44818 .70606 .43942 Mtetra
.70606 .43942 .71312 .44818 .72836 .44344 .72135 .43462 Mtetra
.664 .741 .908 r
.72135 .43462 .72836 .44344 .74368 .43867 .73673 .4298 Mtetra
.73673 .4298 .74368 .43867 .75908 .43387 .75218 .42496 Mtetra
.75218 .42496 .75908 .43387 .77456 .42906 .76773 .4201 Mtetra
.76773 .4201 .77456 .42906 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.65 .765 .933 r
.32911 .7497 .33803 .75688 .35226 .7528 .34339 .74563 Mtetra
.653 .767 .933 r
.34339 .74563 .35226 .7528 .36657 .74854 .35774 .74142 Mtetra
.659 .77 .932 r
.35774 .74142 .36657 .74854 .38096 .74396 .37218 .73697 Mtetra
.67 .777 .93 r
.37218 .73697 .38096 .74396 .39545 .7388 .3867 .73209 Mtetra
.69 .79 .926 r
.3867 .73209 .39545 .7388 .41004 .73258 .40133 .72643 Mtetra
.725 .811 .918 r
.40133 .72643 .41004 .73258 .42474 .72445 .41607 .71933 Mtetra
.778 .842 .9 r
.41607 .71933 .42474 .72445 .43957 .71301 .43093 .70968 Mtetra
.848 .879 .863 r
.43093 .70968 .43957 .71301 .45453 .69624 .44591 .69577 Mtetra
.917 .909 .798 r
.44591 .69577 .45453 .69624 .46957 .67205 .46102 .6754 Mtetra
.962 .921 .716 r
.46102 .6754 .46957 .67205 .48462 .63984 .47618 .64694 Mtetra
.978 .918 .643 r
.47618 .64694 .48462 .63984 .49955 .60256 .49129 .61141 Mtetra
.976 .918 .608 r
.49129 .61141 .49955 .60256 .51427 .56628 .50622 .57365 Mtetra
.971 .929 .632 r
.50622 .57365 .51427 .56628 .52881 .53637 .52093 .53995 Mtetra
.957 .944 .713 r
.52093 .53995 .52881 .53637 .54324 .51446 .5355 .51394 Mtetra
.912 .933 .811 r
.5355 .51394 .54324 .51446 .55767 .49926 .55001 .49555 Mtetra
.839 .886 .874 r
.55001 .49555 .55767 .49926 .57214 .4886 .56454 .4828 Mtetra
.771 .834 .9 r
.56454 .4828 .57214 .4886 .58669 .48066 .57914 .47362 Mtetra
.725 .795 .907 r
.57914 .47362 .58669 .48066 .60132 .47425 .59382 .4665 Mtetra
.697 .771 .909 r
.59382 .4665 .60132 .47425 .61603 .46867 .60858 .46051 Mtetra
.681 .757 .909 r
.60858 .46051 .61603 .46867 .63083 .46352 .62343 .45512 Mtetra
.673 .75 .908 r
.62343 .45512 .63083 .46352 .64572 .45859 .63836 .45004 Mtetra
.668 .746 .908 r
.63836 .45004 .64572 .45859 .66068 .45376 .65338 .44511 Mtetra
.666 .744 .908 r
.65338 .44511 .66068 .45376 .67572 .44898 .66848 .44025 Mtetra
.665 .743 .908 r
.66848 .44025 .67572 .44898 .69085 .4442 .68366 .43541 Mtetra
.664 .742 .908 r
.68366 .43541 .69085 .4442 .70606 .43942 .69893 .43057 Mtetra
.69893 .43057 .70606 .43942 .72135 .43462 .71427 .42572 Mtetra
.664 .741 .908 r
.71427 .42572 .72135 .43462 .73673 .4298 .72971 .42085 Mtetra
.72971 .42085 .73673 .4298 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .4201 .76082 .41105 Mtetra
.76082 .41105 .76773 .4201 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.649 .764 .933 r
.32011 .74244 .32911 .7497 .34339 .74563 .33442 .73836 Mtetra
.651 .765 .933 r
.33442 .73836 .34339 .74563 .35774 .74142 .34882 .73417 Mtetra
.655 .768 .932 r
.34882 .73417 .35774 .74142 .37218 .73697 .3633 .72981 Mtetra
.664 .773 .931 r
.3633 .72981 .37218 .73697 .3867 .73209 .37787 .72512 Mtetra
.679 .783 .929 r
.37787 .72512 .3867 .73209 .40133 .72643 .39254 .71985 Mtetra
.705 .799 .923 r
.39254 .71985 .40133 .72643 .41607 .71933 .40731 .71352 Mtetra
.749 .825 .911 r
.40731 .71352 .41607 .71933 .43093 .70968 .4222 .70525 Mtetra
.812 .86 .885 r
.4222 .70525 .43093 .70968 .44591 .69577 .43722 .69365 Mtetra
.884 .896 .834 r
.43722 .69365 .44591 .69577 .46102 .6754 .45237 .67668 Mtetra
.944 .917 .758 r
.45237 .67668 .46102 .6754 .47618 .64694 .46761 .65224 Mtetra
.974 .92 .676 r
.46761 .65224 .47618 .64694 .49129 .61141 .48286 .61972 Mtetra
.978 .917 .619 r
.48286 .61972 .49129 .61141 .50622 .57365 .49799 .58211 Mtetra
.974 .922 .612 r
.49799 .58211 .50622 .57365 .52093 .53995 .51291 .54552 Mtetra
.966 .938 .667 r
.51291 .54552 .52093 .53995 .5355 .51394 .52764 .51533 Mtetra
.939 .944 .764 r
.52764 .51533 .5355 .51394 .55001 .49555 .54225 .49321 Mtetra
.877 .912 .848 r
.54225 .49321 .55001 .49555 .56454 .4828 .55686 .47783 Mtetra
.803 .859 .891 r
.55686 .47783 .56454 .4828 .57914 .47362 .57151 .46702 Mtetra
.745 .812 .905 r
.57151 .46702 .57914 .47362 .59382 .4665 .58624 .45894 Mtetra
.709 .781 .908 r
.58624 .45894 .59382 .4665 .60858 .46051 .60105 .45241 Mtetra
.688 .763 .909 r
.60105 .45241 .60858 .46051 .62343 .45512 .61595 .44671 Mtetra
.676 .753 .909 r
.61595 .44671 .62343 .45512 .63836 .45004 .63094 .44144 Mtetra
.67 .747 .908 r
.63094 .44144 .63836 .45004 .65338 .44511 .64601 .43639 Mtetra
.667 .745 .908 r
.64601 .43639 .65338 .44511 .66848 .44025 .66116 .43144 Mtetra
.665 .743 .908 r
.66116 .43144 .66848 .44025 .68366 .43541 .6764 .42653 Mtetra
.665 .742 .908 r
.6764 .42653 .68366 .43541 .69893 .43057 .69172 .42164 Mtetra
.664 .742 .908 r
.69172 .42164 .69893 .43057 .71427 .42572 .70713 .41673 Mtetra
.70713 .41673 .71427 .42572 .72971 .42085 .72262 .41181 Mtetra
.664 .741 .908 r
.72262 .41181 .72971 .42085 .74522 .41596 .73819 .40687 Mtetra
.73819 .40687 .74522 .41596 .76082 .41105 .75385 .4019 Mtetra
.75385 .4019 .76082 .41105 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.648 .764 .933 r
.31101 .73508 .32011 .74244 .33442 .73836 .32537 .73099 Mtetra
.65 .765 .933 r
.32537 .73099 .33442 .73836 .34882 .73417 .33982 .72681 Mtetra
.653 .767 .933 r
.33982 .72681 .34882 .73417 .3633 .72981 .35434 .7225 Mtetra
.659 .77 .932 r
.35434 .7225 .3633 .72981 .37787 .72512 .36896 .71795 Mtetra
.67 .777 .93 r
.36896 .71795 .37787 .72512 .39254 .71985 .38367 .71296 Mtetra
.69 .79 .926 r
.38367 .71296 .39254 .71985 .40731 .71352 .39848 .70717 Mtetra
.725 .811 .918 r
.39848 .70717 .40731 .71352 .4222 .70525 .4134 .69994 Mtetra
.778 .842 .9 r
.4134 .69994 .4222 .70525 .43722 .69365 .42844 .69015 Mtetra
.848 .879 .863 r
.42844 .69015 .43722 .69365 .45237 .67668 .44363 .67606 Mtetra
.917 .909 .798 r
.44363 .67606 .45237 .67668 .46761 .65224 .45893 .65547 Mtetra
.962 .921 .716 r
.45893 .65547 .46761 .65224 .48286 .61972 .4743 .62673 Mtetra
.978 .918 .642 r
.4743 .62673 .48286 .61972 .49799 .58211 .48961 .59087 Mtetra
.976 .918 .608 r
.48961 .59087 .49799 .58211 .51291 .54552 .50474 .55278 Mtetra
.971 .929 .632 r
.50474 .55278 .51291 .54552 .52764 .51533 .51965 .51878 Mtetra
.957 .944 .714 r
.51965 .51878 .52764 .51533 .54225 .49321 .5344 .49253 Mtetra
.912 .932 .811 r
.5344 .49253 .54225 .49321 .55686 .47783 .5491 .47394 Mtetra
.839 .886 .874 r
.5491 .47394 .55686 .47783 .57151 .46702 .56381 .46103 Mtetra
.771 .833 .9 r
.56381 .46103 .57151 .46702 .58624 .45894 .57859 .4517 Mtetra
.725 .795 .907 r
.57859 .4517 .58624 .45894 .60105 .45241 .59346 .44444 Mtetra
.697 .771 .909 r
.59346 .44444 .60105 .45241 .61595 .44671 .6084 .43833 Mtetra
.681 .757 .909 r
.6084 .43833 .61595 .44671 .63094 .44144 .62344 .43282 Mtetra
.673 .75 .908 r
.62344 .43282 .63094 .44144 .64601 .43639 .63856 .42761 Mtetra
.668 .746 .908 r
.63856 .42761 .64601 .43639 .66116 .43144 .65377 .42256 Mtetra
.666 .744 .908 r
.65377 .42256 .66116 .43144 .6764 .42653 .66906 .41758 Mtetra
.665 .743 .908 r
.66906 .41758 .6764 .42653 .69172 .42164 .68444 .41262 Mtetra
.664 .742 .908 r
.68444 .41262 .69172 .42164 .70713 .41673 .69991 .40766 Mtetra
.69991 .40766 .70713 .41673 .72262 .41181 .71545 .40268 Mtetra
.664 .741 .908 r
.71545 .40268 .72262 .41181 .73819 .40687 .73109 .39769 Mtetra
.73109 .39769 .73819 .40687 .75385 .4019 .74681 .39267 Mtetra
.74681 .39267 .75385 .4019 .7696 .39691 .76262 .38762 Mtetra
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.647 .763 .934 r
.30182 .72765 .31101 .73508 .32537 .73099 .31623 .72354 Mtetra
.649 .764 .933 r
.31623 .72354 .32537 .73099 .33982 .72681 .33072 .71935 Mtetra
.651 .765 .933 r
.33072 .71935 .33982 .72681 .35434 .7225 .3453 .71506 Mtetra
.655 .768 .932 r
.3453 .71506 .35434 .7225 .36896 .71795 .35996 .71059 Mtetra
.664 .773 .931 r
.35996 .71059 .36896 .71795 .38367 .71296 .37471 .7058 Mtetra
.679 .783 .929 r
.37471 .7058 .38367 .71296 .39848 .70717 .38956 .70041 Mtetra
.705 .799 .923 r
.38956 .70041 .39848 .70717 .4134 .69994 .40451 .69395 Mtetra
.749 .825 .911 r
.40451 .69395 .4134 .69994 .42844 .69015 .41959 .68555 Mtetra
.812 .86 .885 r
.41959 .68555 .42844 .69015 .44363 .67606 .4348 .67378 Mtetra
.884 .896 .834 r
.4348 .67378 .44363 .67606 .45893 .65547 .45015 .65661 Mtetra
.944 .918 .758 r
.45015 .65661 .45893 .65547 .4743 .62673 .4656 .63191 Mtetra
.974 .92 .676 r
.4656 .63191 .4743 .62673 .48961 .59087 .48106 .59909 Mtetra
.978 .917 .619 r
.48106 .59909 .48961 .59087 .50474 .55278 .4964 .56114 Mtetra
.974 .922 .612 r
.4964 .56114 .50474 .55278 .51965 .51878 .51152 .52423 Mtetra
.966 .938 .667 r
.51152 .52423 .51965 .51878 .5344 .49253 .52643 .49376 Mtetra
.939 .943 .764 r
.52643 .49376 .5344 .49253 .5491 .47394 .54124 .47142 Mtetra
.877 .912 .848 r
.54124 .47142 .5491 .47394 .56381 .46103 .55603 .45586 Mtetra
.803 .859 .891 r
.55603 .45586 .56381 .46103 .57859 .4517 .57087 .44489 Mtetra
.745 .812 .905 r
.57087 .44489 .57859 .4517 .59346 .44444 .58578 .43668 Mtetra
.709 .781 .908 r
.58578 .43668 .59346 .44444 .6084 .43833 .60078 .43002 Mtetra
.688 .763 .909 r
.60078 .43002 .6084 .43833 .62344 .43282 .61587 .42419 Mtetra
.676 .753 .909 r
.61587 .42419 .62344 .43282 .63856 .42761 .63104 .41879 Mtetra
.67 .747 .908 r
.63104 .41879 .63856 .42761 .65377 .42256 .64631 .41362 Mtetra
.667 .745 .908 r
.64631 .41362 .65377 .42256 .66906 .41758 .66166 .40855 Mtetra
.665 .743 .908 r
.66166 .40855 .66906 .41758 .68444 .41262 .67709 .40351 Mtetra
.665 .742 .908 r
.67709 .40351 .68444 .41262 .69991 .40766 .69261 .39849 Mtetra
.664 .742 .908 r
.69261 .39849 .69991 .40766 .71545 .40268 .70822 .39346 Mtetra
.70822 .39346 .71545 .40268 .73109 .39769 .72391 .38841 Mtetra
.664 .741 .908 r
.72391 .38841 .73109 .39769 .74681 .39267 .73969 .38334 Mtetra
.73969 .38334 .74681 .39267 .76262 .38762 .75556 .37824 Mtetra
.75556 .37824 .76262 .38762 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.647 .763 .934 r
.29254 .72014 .30182 .72765 .31623 .72354 .307 .71599 Mtetra
.648 .764 .933 r
.307 .71599 .31623 .72354 .33072 .71935 .32154 .71179 Mtetra
.65 .765 .933 r
.32154 .71179 .33072 .71935 .3453 .71506 .33616 .70751 Mtetra
.653 .767 .933 r
.33616 .70751 .3453 .71506 .35996 .71059 .35086 .70309 Mtetra
.659 .77 .932 r
.35086 .70309 .35996 .71059 .37471 .7058 .36566 .69843 Mtetra
.67 .777 .93 r
.36566 .69843 .37471 .7058 .38956 .70041 .38055 .69332 Mtetra
.69 .79 .926 r
.38055 .69332 .38956 .70041 .40451 .69395 .39554 .68742 Mtetra
.725 .811 .918 r
.39554 .68742 .40451 .69395 .41959 .68555 .41066 .68006 Mtetra
.778 .842 .9 r
.41066 .68006 .41959 .68555 .4348 .67378 .4259 .67011 Mtetra
.848 .879 .863 r
.4259 .67011 .4348 .67378 .45015 .65661 .44128 .65584 Mtetra
.917 .909 .798 r
.44128 .65584 .45015 .65661 .4656 .63191 .45679 .63501 Mtetra
.963 .921 .715 r
.45679 .63501 .4656 .63191 .48106 .59909 .47236 .60599 Mtetra
.978 .918 .642 r
.47236 .60599 .48106 .59909 .4964 .56114 .48788 .5698 Mtetra
.976 .918 .608 r
.48788 .5698 .4964 .56114 .51152 .52423 .50322 .53137 Mtetra
.971 .929 .632 r
.50322 .53137 .51152 .52423 .52643 .49376 .51833 .49707 Mtetra
.957 .944 .714 r
.51833 .49707 .52643 .49376 .54124 .47142 .53328 .47057 Mtetra
.912 .932 .811 r
.53328 .47057 .54124 .47142 .55603 .45586 .54816 .45178 Mtetra
.839 .886 .874 r
.54816 .45178 .55603 .45586 .57087 .44489 .56307 .4387 Mtetra
.771 .833 .9 r
.56307 .4387 .57087 .44489 .58578 .43668 .57803 .42922 Mtetra
.725 .795 .907 r
.57803 .42922 .58578 .43668 .60078 .43002 .59308 .42183 Mtetra
.697 .771 .909 r
.59308 .42183 .60078 .43002 .61587 .42419 .60822 .41558 Mtetra
.681 .757 .909 r
.60822 .41558 .61587 .42419 .63104 .41879 .62345 .40994 Mtetra
.673 .75 .908 r
.62345 .40994 .63104 .41879 .64631 .41362 .63877 .40461 Mtetra
.668 .746 .908 r
.63877 .40461 .64631 .41362 .66166 .40855 .65417 .39944 Mtetra
.666 .744 .908 r
.65417 .39944 .66166 .40855 .67709 .40351 .66967 .39433 Mtetra
.665 .743 .908 r
.66967 .39433 .67709 .40351 .69261 .39849 .68524 .38924 Mtetra
.664 .742 .908 r
.68524 .38924 .69261 .39849 .70822 .39346 .70091 .38415 Mtetra
.70091 .38415 .70822 .39346 .72391 .38841 .71666 .37904 Mtetra
.664 .741 .908 r
.71666 .37904 .72391 .38841 .73969 .38334 .73251 .37392 Mtetra
.73251 .37392 .73969 .38334 .75556 .37824 .74844 .36877 Mtetra
.74844 .36877 .75556 .37824 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.647 .763 .934 r
.28317 .71254 .29254 .72014 .307 .71599 .29767 .70837 Mtetra
.29767 .70837 .307 .71599 .32154 .71179 .31226 .70414 Mtetra
.649 .764 .933 r
.31226 .70414 .32154 .71179 .33616 .70751 .32692 .69985 Mtetra
.651 .765 .933 r
.32692 .69985 .33616 .70751 .35086 .70309 .34168 .69546 Mtetra
.655 .768 .932 r
.34168 .69546 .35086 .70309 .36566 .69843 .35652 .69087 Mtetra
.664 .773 .931 r
.35652 .69087 .36566 .69843 .38055 .69332 .37146 .68596 Mtetra
.679 .783 .929 r
.37146 .68596 .38055 .69332 .39554 .68742 .38649 .68046 Mtetra
.705 .799 .923 r
.38649 .68046 .39554 .68742 .41066 .68006 .40164 .67387 Mtetra
.749 .825 .911 r
.40164 .67387 .41066 .68006 .4259 .67011 .41691 .66532 Mtetra
.812 .861 .885 r
.41691 .66532 .4259 .67011 .44128 .65584 .43232 .65339 Mtetra
.884 .896 .834 r
.43232 .65339 .44128 .65584 .45679 .63501 .44787 .63601 Mtetra
.944 .918 .757 r
.44787 .63601 .45679 .63501 .47236 .60599 .46353 .61105 Mtetra
.974 .921 .675 r
.46353 .61105 .47236 .60599 .48788 .5698 .47921 .57791 Mtetra
.978 .917 .619 r
.47921 .57791 .48788 .5698 .50322 .53137 .49476 .53962 Mtetra
.974 .922 .612 r
.49476 .53962 .50322 .53137 .51833 .49707 .51008 .50239 Mtetra
.966 .938 .668 r
.51008 .50239 .51833 .49707 .53328 .47057 .5252 .47164 Mtetra
.939 .943 .765 r
.5252 .47164 .53328 .47057 .54816 .45178 .5402 .44907 Mtetra
.877 .912 .848 r
.5402 .44907 .54816 .45178 .56307 .4387 .55518 .43333 Mtetra
.803 .858 .89 r
.55518 .43333 .56307 .4387 .57803 .42922 .57021 .4222 Mtetra
.745 .812 .905 r
.57021 .4222 .57803 .42922 .59308 .42183 .58531 .41385 Mtetra
.709 .781 .908 r
.58531 .41385 .59308 .42183 .60822 .41558 .6005 .40705 Mtetra
.688 .763 .909 r
.6005 .40705 .60822 .41558 .62345 .40994 .61578 .40109 Mtetra
.676 .753 .909 r
.61578 .40109 .62345 .40994 .63877 .40461 .63115 .39556 Mtetra
.67 .747 .908 r
.63115 .39556 .63877 .40461 .65417 .39944 .64661 .39026 Mtetra
.667 .745 .908 r
.64661 .39026 .65417 .39944 .66967 .39433 .66216 .38506 Mtetra
.665 .743 .908 r
.66216 .38506 .66967 .39433 .68524 .38924 .6778 .37989 Mtetra
.665 .742 .908 r
.6778 .37989 .68524 .38924 .70091 .38415 .69353 .37474 Mtetra
.664 .742 .908 r
.69353 .37474 .70091 .38415 .71666 .37904 .70934 .36958 Mtetra
.70934 .36958 .71666 .37904 .73251 .37392 .72524 .3644 Mtetra
.664 .741 .908 r
.72524 .3644 .73251 .37392 .74844 .36877 .74124 .35919 Mtetra
.74124 .35919 .74844 .36877 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .763 .934 r
.2737 .70487 .28317 .71254 .29767 .70837 .28825 .70066 Mtetra
.647 .763 .934 r
.28825 .70066 .29767 .70837 .31226 .70414 .30288 .69641 Mtetra
.648 .764 .933 r
.30288 .69641 .31226 .70414 .32692 .69985 .3176 .6921 Mtetra
.65 .765 .933 r
.3176 .6921 .32692 .69985 .34168 .69546 .3324 .6877 Mtetra
.653 .767 .933 r
.3324 .6877 .34168 .69546 .35652 .69087 .34729 .68317 Mtetra
.659 .77 .932 r
.34729 .68317 .35652 .69087 .37146 .68596 .36227 .67839 Mtetra
.67 .777 .93 r
.36227 .67839 .37146 .68596 .38649 .68046 .37735 .67317 Mtetra
.69 .79 .926 r
.37735 .67317 .38649 .68046 .40164 .67387 .39254 .66714 Mtetra
.725 .811 .918 r
.39254 .66714 .40164 .67387 .41691 .66532 .40784 .65964 Mtetra
.778 .842 .9 r
.40784 .65964 .41691 .66532 .43232 .65339 .42328 .64954 Mtetra
.848 .879 .863 r
.42328 .64954 .43232 .65339 .44787 .63601 .43887 .63508 Mtetra
.917 .91 .798 r
.43887 .63508 .44787 .63601 .46353 .61105 .45459 .61401 Mtetra
.963 .921 .715 r
.45459 .61401 .46353 .61105 .47921 .57791 .47038 .5847 Mtetra
.978 .919 .642 r
.47038 .5847 .47921 .57791 .49476 .53962 .48612 .54818 Mtetra
.976 .918 .608 r
.48612 .54818 .49476 .53962 .51008 .50239 .50167 .50941 Mtetra
.971 .929 .632 r
.50167 .50941 .51008 .50239 .5252 .47164 .51699 .47479 Mtetra
.957 .944 .714 r
.51699 .47479 .5252 .47164 .5402 .44907 .53213 .44804 Mtetra
.912 .932 .811 r
.53213 .44804 .5402 .44907 .55518 .43333 .54721 .42905 Mtetra
.839 .886 .874 r
.54721 .42905 .55518 .43333 .57021 .4222 .5623 .41579 Mtetra
.771 .833 .9 r
.5623 .41579 .57021 .4222 .58531 .41385 .57746 .40616 Mtetra
.725 .795 .907 r
.57746 .40616 .58531 .41385 .6005 .40705 .5927 .39863 Mtetra
.697 .771 .909 r
.5927 .39863 .6005 .40705 .61578 .40109 .60804 .39225 Mtetra
.681 .757 .909 r
.60804 .39225 .61578 .40109 .63115 .39556 .62346 .38648 Mtetra
.673 .75 .908 r
.62346 .38648 .63115 .39556 .64661 .39026 .63898 .38102 Mtetra
.668 .746 .908 r
.63898 .38102 .64661 .39026 .66216 .38506 .65459 .37571 Mtetra
.666 .744 .908 r
.65459 .37571 .66216 .38506 .6778 .37989 .67028 .37046 Mtetra
.665 .743 .908 r
.67028 .37046 .6778 .37989 .69353 .37474 .68607 .36524 Mtetra
.664 .742 .908 r
.68607 .36524 .69353 .37474 .70934 .36958 .70194 .36002 Mtetra
.70194 .36002 .70934 .36958 .72524 .3644 .71791 .35478 Mtetra
.664 .741 .908 r
.71791 .35478 .72524 .3644 .74124 .35919 .73396 .34952 Mtetra
.73396 .34952 .74124 .35919 .75732 .35396 .75011 .34423 Mtetra
.75011 .34423 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .763 .934 r
.26413 .69712 .2737 .70487 .28825 .70066 .27873 .69286 Mtetra
.647 .763 .934 r
.27873 .69286 .28825 .70066 .30288 .69641 .29341 .68858 Mtetra
.29341 .68858 .30288 .69641 .3176 .6921 .30818 .68424 Mtetra
.649 .764 .933 r
.30818 .68424 .3176 .6921 .3324 .6877 .32303 .67984 Mtetra
.651 .765 .933 r
.32303 .67984 .3324 .6877 .34729 .68317 .33796 .67533 Mtetra
.655 .768 .932 r
.33796 .67533 .34729 .68317 .36227 .67839 .35299 .67063 Mtetra
.664 .773 .931 r
.35299 .67063 .36227 .67839 .37735 .67317 .36812 .6656 Mtetra
.679 .783 .929 r
.36812 .6656 .37735 .67317 .39254 .66714 .38335 .65998 Mtetra
.705 .799 .923 r
.38335 .65998 .39254 .66714 .40784 .65964 .39869 .65325 Mtetra
.749 .825 .911 r
.39869 .65325 .40784 .65964 .42328 .64954 .41416 .64456 Mtetra
.812 .861 .885 r
.41416 .64456 .42328 .64954 .43887 .63508 .42978 .63245 Mtetra
.884 .897 .834 r
.42978 .63245 .43887 .63508 .45459 .61401 .44554 .61486 Mtetra
.944 .918 .757 r
.44554 .61486 .45459 .61401 .47038 .5847 .46141 .58963 Mtetra
.974 .921 .675 r
.46141 .58963 .47038 .5847 .48612 .54818 .47731 .55618 Mtetra
.978 .917 .619 r
.47731 .55618 .48612 .54818 .50167 .50941 .49308 .51754 Mtetra
.974 .922 .612 r
.49308 .51754 .50167 .50941 .51699 .47479 .50862 .47997 Mtetra
.966 .938 .668 r
.50862 .47997 .51699 .47479 .53213 .44804 .52393 .44895 Mtetra
.939 .943 .765 r
.52393 .44895 .53213 .44804 .54721 .42905 .53913 .42614 Mtetra
.877 .912 .848 r
.53913 .42614 .54721 .42905 .5623 .41579 .55431 .41021 Mtetra
.803 .858 .89 r
.55431 .41021 .5623 .41579 .57746 .40616 .56953 .39892 Mtetra
.745 .812 .905 r
.56953 .39892 .57746 .40616 .5927 .39863 .58483 .39042 Mtetra
.709 .781 .908 r
.58483 .39042 .5927 .39863 .60804 .39225 .60021 .38348 Mtetra
.688 .763 .909 r
.60021 .38348 .60804 .39225 .62346 .38648 .61569 .37738 Mtetra
.676 .753 .909 r
.61569 .37738 .62346 .38648 .63898 .38102 .63127 .37172 Mtetra
.67 .747 .908 r
.63127 .37172 .63898 .38102 .65459 .37571 .64693 .36629 Mtetra
.667 .745 .908 r
.64693 .36629 .65459 .37571 .67028 .37046 .66268 .36095 Mtetra
.665 .743 .908 r
.66268 .36095 .67028 .37046 .68607 .36524 .67853 .35565 Mtetra
.665 .742 .908 r
.67853 .35565 .68607 .36524 .70194 .36002 .69446 .35036 Mtetra
.664 .742 .908 r
.69446 .35036 .70194 .36002 .71791 .35478 .71049 .34506 Mtetra
.71049 .34506 .71791 .35478 .73396 .34952 .72661 .33974 Mtetra
.664 .741 .908 r
.72661 .33974 .73396 .34952 .75011 .34423 .74282 .3344 Mtetra
.74282 .3344 .75011 .34423 .76634 .33891 .75912 .32902 Mtetra
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.646 .763 .934 r
.25446 .68928 .26413 .69712 .27873 .69286 .26911 .68499 Mtetra
.26911 .68499 .27873 .69286 .29341 .68858 .28384 .68066 Mtetra
.647 .763 .934 r
.28384 .68066 .29341 .68858 .30818 .68424 .29866 .6763 Mtetra
.648 .764 .933 r
.29866 .6763 .30818 .68424 .32303 .67984 .31356 .67188 Mtetra
.65 .765 .933 r
.31356 .67188 .32303 .67984 .33796 .67533 .32854 .66737 Mtetra
.653 .767 .933 r
.32854 .66737 .33796 .67533 .35299 .67063 .34362 .66272 Mtetra
.659 .77 .932 r
.34362 .66272 .35299 .67063 .36812 .6656 .35879 .65782 Mtetra
.67 .778 .93 r
.35879 .65782 .36812 .6656 .38335 .65998 .37406 .65247 Mtetra
.69 .79 .926 r
.37406 .65247 .38335 .65998 .39869 .65325 .38945 .64631 Mtetra
.725 .811 .918 r
.38945 .64631 .39869 .65325 .41416 .64456 .40495 .63867 Mtetra
.778 .842 .9 r
.40495 .63867 .41416 .64456 .42978 .63245 .4206 .62841 Mtetra
.848 .88 .863 r
.4206 .62841 .42978 .63245 .44554 .61486 .43639 .61375 Mtetra
.917 .91 .798 r
.43639 .61375 .44554 .61486 .46141 .58963 .45233 .59245 Mtetra
.963 .921 .715 r
.45233 .59245 .46141 .58963 .47731 .55618 .46834 .56284 Mtetra
.978 .919 .642 r
.46834 .56284 .47731 .55618 .49308 .51754 .4843 .52598 Mtetra
.976 .918 .608 r
.4843 .52598 .49308 .51754 .50862 .47997 .50007 .48686 Mtetra
.971 .929 .633 r
.50007 .48686 .50862 .47997 .52393 .44895 .5156 .45194 Mtetra
.957 .944 .714 r
.5156 .45194 .52393 .44895 .53913 .42614 .53095 .42493 Mtetra
.912 .932 .811 r
.53095 .42493 .53913 .42614 .55431 .41021 .54622 .40572 Mtetra
.839 .885 .874 r
.54622 .40572 .55431 .41021 .56953 .39892 .56151 .39229 Mtetra
.771 .833 .9 r
.56151 .39229 .56953 .39892 .58483 .39042 .57687 .3825 Mtetra
.725 .794 .907 r
.57687 .3825 .58483 .39042 .60021 .38348 .59231 .37483 Mtetra
.697 .771 .909 r
.59231 .37483 .60021 .38348 .61569 .37738 .60785 .36831 Mtetra
.681 .757 .909 r
.60785 .36831 .61569 .37738 .63127 .37172 .62347 .3624 Mtetra
.673 .75 .908 r
.62347 .3624 .63127 .37172 .64693 .36629 .6392 .3568 Mtetra
.668 .746 .908 r
.6392 .3568 .64693 .36629 .66268 .36095 .65501 .35135 Mtetra
.666 .744 .908 r
.65501 .35135 .66268 .36095 .67853 .35565 .67091 .34597 Mtetra
.665 .743 .908 r
.67091 .34597 .67853 .35565 .69446 .35036 .68691 .34061 Mtetra
.664 .742 .908 r
.68691 .34061 .69446 .35036 .71049 .34506 .703 .33525 Mtetra
.703 .33525 .71049 .34506 .72661 .33974 .71918 .32987 Mtetra
.664 .741 .908 r
.71918 .32987 .72661 .33974 .74282 .3344 .73545 .32446 Mtetra
.73545 .32446 .74282 .3344 .75912 .32902 .75182 .31903 Mtetra
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .763 .934 r
.2447 .68136 .25446 .68928 .26911 .68499 .2594 .67703 Mtetra
.2594 .67703 .26911 .68499 .28384 .68066 .27417 .67266 Mtetra
.647 .763 .934 r
.27417 .67266 .28384 .68066 .29866 .6763 .28904 .66826 Mtetra
.28904 .66826 .29866 .6763 .31356 .67188 .30399 .66381 Mtetra
.649 .764 .933 r
.30399 .66381 .31356 .67188 .32854 .66737 .31902 .6593 Mtetra
.651 .766 .933 r
.31902 .6593 .32854 .66737 .34362 .66272 .33415 .65467 Mtetra
.655 .768 .932 r
.33415 .65467 .34362 .66272 .35879 .65782 .34937 .64985 Mtetra
.664 .773 .931 r
.34937 .64985 .35879 .65782 .37406 .65247 .36469 .6447 Mtetra
.679 .783 .929 r
.36469 .6447 .37406 .65247 .38945 .64631 .38011 .63894 Mtetra
.705 .799 .923 r
.38011 .63894 .38945 .64631 .40495 .63867 .39566 .63208 Mtetra
.749 .825 .911 r
.39566 .63208 .40495 .63867 .4206 .62841 .41133 .62323 Mtetra
.812 .861 .885 r
.41133 .62323 .4206 .62841 .43639 .61375 .42716 .61094 Mtetra
.884 .897 .834 r
.42716 .61094 .43639 .61375 .45233 .59245 .44314 .59314 Mtetra
.944 .918 .757 r
.44314 .59314 .45233 .59245 .46834 .56284 .45924 .56764 Mtetra
.974 .921 .675 r
.45924 .56764 .46834 .56284 .4843 .52598 .47536 .53386 Mtetra
.978 .917 .618 r
.47536 .53386 .4843 .52598 .50007 .48686 .49135 .49487 Mtetra
.974 .922 .612 r
.49135 .49487 .50007 .48686 .5156 .45194 .50711 .45697 Mtetra
.966 .938 .668 r
.50711 .45697 .5156 .45194 .53095 .42493 .52264 .42565 Mtetra
.939 .943 .765 r
.52264 .42565 .53095 .42493 .54622 .40572 .53804 .40261 Mtetra
.877 .911 .848 r
.53804 .40261 .54622 .40572 .56151 .39229 .55341 .38649 Mtetra
.803 .858 .89 r
.55341 .38649 .56151 .39229 .57687 .3825 .56883 .37503 Mtetra
.745 .812 .905 r
.56883 .37503 .57687 .3825 .59231 .37483 .58433 .36637 Mtetra
.709 .781 .908 r
.58433 .36637 .59231 .37483 .60785 .36831 .59992 .35929 Mtetra
.688 .763 .909 r
.59992 .35929 .60785 .36831 .62347 .3624 .6156 .35305 Mtetra
.676 .753 .909 r
.6156 .35305 .62347 .3624 .6392 .3568 .63138 .34725 Mtetra
.67 .747 .908 r
.63138 .34725 .6392 .3568 .65501 .35135 .64725 .34168 Mtetra
.667 .745 .908 r
.64725 .34168 .65501 .35135 .67091 .34597 .66322 .3362 Mtetra
.665 .743 .908 r
.66322 .3362 .67091 .34597 .68691 .34061 .67928 .33076 Mtetra
.665 .742 .908 r
.67928 .33076 .68691 .34061 .703 .33525 .69543 .32533 Mtetra
.664 .742 .908 r
.69543 .32533 .703 .33525 .71918 .32987 .71167 .31989 Mtetra
.71167 .31989 .71918 .32987 .73545 .32446 .72801 .31442 Mtetra
.664 .741 .908 r
.72801 .31442 .73545 .32446 .75182 .31903 .74444 .30893 Mtetra
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Mtetra
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Mtetra
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68136 .2594 .67703 .24958 .66898 Mtetra
.646 .763 .934 r
.24958 .66898 .2594 .67703 .27417 .67266 .26441 .66458 Mtetra
.26441 .66458 .27417 .67266 .28904 .66826 .27932 .66014 Mtetra
.647 .763 .934 r
.27932 .66014 .28904 .66826 .30399 .66381 .29432 .65565 Mtetra
.648 .764 .933 r
.29432 .65565 .30399 .66381 .31902 .6593 .30941 .65111 Mtetra
.65 .765 .933 r
.30941 .65111 .31902 .6593 .33415 .65467 .32458 .64649 Mtetra
.653 .767 .933 r
.32458 .64649 .33415 .65467 .34937 .64985 .33985 .64171 Mtetra
.659 .77 .932 r
.33985 .64171 .34937 .64985 .36469 .6447 .35522 .63669 Mtetra
.67 .778 .93 r
.35522 .63669 .36469 .6447 .38011 .63894 .37069 .63122 Mtetra
.69 .79 .926 r
.37069 .63122 .38011 .63894 .39566 .63208 .38627 .62492 Mtetra
.725 .811 .918 r
.38627 .62492 .39566 .63208 .41133 .62323 .40198 .61713 Mtetra
.778 .842 .901 r
.40198 .61713 .41133 .62323 .42716 .61094 .41784 .60671 Mtetra
.848 .88 .863 r
.41784 .60671 .42716 .61094 .44314 .59314 .43385 .59185 Mtetra
.917 .91 .798 r
.43385 .59185 .44314 .59314 .45924 .56764 .45001 .5703 Mtetra
.963 .921 .715 r
.45001 .5703 .45924 .56764 .47536 .53386 .46625 .54039 Mtetra
.978 .919 .642 r
.46625 .54039 .47536 .53386 .49135 .49487 .48244 .50319 Mtetra
.976 .918 .608 r
.48244 .50319 .49135 .49487 .50711 .45697 .49844 .46372 Mtetra
.971 .929 .633 r
.49844 .46372 .50711 .45697 .52264 .42565 .51418 .42847 Mtetra
.957 .944 .715 r
.51418 .42847 .52264 .42565 .53804 .40261 .52973 .4012 Mtetra
.912 .932 .811 r
.52973 .4012 .53804 .40261 .55341 .38649 .54521 .38178 Mtetra
.839 .885 .874 r
.54521 .38178 .55341 .38649 .56883 .37503 .56071 .36816 Mtetra
.771 .833 .9 r
.56071 .36816 .56883 .37503 .58433 .36637 .57627 .35822 Mtetra
.725 .794 .907 r
.57627 .35822 .58433 .36637 .59992 .35929 .59191 .35039 Mtetra
.697 .771 .909 r
.59191 .35039 .59992 .35929 .6156 .35305 .60765 .34372 Mtetra
.681 .757 .909 r
.60765 .34372 .6156 .35305 .63138 .34725 .62349 .33767 Mtetra
.673 .75 .908 r
.62349 .33767 .63138 .34725 .64725 .34168 .63942 .33193 Mtetra
.668 .746 .908 r
.63942 .33193 .64725 .34168 .66322 .3362 .65544 .32634 Mtetra
.666 .744 .908 r
.65544 .32634 .66322 .3362 .67928 .33076 .67156 .32082 Mtetra
.665 .743 .908 r
.67156 .32082 .67928 .33076 .69543 .32533 .68778 .31531 Mtetra
.664 .742 .908 r
.68778 .31531 .69543 .32533 .71167 .31989 .70409 .3098 Mtetra
.70409 .3098 .71167 .31989 .72801 .31442 .72049 .30428 Mtetra
.664 .741 .908 r
.72049 .30428 .72801 .31442 .74444 .30893 .73699 .29873 Mtetra
.73699 .29873 .74444 .30893 .76097 .30341 .75358 .29315 Mtetra
.75358 .29315 .76097 .30341 .7776 .29786 .77027 .28754 Mtetra
.77027 .28754 .7776 .29786 .79432 .29228 .78706 .2819 Mtetra
.78706 .2819 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66898 .23965 .66085 Mtetra
.646 .763 .934 r
.23965 .66085 .24958 .66898 .26441 .66458 .25453 .6564 Mtetra
.25453 .6564 .26441 .66458 .27932 .66014 .2695 .65192 Mtetra
.647 .763 .934 r
.2695 .65192 .27932 .66014 .29432 .65565 .28455 .6474 Mtetra
.28455 .6474 .29432 .65565 .30941 .65111 .29969 .64283 Mtetra
.649 .764 .933 r
.29969 .64283 .30941 .65111 .32458 .64649 .31491 .63819 Mtetra
.651 .766 .933 r
.31491 .63819 .32458 .64649 .33985 .64171 .33023 .63344 Mtetra
.655 .768 .932 r
.33023 .63344 .33985 .64171 .35522 .63669 .34565 .6285 Mtetra
.664 .773 .931 r
.34565 .6285 .35522 .63669 .37069 .63122 .36117 .62322 Mtetra
.679 .783 .929 r
.36117 .62322 .37069 .63122 .38627 .62492 .3768 .61733 Mtetra
.705 .799 .923 r
.3768 .61733 .38627 .62492 .40198 .61713 .39254 .61032 Mtetra
.749 .826 .911 r
.39254 .61032 .40198 .61713 .41784 .60671 .40843 .60132 Mtetra
.812 .861 .885 r
.40843 .60132 .41784 .60671 .43385 .59185 .42447 .58884 Mtetra
.884 .897 .834 r
.42447 .58884 .43385 .59185 .45001 .5703 .44067 .57082 Mtetra
.944 .918 .757 r
.44067 .57082 .45001 .5703 .46625 .54039 .457 .54504 Mtetra
.974 .921 .675 r
.457 .54504 .46625 .54039 .48244 .50319 .47335 .51093 Mtetra
.978 .917 .618 r
.47335 .51093 .48244 .50319 .49844 .46372 .48958 .47159 Mtetra
.974 .922 .612 r
.48958 .47159 .49844 .46372 .51418 .42847 .50556 .43334 Mtetra
.966 .938 .668 r
.50556 .43334 .51418 .42847 .52973 .4012 .5213 .40174 Mtetra
.939 .942 .765 r
.5213 .40174 .52973 .4012 .54521 .38178 .53691 .37846 Mtetra
.877 .911 .848 r
.53691 .37846 .54521 .38178 .56071 .36816 .55249 .36213 Mtetra
.803 .858 .89 r
.55249 .36213 .56071 .36816 .57627 .35822 .56812 .3505 Mtetra
.745 .812 .905 r
.56812 .3505 .57627 .35822 .59191 .35039 .58382 .34169 Mtetra
.709 .781 .908 r
.58382 .34169 .59191 .35039 .60765 .34372 .59962 .33445 Mtetra
.688 .763 .909 r
.59962 .33445 .60765 .34372 .62349 .33767 .61551 .32807 Mtetra
.676 .753 .909 r
.61551 .32807 .62349 .33767 .63942 .33193 .6315 .32213 Mtetra
.67 .747 .908 r
.6315 .32213 .63942 .33193 .65544 .32634 .64759 .3164 Mtetra
.667 .745 .908 r
.64759 .3164 .65544 .32634 .67156 .32082 .66377 .31078 Mtetra
.665 .743 .908 r
.66377 .31078 .67156 .32082 .68778 .31531 .68005 .3052 Mtetra
.665 .742 .908 r
.68005 .3052 .68778 .31531 .70409 .3098 .69642 .29962 Mtetra
.664 .742 .908 r
.69642 .29962 .70409 .3098 .72049 .30428 .71289 .29403 Mtetra
.71289 .29403 .72049 .30428 .73699 .29873 .72945 .28841 Mtetra
.664 .741 .908 r
.72945 .28841 .73699 .29873 .75358 .29315 .74611 .28277 Mtetra
.74611 .28277 .75358 .29315 .77027 .28754 .76287 .2771 Mtetra
.76287 .2771 .77027 .28754 .78706 .2819 .77973 .2714 Mtetra
.77973 .2714 .78706 .2819 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66085 .22963 .65263 Mtetra
.22963 .65263 .23965 .66085 .25453 .6564 .24456 .64814 Mtetra
.646 .763 .934 r
.24456 .64814 .25453 .6564 .2695 .65192 .25957 .64361 Mtetra
.25957 .64361 .2695 .65192 .28455 .6474 .27467 .63905 Mtetra
.647 .763 .934 r
.27467 .63905 .28455 .6474 .29969 .64283 .28986 .63445 Mtetra
.648 .764 .933 r
.28986 .63445 .29969 .64283 .31491 .63819 .30514 .62979 Mtetra
.65 .765 .933 r
.30514 .62979 .31491 .63819 .33023 .63344 .32051 .62503 Mtetra
.653 .767 .933 r
.32051 .62503 .33023 .63344 .34565 .6285 .33598 .62014 Mtetra
.659 .77 .932 r
.33598 .62014 .34565 .6285 .36117 .62322 .35155 .61498 Mtetra
.67 .778 .93 r
.35155 .61498 .36117 .62322 .3768 .61733 .36722 .60938 Mtetra
.69 .79 .927 r
.36722 .60938 .3768 .61733 .39254 .61032 .38301 .60294 Mtetra
.725 .811 .919 r
.38301 .60294 .39254 .61032 .40843 .60132 .39893 .595 Mtetra
.778 .843 .901 r
.39893 .595 .40843 .60132 .42447 .58884 .41501 .5844 Mtetra
.848 .88 .863 r
.41501 .5844 .42447 .58884 .44067 .57082 .43124 .56934 Mtetra
.917 .91 .798 r
.43124 .56934 .44067 .57082 .457 .54504 .44763 .54754 Mtetra
.963 .922 .715 r
.44763 .54754 .457 .54504 .47335 .51093 .4641 .51732 Mtetra
.978 .919 .641 r
.4641 .51732 .47335 .51093 .48958 .47159 .48053 .47977 Mtetra
.976 .918 .608 r
.48053 .47977 .48958 .47159 .50556 .43334 .49675 .43994 Mtetra
.971 .929 .633 r
.49675 .43994 .50556 .43334 .5213 .40174 .51272 .40438 Mtetra
.957 .944 .715 r
.51272 .40438 .5213 .40174 .53691 .37846 .52849 .37684 Mtetra
.912 .931 .811 r
.52849 .37684 .53691 .37846 .55249 .36213 .54418 .35719 Mtetra
.839 .885 .874 r
.54418 .35719 .55249 .36213 .56812 .3505 .55988 .34339 Mtetra
.771 .833 .9 r
.55988 .34339 .56812 .3505 .58382 .34169 .57564 .33328 Mtetra
.725 .794 .907 r
.57564 .33328 .58382 .34169 .59962 .33445 .5915 .3253 Mtetra
.697 .771 .909 r
.5915 .3253 .59962 .33445 .61551 .32807 .60745 .31848 Mtetra
.681 .757 .909 r
.60745 .31848 .61551 .32807 .6315 .32213 .6235 .31228 Mtetra
.673 .75 .908 r
.6235 .31228 .6315 .32213 .64759 .3164 .63965 .30639 Mtetra
.668 .746 .908 r
.63965 .30639 .64759 .3164 .66377 .31078 .65589 .30065 Mtetra
.666 .744 .908 r
.65589 .30065 .66377 .31078 .68005 .3052 .67223 .29498 Mtetra
.665 .743 .908 r
.67223 .29498 .68005 .3052 .69642 .29962 .68867 .28933 Mtetra
.664 .742 .908 r
.68867 .28933 .69642 .29962 .71289 .29403 .7052 .28367 Mtetra
.7052 .28367 .71289 .29403 .72945 .28841 .72184 .27799 Mtetra
.664 .741 .908 r
.72184 .27799 .72945 .28841 .74611 .28277 .73857 .27228 Mtetra
.73857 .27228 .74611 .28277 .76287 .2771 .75539 .26655 Mtetra
.75539 .26655 .76287 .2771 .77973 .2714 .77232 .26078 Mtetra
.77232 .26078 .77973 .2714 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65263 .2195 .64433 Mtetra
.2195 .64433 .22963 .65263 .24456 .64814 .23447 .63978 Mtetra
.646 .763 .934 r
.23447 .63978 .24456 .64814 .25957 .64361 .24954 .63521 Mtetra
.24954 .63521 .25957 .64361 .27467 .63905 .26469 .63061 Mtetra
.647 .763 .934 r
.26469 .63061 .27467 .63905 .28986 .63445 .27993 .62597 Mtetra
.27993 .62597 .28986 .63445 .30514 .62979 .29527 .62127 Mtetra
.649 .764 .933 r
.29527 .62127 .30514 .62979 .32051 .62503 .31069 .61651 Mtetra
.651 .766 .933 r
.31069 .61651 .32051 .62503 .33598 .62014 .32621 .61163 Mtetra
.655 .768 .932 r
.32621 .61163 .33598 .62014 .35155 .61498 .34183 .60656 Mtetra
.664 .773 .931 r
.34183 .60656 .35155 .61498 .36722 .60938 .35755 .60114 Mtetra
.679 .783 .929 r
.35755 .60114 .36722 .60938 .38301 .60294 .37338 .59511 Mtetra
.705 .799 .923 r
.37338 .59511 .38301 .60294 .39893 .595 .38934 .58796 Mtetra
.749 .826 .911 r
.38934 .58796 .39893 .595 .41501 .5844 .40545 .57879 Mtetra
.812 .861 .885 r
.40545 .57879 .41501 .5844 .43124 .56934 .42171 .56613 Mtetra
.884 .897 .834 r
.42171 .56613 .43124 .56934 .44763 .54754 .43814 .54787 Mtetra
.944 .919 .757 r
.43814 .54787 .44763 .54754 .4641 .51732 .4547 .52181 Mtetra
.974 .921 .675 r
.4547 .52181 .4641 .51732 .48053 .47977 .47129 .48737 Mtetra
.978 .917 .618 r
.47129 .48737 .48053 .47977 .49675 .43994 .48775 .44767 Mtetra
.974 .922 .613 r
.48775 .44767 .49675 .43994 .51272 .40438 .50397 .40908 Mtetra
.966 .938 .669 r
.50397 .40908 .51272 .40438 .52849 .37684 .51993 .37717 Mtetra
.939 .942 .765 r
.51993 .37717 .52849 .37684 .54418 .35719 .53576 .35365 Mtetra
.877 .911 .848 r
.53576 .35365 .54418 .35719 .55988 .34339 .55155 .33712 Mtetra
.803 .858 .89 r
.55155 .33712 .55988 .34339 .57564 .33328 .56738 .32531 Mtetra
.745 .812 .905 r
.56738 .32531 .57564 .33328 .5915 .3253 .5833 .31633 Mtetra
.709 .781 .908 r
.5833 .31633 .5915 .3253 .60745 .31848 .59931 .30894 Mtetra
.688 .763 .909 r
.59931 .30894 .60745 .31848 .6235 .31228 .61541 .30241 Mtetra
.676 .753 .909 r
.61541 .30241 .6235 .31228 .63965 .30639 .63162 .29631 Mtetra
.67 .747 .908 r
.63162 .29631 .63965 .30639 .65589 .30065 .64793 .29044 Mtetra
.667 .745 .908 r
.64793 .29044 .65589 .30065 .67223 .29498 .66433 .28467 Mtetra
.665 .743 .908 r
.66433 .28467 .67223 .29498 .68867 .28933 .68084 .27893 Mtetra
.665 .742 .908 r
.68084 .27893 .68867 .28933 .7052 .28367 .69744 .2732 Mtetra
.664 .742 .908 r
.69744 .2732 .7052 .28367 .72184 .27799 .71414 .26745 Mtetra
.71414 .26745 .72184 .27799 .73857 .27228 .73093 .26168 Mtetra
.664 .741 .908 r
.73093 .26168 .73857 .27228 .75539 .26655 .74783 .25588 Mtetra
.74783 .25588 .75539 .26655 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24419 Mtetra
.78193 .24419 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63978 .22428 .63134 Mtetra
.22428 .63134 .23447 .63978 .24954 .63521 .2394 .62672 Mtetra
.646 .763 .934 r
.2394 .62672 .24954 .63521 .26469 .63061 .2546 .62208 Mtetra
.2546 .62208 .26469 .63061 .27993 .62597 .2699 .61739 Mtetra
.647 .763 .934 r
.2699 .61739 .27993 .62597 .29527 .62127 .28528 .61266 Mtetra
.648 .764 .933 r
.28528 .61266 .29527 .62127 .31069 .61651 .30076 .60787 Mtetra
.65 .765 .933 r
.30076 .60787 .31069 .61651 .32621 .61163 .31633 .60299 Mtetra
.653 .767 .933 r
.31633 .60299 .32621 .61163 .34183 .60656 .332 .59796 Mtetra
.659 .771 .932 r
.332 .59796 .34183 .60656 .35755 .60114 .34778 .59267 Mtetra
.67 .778 .93 r
.34778 .59267 .35755 .60114 .37338 .59511 .36366 .58692 Mtetra
.69 .79 .927 r
.36366 .58692 .37338 .59511 .38934 .58796 .37966 .58034 Mtetra
.725 .811 .919 r
.37966 .58034 .38934 .58796 .40545 .57879 .3958 .57225 Mtetra
.778 .843 .901 r
.3958 .57225 .40545 .57879 .42171 .56613 .41209 .56147 Mtetra
.848 .88 .863 r
.41209 .56147 .42171 .56613 .43814 .54787 .42855 .5462 Mtetra
.917 .911 .798 r
.42855 .5462 .43814 .54787 .4547 .52181 .44518 .52414 Mtetra
.963 .922 .714 r
.44518 .52414 .4547 .52181 .47129 .48737 .46189 .49361 Mtetra
.978 .919 .641 r
.46189 .49361 .47129 .48737 .48775 .44767 .47856 .4557 Mtetra
.976 .918 .608 r
.47856 .4557 .48775 .44767 .50397 .40908 .49502 .41551 Mtetra
.971 .929 .633 r
.49502 .41551 .50397 .40908 .51993 .37717 .51122 .37963 Mtetra
.957 .943 .715 r
.51122 .37963 .51993 .37717 .53576 .35365 .52721 .35181 Mtetra
.912 .931 .811 r
.52721 .35181 .53576 .35365 .55155 .33712 .54311 .33194 Mtetra
.839 .885 .874 r
.54311 .33194 .55155 .33712 .56738 .32531 .55903 .31795 Mtetra
.771 .833 .9 r
.55903 .31795 .56738 .32531 .5833 .31633 .57501 .30767 Mtetra
.725 .794 .907 r
.57501 .30767 .5833 .31633 .59931 .30894 .59108 .29952 Mtetra
.697 .771 .909 r
.59108 .29952 .59931 .30894 .61541 .30241 .60724 .29255 Mtetra
.681 .757 .909 r
.60724 .29255 .61541 .30241 .63162 .29631 .62351 .28619 Mtetra
.673 .75 .908 r
.62351 .28619 .63162 .29631 .64793 .29044 .63988 .28015 Mtetra
.668 .746 .908 r
.63988 .28015 .64793 .29044 .66433 .28467 .65635 .27426 Mtetra
.666 .744 .908 r
.65635 .27426 .66433 .28467 .68084 .27893 .67292 .26843 Mtetra
.665 .743 .908 r
.67292 .26843 .68084 .27893 .69744 .2732 .68958 .26262 Mtetra
.664 .742 .908 r
.68958 .26262 .69744 .2732 .71414 .26745 .70635 .2568 Mtetra
.70635 .2568 .71414 .26745 .73093 .26168 .72322 .25096 Mtetra
.664 .741 .908 r
.72322 .25096 .73093 .26168 .74783 .25588 .74019 .2451 Mtetra
.74019 .2451 .74783 .25588 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24419 .77443 .23327 Mtetra
.77443 .23327 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.646 .762 .934 r
.18391 .63205 .19431 .64049 .20925 .63593 .1989 .62744 Mtetra
.1989 .62744 .20925 .63593 .22428 .63134 .21398 .62281 Mtetra
.21398 .62281 .22428 .63134 .2394 .62672 .22915 .61814 Mtetra
.646 .763 .934 r
.22915 .61814 .2394 .62672 .2546 .62208 .24441 .61345 Mtetra
.24441 .61345 .2546 .62208 .2699 .61739 .25976 .60871 Mtetra
.647 .763 .934 r
.25976 .60871 .2699 .61739 .28528 .61266 .27519 .60394 Mtetra
.27519 .60394 .28528 .61266 .30076 .60787 .29072 .59912 Mtetra
.649 .764 .933 r
.29072 .59912 .30076 .60787 .31633 .60299 .30635 .59422 Mtetra
.651 .766 .933 r
.30635 .59422 .31633 .60299 .332 .59796 .32207 .58921 Mtetra
.655 .768 .932 r
.32207 .58921 .332 .59796 .34778 .59267 .3379 .584 Mtetra
.664 .774 .931 r
.3379 .584 .34778 .59267 .36366 .58692 .35383 .57845 Mtetra
.679 .783 .929 r
.35383 .57845 .36366 .58692 .37966 .58034 .36988 .57227 Mtetra
.705 .799 .923 r
.36988 .57227 .37966 .58034 .3958 .57225 .38605 .56497 Mtetra
.749 .826 .911 r
.38605 .56497 .3958 .57225 .41209 .56147 .40238 .55563 Mtetra
.812 .861 .885 r
.40238 .55563 .41209 .56147 .42855 .5462 .41887 .54277 Mtetra
.885 .898 .834 r
.41887 .54277 .42855 .5462 .44518 .52414 .43553 .52428 Mtetra
.944 .919 .757 r
.43553 .52428 .44518 .52414 .46189 .49361 .45234 .49794 Mtetra
.974 .921 .674 r
.45234 .49794 .46189 .49361 .47856 .4557 .46918 .46315 Mtetra
.978 .917 .618 r
.46918 .46315 .47856 .4557 .49502 .41551 .48588 .42308 Mtetra
.974 .922 .613 r
.48588 .42308 .49502 .41551 .51122 .37963 .50233 .38414 Mtetra
.966 .938 .669 r
.50233 .38414 .51122 .37963 .52721 .35181 .51853 .35194 Mtetra
.939 .942 .765 r
.51853 .35194 .52721 .35181 .54311 .33194 .53457 .32816 Mtetra
.877 .911 .848 r
.53457 .32816 .54311 .33194 .55903 .31795 .55058 .31142 Mtetra
.803 .858 .89 r
.55058 .31142 .55903 .31795 .57501 .30767 .56663 .29943 Mtetra
.745 .812 .905 r
.56663 .29943 .57501 .30767 .59108 .29952 .58276 .29029 Mtetra
.709 .781 .908 r
.58276 .29029 .59108 .29952 .60724 .29255 .59899 .28273 Mtetra
.688 .763 .909 r
.59899 .28273 .60724 .29255 .62351 .28619 .61532 .27604 Mtetra
.676 .753 .909 r
.61532 .27604 .62351 .28619 .63988 .28015 .63175 .26979 Mtetra
.67 .747 .908 r
.63175 .26979 .63988 .28015 .65635 .27426 .64828 .26376 Mtetra
.667 .745 .908 r
.64828 .26376 .65635 .27426 .67292 .26843 .66491 .25783 Mtetra
.665 .743 .908 r
.66491 .25783 .67292 .26843 .68958 .26262 .68165 .25193 Mtetra
.665 .742 .908 r
.68165 .25193 .68958 .26262 .70635 .2568 .69848 .24604 Mtetra
.664 .742 .908 r
.69848 .24604 .70635 .2568 .72322 .25096 .71542 .24013 Mtetra
.71542 .24013 .72322 .25096 .74019 .2451 .73246 .2342 Mtetra
.664 .741 .908 r
.73246 .2342 .74019 .2451 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22224 Mtetra
.76684 .22224 .77443 .23327 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63205 .1989 .62744 .18844 .61887 Mtetra
.18844 .61887 .1989 .62744 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61814 .21879 .60947 Mtetra
.21879 .60947 .22915 .61814 .24441 .61345 .2341 .60472 Mtetra
.646 .763 .934 r
.2341 .60472 .24441 .61345 .25976 .60871 .2495 .59994 Mtetra
.2495 .59994 .25976 .60871 .27519 .60394 .26499 .59513 Mtetra
.647 .763 .934 r
.26499 .59513 .27519 .60394 .29072 .59912 .28058 .59026 Mtetra
.648 .764 .933 r
.28058 .59026 .29072 .59912 .30635 .59422 .29626 .58534 Mtetra
.65 .765 .933 r
.29626 .58534 .30635 .59422 .32207 .58921 .31204 .58032 Mtetra
.653 .767 .933 r
.31204 .58032 .32207 .58921 .3379 .584 .32791 .57515 Mtetra
.659 .771 .932 r
.32791 .57515 .3379 .584 .35383 .57845 .3439 .56973 Mtetra
.67 .778 .93 r
.3439 .56973 .35383 .57845 .36988 .57227 .35999 .56384 Mtetra
.69 .79 .927 r
.35999 .56384 .36988 .57227 .38605 .56497 .37621 .5571 Mtetra
.725 .811 .919 r
.37621 .5571 .38605 .56497 .40238 .55563 .39257 .54884 Mtetra
.778 .843 .901 r
.39257 .54884 .40238 .55563 .41887 .54277 .40909 .53788 Mtetra
.848 .88 .863 r
.40909 .53788 .41887 .54277 .43553 .52428 .42579 .5224 Mtetra
.918 .911 .798 r
.42579 .5224 .43553 .52428 .45234 .49794 .44265 .50008 Mtetra
.963 .922 .714 r
.44265 .50008 .45234 .49794 .46918 .46315 .45962 .46923 Mtetra
.978 .919 .641 r
.45962 .46923 .46918 .46315 .48588 .42308 .47654 .43096 Mtetra
.976 .918 .608 r
.47654 .43096 .48588 .42308 .50233 .38414 .49325 .3904 Mtetra
.971 .929 .634 r
.49325 .3904 .50233 .38414 .51853 .35194 .50968 .35419 Mtetra
.957 .943 .715 r
.50968 .35419 .51853 .35194 .53457 .32816 .5259 .32609 Mtetra
.911 .931 .811 r
.5259 .32609 .53457 .32816 .55058 .31142 .54202 .306 Mtetra
.839 .885 .874 r
.54202 .306 .55058 .31142 .56663 .29943 .55815 .29181 Mtetra
.771 .833 .899 r
.55815 .29181 .56663 .29943 .58276 .29029 .57435 .28134 Mtetra
.725 .794 .907 r
.57435 .28134 .58276 .29029 .59899 .28273 .59064 .27303 Mtetra
.697 .771 .909 r
.59064 .27303 .59899 .28273 .61532 .27604 .60703 .26589 Mtetra
.681 .757 .909 r
.60703 .26589 .61532 .27604 .63175 .26979 .62353 .25938 Mtetra
.673 .75 .908 r
.62353 .25938 .63175 .26979 .64828 .26376 .64012 .25318 Mtetra
.668 .746 .908 r
.64012 .25318 .64828 .26376 .66491 .25783 .65682 .24712 Mtetra
.666 .744 .908 r
.65682 .24712 .66491 .25783 .68165 .25193 .67362 .24113 Mtetra
.665 .743 .908 r
.67362 .24113 .68165 .25193 .69848 .24604 .69053 .23516 Mtetra
.664 .742 .908 r
.69053 .23516 .69848 .24604 .71542 .24013 .70753 .22918 Mtetra
.70753 .22918 .71542 .24013 .73246 .2342 .72464 .22318 Mtetra
.664 .741 .908 r
.72464 .22318 .73246 .2342 .7496 .22823 .74185 .21714 Mtetra
.74185 .21714 .7496 .22823 .76684 .22224 .75917 .21108 Mtetra
.75917 .21108 .76684 .22224 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .60069 Mtetra
.20832 .60069 .21879 .60947 .2341 .60472 .22368 .5959 Mtetra
.646 .763 .934 r
.22368 .5959 .2341 .60472 .2495 .59994 .23913 .59107 Mtetra
.23913 .59107 .2495 .59994 .26499 .59513 .25468 .58621 Mtetra
.647 .763 .934 r
.25468 .58621 .26499 .59513 .28058 .59026 .27032 .5813 Mtetra
.27032 .5813 .28058 .59026 .29626 .58534 .28605 .57634 Mtetra
.649 .764 .933 r
.28605 .57634 .29626 .58534 .31204 .58032 .30189 .57131 Mtetra
.651 .766 .933 r
.30189 .57131 .31204 .58032 .32791 .57515 .31782 .56615 Mtetra
.655 .768 .932 r
.31782 .56615 .32791 .57515 .3439 .56973 .33386 .5608 Mtetra
.664 .774 .931 r
.33386 .5608 .3439 .56973 .35999 .56384 .35 .55511 Mtetra
.679 .783 .929 r
.35 .55511 .35999 .56384 .37621 .5571 .36627 .54878 Mtetra
.705 .799 .923 r
.36627 .54878 .37621 .5571 .39257 .54884 .38267 .54132 Mtetra
.749 .826 .911 r
.38267 .54132 .39257 .54884 .40909 .53788 .39922 .5318 Mtetra
.812 .862 .885 r
.39922 .5318 .40909 .53788 .42579 .5224 .41595 .51875 Mtetra
.885 .898 .834 r
.41595 .51875 .42579 .5224 .44265 .50008 .43285 .50001 Mtetra
.944 .919 .757 r
.43285 .50001 .44265 .50008 .45962 .46923 .44991 .47337 Mtetra
.974 .921 .674 r
.44991 .47337 .45962 .46923 .47654 .43096 .467 .43824 Mtetra
.978 .917 .618 r
.467 .43824 .47654 .43096 .49325 .3904 .48396 .3978 Mtetra
.974 .922 .613 r
.48396 .3978 .49325 .3904 .50968 .35419 .50065 .35851 Mtetra
.966 .937 .669 r
.50065 .35851 .50968 .35419 .5259 .32609 .51708 .326 Mtetra
.939 .942 .765 r
.51708 .326 .5259 .32609 .54202 .306 .53335 .30197 Mtetra
.877 .91 .848 r
.53335 .30197 .54202 .306 .55815 .29181 .54958 .28502 Mtetra
.803 .858 .89 r
.54958 .28502 .55815 .29181 .57435 .28134 .56585 .27284 Mtetra
.745 .811 .904 r
.56585 .27284 .57435 .28134 .59064 .27303 .58221 .26351 Mtetra
.709 .781 .908 r
.58221 .26351 .59064 .27303 .60703 .26589 .59866 .2558 Mtetra
.688 .763 .909 r
.59866 .2558 .60703 .26589 .62353 .25938 .61521 .24894 Mtetra
.676 .753 .909 r
.61521 .24894 .62353 .25938 .64012 .25318 .63188 .24252 Mtetra
.67 .747 .908 r
.63188 .24252 .64012 .25318 .65682 .24712 .64864 .23633 Mtetra
.667 .745 .908 r
.64864 .23633 .65682 .24712 .67362 .24113 .66551 .23023 Mtetra
.665 .743 .908 r
.66551 .23023 .67362 .24113 .69053 .23516 .68248 .22417 Mtetra
.665 .742 .908 r
.68248 .22417 .69053 .23516 .70753 .22918 .69956 .21811 Mtetra
.664 .742 .908 r
.69956 .21811 .70753 .22918 .72464 .22318 .71674 .21203 Mtetra
.71674 .21203 .72464 .22318 .74185 .21714 .73402 .20593 Mtetra
.664 .741 .908 r
.73402 .20593 .74185 .21714 .75917 .21108 .75141 .1998 Mtetra
.75141 .1998 .75917 .21108 .77659 .20498 .76891 .19363 Mtetra
.76891 .19363 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .60069 .19773 .59183 Mtetra
.19773 .59183 .20832 .60069 .22368 .5959 .21315 .58698 Mtetra
.21315 .58698 .22368 .5959 .23913 .59107 .22865 .5821 Mtetra
.646 .763 .934 r
.22865 .5821 .23913 .59107 .25468 .58621 .24425 .57718 Mtetra
.24425 .57718 .25468 .58621 .27032 .5813 .25995 .57223 Mtetra
.647 .763 .934 r
.25995 .57223 .27032 .5813 .28605 .57634 .27574 .56723 Mtetra
.648 .764 .933 r
.27574 .56723 .28605 .57634 .30189 .57131 .29163 .56217 Mtetra
.65 .765 .933 r
.29163 .56217 .30189 .57131 .31782 .56615 .30761 .55701 Mtetra
.653 .767 .933 r
.30761 .55701 .31782 .56615 .33386 .5608 .32371 .5517 Mtetra
.659 .771 .932 r
.32371 .5517 .33386 .5608 .35 .55511 .33991 .54613 Mtetra
.67 .778 .93 r
.33991 .54613 .35 .55511 .36627 .54878 .35622 .54009 Mtetra
.69 .79 .927 r
.35622 .54009 .36627 .54878 .38267 .54132 .37267 .5332 Mtetra
.725 .811 .919 r
.37267 .5332 .38267 .54132 .39922 .5318 .38926 .52477 Mtetra
.778 .843 .901 r
.38926 .52477 .39922 .5318 .41595 .51875 .40601 .51362 Mtetra
.848 .881 .863 r
.40601 .51362 .41595 .51875 .43285 .50001 .42295 .49791 Mtetra
.918 .911 .798 r
.42295 .49791 .43285 .50001 .44991 .47337 .44006 .47532 Mtetra
.963 .922 .714 r
.44006 .47532 .44991 .47337 .467 .43824 .45728 .44414 Mtetra
.978 .919 .641 r
.45728 .44414 .467 .43824 .48396 .3978 .47446 .40551 Mtetra
.976 .918 .608 r
.47446 .40551 .48396 .3978 .50065 .35851 .49142 .36459 Mtetra
.971 .929 .634 r
.49142 .36459 .50065 .35851 .51708 .326 .5081 .32803 Mtetra
.957 .943 .716 r
.5081 .32803 .51708 .326 .53335 .30197 .52455 .29966 Mtetra
.911 .931 .812 r
.52455 .29966 .53335 .30197 .54958 .28502 .5409 .27933 Mtetra
.839 .884 .874 r
.5409 .27933 .54958 .28502 .56585 .27284 .55725 .26494 Mtetra
.771 .833 .899 r
.55725 .26494 .56585 .27284 .58221 .26351 .57368 .25429 Mtetra
.725 .794 .907 r
.57368 .25429 .58221 .26351 .59866 .2558 .59019 .2458 Mtetra
.697 .771 .909 r
.59019 .2458 .59866 .2558 .61521 .24894 .60681 .23849 Mtetra
.681 .757 .909 r
.60681 .23849 .61521 .24894 .63188 .24252 .62354 .23181 Mtetra
.673 .75 .908 r
.62354 .23181 .63188 .24252 .64864 .23633 .64037 .22544 Mtetra
.668 .746 .908 r
.64037 .22544 .64864 .23633 .66551 .23023 .65731 .21922 Mtetra
.666 .744 .908 r
.65731 .21922 .66551 .23023 .68248 .22417 .67435 .21306 Mtetra
.665 .743 .908 r
.67435 .21306 .68248 .22417 .69956 .21811 .69149 .20692 Mtetra
.664 .742 .908 r
.69149 .20692 .69956 .21811 .71674 .21203 .70875 .20077 Mtetra
.70875 .20077 .71674 .21203 .73402 .20593 .7261 .19459 Mtetra
.664 .741 .908 r
.7261 .19459 .73402 .20593 .75141 .1998 .74357 .18839 Mtetra
.74357 .18839 .75141 .1998 .76891 .19363 .76114 .18215 Mtetra
.76114 .18215 .76891 .19363 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21315 .58698 .20249 .57796 Mtetra
.20249 .57796 .21315 .58698 .22865 .5821 .21805 .57303 Mtetra
.646 .763 .934 r
.21805 .57303 .22865 .5821 .24425 .57718 .23371 .56806 Mtetra
.23371 .56806 .24425 .57718 .25995 .57223 .24946 .56306 Mtetra
.647 .763 .934 r
.24946 .56306 .25995 .57223 .27574 .56723 .26531 .55801 Mtetra
.26531 .55801 .27574 .56723 .29163 .56217 .28125 .55291 Mtetra
.649 .764 .933 r
.28125 .55291 .29163 .56217 .30761 .55701 .2973 .54773 Mtetra
.651 .766 .933 r
.2973 .54773 .30761 .55701 .32371 .5517 .31344 .54244 Mtetra
.655 .768 .932 r
.31344 .54244 .32371 .5517 .33991 .54613 .3297 .53694 Mtetra
.664 .774 .931 r
.3297 .53694 .33991 .54613 .35622 .54009 .34607 .53109 Mtetra
.679 .783 .929 r
.34607 .53109 .35622 .54009 .37267 .5332 .36256 .52461 Mtetra
.705 .8 .923 r
.36256 .52461 .37267 .5332 .38926 .52477 .37919 .51698 Mtetra
.749 .826 .912 r
.37919 .51698 .38926 .52477 .40601 .51362 .39598 .50728 Mtetra
.812 .862 .885 r
.39598 .50728 .40601 .51362 .42295 .49791 .41294 .49402 Mtetra
.885 .898 .834 r
.41294 .49402 .42295 .49791 .44006 .47532 .4301 .47504 Mtetra
.944 .919 .757 r
.4301 .47504 .44006 .47532 .45728 .44414 .44741 .4481 Mtetra
.974 .921 .674 r
.44741 .4481 .45728 .44414 .47446 .40551 .46476 .41262 Mtetra
.978 .917 .618 r
.46476 .41262 .47446 .40551 .49142 .36459 .48198 .3718 Mtetra
.974 .922 .613 r
.48198 .3718 .49142 .36459 .5081 .32803 .49892 .33215 Mtetra
.966 .937 .67 r
.49892 .33215 .5081 .32803 .52455 .29966 .51559 .29933 Mtetra
.939 .942 .766 r
.51559 .29933 .52455 .29966 .5409 .27933 .53209 .27504 Mtetra
.877 .91 .848 r
.53209 .27504 .5409 .27933 .55725 .26494 .54855 .25787 Mtetra
.803 .857 .89 r
.54855 .25787 .55725 .26494 .57368 .25429 .56505 .24549 Mtetra
.745 .811 .904 r
.56505 .24549 .57368 .25429 .59019 .2458 .58164 .23599 Mtetra
.709 .781 .908 r
.58164 .23599 .59019 .2458 .60681 .23849 .59832 .2281 Mtetra
.688 .763 .909 r
.59832 .2281 .60681 .23849 .62354 .23181 .61511 .22106 Mtetra
.676 .753 .909 r
.61511 .22106 .62354 .23181 .64037 .22544 .63201 .21448 Mtetra
.67 .747 .908 r
.63201 .21448 .64037 .22544 .65731 .21922 .64901 .20811 Mtetra
.667 .745 .908 r
.64901 .20811 .65731 .21922 .67435 .21306 .66612 .20185 Mtetra
.665 .743 .908 r
.66612 .20185 .67435 .21306 .69149 .20692 .68334 .19561 Mtetra
.665 .742 .908 r
.68334 .19561 .69149 .20692 .70875 .20077 .70066 .18938 Mtetra
.664 .742 .908 r
.70066 .18938 .70875 .20077 .7261 .19459 .71809 .18313 Mtetra
.71809 .18313 .7261 .19459 .74357 .18839 .73563 .17685 Mtetra
.664 .741 .908 r
.73563 .17685 .74357 .18839 .76114 .18215 .75328 .17053 Mtetra
.75328 .17053 .76114 .18215 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56385 Mtetra
.20734 .56385 .21805 .57303 .23371 .56806 .22305 .55883 Mtetra
.646 .763 .934 r
.22305 .55883 .23371 .56806 .24946 .56306 .23886 .55378 Mtetra
.23886 .55378 .24946 .56306 .26531 .55801 .25476 .54868 Mtetra
.647 .763 .934 r
.25476 .54868 .26531 .55801 .28125 .55291 .27076 .54354 Mtetra
.648 .764 .933 r
.27076 .54354 .28125 .55291 .2973 .54773 .28686 .53833 Mtetra
.65 .765 .933 r
.28686 .53833 .2973 .54773 .31344 .54244 .30307 .53303 Mtetra
.653 .767 .933 r
.30307 .53303 .31344 .54244 .3297 .53694 .31938 .52757 Mtetra
.659 .771 .932 r
.31938 .52757 .3297 .53694 .34607 .53109 .3358 .52184 Mtetra
.67 .778 .93 r
.3358 .52184 .34607 .53109 .36256 .52461 .35234 .51565 Mtetra
.69 .79 .927 r
.35234 .51565 .36256 .52461 .37919 .51698 .36902 .50859 Mtetra
.725 .811 .919 r
.36902 .50859 .37919 .51698 .39598 .50728 .38584 .49999 Mtetra
.778 .843 .901 r
.38584 .49999 .39598 .50728 .41294 .49402 .40284 .48864 Mtetra
.848 .881 .863 r
.40284 .48864 .41294 .49402 .4301 .47504 .42002 .4727 Mtetra
.918 .911 .798 r
.42002 .4727 .4301 .47504 .44741 .4481 .43739 .44983 Mtetra
.963 .922 .714 r
.43739 .44983 .44741 .4481 .46476 .41262 .45488 .41833 Mtetra
.978 .919 .641 r
.45488 .41833 .46476 .41262 .48198 .3718 .47232 .37932 Mtetra
.976 .918 .608 r
.47232 .37932 .48198 .3718 .49892 .33215 .48954 .33803 Mtetra
.971 .929 .634 r
.48954 .33803 .49892 .33215 .51559 .29933 .50647 .30114 Mtetra
.957 .943 .716 r
.50647 .30114 .51559 .29933 .53209 .27504 .52316 .27248 Mtetra
.911 .93 .812 r
.52316 .27248 .53209 .27504 .54855 .25787 .53974 .2519 Mtetra
.839 .884 .874 r
.53974 .2519 .54855 .25787 .56505 .24549 .55633 .2373 Mtetra
.771 .833 .899 r
.55633 .2373 .56505 .24549 .58164 .23599 .57299 .22646 Mtetra
.725 .794 .907 r
.57299 .22646 .58164 .23599 .59832 .2281 .58973 .2178 Mtetra
.697 .77 .909 r
.58973 .2178 .59832 .2281 .61511 .22106 .60659 .21031 Mtetra
.681 .757 .909 r
.60659 .21031 .61511 .22106 .63201 .21448 .62355 .20346 Mtetra
.673 .75 .908 r
.62355 .20346 .63201 .21448 .64901 .20811 .64063 .19691 Mtetra
.668 .746 .908 r
.64063 .19691 .64901 .20811 .66612 .20185 .65781 .19052 Mtetra
.666 .744 .908 r
.65781 .19052 .66612 .20185 .68334 .19561 .67509 .18419 Mtetra
.665 .743 .908 r
.67509 .18419 .68334 .19561 .70066 .18938 .69249 .17787 Mtetra
.664 .742 .908 r
.69249 .17787 .70066 .18938 .71809 .18313 .70999 .17153 Mtetra
.70999 .17153 .71809 .18313 .73563 .17685 .72761 .16518 Mtetra
.664 .741 .908 r
.72761 .16518 .73563 .17685 .75328 .17053 .74533 .15879 Mtetra
.74533 .15879 .75328 .17053 .77104 .16418 .76317 .15237 Mtetra
.76317 .15237 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56462 Mtetra
.16526 .56462 .1762 .57379 .19172 .56884 .18083 .55961 Mtetra
.18083 .55961 .19172 .56884 .20734 .56385 .1965 .55457 Mtetra
.1965 .55457 .20734 .56385 .22305 .55883 .21227 .5495 Mtetra
.646 .763 .934 r
.21227 .5495 .22305 .55883 .23886 .55378 .22813 .54439 Mtetra
.22813 .54439 .23886 .55378 .25476 .54868 .24409 .53924 Mtetra
.647 .763 .934 r
.24409 .53924 .25476 .54868 .27076 .54354 .26015 .53405 Mtetra
.26015 .53405 .27076 .54354 .28686 .53833 .27631 .52881 Mtetra
.649 .764 .933 r
.27631 .52881 .28686 .53833 .30307 .53303 .29257 .52348 Mtetra
.651 .766 .933 r
.29257 .52348 .30307 .53303 .31938 .52757 .30894 .51803 Mtetra
.655 .768 .932 r
.30894 .51803 .31938 .52757 .3358 .52184 .32542 .51238 Mtetra
.664 .774 .931 r
.32542 .51238 .3358 .52184 .35234 .51565 .34201 .50637 Mtetra
.679 .783 .929 r
.34201 .50637 .35234 .51565 .36902 .50859 .35874 .49973 Mtetra
.705 .8 .923 r
.35874 .49973 .36902 .50859 .38584 .49999 .3756 .49192 Mtetra
.749 .826 .912 r
.3756 .49192 .38584 .49999 .40284 .48864 .39263 .48204 Mtetra
.812 .862 .885 r
.39263 .48204 .40284 .48864 .42002 .4727 .40985 .46856 Mtetra
.885 .898 .834 r
.40985 .46856 .42002 .4727 .43739 .44983 .42726 .44933 Mtetra
.944 .92 .757 r
.42726 .44933 .43739 .44983 .45488 .41833 .44483 .42208 Mtetra
.974 .921 .674 r
.44483 .42208 .45488 .41833 .47232 .37932 .46245 .38624 Mtetra
.978 .917 .618 r
.46245 .38624 .47232 .37932 .48954 .33803 .47994 .34505 Mtetra
.974 .922 .613 r
.47994 .34505 .48954 .33803 .50647 .30114 .49714 .30503 Mtetra
.966 .937 .67 r
.49714 .30503 .50647 .30114 .52316 .27248 .51406 .2719 Mtetra
.939 .941 .766 r
.51406 .2719 .52316 .27248 .53974 .2519 .53081 .24735 Mtetra
.877 .91 .848 r
.53081 .24735 .53974 .2519 .55633 .2373 .5475 .22995 Mtetra
.803 .857 .89 r
.5475 .22995 .55633 .2373 .57299 .22646 .56423 .21737 Mtetra
.745 .811 .904 r
.56423 .21737 .57299 .22646 .58973 .2178 .58105 .20768 Mtetra
.709 .781 .908 r
.58105 .20768 .58973 .2178 .60659 .21031 .59797 .1996 Mtetra
.688 .763 .909 r
.59797 .1996 .60659 .21031 .62355 .20346 .615 .19239 Mtetra
.676 .753 .909 r
.615 .19239 .62355 .20346 .64063 .19691 .63214 .18563 Mtetra
.67 .747 .908 r
.63214 .18563 .64063 .19691 .65781 .19052 .64939 .17909 Mtetra
.667 .745 .908 r
.64939 .17909 .65781 .19052 .67509 .18419 .66675 .17264 Mtetra
.665 .743 .908 r
.66675 .17264 .67509 .18419 .69249 .17787 .68422 .16623 Mtetra
.665 .742 .908 r
.68422 .16623 .69249 .17787 .70999 .17153 .7018 .15981 Mtetra
.664 .742 .908 r
.7018 .15981 .70999 .17153 .72761 .16518 .71949 .15338 Mtetra
.71949 .15338 .72761 .16518 .74533 .15879 .73729 .14691 Mtetra
.664 .741 .908 r
.73729 .14691 .74533 .15879 .76317 .15237 .7552 .14041 Mtetra
.7552 .14041 .76317 .15237 .78111 .1459 .77323 .13387 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56462 .15419 .55535 Mtetra
.15419 .55535 .16526 .56462 .18083 .55961 .16982 .55029 Mtetra
.16982 .55029 .18083 .55961 .1965 .55457 .18554 .54519 Mtetra
.18554 .54519 .1965 .55457 .21227 .5495 .20137 .54006 Mtetra
.20137 .54006 .21227 .5495 .22813 .54439 .21728 .53489 Mtetra
.646 .763 .934 r
.21728 .53489 .22813 .54439 .24409 .53924 .2333 .52969 Mtetra
.2333 .52969 .24409 .53924 .26015 .53405 .24942 .52445 Mtetra
.647 .763 .934 r
.24942 .52445 .26015 .53405 .27631 .52881 .26564 .51916 Mtetra
.648 .764 .933 r
.26564 .51916 .27631 .52881 .29257 .52348 .28196 .5138 Mtetra
.65 .765 .933 r
.28196 .5138 .29257 .52348 .30894 .51803 .29838 .50834 Mtetra
.653 .767 .933 r
.29838 .50834 .30894 .51803 .32542 .51238 .31492 .50273 Mtetra
.659 .771 .932 r
.31492 .50273 .32542 .51238 .34201 .50637 .33157 .49684 Mtetra
.67 .778 .93 r
.33157 .49684 .34201 .50637 .35874 .49973 .34835 .49048 Mtetra
.69 .79 .927 r
.34835 .49048 .35874 .49973 .3756 .49192 .36526 .48326 Mtetra
.725 .811 .919 r
.36526 .48326 .3756 .49192 .39263 .48204 .38232 .47447 Mtetra
.778 .843 .901 r
.38232 .47447 .39263 .48204 .40985 .46856 .39957 .46292 Mtetra
.848 .881 .863 r
.39957 .46292 .40985 .46856 .42726 .44933 .41701 .44674 Mtetra
.918 .912 .798 r
.41701 .44674 .42726 .44933 .44483 .42208 .43464 .4236 Mtetra
.963 .922 .714 r
.43464 .4236 .44483 .42208 .46245 .38624 .4524 .39176 Mtetra
.978 .919 .641 r
.4524 .39176 .46245 .38624 .47994 .34505 .47012 .35237 Mtetra
.976 .918 .608 r
.47012 .35237 .47994 .34505 .49714 .30503 .48761 .3107 Mtetra
.971 .929 .634 r
.48761 .3107 .49714 .30503 .51406 .2719 .50479 .27346 Mtetra
.957 .943 .716 r
.50479 .27346 .51406 .2719 .53081 .24735 .52173 .24451 Mtetra
.911 .93 .812 r
.52173 .24451 .53081 .24735 .5475 .22995 .53855 .22369 Mtetra
.839 .884 .874 r
.53855 .22369 .5475 .22995 .56423 .21737 .55538 .20888 Mtetra
.771 .832 .899 r
.55538 .20888 .56423 .21737 .58105 .20768 .57227 .19784 Mtetra
.725 .794 .907 r
.57227 .19784 .58105 .20768 .59797 .1996 .58926 .18899 Mtetra
.697 .77 .909 r
.58926 .18899 .59797 .1996 .615 .19239 .60636 .18132 Mtetra
.681 .757 .909 r
.60636 .18132 .615 .19239 .63214 .18563 .62357 .17428 Mtetra
.673 .75 .908 r
.62357 .17428 .63214 .18563 .64939 .17909 .64089 .16756 Mtetra
.668 .746 .908 r
.64089 .16756 .64939 .17909 .66675 .17264 .65832 .16098 Mtetra
.666 .744 .908 r
.65832 .16098 .66675 .17264 .68422 .16623 .67586 .15446 Mtetra
.665 .743 .908 r
.67586 .15446 .68422 .16623 .7018 .15981 .69352 .14796 Mtetra
.664 .742 .908 r
.69352 .14796 .7018 .15981 .71949 .15338 .71128 .14144 Mtetra
.71128 .14144 .71949 .15338 .73729 .14691 .72916 .13489 Mtetra
.664 .741 .908 r
.72916 .13489 .73729 .14691 .7552 .14041 .74715 .12832 Mtetra
.74715 .12832 .7552 .14041 .77323 .13387 .76525 .1217 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54006 .19034 .53051 Mtetra
.19034 .53051 .20137 .54006 .21728 .53489 .20631 .52529 Mtetra
.646 .763 .934 r
.20631 .52529 .21728 .53489 .2333 .52969 .22239 .52003 Mtetra
.22239 .52003 .2333 .52969 .24942 .52445 .23856 .51473 Mtetra
.647 .763 .934 r
.23856 .51473 .24942 .52445 .26564 .51916 .25484 .50939 Mtetra
.25484 .50939 .26564 .51916 .28196 .5138 .27122 .50399 Mtetra
.649 .764 .933 r
.27122 .50399 .28196 .5138 .29838 .50834 .28771 .49851 Mtetra
.651 .766 .933 r
.28771 .49851 .29838 .50834 .31492 .50273 .3043 .4929 Mtetra
.655 .768 .932 r
.3043 .4929 .31492 .50273 .33157 .49684 .32101 .48709 Mtetra
.664 .774 .931 r
.32101 .48709 .33157 .49684 .34835 .49048 .33784 .48092 Mtetra
.679 .783 .929 r
.33784 .48092 .34835 .49048 .36526 .48326 .3548 .4741 Mtetra
.705 .8 .924 r
.3548 .4741 .36526 .48326 .38232 .47447 .37191 .46612 Mtetra
.749 .826 .912 r
.37191 .46612 .38232 .47447 .39957 .46292 .38919 .45604 Mtetra
.812 .862 .885 r
.38919 .45604 .39957 .46292 .41701 .44674 .40666 .44234 Mtetra
.885 .898 .834 r
.40666 .44234 .41701 .44674 .43464 .4236 .42433 .42285 Mtetra
.944 .92 .756 r
.42433 .42285 .43464 .4236 .4524 .39176 .44218 .39529 Mtetra
.974 .921 .674 r
.44218 .39529 .4524 .39176 .47012 .35237 .46008 .35909 Mtetra
.978 .917 .618 r
.46008 .35909 .47012 .35237 .48761 .3107 .47784 .31751 Mtetra
.974 .922 .613 r
.47784 .31751 .48761 .3107 .50479 .27346 .49531 .27713 Mtetra
.966 .937 .67 r
.49531 .27713 .50479 .27346 .52173 .24451 .51249 .24367 Mtetra
.939 .941 .766 r
.51249 .24367 .52173 .24451 .53855 .22369 .52948 .21885 Mtetra
.877 .91 .848 r
.52948 .21885 .53855 .22369 .55538 .20888 .54642 .20122 Mtetra
.803 .857 .89 r
.54642 .20122 .55538 .20888 .57227 .19784 .56339 .18843 Mtetra
.745 .811 .904 r
.56339 .18843 .57227 .19784 .58926 .18899 .58045 .17854 Mtetra
.709 .781 .908 r
.58045 .17854 .58926 .18899 .60636 .18132 .59762 .17028 Mtetra
.688 .763 .909 r
.59762 .17028 .60636 .18132 .62357 .17428 .61489 .16289 Mtetra
.676 .753 .908 r
.61489 .16289 .62357 .17428 .64089 .16756 .63228 .15594 Mtetra
.67 .747 .908 r
.63228 .15594 .64089 .16756 .65832 .16098 .64979 .14921 Mtetra
.667 .745 .908 r
.64979 .14921 .65832 .16098 .67586 .15446 .6674 .14257 Mtetra
.665 .743 .908 r
.6674 .14257 .67586 .15446 .69352 .14796 .68513 .13597 Mtetra
.665 .742 .908 r
.68513 .13597 .69352 .14796 .71128 .14144 .70297 .12937 Mtetra
.664 .742 .908 r
.70297 .12937 .71128 .14144 .72916 .13489 .72093 .12274 Mtetra
.72093 .12274 .72916 .13489 .74715 .12832 .739 .11608 Mtetra
.664 .741 .908 r
.739 .11608 .74715 .12832 .76525 .1217 .75719 .10939 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53051 .17919 .52085 Mtetra
.17919 .52085 .19034 .53051 .20631 .52529 .19522 .51557 Mtetra
.19522 .51557 .20631 .52529 .22239 .52003 .21135 .51026 Mtetra
.646 .763 .934 r
.21135 .51026 .22239 .52003 .23856 .51473 .22758 .5049 Mtetra
.22758 .5049 .23856 .51473 .25484 .50939 .24392 .4995 Mtetra
.647 .763 .934 r
.24392 .4995 .25484 .50939 .27122 .50399 .26036 .49405 Mtetra
.648 .764 .933 r
.26036 .49405 .27122 .50399 .28771 .49851 .27691 .48854 Mtetra
.65 .765 .933 r
.27691 .48854 .28771 .49851 .3043 .4929 .29356 .48292 Mtetra
.653 .767 .933 r
.29356 .48292 .3043 .4929 .32101 .48709 .31033 .47714 Mtetra
.659 .771 .932 r
.31033 .47714 .32101 .48709 .33784 .48092 .32722 .47109 Mtetra
.67 .778 .93 r
.32722 .47109 .33784 .48092 .3548 .4741 .34423 .46456 Mtetra
.69 .79 .927 r
.34423 .46456 .3548 .4741 .37191 .46612 .36139 .45716 Mtetra
.725 .812 .919 r
.36139 .45716 .37191 .46612 .38919 .45604 .3787 .44818 Mtetra
.778 .843 .901 r
.3787 .44818 .38919 .45604 .40666 .44234 .3962 .43642 Mtetra
.848 .881 .863 r
.3962 .43642 .40666 .44234 .42433 .42285 .41391 .42 Mtetra
.918 .912 .798 r
.41391 .42 .42433 .42285 .44218 .39529 .43181 .39657 Mtetra
.963 .923 .713 r
.43181 .39657 .44218 .39529 .46008 .35909 .44985 .36438 Mtetra
.978 .919 .64 r
.44985 .36438 .46008 .35909 .47784 .31751 .46785 .32462 Mtetra
.976 .918 .608 r
.46785 .32462 .47784 .31751 .49531 .27713 .48562 .28256 Mtetra
.971 .929 .635 r
.48562 .28256 .49531 .27713 .51249 .24367 .50306 .24498 Mtetra
.957 .943 .716 r
.50306 .24498 .51249 .24367 .52948 .21885 .52026 .21573 Mtetra
.911 .93 .812 r
.52026 .21573 .52948 .21885 .54642 .20122 .53733 .19466 Mtetra
.839 .884 .874 r
.53733 .19466 .54642 .20122 .56339 .18843 .5544 .17962 Mtetra
.771 .832 .899 r
.5544 .17962 .56339 .18843 .58045 .17854 .57154 .16838 Mtetra
.725 .794 .907 r
.57154 .16838 .58045 .17854 .59762 .17028 .58878 .15933 Mtetra
.697 .77 .908 r
.58878 .15933 .59762 .17028 .61489 .16289 .60612 .15148 Mtetra
.681 .757 .909 r
.60612 .15148 .61489 .16289 .63228 .15594 .62358 .14425 Mtetra
.673 .75 .908 r
.62358 .14425 .63228 .15594 .64979 .14921 .64116 .13733 Mtetra
.668 .746 .908 r
.64116 .13733 .64979 .14921 .6674 .14257 .65885 .13057 Mtetra
.666 .744 .908 r
.65885 .13057 .6674 .14257 .68513 .13597 .67665 .12386 Mtetra
.665 .743 .908 r
.67665 .12386 .68513 .13597 .70297 .12937 .69457 .11716 Mtetra
.664 .742 .908 r
.69457 .11716 .70297 .12937 .72093 .12274 .71261 .11045 Mtetra
.71261 .11045 .72093 .12274 .739 .11608 .73075 .1037 Mtetra
.664 .741 .908 r
.73075 .1037 .739 .11608 .75719 .10939 .74902 .09693 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52085 .16791 .51109 Mtetra
.16791 .51109 .17919 .52085 .19522 .51557 .18399 .50574 Mtetra
.18399 .50574 .19522 .51557 .21135 .51026 .20018 .50037 Mtetra
.646 .763 .934 r
.20018 .50037 .21135 .51026 .22758 .5049 .21648 .49495 Mtetra
.21648 .49495 .22758 .5049 .24392 .4995 .23287 .4895 Mtetra
.647 .763 .934 r
.23287 .4895 .24392 .4995 .26036 .49405 .24937 .484 Mtetra
.24937 .484 .26036 .49405 .27691 .48854 .26598 .47843 Mtetra
.649 .764 .933 r
.26598 .47843 .27691 .48854 .29356 .48292 .2827 .47279 Mtetra
.651 .766 .933 r
.2827 .47279 .29356 .48292 .31033 .47714 .29953 .46702 Mtetra
.655 .768 .932 r
.29953 .46702 .31033 .47714 .32722 .47109 .31647 .46104 Mtetra
.664 .774 .931 r
.31647 .46104 .32722 .47109 .34423 .46456 .33354 .4547 Mtetra
.679 .783 .929 r
.33354 .4547 .34423 .46456 .36139 .45716 .35075 .4477 Mtetra
.705 .8 .924 r
.35075 .4477 .36139 .45716 .3787 .44818 .36811 .43953 Mtetra
.749 .826 .912 r
.36811 .43953 .3787 .44818 .3962 .43642 .38564 .42925 Mtetra
.812 .862 .886 r
.38564 .42925 .3962 .43642 .41391 .42 .40337 .41533 Mtetra
.885 .899 .834 r
.40337 .41533 .41391 .42 .43181 .39657 .42132 .39556 Mtetra
.945 .92 .756 r
.42132 .39556 .43181 .39657 .44985 .36438 .43945 .36769 Mtetra
.974 .922 .673 r
.43945 .36769 .44985 .36438 .46785 .32462 .45763 .33112 Mtetra
.978 .917 .618 r
.45763 .33112 .46785 .32462 .48562 .28256 .47568 .28914 Mtetra
.974 .922 .613 r
.47568 .28914 .48562 .28256 .50306 .24498 .49343 .24839 Mtetra
.967 .937 .67 r
.49343 .24839 .50306 .24498 .52026 .21573 .51087 .21461 Mtetra
.939 .941 .766 r
.51087 .21461 .52026 .21573 .53733 .19466 .52811 .18951 Mtetra
.877 .909 .848 r
.52811 .18951 .53733 .19466 .5544 .17962 .5453 .17164 Mtetra
.803 .857 .89 r
.5453 .17164 .5544 .17962 .57154 .16838 .56252 .15864 Mtetra
.745 .811 .904 r
.56252 .15864 .57154 .16838 .58878 .15933 .57983 .14855 Mtetra
.709 .781 .908 r
.57983 .14855 .58878 .15933 .60612 .15148 .59725 .14009 Mtetra
.688 .763 .909 r
.59725 .14009 .60612 .15148 .62358 .14425 .61478 .13251 Mtetra
.676 .753 .908 r
.61478 .13251 .62358 .14425 .64116 .13733 .63243 .12536 Mtetra
.67 .747 .908 r
.63243 .12536 .64116 .13733 .65885 .13057 .65019 .11844 Mtetra
.667 .745 .908 r
.65019 .11844 .65885 .13057 .67665 .12386 .66807 .11161 Mtetra
.665 .743 .908 r
.66807 .11161 .67665 .12386 .69457 .11716 .68607 .10481 Mtetra
.665 .742 .908 r
.68607 .10481 .69457 .11716 .71261 .11045 .70418 .09801 Mtetra
.664 .742 .908 r
.70418 .09801 .71261 .11045 .73075 .1037 .72241 .09118 Mtetra
.72241 .09118 .73075 .1037 .74902 .09693 .74076 .08432 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .16791 .51109 .15649 .5012 Mtetra
.15649 .5012 .16791 .51109 .18399 .50574 .17264 .4958 Mtetra
.17264 .4958 .18399 .50574 .20018 .50037 .18889 .49036 Mtetra
.18889 .49036 .20018 .50037 .21648 .49495 .20524 .48489 Mtetra
.646 .763 .934 r
.20524 .48489 .21648 .49495 .23287 .4895 .2217 .47937 Mtetra
.2217 .47937 .23287 .4895 .24937 .484 .23826 .47381 Mtetra
.647 .763 .934 r
.23826 .47381 .24937 .484 .26598 .47843 .25493 .4682 Mtetra
.648 .764 .933 r
.25493 .4682 .26598 .47843 .2827 .47279 .27171 .46252 Mtetra
.65 .765 .933 r
.27171 .46252 .2827 .47279 .29953 .46702 .2886 .45673 Mtetra
.653 .767 .933 r
.2886 .45673 .29953 .46702 .31647 .46104 .3056 .45078 Mtetra
.659 .771 .932 r
.3056 .45078 .31647 .46104 .33354 .4547 .32273 .44456 Mtetra
.67 .778 .93 r
.32273 .44456 .33354 .4547 .35075 .4477 .33999 .43785 Mtetra
.69 .79 .927 r
.33999 .43785 .35075 .4477 .36811 .43953 .3574 .43026 Mtetra
.725 .812 .919 r
.3574 .43026 .36811 .43953 .38564 .42925 .37497 .42109 Mtetra
.778 .843 .901 r
.37497 .42109 .38564 .42925 .40337 .41533 .39273 .40911 Mtetra
.848 .882 .864 r
.39273 .40911 .40337 .41533 .42132 .39556 .41071 .39244 Mtetra
.918 .912 .798 r
.41071 .39244 .42132 .39556 .43945 .36769 .4289 .36871 Mtetra
.963 .923 .713 r
.4289 .36871 .43945 .36769 .45763 .33112 .44722 .33618 Mtetra
.978 .919 .64 r
.44722 .33618 .45763 .33112 .47568 .28914 .46551 .29603 Mtetra
.976 .918 .608 r
.46551 .29603 .47568 .28914 .49343 .24839 .48356 .25358 Mtetra
.971 .929 .635 r
.48356 .25358 .49343 .24839 .51087 .21461 .50129 .21565 Mtetra
.957 .943 .717 r
.50129 .21565 .51087 .21461 .52811 .18951 .51874 .1861 Mtetra
.911 .93 .812 r
.51874 .1861 .52811 .18951 .5453 .17164 .53607 .16477 Mtetra
.839 .884 .874 r
.53607 .16477 .5453 .17164 .56252 .15864 .55339 .1495 Mtetra
.771 .832 .899 r
.55339 .1495 .56252 .15864 .57983 .14855 .57078 .13805 Mtetra
.725 .794 .907 r
.57078 .13805 .57983 .14855 .59725 .14009 .58827 .1288 Mtetra
.697 .77 .908 r
.58827 .1288 .59725 .14009 .61478 .13251 .60588 .12074 Mtetra
.681 .757 .909 r
.60588 .12074 .61478 .13251 .63243 .12536 .6236 .11332 Mtetra
.673 .75 .908 r
.6236 .11332 .63243 .12536 .65019 .11844 .64144 .10621 Mtetra
.668 .746 .908 r
.64144 .10621 .65019 .11844 .66807 .11161 .65939 .09924 Mtetra
.666 .744 .908 r
.65939 .09924 .66807 .11161 .68607 .10481 .67747 .09233 Mtetra
.665 .743 .908 r
.67747 .09233 .68607 .10481 .70418 .09801 .69566 .08543 Mtetra
.664 .742 .908 r
.69566 .08543 .70418 .09801 .72241 .09118 .71397 .07851 Mtetra
.71397 .07851 .72241 .09118 .74076 .08432 .7324 .07157 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49036 .17746 .48024 Mtetra
.17746 .48024 .18889 .49036 .20524 .48489 .19387 .4747 Mtetra
.646 .763 .934 r
.19387 .4747 .20524 .48489 .2217 .47937 .21039 .46912 Mtetra
.21039 .46912 .2217 .47937 .23826 .47381 .22701 .4635 Mtetra
.647 .763 .934 r
.22701 .4635 .23826 .47381 .25493 .4682 .24374 .45783 Mtetra
.24374 .45783 .25493 .4682 .27171 .46252 .26058 .4521 Mtetra
.649 .764 .933 r
.26058 .4521 .27171 .46252 .2886 .45673 .27754 .44629 Mtetra
.651 .766 .933 r
.27754 .44629 .2886 .45673 .3056 .45078 .29461 .44034 Mtetra
.655 .768 .932 r
.29461 .44034 .3056 .45078 .32273 .44456 .31179 .43419 Mtetra
.664 .774 .931 r
.31179 .43419 .32273 .44456 .33999 .43785 .32911 .42767 Mtetra
.679 .783 .929 r
.32911 .42767 .33999 .43785 .3574 .43026 .34657 .42049 Mtetra
.705 .8 .924 r
.34657 .42049 .3574 .43026 .37497 .42109 .36418 .41213 Mtetra
.749 .826 .912 r
.36418 .41213 .37497 .42109 .39273 .40911 .38198 .40164 Mtetra
.812 .862 .886 r
.38198 .40164 .39273 .40911 .41071 .39244 .39998 .38747 Mtetra
.885 .899 .834 r
.39998 .38747 .41071 .39244 .4289 .36871 .41821 .36743 Mtetra
.945 .92 .756 r
.41821 .36743 .4289 .36871 .44722 .33618 .43663 .33923 Mtetra
.974 .922 .673 r
.43663 .33923 .44722 .33618 .46551 .29603 .45511 .30229 Mtetra
.978 .917 .617 r
.45511 .30229 .46551 .29603 .48356 .25358 .47346 .25992 Mtetra
.974 .922 .614 r
.47346 .25992 .48356 .25358 .50129 .21565 .49149 .21879 Mtetra
.967 .937 .671 r
.49149 .21879 .50129 .21565 .51874 .1861 .5092 .18468 Mtetra
.939 .941 .766 r
.5092 .18468 .51874 .1861 .53607 .16477 .52671 .15931 Mtetra
.877 .909 .848 r
.52671 .15931 .53607 .16477 .55339 .1495 .54415 .14119 Mtetra
.803 .857 .89 r
.54415 .14119 .55339 .1495 .57078 .13805 .56163 .12797 Mtetra
.745 .811 .904 r
.56163 .12797 .57078 .13805 .58827 .1288 .57919 .11767 Mtetra
.709 .781 .908 r
.57919 .11767 .58827 .1288 .60588 .12074 .59687 .109 Mtetra
.688 .763 .909 r
.59687 .109 .60588 .12074 .6236 .11332 .61466 .10121 Mtetra
.676 .753 .908 r
.61466 .10121 .6236 .11332 .64144 .10621 .63258 .09387 Mtetra
.67 .747 .908 r
.63258 .09387 .64144 .10621 .65939 .09924 .65061 .08674 Mtetra
.667 .745 .908 r
.65061 .08674 .65939 .09924 .67747 .09233 .66876 .07971 Mtetra
.665 .743 .908 r
.66876 .07971 .67747 .09233 .69566 .08543 .68703 .07271 Mtetra
.665 .742 .908 r
.68703 .07271 .69566 .08543 .71397 .07851 .70543 .0657 Mtetra
.664 .742 .908 r
.70543 .0657 .71397 .07851 .7324 .07157 .72394 .05866 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .4747 .18237 .46439 Mtetra
.18237 .46439 .19387 .4747 .21039 .46912 .19895 .45875 Mtetra
.646 .763 .934 r
.19895 .45875 .21039 .46912 .22701 .4635 .21563 .45307 Mtetra
.21563 .45307 .22701 .4635 .24374 .45783 .23243 .44734 Mtetra
.647 .763 .934 r
.23243 .44734 .24374 .45783 .26058 .4521 .24933 .44156 Mtetra
.648 .764 .933 r
.24933 .44156 .26058 .4521 .27754 .44629 .26635 .4357 Mtetra
.65 .765 .933 r
.26635 .4357 .27754 .44629 .29461 .44034 .28348 .42974 Mtetra
.653 .767 .933 r
.28348 .42974 .29461 .44034 .31179 .43419 .30073 .42361 Mtetra
.659 .771 .932 r
.30073 .42361 .31179 .43419 .32911 .42767 .31811 .41721 Mtetra
.67 .778 .93 r
.31811 .41721 .32911 .42767 .34657 .42049 .33562 .41031 Mtetra
.69 .79 .927 r
.33562 .41031 .34657 .42049 .36418 .41213 .35328 .40253 Mtetra
.725 .812 .919 r
.35328 .40253 .36418 .41213 .38198 .40164 .37112 .39315 Mtetra
.778 .844 .901 r
.37112 .39315 .38198 .40164 .39998 .38747 .38915 .38095 Mtetra
.848 .882 .864 r
.38915 .38095 .39998 .38747 .41821 .36743 .40741 .36402 Mtetra
.918 .912 .798 r
.40741 .36402 .41821 .36743 .43663 .33923 .42589 .33999 Mtetra
.963 .923 .713 r
.42589 .33999 .43663 .33923 .45511 .30229 .44451 .3071 Mtetra
.978 .919 .64 r
.44451 .3071 .45511 .30229 .47346 .25992 .4631 .26656 Mtetra
.976 .918 .608 r
.4631 .26656 .47346 .25992 .49149 .21879 .48145 .22372 Mtetra
.971 .929 .635 r
.48145 .22372 .49149 .21879 .5092 .18468 .49946 .18543 Mtetra
.957 .942 .717 r
.49946 .18543 .5092 .18468 .52671 .15931 .51718 .15557 Mtetra
.911 .929 .812 r
.51718 .15557 .52671 .15931 .54415 .14119 .53477 .13398 Mtetra
.839 .884 .873 r
.53477 .13398 .54415 .14119 .56163 .12797 .55236 .11848 Mtetra
.771 .832 .899 r
.55236 .11848 .56163 .12797 .57919 .11767 .57001 .10681 Mtetra
.725 .794 .907 r
.57001 .10681 .57919 .11767 .59687 .109 .58776 .09735 Mtetra
.697 .77 .908 r
.58776 .09735 .59687 .109 .61466 .10121 .60563 .08908 Mtetra
.681 .757 .909 r
.60563 .08908 .61466 .10121 .63258 .09387 .62361 .08145 Mtetra
.673 .75 .908 r
.62361 .08145 .63258 .09387 .65061 .08674 .64172 .07413 Mtetra
.668 .746 .908 r
.64172 .07413 .65061 .08674 .66876 .07971 .65995 .06696 Mtetra
.666 .744 .908 r
.65995 .06696 .66876 .07971 .68703 .07271 .67831 .05984 Mtetra
.665 .743 .908 r
.67831 .05984 .68703 .07271 .70543 .0657 .69678 .05273 Mtetra
.664 .742 .908 r
.69678 .05273 .70543 .0657 .72394 .05866 .71538 .0456 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47641 Mtetra
.10523 .47641 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .46439 .17073 .45396 Mtetra
.17073 .45396 .18237 .46439 .19895 .45875 .18737 .44825 Mtetra
.646 .763 .934 r
.18737 .44825 .19895 .45875 .21563 .45307 .20412 .44251 Mtetra
.20412 .44251 .21563 .45307 .23243 .44734 .22097 .43671 Mtetra
.647 .763 .934 r
.22097 .43671 .23243 .44734 .24933 .44156 .23794 .43087 Mtetra
.23794 .43087 .24933 .44156 .26635 .4357 .25502 .42496 Mtetra
.649 .764 .933 r
.25502 .42496 .26635 .4357 .28348 .42974 .27222 .41897 Mtetra
.651 .766 .933 r
.27222 .41897 .28348 .42974 .30073 .42361 .28953 .41285 Mtetra
.655 .768 .932 r
.28953 .41285 .30073 .42361 .31811 .41721 .30697 .40651 Mtetra
.664 .774 .931 r
.30697 .40651 .31811 .41721 .33562 .41031 .32454 .3998 Mtetra
.679 .783 .929 r
.32454 .3998 .33562 .41031 .35328 .40253 .34226 .39243 Mtetra
.705 .8 .924 r
.34226 .39243 .35328 .40253 .37112 .39315 .36014 .38386 Mtetra
.749 .826 .912 r
.36014 .38386 .37112 .39315 .38915 .38095 .37821 .37315 Mtetra
.812 .863 .886 r
.37821 .37315 .38915 .38095 .40741 .36402 .39649 .35875 Mtetra
.885 .899 .834 r
.39649 .35875 .40741 .36402 .42589 .33999 .41501 .33842 Mtetra
.945 .92 .756 r
.41501 .33842 .42589 .33999 .44451 .3071 .43373 .30989 Mtetra
.974 .922 .673 r
.43373 .30989 .44451 .3071 .4631 .26656 .45251 .27257 Mtetra
.978 .917 .617 r
.45251 .27257 .4631 .26656 .48145 .22372 .47116 .2298 Mtetra
.974 .922 .614 r
.47116 .2298 .48145 .22372 .49946 .18543 .48949 .18829 Mtetra
.967 .937 .671 r
.48949 .18829 .49946 .18543 .51718 .15557 .50748 .15385 Mtetra
.939 .941 .766 r
.50748 .15385 .51718 .15557 .53477 .13398 .52526 .12818 Mtetra
.876 .909 .848 r
.52526 .12818 .53477 .13398 .55236 .11848 .54296 .10982 Mtetra
.803 .857 .89 r
.54296 .10982 .55236 .11848 .57001 .10681 .56071 .09636 Mtetra
.745 .811 .904 r
.56071 .09636 .57001 .10681 .58776 .09735 .57854 .08585 Mtetra
.709 .781 .908 r
.57854 .08585 .58776 .09735 .60563 .08908 .59648 .07697 Mtetra
.688 .763 .909 r
.59648 .07697 .60563 .08908 .62361 .08145 .61454 .06897 Mtetra
.676 .753 .908 r
.61454 .06897 .62361 .08145 .64172 .07413 .63273 .06141 Mtetra
.67 .747 .908 r
.63273 .06141 .64172 .07413 .65995 .06696 .65104 .05408 Mtetra
.667 .745 .908 r
.65104 .05408 .65995 .06696 .67831 .05984 .66947 .04683 Mtetra
.665 .743 .908 r
.66947 .04683 .67831 .05984 .69678 .05273 .68803 .03961 Mtetra
.665 .742 .908 r
.68803 .03961 .69678 .05273 .71538 .0456 .70671 .03238 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47641 .09322 .46613 Mtetra
.09322 .46613 .10523 .47641 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45396 .15895 .4434 Mtetra
.15895 .4434 .17073 .45396 .18737 .44825 .17565 .43763 Mtetra
.17565 .43763 .18737 .44825 .20412 .44251 .19246 .43182 Mtetra
.646 .763 .934 r
.19246 .43182 .20412 .44251 .22097 .43671 .20938 .42596 Mtetra
.20938 .42596 .22097 .43671 .23794 .43087 .22641 .42005 Mtetra
.647 .763 .934 r
.22641 .42005 .23794 .43087 .25502 .42496 .24356 .41409 Mtetra
.648 .764 .933 r
.24356 .41409 .25502 .42496 .27222 .41897 .26082 .40805 Mtetra
.65 .765 .933 r
.26082 .40805 .27222 .41897 .28953 .41285 .2782 .40191 Mtetra
.653 .767 .933 r
.2782 .40191 .28953 .41285 .30697 .40651 .2957 .3956 Mtetra
.659 .771 .932 r
.2957 .3956 .30697 .40651 .32454 .3998 .31334 .389 Mtetra
.67 .778 .93 r
.31334 .389 .32454 .3998 .34226 .39243 .33111 .38191 Mtetra
.69 .79 .927 r
.33111 .38191 .34226 .39243 .36014 .38386 .34904 .37393 Mtetra
.725 .812 .919 r
.34904 .37393 .36014 .38386 .37821 .37315 .36715 .36433 Mtetra
.778 .844 .901 r
.36715 .36433 .37821 .37315 .39649 .35875 .38546 .3519 Mtetra
.849 .882 .864 r
.38546 .3519 .39649 .35875 .41501 .33842 .40401 .33471 Mtetra
.918 .913 .798 r
.40401 .33471 .41501 .33842 .43373 .30989 .42278 .31036 Mtetra
.963 .923 .713 r
.42278 .31036 .43373 .30989 .45251 .27257 .44172 .27711 Mtetra
.978 .919 .64 r
.44172 .27711 .45251 .27257 .47116 .2298 .46062 .23617 Mtetra
.977 .918 .608 r
.46062 .23617 .47116 .2298 .48949 .18829 .47927 .19293 Mtetra
.971 .929 .635 r
.47927 .19293 .48949 .18829 .50748 .15385 .49757 .15429 Mtetra
.957 .942 .717 r
.49757 .15429 .50748 .15385 .52526 .12818 .51558 .12412 Mtetra
.911 .929 .812 r
.51558 .12412 .52526 .12818 .54296 .10982 .53344 .10226 Mtetra
.839 .883 .873 r
.53344 .10226 .54296 .10982 .56071 .09636 .55129 .08651 Mtetra
.771 .832 .899 r
.55129 .08651 .56071 .09636 .57854 .08585 .5692 .07462 Mtetra
.725 .794 .907 r
.5692 .07462 .57854 .08585 .59648 .07697 .58723 .06493 Mtetra
.697 .77 .908 r
.58723 .06493 .59648 .07697 .61454 .06897 .60537 .05645 Mtetra
.681 .757 .909 r
.60537 .05645 .61454 .06897 .63273 .06141 .62363 .04861 Mtetra
.673 .75 .908 r
.62363 .04861 .63273 .06141 .65104 .05408 .64202 .04107 Mtetra
.668 .746 .908 r
.64202 .04107 .65104 .05408 .66947 .04683 .66053 .03368 Mtetra
.666 .744 .908 r
.66053 .03368 .66947 .04683 .68803 .03961 .67917 .02634 Mtetra
.665 .743 .908 r
.67917 .02634 .68803 .03961 .70671 .03238 .69794 .01901 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .4434 .14703 .43272 Mtetra
.14703 .43272 .15895 .4434 .17565 .43763 .16379 .42688 Mtetra
.16379 .42688 .17565 .43763 .19246 .43182 .18066 .42099 Mtetra
.646 .763 .934 r
.18066 .42099 .19246 .43182 .20938 .42596 .19765 .41507 Mtetra
.19765 .41507 .20938 .42596 .22641 .42005 .21474 .40909 Mtetra
.647 .763 .934 r
.21474 .40909 .22641 .42005 .24356 .41409 .23196 .40307 Mtetra
.23196 .40307 .24356 .41409 .26082 .40805 .24928 .39698 Mtetra
.649 .764 .933 r
.24928 .39698 .26082 .40805 .2782 .40191 .26673 .3908 Mtetra
.651 .766 .933 r
.26673 .3908 .2782 .40191 .2957 .3956 .2843 .38449 Mtetra
.655 .768 .932 r
.2843 .38449 .2957 .3956 .31334 .389 .302 .37796 Mtetra
.664 .774 .931 r
.302 .37796 .31334 .389 .33111 .38191 .31983 .37105 Mtetra
.679 .783 .929 r
.31983 .37105 .33111 .38191 .34904 .37393 .33781 .36348 Mtetra
.705 .8 .924 r
.33781 .36348 .34904 .37393 .36715 .36433 .35597 .3547 Mtetra
.749 .826 .912 r
.35597 .3547 .36715 .36433 .38546 .3519 .37431 .34376 Mtetra
.812 .863 .886 r
.37431 .34376 .38546 .3519 .40401 .33471 .39289 .3291 Mtetra
.885 .899 .834 r
.39289 .3291 .40401 .33471 .42278 .31036 .4117 .30849 Mtetra
.945 .921 .756 r
.4117 .30849 .42278 .31036 .44172 .27711 .43073 .27962 Mtetra
.974 .922 .673 r
.43073 .27962 .44172 .27711 .46062 .23617 .44983 .24191 Mtetra
.978 .917 .617 r
.44983 .24191 .46062 .23617 .47927 .19293 .4688 .19873 Mtetra
.974 .922 .614 r
.4688 .19873 .47927 .19293 .49757 .15429 .48743 .15684 Mtetra
.967 .937 .671 r
.48743 .15684 .49757 .15429 .51558 .12412 .50571 .12206 Mtetra
.939 .94 .766 r
.50571 .12206 .51558 .12412 .53344 .10226 .52376 .09611 Mtetra
.876 .909 .848 r
.52376 .09611 .53344 .10226 .55129 .08651 .54174 .07748 Mtetra
.803 .857 .89 r
.54174 .07748 .55129 .08651 .5692 .07462 .55976 .06379 Mtetra
.745 .811 .904 r
.55976 .06379 .5692 .07462 .58723 .06493 .57786 .05305 Mtetra
.709 .781 .908 r
.57786 .05305 .58723 .06493 .60537 .05645 .59608 .04395 Mtetra
.688 .763 .909 r
.59608 .04395 .60537 .05645 .62363 .04861 .61442 .03573 Mtetra
.676 .753 .908 r
.61442 .03573 .62363 .04861 .64202 .04107 .63289 .02795 Mtetra
.67 .747 .908 r
.63289 .02795 .64202 .04107 .66053 .03368 .65148 .02039 Mtetra
.667 .745 .908 r
.65148 .02039 .66053 .03368 .67917 .02634 .67021 .01292 Mtetra
.665 .743 .908 r
.67021 .01292 .67917 .02634 .69794 .01901 .68905 .00548 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooeKlD]`0
07oo0000Egoo003EOol30003Ool5D_`01000D_aoo`00EWoo003BOol30004Ool02e;LE_aBg5KlD]aF
o5;L001Bg5Kl0000EWoo003@Ool20003Ool;D_`01@00D_aBo5;l0000EGoo003=Ool30003Ool04e;L
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aoo`0005Aoo`00bgoo0P000goo0e;l00=Fo5;l
D_`02U;l00<005;lD_`00U;l00<007ooOol0DWoo0038Ool3000077oo001ooeKlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aoo`00Dgoo001WOol20002Ool2001IOol20003
Ool015Kl001Fo5;l0eKl0e;l00=Fo5;lD_`02E;l00<005;lD_`00U;l00=oo`00Ool0DGoo001XOol0
1000Oomoo`00Egoo0`000goo01mFo5LLE_aFo5;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_`005KlD]aFo5;LOol0001BOol006Uoo`8005Ioo`8000Aoo`06EaaFo5KlE_aG75;l0eKl
00ABo5KlE_aFo0=Bo003E_aBo5;l00MBo004001Bo5;lD]`2D_`00goo001oo`1@Ool006Uoo`8005=o
o`<000Aoo`0RE_aG75KlEaaFo5LLE_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_`005KlD]aFo5;LE_`2Ool00`00Oomoo`1>Ool006Qoo`04001oogoo001@Ool20005Ool3Fa`3
E_`00eLLE_aFo002E_`025;lE_aBo5KlD_aFo5;lE_`;D_`00`00D]aBo002D_`015;LD_aoo`00D7oo
001WOol20002Ool2001<Ool30004Ool0:e/LEaaK75KlFaaG75/LE_aG75KlEaaBo5LLD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo000D_aBg5KlD]aBo5;LE_aoo`0004moo`00]Woo
0`000Woo00@007ooOomoo`9O?0=K7004EaaK75/LFa`8E_`015;lE_aBo5Kl3E;l00@005;lD_aBg0=B
o003D]`0000004moo`00]7oo0P001goo02mK6ellFcaO?5/KFaaG75/LE_aK75KlFaaBo5LLD_aFo5;l
EaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`005KlD]aBo5;LE_aBg5;lD]aoo`00
04ioo`00/Goo0`001goo1ell00EG75/LFaaG75Kl00=G70IFo003D_aFo5;l009Bo003E_aBo5;l00UB
o003001Bo5;l009Bo007D]aBo5;lD_aBg7oo0000CGoo002_Ool20009Ool03fMlHe]O?5/lGcaK6ell
FcaO?5KlFaaFo5/LE_aK7002E_`08U;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aoo`004Goo1@00=goo002/Ool3000:Ool2Ie/00fMlHe]O
?003Gc`2Fa`00e/lE_aG7002Ea`01EKlEaaG75KlD_`00eKl0e;l00EFo5;lD_aBo5Kl00UBo004001B
o5;lD]`3D_`01U;LD_aBo5;lOol0011oo`05001oogooOol0000gOol00:Yoo`8000]oo`0DHe]WO6=K
IgaSFfMlHe]O?5/LFcaK75llFaaK?5KlFaaFo5/LE_aG709Fo00RD_aFo5;lE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LD_aBg5KlD]aBo7oo000@Ool00`00Oomoo`0h
Ool00:Moo`<0009oo`03001oogoo00Moo`05He]WFfMKIgaSF`02Ie/01F=LGcaK75/LFc`00e/L00EK
?5KlE_aFo5LL00AFo004D_aFo5;lE_`3D_`01EKlD_aBo5;lE_`01e;l00<005;LD_`00U;l00EBg5;l
D_aBo5;L00=Bo003001oogoo00Eoo`H000Aoo`03001oogoo03Moo`00YGoo0P003Woo0VnJ00aSFfMl
He]WO6=KHeaO>f=LFaaO?5/LFc`2Fa`0:eLLFaaFo5LLE_aG75KlEaaBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`00015oo`03001o
ogoo03Ioo`00XWoo0`003goo16nJ00USFfMKHcaSG5llHeaS?6=LEa`00e/L00AG75/LFaaG70IFo006
D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01e;l00@005;lD_aBg0=Bo005D]aBo5;lD_aBg002D_`00goo
001oo`0@Ool00`00Oomoo`0eOol007Eoo`@002Moo`80015oo`=_VP0kKi]_VVnJGc]SG5lkHeaO>f=L
FcaO?5KlFaaG75/LE_aK75LLE_aBo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`0000=Ool01@00Oomoogoo0000=goo
001dOol00`00Oomoo`02Ool00`00Oomoo`0QOol3000BOol6KiX2Jg/00ellHeaS?005Gc`015LLFaaK
75/L0eLL1eKl00=Bo5KlD_`00U;l00=Fo5;lD_`02E;l00<005;lD_`00U;l00EBg5;lD_aBo5;L00=B
o004D]aBo7oo000=Ool3000hOol007Aoo`03001oogoo009oo`03001oogoo01ioo`<001Aoo`=_VP0E
Ki]_VVnJIgY[VfMkJi]K6ellFcaO?5/KGcaK?5/LE_aK75KlFaaFo5/L009Fo00XD_aG75;lE_aBo5Kl
D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo7oo0017Ool007Aoo`03001oogoo009oo`03001oogoo01aoo`80009oo`03001oogoo015oo`03
MkMg^6nJ009_VPE[N`03Ie]WO5ll00IO?003EaaFo5LL009G7003E_aG75Kl00EFo0=Bo005E_aBo5;l
D_aFo00:D_`00`00D_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000Agoo001dOol00`00Oomo
o`02Ool00`00Oomoo`0IOol3000HOol04gNhMkMg^7NgJi]WNV^KIg][Vf=KIgaSFfMlFa]O?5/lGcaK
75ll009K700_E_aK75KlFaaFo5/LD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg000D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol00016Ool007Aoo`03001oogoo
009oo`03001oogoo01Moo`8001Yoo`04MkQg]gNhMkL2LkT2Jg/2Ie/01FMlHe]WFfMKIg`00e/L00IK
?5/LFaaK75LLE_`3Ea`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l00D005;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`13Ool007Aoo`03001oogoo009oo`03001oogoo01Aoo`<0
01aoo`0LMkMg^7NgLkUcV7NiLiUWO6=KIgaSFfMlHe]WO5lkHeaK75llFaaK?5/LGcaK75LLE_aG75Kl
Ea`2E_`0:5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`00AGoo001eOol4000EOol2000NOol017NgMkQg]gNh0W>i
00EcVFnJKiYWO6=K009WF`05IgaO?6=LHcaSG003Fa`01E/lFaaK75/LEa`00eKl00UG75KlE_aBo5Kl
D_aFo5;lE_`00e;l00=Fo5;lD_`025;l00<005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;l
D_aoo`00A7oo002;Ool3000OOol01gNgMkQg]gNhLiQg^G>I009_VP11Ki]_VVMlHe]SG5lkHeaO>f=L
Gc]K?5/LGcaG75/LE_aK75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol00013Ool008Uo
o`80009oo`03001oogoo01eoo`03MkQg]gNh009c^@03LiUc^FnJ00A_VP0:HeaO?6=LHcaSG5llHeaS
?5/LEa`3Fa`00eLLFaaFo007E_`015;lE_aBo5Kl3U;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo7oo0000@goo0026Ool3000SOol02GNhMkMg^7>HMkUcVG>iKiY_V`03KiX0@6^K
Ig]SG5lkHeaO>f=LGc]O?5/lFaaFo5/LEaaK75KlFaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aoo`00@Woo0024Ool2000VOol2Nk@017NfNkIcVG>i1FnJ16]k00=SG5llHe`015ll0U/L15LL00=F
o5LLE_`01EKl0e;l00=Fo5;lD_`035;l00<005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg002D_`00goo001oo`10Ool0085oo`<002Moo`08NkAk]GNDNmIg]W^fKiY_V`9_VP14IgY[VfMk
Ji]WNV^KIg]O?5/KGcaK?5llFa]O?5KlFaaFo5/LE_aK75KlEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlOol0045oo`00OWoo0`00:Woo0W^d00Mk]WNfNkIg]gNhMkMg^007Jg/2Ie/4Gc`00e/lFaaK
7002Ea`015KlEaaG75LL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005001Bo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00QBg5;lD_aBo5;LD_aoo`00@7oo001lOol2000/Ool08G^eMiAkeWNfNkIg
]GNhMkMg^7>HMkUWNf^KIgY[Vf=KIgaSFfMlHe]K?5/LGcaK75/lFaaO?5KlFaaFo5/LE_aG7002E_`0
;U;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`00?goo001iOol30002Ool2000ZOol027^dNkEg
]W^fMkIg^7NgMkP2LkT01G>ILkUc^FMlHe/00VMK00EWO6=KHeaS?5/l00=K7005FcaK75/LE_aG7003
E_`00eLLD_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;l001Bo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000?goo001gOol2000`Ool06WNDNkEg]W^f
MkEg^7NgMkQg]gNiLiUc^G>HKi]_VVMlHe]WO6=KHeaO>f=LGc]K?5/LGc`2Fa`0=eKlFaaFo5LLE_aG
75KlEaaBg5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`005;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0003ioo`00M7oo0`00<Woo00Yk]GNf
NkIg]WNhMkMg^7NgLkUcV@9c^@=_VP0;Ie]WO5llHeaS?6=LGcaSG6<lFaaG7003Fa`015LLE_aFo5LL
15Kl00QBo5KlD_aFo5;lE_aBo5Kl35;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l0Woo00<007ooOol0>goo001bOol2000dOol03G^eNkAk]WNeNmIg]gNhMkMg^G>I
LkUcV6nK00=_VP15Ki]O>f=LGc]SG5lkHeaO>ellFcaK75KlFaaG75/LE_aG75;lE_aBo5LLD_aFo5;L
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0003eoo`00Kgoo0`00=Woo00Uk]7^fMkIk]WNgMkQg
]g>iLiT00W>i1FnJ0V]k00AS?6=LGcaSG0AO?09K7004EaaK75LLEa`8E_`3D_`00eKlD_aBo00=D_`0
0`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l009oo`03001o
ogoo03Yoo`00KGoo0P0000=oo`00Ool0=Goo00akTW^cNi=k]7^CNkEgU7_FMkIk]WNeKi/3KiX0AVnK
Ig][VfMjJi]WNellFa]O?5/lGcaK6ellE_aK75KlFaaFo5/LE_aG75;lE_aBo5KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;L0Woo00<007ooOol0>Goo001ZOol3000jOol3Nk<02G^CNkAk]7^eMkIk
]WNfMkQg]`02KiX6Jg/2Ie/5Gc`2Fa`2Ea`015KlEaaG75LL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l
00]Bo004001Bo5;lD]`3D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0
000kOol006Moo`<003aoo`0UNk=kTW^dNi=k]7NDNkEg]W^fMkEkeWNgMkQg]f^KIg][VfMjJi]WNfMl
He]WO5/lGcaK6ellFaaK?5/LGcaFo5/LE_aK75KlEa`00UKl03=Bo5KlD_aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg7oo0000>Woo001UOol2000oOol03G^CNk=kTg^cNkAk]G^dNkIg]W^fMkMg
^7Ng009c^@=[N`08He]WFfMKIgaSFfMKFaaK?0=K7003FcaK75LL009G70=Fo003EaaBo5Kl009Fo004
D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<007ooOol0>7oo001ROol30010Ool0G7^BOk=kTg^d
Ni=k]G^dNkIg]G_FMkIg^7NgMkUcVG>iLiQg^F=KIgaSFfMlHe]WO5lkHeaK75/lFaaO?5/LFcaK75LL
E_aG75KlEaaFo5LLD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`005Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L000iOol0
061oo`8004=oo`05Nk=kTg^cNk=k]@02Nk@01WNfNkIg]WNhMkMg^0Ac^@9_VP0:Ie]WO6=KHeaS?6=L
GcaSG5/LFc`4Fa`015LLE_aFo5LL15Kl00QBo5KlD_aFo5;lE_aBo5Kl35;l00EBg000D_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QBg5;lD_aBo5;LD_aoo`00>7oo001MOol3
00000goo001oo`11Ool017ncNi9k]7^C0W^d00]k]GNeNmIg]WNhMkMg^7>ILkUcV7Ni00=_VP1:Ki]_
VV=LGc]SG5lkHeaO>f=LEaaK75KlFaaG75/LE_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`003Qoo`00Fgoo0P00Agoo00AkTW^cNk=k/`=k]005NkIg]W^f
MkMg^004LkT5KiX2Jg/01F=LGcaSG6<lHe`00Ull0U/L00AG75/LFaaK70QFo004D_aFo5;lE_`?D_`0
0`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
0e;LOol0000gOol002ioo`@002Ioo`<004Qoo`0@Ni9k/g^CNkAkTg^eMiAkeWNfNkIg]gNhLiUc^G>H
MkT3KiX0CVnKKiY[VfMjJi]O>f=LGc]O?5/lGcaK6ellEaaK75KlFaaFo5/LD_aG75;lE_aBo5LLD_aF
o5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0029oo`<0015oo`00;Goo00<0
07ooOol00Woo00<007ooOol08Goo0P00Bgoo0g^c00akTg^cNi=k/g^CNk=k]7^eMkIk]WNfNkH5KiX5
Jg/8Gc`2Ea`015KlEaaG75LL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00]Bo004001Bo5;lD]`3D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`0SOol0
0`00Oomoo`0?Ool0039oo`03001oogoo01eoo`@004aoo`0ONk=kTWncNi9o/g^BOk=kTg^dNi=k]G^d
NkIg]G_FMkMg^6nJKi]_VV^KIgY[VfMkJi]SFfMlFcaO?5/KGc`00U/l049K75llE_aK75KlFaaFo5/L
D_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000SOol0
0`00Oomoo`0?Ool002Eoo`H000Moo`03001oogoo01aoo`<004ioo`9kT`9kTP03Ni=k/g^B009k/`0:
NkEk]7^fMkIk]WNfMkQg]gNhMkL4Jg/2Ie/01FMlHe]WFfMKFc`00e/L00=K?5/LEa`00ULL0eKl00=G
75;lE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;l001Bg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol0025oo`03001o
o`00011oo`00;Woo100077oo0`00D7oo00UkTWncNi9o/g^BOk=kTW^dNi<00W^d01mk]GNeNmIg]WNh
MkMg^7NgLkUcV7NiHe]WO6=KIgaSFfMlHe]SG5lkFcaK75llFaaK?5/LEaaFo5LLE_aG7002E_`0>E;l
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000QOol00`00
Ool0000@Ool002ioo`03001oogoo01Yoo`<005=oo`06Ni=kTW^BNi9k/g^B0g^c0W^d00Mg]W^fMkIg
^7NgMkQg]`03LkT2KiX00fMKIgaSF`02Ie/01F=LGcaSG5/LFc`015/L00AG75KlE_aG70AFo008D_aF
o5;lE_aBo5KlD_aFo0aBo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo002000OOol01@00Oomoogoo00003goo000^Ool00`00
Oomoo`0HOol2001EOol05GncNi9o/g^BOk=kTW^cNi=k]7^CNkEgU7_FMkIg^7NgMkQg]gNhLiQg^@03
KiX0D6nKHe]WO5lkHeaO>f=LGc]SG5LLFaaFo5/LEaaK75KlEaaFo5LLD_aG75;lE_aBg5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000NOol01@00Oomoogoo0000
3goo000^Ool5000COol3001GOol02G^BNi=kTW^cNi9k/g^CNk=kT`02Nk@01g^fMkIk]WNgMkQg]gNh
009c^@I_VP06HcaSG5llHeaS?6=L0Ull0U/L00AG75/LFaaK70QFo004D_aFo5;lE_`?D_`00`00D]aB
o002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aB
o5;lD]aBo7oo000MOol3000017oo000000003Woo0014Ool2001IOol057^BOk=kTWncNi9k/g^BNkAk
Tg^dMiAk]GNfNkIg]gNhMkMg^7>HMkT3KiX0DfnKKiY_VVMjJi]O>f=LGc]O?5/lGcaK6ellEaaK75Kl
FaaFo5/LD_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo000
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo7oo00002Goo100097oo0011Ool300000goo001oo`1HOol2Ni<02W^cNi9kTW^CNk=k
Tg^cNkAk]G^C0W^c00=k]G^dNk@00W>i1VnJ16]k25ll0ULL00AFo5LLEaaG70AFo004D_aFo5KlE_`3
D_`00eKlD_aBo00<D_`00`00D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo0007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol0
03moo`8005ioo`1[Ni9o/g^BOk=kTWncNi=k]7^BOk=kTW^dNi=k]G^dNkEg]G_FMkMg^6nJKi]_VV^K
IgY[VfMkJi]SFfMlFcaO?5/KGcaK?5llFaaO?5KlFaaFo5/LE_aK75;lE_aBo5KlD_aFo5;lE_aBg5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol00007Ool00`00Oomoo`02
Ool00`00Oomoo`0QOol003aoo`<005moo`9kT`=kTP06Nk=kTW^BNi9k/g^B0g^c0g^d00Ik]WNfMkQg
]gNhMkL5Jg/016MKIgaSFfMK0ell0U/L00=K?5/LEa`00ULL0eKl00=G75;lE_`00UKl00ABo5KlD_aF
o0=Bo003E_aBo5;l00IBo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00001Woo00<007ooOol00Woo
00<007ooOol08Goo000jOol2001ROol037ncNi9o/g^BOk=kTWncNi9o/g^BNk=kT`9k]00ONkEgU7_F
MkIg^7NgMkQg]g>iLiQ[VfMkJi]SFfMlHe]WO6=KIgaK75/lFaaO?5/LFcaK75LLE_aG75KlEa`00UKl
03aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_`2Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003Moo`<006=oo`0:Ni=kTW^B
Ni9k/g^BNi=kTW^cNi83Nk<02G^CNkAk]7^eMkIk]WNgMkQg]`05LkT00fMKIgaSF`02Ie/01FMlGcaS
G5/LFc`015/L00AG75KlE_aG70AFo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_`005;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo003Ool007oo00Aoo`03001oogoo009oo`03001oogoo025oo`00=Goo0P0000=oo`00Ool0
Hgoo06ekTWncNi=o]7^COk=kTWncNi9k/g^BNkAkTg^eMiAk]GNfNkIg]gNhMkMg^7>HMkUcVG>iKiY_
Vf=KIgaSFf=LGc]SG5lkHeaG75/LE_aK75LLFaaFo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg002Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0QOol0039oo`<006Moo`04Ni9kTg^DNk@3Ni<03g^cNi9kTW^CNk=k
Tg^cNkAk]GNfNkIg]WNhMkMg^004LkT4KiX2He`015llHeaSG6=L0Ull0U/L00EG75/LFaaK75LL00MF
o004D_aFo5;lE_`@D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo0<000Aoo`@002Aoo`00;goo0`00JWoo01]k
]G^DOkAkTgndNi9o/g^BNk=kTWncNi=k]7NDNkEk]7^fMkEg^7NgMkQcV7NiLiUc^FnJKi/00VnJ05EW
NV^KGc]SG5lkGcaK?5llFa]O?5LLFaaFo5/LE_aK75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000/Ool002eoo`80
06aoo`03NkEkU7^e00AkT`=kTP06Nk=kTg^cNk=k]G^d0g^c0W^d17>i16nJ1F]k1ell0ULL00AFo5LL
EaaG70AFo004D_aFo5KlE_`3D_`00eKlD_aBo00;D_`200000e;lD]aBo002D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomo
o`0002]oo`00:Woo0`00KWoo015kU7neNi=o]7^COk=kTW^cNi9o/g^BNkAkTgncNi9k/g^C009k]00b
NkEg]G_FMkIk]VnJKi]_VV^KIgY[VfMkJi]WNVMlHe]O?5/KGcaK?5llFaaO?5KlFaaFo5/LE_aK75;l
E_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg0<0000ZD]aFo000D_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5Kl0Woo00<007ooOol0:7oo000XOol200000goo001oo`1]Ool00g^DNkEkU002Ni<01G^d
Ni9kTg^BNk<00g^B00=k/g^BNk<00W^c00UkTg^dNkAk]WNfNkIg]gNhMkL01V]k00=WO6=KIe/00ell
0U/L00=K?5/LEa`00ULL0eKl00=G75;lE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00=Bo0<00006
D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol002Yoo`009Woo0P00LWoo035o]G^DOkAk
TgndNi9o/g^BOk=kTWncNi9o/g^BNk=kTW^dNi=k]GNDNmIg]W^fMkEg^7NgLkUcV6^KIg][Vf=KIgaS
FfMlHe]WO5/LFcaK75llFaaK?5/LEaaFo5LLE_aG7002E_`03U;lE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_`20000<E;LE_aBg5KlD]aFo5;LE_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L009oo`03001oogoo
02Moo`009Woo0P00LGoo00Ek]G^DNkEkTg^d00=kT`0CNk=kTW^CNi9k/g^BNk=kTW^cNi=k/g^dNkEg
]W^fMkIg^7NgMkP017>i00=WFfMlHe/00VMK00EWO5llHeaK75/l00AK7004EaaFo5KlEa`4E_`015;l
E_aBo5Kl0e;l00=Fo5;lD_`00`001e;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009o
o`03001oogoo02Ioo`009Woo0`00L7oo03akU7^eNi=o]7^COk=kTWncNi9o]7^BOk=kTW^cNi9o/g^C
NkAgU7^eMkIk]WNeMkQg]gNhLiQg^G>ILkU_VVnKHe]WO6=KHeaO>f=LGc]SG5lkFaaFo5/LEaaK75Kl
EaaFo5LLD_aG75;lE_aBg5KlD_aFo5;LE_`30000>UKlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00:7oo000VOol01000Oomoo`00KWoo00AkU7^eNiAk]0Mk
T`06Nk=kTW^BNi9k/g^C0W^c00Mk]GNfNkIg]WNhMkMg^004LkT4KiX2He`015llHeaSG6=L0ell00=K
75LLFa`00U/L00=G75KlE_`01EKl00=Bo5Kl00000P003e;l00EBg5;lD_aBo00000=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;L
D_aBo5;l0Woo00<007ooOol09Goo000UOol00`00Oomoo`02Ool00`00Oomoo`1[Ool077^eNiAo]7^C
OkAkTWncNiAo]7^COk=kTW^cNi9o/g^BNkAkTg^eNkAk]WNeNmIg]gNhMkMg^G>I0VnJ01U_VfnJKiYW
NV^KGc]SG5lkHeaK?5llFa]O?5LLFaaFo5/LE_aK75KlEaaBo5KlD_aG70030000@EKlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0000
9goo000UOol00`00Oomoo`03Ool00`00Oomoo`1YOol00g^eNiAk]@03Ni<00g^eNiAkT`02Ni<3Ni80
0g^cNi9k/`02Nk<01g^dNkIg]W^fMkMg^7Ng009c^@E_VPE[N`MO?09G7004E_aG75LLEa`2E_`30003
E_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001o
o`0UOol002Eoo`03001oogoo00Aoo`03001oogoo06Qoo`0ENiAo]GNENkIgUGneNiAk]G^COkAkTW^c
Ni9o/g^BNk=kTg^dNi9k/g^C009k]007NkEgU7_FMkIg^7NgKi/00VnJ00YWNV^KIg][VfMjIgaSFell
Fa]O?09K?006FaaO?5KlFaaFo5/L0`0004IFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg09oo`03001oogoo02=o
o`009Goo0P001Woo0P00Igoo00mgUgNgNiIk]W^FNkIkU7^eNi=k]7^BNi=kTW^cNi800g^c00EkTW^c
Nk=k/g^C009k]007NkEg]W^fMkMg^7NgMkP016]k00=WFfMlHe/00VMK00IK?5/LFaaK75/lFa`2Ea`2
0002E_`00eLLD_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0002Eoo`009Goo00<007ooOol01goo00<007ooOol0
Hgoo02mgUg^hMiMk]WNENkIkU7^eNiAo]7^COk=kTWncNi9k/g^BOk=kTW^cNi9k]7^CNkEgU7^eMkIk
]WNgMmQg]gNhLiQg^G>IIgaSFfMlHe]WO6=KHeaO>e/lFaaO?5/L00<00004E_aG75KlEa`2E_`0BE;l
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002Aoo`009Goo00<007ooOol027oo00<007ooOol0HWoo00Ug
]gNGNkIkUW^fNiIk]G^DNk@00g^C00=k/g^BNi<00W^C0g^B00]k/g^CNk=k]7^eNkAk]WNfMkQg]gNh
00=c^@9_VP03IgaSFfMK009SG003GcaSG6=L00<0009K7004EaaFo5KlEa`4E_`015;lE_aBo5Kl0e;l
00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`00
02=oo`009Goo00<007ooOol02Goo00<007ooOol0H7oo029k^7NGMkMgUG^fMiEk]G^DOkEkTgndNi9o
/g^BOkAkTWncNi9k/g^BOk=kTg^dMiAk]G^dNkIg]GOHMkMg^7>HMkUcV@9_VP06Ki]_VVnJGc]SG5lk
0`0005IO>e/LE_aK75LLFaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`008goo
000TOol2000<Ool00`00Oomoo`1OOol2MiL01W^FNkIkUW^eNiAk]@UkT`9kTP0;Nk=kTW^cNk=k]G^d
NkIg]W^fMkMg^004LkT4KiX016]k000000000V=L0ell00MK75LLFaaK75LLE_aG7006E_`3D_`00eKl
D_aBo00>D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`008Woo000T
Ool00`00Oomoo`0<Ool00`00Oomoo`1MOol09GNGMkMgUg^fMiEk]W^DOkEkU7ndNi=o/g^DOkAkTgnc
Ni9k/g^BOk=kTW^dNi=k]G^dNkEg]G_FMkMg^7>HMkUcVG>iKiY_VfnJ00<0001KIg][Ve/KGcaK?5ll
Fa]O?5/lFaaFo5/LE_aK75KlEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`00Woo00<007oo
Ool07goo000TOol00`00Oomoo`0=Ool00`00Oomoo`1KOol3MiL01W^fNiIk]W^DNkEkU09kT`03NkEk
U7^C00AkT`03Ni9k/g^B00=k/`9k]09k/`07Ni=k]7NfNkIg]W^fKiX00`0016]k00=WFfMlGc`015ll
0U/L00=G75KlEa`00ULL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`0
2E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00008Goo000TOol00`00Oomoo`0>Ool00`00
Oomoo`1JOol08GNgMiMk^7NENkIgUGneNiAk]G^CNkIkU7^eNi=o]7^BOk=kTWncNi9k/g^BNkAkTW^c
Ni9k]7^CNkEgU7_FMkIk]P0200005WNgJi]WNV^KIg][Vf=KIgaSFellFa]O?5/LFcaK75llE_aK75Kl
FaaFo5LL0UKl04eBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00021oo`0097oo00<007oo
Ool03goo00<007ooOol0F7oo0WNG00eg]g^FNkIkUW^eNiAk]G^FNkIkU7^eNi=k]003Ni<03G^cNi9k
/g^BNk=kTW^cNi9k/g^CNk=k]7^f00<00004MkQg]g>iLkT3Jg/00fMKIgaSF`02Ie/01E/lFaaK75/L
Fc`00U/L00=Fo5LLE_`00UKl00=G75;lE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`0M
Ool002Aoo`80015oo`03001oogoo05Ioo`0MLiY_NG>JLiQgVG>HNkQgUgNgMiEk]WNENkEkU7ndNi=o
/g^BOk=kTW^cNi9o/g^BNk=kTWncNi=k]00300004g^fMkEgf7NgLkUcV7NiLiUc^F=KIgaSFfMlHe]S
G5lkFcaK75ll009K701FE_aK75KlEaaFo5LLE_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lOol001moo`008goo00<007ooOol04Woo00<007ooOol0E7oo0fnJ00A_VG>ILiQgV@=gU`05NkIk
UW^eNiAk]@04Ni<3Ni801G^cNi=kTW^BNk<00`0000Ek]GNfNkIg]WNh009g]`Ac^@9_VP05He]WFf=L
HeaO?003He`025LLFaaK75/LEaaK75KlEa`4E_`01U;lE_aBo5KlD_aFo0iBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`0MOol001Yoo`@000Eo
o`03001oogoo01=oo`03001oogoo05=oo`0HKgUcVVmiMiUcV7NiMiMg]gNGNkIgUG^fNiAo]G^COkAk
TWncNi9k/g^BOk=kTW^c0`0000mk]7^CNkEk]7^fMkEgf7NgMkQcV7NiLiUc^FnJKk/00VnJ05mO>f=L
Gc]SG5lkHeaK?5llE_aK75LLFaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;L009oo`03001oogoo01]oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
57oo00<007ooOol0DGoo0VnJ00E_VG>ILiQgVG>H009gU`06MkMkUW^fNiAk]G^D17^C0W^B00Ik]000
000007^cNi83Nk<017^dNkIg]W^f0WNg17>i16nJ0V]k00=O?6=LHe`015ll00MK75LLFaaK75LLE_aG
7006E_`3D_`00eKlD_aBo00>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00U;l00=oo`00Ool077oo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0EOol00`00Oomoo`1?Ool056miLiY_NGNILiQg^G>HMkMgUg^hMiEk]WNEOkEkU7ndNi=o/g^BOk<3
00001WncNi9o/g^BNk=kT`9k]00;NkEg]G_FMkMg^7>HMkUcVG>iKiY_^`02KiX0IFMjJi]WNf^KFa]O
?5/lGcaK6ellFcaK75KlFaaFo5/LE_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg7oo000077oo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool2000GOol2001>Ool2KiX0
1FnIKiYcV7NILiP00WNG00Yg]gNGNkIkUW^eNiAk]G^CNkAkU0800006NkAkTg^CNi=k/g^B0g^c00Ak
Tg^dNk=k/`=k]003NkIg]W^f00=_VPE[N`03Ie]WO5ll00=O?0=K7003EaaFo5LL009G70AFo004D_aF
o5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo01Yoo`006Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol067oo00<007ooOol0BWoo015SFfMlIe]WO7>HMkUcV7NIMiMk^7NGNkIg
UG^fNiAk]G^C00<0000/NiAo]7^COk=kTWncNi9k/g^BNkAkTg^cNi9k]7^CNkEgU7_FMkIk]WNgMmQg
]f^KIgY[VfMkIgaSFfMlHe]WO6=KGcaK75/lFaaO?5/LEaaFo5LLE_aG709Fo01BD_aFo5;lE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L000KOol001Uoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo01Uoo`03001oogoo04Moo`05Ig]WFfMkIe]WN`02Jg/016]jJg]gUgNg0WNG00=k
UW^fNi@00`0000AkUW^eNiAk]@AkT`04Ni9k/g^BNk<3Ni802W^cNi=k]7^dNkEg]W^fMkMg^7Ng17>i
0VMK00IWO6=KIe]WFf=LGc`2Fa`01E/lEaaK75/LEa`00eKl00UG75KlE_aBo5KlD_aFo5;lE_`00e;l
00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l
00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000JOol001Uoo`03001oogoo009oo`05001oogooOol0000M
Ool00`00Oomoo`15Ool03VMlHe]WO6MKIga[NVnKJgY[NfmiLiY_NG>JMiD300007gNGNkIgUG^fNiAo
]G^COkAkTWncNi9k/g^BOk=kTW^cNi9o/g^CNkAgU7^eMkIk]WNeMmQg]g>iLiQg^G>I009_VP0=IgaS
FfMlGc]SG5lkHeaO>e/LEaaK75KlFa`00ULL05QFo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlOol000Moo`D000eoo`006Woo100017oo0P007Goo00<007ooOol0
@Woo00EWFfMkIe]WNfMK00=[N`05JgY[NfnJKiY_V@0300002G>HMiMgUgNgNiIk]W^DNkEkU004Ni<0
0g^BNi=kT`03Ni802G^cNi=k/g^dNkEk]7^fMkIg^002MkL3LkT4KiX3He`00ellHeaSG002Gc`3Fa`0
0eLLFaaK7007E_`00e;lE_aBo00?D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00001goo00D007ooOomoo`0000eoo`008Woo
00<007ooOol07Goo00<007ooOol0@7oo00]O?5mLHe]WO6MKJg][NVnKJgY[Nf]j00<0000SKgUg^G>H
MiUgUg^hMiEk]WNEOkEkU7ndNi=o/g^BNk=kTgncNi9k/g^BOk=kTW^dNi=k]G^dNkIg]GOHMkMg^7>H
MkUcV@02KiX04FnkKiY[VfMjHeaO>f=LFa]O?5/lGcaFo5/LEaaK75KlFa`00UKl05MBo5LLD_aFo5;l
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol03Woo
000ROol00`00Oomoo`0NOol00`00Oomoo`0mOol01UmLGcaO?5llGeaO?0=[N`05JgX00000001_V@02
KiX03GNILiQcVGNGMkMgUg^fNiIk]G^DNkEkTg^d00EkT`9kTP05Nk=kTW^cNk=k]@02Nk@017NfMkQg
]gNg0g>i16nJ1F]k1Ull00IFo5LLEaaG75KlEa`6E_`3D_`00eKlD_aBo00>D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo009D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`05
Ool00`00Oomoo`0=Ool0029oo`03001oogoo01moo`03001oogoo03Yoo`0:FcaOGEllGeaK?5mMGcaS
G5mKHe`200007F]jLiY_NG>JKgUg^G>HMiUcV7^hMiMk]WNENkIkU7^eNi=o]7^BOk=kU7ndNi9o/g^B
Ok=kTW^cNi<00W^d00Qk]G^CNkAk]7^eMkEkeWNf0VnJ06e_^fnJJi]WNV^KIg][Vf=KIgaK?5llFa]O
?5/LFcaFo5/LE_aK75KlFaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lOol00008Ool00`00Oomoo`0<Ool0029oo`03001oogoo021oo`03001oogoo03Qoo`03
EaaK?Ell009O?003GeaO?6=L00<0009SG009KiY_VFnJKiYgVG>HLiUcV7Ng009gU`0:NiIk]W^DNkEk
U7^dNi=kUG^DNk@3Ni<02G^cNi9k/g^BNk=kTW^cNi9k/`03Nk@01W^fMkIg]gNgMkQg]`A[N`9WF`05
IgaSFfMKFaaK?003Fa`01E/lFaaFo5KlEa`015Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo003D]aBo5;l009oo`03001oogoo00Ioo`03001oogoo00]oo`008Goo0P008goo00<007ooOol0
=Goo00MK?ELLFceG75/mFcaOG@030000VV=LHe]SG5mKIgaWFg>JKgUcVW>HMiUcV7^hMiMg]gNENkIg
UG^eNiAo]7^CNkIkU7neNi=o/g^BOk=kTW^cNi9k]7^BNk=kTW^dNi=k]GNdNmIg]W^fMkMgf7NgLkUc
V7NiHe]WO6=KIgaSFfMlGc]SG5/LFcaK75llEaaK75KlEaaFo5LLE_aG75;lE_aBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00D007ooOomoo`0000=oo`03001oogoo
00]oo`008Goo00<007ooOol08goo00<007ooOol0<Woo00IG75/mEaaK?ELLFcd30005He`02VMKIg]W
FfMkIe]WNg>HLiUcV7NI0gNG00]k]W^FNkEkU7^eNiIk]W^DNkEkTg^D009kT`=kTP06Nk=kTW^cNi9k
/g^C0W^d00Ik]GNfNkIg]gNhMkL3LkT2KiX00fMKIgaSF`03He`01EllHeaK75/LEa`00e/L1UKl00IB
o5KlD_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo0020004Ool3000>Ool0025oo`03001oogoo02Ao
o`03001oogoo02moo`05EaeC75LMEaaK?@030000=E/mFcaK?EmKHeaSFf=LHe]WO6MKIgaSFfMlJgY[
Nf]jKi]gUgNgMiMk]WNENkIgUg^hMiEk]WNEOkEkU7ndNi9o/g^BNk=kTWncNi9k/g^BOk=kTg^dMkAk
]GNfNkIg]GOHMkMc^G>HMkT00fnJ06a_^elkHeaO>f=LGc]SG5/KGcaG75/LE_aK75LLFaaBo5LLD_aF
o5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000D
Ool0025oo`03001oogoo02Eoo`03001oogoo02]oo`=G7@03DaaG7@0000800003FceG75/m00=K?00:
FceK?6MkIe]WNfMKIg]WFfMkJgX3Jg/03VnIKiY_VWNILiQcVGNGMkMgUg^fNiIk]G^DNiD3Ni<2Ni82
Ni<2Ni802W^cNi9k/g^cNkEg]W^fMkIg^7Ng17>i0fnJ0V]k0V=L1Ell0e/L15LL1UKl00=Bo5KlD_`0
3e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo7oo00004goo000QOol00`00Oomoo`0VOol00`00Oomoo`0XOol015;l
DaeBo5LM0`0003YG7E<LEaeK75lmFcaK?E/LGceK?5mLFcaWO6MKIgaSFfnKJgY[Nf]jKi]_NG>JKgUc
VW>HMiUcV7^hMiMk]WNENkIkU7^eNi=o/g^BNk=kTWndNi9o/g^BOk=kTW^dNi=k]G^dNkIg]G_FMkMc
^G>HMkUcV@9_VP0AKk]WNf^KIgY[VfMkGcaK6ellFcaO?5/KFaaFo5/LE_aK7002E_`0G5;lEaaBo5Kl
D_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000COol0
025oo`8002Qoo`8002Eoo`EC7@8000=G7@04DaaG7ELMEad3Fc`02U/mGcaO?5llGeaO?6MkIe][Nf]j
0f]k00Q_VFnJKiY_VW>HLiUcV7Ng0WNG00IkUW^fNiAkUG^DNk@3Ni<01W^dNi=kTg^BNk=kTP=k/`04
NkAk]WNfNkH2Nk@00gNfNkIg]P03KiX5Jg/2Ie/3Gc`00e/LFcaK7003Ea`01EKlEaaG75KlD_`00eKl
0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo000BOol0025oo`03001oogoo02Uo
o`03001oogoo021oo`04Dae>o5<MD_`30000<e;lDaeBo5LmEaaG?ELLEceG75LmEaaOGEllGeaK?5mM
GcaOG5/lKi][NV]kJgY_VfmiLiY_NG>JLiQgVG>HMkUgUgNgMiEk]WNENkEkU7ndNi9o/g^DOkAkTgnc
Ni9o/g^BNk=kT`02Nk@07g^cNi=k]7^dNkEg]G_FMkIg^7NgMmQWNf^KIgY[Vf=KIgaSFfMlHe]K?5/L
GcaK75/lFaaO?5KlEaaFo5LL009Fo01KD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl00004Woo000POol00`00Oomoo`0[Ool00`00Oomoo`0LOol0
15<MD_eC7E;m0`001E<M00=G7E<MEad00ULM00EG75LMEaeK?ELL009O?004GeaO?5llGc`5He`026nI
KiY_VVnJLiQcVG>HMiT3MiL02G^fNiIkUG^DNkEkTg^ENiAk]004Ni<01G^BNk=kTW^cNi<00g^c00Qk
Tg^dNkAk]WNfNkIg]gNh0g>i00IWO6=KIe]WFfMlHe/2He`00e/lFaaK7002Fa`015LLFaaFo5LL15Kl
00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`00015o
o`0087oo00<007ooOol0;7oo00<007ooOol05Woo00IC7DklDae>o5<MC_`30000^E;lDae>o5<MDaaG
7E;lEaeC75LMD_aG?ELLEceG75/mEaaK?ELLGeeO?5mLGe]SG6=KHeaOFf=LIe]WO6miLiY_NGNILiQg
^GNGMkMgUg^fMiEk]W^DOkEkTg^fNiAo]G^COkAkTWncNi9k/g^BOk=kTW^cNi9k]7^CNkEg]7_FMkIk
]WNgMmQcVG>iLiQ_^fnJIgaSFfMlGc]SG5lkHeaO>e/LE_aK75LLFaaFo5LLE_aG75;lEaaBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo0000
47oo000POol00`00Ool0000]Ool00`00Oomoo`0COol01E;mDaeBoE<MD_d00`0000MBoE<MD_eC7E;m
DaeBo@02Dad03ULMDaeC7E<MEaeC7E/mEaaK?ELLFceG75/mEa`7He`02FMKIg]WFfMkIe]cVG>HMiUc
V002MiL02gNgNiIk]W^DNkEkU7^fNiAk]G^CNi@00g^C0W^B00ikTg^BNi9kTW^cNi=k/g^dNkEg]W^f
MkMg^7Ng0W>i1FnJ00AO?6=LHeaSG0=O?003FaaG75/L009K7003EaaFo5Kl00=Fo006D_aFo5;lE_aB
o5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l0P0047oo000POol2000_Ool00`00Oomoo`0?Ool0
1DklDae>o5<MC_`00`0004a>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMD_aG7E<LEaeC75/mEaaK
?ELLFceG75/mFaaSG6=KHeaOFfMlIe]WO6=KIgaWFf]kJgY_Vf]jMkMgUg^hMiEk]WNENkQgUg^fMiEo
]G^DOkAkTgncNi9k/g^BOk=kTW^cNi9o/g^CNkAg]7^eMkIk]WNgMmQg]g>iLiQg^@=_VP1aKk]WNf^K
Gc]SG5/lGcaK6ellFcaK75KlFaaFo5/LE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000?Ool000Eoo`D000Eoo`8000Eo
o`@000Ioo`03001oogoo02moo`03001oogoo00aoo`04Dae>oE;mD_d300002e;mDaeBoE<MD_eC7E;m
DaeBoE<MD_d00e<M00EBoE<MEaeG7E<L00=G7@04DaaK?ELLFcd3Fc`02U/mFcaSG6=LIg]WFfMkIe]W
NfMK0f]k00Q[NVnJKiY_VW>HLiUcV7Ng0WNG00IkUW^eNiAkU7^CNk@2Ni<00g^BNkAkT`02Ni802W^c
Ni9k/g^cNkEk]7^fMkIg^7Ng0g>i16nJ16]k1ell00=G75KlEa`00ULL15Kl00ABo5KlD_aFo0=Bo003
E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo09oo`03001oogoo00aoo`0017oo0P0000Eo
o`00001oo`0000Aoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo031oo`03001o
ogoo00Qoo`05Dae>o5<MC_eC7@020000D4klDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aC
7E;lEaeC75LMDaaG7E<LEaeC75lmFcaK?E/LGceK?5/mFaaWO6MKIgaSFfMlIe][Nf]jKi][NW>JKgUc
VVmiMiUcV7NiMiMg]gNENkIkU7^eNi=o]7^BOk=kTWndNi9k/g^BOk=kTW^dNi=k]G^dNkIg]G^eNkAk
]WNeNmH3KiX03F^KIg][VfMjJi]SFfMlFa]O?5/lGcaK75ll009K7004E_aK75KlEa`2E_`0Ge;lE_aB
o5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g7oo00003Woo0004Ool20002Ool00`00Ool0000?Ool00`00Oomoo`03Ool00`00Oomoo`0aOol00`00
Oomoo`05Ool014kmD_eBoE<M0`0000EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@MC7@9G
7@05DaaG7ELMEaeG7002Fc`01E/mFcaK?5/lGe`00Ull00=WFfMkIe/00f]k00Q[NVnJKiY_VVnILiUc
V7NI0WNG00IkUW^fNiAkUG^CNk@3Ni<01W^dNi=kTg^BNk=kTP=k/`04NkAk/g^cNk<2Nk@00gNfNkIg
]`02MkL4Jg/01FMlHe]WFfMKIg`00e/L00EK?5/LFaaK75LL00=Fo003EaaBo5Kl009Fo004D_aFo5;l
E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo00ao
o`0017oo0P000Woo00<007oo00003goo00<007ooOol00Woo0P00=7oo00P007ooOomoodklDae>oE<M
0`0004iC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeG
75LmEaaG?ELLEceG75lmFcaK?E/lGeeO?5mLFcaOGEllJg][NVnKJgYcVVmiLiY_NGNILiQg^G>HMkMg
Ug^fMiEk]G^DOkAkTgncNi9o]G^COk=kTWncNi9k/g^CNkAkTW^cNi<2Nk@05g^eMkEkeWNfMkQg]gNi
LiUc^G>HIgaSFfMlHe]WO5lkHeaK75llFaaK?5KlFa`00ULL06EFo5LLE_aG75;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`00
00aoo`0017oo0P000Woo00<007oo00002goo10001Goo00<007ooOol0<Woo00=BoE<MC_d00U;m00IC
7@00000005<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0<DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;m15<M
00=G7E<MDad00ULM00EG75LMEaeG7ELL009O?005GeaO?5llGcaOG005He`3KiX01FnILiUcV7NILiP0
0WNG00Ik]W^FNiEkU7^dNi<2Ni@03W^eNi=kU7^CNk=kTW^cNi9k/g^BNk=kTW^cNi<2Nk@017^fMkIg
]gNg17>i0VnJ0VMK00=SG5llHe`00V=L00EG75/LFaaK75LL009K70EFo006D_aFo5;lE_aBo5Kl3U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000<Ool000=oo`<00005Ool00000Ool0000;
Ool00`00Oomoo`06Ool00`00Oomoo`0`Ool01E<MC_aC7DkmDad00`0005mC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E<LEaeBo5LMEaaG?ELL
EceG75/mEaaOGEllGeaK?6=LHe]SG5lkHeaSFfMlHe]cVVmiLiYcV7NiLiQg]gNGNkIgUG^fNiAo]GNE
NkIgUGneNiAo]7^COk=kTW^cNi9o/g^BNk=kTW^dNi=k]GNdNmIg]WNhMkMgf7>ILkUcV6nk00=_VP0=
HeaO>f=LGc]O?5/lGcaFo5/LEaaK75KlFa`00UKl06ABo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol000]oo`001Goo
00<007ooOol00Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol0;Goo00EC7DkmD_eBoE<M
00<00006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;mDaeBoE<MD_eC7E;m
DaeBoE<MD_d2Dad01ELMDaeC7E<MEad00U<M00QG75/mEaaK?ELLFceG75/m1V=L01AWFfMkIe]WNfMK
Ig]cV7NILiQcVGNGMkMkUW^fMiMg]g^FNkIkUW^e0W^D0W^C0g^B00ekTg^BNi9kTW^cNi=k/g^dNkIg
]W^fMkMg^003LkT4KiX3Jg/7Gc`3Ea`00eKlEaaFo005E_`3D_`00eKlD_aBo00>D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;l
D_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00ABg5;l000000Yoo`001Woo100037oo1@0017oo00<007ooOol0:goo00A>
o5<MC_eC7@<0001SDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E<LEaeG75/mEaaK?ELLFceK75lmHe]SG5lk
HeaWFfMlHe]WO6MKIga[NVnKJgY[NgNGNkQcV7NIMiMk^7NGNkIgUG^fNiAk]G^COkAkTW^cNi9o/g^B
Nk=kTWncNi=k]7NdNkEg]W^fMkMgf7>ILkUcV6nk009_VP0<IgY[VfMkJi]SFfMlFcaO?5/KGcaK75/l
0U/L06UFo5/LE_aK75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00002Woo000OOol00`00Oomoo`0XOol01Dkm
D_eBoE<MC_d00P0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03
D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7E<L00=G7@05DaaG7ELLFceG7002Fc`0
3e/mFcaK?5/lIg]WFfMkIe]WNfMKIg][NV]kJgY[N`02KiX03G>HLiUcV7NgMiMk]W^FNkIkU7^ENi=k
]7^C009kTP06NkAkTg^BNi9k/g^B0W^c00Qk]G^CNk=k]7^eNkAk]WNf0fnJ16]k00IWFfMlHe]WFe/L
Fc`3Fa`00e/lE_aG7002Ea`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]`0000000Uoo`007Woo0P009Goo00M>oE<MC_aC7Dkm
Dae>o0030000hTklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMDaaG7E<LEaeK?5/mFaaO?E/l
FceK75mMGcaOG6=KIgaWFf]kJgY_Vf]jJg]_NG>JLiQgVG>HNkQgUgNgMiEk]WNENkEkU7ndNi=o/g^C
OkAkTWncNi9o/g^BNkAkTg^eNi9k]7^CNkEk]7^fMkEgf7NgMkQcV7NiIg][Vf=KIgaSFfMlGc]SG5/L
FcaK75llFaaK?5KlEaaFo5LLE_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`002Goo000NOol00`00Oomoo`0R
Ool01U<MC_eBoE;mDae>o@<00005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@QC7@03EaeC75LM009G7@04
EaaG7E/lFcd2Fc`00ellGeaO?002Gc`01UmLGca[Nf]jJg][NP=_VP04KgUcVG>HMiT2MiL01W^FNkIk
UW^ENiAk]09kT`03NiAk]7^C009kT`03Nk=kTW^c009k/`04Ni9k/g^cNkD2Nk@017NfNkIg]gNg17>i
00=WFfMlHe/00f=L00AO?6=LFaaK?0AK70IFo006D_aFo5;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003001oogoo00Moo`007Woo00<007ooOol087oo00E>o5<M
C_eC7Dkl00<0001UC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7E;lEceG75Lm
EaaG?ELLEceG75mLFcaOGEllGeaK?5mMGcaSG5lkKi][NW>JKgUcVVmiMiUcV7NiMiMg]gNGNkIgUG^f
NiAo]G^COkAkU7ndNi=o/g^BOk=kTW^cNi9o/g^BNk=kT`02Nk@0O7^eMkEkeWNgMkQg]gNiLiUc^FnJ
Kk]_VV=LGc]SG5lkHeaO>f=LEaaK75KlFaaG75/LD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L17oo00<007ooOol0
1goo000NOol00`00Oomoo`0NOol2D_d00e<MC_d0000200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:
DaeBoE;mD_eC7E;mDaeBoE<MD_d6Dad00eLMEaaG7@02Ead015LLFceG75mL0ell00=OG5llHe`00f=L
0fnJ00A_NG>ILiQgV@=gU`0;NkIkUW^fNiAk]G^CNiAkUW^eNi=kU002Ni<2Ni800g^CNk=kTP03Nk<3
Nk@017^fMkMg]gNg0g>i0fnJ0V]k00ASG5llHeaSG0=O?09K70AG70EFo09Bo003E_aBo5;l00iBo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo0Moo`03001oogoo00Ioo`007Woo00<007ooOol06goo00AC7Dkm
Dae>o0<0003TC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDae>o5LMDaaG
7E;lEaeC75LMEaaG?ELLFceG75/mEaaK?E/lGeeSFf=LGc]SG6=KIgaSFfMlIe]gVG>HMkUcV7NgMiMk
^7NENkIgUGneNiAk]WNEOkEkU7ndNi9o/g^BNk=kTWncNi9k/g^BNkAkTg^eMkAkeWNeMkQg]gNiLiUc
^FnJKk]_VV^KIgY[VfMkGcaK6ellFcaO?5/KGcaFo5/LE_aK75KlFaaBo5KlD_aFo5;lE_aBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l2Woo00<007ooOol01Woo
000MOol2000HOol01U<MC_eBoE;mDae>o@<00005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;m
D_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@04D_eC7E<MEad3Dad02ELMEaaK?ELLFceG75/mEaaK?@05
He`026MkIe]WNfMKJg][NV]kJgX2MiL02GNgNiIk]W^FMkMgUg^fNiIk]P02Ni@3Ni<2Ni801W^CNi9k
TW^BNk=kT`9k]004NkEg]WNgMkL3LkT3KiX4Jg/00fMLIe]O?003Gc`00e/lFaaK7002Ea`3E_`00eLL
D_aFo002E_`015;lE_aBo5Kl25;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l3Woo00<007ooOol01Woo
000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@80002>C_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LMDaaG7ELLFceG75/m
EaaO?E/lFceO>f=LHe]WO6=KIgaWFf]kJgY_Vf]jLiY_NG>JLiQgVG>HNkQgUgNgMiEk]W^DNkEkTgnc
Ni9k/g^BOkAkTW^cNi9o/g^CNkAg]7^eNi=k]7NdNmIg]G^fMkMgf7NgJi]WNV^KHe]WO6=KIgaSFe/l
FaaO?5/LFcaK75llE_aG75KlEa`2E_`0DE;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg00COol00`00Oomoo`06Ool001eoo`03001oogoo01=oo`9Bo@03Dae>oE;m00<0009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;m
DaeC7E<MD_d00eLM00EC75LMEaeG7E<L009K?00>FceK?5/lFcaK?E/lIg]WFfMkIe][Nf]jJg][NP=_
VP04KgUcVG>HMiT2MiL01W^FNkIkUW^ENi=k]0=kT`0BNkAkTg^BNi9k/g^BNk=kTW^cNi9k/g^dNkEg
]W^fMkMg^7Ng0g>i00ESFfMLIe]WO5ll009SG003FcaK75/L009K7004EaaK75KlEa`4E_`015;lE_aB
o5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
001Bo5;L00=Bo006D]aBo5;lD_aBg5;l5Goo00<007ooOol01Woo000MOol00`00Oomoo`0AOol014km
Dae>o5<M0`00085C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75LMDaaG7ELLEceG75lmFcaK?E/LGceK?5mLFcaW
O6MKJg][NVnKJgY[NfmiLiY_NGNILiQg^GNGMkMgUg^fMiEk]G^DOkAkTWncNiAo]7^COk=kTWncNi9k
]7^BOk=kTW^dNi=k]GNeNkIg]GOHMkMc^G>HMkT00fnJ05iSG5lkHeaO>f=LGc]SG5KlFaaG75/LE_aK
75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg1Moo`03001oogoo00Ioo`00
7Goo0P003goo00ABoE<MC_eBo@<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d7Dad2Ead01ELLEaeG7ELMEa`0
0U/l00]K?EllGcaO?5mLGca[Nf]jJg][NV]k009_VP04KgUcVG>HMiT3MiL02G^fNiIk]W^DNkEkTg^E
NiAk]003Ni<01W^cNi9k/g^BNk=kTP9k/`05NkEk]7^fMkIg^002MkL2LkT3KiX2Jg/3He`4Gc`01ULL
FaaK75LLE_aG70IFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]`005;lD_aBg00LOol00`00Oomoo`06Ool001eoo`03001oogoo00Uoo`06C_aC7DkmDae>
o5<M0`0007aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaG?ELLEceG75LmEaaOGEll
GeaK?5mMGcaSG5lkKi][NV]kKgUcVVmiMiUcV7NiMiMg]gNGNkQgUG^fNiAo]G^CNkIkU7neNi=o]7^B
Ok=kTW^cNi9o/g^BNk=kT`9k]007NkIg]GOHMkMg^7>HMkT00fnJ05U[VfMkJi]WNUllFcaO?5/KGcaK
?5llE_aK75KlFaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0001moo`03001oogoo00Eoo`007Goo
00<007ooOol01goo0U;m00=C7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d04E<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_eC
7E;mEad00e<M00=G7E<MDad00ULM00EG75LMEaaK?ELL009O?003GeaSG6=L00ASG09_VP05KgU_VW>H
MiUcV002MiL02gNgNiIk]W^FNkEkU7^fNiAk]G^CNi@00W^C00QkTW^CNi=k/g^BNk=kTW^c0W^d00Ag
]WNhMkMg]`9c^@=_VPA[N`03IgaSFell00=O?09K7003FcaFo5LL009G70AFo004D_aFo5;lE_`3D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOomoo`02Ool0
0`00Oomoo`0LOol00`00Oomoo`05Ool001eoo`03001oogoo00Eoo`04C_eC7DklDad30000Q5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeBo5LMEaaK?ELLFceG75/mEaaK
?F=KHeaO>f=LHe]SG6=KIgaWFfMlLiQg^G>HMkMgUg^hMiMk]WNENkQgUg^fMiEo]G^DOkAkTgncNi9o
]7^BOk=kTW^cNi9k]7^CNkEkT`9k]00INkEg]G_FMkMg^7NgJi]WNf^KHe]WO6=KIgaSFfMlFaaK?5/L
GcaK75/lE_aG75KlEa`00UKl03mBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`027oo00<007ooOol06goo00<007ooOol01Goo000MOol0
1000Oomoodkm0U;m00AC7DkmD_eBo@80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeB
oE<MD_d3Dad015;mDaeC7ELM0e<M00UG7E<LEaeG75/mEaaK?ELLFcd00U/l0f=L00QWNfMKIg]WFfMk
JgY[Nf]j0fnJ00A_NG>ILiQg]`9gU`04NiIk]G^DNi@3Ni<00g^BNi=kT`03Ni801G^cNi=k]7^BNk<0
0g^d00Ak]WNfMkMg]`=c^@0:Ie]WO6=KIeaWFfMlGcaSG5/LFc`4Fa`3E_`02ELLE_aFo5;lE_aBo5Kl
D_aFo003D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo0aoo`03001oogoo01]oo`03001o
ogoo00Eoo`0077oo00P007ooDae>oE<MC_aC7Dkm0`000=e>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75LMEaaK?ELLGceK?5/mFaaO?FMKIgaS
FfMlIe]WO6]jKi][NW>JKgUcVVmiMiUcV7NiMiMg]gNENkIkU7^eNi=o]7^BOk=kTgncNi9k/g^BOk=k
Tg^dNi9k]7^CNkEg]7_FMkEg^7NgMkUcVG>iKiY_^f=KIgaSFf=LGc]SG5lkHeaG75/LE_aK75LLFaaB
o5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L015o
o`03001oogoo01Yoo`03001oogoo00Eoo`0077oo00<005<MC_d00U;m0`0000=BoE<MC_d00U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@0>DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@IC7@03EaeC75LM009G7@04
DaaG7E/lFcd3Fc`02e/mGcaO?6MKIg]WFf]kJgY[Nf]jJg/00VnJ00A_NG>ILiQgV@=gU`05NkIkUW^E
Ni=k]002Ni<00g^DNi=kT`02Ni801W^cNi9k/g^BNk=kT`9k]005NkEg]W^fMkMg^002LkT4KiX2He`0
0ellHeaSG003Gc`2Fa`4Ea`5E_`2D_`00eKlD_aBo00>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`05goo00<007ooOol06Goo00<007ooOol0
1Goo000BOol50005Ool00`00C_d000020000V4kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeBo5LMDaaG7E<LEceG75LmFcaK?E/LGeeO?5mL
FcaOGEllJg][NVnKJgY[NfmiLiY_NG>JLiQg^G>HMkMgUg^fMiEk]G^DOkAkTg^eNiAo]7^BOk=kTWnc
Ni9k/g^BOk=kTg^cMkAk]GNeNkIg]gOHLiUc^G>HKk/2KiX03VMjJi]WNf^KFa]O?5/lGcaK6ellE_aK
75KlFa`2E_`0<U;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`JOol00`00Oomo
o`0HOol00`00Oomoo`05Ool001Aoo`03001oogoo00Eoo`800003D_eC7Dkm009Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0<DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;m25<M00=G7ELLEad0
0ULM00AG75LMEaeOG0=O?007GeaO?6=LHea[Nf]jJg/00VnJ00E_NFnJLiQgVG>H009gU`09MkMkUW^f
NiAk]7^CNkIkU7^e009kT`0>Ni9k/g^BNi=kTW^cNi9k/g^dNkEg]W^fMkIg^0=c^@9_VPE[N`03Ie]W
O5ll009O?003FcaK75/L009G7005E_aG75LLE_aBo003E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l77oo00<0
07ooOol06Goo00<007ooOol017oo000DOol00`00Oomoo`06Ool0[P00Oom>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75Lm
EaaG?ELLEceG75/mEaaOG5/lGeeO?6=LGc]SG6=KHea_NG>JKgUcVW>HMkUcV7NgMiMk^7NENkIkU7ne
MiEk]W^DOkEkTgncNi9o/g^BOk=kTWncNi9k/g^CNkEk]7^fMkEk]G^dNkIg]FnkKiY[VfMjJi]WNfMl
He]WO6=KIgaK75llFaaK?5/LGcaFo5LLE_aG709Fo00ZD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl8Goo
00<007ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07Ool200000e;mDae>o@02D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@AC7@0>
EaeC7E<MDaeG7ELLFceG75/mEaaK?ELLGeaO?0ESG00BIe]WNfMKIg]cV7NILiQcVGNGMkMgUg^fNiIg
]g^FNkIkUW^e0W^D00MkTg^cNi9kU7^CNk=kTP02Nk<017^eNkAk/g^c0W^d00Ak]WNfMkQg]`Ac^@05
IeaWFfMlHe]WG002He`4Fa`015LLFaaFo5LL15Kl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L02Ioo`03001oogoo01Moo`03001o
ogoo00Aoo`0057oo00<007ooOol02Goo090007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK?ELLFceG76=L
Gc]SG6=KHeaSFfMlIe]WO6]jKi][NV]kMiMk^7NGMiUcV7^hMiMk]WNEOkEkU7ndNi9o/g^COkAkTWnc
Ni9k/g^BNkAkTW^cNi<2Nk@027^eMkEkeWNgMkQcV7NiLiT2KiX0=FMlHe]SG5lkHeaO>f=LE_aK75LL
FaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`0:7oo00<007ooOol05goo00<007ooOol017oo000DOol0
0`00Oomoo`0:Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<M
D_eC7E;mDaeBo@=C7@05D_eC7E<MDaeBo@03Ead025<LEaeG7ELMEaaK?ELLFcd3Fc`2He`02FMkIe]W
NfMKIg][NV]kJgY[N`02KiX02VmiLiUcV7NIMiMk]W^FNkIkU7^E0W^C0W^D0W^C0g^B00=k/g^BNk<0
0W^c0W^d00Ag]W^fMkMg]`=c^@A_VP=SG0AO?006EaaK75/LEaaFo5LL1UKl0e;l00=Fo5;lD_`02U;l
00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg5;l;7oo00<007ooOol05Woo00<007ooOol017oo000B
Ool3000=Ool0UP00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7E/LGceK?5/mFaaO?E/lIgaSFfMlIe][Nf]jKi][NV]k
KgUcVVmiMiUcV7NiMiMg]gNENkIkU7^eNi=o/g^DOkAkTgncNi9k/g^BOk=kTW^cNi9k]7^CNkEg]7_F
MkMg^7>HMkUcV@9_VP0`Kk]_VV^KIgY[Ve/lGcaK6ellFcaO?5KlFaaFo5/LE_aG75;lE_aBo5KlD_aF
o5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L<Goo00<007oo
Ool05Goo00<007ooOol017oo000DOol00`00Oomoo`0<Ool200001WooC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m25<M0eLM00AC75LMEaeG7@=K?00;FceO?5ll
GcaOG5llJg][NV]kJgY[N`02KiX016miKiYcV7NI0WNG00]kUW^fNiIkUG^DNkAkU7^ENi=k]7^C009k
TP06Nk=kTg^BNi9k/g^C0W^d00Ak]WNfMkMg]`9c^@=_VPA[N`03He]WG5ll009O?09K7003FcaFo5LL
009G70AFo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l=Woo00<007ooOol0
57oo00<007ooOol017oo000UOol0T@00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEceG75LmEaaG?ELLEceG75mMGcaOG5/lGeeO?6=LGc]_Vf]j
Jg]_NG>JKgUcVW>HMkUgUgNgMiEk]WNENkEkU7^fMiIk]G^COkAkTWncNi9o/g^BNk=kTWncNi=k]GNd
NkEg]GNhMkMg^G>I009_VP0CKk][Nf^KIgYWO6=KIgaSFfMlFaaK?5/LGcaK75/lE_aG75KlEa`00UKl
01EBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`0>Woo00<007ooOol05Goo
00<007ooOol00goo000VOol00`00Oomoo`02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@06DaeBoE<MD_eC7E;m1U<M00=G7E<MEad00ULM00EG75LMEaeK?ELL009O?003GeaO?6=L00ASG09_
VP05KgU_VW>HMiUcV002MiL02G^fNiIk]W^DNkIkUW^ENiAk]003Ni<01g^cNi=kTg^BNk=kTW^c009k
]005Ni=k/g^dNkIg]P02MkL03GNhLkUc^G>iIgaSFfMLIe]WO5llHeaK75/l00AK70=Fo009EaaFo5Kl
D_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l00IBo3eoo`03001oogoo01Aoo`03001oogoo00=oo`009goo
0;L007ooOomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeC75LMD_aG7E<L
EaeBo5LmEaaG?ELLFceG75/mEaaOGEllHeaO>f=LHe]SG6=KIgaWFfMlLiQg^G>HMkMgUg^fMiEk]WNG
NkQgUW^fNiAo]7^COk=kTWncNi=o/g^BOk=kTW^cNi9o/g^BNk=g]7^eMkEk]WNgMmQcVG>iLiQ_^fnJ
IgaSFf=LGc]SG5lkHeaG75/LE_aK75LLFaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]`0@7oo00<007ooOol04goo00<007ooOol00goo000XOol200001GooD_eBoE<MC_d00U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad015;mDaeC7ELM0e<M00YG7E<MFceG75/mEaaK
?ELLFceG70ESG007Ie]WNfMKIg][NV]kJgX00VnJ00]cVG>HLiUgUgNgNiIk]W^DNkEkTg^D00EkT`06
Nk=kTW^cNi9k/g^B0W^c00Ik]7NfNkIg]gNhMkL2LkT4KiX016=LGcaSG6=L0ell0U/L15LL1EKl0U;l
00=Fo5;lD_`01E;lAWoo00<007ooOol04Woo00<007ooOol00goo000ZOol0S`00OomC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75/mEaaK?ELLFceK?5/m
FaaSG6=KIgaSFfMlIe]WO6]jKi][NW>JKgUcVW>HMiUcV7^hMiMk]WNEOkEkTgndNi9o/g^DOkAkTWnc
Ni9k/g^COk=kTW^cNi=k]G^dNkIg]gOHMkMc^G>HMkT00fnJ00e[Vf]kJi]K6ellFcaO?5/KGcaFo5/L
E_aK7002E_`02U;lEaaBo5KlD_aFo5;lE_aBg5KlBWoo00<007ooOol04Woo00<007ooOol00goo000[
Ool01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m1U<M00=G7E<LEad0
0ULM00AC75LMFcaK?@=K?00;FceK?6MkIe]WNfMKJg][NV]kJgY[N`02KiX027>HLiUcV7NgMiMk]W^F
NkD2Ni@017^CNkEkU7^D0W^C0g^B00=k/g^BNk<00W^c00Ek]7^fMkIg^7Ng00=c^@9_VP06Jg][Vf]k
Jg]WFfMl0ell00=K?5/LFa`00ULL00EFo5LLEaaFo5;l00=Fo003D_aoogoo04eoo`03001oogoo015o
o`03001oogoo00=oo`00;7oo088007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MC_aG7E;l
DaeBo5LMD_aG7E<LEaeC75LmEaaG?E/lFceK75lmGcaOG5/lGeeO?6]kJgY_Vf]jJg]_NG>JKgUgVG>H
NkQgUgNgMiEk]W^DOkAkTg^fNiAk]G^COk=kTW^cNi9o/g^BNk=kTP9k]007NkEg]G^eNkAk]WNeNmH0
0VnJ019WNV^KJg]WO6=KIgaSFfMlFaaO?5/LFcaK75llE_aG75KlEa`2E_`00e;lE_aoo`1AOol00`00
Oomoo`0@Ool00`00Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;m
DaeBoE<MD_d6Dad00eLMEaaG7@02Ead015LLEaeG7EmL0ell00MOG5llHeaSG6]kJgY[N`02KiX016mi
LiUcV7Ng0WNG00]kUW^fNiAkUG^FNkIkU7^ENi=k]7^C009kTP07Ni=kTW^cNi9k/g^CNk@00W^c0W^d
00Ag]W^fMkMg]`=c^@04IeaWFfMlHe/3He`4Fa`015LLFaaFo5LL0eKlEGoo00<007ooOol047oo00<0
07ooOol00Woo000_Ool0P@00Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5LM
DaaG?ELLEceG75LmEaaK?ELLGeaK?5mMHe]SG5lkHeaSFf=LKgUcVVmiLiYcV7NiMiMg]gNGNkIgUWNg
MiMk]WNFNkEkU7ndNi9k/g^BOkAkTW^cNi9o/g^CNkEkTP02Nk@027^eMkEkeWNeMkQcV7NiLiT2KiX0
3FnkGc]SG5lkHeaO>f=LE_aK75LLFaaFo5/L05Uoo`03001oogoo011oo`03001oogoo009oo`00<7oo
00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00aC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_d4Dad035LMDaeC7E<MEaeG75/m
EaaK?ELLFceG70MSG006Ie]WNfMKIg]cV7>I0gNG00UcVG>HMiMgUg^fNiIkUG^DNk@00g^C00Yk]7^C
Ni9kTW^cNi=k/g^BNk=kT`9k]004NkIg]WNgMkL2LkT3KiX2Jg/2He`4Gc`00eLLFaaK701LOol00`00
Oomoo`0?Ool00`00Oomoo`02Ool0035oo`27001oogooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeB
o5LMDaaG7E;lEaeC75LMEaaK?ELLFceG75lmFcaSG5lkHeaSFfMlHe]WO6MKIga[NVnKKgUcVVmiMiUc
V7NIMiMk^7NFNkIkU7neNi=o]7^DOkAkTgncNi9o/g^BNk=kTWncNi=k]GNdNmIg]GNhMkMg^G>I009_
VP0;Kk][Nf^KIgY[Ve/lGcaK6ellFcaO?01OOol00`00Oomoo`0>Ool00`00Oomoo`02Ool0039oo`05
001oogooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<M
C_eBoE;mDad00e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05D_eG7ELMEaeC7003Ead015LLFceK
?5/m0e/l00YK?FMKIg]WFfMkIe]WNf]jJg]_N@9_VP05LiUcV7>IMiMg]`02NiH01W^DNkEkTg^DNi=k
]0=kT`0<Nk=kTW^BNi9k/g^CNk=k]7^fMkIk]WNg0W>i0fnJ0f]k00=[Vf=KIe`00ellHGoo00<007oo
Ool03Woo00<007ooOol00Woo000cOol20000S7ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeBo5LM
DaaG7E<LEaeC75LMFaaO?E/lFceK75lmGcaOG6=KIgaWFf]kJgY_Vf]jLiY_NG>JLiQgVG>HNkQgUg^f
MiEo]G^DOkAkTgneNi=o]7^BOk=kTWncNi9o/g^BNk=g]7^eMkEk]WNdNkEg]GNhMkMgf6]kJi]WNVMl
He]WO6=KIgaTOol00`00Oomoo`0=Ool00`00Oomoo`02Ool003Eoo`04001ooe<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00QC7E;mDaeB
oE<MD_eC7E;m1U<M0eLM00AC75LMEaeG7@=K?00:GeaO?5llGcaOG5llJg][NV]kJgX3KiX01G>HLiUc
V7NgMiL00W^F00Ek]G^DNiIkUW^e009kU09kT`05Ni9kTg^BNk=kTP02Nk<02G^dNi=k/g^cNkAg]W^f
MkMg^003LkT016MlHe]WG6MKIgoo00<007ooOol037oo00<007ooOol00Woo000fOol0Q@00OomC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEceG75LmEaaG?ELLEceG75mMGcaOG5/lGeeO?6=LGc]SG6=K
LiY_NG>JLiQgVG>HNkQgUgNgMiEk]W^DMkMgUG^fNiAo]7^COk=kTWndNi9o/g^BNk=kTgncNi9k/g^C
NkEk]7^fMkMgf7>ILkUcV6nk009_VVYoo`03001oogoo00]oo`03001oogoo009oo`00=goo00@007oo
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC
7@03D_d025<MD_eC7E;mDaeBoE<MD_d4Dad00eLMDaeG7@02Ead01ELLEaeG75/mEa`00Ull00=OG6=L
He`00f=L00MWNfMKIg]cV7>ILiQcV@02MiL027^FNkIgUgNGNiIk]W^DNiD3Ni<00g^DNi=k/`03Ni80
0g^cNi9k/`02Nk<01G^dNkIg]gNhMkL00W>i0fnJJgoo00<007ooOol037oo00<007ooOol00Goo000h
Ool20000MU<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeC75LMD_aG7ELLFceG75/mEaaK?ELLHeaSFf=LGc]S
G6=KIgaSFfMlJgY[Nf]jKi]gUgNgMiMgVGNGMkMgUg^fMiIk]G^COkAkTW^eNi=o/g^BNk=kTW^dNi9k
/g^C0W^d00Qk]GNeMmQg]g>iLiQ_^fnJKWoo00<007ooOol02goo00<007ooOol00Goo000jOol00`00
Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;m
DaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@0:EaeC75LMEaaK?ELLFceK?5/mFc`3He`02FMKIg]W
FfMkJgY[Nf]jJg]_N@02KiX03W>ILiQgUgNGNkIkUW^ENiAk]7^CNiEkTg^dNi<2Ni800g^cNi9k/`02
Nk<01G^CNkAg]WNhMkL00W>i0VnJL7oo00<007ooOol02Woo00<007ooOol00Goo000kOol0M`00Oomo
oe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>
o5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75LMDaaK?E/LGceK?5/mFaaO?FMKIgaSFfMlIe][Nf]jKi]_
NG>JKgUgVG>HMkMgUg^hMiIk]W^DOkEkTg^eNiAo]7^BNk=kTWncNi9k/g^BNkAkTg^eMk@00W^d00Ak
]WNeMmQg]g9oo`03001oogoo00Uoo`03001oogoo005oo`00?7oo00<007ooOol00U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@IC7@03
EaeC75LM009G7@04EaaG7ELMFcd3Fc`02U/mGcaO?6MKIg]WFf]kJgY[Nf]j0fnJ00AcV7>IMiMg]`9k
UP06NiAk]G^CNiIkU7^d0W^C00=kTW^cNi<00W^B00Ek/g^CNk=k]7^c009k]004MkIk]WNgMkMbOol0
0`00Oomoo`09Ool00`00Oomoo`01Ool003eoo`80001hOomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aC7ELLEceG75LmEaaG
?ELLFceK75mMGcaOG5/lGeeO?6]kJgY_Vf]jLiY_NG>JLiQgVGNGNkQgUg^fMiEo]G^DNkIkU7neNi=o
/g^BOk=kTgncNi9o/g^CNk=kTWncNi=k]GNeNmIg]gNhM7oo00<007ooOol027oo00<007ooOol00Goo
000oOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad0
0e;m00IC7E;mDaeBoE<MD_d6Dad00eLMEaaG7@02Ead015LLEaeG7EmL0ell00=OG5llHe`00f=L0fnJ
00EcV7>ILiQg]gNG009kUP09MkMgUg^FNiIk]G^CNiAkTg^d009kT`07Ni9k/g^CNk=kTW^cNi<00W^d
00=k]WNgMkL0MWoo00<007ooOol01goo00<007ooOol00Goo0010Ool0MP00OomC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E<LEaeBo5LMDaaG
7ELLEceG75LmEaaK?ELLGeaK?5mMHe]SG5lkHeaSFfMlHe]WO7>HMiUcV7^hMiMg]g>HNkQgUgNgMiEo
]G^DOkAkTgneNi=o]7^BOk=kTW^cNi9o/g^BNk=g]7_FMkEg^7NgMgoo00<007ooOol01goo0@000Goo
0Goo0011Ool01P00Oomooe;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;m
DaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@08EaeG75/mEaaK?ELLFceG70ESG00<Ie]WNfMKIg][
NV]kJgY_VVmiKiYcV7>I0WNG00AkUW^fNiAkU0=kT`09NiAkTg^CNi9kTg^BNk=kTW^c009k]003MkIg
]gNg07Qoo`03001oogoo00Moo`40005oo`5oo`00@Woo0P00071oodkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7ELLFceG75/m
FaaO?E/lFceK76MlIe]WO6=KIga[NV]kJgYcVVmiLiYcV7NIMiMg]gNGNkIkU7^eNi=o]7^DOkAkTgnc
Ni9k/g^BOk=kTW^cNi=k]G^CNk=g]7Yoo`03001oogoo00Ioo`40005oo`5oo`00A7oo00D007ooD_eC
7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;m
DaeG7ELMDa`00eLM00AC75/lFcaK?@=K?00:GeaO?6MkIe]WNf]jJg][NVnJKgT2KiX02g>ILiQgUgNG
NkIkUW^ENi=k]7^DNiD00g^C00AkTW^CNk=kTP9k/`03NkAkTW^c009k]7]oo`03001oogoo00Eoo`40
005oo`5oo`00AGoo06h007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7Dkl
DaeBo5<MD_aG7E;lDaeBo5LMDaaG7E<LEaeG75LmEaaO?E/lFceK?5mMGcaOG5/lGee[NV]kJgYcVVmi
LiY_NGNILiQg]gNGNkIgUW^eNiAk]WNFNkEkTgndNi9k/g^COk=kTW^cNi9k]7^BNk=kTg^eO7oo00<0
07ooOol01Goo0@000Goo0Goo0016Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad0
0e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeG7003Ead015LLGcaO?5mL0ell00IO
G6=LHeaSG6nJKgT2KiX01G>ILiQcVGNGMkL00W^F00=gUgNgNiH00W^E00=k]7^CNi<00W^C0g^B00Ak
/g^BNk=k/`9k]7eoo`03001oogoo00Aoo`40005oo`5oo`00Agoo0P0006Mooe<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMDaaG7E;lEaeG75LmEaaG?ELLFceG75mM
GcaOG5/lHeaSFf=LGc]WO6MKIgaSFgNILiQgVGNGNkQcV7NIMiMk^7NFNkIkU7ndNi=o/g^DOkAkTW^c
Ni9o/g^BNk=kT`02NkAoOol00`00Oomoo`03Ool10001Ool1Ool004Uoo`04001ooe<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@04D_eC7E<MEad3Dad01e/mEaaK?ELL
FceG75/m00ESG007Ig]WFfMkIe][Nf]jJg/00VnJ00QcV7>ILiQg]gNGNiIkUG^e0W^C00=kUG^dNi<0
0W^B00Ek/g^CNi9kTW^c009k]81oo`03001oogoo00=oo`40005oo`00BWoo06L007ooDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LFceG75/mEaaK
?E/LGceSFf=LGc]WO6MKIgaSFfnKJgY[NfmiLiY_NGNILiQk^7NGNkIgUGneNiAo]7^DOkEkTgncNi9o
/g^BNk=kTWncNi=k]@21Ool00`00Oomoo`03Ool10001Ool004]oo`04001ooe<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MD_d00eLM00AC75LMEaeG7@=K?00;FceK
?5/lFcaWNfMKIg][NV]kJgY[N`02KiX016miLiUcV7Ng0WNG00YkUW^eNiAkU7^FNkEkTg^DNi=k]09k
T`05Ni9k/g^CNk=kTP22Ool00`00Oomoo`02Ool10001Ool004aoo`80001RDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75LMDaaG?ELLEceK75lmFcaK?E/lGeeO
?5mLJgY_Vf]jJg]_NG>JKgUgVG>HNkQgUgNgMiEk]W^DNkEgUGneNiAo]7^BOk=kTWncNi9o/g^BNk=k
TXAoo`05001oogooOol00001Ool004ioo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC
7E;mDaeBoE<MD_eC7E;m0e<M00EBoELMEaeG7ELL00=G7@=O?003GeaO?5ll00ASG09_VP04KgU_VW>H
LiT3MiL01G^fMiMgUg^FNkH00W^D1G^C00Ek/g^BNk=kTW^c08Eoo`04001oogoo0001Ool004moo`1P
001oodklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeC75LMD_aG?ELLEceG75/m
EaaK?E/lGeeO?6=LGc]SG6=KHeaSFfMlIe]WO7>HMiUgUgNgMiMgVGNGMkQgUg^fNiAk]G^COk=kU7nd
Ni9o/g^BNk=kTWncQWoo00@007ooOol0005oo`00D7oo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03E<MD_eC
7E;mDaeBoE<MD_eC7E;mDaeBoELM00=C7@0:EaeC7E<MEaaK?ELLFceG75/mEa`5He`01fMKIg]WFfMk
JgY[Nfmi009_VP09LiUcV7NGMiMk]W^FNiEkTg^d009kU09kT`05Ni9k/g^CNk=kTP27Ool00`00Ool0
0001Ool0055oo`80001KC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC
75LMEaaK?ELLFceK?5/mFaaSG6=KHeaSFfMlIe]WO6]jKi]_NG>JKgUgVG>HMkQgUg^hMiIk]G^DOkAg
UW^eNi=o/g^BNk=kTWncNi80RGoo0@000Goo0@00001COol01P00C_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeB
oE<MD_d3Dad01E;mDaeC7E<MDa`00eLM00AC75LMEaeK?@=K?00:FceK?5/lIe]WNfMKJg][NV]kJgX3
KiX017>HLiUgUgNg0W^F00AkUG^fNiIkU@IkT`03Ni9k/goo08Uoo`800000E7oo05T007ooDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E<LEaeC75LMEaaG?ELLFceK75lmFcaOG5/lGeeO?6]k
JgY_Vf]jLiY_NG>JLiQgVGNGNkQgUW^fNiAk^7NFNkIkU7ndNi9o/g^BOk=kTW^c08]oo`800000EGoo
00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@04EaaG7ELMGe`3
Gc`00emLGcaSG003He`3KiX01G>HLiUcV7NgMiL00W^F00EgUg^FNiIkUG^e00=kT`04NkAkTg^BNi:;
Ool2000005Ioo`1G001oogooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E<LEaeG75LmEaaG?ELL
FceG75mLFcaOGF=KHeaO>f=LHe]WO6=KIgacV7NILiQk^7NGMiUcV7^hMiMk]WNEOkEkTgncNi9o]G^B
Ok=kTWnc08Moo`@0009oo`00Egoo0P0000Aooe;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad03ELMDaeC
7E<MEaeC7E/mEaaK?ELLFceG75/m00ESG00<Ig]WFfMkJgY[Nf]jKiY_NG>ILiQcVGNG0W^F00Ek]G^D
NiAkUG^e009kT`03Ni9kTgoo08=oo`@000Ioo`00FGoo05<007ooC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeC
75LMD_aG7E<LEaeC75/mEaaK?ELLGceK?5/mGc]SG6MKIgaSFfMlJgY[Nf]jLiY_NG>JLiQgVGNGMkQg
UG^fNiAo]7NEOkEkU7ndNi9o]7^B081oo`@000Yoo`00FWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad0
1E;mDaeG7ELMDa`00eLM00AC75/lFcaK?@=K?00EFceWFfMkIe]WNf]jJg][NV]kKgU_VW>HLiUcV7NG
NiIk]W^DNiEkUW^e009kU003Ni=k/g^C07eoo`@000ioo`00Fgoo050007ooC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aC
7E;lEaeC75LMDaaG7ELLEceG75lmFcaK?E/LGeeO?5mLFcaOGF]jJg][NVnKKgUcVW>HMiUcV7NhMiMk
]WNFNkEgUg^fNiAk]G^COk=kTgncNGoo10004Woo001LOol200000gooDae>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EB
oE<MDaeG7ELL00=G7@04EaaG7EllGe`3Gc`00emLHeaSG002He`02FmiKiY_VW>ILiQcVGNGNkIkUP02
MiL00g^fNiAkU@02Ni<2Ni@00g^COomoo`1dOol3000FOol005ioo`1<001ooe<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LM
D_aG7E;lEceG75LmEaaK?ELLFceO?5mLFcaSG6=KHeaO>f=LIe]WO6=KMiUcV7NIMiMk^7>HMkQgUg^h
MiIk]G^DOkAkU7ndNi9cOol4000IOol005moo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00aG7E<MDaeC7ELM
EaaK?ELLFceG75/mEa`4He`01fMkIe]WNfMKJg][NV]k009_VP05LiQcVGNGMiMkUP02NiD00g^dNiAk
U@02Ni=_Ool4000MOol0061oo`19001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E<LEaeG75/mEaaK?E/LGceK
?5/mHe]WO6MKIgaSFfnKJgY[NfmiLiYcV7NIMiMk^7NGNkIkU7neMiIk]G^COk<0K7oo10008Goo001Q
Ool200001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeB
oE<MD_eC7E;m0e<M00EBoELMEaeG7E<L00=G7@=K?00;FceK?5/lGcaOG6MKIg]WFf]kJgY[N`02KiX0
0fmiLiUcV002MiL017^FNiEk]G^F0W^E00=k]7^COol0Igoo10009Goo001SOol0AP00Dae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG
7E<LEaeC75LmEaaG?E/LGceK?5mLFcaOGEllGeaK?6nKJgY[NfmiLiY_NGNILiQk^7NGMkQgUG^hMiMk
]W^DOkEkTg^eIGoo0`00:Goo001TOol00`00Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeG7003Ead015LLGcaO?5mL
0ell0f=L0VnJ00A_NG>ILiQcV@9gU`06LiQgUgNGNiIkUG^e0W^CHWoo1000;7oo001UOol0@`00Oom>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeB
o5LMD_aG7ELLEceG75LmEaaK?ELLGeeO?5mLGc]SG6=KHeaSFfMlIe][Nf]jKi]_NG>JLiQgVGNGMkQg
UGneNiAo]7^D05ioo`@0031oo`00IWoo0P0000E>oE;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m
00EC7DkmD_eBoE<M00=Bo@03DaeBoE<M009C7@04D_eC7E<MEad3Dad01U/mEaaK?ELLFceG70ASG00;
Ig]WFfMkIe][Nf]jJg]_NFnJLiQcV@02MiL01G^FNkEkU7^DNiH0Fgoo1000=7oo001XOol0?`00OomC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG
7E<LEaeC75/mEaaK?E/lFceK75lmFcaWO6=KIga[NV]kJgY_VfmiLiY_NGNILiQg^7NGNkIkU7^eMiEo
]@1GOol4000hOol006Uoo`06001ooe;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC
7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMDa`00ULM00EK?E/lFcaK?5/m00=O?006Gea[NV]kJgY[Nfmi
0VnJ00EcVG>HMiMgUg^f00=gU`03NkIkU7oo059oo`@003aoo`00JWoo03`007ooDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7ELLEceG75LmEaaG?ELL
GeeO?5mLFcaOGF=KHeaO>f=LKgUcVVmiMiUcV7NIMiMk^7NGMkQgUg^fNiAAOol30010Ool006]oo`80
009Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00=G7E<M
Dad00ULM00EG75LMEaaK?ELL009O?0ESG006Ie]WNfMKLiUcV7>I0WNG00IcV7NGMiMgUg^FNiE=Ool4
0013Ool006eoo`0h001oodkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<M
D_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaSG6=KHeaO>f=LIe]WO6=KKi][NV]kKgUcVW>HMkQgUg^h
MiIk]DYoo`@004Moo`00KWoo00D007ooD_eC7Dkm009Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eBoE;m
DaeBo@IC7@0:EaeC75LMEaaK?ELLFceK?5/mFc`3He`01VMKIg]WFf]kJgY[N`9_VP03LiQcVGNG009g
U`03NiIkUGoo04Eoo`@004]oo`00Kgoo03H007ooOomC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7Dkl
DaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeC75/mFaaO?E/lFceK75lmIe]WO6=KKi][NV]kJgYcVVmi
MiUgUg^hMiMk]W^DNkQ2Ool4001?Ool0071oo`800003OomC7Dkm009Bo@0>DaeBoE;mD_eC7E;mDaeB
oE<MD_eC7E;mDaeBo@=C7@05DaaG7ELMEaeG7002Ead01E/mFcaK?5/lGe`00ell00Q[Nf]jJg][NVnJ
KgUcVG>H0gNG00=kUWNGOol0?goo0`00Dgoo001bOol0<P00C_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7DklDaeBo5<MD_aG7E;lDaeBo5LmEaaG?ELLEceG75mLFcaOGEllGeaO>f=LHe]SG5lkLiY_NGNI
LiQk^7NGMkQcV7^hMiLlOol4001FOol007=oo`04001BoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00AC
7E;mDaeBo@AC7@03EaeC7ELM009G7@05EaaK?ELLFceG7006He`02VMkIe][Nf]jKiY_NFnJLiQcVGNG
>Goo1000FWoo001dOol0;`00C_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;l
EaeBo5/mEaaK?ELLFceK?5/mFaaSG6=KHeaSFfMlIe][Nf]jLiY_NG>JLiQgVGNGMkP0=Goo1000GWoo
001eOol200001E<MD_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E<LEaeG7ELMDa`00ULM00iK
?E/lFcaK?5/mFcaWNfMKIg]WFf]kJgY[Nfmi0VnJ00=cVGNGMiL0<Woo1000HWoo001gOol0:`00Dae>
o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E<LEaeC75LMEaaG?ELLFceK75lmGcaOG5/lGeeO
?6]kJgY_NfmiLiY_NGNILiQg^7NG02ioo`@006Ioo`00N7oo00<005<MD_d00U;m00YC7E;mDaeBoE<M
D_eC7E;mDaeBo@=C7@05D_eG7ELMEaeG7002Ead01UmLGcaO?5llGeaO?0=SG005KgU_VVnJLiUcV002
MiL/Ool3001ZOol007Uoo`0W001C7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG?ELL
EceG75/mEaaOG5/lGeeSFf=LGc]SG6MKIgaSFfmkJgYcVVmi02Uoo`@006eoo`00NWoo00<007ooD_d0
0U;m00IC7E;mDaeBoE<MD_d6Dad02ELMDaeK?ELLFceG75/mEaaK?@03He`01VMkIe]WNfMKJg][NP9_
VRIoo`@0075oo`00Ngoo0P00029>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LFceG75/m
EaaO?E/lFceK76MlIe]WO6]jKg][NV]kKgUcVR9oo`@007Eoo`00OGoo00H005;mDaeBoE<MD_d3Dad0
1E;mDaeC7E<MDa`00eLM00AC75LMFcaK?@9K?008GcaOG5llGca[NV]kJgY[N`9_VQmoo`@007Uoo`00
OWoo01l004klDaeBo5<MC_aC7E;lDaeBo5LMD_aC7ELLEceG75LmEaaG?ELLGeaK?5mMGcaOG5lkHeaS
Ff=LKgUcVP0LOol4001mOol007moo`06001ooe<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@05EaaK
?ELLGeaO?005He`00fMKIg]oo`0IOol30021Ool0081oo`80000IDaeBo5<MC_aC7E;lEaeBo5LMD_aG
7E;lFceG75/mEaaK?ELLHeaO>f=LHe]WO6=KIg`05goo1000Q7oo0022Ool01@00DaeC7E<MD_d00e<M
00QC75LMEaeG7E<LFceG75/m0e/l00EK?E/lIg]WFfMk01Aoo`@008Qoo`00Pgoo01H005<MD_aC7E;l
EaeBo5<MDaaG7E<LEaeC75lmFcaK?E/LGceO?5mLFcaOGA5oo`@008aoo`00Q7oo00D007ooDaeC7E;m
00=C7@05EaaG7ELMEaeG7002Ead01EmLGcaO?5llGe`03Woo1000T7oo0025Ool200003e;lDaeBo5LM
D_aG7ELLEceG75LmEaaK?ELLGeaK?00=Ool3002DOol008Moo`03001C7ELM00=C7@08EaeC7E/mEaaK
?ELLFceG70Yoo`@009Moo`00R7oo00/007ooOomC75LMDaaG7E<LFceG75/m00Qoo`@009]oo`00RGoo
00@007ooOomC70=G7@03Daaoogoo00Aoo`@009moo`00RWoo0P0000=oo`00Ool017oo1000Xgoo002<
Ool200000goo00000002002WOol008eoo`800:]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo
>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00001\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.666 .775 .931 r
.38976 .79823 .3981 .8047 .41202 .80007 .40372 .79384 Mtetra
.684 .786 .928 r
.40372 .79384 .41202 .80007 .42604 .79458 .41777 .78879 Mtetra
.713 .804 .921 r
.41777 .78879 .42604 .79458 .44014 .78749 .43192 .78256 Mtetra
.761 .832 .907 r
.43192 .78256 .44014 .78749 .45435 .77761 .44616 .77421 Mtetra
.828 .869 .876 r
.44616 .77421 .45435 .77761 .46866 .76313 .46051 .76221 Mtetra
.9 .903 .819 r
.46051 .76221 .46866 .76313 .48304 .7419 .47494 .74451 Mtetra
.953 .92 .738 r
.47494 .74451 .48304 .7419 .49741 .71271 .48942 .71919 Mtetra
.976 .92 .658 r
.48942 .71919 .49741 .71271 .51168 .67736 .50385 .6863 Mtetra
.977 .917 .608 r
.50385 .6863 .51168 .67736 .52576 .64122 .51812 .64958 Mtetra
.971 .925 .614 r
.51812 .64958 .52576 .64122 .53968 .61013 .5322 .61523 Mtetra
.962 .943 .683 r
.5322 .61523 .53968 .61013 .55352 .58681 .54615 .58782 Mtetra
.928 .942 .785 r
.54615 .58782 .55352 .58681 .56735 .57057 .56006 .56816 Mtetra
.861 .903 .862 r
.56006 .56816 .56735 .57057 .58125 .55935 .574 .55462 Mtetra
.788 .848 .896 r
.574 .55462 .58125 .55935 .59522 .55123 .58802 .54509 Mtetra
.735 .804 .907 r
.58802 .54509 .59522 .55123 .60927 .54489 .60211 .53794 Mtetra
.703 .776 .909 r
.60211 .53794 .60927 .54489 .6234 .53951 .61629 .53209 Mtetra
.685 .76 .909 r
.61629 .53209 .6234 .53951 .63762 .53464 .63055 .52696 Mtetra
.675 .751 .909 r
.63055 .52696 .63762 .53464 .65191 .53003 .64489 .52219 Mtetra
.669 .747 .908 r
.64489 .52219 .65191 .53003 .66628 .52555 .65931 .5176 Mtetra
.667 .744 .908 r
.65931 .5176 .66628 .52555 .68073 .52113 .6738 .51311 Mtetra
.665 .743 .908 r
.6738 .51311 .68073 .52113 .69525 .51673 .68837 .50864 Mtetra
.664 .742 .908 r
.68837 .50864 .69525 .51673 .70984 .51232 .70302 .50419 Mtetra
.70302 .50419 .70984 .51232 .72452 .50791 .71775 .49973 Mtetra
.71775 .49973 .72452 .50791 .73926 .50348 .73255 .49525 Mtetra
.664 .741 .908 r
.73255 .49525 .73926 .50348 .75409 .49903 .74743 .49076 Mtetra
.74743 .49076 .75409 .49903 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.661 .772 .932 r
.38134 .79163 .38976 .79823 .40372 .79384 .39535 .78739 Mtetra
.674 .78 .929 r
.39535 .78739 .40372 .79384 .41777 .78879 .40944 .78267 Mtetra
.697 .794 .925 r
.40944 .78267 .41777 .78879 .43192 .78256 .42362 .77706 Mtetra
.735 .817 .915 r
.42362 .77706 .43192 .78256 .44616 .77421 .4379 .76986 Mtetra
.793 .85 .894 r
.4379 .76986 .44616 .77421 .46051 .76221 .45228 .75985 Mtetra
.864 .887 .851 r
.45228 .75985 .46051 .76221 .47494 .74451 .46676 .74519 Mtetra
.93 .914 .78 r
.46676 .74519 .47494 .74451 .48942 .71919 .48132 .72374 Mtetra
.968 .922 .696 r
.48132 .72374 .48942 .71919 .50385 .6863 .49588 .69428 Mtetra
.978 .918 .628 r
.49588 .69428 .50385 .6863 .51812 .64958 .51033 .65862 Mtetra
.974 .919 .603 r
.51033 .65862 .51812 .64958 .5322 .61523 .52459 .62216 Mtetra
.968 .934 .641 r
.52459 .62216 .5322 .61523 .54615 .58782 .53869 .5908 Mtetra
.95 .947 .734 r
.53869 .5908 .54615 .58782 .56006 .56816 .55269 .56726 Mtetra
.898 .927 .829 r
.55269 .56726 .56006 .56816 .574 .55462 .56669 .55084 Mtetra
.823 .875 .883 r
.56669 .55084 .574 .55462 .58802 .54509 .58075 .53948 Mtetra
.759 .824 .903 r
.58075 .53948 .58802 .54509 .60211 .53794 .59489 .53124 Mtetra
.717 .789 .908 r
.59489 .53124 .60211 .53794 .61629 .53209 .60911 .52478 Mtetra
.692 .767 .909 r
.60911 .52478 .61629 .53209 .63055 .52696 .62341 .5193 Mtetra
.679 .755 .909 r
.62341 .5193 .63055 .52696 .64489 .52219 .6378 .51432 Mtetra
.672 .749 .908 r
.6378 .51432 .64489 .52219 .65931 .5176 .65227 .50961 Mtetra
.668 .745 .908 r
.65227 .50961 .65931 .5176 .6738 .51311 .66681 .50502 Mtetra
.666 .743 .908 r
.66681 .50502 .6738 .51311 .68837 .50864 .68143 .50049 Mtetra
.665 .742 .908 r
.68143 .50049 .68837 .50864 .70302 .50419 .69613 .49598 Mtetra
.664 .742 .908 r
.69613 .49598 .70302 .50419 .71775 .49973 .71091 .49147 Mtetra
.71091 .49147 .71775 .49973 .73255 .49525 .72577 .48695 Mtetra
.664 .741 .908 r
.72577 .48695 .73255 .49525 .74743 .49076 .7407 .48241 Mtetra
.7407 .48241 .74743 .49076 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.657 .769 .932 r
.37284 .78489 .38134 .79163 .39535 .78739 .38689 .78076 Mtetra
.666 .775 .931 r
.38689 .78076 .39535 .78739 .40944 .78267 .40102 .77626 Mtetra
.684 .786 .928 r
.40102 .77626 .40944 .78267 .42362 .77706 .41524 .77112 Mtetra
.713 .804 .921 r
.41524 .77112 .42362 .77706 .4379 .76986 .42955 .76477 Mtetra
.761 .833 .907 r
.42955 .76477 .4379 .76986 .45228 .75985 .44397 .75629 Mtetra
.828 .869 .876 r
.44397 .75629 .45228 .75985 .46676 .74519 .4585 .74414 Mtetra
.9 .903 .819 r
.4585 .74414 .46676 .74519 .48132 .72374 .47311 .72625 Mtetra
.953 .92 .738 r
.47311 .72625 .48132 .72374 .49588 .69428 .48778 .70067 Mtetra
.976 .92 .658 r
.48778 .70067 .49588 .69428 .51033 .65862 .50239 .66748 Mtetra
.977 .917 .608 r
.50239 .66748 .51033 .65862 .52459 .62216 .51684 .63045 Mtetra
.971 .925 .614 r
.51684 .63045 .52459 .62216 .53869 .5908 .5311 .5958 Mtetra
.962 .943 .683 r
.5311 .5958 .53869 .5908 .55269 .56726 .54523 .56814 Mtetra
.928 .942 .785 r
.54523 .56814 .55269 .56726 .56669 .55084 .55931 .54829 Mtetra
.861 .903 .862 r
.55931 .54829 .56669 .55084 .58075 .53948 .57342 .53459 Mtetra
.788 .848 .896 r
.57342 .53459 .58075 .53948 .59489 .53124 .5876 .52493 Mtetra
.735 .804 .907 r
.5876 .52493 .59489 .53124 .60911 .52478 .60186 .51765 Mtetra
.703 .776 .909 r
.60186 .51765 .60911 .52478 .62341 .5193 .61621 .51169 Mtetra
.685 .76 .909 r
.61621 .51169 .62341 .5193 .6378 .51432 .63064 .50645 Mtetra
.675 .751 .909 r
.63064 .50645 .6378 .51432 .65227 .50961 .64516 .50157 Mtetra
.669 .747 .908 r
.64516 .50157 .65227 .50961 .66681 .50502 .65975 .49688 Mtetra
.667 .744 .908 r
.65975 .49688 .66681 .50502 .68143 .50049 .67443 .49227 Mtetra
.665 .743 .908 r
.67443 .49227 .68143 .50049 .69613 .49598 .68918 .4877 Mtetra
.664 .742 .908 r
.68918 .4877 .69613 .49598 .71091 .49147 .70401 .48314 Mtetra
.70401 .48314 .71091 .49147 .72577 .48695 .71892 .47856 Mtetra
.71892 .47856 .72577 .48695 .7407 .48241 .73391 .47398 Mtetra
.664 .741 .908 r
.73391 .47398 .7407 .48241 .75571 .47784 .74897 .46937 Mtetra
.74897 .46937 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.654 .767 .933 r
.36427 .77805 .37284 .78489 .38689 .78076 .37836 .77398 Mtetra
.661 .772 .932 r
.37836 .77398 .38689 .78076 .40102 .77626 .39253 .76964 Mtetra
.674 .78 .929 r
.39253 .76964 .40102 .77626 .41524 .77112 .40679 .76482 Mtetra
.697 .794 .925 r
.40679 .76482 .41524 .77112 .42955 .76477 .42114 .75911 Mtetra
.735 .817 .915 r
.42114 .75911 .42955 .76477 .44397 .75629 .43559 .75179 Mtetra
.793 .85 .894 r
.43559 .75179 .44397 .75629 .4585 .74414 .45015 .74163 Mtetra
.864 .888 .851 r
.45015 .74163 .4585 .74414 .47311 .72625 .46482 .7268 Mtetra
.93 .914 .78 r
.46482 .7268 .47311 .72625 .48778 .70067 .47956 .70513 Mtetra
.969 .922 .696 r
.47956 .70513 .48778 .70067 .50239 .66748 .4943 .67539 Mtetra
.978 .918 .627 r
.4943 .67539 .50239 .66748 .51684 .63045 .50894 .63941 Mtetra
.974 .919 .603 r
.50894 .63941 .51684 .63045 .5311 .5958 .52339 .60264 Mtetra
.968 .934 .642 r
.52339 .60264 .5311 .5958 .54523 .56814 .53766 .57101 Mtetra
.95 .947 .734 r
.53766 .57101 .54523 .56814 .55931 .54829 .55184 .54724 Mtetra
.898 .927 .829 r
.55184 .54724 .55931 .54829 .57342 .53459 .56602 .53065 Mtetra
.823 .875 .883 r
.56602 .53065 .57342 .53459 .5876 .52493 .58024 .51914 Mtetra
.759 .824 .903 r
.58024 .51914 .5876 .52493 .60186 .51765 .59455 .51077 Mtetra
.717 .788 .908 r
.59455 .51077 .60186 .51765 .61621 .51169 .60894 .50419 Mtetra
.692 .767 .909 r
.60894 .50419 .61621 .51169 .63064 .50645 .62342 .49859 Mtetra
.679 .755 .909 r
.62342 .49859 .63064 .50645 .64516 .50157 .63799 .4935 Mtetra
.672 .749 .908 r
.63799 .4935 .64516 .50157 .65975 .49688 .65263 .48868 Mtetra
.668 .745 .908 r
.65263 .48868 .65975 .49688 .67443 .49227 .66735 .48398 Mtetra
.666 .743 .908 r
.66735 .48398 .67443 .49227 .68918 .4877 .68216 .47934 Mtetra
.665 .742 .908 r
.68216 .47934 .68918 .4877 .70401 .48314 .69704 .47472 Mtetra
.664 .742 .908 r
.69704 .47472 .70401 .48314 .71892 .47856 .712 .4701 Mtetra
.712 .4701 .71892 .47856 .73391 .47398 .72705 .46546 Mtetra
.664 .741 .908 r
.72705 .46546 .73391 .47398 .74897 .46937 .74217 .46081 Mtetra
.74217 .46081 .74897 .46937 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45144 Mtetra
.77266 .45144 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.652 .766 .933 r
.3556 .77111 .36427 .77805 .37836 .77398 .36974 .76708 Mtetra
.657 .769 .932 r
.36974 .76708 .37836 .77398 .39253 .76964 .38395 .76285 Mtetra
.666 .775 .931 r
.38395 .76285 .39253 .76964 .40679 .76482 .39825 .75825 Mtetra
.684 .786 .928 r
.39825 .75825 .40679 .76482 .42114 .75911 .41264 .753 Mtetra
.713 .804 .921 r
.41264 .753 .42114 .75911 .43559 .75179 .42713 .74654 Mtetra
.761 .833 .907 r
.42713 .74654 .43559 .75179 .45015 .74163 .44173 .73793 Mtetra
.828 .869 .876 r
.44173 .73793 .45015 .74163 .46482 .7268 .45643 .72562 Mtetra
.9 .903 .819 r
.45643 .72562 .46482 .7268 .47956 .70513 .47124 .70752 Mtetra
.953 .921 .738 r
.47124 .70752 .47956 .70513 .4943 .67539 .48609 .6817 Mtetra
.976 .92 .658 r
.48609 .6817 .4943 .67539 .50894 .63941 .50089 .6482 Mtetra
.977 .917 .608 r
.50089 .6482 .50894 .63941 .52339 .60264 .51554 .61084 Mtetra
.971 .925 .614 r
.51554 .61084 .52339 .60264 .53766 .57101 .52998 .5759 Mtetra
.962 .943 .684 r
.52998 .5759 .53766 .57101 .55184 .54724 .54428 .54798 Mtetra
.928 .942 .785 r
.54428 .54798 .55184 .54724 .56602 .53065 .55854 .52793 Mtetra
.861 .903 .862 r
.55854 .52793 .56602 .53065 .58024 .51914 .57282 .51407 Mtetra
.788 .848 .896 r
.57282 .51407 .58024 .51914 .59455 .51077 .58717 .50427 Mtetra
.735 .804 .907 r
.58717 .50427 .59455 .51077 .60894 .50419 .60161 .49686 Mtetra
.703 .776 .909 r
.60161 .49686 .60894 .50419 .62342 .49859 .61613 .49079 Mtetra
.685 .76 .909 r
.61613 .49079 .62342 .49859 .63799 .4935 .63074 .48543 Mtetra
.675 .751 .909 r
.63074 .48543 .63799 .4935 .65263 .48868 .64544 .48044 Mtetra
.669 .747 .908 r
.64544 .48044 .65263 .48868 .66735 .48398 .66021 .47564 Mtetra
.667 .744 .908 r
.66021 .47564 .66735 .48398 .68216 .47934 .67507 .47092 Mtetra
.665 .743 .908 r
.67507 .47092 .68216 .47934 .69704 .47472 .69001 .46623 Mtetra
.664 .742 .908 r
.69001 .46623 .69704 .47472 .712 .4701 .70502 .46156 Mtetra
.70502 .46156 .712 .4701 .72705 .46546 .72012 .45687 Mtetra
.72012 .45687 .72705 .46546 .74217 .46081 .7353 .45217 Mtetra
.664 .741 .908 r
.7353 .45217 .74217 .46081 .75737 .45613 .75056 .44744 Mtetra
.75056 .44744 .75737 .45613 .77266 .45144 .7659 .4427 Mtetra
.7659 .4427 .77266 .45144 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Mtetra
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.65 .765 .933 r
.34686 .76408 .3556 .77111 .36974 .76708 .36104 .76006 Mtetra
.654 .767 .933 r
.36104 .76006 .36974 .76708 .38395 .76285 .3753 .75589 Mtetra
.661 .772 .932 r
.3753 .75589 .38395 .76285 .39825 .75825 .38964 .75146 Mtetra
.674 .78 .93 r
.38964 .75146 .39825 .75825 .41264 .753 .40407 .74653 Mtetra
.697 .794 .925 r
.40407 .74653 .41264 .753 .42713 .74654 .4186 .74071 Mtetra
.735 .817 .916 r
.4186 .74071 .42713 .74654 .44173 .73793 .43323 .73326 Mtetra
.793 .851 .894 r
.43323 .73326 .44173 .73793 .45643 .72562 .44797 .72296 Mtetra
.864 .888 .851 r
.44797 .72296 .45643 .72562 .47124 .70752 .46282 .70795 Mtetra
.93 .915 .78 r
.46282 .70795 .47124 .70752 .48609 .6817 .47776 .68604 Mtetra
.969 .922 .696 r
.47776 .68604 .48609 .6817 .50089 .6482 .49269 .65602 Mtetra
.978 .918 .627 r
.49269 .65602 .50089 .6482 .51554 .61084 .50753 .61972 Mtetra
.974 .919 .603 r
.50753 .61972 .51554 .61084 .52998 .5759 .52216 .58263 Mtetra
.968 .934 .642 r
.52216 .58263 .52998 .5759 .54428 .54798 .53662 .55072 Mtetra
.95 .947 .734 r
.53662 .55072 .54428 .54798 .55854 .52793 .55097 .52673 Mtetra
.897 .926 .829 r
.55097 .52673 .55854 .52793 .57282 .51407 .56532 .50995 Mtetra
.823 .875 .883 r
.56532 .50995 .57282 .51407 .58717 .50427 .57973 .49829 Mtetra
.759 .824 .903 r
.57973 .49829 .58717 .50427 .60161 .49686 .59421 .48979 Mtetra
.717 .788 .908 r
.59421 .48979 .60161 .49686 .61613 .49079 .60878 .48309 Mtetra
.692 .767 .909 r
.60878 .48309 .61613 .49079 .63074 .48543 .62343 .47737 Mtetra
.679 .755 .909 r
.62343 .47737 .63074 .48543 .64544 .48044 .63818 .47217 Mtetra
.672 .749 .908 r
.63818 .47217 .64544 .48044 .66021 .47564 .653 .46723 Mtetra
.668 .745 .908 r
.653 .46723 .66021 .47564 .67507 .47092 .66791 .46242 Mtetra
.666 .743 .908 r
.66791 .46242 .67507 .47092 .69001 .46623 .6829 .45767 Mtetra
.665 .742 .908 r
.6829 .45767 .69001 .46623 .70502 .46156 .69797 .45293 Mtetra
.664 .742 .908 r
.69797 .45293 .70502 .46156 .72012 .45687 .71313 .44819 Mtetra
.71313 .44819 .72012 .45687 .7353 .45217 .72836 .44344 Mtetra
.664 .741 .908 r
.72836 .44344 .7353 .45217 .75056 .44744 .74368 .43867 Mtetra
.74368 .43867 .75056 .44744 .7659 .4427 .75908 .43388 Mtetra
.75908 .43388 .7659 .4427 .78132 .43793 .77456 .42906 Mtetra
.77456 .42906 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Mtetra
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.649 .764 .933 r
.33803 .75696 .34686 .76408 .36104 .76006 .35225 .75294 Mtetra
.652 .766 .933 r
.35225 .75294 .36104 .76006 .3753 .75589 .36656 .74881 Mtetra
.657 .769 .932 r
.36656 .74881 .3753 .75589 .38964 .75146 .38094 .74448 Mtetra
.666 .775 .931 r
.38094 .74448 .38964 .75146 .40407 .74653 .39541 .73978 Mtetra
.684 .786 .928 r
.39541 .73978 .40407 .74653 .4186 .74071 .40998 .73442 Mtetra
.713 .804 .921 r
.40998 .73442 .4186 .74071 .43323 .73326 .42465 .72784 Mtetra
.761 .833 .907 r
.42465 .72784 .43323 .73326 .44797 .72296 .43943 .71909 Mtetra
.828 .87 .876 r
.43943 .71909 .44797 .72296 .46282 .70795 .45432 .70662 Mtetra
.9 .904 .819 r
.45432 .70662 .46282 .70795 .47776 .68604 .46931 .68832 Mtetra
.954 .921 .738 r
.46931 .68832 .47776 .68604 .49269 .65602 .48436 .66224 Mtetra
.976 .92 .657 r
.48436 .66224 .49269 .65602 .50753 .61972 .49936 .62843 Mtetra
.977 .917 .608 r
.49936 .62843 .50753 .61972 .52216 .58263 .5142 .59075 Mtetra
.971 .925 .614 r
.5142 .59075 .52216 .58263 .53662 .55072 .52883 .5555 Mtetra
.962 .943 .684 r
.52883 .5555 .53662 .55072 .55097 .52673 .54332 .52733 Mtetra
.928 .942 .785 r
.54332 .52733 .55097 .52673 .56532 .50995 .55775 .50706 Mtetra
.861 .902 .862 r
.55775 .50706 .56532 .50995 .57973 .49829 .57221 .49304 Mtetra
.788 .848 .896 r
.57221 .49304 .57973 .49829 .59421 .48979 .58674 .4831 Mtetra
.735 .804 .907 r
.58674 .4831 .59421 .48979 .60878 .48309 .60135 .47556 Mtetra
.703 .776 .909 r
.60135 .47556 .60878 .48309 .62343 .47737 .61605 .46937 Mtetra
.685 .76 .909 r
.61605 .46937 .62343 .47737 .63818 .47217 .63085 .46389 Mtetra
.675 .751 .909 r
.63085 .46389 .63818 .47217 .653 .46723 .64572 .45879 Mtetra
.669 .747 .908 r
.64572 .45879 .653 .46723 .66791 .46242 .66068 .45387 Mtetra
.667 .744 .908 r
.66068 .45387 .66791 .46242 .6829 .45767 .67573 .44903 Mtetra
.665 .743 .908 r
.67573 .44903 .6829 .45767 .69797 .45293 .69085 .44423 Mtetra
.664 .742 .908 r
.69085 .44423 .69797 .45293 .71313 .44819 .70606 .43943 Mtetra
.70606 .43943 .71313 .44819 .72836 .44344 .72135 .43463 Mtetra
.72135 .43463 .72836 .44344 .74368 .43867 .73673 .42981 Mtetra
.664 .741 .908 r
.73673 .42981 .74368 .43867 .75908 .43388 .75218 .42496 Mtetra
.75218 .42496 .75908 .43388 .77456 .42906 .76773 .4201 Mtetra
.76773 .4201 .77456 .42906 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Mtetra
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.648 .764 .933 r
.32911 .74976 .33803 .75696 .35225 .75294 .34338 .74573 Mtetra
.65 .765 .933 r
.34338 .74573 .35225 .75294 .36656 .74881 .35773 .74162 Mtetra
.654 .767 .933 r
.35773 .74162 .36656 .74881 .38094 .74448 .37216 .73735 Mtetra
.661 .772 .932 r
.37216 .73735 .38094 .74448 .39541 .73978 .38668 .73281 Mtetra
.674 .78 .93 r
.38668 .73281 .39541 .73978 .40998 .73442 .40128 .72777 Mtetra
.697 .794 .925 r
.40128 .72777 .40998 .73442 .42465 .72784 .41599 .72184 Mtetra
.735 .817 .916 r
.41599 .72184 .42465 .72784 .43943 .71909 .4308 .71426 Mtetra
.793 .851 .894 r
.4308 .71426 .43943 .71909 .45432 .70662 .44573 .70381 Mtetra
.865 .888 .851 r
.44573 .70381 .45432 .70662 .46931 .68832 .46078 .68861 Mtetra
.93 .915 .78 r
.46078 .68861 .46931 .68832 .48436 .66224 .47591 .66648 Mtetra
.969 .922 .695 r
.47591 .66648 .48436 .66224 .49936 .62843 .49104 .63616 Mtetra
.978 .918 .627 r
.49104 .63616 .49936 .62843 .5142 .59075 .50607 .59954 Mtetra
.974 .919 .603 r
.50607 .59954 .5142 .59075 .52883 .5555 .52091 .56212 Mtetra
.968 .934 .642 r
.52091 .56212 .52883 .5555 .54332 .52733 .53555 .52993 Mtetra
.95 .947 .734 r
.53555 .52993 .54332 .52733 .55775 .50706 .55008 .5057 Mtetra
.897 .926 .829 r
.55008 .5057 .55775 .50706 .57221 .49304 .56461 .48874 Mtetra
.823 .875 .883 r
.56461 .48874 .57221 .49304 .58674 .4831 .57919 .47693 Mtetra
.759 .824 .903 r
.57919 .47693 .58674 .4831 .60135 .47556 .59385 .46829 Mtetra
.717 .788 .908 r
.59385 .46829 .60135 .47556 .61605 .46937 .6086 .46147 Mtetra
.692 .767 .909 r
.6086 .46147 .61605 .46937 .63085 .46389 .62344 .45563 Mtetra
.679 .755 .909 r
.62344 .45563 .63085 .46389 .64572 .45879 .63837 .4503 Mtetra
.672 .749 .908 r
.63837 .4503 .64572 .45879 .66068 .45387 .65338 .44525 Mtetra
.668 .745 .908 r
.65338 .44525 .66068 .45387 .67573 .44903 .66848 .44032 Mtetra
.666 .743 .908 r
.66848 .44032 .67573 .44903 .69085 .44423 .68366 .43545 Mtetra
.665 .742 .908 r
.68366 .43545 .69085 .44423 .70606 .43943 .69893 .43059 Mtetra
.664 .742 .908 r
.69893 .43059 .70606 .43943 .72135 .43463 .71428 .42573 Mtetra
.71428 .42573 .72135 .43463 .73673 .42981 .72971 .42086 Mtetra
.664 .741 .908 r
.72971 .42086 .73673 .42981 .75218 .42496 .74522 .41596 Mtetra
.74522 .41596 .75218 .42496 .76773 .4201 .76082 .41105 Mtetra
.76082 .41105 .76773 .4201 .78335 .4152 .77651 .4061 Mtetra
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Mtetra
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Mtetra
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.647 .763 .934 r
.3201 .74247 .32911 .74976 .34338 .74573 .33442 .73843 Mtetra
.649 .764 .933 r
.33442 .73843 .34338 .74573 .35773 .74162 .34881 .73432 Mtetra
.652 .766 .933 r
.34881 .73432 .35773 .74162 .37216 .73735 .36329 .73008 Mtetra
.657 .769 .932 r
.36329 .73008 .37216 .73735 .38668 .73281 .37785 .72565 Mtetra
.666 .775 .931 r
.37785 .72565 .38668 .73281 .40128 .72777 .3925 .72084 Mtetra
.684 .786 .928 r
.3925 .72084 .40128 .72777 .41599 .72184 .40725 .71537 Mtetra
.713 .804 .921 r
.40725 .71537 .41599 .72184 .4308 .71426 .4221 .70867 Mtetra
.761 .833 .907 r
.4221 .70867 .4308 .71426 .44573 .70381 .43707 .69978 Mtetra
.828 .87 .876 r
.43707 .69978 .44573 .70381 .46078 .68861 .45215 .68714 Mtetra
.9 .904 .819 r
.45215 .68714 .46078 .68861 .47591 .66648 .46734 .66862 Mtetra
.954 .921 .738 r
.46734 .66862 .47591 .66648 .49104 .63616 .48259 .64228 Mtetra
.976 .921 .657 r
.48259 .64228 .49104 .63616 .50607 .59954 .49779 .60816 Mtetra
.977 .917 .608 r
.49779 .60816 .50607 .59954 .52091 .56212 .51283 .57014 Mtetra
.971 .925 .615 r
.51283 .57014 .52091 .56212 .53555 .52993 .52765 .53458 Mtetra
.962 .942 .684 r
.52765 .53458 .53555 .52993 .55008 .5057 .54232 .50615 Mtetra
.928 .941 .785 r
.54232 .50615 .55008 .5057 .56461 .48874 .55694 .48568 Mtetra
.861 .902 .862 r
.55694 .48568 .56461 .48874 .57919 .47693 .57158 .47149 Mtetra
.788 .848 .896 r
.57158 .47149 .57919 .47693 .59385 .46829 .58629 .4614 Mtetra
.735 .804 .906 r
.58629 .4614 .59385 .46829 .6086 .46147 .60108 .45373 Mtetra
.703 .776 .909 r
.60108 .45373 .6086 .46147 .62344 .45563 .61597 .44741 Mtetra
.685 .76 .909 r
.61597 .44741 .62344 .45563 .63837 .4503 .63095 .44181 Mtetra
.675 .751 .909 r
.63095 .44181 .63837 .4503 .65338 .44525 .64601 .43658 Mtetra
.669 .747 .908 r
.64601 .43658 .65338 .44525 .66848 .44032 .66117 .43154 Mtetra
.667 .744 .908 r
.66117 .43154 .66848 .44032 .68366 .43545 .6764 .42659 Mtetra
.665 .743 .908 r
.6764 .42659 .68366 .43545 .69893 .43059 .69172 .42167 Mtetra
.664 .742 .908 r
.69172 .42167 .69893 .43059 .71428 .42573 .70713 .41675 Mtetra
.70713 .41675 .71428 .42573 .72971 .42086 .72262 .41182 Mtetra
.72262 .41182 .72971 .42086 .74522 .41596 .73819 .40687 Mtetra
.664 .741 .908 r
.73819 .40687 .74522 .41596 .76082 .41105 .75385 .40191 Mtetra
.75385 .40191 .76082 .41105 .77651 .4061 .7696 .39691 Mtetra
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Mtetra
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Mtetra
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.647 .763 .934 r
.31101 .73511 .3201 .74247 .33442 .73843 .32537 .73105 Mtetra
.648 .764 .933 r
.32537 .73105 .33442 .73843 .34881 .73432 .33981 .72692 Mtetra
.65 .765 .933 r
.33981 .72692 .34881 .73432 .36329 .73008 .35433 .7227 Mtetra
.654 .767 .933 r
.35433 .7227 .36329 .73008 .37785 .72565 .36894 .71833 Mtetra
.661 .772 .932 r
.36894 .71833 .37785 .72565 .3925 .72084 .38364 .71368 Mtetra
.674 .78 .93 r
.38364 .71368 .3925 .72084 .40725 .71537 .39843 .70853 Mtetra
.697 .794 .925 r
.39843 .70853 .40725 .71537 .4221 .70867 .41332 .70247 Mtetra
.735 .817 .916 r
.41332 .70247 .4221 .70867 .43707 .69978 .42832 .69477 Mtetra
.793 .851 .894 r
.42832 .69477 .43707 .69978 .45215 .68714 .44344 .68416 Mtetra
.865 .888 .851 r
.44344 .68416 .45215 .68714 .46734 .66862 .45868 .66878 Mtetra
.93 .915 .78 r
.45868 .66878 .46734 .66862 .48259 .64228 .47401 .6464 Mtetra
.969 .922 .695 r
.47401 .6464 .48259 .64228 .49779 .60816 .48935 .61579 Mtetra
.978 .918 .627 r
.48935 .61579 .49779 .60816 .51283 .57014 .50458 .57884 Mtetra
.974 .919 .603 r
.50458 .57884 .51283 .57014 .52765 .53458 .51961 .54109 Mtetra
.968 .934 .642 r
.51961 .54109 .52765 .53458 .54232 .50615 .53445 .50861 Mtetra
.95 .946 .735 r
.53445 .50861 .54232 .50615 .55694 .48568 .54917 .48415 Mtetra
.897 .926 .829 r
.54917 .48415 .55694 .48568 .57158 .47149 .56388 .467 Mtetra
.823 .875 .883 r
.56388 .467 .57158 .47149 .58629 .4614 .57865 .45503 Mtetra
.759 .824 .903 r
.57865 .45503 .58629 .4614 .60108 .45373 .59349 .44625 Mtetra
.717 .788 .908 r
.59349 .44625 .60108 .45373 .61597 .44741 .60843 .43929 Mtetra
.692 .767 .909 r
.60843 .43929 .61597 .44741 .63095 .44181 .62346 .43333 Mtetra
.679 .755 .909 r
.62346 .43333 .63095 .44181 .64601 .43658 .63857 .42788 Mtetra
.672 .749 .908 r
.63857 .42788 .64601 .43658 .66117 .43154 .65378 .4227 Mtetra
.668 .745 .908 r
.65378 .4227 .66117 .43154 .6764 .42659 .66907 .41765 Mtetra
.666 .743 .908 r
.66907 .41765 .6764 .42659 .69172 .42167 .68444 .41266 Mtetra
.665 .742 .908 r
.68444 .41266 .69172 .42167 .70713 .41675 .69991 .40768 Mtetra
.664 .742 .908 r
.69991 .40768 .70713 .41675 .72262 .41182 .71545 .40269 Mtetra
.71545 .40269 .72262 .41182 .73819 .40687 .73109 .39769 Mtetra
.664 .741 .908 r
.73109 .39769 .73819 .40687 .75385 .40191 .74681 .39267 Mtetra
.74681 .39267 .75385 .40191 .7696 .39691 .76262 .38763 Mtetra
.76262 .38763 .7696 .39691 .78543 .39189 .77851 .38255 Mtetra
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Mtetra
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.647 .763 .934 r
.30182 .72767 .31101 .73511 .32537 .73105 .31623 .72358 Mtetra
.31623 .72358 .32537 .73105 .33981 .72692 .33072 .71943 Mtetra
.649 .764 .933 r
.33072 .71943 .33981 .72692 .35433 .7227 .34529 .71521 Mtetra
.652 .766 .933 r
.34529 .71521 .35433 .7227 .36894 .71833 .35994 .71087 Mtetra
.657 .769 .932 r
.35994 .71087 .36894 .71833 .38364 .71368 .37468 .70632 Mtetra
.666 .775 .931 r
.37468 .70632 .38364 .71368 .39843 .70853 .38952 .70141 Mtetra
.684 .786 .928 r
.38952 .70141 .39843 .70853 .41332 .70247 .40445 .69581 Mtetra
.713 .804 .921 r
.40445 .69581 .41332 .70247 .42832 .69477 .41949 .68899 Mtetra
.761 .833 .907 r
.41949 .68899 .42832 .69477 .44344 .68416 .43464 .67995 Mtetra
.828 .87 .876 r
.43464 .67995 .44344 .68416 .45868 .66878 .44992 .66714 Mtetra
.9 .904 .819 r
.44992 .66714 .45868 .66878 .47401 .6464 .46532 .64842 Mtetra
.954 .921 .737 r
.46532 .64842 .47401 .6464 .48935 .61579 .48077 .6218 Mtetra
.976 .921 .657 r
.48077 .6218 .48935 .61579 .50458 .57884 .49618 .58736 Mtetra
.977 .917 .608 r
.49618 .58736 .50458 .57884 .51961 .54109 .51142 .54901 Mtetra
.971 .925 .615 r
.51142 .54901 .51961 .54109 .53445 .50861 .52644 .51313 Mtetra
.962 .942 .684 r
.52644 .51313 .53445 .50861 .54917 .48415 .5413 .48444 Mtetra
.928 .941 .786 r
.5413 .48444 .54917 .48415 .56388 .467 .55611 .46376 Mtetra
.861 .902 .862 r
.55611 .46376 .56388 .467 .57865 .45503 .57093 .44939 Mtetra
.788 .848 .896 r
.57093 .44939 .57865 .45503 .59349 .44625 .58583 .43915 Mtetra
.735 .804 .906 r
.58583 .43915 .59349 .44625 .60843 .43929 .60081 .43134 Mtetra
.703 .776 .909 r
.60081 .43134 .60843 .43929 .62346 .43333 .61589 .42489 Mtetra
.685 .76 .909 r
.61589 .42489 .62346 .43333 .63857 .42788 .63106 .41917 Mtetra
.675 .751 .909 r
.63106 .41917 .63857 .42788 .65378 .4227 .64631 .41381 Mtetra
.669 .747 .908 r
.64631 .41381 .65378 .4227 .66907 .41765 .66166 .40865 Mtetra
.667 .744 .908 r
.66166 .40865 .66907 .41765 .68444 .41266 .67709 .40357 Mtetra
.665 .743 .908 r
.67709 .40357 .68444 .41266 .69991 .40768 .69261 .39852 Mtetra
.664 .742 .908 r
.69261 .39852 .69991 .40768 .71545 .40269 .70822 .39348 Mtetra
.70822 .39348 .71545 .40269 .73109 .39769 .72391 .38842 Mtetra
.72391 .38842 .73109 .39769 .74681 .39267 .73969 .38334 Mtetra
.664 .741 .908 r
.73969 .38334 .74681 .39267 .76262 .38763 .75556 .37825 Mtetra
.75556 .37825 .76262 .38763 .77851 .38255 .77152 .37312 Mtetra
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Mtetra
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .763 .934 r
.29254 .72015 .30182 .72767 .31623 .72358 .307 .71602 Mtetra
.647 .763 .934 r
.307 .71602 .31623 .72358 .33072 .71943 .32153 .71185 Mtetra
.648 .764 .933 r
.32153 .71185 .33072 .71943 .34529 .71521 .33615 .70762 Mtetra
.65 .765 .933 r
.33615 .70762 .34529 .71521 .35994 .71087 .35085 .70329 Mtetra
.654 .767 .933 r
.35085 .70329 .35994 .71087 .37468 .70632 .36564 .69881 Mtetra
.661 .772 .932 r
.36564 .69881 .37468 .70632 .38952 .70141 .38052 .69405 Mtetra
.674 .78 .93 r
.38052 .69405 .38952 .70141 .40445 .69581 .39549 .68879 Mtetra
.697 .794 .925 r
.39549 .68879 .40445 .69581 .41949 .68899 .41057 .6826 Mtetra
.735 .817 .916 r
.41057 .6826 .41949 .68899 .43464 .67995 .42577 .67476 Mtetra
.793 .851 .894 r
.42577 .67476 .43464 .67995 .44992 .66714 .44108 .66399 Mtetra
.865 .889 .851 r
.44108 .66399 .44992 .66714 .46532 .64842 .45652 .64842 Mtetra
.931 .915 .78 r
.45652 .64842 .46532 .64842 .48077 .6218 .47206 .6258 Mtetra
.969 .922 .695 r
.47206 .6258 .48077 .6218 .49618 .58736 .48761 .59489 Mtetra
.978 .918 .627 r
.48761 .59489 .49618 .58736 .51142 .54901 .50305 .5576 Mtetra
.974 .919 .604 r
.50305 .5576 .51142 .54901 .52644 .51313 .51829 .51952 Mtetra
.968 .934 .643 r
.51829 .51952 .52644 .51313 .5413 .48444 .53332 .48675 Mtetra
.95 .946 .735 r
.53332 .48675 .5413 .48444 .55611 .46376 .54824 .46205 Mtetra
.897 .926 .829 r
.54824 .46205 .55611 .46376 .57093 .44939 .56314 .44471 Mtetra
.823 .874 .883 r
.56314 .44471 .57093 .44939 .58583 .43915 .57809 .43257 Mtetra
.759 .824 .903 r
.57809 .43257 .58583 .43915 .60081 .43134 .59312 .42365 Mtetra
.717 .788 .908 r
.59312 .42365 .60081 .43134 .61589 .42489 .60825 .41656 Mtetra
.692 .767 .909 r
.60825 .41656 .61589 .42489 .63106 .41917 .62347 .41046 Mtetra
.679 .755 .909 r
.62347 .41046 .63106 .41917 .64631 .41381 .63878 .40489 Mtetra
.672 .749 .908 r
.63878 .40489 .64631 .41381 .66166 .40865 .65418 .39958 Mtetra
.668 .745 .908 r
.65418 .39958 .66166 .40865 .67709 .40357 .66967 .3944 Mtetra
.666 .743 .908 r
.66967 .3944 .67709 .40357 .69261 .39852 .68525 .38928 Mtetra
.665 .742 .908 r
.68525 .38928 .69261 .39852 .70822 .39348 .70091 .38417 Mtetra
.664 .742 .908 r
.70091 .38417 .70822 .39348 .72391 .38842 .71666 .37905 Mtetra
.71666 .37905 .72391 .38842 .73969 .38334 .73251 .37392 Mtetra
.664 .741 .908 r
.73251 .37392 .73969 .38334 .75556 .37825 .74844 .36877 Mtetra
.74844 .36877 .75556 .37825 .77152 .37312 .76445 .36359 Mtetra
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Mtetra
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .763 .934 r
.28317 .71256 .29254 .72015 .307 .71602 .29767 .70839 Mtetra
.647 .763 .934 r
.29767 .70839 .307 .71602 .32153 .71185 .31225 .70419 Mtetra
.31225 .70419 .32153 .71185 .33615 .70762 .32692 .69993 Mtetra
.649 .764 .933 r
.32692 .69993 .33615 .70762 .35085 .70329 .34167 .6956 Mtetra
.652 .766 .933 r
.34167 .6956 .35085 .70329 .36564 .69881 .35651 .69115 Mtetra
.657 .769 .932 r
.35651 .69115 .36564 .69881 .38052 .69405 .37143 .68649 Mtetra
.666 .775 .931 r
.37143 .68649 .38052 .69405 .39549 .68879 .38645 .68146 Mtetra
.684 .786 .928 r
.38645 .68146 .39549 .68879 .41057 .6826 .40157 .67575 Mtetra
.713 .804 .921 r
.40157 .67575 .41057 .6826 .42577 .67476 .4168 .66879 Mtetra
.761 .833 .907 r
.4168 .66879 .42577 .67476 .44108 .66399 .43216 .6596 Mtetra
.828 .87 .876 r
.43216 .6596 .44108 .66399 .45652 .64842 .44764 .64662 Mtetra
.9 .904 .819 r
.44764 .64662 .45652 .64842 .47206 .6258 .46324 .62767 Mtetra
.954 .921 .737 r
.46324 .62767 .47206 .6258 .48761 .59489 .4789 .60078 Mtetra
.976 .921 .657 r
.4789 .60078 .48761 .59489 .50305 .5576 .49452 .56602 Mtetra
.977 .917 .608 r
.49452 .56602 .50305 .5576 .51829 .51952 .50997 .52732 Mtetra
.971 .925 .615 r
.50997 .52732 .51829 .51952 .53332 .48675 .5252 .49113 Mtetra
.962 .942 .685 r
.5252 .49113 .53332 .48675 .54824 .46205 .54026 .46217 Mtetra
.928 .941 .786 r
.54026 .46217 .54824 .46205 .56314 .44471 .55525 .44127 Mtetra
.861 .902 .862 r
.55525 .44127 .56314 .44471 .57809 .43257 .57027 .42672 Mtetra
.788 .848 .896 r
.57027 .42672 .57809 .43257 .59312 .42365 .58536 .41633 Mtetra
.735 .804 .906 r
.58536 .41633 .59312 .42365 .60825 .41656 .60053 .40838 Mtetra
.703 .776 .909 r
.60053 .40838 .60825 .41656 .62347 .41046 .6158 .4018 Mtetra
.685 .76 .909 r
.6158 .4018 .62347 .41046 .63878 .40489 .63117 .39594 Mtetra
.675 .751 .909 r
.63117 .39594 .63878 .40489 .65418 .39958 .64662 .39046 Mtetra
.669 .747 .908 r
.64662 .39046 .65418 .39958 .66967 .3944 .66217 .38516 Mtetra
.667 .744 .908 r
.66217 .38516 .66967 .3944 .68525 .38928 .6778 .37995 Mtetra
.665 .743 .908 r
.6778 .37995 .68525 .38928 .70091 .38417 .69353 .37477 Mtetra
.664 .742 .908 r
.69353 .37477 .70091 .38417 .71666 .37905 .70934 .36959 Mtetra
.70934 .36959 .71666 .37905 .73251 .37392 .72524 .3644 Mtetra
.72524 .3644 .73251 .37392 .74844 .36877 .74124 .35919 Mtetra
.664 .741 .908 r
.74124 .35919 .74844 .36877 .76445 .36359 .75732 .35396 Mtetra
.75732 .35396 .76445 .36359 .78056 .35838 .77349 .3487 Mtetra
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .763 .934 r
.2737 .70488 .28317 .71256 .29767 .70839 .28825 .70067 Mtetra
.28825 .70067 .29767 .70839 .31225 .70419 .30288 .69643 Mtetra
.647 .763 .934 r
.30288 .69643 .31225 .70419 .32692 .69993 .3176 .69215 Mtetra
.648 .764 .933 r
.3176 .69215 .32692 .69993 .34167 .6956 .33239 .68781 Mtetra
.65 .765 .933 r
.33239 .68781 .34167 .6956 .35651 .69115 .34728 .68337 Mtetra
.654 .767 .933 r
.34728 .68337 .35651 .69115 .37143 .68649 .36225 .67878 Mtetra
.661 .772 .932 r
.36225 .67878 .37143 .68649 .38645 .68146 .37732 .6739 Mtetra
.674 .78 .93 r
.37732 .6739 .38645 .68146 .40157 .67575 .39248 .66852 Mtetra
.697 .794 .925 r
.39248 .66852 .40157 .67575 .4168 .66879 .40776 .66221 Mtetra
.735 .817 .916 r
.40776 .66221 .4168 .66879 .43216 .6596 .42315 .65422 Mtetra
.793 .851 .895 r
.42315 .65422 .43216 .6596 .44764 .64662 .43866 .64329 Mtetra
.865 .889 .851 r
.43866 .64329 .44764 .64662 .46324 .62767 .45431 .62751 Mtetra
.931 .916 .78 r
.45431 .62751 .46324 .62767 .4789 .60078 .47006 .60465 Mtetra
.969 .923 .695 r
.47006 .60465 .4789 .60078 .49452 .56602 .48583 .57344 Mtetra
.978 .918 .627 r
.48583 .57344 .49452 .56602 .50997 .52732 .50149 .53581 Mtetra
.974 .919 .604 r
.50149 .53581 .50997 .52732 .5252 .49113 .51693 .49739 Mtetra
.968 .934 .643 r
.51693 .49739 .5252 .49113 .54026 .46217 .53216 .46432 Mtetra
.95 .946 .735 r
.53216 .46432 .54026 .46217 .55525 .44127 .54728 .43938 Mtetra
.897 .925 .829 r
.54728 .43938 .55525 .44127 .57027 .42672 .56237 .42183 Mtetra
.823 .874 .883 r
.56237 .42183 .57027 .42672 .58536 .41633 .57751 .40953 Mtetra
.759 .824 .903 r
.57751 .40953 .58536 .41633 .60053 .40838 .59274 .40046 Mtetra
.717 .788 .908 r
.59274 .40046 .60053 .40838 .6158 .4018 .60806 .39323 Mtetra
.692 .767 .909 r
.60806 .39323 .6158 .4018 .63117 .39594 .62348 .387 Mtetra
.679 .755 .909 r
.62348 .387 .63117 .39594 .64662 .39046 .63899 .38129 Mtetra
.672 .749 .908 r
.63899 .38129 .64662 .39046 .66217 .38516 .65459 .37585 Mtetra
.668 .745 .908 r
.65459 .37585 .66217 .38516 .6778 .37995 .67028 .37054 Mtetra
.666 .743 .908 r
.67028 .37054 .6778 .37995 .69353 .37477 .68607 .36528 Mtetra
.665 .742 .908 r
.68607 .36528 .69353 .37477 .70934 .36959 .70194 .36004 Mtetra
.664 .742 .908 r
.70194 .36004 .70934 .36959 .72524 .3644 .71791 .35479 Mtetra
.71791 .35479 .72524 .3644 .74124 .35919 .73396 .34952 Mtetra
.664 .741 .908 r
.73396 .34952 .74124 .35919 .75732 .35396 .75011 .34423 Mtetra
.75011 .34423 .75732 .35396 .77349 .3487 .76634 .33891 Mtetra
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .763 .934 r
.26413 .69712 .2737 .70488 .28825 .70067 .27873 .69288 Mtetra
.27873 .69288 .28825 .70067 .30288 .69643 .29341 .6886 Mtetra
.647 .763 .934 r
.29341 .6886 .30288 .69643 .3176 .69215 .30817 .68429 Mtetra
.30817 .68429 .3176 .69215 .33239 .68781 .32302 .67992 Mtetra
.649 .764 .933 r
.32302 .67992 .33239 .68781 .34728 .68337 .33796 .67548 Mtetra
.652 .766 .933 r
.33796 .67548 .34728 .68337 .36225 .67878 .35298 .67091 Mtetra
.657 .769 .932 r
.35298 .67091 .36225 .67878 .37732 .6739 .36809 .66614 Mtetra
.666 .775 .931 r
.36809 .66614 .37732 .6739 .39248 .66852 .3833 .66099 Mtetra
.684 .786 .928 r
.3833 .66099 .39248 .66852 .40776 .66221 .39862 .65514 Mtetra
.713 .804 .922 r
.39862 .65514 .40776 .66221 .42315 .65422 .41405 .64805 Mtetra
.761 .833 .907 r
.41405 .64805 .42315 .65422 .43866 .64329 .4296 .63871 Mtetra
.828 .87 .876 r
.4296 .63871 .43866 .64329 .45431 .62751 .44529 .62554 Mtetra
.9 .905 .819 r
.44529 .62554 .45431 .62751 .47006 .60465 .4611 .60637 Mtetra
.954 .922 .737 r
.4611 .60637 .47006 .60465 .48583 .57344 .47698 .5792 Mtetra
.976 .921 .657 r
.47698 .5792 .48583 .57344 .50149 .53581 .49282 .54411 Mtetra
.977 .917 .608 r
.49282 .54411 .50149 .53581 .51693 .49739 .50849 .50507 Mtetra
.972 .925 .615 r
.50849 .50507 .51693 .49739 .53216 .46432 .52393 .46855 Mtetra
.962 .942 .685 r
.52393 .46855 .53216 .46432 .54728 .43938 .53919 .43932 Mtetra
.928 .941 .786 r
.53919 .43932 .54728 .43938 .56237 .42183 .55438 .4182 Mtetra
.86 .902 .862 r
.55438 .4182 .56237 .42183 .57751 .40953 .56959 .40347 Mtetra
.788 .847 .896 r
.56959 .40347 .57751 .40953 .59274 .40046 .58487 .39291 Mtetra
.735 .804 .906 r
.58487 .39291 .59274 .40046 .60806 .39323 .60025 .38482 Mtetra
.703 .776 .909 r
.60025 .38482 .60806 .39323 .62348 .387 .61571 .3781 Mtetra
.685 .76 .909 r
.61571 .3781 .62348 .387 .63899 .38129 .63128 .3721 Mtetra
.675 .751 .909 r
.63128 .3721 .63899 .38129 .65459 .37585 .64694 .36648 Mtetra
.669 .747 .908 r
.64694 .36648 .65459 .37585 .67028 .37054 .66269 .36105 Mtetra
.667 .744 .908 r
.66269 .36105 .67028 .37054 .68607 .36528 .67853 .35571 Mtetra
.665 .743 .908 r
.67853 .35571 .68607 .36528 .70194 .36004 .69447 .35039 Mtetra
.664 .742 .908 r
.69447 .35039 .70194 .36004 .71791 .35479 .71049 .34508 Mtetra
.71049 .34508 .71791 .35479 .73396 .34952 .72661 .33975 Mtetra
.72661 .33975 .73396 .34952 .75011 .34423 .74282 .3344 Mtetra
.664 .741 .908 r
.74282 .3344 .75011 .34423 .76634 .33891 .75912 .32903 Mtetra
.75912 .32903 .76634 .33891 .78267 .33357 .77552 .32362 Mtetra
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68928 .26413 .69712 .27873 .69288 .26911 .685 Mtetra
.646 .763 .934 r
.26911 .685 .27873 .69288 .29341 .6886 .28384 .68068 Mtetra
.28384 .68068 .29341 .6886 .30817 .68429 .29866 .67633 Mtetra
.647 .763 .934 r
.29866 .67633 .30817 .68429 .32302 .67992 .31355 .67193 Mtetra
.648 .764 .933 r
.31355 .67193 .32302 .67992 .33796 .67548 .32854 .66748 Mtetra
.65 .765 .933 r
.32854 .66748 .33796 .67548 .35298 .67091 .34361 .66292 Mtetra
.654 .767 .933 r
.34361 .66292 .35298 .67091 .36809 .66614 .35877 .65821 Mtetra
.661 .772 .932 r
.35877 .65821 .36809 .66614 .3833 .66099 .37403 .65321 Mtetra
.674 .78 .93 r
.37403 .65321 .3833 .66099 .39862 .65514 .38939 .6477 Mtetra
.696 .794 .925 r
.38939 .6477 .39862 .65514 .41405 .64805 .40486 .64126 Mtetra
.735 .818 .916 r
.40486 .64126 .41405 .64805 .4296 .63871 .42046 .63313 Mtetra
.793 .851 .895 r
.42046 .63313 .4296 .63871 .44529 .62554 .43618 .62203 Mtetra
.865 .889 .851 r
.43618 .62203 .44529 .62554 .4611 .60637 .45204 .60605 Mtetra
.931 .916 .78 r
.45204 .60605 .4611 .60637 .47698 .5792 .46801 .58293 Mtetra
.969 .923 .695 r
.46801 .58293 .47698 .5792 .49282 .54411 .484 .55141 Mtetra
.978 .918 .626 r
.484 .55141 .49282 .54411 .50849 .50507 .49987 .51343 Mtetra
.974 .919 .604 r
.49987 .51343 .50849 .50507 .52393 .46855 .51554 .47468 Mtetra
.968 .934 .643 r
.51554 .47468 .52393 .46855 .53919 .43932 .53098 .4413 Mtetra
.95 .946 .735 r
.53098 .4413 .53919 .43932 .55438 .4182 .54629 .41611 Mtetra
.897 .925 .829 r
.54629 .41611 .55438 .4182 .56959 .40347 .56158 .39837 Mtetra
.823 .874 .883 r
.56158 .39837 .56959 .40347 .58487 .39291 .57693 .38589 Mtetra
.759 .824 .903 r
.57693 .38589 .58487 .39291 .60025 .38482 .59235 .37666 Mtetra
.717 .788 .908 r
.59235 .37666 .60025 .38482 .61571 .3781 .60787 .36929 Mtetra
.692 .767 .909 r
.60787 .36929 .61571 .3781 .63128 .3721 .62349 .36292 Mtetra
.679 .755 .909 r
.62349 .36292 .63128 .3721 .64694 .36648 .63921 .35707 Mtetra
.672 .749 .908 r
.63921 .35707 .64694 .36648 .66269 .36105 .65502 .3515 Mtetra
.668 .745 .908 r
.65502 .3515 .66269 .36105 .67853 .35571 .67092 .34605 Mtetra
.666 .743 .908 r
.67092 .34605 .67853 .35571 .69447 .35039 .68691 .34065 Mtetra
.665 .742 .908 r
.68691 .34065 .69447 .35039 .71049 .34508 .703 .33527 Mtetra
.664 .742 .908 r
.703 .33527 .71049 .34508 .72661 .33975 .71918 .32988 Mtetra
.71918 .32988 .72661 .33975 .74282 .3344 .73545 .32447 Mtetra
.664 .741 .908 r
.73545 .32447 .74282 .3344 .75912 .32903 .75182 .31903 Mtetra
.75182 .31903 .75912 .32903 .77552 .32362 .76828 .31357 Mtetra
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .762 .934 r
.2447 .68136 .25446 .68928 .26911 .685 .25939 .67703 Mtetra
.646 .763 .934 r
.25939 .67703 .26911 .685 .28384 .68068 .27417 .67267 Mtetra
.27417 .67267 .28384 .68068 .29866 .67633 .28904 .66828 Mtetra
.647 .763 .934 r
.28904 .66828 .29866 .67633 .31355 .67193 .30399 .66385 Mtetra
.30399 .66385 .31355 .67193 .32854 .66748 .31902 .65937 Mtetra
.649 .764 .933 r
.31902 .65937 .32854 .66748 .34361 .66292 .33414 .65481 Mtetra
.652 .766 .933 r
.33414 .65481 .34361 .66292 .35877 .65821 .34936 .65013 Mtetra
.657 .769 .932 r
.34936 .65013 .35877 .65821 .37403 .65321 .36466 .64523 Mtetra
.666 .775 .931 r
.36466 .64523 .37403 .65321 .38939 .6477 .38007 .63995 Mtetra
.683 .786 .928 r
.38007 .63995 .38939 .6477 .40486 .64126 .39559 .63398 Mtetra
.713 .805 .922 r
.39559 .63398 .40486 .64126 .42046 .63313 .41122 .62675 Mtetra
.761 .833 .907 r
.41122 .62675 .42046 .63313 .43618 .62203 .42698 .61725 Mtetra
.828 .87 .876 r
.42698 .61725 .43618 .62203 .45204 .60605 .44288 .6039 Mtetra
.9 .905 .819 r
.44288 .6039 .45204 .60605 .46801 .58293 .45891 .58449 Mtetra
.954 .922 .737 r
.45891 .58449 .46801 .58293 .484 .55141 .47501 .55704 Mtetra
.976 .921 .656 r
.47501 .55704 .484 .55141 .49987 .51343 .49108 .52162 Mtetra
.977 .917 .608 r
.49108 .52162 .49987 .51343 .51554 .47468 .50697 .48222 Mtetra
.972 .925 .615 r
.50697 .48222 .51554 .47468 .53098 .4413 .52262 .44538 Mtetra
.962 .942 .685 r
.52262 .44538 .53098 .4413 .54629 .41611 .53809 .41587 Mtetra
.928 .941 .786 r
.53809 .41587 .54629 .41611 .56158 .39837 .55348 .39452 Mtetra
.86 .901 .861 r
.55348 .39452 .56158 .39837 .57693 .38589 .56889 .3796 Mtetra
.788 .847 .896 r
.56889 .3796 .57693 .38589 .59235 .37666 .58438 .36888 Mtetra
.735 .804 .906 r
.58438 .36888 .59235 .37666 .60787 .36929 .59995 .36064 Mtetra
.703 .776 .909 r
.59995 .36064 .60787 .36929 .62349 .36292 .61562 .35377 Mtetra
.685 .76 .909 r
.61562 .35377 .62349 .36292 .63921 .35707 .63139 .34763 Mtetra
.675 .751 .909 r
.63139 .34763 .63921 .35707 .65502 .3515 .64726 .34188 Mtetra
.669 .747 .908 r
.64726 .34188 .65502 .3515 .67092 .34605 .66322 .3363 Mtetra
.667 .744 .908 r
.66322 .3363 .67092 .34605 .68691 .34065 .67928 .33082 Mtetra
.665 .743 .908 r
.67928 .33082 .68691 .34065 .703 .33527 .69543 .32536 Mtetra
.664 .742 .908 r
.69543 .32536 .703 .33527 .71918 .32988 .71167 .3199 Mtetra
.71167 .3199 .71918 .32988 .73545 .32447 .72801 .31443 Mtetra
.72801 .31443 .73545 .32447 .75182 .31903 .74444 .30894 Mtetra
.664 .741 .908 r
.74444 .30894 .75182 .31903 .76828 .31357 .76097 .30342 Mtetra
.76097 .30342 .76828 .31357 .78484 .30808 .7776 .29787 Mtetra
.7776 .29787 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68136 .25939 .67703 .24958 .66899 Mtetra
.24958 .66899 .25939 .67703 .27417 .67267 .2644 .66458 Mtetra
.646 .763 .934 r
.2644 .66458 .27417 .67267 .28904 .66828 .27932 .66015 Mtetra
.27932 .66015 .28904 .66828 .30399 .66385 .29432 .65568 Mtetra
.647 .763 .934 r
.29432 .65568 .30399 .66385 .31902 .65937 .3094 .65117 Mtetra
.648 .764 .933 r
.3094 .65117 .31902 .65937 .33414 .65481 .32458 .64659 Mtetra
.65 .765 .933 r
.32458 .64659 .33414 .65481 .34936 .65013 .33984 .64192 Mtetra
.654 .767 .933 r
.33984 .64192 .34936 .65013 .36466 .64523 .3552 .63708 Mtetra
.661 .772 .932 r
.3552 .63708 .36466 .64523 .38007 .63995 .37066 .63196 Mtetra
.674 .78 .93 r
.37066 .63196 .38007 .63995 .39559 .63398 .38622 .62632 Mtetra
.696 .794 .925 r
.38622 .62632 .39559 .63398 .41122 .62675 .40189 .61974 Mtetra
.735 .818 .916 r
.40189 .61974 .41122 .62675 .42698 .61725 .41769 .61146 Mtetra
.793 .851 .895 r
.41769 .61146 .42698 .61725 .44288 .6039 .43363 .60019 Mtetra
.865 .889 .851 r
.43363 .60019 .44288 .6039 .45891 .58449 .44971 .584 Mtetra
.931 .916 .78 r
.44971 .584 .45891 .58449 .47501 .55704 .4659 .56062 Mtetra
.969 .923 .694 r
.4659 .56062 .47501 .55704 .49108 .52162 .48211 .52878 Mtetra
.978 .918 .626 r
.48211 .52878 .49108 .52162 .50697 .48222 .49822 .49046 Mtetra
.974 .919 .604 r
.49822 .49046 .50697 .48222 .52262 .44538 .5141 .45135 Mtetra
.968 .934 .644 r
.5141 .45135 .52262 .44538 .53809 .41587 .52976 .41767 Mtetra
.95 .946 .736 r
.52976 .41767 .53809 .41587 .55348 .39452 .54528 .39223 Mtetra
.897 .925 .829 r
.54528 .39223 .55348 .39452 .56889 .3796 .56078 .37428 Mtetra
.823 .874 .883 r
.56078 .37428 .56889 .3796 .58438 .36888 .57632 .36162 Mtetra
.759 .823 .903 r
.57632 .36162 .58438 .36888 .59995 .36064 .59195 .35224 Mtetra
.717 .788 .908 r
.59195 .35224 .59995 .36064 .61562 .35377 .60768 .34471 Mtetra
.692 .767 .909 r
.60768 .34471 .61562 .35377 .63139 .34763 .6235 .33819 Mtetra
.679 .755 .909 r
.6235 .33819 .63139 .34763 .64726 .34188 .63943 .33221 Mtetra
.672 .749 .908 r
.63943 .33221 .64726 .34188 .66322 .3363 .65545 .32649 Mtetra
.668 .745 .908 r
.65545 .32649 .66322 .3363 .67928 .33082 .67157 .32089 Mtetra
.666 .743 .908 r
.67157 .32089 .67928 .33082 .69543 .32536 .68778 .31535 Mtetra
.665 .742 .908 r
.68778 .31535 .69543 .32536 .71167 .3199 .70409 .30983 Mtetra
.664 .742 .908 r
.70409 .30983 .71167 .3199 .72801 .31443 .72049 .30429 Mtetra
.72049 .30429 .72801 .31443 .74444 .30894 .73699 .29873 Mtetra
.664 .741 .908 r
.73699 .29873 .74444 .30894 .76097 .30342 .75358 .29315 Mtetra
.75358 .29315 .76097 .30342 .7776 .29787 .77027 .28754 Mtetra
.77027 .28754 .7776 .29787 .79432 .29228 .78706 .2819 Mtetra
.78706 .2819 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66085 Mtetra
.23965 .66085 .24958 .66899 .2644 .66458 .25453 .65641 Mtetra
.646 .763 .934 r
.25453 .65641 .2644 .66458 .27932 .66015 .2695 .65193 Mtetra
.2695 .65193 .27932 .66015 .29432 .65568 .28455 .64742 Mtetra
.647 .763 .934 r
.28455 .64742 .29432 .65568 .3094 .65117 .29968 .64287 Mtetra
.29968 .64287 .3094 .65117 .32458 .64659 .31491 .63827 Mtetra
.649 .764 .933 r
.31491 .63827 .32458 .64659 .33984 .64192 .33023 .63359 Mtetra
.652 .766 .933 r
.33023 .63359 .33984 .64192 .3552 .63708 .34564 .62878 Mtetra
.657 .769 .932 r
.34564 .62878 .3552 .63708 .37066 .63196 .36114 .62376 Mtetra
.666 .775 .931 r
.36114 .62376 .37066 .63196 .38622 .62632 .37675 .61835 Mtetra
.683 .786 .928 r
.37675 .61835 .38622 .62632 .40189 .61974 .39247 .61224 Mtetra
.713 .805 .922 r
.39247 .61224 .40189 .61974 .41769 .61146 .40831 .60486 Mtetra
.761 .833 .907 r
.40831 .60486 .41769 .61146 .43363 .60019 .42429 .5952 Mtetra
.828 .871 .876 r
.42429 .5952 .43363 .60019 .44971 .584 .44041 .58165 Mtetra
.9 .905 .819 r
.44041 .58165 .44971 .584 .4659 .56062 .45666 .56201 Mtetra
.954 .922 .737 r
.45666 .56201 .4659 .56062 .48211 .52878 .47299 .53427 Mtetra
.976 .921 .656 r
.47299 .53427 .48211 .52878 .49822 .49046 .48929 .49851 Mtetra
.977 .917 .608 r
.48929 .49851 .49822 .49046 .5141 .45135 .50541 .45875 Mtetra
.972 .925 .616 r
.50541 .45875 .5141 .45135 .52976 .41767 .52128 .42158 Mtetra
.962 .942 .686 r
.52128 .42158 .52976 .41767 .54528 .39223 .53696 .39179 Mtetra
.928 .94 .786 r
.53696 .39179 .54528 .39223 .56078 .37428 .55256 .37021 Mtetra
.86 .901 .861 r
.55256 .37021 .56078 .37428 .57632 .36162 .56818 .3551 Mtetra
.788 .847 .896 r
.56818 .3551 .57632 .36162 .59195 .35224 .58387 .34421 Mtetra
.735 .804 .906 r
.58387 .34421 .59195 .35224 .60768 .34471 .59965 .33581 Mtetra
.703 .776 .909 r
.59965 .33581 .60768 .34471 .6235 .33819 .61553 .32879 Mtetra
.685 .76 .909 r
.61553 .32879 .6235 .33819 .63943 .33221 .63151 .32251 Mtetra
.675 .751 .909 r
.63151 .32251 .63943 .33221 .65545 .32649 .64759 .3166 Mtetra
.669 .747 .908 r
.64759 .3166 .65545 .32649 .67157 .32089 .66377 .31089 Mtetra
.667 .744 .908 r
.66377 .31089 .67157 .32089 .68778 .31535 .68005 .30525 Mtetra
.665 .743 .908 r
.68005 .30525 .68778 .31535 .70409 .30983 .69642 .29965 Mtetra
.664 .742 .908 r
.69642 .29965 .70409 .30983 .72049 .30429 .71289 .29404 Mtetra
.71289 .29404 .72049 .30429 .73699 .29873 .72945 .28842 Mtetra
.72945 .28842 .73699 .29873 .75358 .29315 .74612 .28277 Mtetra
.664 .741 .908 r
.74612 .28277 .75358 .29315 .77027 .28754 .76287 .2771 Mtetra
.76287 .2771 .77027 .28754 .78706 .2819 .77973 .2714 Mtetra
.77973 .2714 .78706 .2819 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66085 .22963 .65263 Mtetra
.22963 .65263 .23965 .66085 .25453 .65641 .24456 .64814 Mtetra
.24456 .64814 .25453 .65641 .2695 .65193 .25957 .64362 Mtetra
.646 .763 .934 r
.25957 .64362 .2695 .65193 .28455 .64742 .27467 .63907 Mtetra
.27467 .63907 .28455 .64742 .29968 .64287 .28986 .63448 Mtetra
.647 .763 .934 r
.28986 .63448 .29968 .64287 .31491 .63827 .30514 .62984 Mtetra
.648 .764 .933 r
.30514 .62984 .31491 .63827 .33023 .63359 .32051 .62514 Mtetra
.65 .765 .933 r
.32051 .62514 .33023 .63359 .34564 .62878 .33597 .62034 Mtetra
.654 .767 .933 r
.33597 .62034 .34564 .62878 .36114 .62376 .35153 .61538 Mtetra
.661 .772 .932 r
.35153 .61538 .36114 .62376 .37675 .61835 .36719 .61012 Mtetra
.674 .78 .93 r
.36719 .61012 .37675 .61835 .39247 .61224 .38295 .60435 Mtetra
.696 .794 .925 r
.38295 .60435 .39247 .61224 .40831 .60486 .39884 .59762 Mtetra
.735 .818 .916 r
.39884 .59762 .40831 .60486 .42429 .5952 .41485 .58918 Mtetra
.793 .851 .895 r
.41485 .58918 .42429 .5952 .44041 .58165 .43101 .57774 Mtetra
.865 .889 .851 r
.43101 .57774 .44041 .58165 .45666 .56201 .44731 .56133 Mtetra
.931 .916 .78 r
.44731 .56133 .45666 .56201 .47299 .53427 .46373 .53769 Mtetra
.969 .923 .694 r
.46373 .53769 .47299 .53427 .48929 .49851 .48018 .50554 Mtetra
.978 .918 .626 r
.48018 .50554 .48929 .49851 .50541 .45875 .49652 .46685 Mtetra
.974 .919 .604 r
.49652 .46685 .50541 .45875 .52128 .42158 .51263 .42739 Mtetra
.968 .934 .644 r
.51263 .42739 .52128 .42158 .53696 .39179 .52851 .3934 Mtetra
.95 .946 .736 r
.52851 .3934 .53696 .39179 .55256 .37021 .54424 .3677 Mtetra
.897 .925 .829 r
.54424 .3677 .55256 .37021 .56818 .3551 .55995 .34954 Mtetra
.823 .874 .883 r
.55995 .34954 .56818 .3551 .58387 .34421 .5757 .33671 Mtetra
.759 .823 .903 r
.5757 .33671 .58387 .34421 .59965 .33581 .59154 .32715 Mtetra
.717 .788 .908 r
.59154 .32715 .59965 .33581 .61553 .32879 .60748 .31947 Mtetra
.692 .767 .909 r
.60748 .31947 .61553 .32879 .63151 .32251 .62352 .3128 Mtetra
.679 .755 .909 r
.62352 .3128 .63151 .32251 .64759 .3166 .63966 .30667 Mtetra
.672 .749 .908 r
.63966 .30667 .64759 .3166 .66377 .31089 .6559 .3008 Mtetra
.668 .745 .908 r
.6559 .3008 .66377 .31089 .68005 .30525 .67224 .29506 Mtetra
.666 .743 .908 r
.67224 .29506 .68005 .30525 .69642 .29965 .68867 .28937 Mtetra
.665 .742 .908 r
.68867 .28937 .69642 .29965 .71289 .29404 .7052 .28369 Mtetra
.664 .742 .908 r
.7052 .28369 .71289 .29404 .72945 .28842 .72184 .278 Mtetra
.72184 .278 .72945 .28842 .74612 .28277 .73857 .27229 Mtetra
.664 .741 .908 r
.73857 .27229 .74612 .28277 .76287 .2771 .75539 .26655 Mtetra
.75539 .26655 .76287 .2771 .77973 .2714 .77232 .26078 Mtetra
.77232 .26078 .77973 .2714 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65263 .2195 .64433 Mtetra
.2195 .64433 .22963 .65263 .24456 .64814 .23447 .63979 Mtetra
.23447 .63979 .24456 .64814 .25957 .64362 .24954 .63522 Mtetra
.646 .763 .934 r
.24954 .63522 .25957 .64362 .27467 .63907 .26469 .63062 Mtetra
.26469 .63062 .27467 .63907 .28986 .63448 .27993 .62599 Mtetra
.647 .763 .934 r
.27993 .62599 .28986 .63448 .30514 .62984 .29526 .62132 Mtetra
.29526 .62132 .30514 .62984 .32051 .62514 .31069 .61659 Mtetra
.649 .764 .933 r
.31069 .61659 .32051 .62514 .33597 .62034 .3262 .61178 Mtetra
.652 .766 .933 r
.3262 .61178 .33597 .62034 .35153 .61538 .34181 .60684 Mtetra
.657 .769 .932 r
.34181 .60684 .35153 .61538 .36719 .61012 .35752 .60169 Mtetra
.666 .775 .931 r
.35752 .60169 .36719 .61012 .38295 .60435 .37334 .59614 Mtetra
.683 .786 .928 r
.37334 .59614 .38295 .60435 .39884 .59762 .38927 .58989 Mtetra
.713 .805 .922 r
.38927 .58989 .39884 .59762 .41485 .58918 .40532 .58236 Mtetra
.761 .833 .907 r
.40532 .58236 .41485 .58918 .43101 .57774 .42152 .57253 Mtetra
.828 .871 .876 r
.42152 .57253 .43101 .57774 .44731 .56133 .43786 .55878 Mtetra
.9 .905 .819 r
.43786 .55878 .44731 .56133 .46373 .53769 .45434 .53891 Mtetra
.954 .922 .737 r
.45434 .53891 .46373 .53769 .48018 .50554 .47091 .51087 Mtetra
.976 .921 .656 r
.47091 .51087 .48018 .50554 .49652 .46685 .48745 .47476 Mtetra
.977 .917 .608 r
.48745 .47476 .49652 .46685 .51263 .42739 .5038 .43464 Mtetra
.972 .925 .616 r
.5038 .43464 .51263 .42739 .52851 .3934 .5199 .39713 Mtetra
.962 .942 .686 r
.5199 .39713 .52851 .3934 .54424 .3677 .5358 .36705 Mtetra
.928 .94 .786 r
.5358 .36705 .54424 .3677 .55995 .34954 .55162 .34524 Mtetra
.86 .901 .861 r
.55162 .34524 .55995 .34954 .5757 .33671 .56744 .32993 Mtetra
.788 .847 .895 r
.56744 .32993 .5757 .33671 .59154 .32715 .58334 .31887 Mtetra
.735 .804 .906 r
.58334 .31887 .59154 .32715 .60748 .31947 .59934 .31031 Mtetra
.703 .776 .909 r
.59934 .31031 .60748 .31947 .62352 .3128 .61544 .30313 Mtetra
.685 .76 .909 r
.61544 .30313 .62352 .3128 .63966 .30667 .63164 .2967 Mtetra
.675 .751 .909 r
.63164 .2967 .63966 .30667 .6559 .3008 .64794 .29064 Mtetra
.669 .747 .908 r
.64794 .29064 .6559 .3008 .67224 .29506 .66434 .28477 Mtetra
.667 .744 .908 r
.66434 .28477 .67224 .29506 .68867 .28937 .68084 .27899 Mtetra
.665 .743 .908 r
.68084 .27899 .68867 .28937 .7052 .28369 .69744 .27323 Mtetra
.664 .742 .908 r
.69744 .27323 .7052 .28369 .72184 .278 .71414 .26747 Mtetra
.71414 .26747 .72184 .278 .73857 .27229 .73093 .26169 Mtetra
.73093 .26169 .73857 .27229 .75539 .26655 .74783 .25589 Mtetra
.664 .741 .908 r
.74783 .25589 .75539 .26655 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24419 Mtetra
.78193 .24419 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63134 Mtetra
.22428 .63134 .23447 .63979 .24954 .63522 .2394 .62673 Mtetra
.2394 .62673 .24954 .63522 .26469 .63062 .2546 .62208 Mtetra
.646 .763 .934 r
.2546 .62208 .26469 .63062 .27993 .62599 .2699 .61741 Mtetra
.2699 .61741 .27993 .62599 .29526 .62132 .28528 .61269 Mtetra
.647 .763 .934 r
.28528 .61269 .29526 .62132 .31069 .61659 .30076 .60793 Mtetra
.648 .764 .933 r
.30076 .60793 .31069 .61659 .3262 .61178 .31633 .6031 Mtetra
.65 .765 .933 r
.31633 .6031 .3262 .61178 .34181 .60684 .33199 .59817 Mtetra
.654 .767 .933 r
.33199 .59817 .34181 .60684 .35752 .60169 .34776 .59307 Mtetra
.661 .772 .932 r
.34776 .59307 .35752 .60169 .37334 .59614 .36362 .58768 Mtetra
.674 .78 .93 r
.36362 .58768 .37334 .59614 .38927 .58989 .3796 .58176 Mtetra
.696 .794 .925 r
.3796 .58176 .38927 .58989 .40532 .58236 .3957 .57489 Mtetra
.735 .818 .916 r
.3957 .57489 .40532 .58236 .42152 .57253 .41193 .56629 Mtetra
.793 .852 .895 r
.41193 .56629 .42152 .57253 .43786 .55878 .42831 .55465 Mtetra
.865 .89 .851 r
.42831 .55465 .43786 .55878 .45434 .53891 .44484 .53803 Mtetra
.931 .917 .779 r
.44484 .53803 .45434 .53891 .47091 .51087 .4615 .51411 Mtetra
.969 .923 .694 r
.4615 .51411 .47091 .51087 .48745 .47476 .47819 .48164 Mtetra
.978 .918 .626 r
.47819 .48164 .48745 .47476 .5038 .43464 .49477 .44259 Mtetra
.974 .919 .604 r
.49477 .44259 .5038 .43464 .5199 .39713 .51112 .40278 Mtetra
.969 .933 .644 r
.51112 .40278 .5199 .39713 .5358 .36705 .52722 .36847 Mtetra
.95 .945 .736 r
.52722 .36847 .5358 .36705 .55162 .34524 .54318 .34251 Mtetra
.897 .924 .829 r
.54318 .34251 .55162 .34524 .56744 .32993 .5591 .32413 Mtetra
.823 .874 .883 r
.5591 .32413 .56744 .32993 .58334 .31887 .57506 .31111 Mtetra
.759 .823 .902 r
.57506 .31111 .58334 .31887 .59934 .31031 .59112 .30139 Mtetra
.717 .788 .908 r
.59112 .30139 .59934 .31031 .61544 .30313 .60727 .29354 Mtetra
.692 .767 .909 r
.60727 .29354 .61544 .30313 .63164 .2967 .62353 .28672 Mtetra
.679 .755 .909 r
.62353 .28672 .63164 .2967 .64794 .29064 .63989 .28043 Mtetra
.672 .749 .908 r
.63989 .28043 .64794 .29064 .66434 .28477 .65636 .2744 Mtetra
.668 .745 .908 r
.65636 .2744 .66434 .28477 .68084 .27899 .67292 .26851 Mtetra
.666 .743 .908 r
.67292 .26851 .68084 .27899 .69744 .27323 .68959 .26266 Mtetra
.665 .742 .908 r
.68959 .26266 .69744 .27323 .71414 .26747 .70635 .25682 Mtetra
.664 .742 .908 r
.70635 .25682 .71414 .26747 .73093 .26169 .72322 .25097 Mtetra
.72322 .25097 .73093 .26169 .74783 .25589 .74019 .2451 Mtetra
.664 .741 .908 r
.74019 .2451 .74783 .25589 .76483 .25005 .75726 .23921 Mtetra
.75726 .23921 .76483 .25005 .78193 .24419 .77443 .23327 Mtetra
.77443 .23327 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.646 .762 .934 r
.18391 .63205 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63134 .21398 .62281 Mtetra
.21398 .62281 .22428 .63134 .2394 .62673 .22915 .61815 Mtetra
.22915 .61815 .2394 .62673 .2546 .62208 .24441 .61345 Mtetra
.646 .763 .934 r
.24441 .61345 .2546 .62208 .2699 .61741 .25975 .60873 Mtetra
.25975 .60873 .2699 .61741 .28528 .61269 .27519 .60397 Mtetra
.647 .763 .934 r
.27519 .60397 .28528 .61269 .30076 .60793 .29072 .59916 Mtetra
.29072 .59916 .30076 .60793 .31633 .6031 .30635 .5943 Mtetra
.649 .764 .933 r
.30635 .5943 .31633 .6031 .33199 .59817 .32206 .58936 Mtetra
.652 .766 .933 r
.32206 .58936 .33199 .59817 .34776 .59307 .33788 .58429 Mtetra
.657 .769 .932 r
.33788 .58429 .34776 .59307 .36362 .58768 .3538 .579 Mtetra
.666 .775 .931 r
.3538 .579 .36362 .58768 .3796 .58176 .36983 .57331 Mtetra
.683 .786 .928 r
.36983 .57331 .3796 .58176 .3957 .57489 .38597 .56691 Mtetra
.713 .805 .922 r
.38597 .56691 .3957 .57489 .41193 .56629 .40225 .55922 Mtetra
.761 .834 .908 r
.40225 .55922 .41193 .56629 .42831 .55465 .41867 .54922 Mtetra
.828 .871 .877 r
.41867 .54922 .42831 .55465 .44484 .53803 .43524 .53527 Mtetra
.9 .906 .819 r
.43524 .53527 .44484 .53803 .4615 .51411 .45196 .51515 Mtetra
.954 .922 .737 r
.45196 .51515 .4615 .51411 .47819 .48164 .46877 .48681 Mtetra
.976 .921 .656 r
.46877 .48681 .47819 .48164 .49477 .44259 .48555 .45035 Mtetra
.977 .917 .608 r
.48555 .45035 .49477 .44259 .51112 .40278 .50215 .40987 Mtetra
.972 .925 .616 r
.50215 .40987 .51112 .40278 .52722 .36847 .51849 .37201 Mtetra
.962 .942 .686 r
.51849 .37201 .52722 .36847 .54318 .34251 .53461 .34164 Mtetra
.928 .94 .786 r
.53461 .34164 .54318 .34251 .5591 .32413 .55064 .31959 Mtetra
.86 .901 .861 r
.55064 .31959 .5591 .32413 .57506 .31111 .56669 .30408 Mtetra
.788 .847 .895 r
.56669 .30408 .57506 .31111 .59112 .30139 .58281 .29283 Mtetra
.735 .804 .906 r
.58281 .29283 .59112 .30139 .60727 .29354 .59902 .28411 Mtetra
.703 .776 .909 r
.59902 .28411 .60727 .29354 .62353 .28672 .61534 .27677 Mtetra
.685 .76 .909 r
.61534 .27677 .62353 .28672 .63989 .28043 .63176 .27017 Mtetra
.675 .751 .909 r
.63176 .27017 .63989 .28043 .65636 .2744 .64829 .26396 Mtetra
.669 .747 .908 r
.64829 .26396 .65636 .2744 .67292 .26851 .66492 .25793 Mtetra
.667 .744 .908 r
.66492 .25793 .67292 .26851 .68959 .26266 .68165 .25199 Mtetra
.665 .743 .908 r
.68165 .25199 .68959 .26266 .70635 .25682 .69848 .24607 Mtetra
.664 .742 .908 r
.69848 .24607 .70635 .25682 .72322 .25097 .71542 .24015 Mtetra
.71542 .24015 .72322 .25097 .74019 .2451 .73246 .23421 Mtetra
.73246 .23421 .74019 .2451 .75726 .23921 .7496 .22824 Mtetra
.664 .741 .908 r
.7496 .22824 .75726 .23921 .77443 .23327 .76684 .22224 Mtetra
.76684 .22224 .77443 .23327 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63205 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61345 .2341 .60472 Mtetra
.2341 .60472 .24441 .61345 .25975 .60873 .2495 .59995 Mtetra
.646 .763 .934 r
.2495 .59995 .25975 .60873 .27519 .60397 .26499 .59514 Mtetra
.26499 .59514 .27519 .60397 .29072 .59916 .28058 .59029 Mtetra
.647 .763 .934 r
.28058 .59029 .29072 .59916 .30635 .5943 .29625 .5854 Mtetra
.648 .764 .933 r
.29625 .5854 .30635 .5943 .32206 .58936 .31203 .58043 Mtetra
.65 .765 .933 r
.31203 .58043 .32206 .58936 .33788 .58429 .3279 .57537 Mtetra
.654 .767 .933 r
.3279 .57537 .33788 .58429 .3538 .579 .34388 .57013 Mtetra
.661 .772 .932 r
.34388 .57013 .3538 .579 .36983 .57331 .35996 .5646 Mtetra
.674 .78 .93 r
.35996 .5646 .36983 .57331 .38597 .56691 .37615 .55853 Mtetra
.696 .794 .925 r
.37615 .55853 .38597 .56691 .40225 .55922 .39247 .55151 Mtetra
.735 .818 .916 r
.39247 .55151 .40225 .55922 .41867 .54922 .40893 .54274 Mtetra
.793 .852 .895 r
.40893 .54274 .41867 .54922 .43524 .53527 .42554 .53091 Mtetra
.865 .89 .851 r
.42554 .53091 .43524 .53527 .45196 .51515 .44231 .51406 Mtetra
.931 .917 .779 r
.44231 .51406 .45196 .51515 .46877 .48681 .45921 .48987 Mtetra
.969 .923 .694 r
.45921 .48987 .46877 .48681 .48555 .45035 .47615 .45706 Mtetra
.978 .918 .626 r
.47615 .45706 .48555 .45035 .50215 .40987 .49298 .41765 Mtetra
.974 .919 .604 r
.49298 .41765 .50215 .40987 .51849 .37201 .50957 .37748 Mtetra
.969 .933 .644 r
.50957 .37748 .51849 .37201 .53461 .34164 .5259 .34285 Mtetra
.95 .945 .736 r
.5259 .34285 .53461 .34164 .55064 .31959 .54208 .31662 Mtetra
.897 .924 .829 r
.54208 .31662 .55064 .31959 .56669 .30408 .55822 .29802 Mtetra
.823 .873 .883 r
.55822 .29802 .56669 .30408 .58281 .29283 .57441 .28481 Mtetra
.759 .823 .902 r
.57441 .28481 .58281 .29283 .59902 .28411 .59068 .27491 Mtetra
.717 .788 .908 r
.59068 .27491 .59902 .28411 .61534 .27677 .60706 .2669 Mtetra
.692 .767 .909 r
.60706 .2669 .61534 .27677 .63176 .27017 .62354 .25991 Mtetra
.679 .755 .909 r
.62354 .25991 .63176 .27017 .64829 .26396 .64013 .25346 Mtetra
.672 .749 .908 r
.64013 .25346 .64829 .26396 .66492 .25793 .65683 .24727 Mtetra
.668 .745 .908 r
.65683 .24727 .66492 .25793 .68165 .25199 .67363 .24121 Mtetra
.666 .743 .908 r
.67363 .24121 .68165 .25199 .69848 .24607 .69053 .2352 Mtetra
.665 .742 .908 r
.69053 .2352 .69848 .24607 .71542 .24015 .70753 .2292 Mtetra
.664 .742 .908 r
.70753 .2292 .71542 .24015 .73246 .23421 .72464 .22319 Mtetra
.72464 .22319 .73246 .23421 .7496 .22824 .74185 .21715 Mtetra
.664 .741 .908 r
.74185 .21715 .7496 .22824 .76684 .22224 .75917 .21108 Mtetra
.75917 .21108 .76684 .22224 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19885 Mtetra
.79412 .19885 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60472 .22368 .5959 Mtetra
.22368 .5959 .2341 .60472 .2495 .59995 .23913 .59108 Mtetra
.646 .763 .934 r
.23913 .59108 .2495 .59995 .26499 .59514 .25468 .58622 Mtetra
.25468 .58622 .26499 .59514 .28058 .59029 .27032 .58132 Mtetra
.647 .763 .934 r
.27032 .58132 .28058 .59029 .29625 .5854 .28605 .57638 Mtetra
.28605 .57638 .29625 .5854 .31203 .58043 .30188 .57139 Mtetra
.649 .764 .933 r
.30188 .57139 .31203 .58043 .3279 .57537 .31781 .56631 Mtetra
.652 .766 .933 r
.31781 .56631 .3279 .57537 .34388 .57013 .33384 .5611 Mtetra
.657 .769 .932 r
.33384 .5611 .34388 .57013 .35996 .5646 .34997 .55566 Mtetra
.666 .775 .931 r
.34997 .55566 .35996 .5646 .37615 .55853 .36622 .54983 Mtetra
.683 .786 .928 r
.36622 .54983 .37615 .55853 .39247 .55151 .38259 .54328 Mtetra
.713 .805 .922 r
.38259 .54328 .39247 .55151 .40893 .54274 .39909 .53542 Mtetra
.761 .834 .908 r
.39909 .53542 .40893 .54274 .42554 .53091 .41574 .52524 Mtetra
.828 .871 .877 r
.41574 .52524 .42554 .53091 .44231 .51406 .43255 .51108 Mtetra
.901 .906 .819 r
.43255 .51108 .44231 .51406 .45921 .48987 .44951 .4907 Mtetra
.954 .923 .736 r
.44951 .4907 .45921 .48987 .47615 .45706 .46658 .46205 Mtetra
.976 .921 .655 r
.46658 .46205 .47615 .45706 .49298 .41765 .48361 .42524 Mtetra
.977 .917 .608 r
.48361 .42524 .49298 .41765 .50957 .37748 .50045 .38439 Mtetra
.972 .925 .616 r
.50045 .38439 .50957 .37748 .5259 .34285 .51703 .34619 Mtetra
.962 .942 .686 r
.51703 .34619 .5259 .34285 .54208 .31662 .53339 .31553 Mtetra
.928 .94 .786 r
.53339 .31553 .54208 .31662 .55822 .29802 .54965 .29323 Mtetra
.86 .9 .861 r
.54965 .29323 .55822 .29802 .57441 .28481 .56591 .27751 Mtetra
.788 .847 .895 r
.56591 .27751 .57441 .28481 .59068 .27491 .58225 .26608 Mtetra
.735 .804 .906 r
.58225 .26608 .59068 .27491 .60706 .2669 .59869 .25717 Mtetra
.703 .776 .909 r
.59869 .25717 .60706 .2669 .62354 .25991 .61524 .24967 Mtetra
.685 .76 .909 r
.61524 .24967 .62354 .25991 .64013 .25346 .63189 .24291 Mtetra
.675 .751 .909 r
.63189 .24291 .64013 .25346 .65683 .24727 .64865 .23653 Mtetra
.669 .747 .908 r
.64865 .23653 .65683 .24727 .67363 .24121 .66551 .23034 Mtetra
.667 .744 .908 r
.66551 .23034 .67363 .24121 .69053 .2352 .68248 .22423 Mtetra
.665 .743 .908 r
.68248 .22423 .69053 .2352 .70753 .2292 .69956 .21814 Mtetra
.664 .742 .908 r
.69956 .21814 .70753 .2292 .72464 .22319 .71674 .21205 Mtetra
.71674 .21205 .72464 .22319 .74185 .21715 .73402 .20594 Mtetra
.73402 .20594 .74185 .21715 .75917 .21108 .75141 .1998 Mtetra
.664 .741 .908 r
.75141 .1998 .75917 .21108 .77659 .20498 .76891 .19363 Mtetra
.76891 .19363 .77659 .20498 .79412 .19885 .78651 .18742 Mtetra
.78651 .18742 .79412 .19885 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .5959 .21314 .58698 Mtetra
.21314 .58698 .22368 .5959 .23913 .59108 .22865 .5821 Mtetra
.22865 .5821 .23913 .59108 .25468 .58622 .24425 .57719 Mtetra
.646 .763 .934 r
.24425 .57719 .25468 .58622 .27032 .58132 .25995 .57225 Mtetra
.25995 .57225 .27032 .58132 .28605 .57638 .27574 .56726 Mtetra
.647 .763 .934 r
.27574 .56726 .28605 .57638 .30188 .57139 .29162 .56223 Mtetra
.648 .764 .933 r
.29162 .56223 .30188 .57139 .31781 .56631 .30761 .55712 Mtetra
.65 .765 .933 r
.30761 .55712 .31781 .56631 .33384 .5611 .32369 .55191 Mtetra
.654 .767 .933 r
.32369 .55191 .33384 .5611 .34997 .55566 .33988 .54653 Mtetra
.661 .772 .932 r
.33988 .54653 .34997 .55566 .36622 .54983 .35618 .54085 Mtetra
.674 .78 .93 r
.35618 .54085 .36622 .54983 .38259 .54328 .3726 .53464 Mtetra
.696 .794 .926 r
.3726 .53464 .38259 .54328 .39909 .53542 .38915 .52745 Mtetra
.735 .818 .916 r
.38915 .52745 .39909 .53542 .41574 .52524 .40584 .5185 Mtetra
.793 .852 .895 r
.40584 .5185 .41574 .52524 .43255 .51108 .42269 .50648 Mtetra
.865 .89 .851 r
.42269 .50648 .43255 .51108 .44951 .4907 .4397 .4894 Mtetra
.931 .917 .779 r
.4397 .4894 .44951 .4907 .46658 .46205 .45685 .46492 Mtetra
.969 .923 .694 r
.45685 .46492 .46658 .46205 .48361 .42524 .47405 .43178 Mtetra
.978 .918 .626 r
.47405 .43178 .48361 .42524 .50045 .38439 .49113 .392 Mtetra
.974 .919 .604 r
.49113 .392 .50045 .38439 .51703 .34619 .50797 .35146 Mtetra
.969 .933 .645 r
.50797 .35146 .51703 .34619 .53339 .31553 .52454 .31651 Mtetra
.95 .945 .736 r
.52454 .31651 .53339 .31553 .54965 .29323 .54095 .29001 Mtetra
.897 .924 .829 r
.54095 .29001 .54965 .29323 .56591 .27751 .55732 .27118 Mtetra
.823 .873 .882 r
.55732 .27118 .56591 .27751 .58225 .26608 .57373 .25777 Mtetra
.759 .823 .902 r
.57373 .25777 .58225 .26608 .59869 .25717 .59023 .24769 Mtetra
.717 .788 .908 r
.59023 .24769 .59869 .25717 .61524 .24967 .60684 .2395 Mtetra
.692 .767 .909 r
.60684 .2395 .61524 .24967 .63189 .24291 .62356 .23234 Mtetra
.679 .755 .909 r
.62356 .23234 .63189 .24291 .64865 .23653 .64038 .22572 Mtetra
.672 .749 .908 r
.64038 .22572 .64865 .23653 .66551 .23034 .65731 .21937 Mtetra
.668 .745 .908 r
.65731 .21937 .66551 .23034 .68248 .22423 .67435 .21314 Mtetra
.666 .743 .908 r
.67435 .21314 .68248 .22423 .69956 .21814 .6915 .20696 Mtetra
.665 .742 .908 r
.6915 .20696 .69956 .21814 .71674 .21205 .70875 .20079 Mtetra
.664 .742 .908 r
.70875 .20079 .71674 .21205 .73402 .20594 .7261 .1946 Mtetra
.7261 .1946 .73402 .20594 .75141 .1998 .74357 .18839 Mtetra
.664 .741 .908 r
.74357 .18839 .75141 .1998 .76891 .19363 .76114 .18215 Mtetra
.76114 .18215 .76891 .19363 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16956 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .5821 .21805 .57303 Mtetra
.21805 .57303 .22865 .5821 .24425 .57719 .23371 .56807 Mtetra
.646 .763 .934 r
.23371 .56807 .24425 .57719 .25995 .57225 .24946 .56307 Mtetra
.24946 .56307 .25995 .57225 .27574 .56726 .26531 .55804 Mtetra
.647 .763 .934 r
.26531 .55804 .27574 .56726 .29162 .56223 .28125 .55296 Mtetra
.28125 .55296 .29162 .56223 .30761 .55712 .29729 .54782 Mtetra
.649 .764 .933 r
.29729 .54782 .30761 .55712 .32369 .55191 .31343 .54259 Mtetra
.652 .766 .933 r
.31343 .54259 .32369 .55191 .33988 .54653 .32968 .53723 Mtetra
.657 .769 .932 r
.32968 .53723 .33988 .54653 .35618 .54085 .34604 .53165 Mtetra
.666 .775 .931 r
.34604 .53165 .35618 .54085 .3726 .53464 .36251 .52566 Mtetra
.683 .786 .928 r
.36251 .52566 .3726 .53464 .38915 .52745 .3791 .51895 Mtetra
.713 .805 .922 r
.3791 .51895 .38915 .52745 .40584 .5185 .39583 .51093 Mtetra
.761 .834 .908 r
.39583 .51093 .40584 .5185 .42269 .50648 .41272 .50056 Mtetra
.828 .871 .877 r
.41272 .50056 .42269 .50648 .4397 .4894 .42978 .48618 Mtetra
.901 .906 .819 r
.42978 .48618 .4397 .4894 .45685 .46492 .44699 .46555 Mtetra
.954 .923 .736 r
.44699 .46555 .45685 .46492 .47405 .43178 .46431 .43659 Mtetra
.976 .921 .655 r
.46431 .43659 .47405 .43178 .49113 .392 .48161 .39941 Mtetra
.977 .917 .608 r
.48161 .39941 .49113 .392 .50797 .35146 .49871 .35818 Mtetra
.972 .925 .617 r
.49871 .35818 .50797 .35146 .52454 .31651 .51553 .31963 Mtetra
.963 .942 .687 r
.51553 .31963 .52454 .31651 .54095 .29001 .53213 .28867 Mtetra
.928 .939 .786 r
.53213 .28867 .54095 .29001 .55732 .27118 .54862 .26612 Mtetra
.86 .9 .861 r
.54862 .26612 .55732 .27118 .57373 .25777 .56512 .25019 Mtetra
.788 .847 .895 r
.56512 .25019 .57373 .25777 .59023 .24769 .58169 .23856 Mtetra
.735 .803 .906 r
.58169 .23856 .59023 .24769 .60684 .2395 .59835 .22948 Mtetra
.703 .776 .909 r
.59835 .22948 .60684 .2395 .62356 .23234 .61513 .2218 Mtetra
.685 .76 .909 r
.61513 .2218 .62356 .23234 .64038 .22572 .63202 .21487 Mtetra
.675 .751 .909 r
.63202 .21487 .64038 .22572 .65731 .21937 .64902 .20832 Mtetra
.669 .747 .908 r
.64902 .20832 .65731 .21937 .67435 .21314 .66613 .20195 Mtetra
.667 .744 .908 r
.66613 .20195 .67435 .21314 .6915 .20696 .68334 .19567 Mtetra
.665 .743 .908 r
.68334 .19567 .6915 .20696 .70875 .20079 .70067 .18941 Mtetra
.664 .742 .908 r
.70067 .18941 .70875 .20079 .7261 .1946 .7181 .18314 Mtetra
.7181 .18314 .7261 .1946 .74357 .18839 .73563 .17686 Mtetra
.73563 .17686 .74357 .18839 .76114 .18215 .75328 .17054 Mtetra
.664 .741 .908 r
.75328 .17054 .76114 .18215 .77882 .17587 .77104 .16419 Mtetra
.77104 .16419 .77882 .17587 .79661 .16956 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56385 Mtetra
.20734 .56385 .21805 .57303 .23371 .56807 .22305 .55884 Mtetra
.22305 .55884 .23371 .56807 .24946 .56307 .23885 .55379 Mtetra
.646 .763 .934 r
.23885 .55379 .24946 .56307 .26531 .55804 .25476 .5487 Mtetra
.25476 .5487 .26531 .55804 .28125 .55296 .27076 .54357 Mtetra
.647 .763 .934 r
.27076 .54357 .28125 .55296 .29729 .54782 .28686 .53839 Mtetra
.648 .764 .933 r
.28686 .53839 .29729 .54782 .31343 .54259 .30306 .53314 Mtetra
.65 .765 .933 r
.30306 .53314 .31343 .54259 .32968 .53723 .31936 .52778 Mtetra
.654 .767 .933 r
.31936 .52778 .32968 .53723 .34604 .53165 .33578 .52225 Mtetra
.661 .772 .932 r
.33578 .52225 .34604 .53165 .36251 .52566 .3523 .51642 Mtetra
.674 .78 .93 r
.3523 .51642 .36251 .52566 .3791 .51895 .36895 .51004 Mtetra
.696 .794 .926 r
.36895 .51004 .3791 .51895 .39583 .51093 .38573 .50269 Mtetra
.735 .818 .916 r
.38573 .50269 .39583 .51093 .41272 .50056 .40266 .49356 Mtetra
.793 .852 .895 r
.40266 .49356 .41272 .50056 .42978 .48618 .41975 .48134 Mtetra
.865 .89 .851 r
.41975 .48134 .42978 .48618 .44699 .46555 .43701 .46401 Mtetra
.931 .917 .779 r
.43701 .46401 .44699 .46555 .46431 .43659 .45442 .43925 Mtetra
.969 .924 .693 r
.45442 .43925 .46431 .43659 .48161 .39941 .47188 .40576 Mtetra
.978 .918 .625 r
.47188 .40576 .48161 .39941 .49871 .35818 .48923 .3656 Mtetra
.974 .919 .604 r
.48923 .3656 .49871 .35818 .51553 .31963 .50633 .32469 Mtetra
.969 .933 .645 r
.50633 .32469 .51553 .31963 .53213 .28867 .52315 .28942 Mtetra
.95 .945 .737 r
.52315 .28942 .53213 .28867 .54862 .26612 .53979 .26264 Mtetra
.897 .924 .829 r
.53979 .26264 .54862 .26612 .56512 .25019 .5564 .24358 Mtetra
.823 .873 .882 r
.5564 .24358 .56512 .25019 .58169 .23856 .57304 .22996 Mtetra
.759 .823 .902 r
.57304 .22996 .58169 .23856 .59835 .22948 .58978 .21969 Mtetra
.717 .788 .908 r
.58978 .21969 .59835 .22948 .61513 .2218 .60662 .21133 Mtetra
.692 .767 .909 r
.60662 .21133 .61513 .2218 .63202 .21487 .62357 .20399 Mtetra
.679 .755 .909 r
.62357 .20399 .63202 .21487 .64902 .20832 .64064 .1972 Mtetra
.672 .749 .908 r
.64064 .1972 .64902 .20832 .66613 .20195 .65781 .19067 Mtetra
.668 .745 .908 r
.65781 .19067 .66613 .20195 .68334 .19567 .6751 .18426 Mtetra
.666 .743 .908 r
.6751 .18426 .68334 .19567 .70067 .18941 .69249 .17791 Mtetra
.665 .742 .908 r
.69249 .17791 .70067 .18941 .7181 .18314 .71 .17156 Mtetra
.664 .742 .908 r
.71 .17156 .7181 .18314 .73563 .17686 .72761 .16519 Mtetra
.72761 .16519 .73563 .17686 .75328 .17054 .74533 .1588 Mtetra
.664 .741 .908 r
.74533 .1588 .75328 .17054 .77104 .16419 .76317 .15237 Mtetra
.76317 .15237 .77104 .16419 .78891 .1578 .78111 .14591 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56462 Mtetra
.16526 .56462 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56385 .1965 .55457 Mtetra
.1965 .55457 .20734 .56385 .22305 .55884 .21227 .5495 Mtetra
.21227 .5495 .22305 .55884 .23885 .55379 .22813 .5444 Mtetra
.646 .763 .934 r
.22813 .5444 .23885 .55379 .25476 .5487 .24409 .53926 Mtetra
.24409 .53926 .25476 .5487 .27076 .54357 .26015 .53408 Mtetra
.647 .763 .934 r
.26015 .53408 .27076 .54357 .28686 .53839 .27631 .52885 Mtetra
.27631 .52885 .28686 .53839 .30306 .53314 .29257 .52356 Mtetra
.649 .764 .933 r
.29257 .52356 .30306 .53314 .31936 .52778 .30893 .51819 Mtetra
.652 .766 .933 r
.30893 .51819 .31936 .52778 .33578 .52225 .3254 .51267 Mtetra
.657 .769 .932 r
.3254 .51267 .33578 .52225 .3523 .51642 .34198 .50693 Mtetra
.666 .775 .931 r
.34198 .50693 .3523 .51642 .36895 .51004 .35868 .50079 Mtetra
.683 .786 .928 r
.35868 .50079 .36895 .51004 .38573 .50269 .37551 .49391 Mtetra
.713 .805 .922 r
.37551 .49391 .38573 .50269 .40266 .49356 .39248 .48571 Mtetra
.761 .834 .908 r
.39248 .48571 .40266 .49356 .41975 .48134 .40962 .47515 Mtetra
.828 .872 .877 r
.40962 .47515 .41975 .48134 .43701 .46401 .42692 .46055 Mtetra
.901 .906 .819 r
.42692 .46055 .43701 .46401 .45442 .43925 .4444 .43965 Mtetra
.954 .923 .736 r
.4444 .43965 .45442 .43925 .47188 .40576 .46198 .41037 Mtetra
.976 .921 .655 r
.46198 .41037 .47188 .40576 .48923 .3656 .47954 .37283 Mtetra
.977 .917 .608 r
.47954 .37283 .48923 .3656 .50633 .32469 .49691 .33121 Mtetra
.972 .925 .617 r
.49691 .33121 .50633 .32469 .52315 .28942 .51399 .29231 Mtetra
.963 .941 .687 r
.51399 .29231 .52315 .28942 .53979 .26264 .53083 .26104 Mtetra
.928 .939 .786 r
.53083 .26104 .53979 .26264 .5564 .24358 .54756 .23824 Mtetra
.86 .9 .861 r
.54756 .23824 .5564 .24358 .57304 .22996 .5643 .22208 Mtetra
.788 .846 .895 r
.5643 .22208 .57304 .22996 .58978 .21969 .5811 .21026 Mtetra
.735 .803 .906 r
.5811 .21026 .58978 .21969 .60662 .21133 .59801 .20099 Mtetra
.703 .776 .908 r
.59801 .20099 .60662 .21133 .62357 .20399 .61503 .19313 Mtetra
.685 .76 .909 r
.61503 .19313 .62357 .20399 .64064 .1972 .63216 .18602 Mtetra
.675 .751 .908 r
.63216 .18602 .64064 .1972 .65781 .19067 .6494 .17929 Mtetra
.669 .747 .908 r
.6494 .17929 .65781 .19067 .6751 .18426 .66676 .17275 Mtetra
.667 .744 .908 r
.66676 .17275 .6751 .18426 .69249 .17791 .68423 .16628 Mtetra
.665 .743 .908 r
.68423 .16628 .69249 .17791 .71 .17156 .7018 .15984 Mtetra
.664 .742 .908 r
.7018 .15984 .71 .17156 .72761 .16519 .71949 .15339 Mtetra
.71949 .15339 .72761 .16519 .74533 .1588 .73729 .14692 Mtetra
.73729 .14692 .74533 .1588 .76317 .15237 .75521 .14041 Mtetra
.664 .741 .908 r
.75521 .14041 .76317 .15237 .78111 .14591 .77323 .13387 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56462 .15419 .55535 Mtetra
.15419 .55535 .16526 .56462 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55457 .18554 .54519 Mtetra
.18554 .54519 .1965 .55457 .21227 .5495 .20137 .54006 Mtetra
.20137 .54006 .21227 .5495 .22813 .5444 .21728 .5349 Mtetra
.21728 .5349 .22813 .5444 .24409 .53926 .2333 .5297 Mtetra
.646 .763 .934 r
.2333 .5297 .24409 .53926 .26015 .53408 .24942 .52447 Mtetra
.24942 .52447 .26015 .53408 .27631 .52885 .26563 .51919 Mtetra
.647 .763 .934 r
.26563 .51919 .27631 .52885 .29257 .52356 .28195 .51386 Mtetra
.648 .764 .933 r
.28195 .51386 .29257 .52356 .30893 .51819 .29838 .50845 Mtetra
.65 .765 .933 r
.29838 .50845 .30893 .51819 .3254 .51267 .31491 .50294 Mtetra
.654 .767 .933 r
.31491 .50294 .3254 .51267 .34198 .50693 .33155 .49725 Mtetra
.661 .772 .932 r
.33155 .49725 .34198 .50693 .35868 .50079 .34831 .49126 Mtetra
.674 .78 .93 r
.34831 .49126 .35868 .50079 .37551 .49391 .36519 .48472 Mtetra
.696 .794 .926 r
.36519 .48472 .37551 .49391 .39248 .48571 .38221 .47719 Mtetra
.735 .818 .916 r
.38221 .47719 .39248 .48571 .40962 .47515 .39938 .46787 Mtetra
.793 .852 .895 r
.39938 .46787 .40962 .47515 .42692 .46055 .41672 .45544 Mtetra
.865 .891 .852 r
.41672 .45544 .42692 .46055 .4444 .43965 .43425 .43787 Mtetra
.931 .918 .779 r
.43425 .43787 .4444 .43965 .46198 .41037 .45192 .41281 Mtetra
.969 .924 .693 r
.45192 .41281 .46198 .41037 .47954 .37283 .46966 .37898 Mtetra
.978 .918 .625 r
.46966 .37898 .47954 .37283 .49691 .33121 .48728 .33843 Mtetra
.974 .919 .604 r
.48728 .33843 .49691 .33121 .51399 .29231 .50464 .29715 Mtetra
.969 .933 .645 r
.50464 .29715 .51399 .29231 .53083 .26104 .52171 .26154 Mtetra
.95 .945 .737 r
.52171 .26154 .53083 .26104 .54756 .23824 .5386 .23449 Mtetra
.897 .923 .829 r
.5386 .23449 .54756 .23824 .5643 .22208 .55544 .21518 Mtetra
.823 .873 .882 r
.55544 .21518 .5643 .22208 .5811 .21026 .57233 .20135 Mtetra
.759 .823 .902 r
.57233 .20135 .5811 .21026 .59801 .20099 .5893 .19089 Mtetra
.717 .788 .908 r
.5893 .19089 .59801 .20099 .61503 .19313 .60639 .18234 Mtetra
.692 .767 .909 r
.60639 .18234 .61503 .19313 .63216 .18602 .62359 .17482 Mtetra
.679 .755 .909 r
.62359 .17482 .63216 .18602 .6494 .17929 .6409 .16784 Mtetra
.672 .749 .908 r
.6409 .16784 .6494 .17929 .66676 .17275 .65833 .16113 Mtetra
.668 .745 .908 r
.65833 .16113 .66676 .17275 .68423 .16628 .67587 .15454 Mtetra
.666 .743 .908 r
.67587 .15454 .68423 .16628 .7018 .15984 .69352 .148 Mtetra
.665 .742 .908 r
.69352 .148 .7018 .15984 .71949 .15339 .71128 .14146 Mtetra
.664 .742 .908 r
.71128 .14146 .71949 .15339 .73729 .14692 .72916 .13491 Mtetra
.72916 .13491 .73729 .14692 .75521 .14041 .74715 .12832 Mtetra
.664 .741 .908 r
.74715 .12832 .75521 .14041 .77323 .13387 .76526 .1217 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54006 .19034 .53051 Mtetra
.19034 .53051 .20137 .54006 .21728 .5349 .20631 .52529 Mtetra
.20631 .52529 .21728 .5349 .2333 .5297 .22239 .52004 Mtetra
.646 .763 .934 r
.22239 .52004 .2333 .5297 .24942 .52447 .23856 .51475 Mtetra
.23856 .51475 .24942 .52447 .26563 .51919 .25484 .50941 Mtetra
.647 .763 .934 r
.25484 .50941 .26563 .51919 .28195 .51386 .27122 .50403 Mtetra
.27122 .50403 .28195 .51386 .29838 .50845 .2877 .49859 Mtetra
.649 .764 .933 r
.2877 .49859 .29838 .50845 .31491 .50294 .30429 .49306 Mtetra
.652 .766 .933 r
.30429 .49306 .31491 .50294 .33155 .49725 .32099 .48739 Mtetra
.657 .769 .932 r
.32099 .48739 .33155 .49725 .34831 .49126 .33781 .48148 Mtetra
.666 .775 .931 r
.33781 .48148 .34831 .49126 .36519 .48472 .35475 .47517 Mtetra
.683 .786 .928 r
.35475 .47517 .36519 .48472 .38221 .47719 .37182 .46812 Mtetra
.713 .805 .922 r
.37182 .46812 .38221 .47719 .39938 .46787 .38903 .45974 Mtetra
.761 .834 .908 r
.38903 .45974 .39938 .46787 .41672 .45544 .40642 .44897 Mtetra
.828 .872 .877 r
.40642 .44897 .41672 .45544 .43425 .43787 .42398 .43414 Mtetra
.901 .907 .819 r
.42398 .43414 .43425 .43787 .45192 .41281 .44172 .41297 Mtetra
.954 .923 .736 r
.44172 .41297 .45192 .41281 .46966 .37898 .45958 .38336 Mtetra
.976 .921 .655 r
.45958 .38336 .46966 .37898 .48728 .33843 .47742 .34545 Mtetra
.977 .917 .608 r
.47742 .34545 .48728 .33843 .50464 .29715 .49506 .30345 Mtetra
.972 .925 .617 r
.49506 .30345 .50464 .29715 .52171 .26154 .51241 .26419 Mtetra
.963 .941 .687 r
.51241 .26419 .52171 .26154 .5386 .23449 .5295 .23262 Mtetra
.928 .939 .787 r
.5295 .23262 .5386 .23449 .55544 .21518 .54647 .20955 Mtetra
.86 .9 .861 r
.54647 .20955 .55544 .21518 .57233 .20135 .56345 .19317 Mtetra
.788 .846 .895 r
.56345 .19317 .57233 .20135 .5893 .19089 .5805 .18114 Mtetra
.735 .803 .906 r
.5805 .18114 .5893 .19089 .60639 .18234 .59765 .17168 Mtetra
.703 .776 .908 r
.59765 .17168 .60639 .18234 .62359 .17482 .61492 .16363 Mtetra
.685 .76 .909 r
.61492 .16363 .62359 .17482 .6409 .16784 .6323 .15633 Mtetra
.675 .751 .908 r
.6323 .15633 .6409 .16784 .65833 .16113 .6498 .14942 Mtetra
.669 .747 .908 r
.6498 .14942 .65833 .16113 .67587 .15454 .66741 .14268 Mtetra
.667 .744 .908 r
.66741 .14268 .67587 .15454 .69352 .148 .68514 .13603 Mtetra
.665 .743 .908 r
.68514 .13603 .69352 .148 .71128 .14146 .70298 .1294 Mtetra
.664 .742 .908 r
.70298 .1294 .71128 .14146 .72916 .13491 .72093 .12276 Mtetra
.72093 .12276 .72916 .13491 .74715 .12832 .739 .11609 Mtetra
.739 .11609 .74715 .12832 .76526 .1217 .75719 .10939 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53051 .17919 .52086 Mtetra
.17919 .52086 .19034 .53051 .20631 .52529 .19522 .51558 Mtetra
.19522 .51558 .20631 .52529 .22239 .52004 .21135 .51026 Mtetra
.646 .763 .934 r
.21135 .51026 .22239 .52004 .23856 .51475 .22758 .50491 Mtetra
.22758 .50491 .23856 .51475 .25484 .50941 .24392 .49952 Mtetra
.24392 .49952 .25484 .50941 .27122 .50403 .26036 .49409 Mtetra
.647 .763 .934 r
.26036 .49409 .27122 .50403 .2877 .49859 .2769 .4886 Mtetra
.648 .764 .933 r
.2769 .4886 .2877 .49859 .30429 .49306 .29356 .48303 Mtetra
.65 .765 .933 r
.29356 .48303 .30429 .49306 .32099 .48739 .31032 .47736 Mtetra
.654 .767 .933 r
.31032 .47736 .32099 .48739 .33781 .48148 .32719 .4715 Mtetra
.661 .772 .932 r
.32719 .4715 .33781 .48148 .35475 .47517 .34419 .46534 Mtetra
.674 .78 .93 r
.34419 .46534 .35475 .47517 .37182 .46812 .36131 .45863 Mtetra
.696 .794 .926 r
.36131 .45863 .37182 .46812 .38903 .45974 .37858 .45092 Mtetra
.735 .818 .916 r
.37858 .45092 .38903 .45974 .40642 .44897 .396 .44141 Mtetra
.793 .852 .895 r
.396 .44141 .40642 .44897 .42398 .43414 .41361 .42876 Mtetra
.865 .891 .852 r
.41361 .42876 .42398 .43414 .44172 .41297 .4314 .41094 Mtetra
.931 .918 .779 r
.4314 .41094 .44172 .41297 .45958 .38336 .44935 .38558 Mtetra
.969 .924 .693 r
.44935 .38558 .45958 .38336 .47742 .34545 .46736 .35139 Mtetra
.978 .918 .625 r
.46736 .35139 .47742 .34545 .49506 .30345 .48526 .31046 Mtetra
.974 .919 .604 r
.48526 .31046 .49506 .30345 .51241 .26419 .50289 .26879 Mtetra
.969 .933 .646 r
.50289 .26879 .51241 .26419 .5295 .23262 .52023 .23285 Mtetra
.95 .944 .737 r
.52023 .23285 .5295 .23262 .54647 .20955 .53738 .20551 Mtetra
.897 .923 .829 r
.53738 .20551 .54647 .20955 .56345 .19317 .55446 .18596 Mtetra
.823 .873 .882 r
.55446 .18596 .56345 .19317 .5805 .18114 .57159 .17191 Mtetra
.759 .823 .902 r
.57159 .17191 .5805 .18114 .59765 .17168 .58882 .16125 Mtetra
.717 .788 .908 r
.58882 .16125 .59765 .17168 .61492 .16363 .60615 .1525 Mtetra
.692 .767 .909 r
.60615 .1525 .61492 .16363 .6323 .15633 .6236 .14479 Mtetra
.679 .755 .909 r
.6236 .14479 .6323 .15633 .6498 .14942 .64117 .13762 Mtetra
.672 .749 .908 r
.64117 .13762 .6498 .14942 .66741 .14268 .65885 .13072 Mtetra
.668 .745 .908 r
.65885 .13072 .66741 .14268 .68514 .13603 .67666 .12394 Mtetra
.666 .743 .908 r
.67666 .12394 .68514 .13603 .70298 .1294 .69457 .1172 Mtetra
.665 .742 .908 r
.69457 .1172 .70298 .1294 .72093 .12276 .71261 .11047 Mtetra
.664 .742 .908 r
.71261 .11047 .72093 .12276 .739 .11609 .73076 .10372 Mtetra
.73076 .10372 .739 .11609 .75719 .10939 .74902 .09693 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51026 .20018 .50037 Mtetra
.20018 .50037 .21135 .51026 .22758 .50491 .21648 .49496 Mtetra
.646 .763 .934 r
.21648 .49496 .22758 .50491 .24392 .49952 .23287 .48951 Mtetra
.23287 .48951 .24392 .49952 .26036 .49409 .24937 .48402 Mtetra
.647 .763 .934 r
.24937 .48402 .26036 .49409 .2769 .4886 .26598 .47848 Mtetra
.26598 .47848 .2769 .4886 .29356 .48303 .28269 .47287 Mtetra
.649 .764 .933 r
.28269 .47287 .29356 .48303 .31032 .47736 .29952 .46717 Mtetra
.652 .766 .933 r
.29952 .46717 .31032 .47736 .32719 .4715 .31645 .46134 Mtetra
.657 .769 .932 r
.31645 .46134 .32719 .4715 .34419 .46534 .33351 .45527 Mtetra
.666 .775 .931 r
.33351 .45527 .34419 .46534 .36131 .45863 .35069 .44878 Mtetra
.683 .786 .928 r
.35069 .44878 .36131 .45863 .37858 .45092 .36801 .44155 Mtetra
.713 .805 .922 r
.36801 .44155 .37858 .45092 .396 .44141 .38548 .43298 Mtetra
.761 .834 .908 r
.38548 .43298 .396 .44141 .41361 .42876 .40312 .422 Mtetra
.828 .872 .877 r
.40312 .422 .41361 .42876 .4314 .41094 .42095 .40693 Mtetra
.901 .907 .819 r
.42095 .40693 .4314 .41094 .44935 .38558 .43897 .38548 Mtetra
.954 .923 .736 r
.43897 .38548 .44935 .38558 .46736 .35139 .45711 .35554 Mtetra
.976 .921 .655 r
.45711 .35554 .46736 .35139 .48526 .31046 .47524 .31725 Mtetra
.977 .917 .608 r
.47524 .31725 .48526 .31046 .50289 .26879 .49316 .27486 Mtetra
.972 .925 .617 r
.49316 .27486 .50289 .26879 .52023 .23285 .51077 .23524 Mtetra
.963 .941 .688 r
.51077 .23524 .52023 .23285 .53738 .20551 .52813 .20335 Mtetra
.928 .939 .787 r
.52813 .20335 .53738 .20551 .55446 .18596 .54536 .18002 Mtetra
.86 .9 .861 r
.54536 .18002 .55446 .18596 .57159 .17191 .56258 .1634 Mtetra
.788 .846 .895 r
.56258 .1634 .57159 .17191 .58882 .16125 .57988 .15117 Mtetra
.735 .803 .906 r
.57988 .15117 .58882 .16125 .60615 .1525 .59728 .1415 Mtetra
.703 .776 .908 r
.59728 .1415 .60615 .1525 .6236 .14479 .6148 .13325 Mtetra
.685 .76 .909 r
.6148 .13325 .6236 .14479 .64117 .13762 .63244 .12576 Mtetra
.675 .751 .908 r
.63244 .12576 .64117 .13762 .65885 .13072 .6502 .11865 Mtetra
.669 .747 .908 r
.6502 .11865 .65885 .13072 .67666 .12394 .66808 .11172 Mtetra
.667 .744 .908 r
.66808 .11172 .67666 .12394 .69457 .1172 .68607 .10487 Mtetra
.665 .743 .908 r
.68607 .10487 .69457 .1172 .71261 .11047 .70418 .09804 Mtetra
.664 .742 .908 r
.70418 .09804 .71261 .11047 .73076 .10372 .72241 .0912 Mtetra
.72241 .0912 .73076 .10372 .74902 .09693 .74076 .08433 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50037 .18889 .49036 Mtetra
.18889 .49036 .20018 .50037 .21648 .49496 .20524 .48489 Mtetra
.646 .763 .934 r
.20524 .48489 .21648 .49496 .23287 .48951 .2217 .47938 Mtetra
.2217 .47938 .23287 .48951 .24937 .48402 .23826 .47383 Mtetra
.23826 .47383 .24937 .48402 .26598 .47848 .25493 .46823 Mtetra
.647 .763 .934 r
.25493 .46823 .26598 .47848 .28269 .47287 .2717 .46258 Mtetra
.648 .764 .933 r
.2717 .46258 .28269 .47287 .29952 .46717 .28859 .45684 Mtetra
.65 .765 .933 r
.28859 .45684 .29952 .46717 .31645 .46134 .30559 .451 Mtetra
.654 .767 .933 r
.30559 .451 .31645 .46134 .33351 .45527 .32271 .44498 Mtetra
.661 .772 .932 r
.32271 .44498 .33351 .45527 .35069 .44878 .33995 .43864 Mtetra
.674 .78 .93 r
.33995 .43864 .35069 .44878 .36801 .44155 .35732 .43174 Mtetra
.696 .794 .926 r
.35732 .43174 .36801 .44155 .38548 .43298 .37484 .42384 Mtetra
.735 .818 .916 r
.37484 .42384 .38548 .43298 .40312 .422 .39252 .41413 Mtetra
.793 .853 .895 r
.39252 .41413 .40312 .422 .42095 .40693 .41039 .40126 Mtetra
.865 .891 .852 r
.41039 .40126 .42095 .40693 .43897 .38548 .42846 .38317 Mtetra
.931 .918 .779 r
.42846 .38317 .43897 .38548 .45711 .35554 .4467 .3575 Mtetra
.969 .924 .693 r
.4467 .3575 .45711 .35554 .47524 .31725 .465 .32296 Mtetra
.978 .918 .625 r
.465 .32296 .47524 .31725 .49316 .27486 .48319 .28163 Mtetra
.974 .919 .604 r
.48319 .28163 .49316 .27486 .51077 .23524 .5011 .23959 Mtetra
.969 .933 .646 r
.5011 .23959 .51077 .23524 .52813 .20335 .51871 .2033 Mtetra
.95 .944 .737 r
.51871 .2033 .52813 .20335 .54536 .18002 .53611 .17567 Mtetra
.897 .923 .829 r
.53611 .17567 .54536 .18002 .56258 .1634 .55346 .15587 Mtetra
.823 .873 .882 r
.55346 .15587 .56258 .1634 .57988 .15117 .57084 .1416 Mtetra
.759 .823 .902 r
.57084 .1416 .57988 .15117 .59728 .1415 .58832 .13072 Mtetra
.717 .788 .908 r
.58832 .13072 .59728 .1415 .6148 .13325 .60591 .12177 Mtetra
.692 .767 .909 r
.60591 .12177 .6148 .13325 .63244 .12576 .62362 .11386 Mtetra
.679 .755 .909 r
.62362 .11386 .63244 .12576 .6502 .11865 .64145 .10649 Mtetra
.672 .749 .908 r
.64145 .10649 .6502 .11865 .66808 .11172 .6594 .09939 Mtetra
.668 .745 .908 r
.6594 .09939 .66808 .11172 .68607 .10487 .67747 .09241 Mtetra
.666 .743 .908 r
.67747 .09241 .68607 .10487 .70418 .09804 .69566 .08547 Mtetra
.665 .742 .908 r
.69566 .08547 .70418 .09804 .72241 .0912 .71397 .07854 Mtetra
.664 .742 .908 r
.71397 .07854 .72241 .0912 .74076 .08433 .7324 .07158 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49036 .17746 .48024 Mtetra
.17746 .48024 .18889 .49036 .20524 .48489 .19387 .4747 Mtetra
.19387 .4747 .20524 .48489 .2217 .47938 .21039 .46913 Mtetra
.646 .763 .934 r
.21039 .46913 .2217 .47938 .23826 .47383 .22701 .46352 Mtetra
.22701 .46352 .23826 .47383 .25493 .46823 .24374 .45786 Mtetra
.647 .763 .934 r
.24374 .45786 .25493 .46823 .2717 .46258 .26058 .45215 Mtetra
.26058 .45215 .2717 .46258 .28859 .45684 .27753 .44637 Mtetra
.649 .764 .933 r
.27753 .44637 .28859 .45684 .30559 .451 .29459 .4405 Mtetra
.652 .766 .933 r
.29459 .4405 .30559 .451 .32271 .44498 .31178 .43449 Mtetra
.657 .769 .932 r
.31178 .43449 .32271 .44498 .33995 .43864 .32908 .42824 Mtetra
.666 .775 .931 r
.32908 .42824 .33995 .43864 .35732 .43174 .34651 .42158 Mtetra
.683 .786 .928 r
.34651 .42158 .35732 .43174 .37484 .42384 .36408 .41416 Mtetra
.713 .805 .922 r
.36408 .41416 .37484 .42384 .39252 .41413 .38181 .40538 Mtetra
.761 .834 .908 r
.38181 .40538 .39252 .41413 .41039 .40126 .39972 .39419 Mtetra
.828 .872 .877 r
.39972 .39419 .41039 .40126 .42846 .38317 .41783 .37888 Mtetra
.901 .907 .819 r
.41783 .37888 .42846 .38317 .4467 .3575 .43613 .35714 Mtetra
.954 .924 .736 r
.43613 .35714 .4467 .3575 .465 .32296 .45456 .32686 Mtetra
.976 .921 .654 r
.45456 .32686 .465 .32296 .48319 .28163 .47298 .28819 Mtetra
.977 .917 .608 r
.47298 .28819 .48319 .28163 .5011 .23959 .4912 .24541 Mtetra
.972 .925 .617 r
.4912 .24541 .5011 .23959 .51871 .2033 .50909 .20541 Mtetra
.963 .941 .688 r
.50909 .20541 .51871 .2033 .53611 .17567 .52671 .17321 Mtetra
.928 .939 .787 r
.52671 .17321 .53611 .17567 .55346 .15587 .5442 .14961 Mtetra
.86 .899 .861 r
.5442 .14961 .55346 .15587 .57084 .1416 .56169 .13275 Mtetra
.788 .846 .895 r
.56169 .13275 .57084 .1416 .58832 .13072 .57924 .12029 Mtetra
.735 .803 .906 r
.57924 .12029 .58832 .13072 .60591 .12177 .5969 .11042 Mtetra
.703 .776 .908 r
.5969 .11042 .60591 .12177 .62362 .11386 .61469 .10196 Mtetra
.685 .76 .909 r
.61469 .10196 .62362 .11386 .64145 .10649 .63259 .09427 Mtetra
.675 .751 .908 r
.63259 .09427 .64145 .10649 .6594 .09939 .65062 .08695 Mtetra
.669 .747 .908 r
.65062 .08695 .6594 .09939 .67747 .09241 .66877 .07982 Mtetra
.667 .744 .908 r
.66877 .07982 .67747 .09241 .69566 .08547 .68704 .07277 Mtetra
.665 .743 .908 r
.68704 .07277 .69566 .08547 .71397 .07854 .70543 .06573 Mtetra
.664 .742 .908 r
.70543 .06573 .71397 .07854 .7324 .07158 .72394 .05868 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .4747 .18237 .46439 Mtetra
.18237 .46439 .19387 .4747 .21039 .46913 .19895 .45876 Mtetra
.646 .763 .934 r
.19895 .45876 .21039 .46913 .22701 .46352 .21563 .45308 Mtetra
.21563 .45308 .22701 .46352 .24374 .45786 .23242 .44736 Mtetra
.23242 .44736 .24374 .45786 .26058 .45215 .24933 .44159 Mtetra
.647 .763 .934 r
.24933 .44159 .26058 .45215 .27753 .44637 .26634 .43576 Mtetra
.648 .764 .933 r
.26634 .43576 .27753 .44637 .29459 .4405 .28347 .42985 Mtetra
.65 .765 .933 r
.28347 .42985 .29459 .4405 .31178 .43449 .30071 .42383 Mtetra
.654 .767 .933 r
.30071 .42383 .31178 .43449 .32908 .42824 .31808 .41763 Mtetra
.661 .772 .932 r
.31808 .41763 .32908 .42824 .34651 .42158 .33557 .41111 Mtetra
.674 .78 .93 r
.33557 .41111 .34651 .42158 .36408 .41416 .3532 .40402 Mtetra
.696 .794 .926 r
.3532 .40402 .36408 .41416 .38181 .40538 .37098 .39593 Mtetra
.735 .818 .916 r
.37098 .39593 .38181 .40538 .39972 .39419 .38894 .38601 Mtetra
.793 .853 .895 r
.38894 .38601 .39972 .39419 .41783 .37888 .40708 .3729 Mtetra
.865 .891 .852 r
.40708 .3729 .41783 .37888 .43613 .35714 .42543 .35455 Mtetra
.932 .918 .779 r
.42543 .35455 .43613 .35714 .45456 .32686 .44396 .32856 Mtetra
.969 .924 .692 r
.44396 .32856 .45456 .32686 .47298 .28819 .46256 .29365 Mtetra
.978 .919 .625 r
.46256 .29365 .47298 .28819 .4912 .24541 .48105 .25193 Mtetra
.974 .919 .605 r
.48105 .25193 .4912 .24541 .50909 .20541 .49925 .20949 Mtetra
.969 .933 .646 r
.49925 .20949 .50909 .20541 .52671 .17321 .51714 .17286 Mtetra
.95 .944 .737 r
.51714 .17286 .52671 .17321 .5442 .14961 .53481 .14493 Mtetra
.897 .923 .829 r
.53481 .14493 .5442 .14961 .56169 .13275 .55242 .12488 Mtetra
.823 .872 .882 r
.55242 .12488 .56169 .13275 .57924 .12029 .57006 .11037 Mtetra
.759 .823 .902 r
.57006 .11037 .57924 .12029 .5969 .11042 .5878 .09928 Mtetra
.717 .788 .908 r
.5878 .09928 .5969 .11042 .61469 .10196 .60565 .09012 Mtetra
.692 .767 .909 r
.60565 .09012 .61469 .10196 .63259 .09427 .62363 .082 Mtetra
.679 .755 .909 r
.62363 .082 .63259 .09427 .65062 .08695 .64173 .07442 Mtetra
.672 .749 .908 r
.64173 .07442 .65062 .08695 .66877 .07982 .65996 .06711 Mtetra
.668 .745 .908 r
.65996 .06711 .66877 .07982 .68704 .07277 .67831 .05992 Mtetra
.666 .743 .908 r
.67831 .05992 .68704 .07277 .70543 .06573 .69678 .05277 Mtetra
.665 .742 .908 r
.69678 .05277 .70543 .06573 .72394 .05868 .71538 .04562 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .46439 .17073 .45396 Mtetra
.17073 .45396 .18237 .46439 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45308 .20411 .44251 Mtetra
.646 .763 .934 r
.20411 .44251 .21563 .45308 .23242 .44736 .22097 .43673 Mtetra
.22097 .43673 .23242 .44736 .24933 .44159 .23794 .43089 Mtetra
.647 .763 .934 r
.23794 .43089 .24933 .44159 .26634 .43576 .25502 .42501 Mtetra
.25502 .42501 .26634 .43576 .28347 .42985 .27221 .41906 Mtetra
.649 .764 .933 r
.27221 .41906 .28347 .42985 .30071 .42383 .28952 .41301 Mtetra
.652 .766 .933 r
.28952 .41301 .30071 .42383 .31808 .41763 .30695 .40681 Mtetra
.657 .769 .932 r
.30695 .40681 .31808 .41763 .33557 .41111 .32451 .40038 Mtetra
.666 .775 .931 r
.32451 .40038 .33557 .41111 .3532 .40402 .3422 .39352 Mtetra
.683 .786 .928 r
.3422 .39352 .3532 .40402 .37098 .39593 .36003 .38591 Mtetra
.713 .805 .922 r
.36003 .38591 .37098 .39593 .38894 .38601 .37803 .37693 Mtetra
.761 .834 .908 r
.37803 .37693 .38894 .38601 .40708 .3729 .39622 .36551 Mtetra
.828 .872 .877 r
.39622 .36551 .40708 .3729 .42543 .35455 .41461 .34995 Mtetra
.901 .907 .819 r
.41461 .34995 .42543 .35455 .44396 .32856 .4332 .32791 Mtetra
.954 .924 .735 r
.4332 .32791 .44396 .32856 .46256 .29365 .45194 .29729 Mtetra
.976 .922 .654 r
.45194 .29729 .46256 .29365 .48105 .25193 .47066 .25823 Mtetra
.977 .917 .607 r
.47066 .25823 .48105 .25193 .49925 .20949 .48917 .21504 Mtetra
.972 .925 .618 r
.48917 .21504 .49925 .20949 .51714 .17286 .50736 .17468 Mtetra
.963 .941 .688 r
.50736 .17468 .51714 .17286 .53481 .14493 .52526 .14215 Mtetra
.928 .938 .787 r
.52526 .14215 .53481 .14493 .55242 .12488 .54302 .11827 Mtetra
.86 .899 .861 r
.54302 .11827 .55242 .12488 .57006 .11037 .56077 .10117 Mtetra
.788 .846 .895 r
.56077 .10117 .57006 .11037 .5878 .09928 .57859 .08848 Mtetra
.735 .803 .906 r
.57859 .08848 .5878 .09928 .60565 .09012 .59651 .07839 Mtetra
.703 .776 .908 r
.59651 .07839 .60565 .09012 .62363 .082 .61457 .06972 Mtetra
.685 .76 .909 r
.61457 .06972 .62363 .082 .64173 .07442 .63274 .06181 Mtetra
.675 .751 .908 r
.63274 .06181 .64173 .07442 .65996 .06711 .65105 .05429 Mtetra
.669 .747 .908 r
.65105 .05429 .65996 .06711 .67831 .05992 .66948 .04694 Mtetra
.667 .744 .908 r
.66948 .04694 .67831 .05992 .69678 .05277 .68803 .03967 Mtetra
.665 .743 .908 r
.68803 .03967 .69678 .05277 .71538 .04562 .70671 .03241 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45396 .15895 .44341 Mtetra
.15895 .44341 .17073 .45396 .18737 .44826 .17565 .43763 Mtetra
.17565 .43763 .18737 .44826 .20411 .44251 .19246 .43182 Mtetra
.646 .763 .934 r
.19246 .43182 .20411 .44251 .22097 .43673 .20938 .42597 Mtetra
.20938 .42597 .22097 .43673 .23794 .43089 .22641 .42007 Mtetra
.22641 .42007 .23794 .43089 .25502 .42501 .24356 .41412 Mtetra
.647 .763 .934 r
.24356 .41412 .25502 .42501 .27221 .41906 .26081 .40811 Mtetra
.648 .764 .933 r
.26081 .40811 .27221 .41906 .28952 .41301 .27819 .40202 Mtetra
.65 .765 .933 r
.27819 .40202 .28952 .41301 .30695 .40681 .29569 .39582 Mtetra
.654 .767 .933 r
.29569 .39582 .30695 .40681 .32451 .40038 .31331 .38942 Mtetra
.661 .772 .932 r
.31331 .38942 .32451 .40038 .3422 .39352 .33106 .38271 Mtetra
.674 .78 .93 r
.33106 .38271 .3422 .39352 .36003 .38591 .34896 .37543 Mtetra
.696 .794 .926 r
.34896 .37543 .36003 .38591 .37803 .37693 .36701 .36713 Mtetra
.735 .818 .916 r
.36701 .36713 .37803 .37693 .39622 .36551 .38524 .35699 Mtetra
.793 .853 .895 r
.38524 .35699 .39622 .36551 .41461 .34995 .40366 .34364 Mtetra
.865 .891 .852 r
.40366 .34364 .41461 .34995 .4332 .32791 .42231 .32501 Mtetra
.932 .919 .779 r
.42231 .32501 .4332 .32791 .45194 .29729 .44114 .2987 Mtetra
.969 .924 .692 r
.44114 .2987 .45194 .29729 .47066 .25823 .46005 .26341 Mtetra
.978 .919 .625 r
.46005 .26341 .47066 .25823 .48917 .21504 .47884 .22129 Mtetra
.974 .919 .605 r
.47884 .22129 .48917 .21504 .50736 .17468 .49735 .17847 Mtetra
.969 .933 .646 r
.49735 .17847 .50736 .17468 .52526 .14215 .51552 .14148 Mtetra
.95 .944 .738 r
.51552 .14148 .52526 .14215 .54302 .11827 .53347 .11326 Mtetra
.897 .922 .829 r
.53347 .11326 .54302 .11827 .56077 .10117 .55135 .09294 Mtetra
.823 .872 .882 r
.55135 .09294 .56077 .10117 .57859 .08848 .56926 .07819 Mtetra
.759 .823 .902 r
.56926 .07819 .57859 .08848 .59651 .07839 .58727 .06687 Mtetra
.717 .788 .908 r
.58727 .06687 .59651 .07839 .61457 .06972 .60539 .05749 Mtetra
.692 .767 .909 r
.60539 .05749 .61457 .06972 .63274 .06181 .62365 .04915 Mtetra
.679 .755 .909 r
.62365 .04915 .63274 .06181 .65105 .05429 .64203 .04136 Mtetra
.672 .749 .908 r
.64203 .04136 .65105 .05429 .66948 .04694 .66054 .03383 Mtetra
.668 .745 .908 r
.66054 .03383 .66948 .04694 .68803 .03967 .67918 .02642 Mtetra
.666 .743 .908 r
.67918 .02642 .68803 .03967 .70671 .03241 .69794 .01905 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43763 .16379 .42688 Mtetra
.16379 .42688 .17565 .43763 .19246 .43182 .18066 .421 Mtetra
.18066 .421 .19246 .43182 .20938 .42597 .19765 .41507 Mtetra
.646 .763 .934 r
.19765 .41507 .20938 .42597 .22641 .42007 .21474 .40911 Mtetra
.21474 .40911 .22641 .42007 .24356 .41412 .23195 .40309 Mtetra
.647 .763 .934 r
.23195 .40309 .24356 .41412 .26081 .40811 .24928 .39702 Mtetra
.24928 .39702 .26081 .40811 .27819 .40202 .26672 .39088 Mtetra
.649 .764 .933 r
.26672 .39088 .27819 .40202 .29569 .39582 .28429 .38465 Mtetra
.652 .766 .933 r
.28429 .38465 .29569 .39582 .31331 .38942 .30198 .37826 Mtetra
.657 .769 .932 r
.30198 .37826 .31331 .38942 .33106 .38271 .31979 .37163 Mtetra
.666 .775 .931 r
.31979 .37163 .33106 .38271 .34896 .37543 .33775 .36458 Mtetra
.683 .786 .928 r
.33775 .36458 .34896 .37543 .36701 .36713 .35586 .35676 Mtetra
.713 .805 .922 r
.35586 .35676 .36701 .36713 .38524 .35699 .37413 .34756 Mtetra
.761 .834 .908 r
.37413 .34756 .38524 .35699 .40366 .34364 .3926 .33591 Mtetra
.828 .873 .877 r
.3926 .33591 .40366 .34364 .42231 .32501 .41128 .32009 Mtetra
.901 .908 .819 r
.41128 .32009 .42231 .32501 .44114 .2987 .43018 .29775 Mtetra
.955 .924 .735 r
.43018 .29775 .44114 .2987 .46005 .26341 .44923 .26677 Mtetra
.976 .922 .654 r
.44923 .26677 .46005 .26341 .47884 .22129 .46827 .22732 Mtetra
.977 .917 .607 r
.46827 .22732 .47884 .22129 .49735 .17847 .48709 .18373 Mtetra
.972 .925 .618 r
.48709 .18373 .49735 .17847 .51552 .14148 .50557 .14299 Mtetra
.963 .941 .688 r
.50557 .14299 .51552 .14148 .53347 .11326 .52376 .11013 Mtetra
.928 .938 .787 r
.52376 .11013 .53347 .11326 .55135 .09294 .54179 .08597 Mtetra
.86 .899 .861 r
.54179 .08597 .55135 .09294 .56926 .07819 .55981 .06862 Mtetra
.788 .846 .895 r
.55981 .06862 .56926 .07819 .58727 .06687 .57791 .05569 Mtetra
.735 .803 .906 r
.57791 .05569 .58727 .06687 .60539 .05749 .59611 .04537 Mtetra
.703 .776 .908 r
.59611 .04537 .60539 .05749 .62365 .04915 .61444 .03648 Mtetra
.685 .76 .909 r
.61444 .03648 .62365 .04915 .64203 .04136 .6329 .02835 Mtetra
.675 .751 .908 r
.6329 .02835 .64203 .04136 .66054 .03383 .65149 .0206 Mtetra
.669 .747 .908 r
.65149 .0206 .66054 .03383 .67918 .02642 .67021 .01303 Mtetra
.667 .744 .908 r
.67021 .01303 .67918 .02642 .69794 .01905 .68906 .00553 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooeKlD]`0
07oo0000Egoo003EOol30003Ool5D_`01000D_aoo`00EWoo003BOol30004Ool02e;LE_aBo5KlD]aF
o5;L001Bg5Kl0000EWoo003@Ool20003Ool01EKlD_aBo5;lE_`01U;l00D005;lD_aBo00005Eoo`00
cGoo0`000goo01=Bo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg000D]aFo5;LOol0001DOol00<]oo`80
00=oo`08D_aFo5;lE_aBo5KlD_aFo0=Bo003E_aBo5;l009Bo003001Bo5;l009Bo003001oogoo059o
o`00b7oo0`0001aoo`00OomG75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo000E_aB
g5KlOol005=oo`00Igoo0P000Woo0P00FGoo0P000goo00=Fo000E_`015Kl00QBo5KlD_aFo5;lE_aB
o5Kl0e;l00EFo5;lD_aBo00000ABo003Ool007oo055oo`00J7oo00@007ooOol005Moo`<000=oo`08
E_aK75KlEaaFo5LLD_aG709Fo00ED_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]ao
o`00059oo`00JGoo0P00EWoo0P0017oo00EK75LLEaaG75/L00QFo004D_aFo5;lE_`3D_`00eKlD_aB
o003D_`00`00D_aBo003D_`00goo001oo`1@Ool006Uoo`8005=oo`<000Aoo`0RE_aK75KlFaaFo5/L
E_aK75;lEaaFo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_`005KlD]aFo5;LE_`2Ool0
0`00Oomoo`1>Ool006Qoo`04001oogoo001@Ool20006Ool00e/lGcaG7002Ea`01U/LEaaG75LLE_aB
o0=Fo008D_aFo5;lE_aBo5KlD_aFo0MBo003001Bo5;l009Bo004D]aBo7oo001@Ool006Moo`80009o
o`8004aoo`<000Ioo`0;GcaK6ellFaaO?5KlFaaFo5/LE_aK7002E_`075;lEaaBo5KlD_aG75;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LE_aoo`00Cgoo002fOol30002Ool00`00Oomo
o`02Ool03U/LGcaK?5llFaaO?5/lGcaFo5LLE_aG75KlEa`2E_`015;lE_aFo5Kl0e;l00EFo5;lD_aB
o5Kl00EBo004001Bo5;lD]`3D_`00e;L0000001?Ool00;Aoo`8000Uoo`08He]SG5/KGcaK75llFa]O
?09K700SE_aK75KlEaaFo5/LD_aFo5;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5Kl001Fo5;L
E_aBg5KlD]aFo5;LOol0001>Ool00;5oo`<000Yoo`07He]SG6=LHeaK75llFc`01E/L00aFo5LLE_aG
75KlEaaBo5KlD_aFo5;lE_`3D_`01EKlD_aBo5;lE_`00e;l00<005;lD_`00U;l00MBg5;lD_aBo5;L
Ool0001=Ool00:moo`8000]oo`09IeaSFf=LHe]WG6=KHeaG75/l009K700VEaaK?5/LEaaFo5/LE_aG
75;lEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aBo5;LE_aBg5;lOol0
015oo`D003Moo`00[7oo0`0037oo00=SG6=KHe`00V=L00ASFf=LGcaO?0MK70MFo006D_aFo5;lE_aB
o5Kl0e;l00=Fo5;lD_`00e;l00<005;lD_`015;l00IBg5;lD_aBo7oo000@Ool01@00Oomoogoo0000
=goo002ZOol2000>Ool03FnKJgYSG6=KIeaSFf=LGc]SG5lkHeaG75/l009K700VE_aK75KlEaaBo5LL
E_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aBo5;LE_aBg5;l
Ool0011oo`03001oogoo03Qoo`00Ygoo0`000Woo00<007ooOol02Woo00E_Vf^JKi][VVnK00QO?0=G
7003FaaG75LL00IFo008D_aFo5;lE_aBo5KlD_aFo0MBo003001Bo5;l00IBo005D]aBo5;lD_`00007
Ool60004Ool00`00Oomoo`0gOol00:Eoo`80015oo`0hKi][NVnKJgY_VfMkJg]O>f=LGc]SG5lkGcaK
75llE_aK75KlFaaFo5/LD_aFo5;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo000E_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LOol0015oo`03001oogoo03Ioo`00XWoo0`004Woo00E_Vf^JKi][
VVnK00=WN`=O?006FcaO?5/LGcaK?5/L0eLL00=K75KlEa`00UKl00QBo5KlE_aFo5;lE_aBo5Kl2E;l
00@005;lD_aBg0=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0@Ool00`00Oomoo`0eOol007Eoo`@0
02Moo`8001Aoo`0AKi][NVnKJgY_VfMkJg]WFf]lIg]O?5/KGcaK75llFa]O?002Fa`0:5KlFaaFo5LL
E_aK75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;lE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg0003Goo00D007ooOomoo`0003Moo`00M7oo00<007ooOol00Woo00<007ooOol08Goo
0`005Goo00Eg^7>hKi][VVnK00EWN`9SG00=GcaK75llFcaO?5/LGcaFo5LLE_aG75KlEa`015Kl00AB
o5KlD_aFo0=Bo003E_aBo5;l00EBo003001Bo5;l009Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`00
3Goo0`00>7oo001dOol00`00Oomoo`02Ool00`00Oomoo`0NOol3000GOol04GNiLkQg^7>hMkUWNf]k
Ie][O6MkHeaSFfMLHe]O?5/KGc`00U/L00QG75/lE_aG75KlFaaFo5LL0UKl029Bo5KlD_aFo5;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol004Moo`00
M7oo00<007ooOol00Woo00<007ooOol077oo0P000Woo00<007ooOol05Goo00Ic^7NhMkQg^6nILkX2
Ig/01F=KHeaSG6=LHe/00V=L1e/L00AFo5LLE_aG70AFo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`0
15;l00<005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`0004Moo`00M7oo00<007ooOol00Woo
00<007ooOol06Goo0`006goo01Ac^7NhLkQg^FnILkY_VG>jHe]SG6=KIeaSFf=LHe]SG5lkFaaG75/l
0U/L02]G75/lE_aG75;lEaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol00016Ool007Aoo`03001oogoo009oo`03001oogoo
01Moo`8001eoo`0:LkQg^7NhMkQ_VG>jLiUc^V^JKi/2He`00f=KHeaO?004Gc`5Fa`2Ea`6E_`025;l
E_aBo5KlD_aFo5;lE_`3D_`00eKlD_aBo002D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o09oo`03001oogoo04=oo`00M7oo00<007ooOol00Woo00<007ooOol057oo0`007Woo01Ac^7NhLkQg
^FnILkY_VG>jJgY_Vf]jKi][NV=LGc]SG5lkHeaO>f=L0U/L02iG75/LE_aK75KlEaaFo5LLD_aG75;l
E_aBg5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lOol004Eoo`00MGoo10005Goo0P008Goo0g^e00U_VG>jLiUc^V^JKi][VVnKJiX00VMk1ell
00=G75/LEa`00ULL00=K75LLE_`00UKl00YBo5KlE_aFo5;lE_aBo5KlD_aFo0QBo003001Bo5;l00=B
o005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol004Aoo`00Rgoo0`008Woo04Mk]GNeNkEg]W^gKiUc
^V]jKi][NVnKJgY[NfMKJgaWNf=LGc]SG5lkGcaK6ellE_aK75KlFaaFo5LLE_aG75;lE_aBo5LLD_aF
o5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aoo`0004=oo`00RGoo0P000Woo00<007ooOol087oo0g^e00Qg]gNfNkM[VVnKJiY_Vf^J1VMk
00IO?5/LGcaK?5llFa`2Ea`01E/LE_aG75KlEa`015Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005
001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0004=oo`00QWoo0`009Woo04Ug
]G^eMkEk]gNfNmMc^7NhJgY_Vf]jJg]WFf]lIg][NfMKIeaSFellFa]O?5/LGcaK6e/LE_aG75KlFaaF
o5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LOol00012Ool008Aoo`8002Uoo`=k]@03MkIk]gNf00=g^003LkQW
NfMk00AWN`07HeaSFf=LFcaO?5/LGc`00e/L00mG75KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo5;lE_`0
0e;l00=Fo5;lD_`015;l00<005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`0
0goo001oo`10Ool0085oo`<002Yoo`0ENkEg]G^eMkIkegNfMkQc^7NiLkQc^VnIJgaWNf]kHe]WG6=K
HeaSFfML009K700dEaaK?5/LFaaG75/LE_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0011Ool0
07ioo`<002eoo`9k]@03MkIk]gNf00=g^006LkQc^W>ILkY_VG>j0V=L00ASFf=LHeaSG09O?0MK70MF
o008D_aFo5;lE_aBo5KlD_aFo0=Bo003E_aBo5;l009Bo005001Bo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00QBg5;lD_aBo5;LD_aoo`00@7oo001lOol2000_Ool067NeNkEg]G_GMkIg^7>hMkUc^7>j
KiUc^VnILkY[NVnKHe]SG6=KHeaO>f=LGc]SG09K700:EaaK?5KlFaaFo5LLE_aG75;lEa`2E_`0:5;L
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aoo`00?goo001iOol30002Ool2000]Ool2NkD00g^gMkIg]`02MkP02W>hLkYc
VG>jKiUc^V^JKi][VVnK25ll00=G75/LEa`00ULL00=K75KlE_`00UKl00QBo5KlE_aFo5;lE_aBo5Kl
0e;l00=Fo5;lD_`015;l00<005;lD_`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
0e;LOol0000oOol007Moo`8003=oo`1@Nk=kTW^dNi=k]7>hMkUc^7>jKiUc^VnILkY[NVnKJgY_VfMK
JgaO>f=LGc]SG5lkHeaK6ellE_aK75KlFaaFo5/LD_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
Ool003ioo`00M7oo0`00=7oo00Ek/g^CNk=k/g^d00=k]@09MkMg]W>jKiUc^V^JKi][VVnK00AWN`AO
?003FcaO?5/L009G7006FaaG75LLE_aG75;l0eKl00QBo5KlD_aFo5;lE_aBo5Kl25;l00D005;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l0Woo00<007ooOol0>goo001bOol2
000gOol0DW^BNk=kTg^dNi=k]GNeNkEg]W_GMkIk]f]jKi][NV]kIe][O6MkJg]WFf]lFaaO?5/KGcaK
75llFa]K75KlEaaFo5/LE_aG75;lEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L001B
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`00?Goo001_Ool3
000hOol00g^CNk=kT`02Nk@3NkD017NfNkMg]WNg0WNh00=c^6MkIg/01FMk00MSFf=LFcaO?5/LGcaK
?002Fa`01ELLE_aG75KlEa`00UKl00QBo5KlE_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01E;l00<005;L
D_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo002Ool00`00Oomoo`0j
Ool006eoo`800003Ool007oo03Qoo`0MNk=kTW^dNi=k]7NeNkEg]G_GMkIk]g>hMkUc^7>jKiU[O6Mk
Jg]WFf]lHe]SG6=KGcaK75llEaaK?002Fa`01ULLFaaFo5LLE_aK709Fo00[D_aFo5;lE_aBo5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]`00Woo00<007ooOol0>Goo001ZOol3000lOol00g^cNi=k/`02Nk@3NkD02W^gMkIg
]gNfMkQc^7>jLiUc^VnI0VMk00=SG6=KHe`00V=L00=SFe/LFa`01E/L00AFo5LLE_aG70AFo004D_aF
o5;lE_`3D_`01EKlD_aBo5;lE_`01E;l00@005;lD_aBg0=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aoo`0003]oo`00Igoo0`00?goo01akTW^cNi=k]7^CNkEg]G_GMkIk]gNf
MkUc^7NhKiUc^VnILkY_VFMLHe]SG6=KIeaSFf=LGc]K?09K700iEaaK?5/LFaaBo5LLE_aG75;lEaaB
o5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0003Yoo`00IGoo0P00@Goo00EkTg^cNi=k]7^c
00=k]@0=MkIg]gNfMkQc^7NhLiUc^VnILkYcVFnKJiX00f=L1Ell15/L0ULL00=K75KlE_`015Kl00IB
o5KlD_aFo5;lE_`3D_`00eKlD_aBo005D_`00`00D_aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00Oomoo`0hOol0069oo`<004=oo`0WNk=kTW^dNi=k
]7NeNkEg]W^gMkIg^G>hMkQ_VG>jKiUc^VnIKi][NVnKJgY_VelkHeaO>f=LGc]SG5lkFaaFo5/LE_aK
75KlEaaBo5LL009Fo00`D_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000>Goo001POol2
0015Ool027^cNi=k/g^cNkAkTg^cNi<3Nk@2NkD02W>ILkY_VG>jJiY_Vf^JKi][VVnK0VMk1Ull00AK
75LLEaaK70=G7003E_aBo5Kl009Fo008D_aFo5;lE_aBo5KlD_aFo0UBo004001Bo5;lD]`3D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol003Qoo`00GGoo0`0000=o
o`00Ool0A7oo02IkTW^cNi9k/g^BNk=kTW^dNi=k]7NeNkEg]W_GMkIk]f]jKi][NVnKJgY_VfMkJg]W
Ff=LGc]SG5/KGcaK75llE_aK75KlFaaFo5/L0UKl03=Bo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5Kl0000>7oo001KOol20019Ool00g^BNi=kTP02Ni800g^cNi=k/`02Nk@01W^cNkEk
]G^gMkIg]`9g^003JiY_Vf^J00IWN`0=GcaK?5llFaaO?5/lGcaFo5LLE_aG75KlEa`00UKl00QBo5Kl
E_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01E;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000=goo000^Ool4000VOol3001;Ool08Gnc
Ni9k/g^BOk=kTW^cNi=k]7^CNkEg]G_GMkIk]gNfMkUc^7NhLkQ[O6MkJg]WFf]lIg]SG6=KGcaK75ll
Fa]K?002Fa`01UKlFaaFo5LLE_aK709Fo00cD_aFo5;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aoo`00029oo`<0015oo`00;Goo00<007ooOol00Woo00<007ooOol08Goo0P00CGoo00]kTg^B
Ni9kTW^bNi=k/g^CNkAk/g^d009k]@05MkIg]gNfMkQc^002MkP00g>jKiUWN`02Ig/01V=KHeaSG6=L
He]SG0IK7004E_aG75KlEa`4E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01e;l00@005;lD_aBg0=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo02=oo`03
001oogoo00moo`00<Woo00<007ooOol07Goo1000Cgoo021kTWncNi9o/g^BNk=kTW^dNi=k]7NeNkEg
]W^gMkIg^G>hMkQc^7>jKiUc^VnIIeaSFf=LHe]WG6=KHeaO>f=L0U/L03iG75/lFaaK75;lEaaFo5LL
D_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`008goo00<007ooOol0
3goo000UOol60007Ool00`00Oomoo`0LOol3001@Ool3Ni8017^bNi9k/g^C0W^c0W^d00Ik]GNfMkMg
]WNhLkP3MkP01FnILkYcVFnKJiX00f=L00=SFellGc`00Ull15/L0ULL00=K75KlE_`015Kl00IBo5Kl
D_aFo5;lE_`3D_`00eKlD_aBo005D_`00`00D_aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol0025oo`03001oo`00011oo`00;Woo1000
77oo0`00Dgoo02]o/g^BOk=kTW^cNi9k/g^CNkAkTg^eMkEk]gNfNmMc^7NhLkQg^FnILkY_VFnKJgY_
Vf]jKi]O>f=LGc]SG5lkHeaO>e/LE_aK75KlFaaFo5LLD_aG7002E_`0=E;lEaaBo5KlD]aFo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo00008Goo00<007oo000047oo000^Ool00`00Oomoo`0J
Ool3001FOol01g^BNi=kTW^BNi=k/g^C00=k]005NkEg]gNfNkMc^003MkP026nILkYcVFnKJiY_Vf^J
Ki/2Ig/6Gc`015/LEaaG75/L0eLL00=Fo5;lE_`00UKl00IBo5KlD_aFo5;lE_`;D_`01000D_aBo5;L
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg5;lD_`0
0P007goo00D007ooOomoo`0000moo`00;Woo00<007ooOol067oo0P00F7oo02YkTWncNi9k/g^BNk=k
TW^dNi=k]7^BNk=kTg^dMkEk]GNeNkE_VG>jKiU_Vf]jKi][NVnKIg][NfMKHeaO>f=LFa]O?5/LGcaF
o5/LE_aK75KlFa`2E_`0>E;lEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_`005Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LOol0000NOol01@00Oomoogoo00003goo000^Ool5000COol3001JOol02g^CNi9kTW^BNk=k
Tg^cNi9k/W^BNk<00W^d00]k/g^eNkEk]GNfMkMg]VnKJiY_Vf^J00IWN`0=GcaK?5llFaaO?5/lGcaF
o5LLE_aG75KlEa`00UKl00QBo5KlE_aFo5;lE_aBo5Kl2e;l00<005;LD_`00U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QBg5;lD_aBo5;LD_aoo`007Goo0`00
00Aoo`00000000ioo`00A7oo0P00GGoo02AkTWncNi9o/g^BOk=kTWncNi9k/g^BNkAkTg^eMkEk]GNe
NkMg]WNiLkQg^7>hJgaWNf]kIe][O6MkHeaSFellFaaO?5/KGc`2Fa`01UKlFaaFo5LLE_aK709Fo00h
D_aFo5;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol000Uoo`@002Ao
o`00@Goo0`0000=oo`00Ool0Fgoo0g^B00Ek/W^CNi9kTW^b009kTP04Ni=k]7^cNk@3NkD017NgMkIk
]g>h0WNh00=c^VnIIg/00VMk00MSFf=LHeaSG6=KGcaK?005Fa`015KlEaaFo5LL15Kl00ABo5KlD_aF
o0=Bo003E_aBo5;l00QBo003001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol000Moo`03001oogoo009oo`03001oogoo025o
o`00?goo0P00HGoo02=o/g^BOk=kTgncNi9o/g^BNk=kTW^cNi=k]7NeNkEg]G^gMkIkeg>hMkQc^7>j
KiUc^VnIIeaSFf=LHe]WG6=KHeaSFe/l009K7013EaaK?5/LFaaBo5LLE_aG75;lEaaBo5KlD_aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol00Woo
00<007ooOol08Goo000lOol3001ROol2Ni801G^dNi=kTg^BNi<00g^B0W^c0W^d0W^e00Ag]gNfNkMc
^0=g^005KiUc^W>IKi][VP03He`00f=KHeaSG002Gc`4Fa`2Ea`00e/LE_aFo004E_`01U;lE_aBo5Kl
D_aFo0=Bo003E_aBo5;l00IBo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01e;LD_aBo5;lD]aoo`0000Ioo`03001oogoo009oo`03001o
ogoo025oo`00>Woo0P00IGoo02ikTgndNi=o/g^BOk=kTW^cNi9k/g^BNkAkTg^eMkEk]GNfNmMg]WNh
LkQg^FnILkY_VFnKJgY_Vf]jIeaSFf=LGc]SG5lkHeaO>e/LE_aK75KlFaaFo5LLD_aG709Fo00hD_aG
75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo09oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo025oo`00=goo0`00Igoo00=k]7^DNi<00W^C0g^B00=k/W^B
Nk@00W^d0W^e00=g]W^gMkH00gNh00U_VG>jLiUc^V^JKi][VVnKJiX01ell00AK75LLEaaK70=G7003
E_aBo5Kl009Fo006D_aFo5;lE_aBo5Kl35;l00<005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo00Aoo`03001o
ogoo009oo`03001oogoo025oo`00=Goo0P0000=oo`00Ool0IWoo02eo]7^DOk=kTWncNi9o/g^BOk=k
TW^cNi=k]7^BNk=kTW^dNi=k]GNdNkE_VG>jKiUc^V]jKi][NVnKJgY[NfMKHeaO>f=LFa]O?5/LGcaK
6e/LE_aK75KlFa`00UKl03]Bo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]`0
05;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo025oo`00<Woo
0`00Jgoo00AkU7^dNi=k/`=kTP0;Nk9kTW^cNi9k/W^BNk=kTg^dNk=k]002NkD027NfMkMg]W^gJiY_
Vf^JKi/5Ig/03EllFcaO?5/LGcaK?5llFaaG75KlEaaFo5LL009Fo004D_aFo5;lE_`3D_`00eKlD_aB
o00:D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L009Bo0<000Aoo`@002Aoo`00;goo0`00KGoo02QkU7^dNi=o/g^C
Ok=kTWncNi9k/g^BOk=kTW^cNi9k/g^CNkAg]7^eMkEk]gNfNmMc^7NhLkQ[O6MkJg]WFf]lIg]SG6=K
GcaK75llFa]O?09K7006EaaK75KlEaaFo5/L0UKl03eBo5KlD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5Kl
D]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000/Ool002eoo`80071oo`03NkAkU7^c009k
T`03Ni9kTg^B009kTP04Nk9kTW^BNi<2Nk<2Nk@2NkD017NgMkIk]g>h0WNh00=c^VnIIg/00VMk00QS
Ff=LHeaSG6=KGcaK?5ll15/L00AFo5LLE_aG70AFo004D_aFo5;lE_`3D_`00eKlD_aBo007D_`20000
0e;lD]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`0002]oo`00:Woo0`00LGoo02Mk]7^COkAkTgncNi9o/g^B
Nk=kTWncNi9k/g^BNk=kTW^dNi=k]GNeNkEg]W_GMkIg^7>hLkY_VG>jKiUc^V=KHeaSFfMLHe]SG6=K
Fc`00U/L01UG75/lFaaK75;lEaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg003
0000:U;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo09oo`03001oogoo02Qoo`00:7oo0P0000=oo`00Ool0
LGoo00=kU7^dNi<00g^C00AkTW^CNi=kT`=kTP03Nk=kTW^d009k]09k]@03MkIk]gNf00=g^006KiUc
^W>ILkY[VVnK0V=L00=SFf=LHe`00Ull15/L0ULL00=K75KlE_`015Kl00IBo5KlD_aFo5;lE_`3D_`0
0eKlD_`000020004D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000ZOol002Ioo`8007Eoo`0b
Ni=o]7^DOk=kTWncNi9k]7^BOk=kTW^cNi9k/g^BNk=kTg^dMkEk]GNfNmMg]WNhLkQg^FnILkY_VG>j
JgY_Vf]jIeaSFf=LGc]SG5lkHeaO>e/LE_aK75KlFaaFo5LLD_aG709Fo00:D_aG75;lE_aBg5KlD_aF
o5;LE_`20000<E;LE_aBg5KlD]aFo5;LE_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L009oo`03001oogoo
02Moo`009Woo0P00MGoo00Uk]7^DNi=kTg^cNiAk]7^CNk<00g^B00=k/W^BNk<00W^d00Ek/g^eNkEk
]gNf00=g^009KiUc^W>ILkY[VVnKJiY_Vf^J00MO?004FaaG75LLFa`3Ea`00eKlD_aFo002E_`01U;l
E_aBo5KlD_aFo0<000]Bo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg7ooOol002Qoo`009Woo0`00Lgoo
035o]7^DNkAkUG^fNiAk]7^COk=kTgncNi9o/g^BNk=kTW^dNi=k]GNdNkAkTg^eMkAk]FnILkY_VG>j
JgY_Vf]jKi][NV]kIe]SG5lkHeaK6ellFaaO?5/KFaaFo5/LE_aK7002E_`01U;lEaaBo5KlD_aFo0<0
000jE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000X
Ool002Ioo`04001oogoo001bOol02GNFNkMkUG^eNiEk]7^DNk=kT`02Ni8027^bNi9k/g^CNkAk/g^B
Ni<2Nk<02g^dNkEk]G^eMkMg]W^gJiY_Vf^JKi/01VMk00aK?5llFaaO?5/lGcaK75LLE_aG75KlEa`2
E_`00e;lE_`000020002D_`00eKlD_aBo00:D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo5;lD_`2
Ool00`00Oomoo`0UOol002Eoo`03001oogoo009oo`03001oogoo06ioo`0/MiIk]gNFNkIkUG^dNi=o
]7^COk=kTWncNi9k/g^BNk=kTW^cNi9k/g^CNkAg]7^eMkEk]gNfNmMc^7NhLkQ[O6MkJg]WFf]lIg][
Nf=KIeaK75llFa]O?09K7006EaaK75KlEaaFo5/L0`00045Fo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0002Moo`009Goo00<007oo
Ool00goo00<007ooOol0KGoo00Mk]gNFNkEkUG^eNiAk]002Ni<00g^BNi=kTP02Ni801W^CNi9kTW^B
Nk=kTP9k]0=k]@03MkIk]g>h009g^003LkY_VFMk00=WN`=SG003He]SG5/L00EK7003E_aG70000080
00=Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`00goo001oo`0UOol002Eoo`03001oogoo00Aoo`03001oogoo06]oo`0[NkMgUW^gNiEk]G^C
OkAkU7ncNi9o/g^BNk=kTWncNi9k/g^BNk=kTW^dNi=k]GNeNkEg]W_GMkIg^7>hMkU_VG>jKiUc^V=K
HeaSFfMLHe]SG5lkHe`00U/L00=G75/l00000P0004IG75KlEaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg09oo`03001o
ogoo02=oo`009Goo0P001Woo0P00JWoo00Qk]gNFNkMkUG^eNiEk]7^D0g^C00AkTW^CNi=kT`=kTP03
Nk9kTW^c009k]0=k]@03NkMg]WNh009g^006KiUc^W>ILkY[VVnK0V=L00=SFellGc`00Ull0U/L0P00
0ULL00=K75KlE_`015Kl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00U;l
00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000UOol002Eoo`03001oogoo00Moo`03001oogoo06Mo
o`0[MiIk]g^ENkEkUGndNiAk]7^BOk=kTW^dNi9o/g^BOk=kTWncNi9k/g^CNkAg]G^eMkAkegNfMkQc
^7NiKiUc^VnILkY[NVnKJgY_VelkHeaO>f=LGc/00`0000QFo5/LE_aK75KlEaaBo5LL0UKl04EBo5LL
D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]`005;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg7oo000097oo000UOol00`00Oomoo`08Ool00`00Oomoo`1UOol02WNFNkMgUW^eNiEk
]G^DNkAkTg^c0W^D00=kTg^cNi800W^B00Ik/W^BNk=kTg^dNk<3NkD037NfMkQg^7NhLkQc^W>ILkY[
VVnKJiY_V`9WN`04Gc`000000002Gc`015/LEaaG75/L0eLL00=Fo5;lE_`00UKl00ABo5KlD_aFo0=B
o003E_aBo5;l00YBo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`0002=o
o`009Goo00<007ooOol02Goo00<007ooOol0Hgoo02MgUW^gMiIk]G^ENkIkU7^dNi=o/g^ENkAkTgnc
Ni=o/g^BOk=kTW^cNi9k]7^CNkEg]7^eNi=k]7NdNmEg]G>jKiUc^V]jKi][NVnKIg/00`0000aO>f=L
Fa]O?5/LGcaK6e/LE_aK75KlFa`2E_`0B5;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol002=oo`0097oo0P00
37oo00<007ooOol0HWoo00Yk]gNFNkMkUG^eNiEk]7^DNkEkU@9kU005Nk=kTg^CNi9kT`02Ni8027^C
Nk=k/g^BNi=k/g^BNk@3NkD01WNgMkIk]f^JKi][VP<000AWN`0<FcaO?5/LGcaK?5llFaaG75KlEaaF
o5LL0UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo004D]aBo7oo000ROol002Aoo`03001oogoo00aoo`03001oogoo061oo`0RNkMgUW^gNiEk
]W^ENkMgUW^gNiEk]G^COkAkTgncNi9o/g^BNk=kTW^cNi9k/g^BNk=kTW^dNi=keGNeNkEg]W_GLkP3
000036MkJgaWFf]lIg][O6=KIeaK75llFa]O?09K7006EaaK75KlEaaFo5/L0UKl04EBo5KlD_aFo5;l
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]`00Woo00<007ooOol07goo000TOol00`00Oomoo`0=Ool00`00Oomoo`1NOol3LiT02gNH
MkQgV7^gMiIk]g^ENkEkU7^dNi@00g^C0g^B00Qk/g^BNi9kTW^cNi9k/g^d0g^e00Ag]P000000009g
^003KiUc^VMk009WN`=SG003He]SG5/L00IK70MFo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;L
D_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol0000QOol002Aoo`03001oogoo00io
o`03001oogoo05aoo`0OLiY_VG>IKiUg^7>HMkQgUW^gMiIk]G^EOkAkU7ncNi9o/g^BOk=kTWncNi9k
/g^BNk=kTW^cNi=k]7NeNkD00P00011g]WNhLkQg^FnILkY_VG>jHe]SG6=KIeaSFf=LGc]SG09K700:
EaaK?5KlFaaFo5LLE_aG75;lEa`2E_`0Ae;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000087oo000TOol00`00
Oomoo`0?Ool00`00Oomoo`1KOol3LiT02GNhMiQgV7NFNkMgUW^eNiEk]002Ni@00g^CNk=kTP02Ni80
2G^bNi=kTW^BNk9kTW^cNi=k]00300000g^gMkIg^002MkP01VnILkYcVG>jJiY_V`9SG003He]O?5ll
00=O?003EaaK75LL009G7003FaaFo5Kl009Fo008D_aFo5KlE_aBo5KlD_aFo0aBo005D]aBo5;lD_aB
g003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol07Goo000TOol2000A
Ool00`00Oomoo`1IOol06VnILiU_VG>JLiQg^7>GNkMgUW^gNiEk]W^DNkAkTWncNi9o/g^BOk=kTgnc
Ni9o/g^BNk<30000Jg^eMkAkegNfNkMc^7NiKiUc^VnILkY[NVnKJgY_VelkHeaO>f=LGc]SG5/KGcaF
o5/LE_aK75KlFaaBo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo00007goo000SOol00`00
Oomoo`0BOol00`00Oomoo`1GOol4LiT3MiP01G^gMiIk]g^ENkD00g^D00Ek/g^CNiAkU7^d009kT`03
Ni9k/P000080009k/`9k]@03NkMg]WNg009g^008KiUc^W>ILkY[VVnKJiY_V`9WN`AO?006FcaO?5/L
GcaG75/L0ULL00=Fo5LLD_`00eKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`0MOol001Yoo`@000Eo
o`03001oogoo01=oo`03001oogoo05Eoo`0FKiUcVFnILiYcV7NhLiMg^7NFNkMgUW^fNiEk]7^COk=k
Tg^eNi=o]7^COk<30000L7^cNi9k/g^CNkAkTW^cNi=k]7NdNmEg]W^gMkIkef]jKi][NV]lIg][O6MK
JgaWNellFa]O?5/LGcaK6ellE_aG75KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
0Woo00<007ooOol06goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0DOol00`00
Oomoo`1COol2Ig/3LiT2MiP01WNhMiIk]gNFNkEkU@9kU005NkAkUG^eNiAk]003000027^CNi9kTW^C
Nk=kTW^dNi82Nk<2Nk@2NkD017NgMkIk]g>h0WNh1VMk0V=L00AO?5/LGcaK?0=K700:E_aG75KlEaaF
o5LLD_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool077oo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0EOol00`00Oomoo`1AOol04VMkJg]WFf]kIg]g^7>GMkQcV7^gMiIk]g^ENkEgUW^gMiIk
]@<0000SOk=kTWncNi9k/g^BNk=kTW^cNi9k/g^BNkAkTg_EMkEk]gNfNmMc^7NhLkQc^VnIJgaWFf]l
He]SG6=KIeaSFe/LEaaK?002Fa`0EELLFaaFo5LLE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aoo`0001aoo`006Goo00<007ooOol00Woo00<007ooOol00Woo0P005goo0P00Cgoo00e[
NfMkIg]WNf]kIg]_VVmjKiY[NW^gMiIk]`02MiP00gNFNkMgUP0200001G^dNiAkU7^CNk<00g^B00Ik
Tg^BNi9kTW^bNi83Nk@2NkD00gNfNkMg]P02MkP01W>jKiUc^W>IHeaSF`=SG003He]O?5ll00IK70MF
o004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool06Woo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0HOol00`00Oomoo`1;Ool046]kIg][NfMKJg]WNfnKJgY_Vf]jLiU_VG>JLiQg^7>G0`00
02IkUG^fNiAk]7^BOk=kTgncNi9o/g^BOk=kTWncNi9k/g^CNkAg]G^eMkIkegNfMkQc^7NiKiUc^VnI
Ki][NV=LHe]WG5llHeaO>f=L0U/L00YG75/lE_aK75KlEaaFo5LLD_aG709Fo01<D]aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;L000KOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
01Uoo`03001oogoo04Uoo`0:Jg]WNfMkIg][NfMkKiY_NVnJJgX4LiT3000017NFNkMkUG^e0g^D00Ek
/g^CNi9kTW^c00=kTP03Nk9kTW^c009k]005Nk=k]GNfNkMg]P03MkP026nILkYcVFnKJiY_Vf^JKi/6
Gc`00eLLFaaG7002Ea`00e/LEaaFo002E_`025;lE_aFo5KlD_aFo5;lE_`<D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol001Yoo`006Goo00<0
07ooOol00Woo00D007ooOomoo`0001eoo`03001oogoo04Moo`0<HeaO?6=LIe][NfMkKi][NVnKJgY_
VfnI0`0002YcUgNhMiIk]gNFNkIkUG^dNi=o/g^COk=kTWncNi=o/g^BOk=kTW^cNi9k]7^CNkEg]7_G
MkIg^7>hMkU_VG>jKiU_Vf]jKi][NVnKIg][O5lkHe`2Gc`0G5/KGcaFo5/LE_aK75KlEaaFo5LLD_aF
o5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0007Ool5000=Ool001Yoo`@000Ao
o`8001eoo`03001oogoo04Aoo`9OG009GcaOG5mLGeaO?6nJKgY_VV]j00<00009LiUgV7NHMkQgUW^g
MiIk]G^E009kU006NkAkTg^CNi9k]7^C0W^B00YkTg^BNi9kTg^dNk=k]7^eNkAk/`=k]@08KiUc^W>I
Ki][VVnKJiY_V`AWN`0<FaaO?5/lGcaK75llFcaG75KlEaaFo5LL15Kl00ABo5KlD_aFo0=Bo003E_aB
o5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003001B
g5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`00e;LOol00007Ool01@00Oomoogoo00003Goo000ROol00`00Oomoo`0MOol00`00
Oomoo`11Ool02V=LGcaSG5llHeaO?6=LGcaWO6=K0`0003a_VG>JKiUg^7>GMkQcV7^gMiIk]g^ENkEk
TgndNi=o/g^BOkAkTgncNi9o/g^BNk=kTW^cNi=k]7^BNk=kTg^dMkAkeGNfNkMg]WNiLkQ_Vf]jJgaW
Nf]lIe][O6=KHeaK6ellFaaO?5LLFcaK75LLE_aK75KlEa`2E_`0DE;lE_aBo5KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LOol00007Ool00`00Oomoo`0>Ool0029oo`03001oogoo01ioo`03001o
ogoo03moo`04FceK?5mLGc`3Ge`01V=K00000000He]SG0AcV@0?MiQg^7NHNkMgUW^gNiEk]G^DNkAk
U7^eNiEk]G^D00=kT`=kTP04Nk=kTW^BNi82Nk<027^dNkEk]G^eMkMg]W^gLkP2MkP4Ig/00f=LHe]S
G002He`6Fa`015KlEaaFo5LL15Kl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo009D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2Ool00`00Oomo
o`05Ool00`00Oomoo`0=Ool0029oo`03001oogoo01moo`03001oogoo03aoo`08EaaK?ELLFceG76=L
GcaSG080000jHe]WO6=KIgaWFf]kIg][Ng>GMkQcV7NhMiIk]gNFNkEkUG^gMiIk]g^ENkIkU7ncNi9o
/g^BNk=kTW^cNi9k/g^BNk=kTW^dNi=keGNeNkMg]W_GLkQg^7>hLkY_VG>jKiUWG6=KHeaSFfMLGcaS
G5LLFc`2Fa`0FULLFcaFo5LLD_aG75KlEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lOol000Qoo`03001oogoo00aoo`008Woo00<007ooOol087oo00<007ooOol0>Goo00MK?E/l
FceK?5/mFcaK?@030002He`01FMLHe]SG6MkJg/00VMk00M_NVnJJgY_VWNFNkMgUP02MiP02G^gMiIk
]g^ENkEkUG^DNi=k/`03Ni8027^bNi9kTW^BNk9kTW^dNk<3NkD00gNfNkMc^002MkP01W>jKiUc^W>I
Ki][VP9SG0EO?0AK709G70IFo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l009oo`03001oogoo00Io
o`03001oogoo00]oo`008Goo0P008goo00<007ooOol0=Woo00IC75LmDaaK?ELLFcd30000VUmMFcaO
?F=KIgaSFf]kIe][NfMkJg][NVnKJgY_VfnILiY_VGNhLiMg^7NFNkMgUW^fNiEk]7^BOk=kTWncNi9o
/g^COk=kTWncNi9k/g^CNkAg]G^eMkIkeg>hMkQc^7NiKiUc^VnIKi][NVnKJgYSG5llHeaO>f=LGcaS
G5KlFaaFo5/LE_aK75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;L0Woo00D007ooOomoo`0000=oo`03001oogoo00]oo`008Goo00<007ooOol08goo00<007ooOol0
<Woo00IG75LMEaeG7ELLEad3000025/mFcaO?5/lGcaK?5llFc`2Ig/01f]kIg]WNfmjKiY[NVnJ00Ac
V@0;MiQg^7NFNkMgUW^eNiEk]G^DNk=kT`02Ni802G^cNi=kTW^BNk9kTW^cNi=k]003NkD00g^gMkIg
^002MkP01fnILkYcVFnKJiY_Vf^J009WN`EO?003FcaO?5LL00=G7005E_aG75KlE_aBo003E_`3D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo0020004Ool3000>Ool0025oo`03001oogoo02Aoo`03
001oogoo02moo`05EaeBo5LMDaaG?@030000Y5LmDaaO?E/lGeeK?5lmFcaOGEllHeaO?6]kIg][Nf]j
Ki][NVnKJgYcVVnILiUcUgNhLiQk]gNFNkMkUG^eNi=o/g^COk=kTWndNi=o/g^BOk=kTW^cNi9k]7^C
NkEg]7_GMkIg^7>hMkU_VG>jKiU_Vf]jKi][NV]lIg][O6MKGcaK75llFa]O?5/LGcaFo5/LE_aG75Kl
FaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000DOol0
025oo`03001oogoo02Eoo`03001oogoo02]oo`EC7@<000=G7@09EaaG7ELMGcaK?5llFcaOG5ll00=O
G007GcaOG6mjKiY[NVnJKgX00g>I00YgV7NhMiQk]gNFNkMkUG^eNiEk]09kT`06NiAk]7^CNi=kTW^C
0W^B00EkTg^cNk=k/g^C009k/`09NkAk]G^eMkIg]gNfKi][VVnK00EWN`05HeaSFellFcaO?004Fa`0
35KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`00
01=oo`008Goo00<007ooOol09Woo00<007ooOol0:7oo00ABo5<MD_aG7@<00019EaeBo5LMEaaK?ELL
FceG75/mEaaK?EllHeaO?6=LGcaSG5llHeaSFfMlJgY_Vf]jLiY_VG>ILiMg^7>HMkQgUW^gMiIk]G^E
OkAkTgncNiEo]7^DOk=kTWncNi9k/g^BNk=kTg^cNi9k/g^CNkAg]7_EMkEkegNfMkUc^7NhIe][O6Mk
JgaSFfMLHe]SG6=KFc`00U/L061G75/lFaaG75KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000COol0025oo`8002Qoo`8002Eoo`05D_eC7E;m
DaeBo@020004Dad015LMDaeG7ELL0ULM00IG?ELLEaeK?5/mGc`3Ge`01EllHeaSG6MLHe/00V=L17>I
00ig^7NHMiQgUW^gMiIk]G^ENkEkU7^eNiEk]7^D0W^C00Ek/g^BNi9kTW^c009kTP05Ni=k/g^BNkAk
/`02NkD02GNgMkIk]g>hMkQcVG>jKiUc^P02He`00f=KHeaSG002Gc`6Fa`7E_`01U;lE_aBo5KlD_aF
o0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol0019oo`008Goo00<007ooOol0:Goo00<007oo
Ool087oo00AC7DklDaeBo0<0001@D_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK?ELLFceG75/mGcaS
G5llIgaSFfMlHe]WO6=KJg]WNf]kIe]g^7>HMkQcUg^gMiIk]g^ENkIgUW^gNiEk]W^DNkAkTWncNi9o
/g^BNk=kTWncNi9k/g^BNkAkTg_EMkEkegNfNmMc^7NhKiUc^VnILkY[NVnKHe]SG5lkHeaO?6=LGc]K
?09K701OE_aK75KlEaaBo5LLE_aG75;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_`0000BOol0021oo`03001oogoo02]oo`03001oogoo01aoo`04DaeBoE<MD_d3
00000e;mDaeBo@03Dad04E;mEaeC7ELMDaeG7E<MEaeK?5/mFcaK?E/lFceK?5/mHe/00V=L00EWG6=K
HeaSG6]k00=WN`0=KiY[NVnJKgYk]gNFNkMgV7NhMiIk]g^ENkD00g^D00Ek/g^CNi9kTW^b00=kTP0:
Nk9kTW^cNk=k]7^eMkMg]W^gLkP2MkP01g>jKiUc^V^JKi][VVnK00MO?09G7006FaaG75LLEaaFo5;l
0eKl00IBo5KlD_aFo5;lE_`>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`00015oo`0087oo00<007ooOol0;7oo00<0
07ooOol05Woo00IC7DklDae>o5<MC_`30000G4klDae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEaeBo5Lm
DaaG7ELLFceG75/mEaaK?E/lGceK?6MlHe]WO6MKJg]WNf]kIe]_Vf]jKi][NW>JKiUcVG>GMkQcV7^g
MiIk]W^ENkAkTgncNi=o/g^BOk=kTgncNi9o/g^BNk=kTg^dMkEk]GNfNmMg]WNhLkQc^VnIKi][NVnK
JgY_VfMKJgaO?6=LGc]SG5/LGcaK6e/LE_aK75KlFa`2E_`0Fe;lEaaBo5KlD_aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00011oo`0087oo00<007oo0000;Goo
00<007ooOol04goo00=BoE<MC_d00U;m0`0000MBoE<MD_eC7E;mDaeBo@03Dad01E;mDaeC7E<MD_d0
0eLM011G75LMEaeG7E/lFceK?5llFcaO?5/lGcaK?5llIg][N`=WN`04KiY[NVnJKgX4LiT01WNhMiQk
]gNFNkEkU@9kU004NkAkTg^CNi82Ni<2Ni802W^bNi9k/g^CNkAk/g^eMkIk]gNf0WNh00Mc^VnIKi][
VVnKJiY_V`04Ig/035/lGcaK75llFcaO?5/LEaaFo5LLE_aG709Fo004D_aFo5;lE_`3D_`00eKlD_aB
o006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2000@Ool0021oo`8002moo`03001oogoo00moo`05
C_eC7DklDae>o@030000G4klDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEceC75LM
DaaG?E<LEaeK?5mMFcaO?E/lGeeK?5lmGcaSG6MkJg]WFfnKJgY_Vf]jKi]_VG>IKiUg^7>HNkMgUW^g
NiEk]G^COkAkTgncNi9o/g^DOk=kTWncNi9k/g^BNkAkTg^cNi9k]7^cNkEg]7_GMkIg^7>hKi][NVnK
Ie][O6MkJgaSFfMLFaaO?5/KGc`2Fa`0HULLFaaFo5LLE_aK75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000?Ool000Eoo`D000Eoo`8000Eo
o`@000Ioo`03001oogoo02moo`03001oogoo00aoo`04Dae>oE;mD_d300000e;mDaeBo@02D_d02U<M
D_eBoE;mDaeBoE<MD_eC7E;m25<M0eLM00UG75LMEaeG?E/lGcaK?5llFc`00emL00QO?5mLGea_VV]j
KiY_NVnJ0g>I00Yg^7NHMiQgUW^gNiEk]G^DNkAkU09kT`05NkAkU7^CNi9kT`02Ni8027^CNk=k/g^B
Ni=k]7^cNk@2NkD01WNfMkMg^7NhLkQg^0=WN`=SG003He]SG6=L00EK7003E_aG75Kl00=Fo006D_aF
o5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0Woo00<007ooOol0
37oo0004Ool200001Goo000007oo000017oo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0<7oo00<007ooOol027oo00EC7DklDae>oE<M0080001;C_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E;lFceG75/mEaaK?ELLFceK?5mMFcaSG5llHeaO
?6=LGcaWO6=KKi][NVnKKiUcVFnIMkQcV7NhMiIk]gNFNkEkUGndNiAo/g^BNkIkU7^dNi=o/g^BNk=k
TW^cNi9k/g^B009k/`0GNkAg]7_EMkIkeg>hMkUc^7NhKiUc^VnIHeaSFfMLHe]SG6=KHeaO?5/LEaaK
?002Fa`01U;lEaaFo5LLD_aG709Fo01ID]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LOol0000>Ool000Aoo`80009oo`03001oo`0000moo`03001oogoo00=o
o`03001oogoo035oo`03001oogoo00Eoo`04C_eBoE;mDad300001U<MC_eBoE;mDae>o@9Bo@05DaeB
oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@IC7@06EaeC7ELMEaeG?ELL0ULM00=G?EllGe`00UmL00EO
?5mLHeaWG6=K009SG003IeacVG>I009cV@9gV006MiIk]gNFNkEkUG^d0W^D00AkUG^eNiAkU09kT`=k
TP04Nk=kTW^BNi82Nk<04G^dNk=k]G^eMkMg]WNhLkQg^7>ILkY_VFnKJiYSG6=KHe`01Ell00EK75LL
EaaG75/L00AFo008D_aFo5KlE_aBo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool0
07oo00aoo`0017oo0P000Woo00<007oo00003goo00<007ooOol00Woo0P00=7oo00P007ooOomoodkl
Dae>oE<M0`0006MC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC
7E;lDaeC75LMD_aG7E<LEaeBo5/mEaaK?ELLFceG75/mGcaSG5llHeaSFfMlHe]WO6=KIgaWNf]kIe][
Ng>HMkQcUg^gMiIk]g^ENkIgUW^gNiEk]W^ENkAkTgncNi9o/g^BOk=kTW^cNi9k/g^BNkAgTg_EMkEk
egNfMkUc^7NhKiUc^VnIKi][NVnKJgYSG5lkHeaO?6=LGc]O?002Fa`0IEKlFaaFo5/LD_aG75;lE_aB
o5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g7oo000037oo0004Ool20002Ool00`00Ool0000;Ool40005Ool00`00Oomoo`0bOol00e;mDae>o@02
D_d01U<M00000000Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m019C7DkmD_eBoE<MD_eC7E;mDaeBoE<M
D_eC7E;mDaeBoE<MD_d2Dad03ULMDaeG7E<MEaeC7E/mFcaK?E/lFceK?5/mFc`2He`01FMLHe]SG6=L
Jg/00fMk00i[Nf]jKiY_NW^gMiIk]gNHMkQgUW^gMiIk]G^E0W^D00Ik/g^BNi9kTW^bNi<2Ni8017^b
Ni9k/g^c0g^e00]g]W^gLkQg^7>ILkY_VFnKJiY_Vf^J009WN`=O?006FcaO?5/LGcaG75/L0ULL00=F
o5LLD_`00eKl00ABo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`0037oo
0003Ool300001Goo000007oo00002goo00<007ooOol01Woo00<007ooOol0<7oo00EC7DklDae>oE<M
00<0001cDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7E;lEaeBo5<MD_aG7E<LEaeBo5LMDaaG7E<LFceG75/mEaaK?ELLGceK?6MlHe]WO6=KJg]WNf]k
Ie][Nf]jKi][NW>JKiUcVG>GMkQcV7^gMiIk]W^ENkEkTgndNi=o/g^BOk=kTgncNi9o/g^BNk=gTg^d
MkEk]GNfNmMc^7NhKiUc^VnIKi][NVnKIg][O6MKJgaWNellFa]O?5/LGcaK6ellE_aG75KlFa`00UKl
061Bo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo7oo000;Ool000Eoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo02eoo`05Dae>oE;mD_eC7@0300001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMEa`00eLM00aG
75/mFcaK?E/lGcaK?5llFcaO?6MkJg/3Ig/016nJJgY_VVmj17>I00Yg^7NHNkMgUW^gNiEk]G^DNkAk
T`9kTP0BNkAkTg^CNi9k/W^BNk=kTg^dNi9k/g^CNkAk/g^eMkIk]gNf0gNh1FMk0V=L00AO?5/LGcaK
?0=K7004E_aG75KlEa`2E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg000
0U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo004D]aBo000000:Ool000Ioo`@000aoo`D000Aoo`03001oogoo02]oo`04C_aC7DkmDad3
0000Le<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMDaaG7E<LEceC75LMDaaOGE/lGceK?5mMFcaO?Ell
HeaWNf]kIe]_Vf]jKi][NVnKKiUcVFnIMkQcV7NhMiIk]g^ENkEkUGndNiAo/g^COkAkTgncNi9o/g^B
Nk=kTW^dNi9k/g^BNkAk/g^eMkAkegNfMkQc^7NiKiUc^VMKJgaSFf=LHe]WO6=KHeaG75/l009K7006
EaaK?5KlEaaBo5LL0UKl05mBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0000Yoo`007goo00<007ooOol0:7oo00E>oE;mD_eC7Dkm
00800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>
oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d7Dad2Ead02ELLEaeG7ELmEaaO?5/lGcaK?003Ge`0
25llGeaOG6nJJgY_VVmjKiX3LiT03WNhMiQgV7NFNkMgUW^eNiEk]7^DNi=kUG^dNi@3Ni<2Ni801G^C
Nk=kTW^cNi<00W^c00Ek]7^eNkMg]WNg009g^005KiUc^W>ILkYSF`03He`016=KGcaO?5ll15/L0ULL
1UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg0020009Ool001ioo`8002Eoo`07C_eC7DklDae>oE<MC_`00`00065>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7E;lDaeBo5LMD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaK?EllHeaO?6=LGcaSG5llIgaSFfnK
JgY_VfnILiU_VGNhLiQg^7NFNkMgUW^eNiEk]W^DNkAkUGndNiAo/g^COk=kTW^cNi9k/g^BNk=kTP02
Nk<0Og^dMkAkeGNfNmMc^7NiLkQc^VnILkY[NVnKJgYSG5llHeaO>f=LGcaSG5KlFaaFo5/LE_aG75Kl
EaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aoo`0000Uoo`007Woo00<007ooOol08Woo00IC7DkmD_eBoE<MC_d300001Dkm
D_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@AC7@06EaeC7ELMEaeG?ELL0ULM00=G
?E/lFcd00UmL00EO?5mLGeaWG6=K009SG003IeacVG>I009cV@=gV009NkMgUW^gNiEk]GNFNkMgUW^e
009kU003Ni=k/g^B009kTP0;Ni=kTW^BNi9k/g^BNkAk/g^eMkIg]`02MkP01g>hLkYcVG>jJiY_Vf^J
009WN`EO?003FcaO?5LL009G7003FaaG75Kl009Fo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00<007ooOol01goo000NOol00`00Oomo
o`0POol01DklDae>oE<MC_`00`000>=>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeB
o5<MD_aG7E;lEaeC75LMD_aG7ELLFceG75/mEaaK?ELLFceO?6=LHe]WO6=KIgaSFfMlIg][NfMKJg]c
V7NhLiMk]gNFNkMcUgNhMiIk]gNFNkIkUG^dNi=o/g^BOk=kTWncNi9o/g^BNk=kTW^dMi=keGNeNmMc
^7NiLkQc^VnILkY[NVnKJgY[O6MkJgaWFf]lFaaO?5/KGcaK75llE_aK75KlEaaFo5LLD_aFo5;lE_aB
o5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L00Ao
o`03001oogoo00Moo`007Woo00<007ooOol07Woo0U;m00=C7Dkm00000P0000E>oE;mD_eC7Dkm009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M019G7E<MEaeC7ELMDaeG7E/l
FceK?5/mFcaK?E/lFceSG6MLHe/2He`026MLIg]WNfMkJg][NVnJKgX3LiT3MiP017^gMiIk]g^E0W^D
00Ek/g^CNi9kTW^c00=kTP08Nk9kTW^cNk=k]7^eNkAk/`9k]@06MkMg]W^gJiY_Vf^J1FMk00ASFf=L
FcaO?0AK7004E_aG75KlEa`2E_`01U;lE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo0Moo`03001oogoo00Ioo`007Woo00<007ooOol06goo00AC7DkmDae>o0<00022
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5LMD_aC7E;lEaeBo5<M
D_aG7E<LEaeC75LmEaaK?ELLFceG75/mFcaOGF=KIgaSFf]kIg][NfMKJg][NVnKJgYcVVnILiU_NGNh
LiQk]gNFNkMkUG^eNi=o/g^COk=kTWndNi=o/g^BOk=kTW^cMi=k]7^BNk=gTg_EMkEk]GNfNmMc^7Nh
LkQ[O6MkJgaWFfMlHe]SG6=KIg`2Fa`0H5LLFcaK75LLE_aK75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo0Yoo`03001oogoo00Ioo`007Goo0P00
67oo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m
00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG7003Ead035LLEaeK?5/mFcaO?5/lGcaK
?5llFca[N`=WN`05Jg][NVnJKgY_VP03LiT3MiP01WNFNkMgUW^eNiAk]09kT`0;NiAk]7^CNi=kTW^b
Ni9k/g^CNkAkTP02Nk<01W^dNkEk]GNfNkMg]P9g^003LkY_VG>j009SG004He]SG6=LHe`2Gc`5Fa`7
E_`01U;lE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`0
05;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l3Woo00<007ooOol01Woo000NOol0
0`00Oomoo`0DOol01TklDae>oE<MC_aC7@80002BC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG7E<LEceC75LMDaaG?E/l
GceK?5mMFcaO?E/lHeaO?6]kIe][Nf]jKi][NVnKKiUcVFmiMkQcV7NhMiIk]gNFNkEkUGndNi=o/g^E
OkAkU7ncNi9o/g^BNk=kTWncNi9k/g^BNkAg]G^eMkIkegNfMkQc^7>jKiUc^V]jKi]SFf=LHe]SG5ll
HeaO>f=LE_aK75KlFaaFo5LLD_aG709Fo01=D_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g00COol00`00Oomoo`06Ool001eoo`03001oogoo01=oo`9Bo@03Dae>oE;m00<0009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;m
DaeBo@MC7@0:EaaG7ELMEceG75LMFcaO?5/lGc`2Ge`025llGeaOG5mLJgY_VVmjKiX3LiT4MiP02W^g
MiIk]g^ENkEkU7^eNiEk]7^D0g^C0W^B0W^C0W^B00MkTg^dNk=k]GNfNkMg]P03MkP01fnILkY[VVnK
JiY_Vf^J00EO?004FaaO?5LLFa`3Ea`00eKlD_aFo002E_`015;lE_aBo5Kl25;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo006D]aBo5;lD_aBg5;l5Goo00<0
07ooOol01Woo000MOol00`00Oomoo`0AOol014kmDae>o5<M0`0007QC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeB
o5LMD_aG7E;lEaeG75/mEaaK?ELLFceG76=LGcaSG5llHeaO?6=LHe]WO6=KIga_VG>IKgUcVW>HMkQc
Ug^gMiIk]g^ENkIkU7^gNiEk]W^DNkAkTgncNi9k/g^BOk=kTW^cNi82Nk<06g^eMkAkegNfNmMc^7Ni
KiUc^V]jKi][NVnKJgY[O6MkHeaO>ellFaaO?5/KFaaFo5/LE_aK7002E_`0Be;lEaaBo5KlD_aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000
D_aBg5KlD]aBo5;LE_aBg00GOol00`00Oomoo`06Ool001eoo`8000moo`04D_eC7DkmD_d30002D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05
DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@AC7@04EaeC7ELMEa`2Ead01ULmFcaK?E/lGeaO?09O
G005IeaSFf=LHeaWG003Ig/00f]kMiQgV002MiP027NFNkMgUW^eNiEk]g^ENkD2Ni@00g^CNk=kTP02
Ni8017^cNi9kTW^B0W^c00Ek]7^eNkMg]WNg009g^006KiUc^V^JKi][VVnK1FMk00]O?5/LGcaK?5ll
FaaG75KlEaaFo5LL009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`077oo00<007ooOol01Woo000MOol00`00Oomoo`09
Ool01TklDae>oE<MC_aC7@<00020Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeB
o5LMDaaG7E;lFceG75/mEaaK?ELLFceSFfMlHe]WO6=KIgaWNf]kIe][Nf]jKiY[NVnKMiIk]gNFMkQc
V7^gMiIk]W^ENkAkTgncNi=o/g^COk=kTWncNi9k/g^BNkAg]09k/`0CNkAg]7_EMkIkeg>hMkUc^6]l
Ie][O6MkJgaSFfMlHe]O?5/KGc`00U/L00IG75/LE_aG75;lEa`2E_`0@U;lE_aBo5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol001moo`03
001oogoo00Eoo`007Goo00<007ooOol01goo0U;m00=C7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mEaeC7ELMDad00eLM00UG75/mFcaK?E/lFceK?5ll
He/00V=L00I[NfMkIg]WNf]kJgX2KgX016nJLiUcVG>I0gNH00=gUW^eNiD00W^D00Ik/g^CNi9kU7^c
Ni<2Ni800g^bNi9k]003Nk<037^dNk=k]G^eMkMg]WNhLkQc^W>iLkYSF`=SG003He]SG6=L00IK70EF
o006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`017oo00<007ooOol077oo00<007ooOol01Goo000MOol00`00Oomoo`05Ool014kmDae>o5<M0`00
0>1C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEaeC75Lm
DaaG7E<LFceG75lmFcaOGE/lGceK?6]kIg][NfMKJg][NVnJJgY_VfnILiU_NG>JLiQg^7NFNkMkUG^e
Ni=o]7^COk=kTgncNi=o/g^BOk=kTW^cNi9o/g^BNkAgTg_EMkEkegNfMkUc^7>jKiUc^V]jKi]SFfMl
He]SG5lkHeaO?5/LEaaK?5KlFaaFo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L27oo00<007ooOol06goo00<007ooOol01Goo000M
Ool01000Oomoodkm0U;m00AC7DkmD_eBo@80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad0
0e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@EC7@9G7@0=EaaG7ELMEaeG75llFcaO?5/lGcaK?5mLGc`0
0VMk00I[Nf]jKgY_NVnJJgX3LiT3MiP01G^gNiEk]G^DNk@00W^C00ikUG^dNi=kTg^BNk9kTW^cNi9k
/W^BNkAk/g^d0W^e00]g]WNhLkQg^7>iLkY[VVnKJiY_Vf^J00IO?006FaaG75LLEaaK75LL0eKl00QB
o5KlD_aFo5;lE_aBo5Kl25;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`<Ool00`00Oomoo`0KOol00`00Oomo
o`05Ool001aoo`08001ooe<MC_eC7DklDae>o@<0002PC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aG7E<LEaeC75LmEaaK?ELLGeeK?5lmGcaS
G5llHeaO?6=LJgY_VV]jKi][NW>IKgUcVW>HMkQcUg^gMiIk]G^EOkAkU7^eNiEo]7^COk=kTWncNi9o
/g^BOk=kTW^cMi=k]7NeNkEg]W_GLkQg^6nILkY[NVnKJgY_Vf]jJgaWFf=LGcaSG5/LGc`2Fa`0>eKl
FaaFo5LLE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`04Goo
00<007ooOol06Woo00<007ooOol01Goo000LOol00`00Dae>o@02D_d300000e;mDae>o@02D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@MC7@03
EaeG?ELL009G7@03EceG75mL009OG009GcaOG5mLGeaSFf=LKgY_VV]j00=cV@=gV00:NkMgUW^eNiEk
]7^DNkMkUG^eNi@3Ni<027^BNi=kTW^CNi9k/g^CNk@3NkD02G^gLkQg^7>iLkY[VVnKJiY_V`05Ig/0
2ellFcaO?5/LGcaK?5LLE_aG75KlEa`00UKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`05goo
00<007ooOol06Goo00<007ooOol01Goo000BOol50005Ool00`00C_d000020000g4kmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG
7E;lEaeBo5LMEaaK?ELLFceG75/mEaaSG5llHeaO?6=LHe]WO6=KIgaSFg>IKgUcVVnIMkQcUgNhMiIk
]g^ENkIgUW^gNiEk]W^DOk=kTgncNi9k/g^BOk=kTW^cNi9k]7^cNkEg]7^dNk=k]GNfNmMc^7NhLkQg
^6MkJgaWFf]lIg]SG6=KGcaK75llEaaK?5/LEaaFo5/LE_aG75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5Kl6Woo00<007ooOol067oo00<007ooOol01Goo000DOol00`00Oomoo`05Ool200000e;m
Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0B
DaeBoE<MD_eC7E;mDaeBoE<MD_eC7E;mEaeC7ELMDaeG7E<M0ULM00IG?E/lFceK?5/mFc`2Ge`01VML
He]SG6=LIeaSF`9WN`03Jg]WNgNH009gV00<MiIk]gNHMiQgUW^gMiIk]G^ENiAkTg^c0W^B0W^C0g^B
0g^c00=kTg^dNk<00W^e00=k]gNfMkP00WNh00E_VG>jIg]WNf=K00=SG003He]K75/L00AK70EFo008
D_aFo5;lE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L009Bo1aoo`03001oogoo01Uoo`03001oogoo00Aoo`0057oo00<007ooOol0
1Woo094007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMD_aG7ELLFceG75/mEaaK?ELLIgaSFfMlHe]W
O6=KJg]WFf]kIe]_VV]jKi]_VG>ILiMg^7>HNkMgUW^fNiEk]7^COk=kTWncNi=o/g^BNk=kTP03Nk<0
5W^BNk=k/g^dMkAkegNfMkQc^7NhKiUc^VnILkYSFf=LHe]WO5llHeaO>e/l0U/L02iFo5/LE_aG75;l
EaaFo5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo25oo`03001oogoo01Qoo`03001oogoo00Aoo`0057oo00<007oo
Ool01goo0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;m
D_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M015BoE<MDaeG7E<MEaeC7ELMEaaG7E/lFceK?5/mFcaO
?5/l009SG006IeaWNfMkIg][NfMk0Vmj00A_VW>ILiUcV@9gV008NkMgUW^gNiEk]G^DNk=kT`9kU005
Nk=kTW^BNi9k/P02Ni8017^CNk=k/g^d0W^e00]g]WNhMkQg^6nILkYc^G>jJiY_Vf^J00IO?09G7006
FaaG75LLEaaFo5;l0eKl00IBo5KlD_aFo5;lE_`:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo003D]aoogoo02Aoo`03001oogoo01Moo`03001oogoo00Aoo`0057oo00<007ooOol02Goo0:L0
07ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC
7E;lEaeBo5<MD_aG7E;lEaeC75LmDaaG7E<LEceC75lmFcaOGE/lGceK?5mMIe][NfMKJg][NVnJJgY_
Vf]jLiU_NGNhLiQg^7NFNkMkUG^eNi=o/g^CNkEkTgndNi=o/g^BOk=kTWncNi9k/g^BNkAgTg_EMkIk
eg>hMkQ_VG>jKiUc^V]jKi][NV]lIg]SG5lkHeaK75ll009K7004E_aK75KlFa`2E_`08U;lEaaBo5Kl
D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
:7oo00<007ooOol05goo00<007ooOol017oo000DOol00`00Oomoo`0:Ool01000OomC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m
1U<M00=G7ELLEad00ULM00MG75LMEaeO?5/lGcaK?002Gc`3Ge`01F]jKgY_NVnJJgX00g>I0WNH00Yg
UW^gMiIk]G^ENkAkUG^eNiAk]09kT`03Ni9k/W^B009kTP04Nk=kTW^dNk<2NkD02GNgMkQg^6nILkYc
^G>jJiY_V`05Ig/02ellFaaO?5/lGcaK75LLE_aG75KlEa`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]aBo2aoo`03001oogoo01Ioo`03001oogoo00Ao
o`004Woo0`003Goo0:D007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7E;lEaeG75/mEaaK?ELLFceK?5lmFcaSG5llHeaO?6=L
He]WO6]jKi][NW>IKgUcVW>HMkQgUW^gMiIk]G^EOkAgUW^eNiEo]7^DOk=kTWncNi9o/g^BOk=kTW^c
Mi=k]7NeNkAgTg_EMkIkegNfNmM[NVnKIe][O6MkJgaWFfMlHe]O?5/LGc`00U/L00IG75/LE_aG75;l
Ea`2E_`06E;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L035o
o`03001oogoo01Eoo`03001oogoo00Aoo`0057oo00<007ooOol037oo0P0000IoodkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE;mD_eC7E;mDaeBo@IC7@04EaeC
7ELMEa`2Ead00eLmEaaG7@02Ge`01EllGeaOG5mLHe/00V=L00=WG6=KLiT00g>I0WNH00Yk]gNFNkMk
UG^eMiIk]G^ENkAkU0EkT`03Ni9kTg^B009k/`04NkAkTW^cNk<2NkD2MkH01G^gLkQg^7>iLkX00VMk
0V=L00=SFf=LHe`01U/L1EKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`015;LD_aBo5;l=Woo
00<007ooOol057oo00<007ooOol017oo000UOol0_@00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK?ELLFceO
?6=LGcaWO6=KIgaSFfMlHe][NfMKJg]WFgNhLiMk]gNFNkMcUgNhMiIk]g^ENkIkU7^dNi=o/g^DOk=k
TgncNi9k/g^BNkAkTW^cMi=k]7NeNmMg]W_GLkQg^6nILkY_VG>jHe]WO6=KHeaO>f=LGcaK75LLFcaF
o5/LE_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg00jOol00`00Oomo
o`0EOol00`00Oomoo`03Ool002Ioo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad04E;mEaeC7ELMDaeG7E<MEaeK?5/mFcaK?E/l
FceK?6MLHe/00V=L00IWG6=KIg]WNf]kIg/2KgX3LiT3MiP00g^gNiEk]@02Ni@00g^CNk=kTP03Ni<2
Ni801W^CNk9kTW^cNi=k]09k]@03MkIk]g>h009g^006LkY_VG>jJiY_Vf^J1Ull00IK75LLEaaG75/L
Ea`3E_`025;lE_aBo5KlD_aFo5;lE_`8D_`mOol00`00Oomoo`0DOol00`00Oomoo`03Ool002Moo`2P
001oogooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<M
D_aG7E<LEaeBo5LmDaaG7ELLFceG75/mFcaOGE/lIgaSFfMlIe][NfMKJg]WFfnJJgY_VfnILiUcUgNh
LiQk]gNFNkIkUG^dNi=o/g^CNkAkTgncNi9k/g^BOk=kTW^cNi9k]7^cNkEg]W_GLkQg^7>hLkY_VG>j
JgY_Vf^JJgaWFf=LGcaSG5/LGc`2Fa`05EKlFaaFo5LLE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg010Ool00`00Oomoo`0COol00`00Oomoo`03Ool002Qoo`800005OomBoE;mDae>o@02D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeBo@03Ead035LL
EaeG7ELMFcaO?5/lGcaK?5llFcaO?0=WN`05Jg][NVmjKgY_VP03LiT3MiP00gNFNkEkU@02Ni@01G^c
Ni=k]G^DNk<00g^B00AkTg^BNi9kT`9k/`9k]@09NkMc^7NhMkQc^VnILkY[VVnK00EWN`0;GcaK?5ll
FaaO?5/lEaaFo5LLE_aG7002E_`01U;lE_aBo5KlD_aFo0=Bo4Ioo`03001oogoo019oo`03001oogoo
00=oo`00:Woo08H007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC
7E;lEaeBo5LMD_aG?E<LEaeC75/mEaaK?E/lGeeK?5lmFcaOGEllHeaO?6=LJgY_VV]jKi]_VG>IKgUg
^7>HMkQgUW^gNiEk]G^COkAkUG^eNi=o/g^COk=kTWncNi9k/g^B0W^c01=k]7NdNkAk/g^eMkAkegNf
NmM[NVnKIg][O6MKJgaSFf=LHe]WO002Fa`03ULLFcaK75LLE_aK75KlEaaBo5KlD_aFo5;lE_a:Ool0
0`00Oomoo`0BOol00`00Oomoo`03Ool002]oo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d9Dad00eLMEceG7002Ead01ULmFcaO?5/lGeaO?0=OG005He]S
G6mjKiY[NP02LiT3MiP02gNFNkMkUG^eMiIk]g^ENkEkUG^dNi<00W^B00Qk/W^BNi9kTW^cNi9k]7^C
0W^c0g^e0WNf0WNh00E_VG>jLkUSG6=K00=SG09O?0EK70IFo4moo`03001oogoo015oo`03001oogoo
00=oo`00;7oo08H007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG
7E;lEaeBo5LMD_aG7ELLFceG75/mEaaK?EllHeaO?6=LGcaSG6=KIgaSFfMlHe]cVFmiMkQcV7NhLiMk
]gNFMkQcUg^gMiIk]G^EOkAkTgncNi9o/g^COk=kTWncNi9k]7^B0W^c01]k]7NdNmEg]W_GLkQgf6nI
LkY_VFnKJiYSG6=KHeaO?6=LGc]SG5KlFaaFo5/LE_aG75;lEa`0DWoo00<007ooOol047oo00<007oo
Ool00goo000]Ool20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0>DaeBoE<MD_eC
7E;mDaeBoELMDaeG7E<MEaeC7@9G7@06EceG75/mFcaK?Ell0UmL00IWG6=KHeaSG6MLHe/2Ig/016nJ
JgY_NVmj0W>I0WNH01=k]gNFNkEkUG^eNiAkTg^BNi=kU7^CNi9k/W^BNk=kTW^cNi9k]003NkD2MkH0
27NhLkQc^W>iKi][VVnKJiX5Gc`015/LGcaG75/L0eLLEGoo00<007ooOol047oo00<007ooOol00Woo
000_Ool0VP00Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeC
75LMD_aG7ELLFceG75/mEaaK?ELLIgaSFfMlHe]WO6=KJg]WFfnKJgY_VV]jLiY_VG>ILiMg^7NFNkMk
UG^fNiAk]7^COkAkU7ncNi9o/g^BNk=kTWncNi9k]7NCNmEg]G_GMkIgf7>hLkY_VFnKJiY_Vf]jJgaW
Nf]lFaaO?5/LGcaK75llFGoo00<007ooOol047oo00<007ooOol00Woo000`Ool01@00OomBoE<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01E<MD_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad04E;mDaeC7ELMDaeG7E<MEaeG75LMFcaK
?E/lFceK?5llFc`00V=L00IWG6MkIg]WNf]kJgX2KgX3LiT2MiP027NFNkMkUG^eNiEkU7^CNkD2Ni@2
Ni<01G^BNk=kTW^bNi800W^c0g^e00Qg]WNhLkQc^W>iKi][VVnK16Mk0V=L00=K75llFc`0G7oo00<0
07ooOol03goo00<007ooOol00Woo000aOol0U000Oomooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
D_aG7E;lDaeBo5LMD_aG7E<LEceC75LMDaaG?E/lGceK?5mMFcaO?E/lGeeWFf]kIe][Nf]jKiY[NW>J
KiUcVG>GMkQcV7^gMiIk]W^ENkAkTg^fNiAk]7^COk=kTW^cNi9o/g^BNk=gTg^dMkEk]GNCNkAg]G_G
MkIgf7>hMkQWFf]lIg]SG6=KIgaSFf=LGgoo00<007ooOol03Woo00<007ooOol00Woo000bOol01@00
Oomooe<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d6Dad03ULMEaaG7ELMEceG75LM
FcaO?5/lGcaK?5mLGc`3Ge`00f]jKgY_NP03LiT3MiP027^gMiIk]G^ENkEkU7^eNiD2Ni@00g^cNi9k
TP02Ni<2Ni800g^CNkAkTP02Nk<02W^dNkEk]GNfNkMc^7NhLkUc^VnI0f=L00=SFgooOol0Ggoo00<0
07ooOol03Woo00<007ooOol00Woo000cOol20000S7ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeB
o5LMD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaSG5llHeaO?6=LGcaSG6=KIgaSFg>JKiUcVFmiMkQc
V7NhMiIk]g^ENkEgUW^gNiEk]7^DOk=kTgncNi=o/g^BNk=kTW^dNi9k/g^BNkAk/g^eMkIkeg>hMkQ_
VG>jKiU_Vf]jKi]TOol00`00Oomoo`0=Ool00`00Oomoo`02Ool003Eoo`04001ooe<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeB
oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@AC7@0<EaeC7ELMEaaG7ELLEceG75/mFcaOG5ll0UmL00EW
G6=KHeaSG6]k00=WN`=gV00>MiIk]gNHMiQgUW^gNiEk]G^DNkAkTg^BNiAk/`=kTP06Nk=kTW^cNi=k
]7^c0W^e00Uk]g>hMkQg^7>jKiU_Vf^JKi/0IWoo00<007ooOol037oo00<007ooOol00Woo000fOol0
O000OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK?ELLFceG
75/mHe]WO6=KIgaSFf]kIe][NfMKKi][NVnJKgUcVW>HMkQcUg^gMiIk]G^EOkAkTgncNiAo/g^BOk=k
TWncNi9k/g^B0W^c00]k]7NdNmMg]WNhLkQc^VnIKi][NVnK06Qoo`03001oogoo00]oo`03001oogoo
009oo`00=goo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@0AD_eG7E<MEaeC7ELM
DaeG7E/lFceK?5/mFcaK?E/lGcaSF`02He`01f]kIg]WNfMkKiY[NVmj00=cV@9gV00:NkMgUW^eNiEk
]7^DNi=kUG^dNi<2Ni8017^bNi9kTW^C0W^c00Ak]7^eNkEg]P9g^005LkY_VFnKJiY_V`1YOol00`00
Oomoo`0<Ool00`00Oomoo`01Ool003Qoo`800023Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aG7E;lDaeBo5LM
DaaG7E<LEceC75LMEaaK?ELLGceK?5mMFcaO?E/lJg]WFf]kIe]_Vf]jKiY[NW>JKiUg^7>GMkQgUW^g
NiEk]W^DNkEkUGndNiAo/g^BOk=kTWncNi9k/g^BNkAgTg_ENk=k]7NdNmMg]WNhLkQgf01[Ool00`00
Oomoo`0;Ool00`00Oomoo`01Ool003Yoo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m1E<M
0ULM00eG75LMEaeG7E/lGcaK?5llFcaO?5/lGeaO?002Ig/016nJJgY_NVmj0g>I0WNH019gUW^gNiEk
]G^DNkMkUG^eNiAkTg^BNk9kTW^CNi9k/W^BNk@2Nk<017^BNkAk]G^e0WNf0WNhKGoo00<007ooOol0
2Woo00<007ooOol00Goo000kOol0P000Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeBo5LMDaaG7E<L
FceG75/mFcaOGE/lGceO?6=LGcaSG5llKi][NVnJJgYcVVnILiUcUgNhMiIk]gNFNkIkUG^gNiEk]W^D
NkAkTgncNi=o/g^BOk=kTW^cMi=o/g^BNkAgTg_EMkIkeg>hMmQ_Ool00`00Oomoo`09Ool00`00Oomo
o`01Ool003aoo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d7Dad01eLLEceG75LMEaaG?ELL00=O
G005GcaOG5mLIeaSF`02He`4LiT2MiP02G^gMiIgV7NHNkMgUW^eNiEkU002Ni<02G^DNi=kTg^CNi9k
/g^BNk9kTP02Nk<00g^eMkIg]P02MkQ`Ool00`00Oomoo`09Ool00`00Oomoo`01Ool003eoo`80001j
OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMD_aG7ELLFceG75/mEaaK?ELLHeaO?6=LHe]WO6=KIeaSFf]k
Ie][NfMKMkQcV7>IKgUg^7>HMkQgUW^fNiEk]7^DOk=kU7ncNi=o/g^BNk=kTWncNi9k/gNCNkAg]7_G
MkIgf79oo`03001oogoo00Qoo`03001oogoo005oo`00?goo00H007ooD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d07U<MD_eC7E;mDaeBoE<MD_eC7E;mDaeB
oELMDaeG7E<MEaeC7ELMDaeK?E/lFceK?5/mFcaK?F=LIeaSF`9SG006Jg]WNfMkIg]_VV]j0g>I0WNH
00YgUW^gNiEk]G^DNkAkUG^DNi=k/`=kTP06Nk9kTW^cNi=k]7^e0WNf00=k]GooOol0LWoo00<007oo
Ool01goo00<007ooOol00Goo0010Ool0L`00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMDaaG?E<LFceG
75/mEaaO?E/lGeeSFfMLHe][NfMKJg]WFfnKJgYcVFmiLiYcV7NhLiMk]g^ENkEkU7ndNi=k]7^DOk=k
TWncNi=o/g^BNk=kTW^d009k/`03Mi=keGNd07Eoo`03001oogoo00Moo`40005oo`5oo`00@Goo00H0
07ooOomBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeB
oE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@0<EaaG7ELMGcaK?5llFcaO?5/lGcaK?6]k0VMk00A_
NVnJJgY_NP9cV@=gV00:NkMgUW^eNiEk]7^DNkEkU7^cNi<2Ni8017^CNi9kTW^B17^c00=k]7^eOol0
MGoo00<007ooOol01goo0@000Goo0Goo0012Ool20000K7ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5LMDaaG?E<LEaeG75/m
EaaO?E/lGeeK?5lmGcaSG5llHea[NVnKJgY_VVmiLiYcV7NhLiMk]gNFNkEkUG^gMiIk]G^DOkAkTgnc
Ni9o/g^BNk=kTP=k/`04Ni9k]7NdNkEgOol00`00Oomoo`06Ool10001Ool1Ool004Aoo`05001ooe;m
Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC
7E;m25<M00QG7ELLEceG75LMEaaG?Ell0emL00IO?5mLHeaWG6=KHe`3LiT3MiP027NFNkMgV7NHMiIk
Ug^ENk@2Ni<00g^BNkAkT`02Ni801g^bNi9kTW^CNkAk/g^e07Uoo`03001oogoo00Eoo`40005oo`5o
o`00AGoo06d007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMD_aK?ELLFceG75/mEaaK?EllHeaO?6MLHe]WO6=KIeaWFf]k
Ie]g^7>GMkQ_VG>ILiMg^7NFNkMkUG^fNiAo/g^DOkAkTgncNi9o/g^BOk=kTP02Nk<00g^eMkAoo`1h
Ool00`00Oomoo`05Ool10001Ool1Ool004Ioo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00iG7E<MEaeC7ELMEaaG7ELL
FceK?5/mFcaK?E/l0V=L00IWG6=KHeaWNf]kIg/2KgX016nJLiUcVG>I0WNH00=kUgNFNkD00W^D00Ik
UG^dNiAkTg^BNk83Ni82Nk<00g^dNkEoo`1jOol00`00Oomoo`04Ool10001Ool1Ool004Moo`80001/
OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aG7E;lDaeBo5LM
DaaG7E;lEaeC75LMEaaK?ELLFceG75/mEaaO?E/lIgaSFf]kIe][NfMKKiY[NVnKKiUcVFmiMkQcV7^g
MiIk]W^ENkAkTgndNiAo/g^BOk=kTWncNi9o/g^BNkAkTW^cO7oo00<007ooOol00goo0@000Goo0Goo
0019Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC7E;m
DaeBo@=C7@05D_eC7E<MEaeG7003Ead02E/lFceK?5/mFcaO?5/lGcaK?002Ig/01F]kIg]_NVmjKiX0
0g>I0gNH00=gUW^eNiD00W^D00=k]G^DNi@00W^C00QkTW^CNi9k/W^BNkAkTW^cOWoo00<007ooOol0
0goo0@000Goo001:Ool0JP00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7Dkl
DaeBo5<MC_aG7E;lDaeBo5LMD_aG7E<LEceC75LMDaaOGE/lGceK?5mMFcaSG5llHeaO?6nJJgY_VfnI
LiU_NGNhLiQg^7NFNkMkUG^eMiIk]g^DNkAkU7ncNi9o/g^COk=kTW^cNi9k/g^BOWoo00<007ooOol0
0goo0@000Goo001;Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;m
D_eC7E;mDaeBoE<MD_d6Dad025LMEaaG7ELLEceG75llFc`2Gc`3Ge`015llHeaSG6ML17>I0gNH00Ik
]gNHMiQgUW^gNiD2Ni@00g^cNi9kU002Ni<3Ni800g^bNi9oo`1oOol00`00Oomoo`02Ool10001Ool0
04aoo`80001UDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeB
o5LMD_aG7E;lFceG75/mEaaK?ELLFceO?6=LGcaSG5llIeaSFfMlIe][NfMKJg]cV7NhLiMcVW>HMkQc
Ug^gMiIk]G^DOkAkTg^dNi=o/g^BNk=kTWncNi9k/`21Ool01@00Oomoogoo00000Goo001>Ool00`00
Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m01MC7E;mDaeBoE<MD_eC7E;mDaeBoELMDaeG
7E<MEaeC7ELmEaaG7ELLFceK?5/m009OG004He]SG6=LIe`3Ig/016]kJgY_NVmj0W>I0WNH00Uk]gNF
NkEkU7^dNi=k]G^DNk<00g^B00=kTg^BNk<0Pgoo00@007ooOol0005oo`00Cgoo06<007ooC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMDaaG7E;lEaeC75/mEaaK?ELL
FceG75/mHe]WG6=KIgaWFf]kIe][Nf]jKiY[NW>JKiUg^7>GMkQgUW^gNiEo]7^DNkEkU7ncNi=o/g^B
Ok=kTW^cNi80Pgoo00@007ooOol0005oo`00D7oo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;m
DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMEa`00ULM00UK?E/lFceK?5llFcaO?5/lGc`0
0fMk00A[Nf]jKgY_NP=cV@9gV009MiIkUg^ENkAkU7^eNiEk]7^C009kTP04Nk=kTW^BNi>5Ool00`00
Ool00001Ool0055oo`80001NC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;l
EaeBo5LMDaaG7E<LEceC75LMFcaOGE/lGceK?5mMGcaSG5llHea[NVnJJgYcVVnILiUcUgNhMiIk]gNF
NkIgUW^gNiEo]7^DOk=kTWndNi=o/g^BNk>6Ool10001Ool1000005=oo`06001>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eB
oE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@MC7@9G7@09EaaG7ELLEceK?5llFcaOG5ll00=OG003He]S
G6=L00AcV@9gV00<NiMgUWNHMiQkUg^ENkEkU7^CNi9k]7^C0W^B00=k/g^BOol0QWoo0P00001DOol0
G000OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMEaaK?ELLFceG
75/mEaaSG5llHeaO?6=LHe]WG6=KJg]WFf]kIe]g^7>HLiU_NGNhLiQk]gNFNkIkUG^dNi=o]7^DOk=k
TWncNi:8Ool2000005Eoo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@9C
7@0<EaeC7ELMDaeG7ELLEceG75LMFcaK?E/L0UmL00EWG6=KHeaSG6]k00=WN`03KiY[NW>I009cV@9g
V007MiIk]G^ENiAkTg^eNi@017^C00=kTWooOol0QWoo0P00001FOol0F@00OomoodkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEaeBo5LMEaaK?ELLFceG75/mEaaWO6=KIeaSFf]kIe][
NfMKKi][NW>IKgUcVW>HMkQgUW^gNiEk]G^DNkIkU7^dNi=o/g^BOk<0QGoo10000Woo001GOol20000
17ooD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeBo@03Ead035LLEaeK?5/mFaaK?E/l
GcaK?5llFca[N`9WN`04KgY_VV]jKgX2LiT3MiP037^gNiEk]G^DNkMkUG^DNi=k/g^BNi=kTX5oo`@0
00Ioo`00FGoo05H007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LmEaaG7E<LEceG
75lmFcaOGE/lGceK?6=LGcaSG6]jKi][NVnJKgUcVW>HMkQcUg^gMiIk]G^ENkMkUG^dNiAo/g^BNkAk
TgncOGoo10002Woo001JOol01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@MC7@0:EaaG7ELMEaeG
75LMEaaO?5/lGc`2Ge`01UllGeaSFfMLHe]SG0=cV@=gV00:MiIgV7NHNkMgUW^eNiAk/g^CNi@2Ni=j
Ool4000>Ool005]oo`1C001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMEaaK?ELLFceG
75/mEaaSG5llHeaO?6MLHe]WO6=KIeaWFf]kIe]g^7>GMkQ_VGNhLiMg^7NFNkIkU7ndNi=k]W^DOk=k
TP1fOol4000BOol005aoo`800003OomC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0FDaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mEaeC7ELMDaeG7ELL
EaeG75LmFa`2Fc`02U/mFaaSG6=KIeaSFf=LIg][NfMk0Vmj00=_VW>ILiT00WNH00UgUW^GNiEk]7^C
NkEkU7^cNi80M7oo0`005Woo001NOol0C`00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5LMD_aG7E<LEaeB
o5/mEaaK?ELLFceG75lmFcaWO6=KJg]WFf]kIe]_VV]jKi]_VG>ILiMg^7NFNkMkUGndNiAk]W^EOkAk
Tgnc071oo`@001Uoo`00Ggoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM00UG75/l
FcaK?E/lGcaK?5llFc`00VMk00E[NfMkKgY_NVnJ009cV@9gV00;MiIkUgNFNkEgUWNGNiEk]7^DNi=k
U01/Ool4000MOol0061oo`1<001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LEceK?5lm
FcaOGEllHeaO?6=LGca_VV]jKi]_VG>IKgUg^7>HNkMgUW^fLiQk]g^ENkIkU7ncNi9YOol4000QOol0
065oo`800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:
DaeBoE;mD_eC7E;mDaeBoE<MD_d7Dad02ELLEaeG75LmEaaG7ELLGeaO?003Ge`015llHeaSFfML0g>I
0WNH00]kUgNFNkMgV7NGMiIk]G^ENiAkTg^d06Eoo`@002Eoo`00Hgoo04P005<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LM
D_aG7E<LEaeG75/mEaaK?ELLFceG76=LGcaSG6=KIeaSFfMlIe][NfMKKi][NW>IKgUcVW>HMkQgUW^f
NiEk]7^CNkISOol3000YOol006Aoo`03001C7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad01ULMDaeG7E<MEaeC7@9K?009
FceK75/lFcaK?F=KHeaSFfML00=WN`03KiY[NW>I009cV@9gV007MiIk]g^ENkEkU7^eNi@0Ggoo1000
;7oo001UOol0AP00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklEaeBo5<MD_aG7E<LEaeBo5LMEaaG7E<LFceG75/mEaaOGE/lGceSFfMlIe][NfMK
Jg][NVnJKgUcVVnIMkQcUg^gNiEk]W^DNkMkUG^dFgoo1000<7oo001VOol200001DkmD_eBoE<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC
7ELMEa`00eLM00QG75llFcaO?5/lGcaK?5ll0fMk00=[Nf]jKgX00g>I0WNH00Mk]gNFNkEkUG^gNiEk
U01HOol4000dOol006Qoo`12001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E;lEaeC75LmEaaK?ELLGeeK?5lmFcaSG5llHeaO?6=L
JgY_VVmiLiY_VGNhLiMg^7NFMiQcUg^gMiIk]W^DE7oo1000>7oo001YOol01P00OomBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m1U<M00MG?ELLEaeG
75LmEaaG7@02Ge`02EllGeaOG5mLHe]SG6MkJg]WN`03MiP01g>IMiQgV7NHMiIk]G^D055oo`@003ao
o`00JWoo03l007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
DaeBo5<MD_aC7E<LEaeBo5LMDaaK?ELLFceG75/mEaaK?EllHeaO?6MlHe]WG6MKJg]WFfnJJgY_VfnI
LiUcUgNhMiIk]gNEOk@0CWoo0`00@7oo001[Ool20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@9C7@06EaeC7ELMDaeG7E/L0U/l00YK?E/LFcaS
FfMLHe]SG6MkJg]WN`9_NP03KiYcVG>I009gV005MiIgUg^ENkAgUP1:Ool40013Ool006eoo`0k001o
odkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aG7E;lDaeBo5LMDaaG
7E;lEceG75LMEaaK?ELLGceK?5mMFcaO?FMKJg]WFfnJJgY_Vf]jLiUcUgNhMiIk]gNFNkIgUP17Ool4
0017Ool006ioo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeB
oE<MD_d3Dad01E;mEaeG7ELMEa`00eLM00IK?5llFcaO?5/lGc`2Ge`01EllKgY_NVnJJgX00W>I0WNH
00EgUgNFMiQgUWNG04=oo`@004]oo`00Kgoo03P007ooOomC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeBo5/mEaaK?ELLFceK?5mMFcaSG5llHeaO?6MLHe]W
O6=KLiU_NGNhLiQcVFmiMkQcV7^g@7oo1000Cgoo001`Ool200000gooDae>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@08DaeBoE;mD_eC7E;mDaeBo@IC7@08EaeC7ELmEaaG7ELLEceG70=OG005He]SG6=KIeaS
F`02Ig/00fnJJgYcV@02LiT00gNHMiMgUP0mOol3001COol0079oo`0d001>oE<MC_aC7DkmDae>o5<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LFceG75/mEaaK?ELLFceSFfML
He]WO6MKJg]WFfnKJgYcVFmiLiYcV7NHMiHjOol4001FOol007=oo`04001BoE<MC_d2D_d01E<MC_eB
oE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mEaeC7ELMEa`00ULM00UK?E/LFcaK?5llFcaO?5/l
Jg/00fMk00=_VV]jKgX00W>I0WNH00=gUW^gOol0=Goo1000FWoo001dOol0<@00C_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lDaeBo5LmEaaG7E<LEceG75LMFcaOGE/lGceK?6=L
GcaSG5llKi][NVnJKgUcVVnIMiQcUg^g03=oo`@005ioo`00MGoo0P0000EC7DkmD_eBoE<M00=Bo@08
DaeBoE;mD_eC7E;mDaeBo@IC7@=G7@06EaaG7ELLEceK?5ll0UmL00IO?5mLGeaWG6=KHe`3LiT2MiP0
0g^gMiIoo`0^Ool4001ROol007Moo`0]001C7DklDae>oE<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<M
D_aG7E;lEaeBo5LMEaaK?ELLFceG75/mGcaSG5llHeaSFfMlHe]WG6MKJg]WFfnJJgYcVVnI02aoo`@0
06Ioo`00N7oo00<005<MC_d00U;m01IC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;mEaeC7ELMDaeG
7ELLEceG709K?00:FceK75/lHe]WG6=KHeaWNf]kIg/2KgX3LiTYOol3001ZOol007Uoo`0Z001C7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LMEaaK?ELLFceG75lmFcaOGF=K
IeaWFf]kIe]_VV]jKi]_VG>I9Woo1000KGoo001jOol00`00OomBo@02D_d02U<MD_eC7E;mDaeBoE<M
D_eC7E;m0e<M00EBoELMEaeG7ELL00=G7@09FcaO?5/lGcaK?5llIg][NfMk009_NP03KiYcVG>I02=o
o`@0075oo`00Ngoo0P0002E>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEceG75LMDaaK
?ELLFceK?5mMFcaSG5llHeaO?6nJJgY_VfnILiU_N@0OOol4001eOol007eoo`0<001BoE;mD_eC7E;m
DaeBoE<MD_eC7E;m1e<M00MG75LmEaaG7ELLEceO?003Ge`016=KHeaSFfML0fMk77oo1000NGoo001n
Ool08P00C_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LMEaaK?ELLFceG75/mEaaWO6=K
IeaSFfMlIe][NfMK6Goo1000OGoo001oOol02P00OomC7E;mDaeBoE<MD_eC7E;m0e<M00UC75LMDaeG
7E<LEaeK?5/mFa`00U/l00EO?5/lHeaSFfML00=WNaMoo`<0085oo`00P7oo0P0001aC7DklDae>o5<M
D_aC7E;lEaeBo5<MD_aG?ELLEaeC75LmEaaK?E/lGeeK?5lmFcaOGFMKJg]WFaAoo`@008Aoo`00PWoo
00D005<MD_eC7E;m00=C7@03D_eC7E<M009C7@=G7@0;EaaG7E/lGcaK?5llFcaOG5llGeaO?00AOol4
0028Ool008=oo`0I001C7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/mEaaK?EllHeaO?6=L
Gc`03Woo1000S7oo0024Ool04@00OomBoE<MD_eC7E;mDaeC75LMDaeG7E<LEaeG75LmEa`00U/l00=K
?EllGe`037oo1000T7oo0025Ool200004U;lDaeBo5LMD_aC7E;lEaeC75LMD_aG7ELLFceG75/mEaaK
?@Yoo`<009Aoo`00Qgoo00@005<MDaeBo@=C7@09D_eG7ELMEaeG75LMFcaK?E/L00Qoo`@009Moo`00
R7oo00d005;lDaeBo5LMD_aG7E;lEceG75LMDaaG?@06Ool4002KOol008Uoo`03001ooe<M00EC7@Io
o`@009moo`00RWoo0P0000=oo`00Ool017oo1000Xgoo002<Ool200000goo00000002002WOol008eo
o`800:]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo
>goo003oOolkOol00001\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.658 .77 .932 r
.38975 .79854 .39808 .80512 .412 .80088 .4037 .79442 Mtetra
.669 .777 .93 r
.4037 .79442 .412 .80088 .42599 .79608 .41774 .7899 Mtetra
.689 .789 .927 r
.41774 .7899 .42599 .79608 .44008 .79029 .43186 .78463 Mtetra
.722 .81 .919 r
.43186 .78463 .44008 .79029 .45425 .78268 .44608 .778 Mtetra
.775 .841 .902 r
.44608 .778 .45425 .78268 .46852 .77193 .46039 .76896 Mtetra
.844 .879 .866 r
.46039 .76896 .46852 .77193 .48287 .75609 .47479 .75586 Mtetra
.915 .91 .802 r
.47479 .75586 .48287 .75609 .49725 .73306 .48925 .73655 Mtetra
.962 .923 .718 r
.48925 .73655 .49725 .73306 .51158 .70215 .50371 .70937 Mtetra
.977 .92 .64 r
.50371 .70937 .51158 .70215 .52577 .66602 .51807 .6751 Mtetra
.975 .918 .6 r
.51807 .6751 .52577 .66602 .53977 .63052 .53225 .63832 Mtetra
.969 .929 .62 r
.53225 .63832 .53977 .63052 .55364 .60104 .54626 .60521 Mtetra
.957 .947 .703 r
.54626 .60521 .55364 .60104 .56747 .57941 .56018 .57955 Mtetra
.916 .938 .805 r
.56018 .57955 .56747 .57941 .58133 .56446 .5741 .56141 Mtetra
.844 .892 .873 r
.5741 .56141 .58133 .56446 .59527 .55406 .58809 .54892 Mtetra
.774 .838 .9 r
.58809 .54892 .59527 .55406 .60931 .54641 .60216 .54002 Mtetra
.726 .797 .908 r
.60216 .54002 .60931 .54641 .62343 .54032 .61632 .53321 Mtetra
.698 .772 .909 r
.61632 .53321 .62343 .54032 .63763 .53507 .63057 .52755 Mtetra
.682 .758 .909 r
.63057 .52755 .63763 .53507 .65192 .53026 .6449 .5225 Mtetra
.673 .75 .909 r
.6449 .5225 .65192 .53026 .66629 .52567 .65931 .51777 Mtetra
.669 .746 .908 r
.65931 .51777 .66629 .52567 .68073 .52119 .6738 .51319 Mtetra
.666 .744 .908 r
.6738 .51319 .68073 .52119 .69525 .51676 .68838 .50869 Mtetra
.665 .743 .908 r
.68838 .50869 .69525 .51676 .70984 .51234 .70302 .50421 Mtetra
.664 .742 .908 r
.70302 .50421 .70984 .51234 .72452 .50792 .71775 .49974 Mtetra
.71775 .49974 .72452 .50792 .73927 .50348 .73255 .49526 Mtetra
.664 .741 .908 r
.73255 .49526 .73927 .50348 .75409 .49903 .74743 .49076 Mtetra
.74743 .49076 .75409 .49903 .76899 .49456 .76238 .48624 Mtetra
.76238 .48624 .76899 .49456 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.655 .768 .932 r
.38133 .79185 .38975 .79854 .4037 .79442 .39533 .78781 Mtetra
.663 .773 .931 r
.39533 .78781 .4037 .79442 .41774 .7899 .40941 .78347 Mtetra
.678 .782 .929 r
.40941 .78347 .41774 .7899 .43186 .78463 .42357 .77858 Mtetra
.704 .798 .924 r
.42357 .77858 .43186 .78463 .44608 .778 .43783 .77268 Mtetra
.746 .824 .912 r
.43783 .77268 .44608 .778 .46039 .76896 .45217 .76495 Mtetra
.808 .859 .887 r
.45217 .76495 .46039 .76896 .47479 .75586 .46662 .75405 Mtetra
.881 .896 .837 r
.46662 .75405 .47479 .75586 .48925 .73655 .48114 .73803 Mtetra
.942 .919 .761 r
.48114 .73803 .48925 .73655 .50371 .70937 .49571 .71477 Mtetra
.973 .923 .676 r
.49571 .71477 .50371 .70937 .51807 .6751 .51022 .68358 Mtetra
.977 .918 .614 r
.51022 .68358 .51807 .6751 .53225 .63832 .52459 .64713 Mtetra
.972 .921 .602 r
.52459 .64713 .53225 .63832 .54626 .60521 .53877 .61132 Mtetra
.965 .939 .655 r
.53877 .61132 .54626 .60521 .56018 .57955 .55281 .58158 Mtetra
.942 .948 .756 r
.55281 .58158 .56018 .57955 .5741 .56141 .5668 .55974 Mtetra
.882 .918 .845 r
.5668 .55974 .5741 .56141 .58809 .54892 .58084 .54462 Mtetra
.807 .864 .89 r
.58084 .54462 .58809 .54892 .60216 .54002 .59495 .53409 Mtetra
.748 .815 .905 r
.59495 .53409 .60216 .54002 .61632 .53321 .60915 .52632 Mtetra
.71 .783 .909 r
.60915 .52632 .61632 .53321 .63057 .52755 .62344 .52012 Mtetra
.688 .764 .909 r
.62344 .52012 .63057 .52755 .6449 .5225 .63781 .51475 Mtetra
.677 .753 .909 r
.63781 .51475 .6449 .5225 .65931 .51777 .65227 .50984 Mtetra
.671 .748 .908 r
.65227 .50984 .65931 .51777 .6738 .51319 .66682 .50514 Mtetra
.667 .745 .908 r
.66682 .50514 .6738 .51319 .68838 .50869 .68144 .50056 Mtetra
.665 .743 .908 r
.68144 .50056 .68838 .50869 .70302 .50421 .69613 .49602 Mtetra
.665 .742 .908 r
.69613 .49602 .70302 .50421 .71775 .49974 .71091 .49149 Mtetra
.664 .742 .908 r
.71091 .49149 .71775 .49974 .73255 .49526 .72577 .48696 Mtetra
.72577 .48696 .73255 .49526 .74743 .49076 .7407 .48241 Mtetra
.664 .741 .908 r
.7407 .48241 .74743 .49076 .76238 .48624 .75571 .47785 Mtetra
.75571 .47785 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.653 .767 .933 r
.37284 .78506 .38133 .79185 .39533 .78781 .38688 .78107 Mtetra
.658 .77 .932 r
.38688 .78107 .39533 .78781 .40941 .78347 .401 .77685 Mtetra
.669 .777 .93 r
.401 .77685 .40941 .78347 .42357 .77858 .41521 .77223 Mtetra
.689 .789 .927 r
.41521 .77223 .42357 .77858 .43783 .77268 .4295 .76686 Mtetra
.722 .81 .919 r
.4295 .76686 .43783 .77268 .45217 .76495 .44389 .76012 Mtetra
.775 .841 .902 r
.44389 .76012 .45217 .76495 .46662 .75405 .45837 .75094 Mtetra
.844 .879 .866 r
.45837 .75094 .46662 .75405 .48114 .73803 .47295 .73767 Mtetra
.915 .91 .802 r
.47295 .73767 .48114 .73803 .49571 .71477 .48759 .71816 Mtetra
.962 .923 .717 r
.48759 .71816 .49571 .71477 .51022 .68358 .50224 .69071 Mtetra
.977 .92 .64 r
.50224 .69071 .51022 .68358 .52459 .64713 .51678 .65614 Mtetra
.975 .918 .6 r
.51678 .65614 .52459 .64713 .53877 .61132 .53115 .61904 Mtetra
.969 .929 .62 r
.53115 .61904 .53877 .61132 .55281 .58158 .54533 .58564 Mtetra
.957 .947 .703 r
.54533 .58564 .55281 .58158 .5668 .55974 .55943 .55974 Mtetra
.916 .938 .806 r
.55943 .55974 .5668 .55974 .58084 .54462 .57352 .54142 Mtetra
.844 .892 .873 r
.57352 .54142 .58084 .54462 .59495 .53409 .58767 .52878 Mtetra
.774 .837 .9 r
.58767 .52878 .59495 .53409 .60915 .52632 .60191 .51975 Mtetra
.726 .797 .908 r
.60191 .51975 .60915 .52632 .62344 .52012 .61624 .51282 Mtetra
.698 .772 .909 r
.61624 .51282 .62344 .52012 .63781 .51475 .63066 .50704 Mtetra
.682 .758 .909 r
.63066 .50704 .63781 .51475 .65227 .50984 .64517 .50188 Mtetra
.673 .75 .909 r
.64517 .50188 .65227 .50984 .66682 .50514 .65976 .49704 Mtetra
.669 .746 .908 r
.65976 .49704 .66682 .50514 .68144 .50056 .67443 .49236 Mtetra
.666 .744 .908 r
.67443 .49236 .68144 .50056 .69613 .49602 .68918 .48775 Mtetra
.665 .743 .908 r
.68918 .48775 .69613 .49602 .71091 .49149 .70401 .48316 Mtetra
.664 .742 .908 r
.70401 .48316 .71091 .49149 .72577 .48696 .71892 .47858 Mtetra
.71892 .47858 .72577 .48696 .7407 .48241 .73391 .47398 Mtetra
.664 .741 .908 r
.73391 .47398 .7407 .48241 .75571 .47785 .74897 .46937 Mtetra
.74897 .46937 .75571 .47785 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.651 .765 .933 r
.36426 .77817 .37284 .78506 .38688 .78107 .37835 .77421 Mtetra
.655 .768 .932 r
.37835 .77421 .38688 .78107 .401 .77685 .39251 .77007 Mtetra
.663 .773 .931 r
.39251 .77007 .401 .77685 .41521 .77223 .40676 .76564 Mtetra
.678 .782 .929 r
.40676 .76564 .41521 .77223 .4295 .76686 .42109 .76064 Mtetra
.704 .798 .924 r
.42109 .76064 .4295 .76686 .44389 .76012 .43552 .75463 Mtetra
.746 .824 .912 r
.43552 .75463 .44389 .76012 .45837 .75094 .45004 .74678 Mtetra
.808 .86 .887 r
.45004 .74678 .45837 .75094 .47295 .73767 .46467 .73573 Mtetra
.881 .897 .837 r
.46467 .73573 .47295 .73767 .48759 .71816 .47937 .71952 Mtetra
.942 .919 .761 r
.47937 .71952 .48759 .71816 .50224 .69071 .49412 .69603 Mtetra
.973 .923 .676 r
.49412 .69603 .50224 .69071 .51678 .65614 .50883 .66454 Mtetra
.977 .918 .613 r
.50883 .66454 .51678 .65614 .53115 .61904 .52338 .62777 Mtetra
.972 .921 .602 r
.52338 .62777 .53115 .61904 .54533 .58564 .53774 .59165 Mtetra
.965 .939 .656 r
.53774 .59165 .54533 .58564 .55943 .55974 .55196 .56165 Mtetra
.942 .947 .756 r
.55196 .56165 .55943 .55974 .57352 .54142 .56613 .5396 Mtetra
.882 .918 .845 r
.56613 .5396 .57352 .54142 .58767 .52878 .58033 .52431 Mtetra
.807 .864 .89 r
.58033 .52431 .58767 .52878 .60191 .51975 .59461 .51363 Mtetra
.748 .815 .905 r
.59461 .51363 .60191 .51975 .61624 .51282 .60898 .50574 Mtetra
.71 .783 .909 r
.60898 .50574 .61624 .51282 .63066 .50704 .62345 .49941 Mtetra
.689 .764 .909 r
.62345 .49941 .63066 .50704 .64517 .50188 .638 .49394 Mtetra
.677 .753 .909 r
.638 .49394 .64517 .50188 .65976 .49704 .65264 .48891 Mtetra
.671 .748 .908 r
.65264 .48891 .65976 .49704 .67443 .49236 .66736 .48411 Mtetra
.667 .745 .908 r
.66736 .48411 .67443 .49236 .68918 .48775 .68216 .47941 Mtetra
.665 .743 .908 r
.68216 .47941 .68918 .48775 .70401 .48316 .69704 .47476 Mtetra
.665 .742 .908 r
.69704 .47476 .70401 .48316 .71892 .47858 .71201 .47012 Mtetra
.664 .742 .908 r
.71201 .47012 .71892 .47858 .73391 .47398 .72705 .46547 Mtetra
.72705 .46547 .73391 .47398 .74897 .46937 .74217 .46082 Mtetra
.664 .741 .908 r
.74217 .46082 .74897 .46937 .76412 .46474 .75737 .45614 Mtetra
.75737 .45614 .76412 .46474 .77935 .46009 .77266 .45144 Mtetra
.77266 .45144 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Mtetra
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.649 .765 .933 r
.3556 .7712 .36426 .77817 .37835 .77421 .36973 .76724 Mtetra
.653 .767 .933 r
.36973 .76724 .37835 .77421 .39251 .77007 .38394 .76316 Mtetra
.658 .77 .932 r
.38394 .76316 .39251 .77007 .40676 .76564 .39823 .75885 Mtetra
.669 .777 .93 r
.39823 .75885 .40676 .76564 .42109 .76064 .41261 .75412 Mtetra
.689 .789 .927 r
.41261 .75412 .42109 .76064 .43552 .75463 .42707 .74864 Mtetra
.722 .81 .919 r
.42707 .74864 .43552 .75463 .45004 .74678 .44164 .74178 Mtetra
.775 .841 .902 r
.44164 .74178 .45004 .74678 .46467 .73573 .4563 .73247 Mtetra
.844 .879 .866 r
.4563 .73247 .46467 .73573 .47937 .71952 .47106 .71903 Mtetra
.915 .911 .802 r
.47106 .71903 .47937 .71952 .49412 .69603 .4859 .6993 Mtetra
.962 .923 .717 r
.4859 .6993 .49412 .69603 .50883 .66454 .50073 .67159 Mtetra
.977 .92 .64 r
.50073 .67159 .50883 .66454 .52338 .62777 .51547 .63671 Mtetra
.975 .918 .6 r
.51547 .63671 .52338 .62777 .53774 .59165 .53002 .59928 Mtetra
.969 .929 .621 r
.53002 .59928 .53774 .59165 .55196 .56165 .54438 .56559 Mtetra
.957 .946 .703 r
.54438 .56559 .55196 .56165 .56613 .5396 .55865 .53945 Mtetra
.916 .938 .806 r
.55865 .53945 .56613 .5396 .58033 .52431 .57292 .52094 Mtetra
.844 .892 .873 r
.57292 .52094 .58033 .52431 .59461 .51363 .58725 .50814 Mtetra
.774 .837 .9 r
.58725 .50814 .59461 .51363 .60898 .50574 .60166 .49898 Mtetra
.726 .797 .908 r
.60166 .49898 .60898 .50574 .62345 .49941 .61617 .49192 Mtetra
.698 .772 .909 r
.61617 .49192 .62345 .49941 .638 .49394 .63076 .48603 Mtetra
.682 .758 .909 r
.63076 .48603 .638 .49394 .65264 .48891 .64545 .48076 Mtetra
.673 .75 .909 r
.64545 .48076 .65264 .48891 .66736 .48411 .66022 .4758 Mtetra
.669 .746 .908 r
.66022 .4758 .66736 .48411 .68216 .47941 .67507 .47101 Mtetra
.666 .744 .908 r
.67507 .47101 .68216 .47941 .69704 .47476 .69001 .46628 Mtetra
.665 .743 .908 r
.69001 .46628 .69704 .47476 .71201 .47012 .70502 .46158 Mtetra
.664 .742 .908 r
.70502 .46158 .71201 .47012 .72705 .46547 .72012 .45688 Mtetra
.72012 .45688 .72705 .46547 .74217 .46082 .7353 .45217 Mtetra
.664 .741 .908 r
.7353 .45217 .74217 .46082 .75737 .45614 .75056 .44745 Mtetra
.75056 .44745 .75737 .45614 .77266 .45144 .7659 .4427 Mtetra
.7659 .4427 .77266 .45144 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Mtetra
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42347 Mtetra
.8281 .42347 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.648 .764 .933 r
.34686 .76414 .3556 .7712 .36973 .76724 .36103 .76018 Mtetra
.651 .765 .933 r
.36103 .76018 .36973 .76724 .38394 .76316 .37529 .75612 Mtetra
.655 .768 .932 r
.37529 .75612 .38394 .76316 .39823 .75885 .38962 .75189 Mtetra
.663 .773 .931 r
.38962 .75189 .39823 .75885 .41261 .75412 .40404 .74735 Mtetra
.678 .782 .929 r
.40404 .74735 .41261 .75412 .42707 .74864 .41855 .74225 Mtetra
.704 .798 .924 r
.41855 .74225 .42707 .74864 .44164 .74178 .43315 .73612 Mtetra
.746 .824 .912 r
.43315 .73612 .44164 .74178 .4563 .73247 .44786 .72814 Mtetra
.808 .86 .887 r
.44786 .72814 .4563 .73247 .47106 .71903 .46266 .71694 Mtetra
.881 .897 .838 r
.46266 .71694 .47106 .71903 .4859 .6993 .47756 .70054 Mtetra
.942 .92 .761 r
.47756 .70054 .4859 .6993 .50073 .67159 .4925 .67681 Mtetra
.973 .923 .675 r
.4925 .67681 .50073 .67159 .51547 .63671 .5074 .64502 Mtetra
.977 .918 .613 r
.5074 .64502 .51547 .63671 .53002 .59928 .52214 .60793 Mtetra
.972 .921 .602 r
.52214 .60793 .53002 .59928 .54438 .56559 .53669 .5715 Mtetra
.965 .939 .656 r
.53669 .5715 .54438 .56559 .55865 .53945 .55109 .54123 Mtetra
.942 .947 .756 r
.55109 .54123 .55865 .53945 .57292 .52094 .56543 .51896 Mtetra
.882 .918 .845 r
.56543 .51896 .57292 .52094 .58725 .50814 .57981 .50349 Mtetra
.807 .863 .89 r
.57981 .50349 .58725 .50814 .60166 .49898 .59427 .49267 Mtetra
.748 .815 .905 r
.59427 .49267 .60166 .49898 .61617 .49192 .60882 .48465 Mtetra
.71 .783 .909 r
.60882 .48465 .61617 .49192 .63076 .48603 .62346 .4782 Mtetra
.689 .764 .909 r
.62346 .4782 .63076 .48603 .64545 .48076 .63819 .47261 Mtetra
.677 .753 .909 r
.63819 .47261 .64545 .48076 .66022 .4758 .65301 .46747 Mtetra
.671 .748 .908 r
.65301 .46747 .66022 .4758 .67507 .47101 .66792 .46255 Mtetra
.667 .745 .908 r
.66792 .46255 .67507 .47101 .69001 .46628 .6829 .45773 Mtetra
.665 .743 .908 r
.6829 .45773 .69001 .46628 .70502 .46158 .69797 .45297 Mtetra
.665 .742 .908 r
.69797 .45297 .70502 .46158 .72012 .45688 .71313 .44821 Mtetra
.664 .742 .908 r
.71313 .44821 .72012 .45688 .7353 .45217 .72836 .44345 Mtetra
.72836 .44345 .7353 .45217 .75056 .44745 .74368 .43867 Mtetra
.664 .741 .908 r
.74368 .43867 .75056 .44745 .7659 .4427 .75908 .43388 Mtetra
.75908 .43388 .7659 .4427 .78132 .43793 .77456 .42906 Mtetra
.77456 .42906 .78132 .43793 .79683 .43313 .79013 .42421 Mtetra
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42347 .82151 .41445 Mtetra
.82151 .41445 .8281 .42347 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.648 .764 .933 r
.33803 .757 .34686 .76414 .36103 .76018 .35225 .75303 Mtetra
.649 .765 .933 r
.35225 .75303 .36103 .76018 .37529 .75612 .36655 .74898 Mtetra
.653 .767 .933 r
.36655 .74898 .37529 .75612 .38962 .75189 .38093 .7448 Mtetra
.658 .77 .932 r
.38093 .7448 .38962 .75189 .40404 .74735 .39539 .74038 Mtetra
.669 .777 .93 r
.39539 .74038 .40404 .74735 .41855 .74225 .40994 .73555 Mtetra
.689 .789 .927 r
.40994 .73555 .41855 .74225 .43315 .73612 .42459 .72996 Mtetra
.722 .81 .919 r
.42459 .72996 .43315 .73612 .44786 .72814 .43933 .72297 Mtetra
.775 .841 .902 r
.43933 .72297 .44786 .72814 .46266 .71694 .45418 .71352 Mtetra
.844 .879 .866 r
.45418 .71352 .46266 .71694 .47756 .70054 .46913 .69991 Mtetra
.915 .911 .802 r
.46913 .69991 .47756 .70054 .4925 .67681 .48415 .67997 Mtetra
.962 .923 .717 r
.48415 .67997 .4925 .67681 .5074 .64502 .49919 .65198 Mtetra
.977 .92 .639 r
.49919 .65198 .5074 .64502 .52214 .60793 .51412 .61678 Mtetra
.975 .918 .6 r
.51412 .61678 .52214 .60793 .53669 .5715 .52886 .57903 Mtetra
.969 .929 .621 r
.52886 .57903 .53669 .5715 .55109 .54123 .54341 .54504 Mtetra
.957 .946 .704 r
.54341 .54504 .55109 .54123 .56543 .51896 .55786 .51866 Mtetra
.916 .938 .806 r
.55786 .51866 .56543 .51896 .57981 .50349 .57231 .49995 Mtetra
.844 .891 .873 r
.57231 .49995 .57981 .50349 .59427 .49267 .58681 .48699 Mtetra
.774 .837 .9 r
.58681 .48699 .59427 .49267 .60882 .48465 .6014 .47769 Mtetra
.726 .797 .908 r
.6014 .47769 .60882 .48465 .62346 .4782 .61609 .47051 Mtetra
.698 .772 .909 r
.61609 .47051 .62346 .4782 .63819 .47261 .63087 .4645 Mtetra
.682 .758 .909 r
.63087 .4645 .63819 .47261 .65301 .46747 .64573 .45911 Mtetra
.673 .75 .909 r
.64573 .45911 .65301 .46747 .66792 .46255 .66069 .45403 Mtetra
.669 .746 .908 r
.66069 .45403 .66792 .46255 .6829 .45773 .67573 .44912 Mtetra
.666 .744 .908 r
.67573 .44912 .6829 .45773 .69797 .45297 .69086 .44428 Mtetra
.665 .743 .908 r
.69086 .44428 .69797 .45297 .71313 .44821 .70606 .43946 Mtetra
.664 .742 .908 r
.70606 .43946 .71313 .44821 .72836 .44345 .72135 .43464 Mtetra
.72135 .43464 .72836 .44345 .74368 .43867 .73673 .42981 Mtetra
.664 .741 .908 r
.73673 .42981 .74368 .43867 .75908 .43388 .75218 .42497 Mtetra
.75218 .42497 .75908 .43388 .77456 .42906 .76773 .4201 Mtetra
.76773 .4201 .77456 .42906 .79013 .42421 .78335 .4152 Mtetra
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41029 Mtetra
.79906 .41029 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.647 .763 .934 r
.32911 .74979 .33803 .757 .35225 .75303 .34338 .7458 Mtetra
.648 .764 .933 r
.34338 .7458 .35225 .75303 .36655 .74898 .35772 .74174 Mtetra
.651 .765 .933 r
.35772 .74174 .36655 .74898 .38093 .7448 .37215 .73758 Mtetra
.655 .768 .932 r
.37215 .73758 .38093 .7448 .39539 .74038 .38666 .73324 Mtetra
.663 .773 .931 r
.38666 .73324 .39539 .74038 .40994 .73555 .40126 .7286 Mtetra
.678 .782 .929 r
.40126 .7286 .40994 .73555 .42459 .72996 .41594 .72339 Mtetra
.704 .798 .924 r
.41594 .72339 .42459 .72996 .43933 .72297 .43073 .71714 Mtetra
.746 .824 .912 r
.43073 .71714 .43933 .72297 .45418 .71352 .44562 .70903 Mtetra
.808 .86 .887 r
.44562 .70903 .45418 .71352 .46913 .69991 .46061 .69767 Mtetra
.881 .897 .838 r
.46061 .69767 .46913 .69991 .48415 .67997 .4757 .68107 Mtetra
.942 .92 .76 r
.4757 .68107 .48415 .67997 .49919 .65198 .49084 .6571 Mtetra
.973 .923 .675 r
.49084 .6571 .49919 .65198 .51412 .61678 .50593 .62501 Mtetra
.977 .918 .613 r
.50593 .62501 .51412 .61678 .52886 .57903 .52088 .58758 Mtetra
.972 .921 .602 r
.52088 .58758 .52886 .57903 .54341 .54504 .53561 .55084 Mtetra
.965 .939 .656 r
.53561 .55084 .54341 .54504 .55786 .51866 .55019 .52029 Mtetra
.942 .947 .756 r
.55019 .52029 .55786 .51866 .57231 .49995 .56472 .4978 Mtetra
.882 .918 .845 r
.56472 .4978 .57231 .49995 .58681 .48699 .57928 .48216 Mtetra
.807 .863 .89 r
.57928 .48216 .58681 .48699 .6014 .47769 .59392 .47119 Mtetra
.748 .815 .905 r
.59392 .47119 .6014 .47769 .61609 .47051 .60864 .46303 Mtetra
.71 .783 .909 r
.60864 .46303 .61609 .47051 .63087 .4645 .62347 .45646 Mtetra
.689 .764 .909 r
.62347 .45646 .63087 .4645 .64573 .45911 .63839 .45075 Mtetra
.677 .753 .909 r
.63839 .45075 .64573 .45911 .66069 .45403 .65339 .44548 Mtetra
.671 .748 .908 r
.65339 .44548 .66069 .45403 .67573 .44912 .66849 .44044 Mtetra
.667 .745 .908 r
.66849 .44044 .67573 .44912 .69086 .44428 .68367 .43551 Mtetra
.665 .743 .908 r
.68367 .43551 .69086 .44428 .70606 .43946 .69893 .43063 Mtetra
.665 .742 .908 r
.69893 .43063 .70606 .43946 .72135 .43464 .71428 .42575 Mtetra
.664 .742 .908 r
.71428 .42575 .72135 .43464 .73673 .42981 .72971 .42087 Mtetra
.72971 .42087 .73673 .42981 .75218 .42497 .74522 .41597 Mtetra
.664 .741 .908 r
.74522 .41597 .75218 .42497 .76773 .4201 .76082 .41105 Mtetra
.76082 .41105 .76773 .4201 .78335 .4152 .77651 .40611 Mtetra
.77651 .40611 .78335 .4152 .79906 .41029 .79228 .40114 Mtetra
.79228 .40114 .79906 .41029 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38607 Mtetra
.84012 .38607 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.647 .763 .934 r
.3201 .7425 .32911 .74979 .34338 .7458 .33442 .73848 Mtetra
.648 .764 .933 r
.33442 .73848 .34338 .7458 .35772 .74174 .34881 .7344 Mtetra
.649 .765 .933 r
.34881 .7344 .35772 .74174 .37215 .73758 .36328 .73025 Mtetra
.653 .767 .933 r
.36328 .73025 .37215 .73758 .38666 .73324 .37784 .72596 Mtetra
.658 .77 .932 r
.37784 .72596 .38666 .73324 .40126 .7286 .39248 .72144 Mtetra
.669 .777 .93 r
.39248 .72144 .40126 .7286 .41594 .72339 .40721 .7165 Mtetra
.689 .789 .927 r
.40721 .7165 .41594 .72339 .43073 .71714 .42204 .71079 Mtetra
.722 .81 .919 r
.42204 .71079 .43073 .71714 .44562 .70903 .43697 .70368 Mtetra
.775 .841 .902 r
.43697 .70368 .44562 .70903 .46061 .69767 .45201 .69409 Mtetra
.845 .879 .866 r
.45201 .69409 .46061 .69767 .4757 .68107 .46715 .6803 Mtetra
.915 .911 .802 r
.46715 .6803 .4757 .68107 .49084 .6571 .48237 .66013 Mtetra
.962 .924 .717 r
.48237 .66013 .49084 .6571 .50593 .62501 .4976 .63187 Mtetra
.977 .92 .639 r
.4976 .63187 .50593 .62501 .52088 .58758 .51273 .59635 Mtetra
.975 .918 .6 r
.51273 .59635 .52088 .58758 .53561 .55084 .52767 .55827 Mtetra
.969 .929 .621 r
.52767 .55827 .53561 .55084 .55019 .52029 .54242 .52398 Mtetra
.957 .946 .704 r
.54242 .52398 .55019 .52029 .56472 .4978 .55705 .49735 Mtetra
.916 .937 .806 r
.55705 .49735 .56472 .4978 .57928 .48216 .57168 .47844 Mtetra
.844 .891 .873 r
.57168 .47844 .57928 .48216 .59392 .47119 .58636 .46532 Mtetra
.774 .837 .9 r
.58636 .46532 .59392 .47119 .60864 .46303 .60113 .45587 Mtetra
.726 .797 .908 r
.60113 .45587 .60864 .46303 .62347 .45646 .616 .44856 Mtetra
.698 .772 .909 r
.616 .44856 .62347 .45646 .63839 .45075 .63097 .44242 Mtetra
.682 .758 .909 r
.63097 .44242 .63839 .45075 .65339 .44548 .64603 .43691 Mtetra
.673 .75 .909 r
.64603 .43691 .65339 .44548 .66849 .44044 .66117 .43171 Mtetra
.669 .746 .908 r
.66117 .43171 .66849 .44044 .68367 .43551 .67641 .42668 Mtetra
.666 .744 .908 r
.67641 .42668 .68367 .43551 .69893 .43063 .69172 .42171 Mtetra
.665 .743 .908 r
.69172 .42171 .69893 .43063 .71428 .42575 .70713 .41677 Mtetra
.664 .742 .908 r
.70713 .41677 .71428 .42575 .72971 .42087 .72262 .41183 Mtetra
.72262 .41183 .72971 .42087 .74522 .41597 .73819 .40688 Mtetra
.664 .741 .908 r
.73819 .40688 .74522 .41597 .76082 .41105 .75385 .40191 Mtetra
.75385 .40191 .76082 .41105 .77651 .40611 .7696 .39691 Mtetra
.7696 .39691 .77651 .40611 .79228 .40114 .78543 .39189 Mtetra
.78543 .39189 .79228 .40114 .80814 .39614 .80135 .38684 Mtetra
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38607 .83346 .37667 Mtetra
.83346 .37667 .84012 .38607 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.647 .763 .934 r
.31101 .73513 .3201 .7425 .33442 .73848 .32537 .73108 Mtetra
.32537 .73108 .33442 .73848 .34881 .7344 .33981 .72698 Mtetra
.648 .764 .933 r
.33981 .72698 .34881 .7344 .36328 .73025 .35433 .72282 Mtetra
.651 .765 .933 r
.35433 .72282 .36328 .73025 .37784 .72596 .36893 .71856 Mtetra
.655 .768 .932 r
.36893 .71856 .37784 .72596 .39248 .72144 .38362 .71412 Mtetra
.663 .773 .931 r
.38362 .71412 .39248 .72144 .40721 .7165 .3984 .70936 Mtetra
.678 .782 .929 r
.3984 .70936 .40721 .7165 .42204 .71079 .41327 .70404 Mtetra
.703 .799 .924 r
.41327 .70404 .42204 .71079 .43697 .70368 .42824 .69767 Mtetra
.746 .824 .913 r
.42824 .69767 .43697 .70368 .45201 .69409 .44332 .68942 Mtetra
.808 .86 .887 r
.44332 .68942 .45201 .69409 .46715 .6803 .4585 .6779 Mtetra
.881 .897 .838 r
.4585 .6779 .46715 .6803 .48237 .66013 .47379 .6611 Mtetra
.942 .92 .76 r
.47379 .6611 .48237 .66013 .4976 .63187 .48913 .63687 Mtetra
.973 .923 .675 r
.48913 .63687 .4976 .63187 .51273 .59635 .50443 .60448 Mtetra
.977 .918 .613 r
.50443 .60448 .51273 .59635 .52767 .55827 .51957 .56672 Mtetra
.972 .921 .602 r
.51957 .56672 .52767 .55827 .54242 .52398 .53451 .52965 Mtetra
.965 .938 .656 r
.53451 .52965 .54242 .52398 .55705 .49735 .54928 .49883 Mtetra
.942 .947 .757 r
.54928 .49883 .55705 .49735 .57168 .47844 .56399 .47612 Mtetra
.882 .917 .845 r
.56399 .47612 .57168 .47844 .58636 .46532 .57873 .46029 Mtetra
.807 .863 .89 r
.57873 .46029 .58636 .46532 .60113 .45587 .59355 .44916 Mtetra
.748 .815 .905 r
.59355 .44916 .60113 .45587 .616 .44856 .60847 .44087 Mtetra
.71 .783 .909 r
.60847 .44087 .616 .44856 .63097 .44242 .62348 .43417 Mtetra
.689 .764 .909 r
.62348 .43417 .63097 .44242 .64603 .43691 .63859 .42833 Mtetra
.677 .753 .909 r
.63859 .42833 .64603 .43691 .66117 .43171 .65379 .42294 Mtetra
.671 .748 .908 r
.65379 .42294 .66117 .43171 .67641 .42668 .66907 .41778 Mtetra
.667 .745 .908 r
.66907 .41778 .67641 .42668 .69172 .42171 .68445 .41272 Mtetra
.665 .743 .908 r
.68445 .41272 .69172 .42171 .70713 .41677 .69991 .40771 Mtetra
.665 .742 .908 r
.69991 .40771 .70713 .41677 .72262 .41183 .71546 .40271 Mtetra
.664 .742 .908 r
.71546 .40271 .72262 .41183 .73819 .40688 .73109 .3977 Mtetra
.73109 .3977 .73819 .40688 .75385 .40191 .74681 .39268 Mtetra
.664 .741 .908 r
.74681 .39268 .75385 .40191 .7696 .39691 .76262 .38763 Mtetra
.76262 .38763 .7696 .39691 .78543 .39189 .77851 .38256 Mtetra
.77851 .38256 .78543 .39189 .80135 .38684 .79449 .37746 Mtetra
.79449 .37746 .80135 .38684 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .763 .934 r
.30182 .72769 .31101 .73513 .32537 .73108 .31623 .7236 Mtetra
.647 .763 .934 r
.31623 .7236 .32537 .73108 .33981 .72698 .33072 .71948 Mtetra
.648 .764 .933 r
.33072 .71948 .33981 .72698 .35433 .72282 .34528 .7153 Mtetra
.649 .765 .933 r
.34528 .7153 .35433 .72282 .36893 .71856 .35993 .71104 Mtetra
.653 .767 .933 r
.35993 .71104 .36893 .71856 .38362 .71412 .37467 .70664 Mtetra
.658 .77 .932 r
.37467 .70664 .38362 .71412 .3984 .70936 .38949 .70201 Mtetra
.669 .777 .93 r
.38949 .70201 .3984 .70936 .41327 .70404 .40441 .69696 Mtetra
.689 .789 .927 r
.40441 .69696 .41327 .70404 .42824 .69767 .41942 .69113 Mtetra
.722 .81 .919 r
.41942 .69113 .42824 .69767 .44332 .68942 .43454 .68389 Mtetra
.775 .841 .902 r
.43454 .68389 .44332 .68942 .4585 .6779 .44977 .67414 Mtetra
.845 .88 .866 r
.44977 .67414 .4585 .6779 .47379 .6611 .46511 .66018 Mtetra
.915 .911 .802 r
.46511 .66018 .47379 .6611 .48913 .63687 .48054 .63978 Mtetra
.962 .924 .717 r
.48054 .63978 .48913 .63687 .50443 .60448 .49597 .61124 Mtetra
.977 .92 .639 r
.49597 .61124 .50443 .60448 .51957 .56672 .51131 .57539 Mtetra
.975 .918 .6 r
.51131 .57539 .51957 .56672 .53451 .52965 .52645 .53697 Mtetra
.969 .929 .621 r
.52645 .53697 .53451 .52965 .54928 .49883 .54139 .50238 Mtetra
.957 .946 .704 r
.54139 .50238 .54928 .49883 .56399 .47612 .55622 .47549 Mtetra
.916 .937 .806 r
.55622 .47549 .56399 .47612 .57873 .46029 .57103 .45638 Mtetra
.844 .891 .873 r
.57103 .45638 .57873 .46029 .59355 .44916 .5859 .44309 Mtetra
.774 .837 .9 r
.5859 .44309 .59355 .44916 .60847 .44087 .60086 .43349 Mtetra
.726 .797 .908 r
.60086 .43349 .60847 .44087 .62348 .43417 .61592 .42605 Mtetra
.698 .772 .909 r
.61592 .42605 .62348 .43417 .63859 .42833 .63108 .41978 Mtetra
.682 .758 .909 r
.63108 .41978 .63859 .42833 .65379 .42294 .64633 .41414 Mtetra
.673 .75 .909 r
.64633 .41414 .65379 .42294 .66907 .41778 .66167 .40882 Mtetra
.669 .746 .908 r
.66167 .40882 .66907 .41778 .68445 .41272 .6771 .40366 Mtetra
.666 .744 .908 r
.6771 .40366 .68445 .41272 .69991 .40771 .69262 .39857 Mtetra
.665 .743 .908 r
.69262 .39857 .69991 .40771 .71546 .40271 .70822 .3935 Mtetra
.664 .742 .908 r
.70822 .3935 .71546 .40271 .73109 .3977 .72391 .38843 Mtetra
.72391 .38843 .73109 .3977 .74681 .39268 .73969 .38335 Mtetra
.664 .741 .908 r
.73969 .38335 .74681 .39268 .76262 .38763 .75556 .37825 Mtetra
.75556 .37825 .76262 .38763 .77851 .38256 .77152 .37312 Mtetra
.77152 .37312 .77851 .38256 .79449 .37746 .78756 .36797 Mtetra
.78756 .36797 .79449 .37746 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .763 .934 r
.29254 .72016 .30182 .72769 .31623 .7236 .307 .71604 Mtetra
.647 .763 .934 r
.307 .71604 .31623 .7236 .33072 .71948 .32153 .71188 Mtetra
.32153 .71188 .33072 .71948 .34528 .7153 .33615 .70768 Mtetra
.648 .764 .933 r
.33615 .70768 .34528 .7153 .35993 .71104 .35085 .70341 Mtetra
.651 .765 .933 r
.35085 .70341 .35993 .71104 .37467 .70664 .36563 .69904 Mtetra
.655 .768 .932 r
.36563 .69904 .37467 .70664 .38949 .70201 .3805 .69449 Mtetra
.663 .773 .931 r
.3805 .69449 .38949 .70201 .40441 .69696 .39546 .68962 Mtetra
.678 .782 .929 r
.39546 .68962 .40441 .69696 .41942 .69113 .41052 .68418 Mtetra
.703 .799 .924 r
.41052 .68418 .41942 .69113 .43454 .68389 .42568 .67768 Mtetra
.746 .825 .913 r
.42568 .67768 .43454 .68389 .44977 .67414 .44096 .66929 Mtetra
.808 .86 .887 r
.44096 .66929 .44977 .67414 .46511 .66018 .45634 .65761 Mtetra
.881 .897 .838 r
.45634 .65761 .46511 .66018 .48054 .63978 .47183 .64061 Mtetra
.942 .92 .76 r
.47183 .64061 .48054 .63978 .49597 .61124 .48738 .61612 Mtetra
.973 .923 .675 r
.48738 .61612 .49597 .61124 .51131 .57539 .50289 .58342 Mtetra
.977 .918 .613 r
.50289 .58342 .51131 .57539 .52645 .53697 .51824 .54532 Mtetra
.972 .921 .602 r
.51824 .54532 .52645 .53697 .54139 .50238 .53337 .50792 Mtetra
.965 .938 .657 r
.53337 .50792 .54139 .50238 .55622 .47549 .54834 .47681 Mtetra
.942 .947 .757 r
.54834 .47681 .55622 .47549 .57103 .45638 .56324 .45388 Mtetra
.882 .917 .845 r
.56324 .45388 .57103 .45638 .5859 .44309 .57817 .43786 Mtetra
.807 .863 .89 r
.57817 .43786 .5859 .44309 .60086 .43349 .59318 .42658 Mtetra
.748 .815 .905 r
.59318 .42658 .60086 .43349 .61592 .42605 .60829 .41814 Mtetra
.71 .783 .909 r
.60829 .41814 .61592 .42605 .63108 .41978 .62349 .4113 Mtetra
.689 .764 .909 r
.62349 .4113 .63108 .41978 .64633 .41414 .63879 .40533 Mtetra
.677 .753 .909 r
.63879 .40533 .64633 .41414 .66167 .40882 .65419 .39982 Mtetra
.671 .748 .908 r
.65419 .39982 .66167 .40882 .6771 .40366 .66967 .39453 Mtetra
.667 .745 .908 r
.66967 .39453 .6771 .40366 .69262 .39857 .68525 .38934 Mtetra
.665 .743 .908 r
.68525 .38934 .69262 .39857 .70822 .3935 .70091 .3842 Mtetra
.665 .742 .908 r
.70091 .3842 .70822 .3935 .72391 .38843 .71667 .37907 Mtetra
.664 .742 .908 r
.71667 .37907 .72391 .38843 .73969 .38335 .73251 .37393 Mtetra
.73251 .37393 .73969 .38335 .75556 .37825 .74844 .36877 Mtetra
.664 .741 .908 r
.74844 .36877 .75556 .37825 .77152 .37312 .76446 .36359 Mtetra
.76446 .36359 .77152 .37312 .78756 .36797 .78056 .35839 Mtetra
.78056 .35839 .78756 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .763 .934 r
.28317 .71256 .29254 .72016 .307 .71604 .29767 .7084 Mtetra
.29767 .7084 .307 .71604 .32153 .71188 .31225 .70421 Mtetra
.647 .763 .934 r
.31225 .70421 .32153 .71188 .33615 .70768 .32692 .69998 Mtetra
.648 .764 .933 r
.32692 .69998 .33615 .70768 .35085 .70341 .34167 .69569 Mtetra
.649 .765 .933 r
.34167 .69569 .35085 .70341 .36563 .69904 .3565 .69132 Mtetra
.653 .767 .933 r
.3565 .69132 .36563 .69904 .3805 .69449 .37142 .68682 Mtetra
.658 .77 .932 r
.37142 .68682 .3805 .69449 .39546 .68962 .38643 .68207 Mtetra
.669 .777 .93 r
.38643 .68207 .39546 .68962 .41052 .68418 .40153 .6769 Mtetra
.689 .789 .927 r
.40153 .6769 .41052 .68418 .42568 .67768 .41674 .67095 Mtetra
.722 .81 .919 r
.41674 .67095 .42568 .67768 .44096 .66929 .43205 .66357 Mtetra
.775 .842 .902 r
.43205 .66357 .44096 .66929 .45634 .65761 .44748 .65367 Mtetra
.845 .88 .866 r
.44748 .65367 .45634 .65761 .47183 .64061 .46303 .63952 Mtetra
.915 .912 .802 r
.46303 .63952 .47183 .64061 .48738 .61612 .47866 .61889 Mtetra
.962 .924 .716 r
.47866 .61889 .48738 .61612 .50289 .58342 .49431 .59006 Mtetra
.977 .92 .639 r
.49431 .59006 .50289 .58342 .51824 .54532 .50986 .55388 Mtetra
.975 .918 .6 r
.50986 .55388 .51824 .54532 .53337 .50792 .5252 .51512 Mtetra
.969 .929 .622 r
.5252 .51512 .53337 .50792 .54834 .47681 .54034 .48022 Mtetra
.957 .946 .704 r
.54034 .48022 .54834 .47681 .56324 .45388 .55536 .45307 Mtetra
.916 .937 .806 r
.55536 .45307 .56324 .45388 .57817 .43786 .57037 .43376 Mtetra
.844 .891 .873 r
.57037 .43376 .57817 .43786 .59318 .42658 .58543 .42029 Mtetra
.774 .837 .9 r
.58543 .42029 .59318 .42658 .60829 .41814 .60058 .41054 Mtetra
.726 .797 .908 r
.60058 .41054 .60829 .41814 .62349 .4113 .61584 .40296 Mtetra
.698 .772 .909 r
.61584 .40296 .62349 .4113 .63879 .40533 .63119 .39655 Mtetra
.682 .758 .909 r
.63119 .39655 .63879 .40533 .65419 .39982 .64663 .39078 Mtetra
.673 .75 .909 r
.64663 .39078 .65419 .39982 .66967 .39453 .66218 .38533 Mtetra
.669 .746 .908 r
.66218 .38533 .66967 .39453 .68525 .38934 .67781 .38004 Mtetra
.666 .744 .908 r
.67781 .38004 .68525 .38934 .70091 .3842 .69353 .37482 Mtetra
.665 .743 .908 r
.69353 .37482 .70091 .3842 .71667 .37907 .70934 .36962 Mtetra
.664 .742 .908 r
.70934 .36962 .71667 .37907 .73251 .37393 .72524 .36442 Mtetra
.72524 .36442 .73251 .37393 .74844 .36877 .74124 .3592 Mtetra
.664 .741 .908 r
.74124 .3592 .74844 .36877 .76446 .36359 .75732 .35396 Mtetra
.75732 .35396 .76446 .36359 .78056 .35839 .77349 .3487 Mtetra
.77349 .3487 .78056 .35839 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .763 .934 r
.2737 .70488 .28317 .71256 .29767 .7084 .28825 .70068 Mtetra
.28825 .70068 .29767 .7084 .31225 .70421 .30288 .69645 Mtetra
.647 .763 .934 r
.30288 .69645 .31225 .70421 .32692 .69998 .31759 .69219 Mtetra
.31759 .69219 .32692 .69998 .34167 .69569 .33239 .68788 Mtetra
.648 .764 .933 r
.33239 .68788 .34167 .69569 .3565 .69132 .34727 .6835 Mtetra
.651 .765 .933 r
.34727 .6835 .3565 .69132 .37142 .68682 .36224 .67901 Mtetra
.655 .768 .932 r
.36224 .67901 .37142 .68682 .38643 .68207 .3773 .67435 Mtetra
.663 .773 .931 r
.3773 .67435 .38643 .68207 .40153 .6769 .39245 .66936 Mtetra
.678 .782 .929 r
.39245 .66936 .40153 .6769 .41674 .67095 .4077 .66379 Mtetra
.703 .799 .924 r
.4077 .66379 .41674 .67095 .43205 .66357 .42306 .65717 Mtetra
.746 .825 .913 r
.42306 .65717 .43205 .66357 .44748 .65367 .43853 .64863 Mtetra
.808 .86 .888 r
.43853 .64863 .44748 .65367 .46303 .63952 .45412 .63677 Mtetra
.881 .898 .838 r
.45412 .63677 .46303 .63952 .47866 .61889 .46982 .61956 Mtetra
.943 .921 .76 r
.46982 .61956 .47866 .61889 .49431 .59006 .48558 .59481 Mtetra
.973 .923 .674 r
.48558 .59481 .49431 .59006 .50986 .55388 .5013 .5618 Mtetra
.977 .918 .613 r
.5013 .5618 .50986 .55388 .5252 .51512 .51687 .52335 Mtetra
.972 .921 .603 r
.51687 .52335 .5252 .51512 .54034 .48022 .53221 .48562 Mtetra
.965 .938 .657 r
.53221 .48562 .54034 .48022 .55536 .45307 .54738 .45423 Mtetra
.942 .946 .757 r
.54738 .45423 .55536 .45307 .57037 .43376 .56248 .43106 Mtetra
.882 .917 .845 r
.56248 .43106 .57037 .43376 .58543 .42029 .5776 .41486 Mtetra
.807 .863 .89 r
.5776 .41486 .58543 .42029 .60058 .41054 .5928 .4034 Mtetra
.748 .815 .905 r
.5928 .4034 .60058 .41054 .61584 .40296 .6081 .39482 Mtetra
.71 .783 .909 r
.6081 .39482 .61584 .40296 .63119 .39655 .6235 .38784 Mtetra
.689 .764 .909 r
.6235 .38784 .63119 .39655 .64663 .39078 .63901 .38174 Mtetra
.677 .753 .909 r
.63901 .38174 .64663 .39078 .66218 .38533 .6546 .37609 Mtetra
.671 .748 .908 r
.6546 .37609 .66218 .38533 .67781 .38004 .67029 .37067 Mtetra
.667 .745 .908 r
.67029 .37067 .67781 .38004 .69353 .37482 .68607 .36535 Mtetra
.665 .743 .908 r
.68607 .36535 .69353 .37482 .70934 .36962 .70194 .36007 Mtetra
.665 .742 .908 r
.70194 .36007 .70934 .36962 .72524 .36442 .71791 .35481 Mtetra
.664 .742 .908 r
.71791 .35481 .72524 .36442 .74124 .3592 .73396 .34953 Mtetra
.73396 .34953 .74124 .3592 .75732 .35396 .75011 .34424 Mtetra
.664 .741 .908 r
.75011 .34424 .75732 .35396 .77349 .3487 .76634 .33892 Mtetra
.76634 .33892 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .762 .934 r
.26413 .69712 .2737 .70488 .28825 .70068 .27873 .69288 Mtetra
.646 .763 .934 r
.27873 .69288 .28825 .70068 .30288 .69645 .29341 .68861 Mtetra
.29341 .68861 .30288 .69645 .31759 .69219 .30817 .68431 Mtetra
.647 .763 .934 r
.30817 .68431 .31759 .69219 .33239 .68788 .32302 .67997 Mtetra
.648 .764 .933 r
.32302 .67997 .33239 .68788 .34727 .6835 .33795 .67557 Mtetra
.649 .765 .933 r
.33795 .67557 .34727 .6835 .36224 .67901 .35297 .67108 Mtetra
.653 .767 .933 r
.35297 .67108 .36224 .67901 .3773 .67435 .36808 .66646 Mtetra
.658 .77 .932 r
.36808 .66646 .3773 .67435 .39245 .66936 .38328 .6616 Mtetra
.669 .777 .93 r
.38328 .6616 .39245 .66936 .4077 .66379 .39858 .65631 Mtetra
.689 .789 .927 r
.39858 .65631 .4077 .66379 .42306 .65717 .41398 .65022 Mtetra
.722 .81 .92 r
.41398 .65022 .42306 .65717 .43853 .64863 .42949 .64271 Mtetra
.775 .842 .903 r
.42949 .64271 .43853 .64863 .45412 .63677 .44513 .63265 Mtetra
.845 .88 .866 r
.44513 .63265 .45412 .63677 .46982 .61956 .46088 .6183 Mtetra
.915 .912 .802 r
.46088 .6183 .46982 .61956 .48558 .59481 .47673 .59744 Mtetra
.962 .924 .716 r
.47673 .59744 .48558 .59481 .5013 .5618 .49259 .56832 Mtetra
.977 .92 .639 r
.49259 .56832 .5013 .5618 .51687 .52335 .50836 .5318 Mtetra
.975 .918 .6 r
.50836 .5318 .51687 .52335 .53221 .48562 .52392 .49269 Mtetra
.969 .929 .622 r
.52392 .49269 .53221 .48562 .54738 .45423 .53927 .45747 Mtetra
.957 .946 .705 r
.53927 .45747 .54738 .45423 .56248 .43106 .55449 .43007 Mtetra
.916 .937 .806 r
.55449 .43007 .56248 .43106 .5776 .41486 .56969 .41054 Mtetra
.844 .891 .873 r
.56969 .41054 .5776 .41486 .5928 .4034 .58495 .3969 Mtetra
.774 .837 .9 r
.58495 .3969 .5928 .4034 .6081 .39482 .6003 .387 Mtetra
.726 .797 .907 r
.6003 .387 .6081 .39482 .6235 .38784 .61575 .37926 Mtetra
.698 .772 .909 r
.61575 .37926 .6235 .38784 .63901 .38174 .6313 .37272 Mtetra
.682 .758 .909 r
.6313 .37272 .63901 .38174 .6546 .37609 .64695 .36681 Mtetra
.673 .75 .909 r
.64695 .36681 .6546 .37609 .67029 .37067 .6627 .36123 Mtetra
.669 .746 .908 r
.6627 .36123 .67029 .37067 .68607 .36535 .67854 .3558 Mtetra
.666 .744 .908 r
.67854 .3558 .68607 .36535 .70194 .36007 .69447 .35044 Mtetra
.665 .743 .908 r
.69447 .35044 .70194 .36007 .71791 .35481 .71049 .3451 Mtetra
.664 .742 .908 r
.71049 .3451 .71791 .35481 .73396 .34953 .72661 .33976 Mtetra
.72661 .33976 .73396 .34953 .75011 .34424 .74282 .33441 Mtetra
.664 .741 .908 r
.74282 .33441 .75011 .34424 .76634 .33892 .75912 .32903 Mtetra
.75912 .32903 .76634 .33892 .78267 .33357 .77552 .32363 Mtetra
.77552 .32363 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69712 .27873 .69288 .26911 .685 Mtetra
.646 .763 .934 r
.26911 .685 .27873 .69288 .29341 .68861 .28384 .68069 Mtetra
.28384 .68069 .29341 .68861 .30817 .68431 .29865 .67635 Mtetra
.647 .763 .934 r
.29865 .67635 .30817 .68431 .32302 .67997 .31355 .67197 Mtetra
.31355 .67197 .32302 .67997 .33795 .67557 .32853 .66754 Mtetra
.648 .764 .933 r
.32853 .66754 .33795 .67557 .35297 .67108 .3436 .66305 Mtetra
.651 .765 .933 r
.3436 .66305 .35297 .67108 .36808 .66646 .35876 .65844 Mtetra
.655 .768 .932 r
.35876 .65844 .36808 .66646 .38328 .6616 .37401 .65366 Mtetra
.663 .773 .931 r
.37401 .65366 .38328 .6616 .39858 .65631 .38936 .64855 Mtetra
.678 .782 .929 r
.38936 .64855 .39858 .65631 .41398 .65022 .40481 .64286 Mtetra
.703 .799 .924 r
.40481 .64286 .41398 .65022 .42949 .64271 .42037 .6361 Mtetra
.746 .825 .913 r
.42037 .6361 .42949 .64271 .44513 .63265 .43604 .62741 Mtetra
.808 .861 .888 r
.43604 .62741 .44513 .63265 .46088 .6183 .45184 .61537 Mtetra
.882 .898 .838 r
.45184 .61537 .46088 .6183 .47673 .59744 .46776 .59795 Mtetra
.943 .921 .76 r
.46776 .59795 .47673 .59744 .49259 .56832 .48373 .57293 Mtetra
.973 .923 .674 r
.48373 .57293 .49259 .56832 .50836 .5318 .49968 .5396 Mtetra
.977 .918 .613 r
.49968 .5396 .50836 .5318 .52392 .49269 .51546 .5008 Mtetra
.972 .921 .603 r
.51546 .5008 .52392 .49269 .53927 .45747 .53102 .46273 Mtetra
.965 .938 .657 r
.53102 .46273 .53927 .45747 .55449 .43007 .54639 .43105 Mtetra
.942 .946 .757 r
.54639 .43105 .55449 .43007 .56969 .41054 .56169 .40764 Mtetra
.881 .917 .845 r
.56169 .40764 .56969 .41054 .58495 .3969 .57701 .39125 Mtetra
.807 .863 .89 r
.57701 .39125 .58495 .3969 .6003 .387 .59241 .37963 Mtetra
.748 .815 .905 r
.59241 .37963 .6003 .387 .61575 .37926 .60791 .37089 Mtetra
.71 .783 .909 r
.60791 .37089 .61575 .37926 .6313 .37272 .62352 .36377 Mtetra
.689 .764 .909 r
.62352 .36377 .6313 .37272 .64695 .36681 .63922 .35752 Mtetra
.677 .753 .909 r
.63922 .35752 .64695 .36681 .6627 .36123 .65502 .35173 Mtetra
.671 .748 .908 r
.65502 .35173 .6627 .36123 .67854 .3558 .67092 .34617 Mtetra
.667 .745 .908 r
.67092 .34617 .67854 .3558 .69447 .35044 .68692 .34072 Mtetra
.665 .743 .908 r
.68692 .34072 .69447 .35044 .71049 .3451 .703 .3353 Mtetra
.665 .742 .908 r
.703 .3353 .71049 .3451 .72661 .33976 .71918 .3299 Mtetra
.664 .742 .908 r
.71918 .3299 .72661 .33976 .74282 .33441 .73545 .32448 Mtetra
.73545 .32448 .74282 .33441 .75912 .32903 .75182 .31904 Mtetra
.664 .741 .908 r
.75182 .31904 .75912 .32903 .77552 .32363 .76828 .31358 Mtetra
.76828 .31358 .77552 .32363 .79201 .31819 .78484 .30808 Mtetra
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .762 .934 r
.2447 .68136 .25446 .68929 .26911 .685 .25939 .67704 Mtetra
.25939 .67704 .26911 .685 .28384 .68069 .27417 .67268 Mtetra
.646 .763 .934 r
.27417 .67268 .28384 .68069 .29865 .67635 .28904 .6683 Mtetra
.28904 .6683 .29865 .67635 .31355 .67197 .30398 .66388 Mtetra
.647 .763 .934 r
.30398 .66388 .31355 .67197 .32853 .66754 .31902 .65942 Mtetra
.648 .764 .933 r
.31902 .65942 .32853 .66754 .3436 .66305 .33414 .6549 Mtetra
.649 .765 .933 r
.33414 .6549 .3436 .66305 .35876 .65844 .34935 .6503 Mtetra
.653 .767 .933 r
.34935 .6503 .35876 .65844 .37401 .65366 .36465 .64556 Mtetra
.658 .77 .932 r
.36465 .64556 .37401 .65366 .38936 .64855 .38005 .64058 Mtetra
.669 .777 .93 r
.38005 .64058 .38936 .64855 .40481 .64286 .39554 .63515 Mtetra
.689 .79 .927 r
.39554 .63515 .40481 .64286 .42037 .6361 .41115 .62894 Mtetra
.722 .81 .92 r
.41115 .62894 .42037 .6361 .43604 .62741 .42687 .62128 Mtetra
.775 .842 .903 r
.42687 .62128 .43604 .62741 .45184 .61537 .44271 .61105 Mtetra
.845 .88 .866 r
.44271 .61105 .45184 .61537 .46776 .59795 .45868 .59651 Mtetra
.915 .912 .802 r
.45868 .59651 .46776 .59795 .48373 .57293 .47474 .5754 Mtetra
.962 .924 .716 r
.47474 .5754 .48373 .57293 .49968 .5396 .49083 .54599 Mtetra
.977 .92 .638 r
.49083 .54599 .49968 .5396 .51546 .5008 .50682 .50912 Mtetra
.975 .918 .6 r
.50682 .50912 .51546 .5008 .53102 .46273 .52261 .46966 Mtetra
.969 .929 .622 r
.52261 .46966 .53102 .46273 .54639 .43105 .53816 .43413 Mtetra
.958 .946 .705 r
.53816 .43413 .54639 .43105 .56169 .40764 .55359 .40646 Mtetra
.916 .936 .806 r
.55359 .40646 .56169 .40764 .57701 .39125 .56899 .38672 Mtetra
.844 .89 .873 r
.56899 .38672 .57701 .39125 .59241 .37963 .58445 .37289 Mtetra
.774 .837 .9 r
.58445 .37289 .59241 .37963 .60791 .37089 .6 .36283 Mtetra
.726 .797 .907 r
.6 .36283 .60791 .37089 .62352 .36377 .61566 .35494 Mtetra
.698 .772 .909 r
.61566 .35494 .62352 .36377 .63922 .35752 .63142 .34826 Mtetra
.682 .758 .909 r
.63142 .34826 .63922 .35752 .65502 .35173 .64727 .34221 Mtetra
.673 .75 .909 r
.64727 .34221 .65502 .35173 .67092 .34617 .66323 .33648 Mtetra
.669 .746 .908 r
.66323 .33648 .67092 .34617 .68692 .34072 .67928 .33091 Mtetra
.666 .744 .908 r
.67928 .33091 .68692 .34072 .703 .3353 .69543 .32541 Mtetra
.665 .743 .908 r
.69543 .32541 .703 .3353 .71918 .3299 .71168 .31993 Mtetra
.664 .742 .908 r
.71168 .31993 .71918 .3299 .73545 .32448 .72801 .31444 Mtetra
.72801 .31444 .73545 .32448 .75182 .31904 .74445 .30894 Mtetra
.664 .741 .908 r
.74445 .30894 .75182 .31904 .76828 .31358 .76097 .30342 Mtetra
.76097 .30342 .76828 .31358 .78484 .30808 .7776 .29787 Mtetra
.7776 .29787 .78484 .30808 .80149 .30256 .79432 .29228 Mtetra
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68136 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67268 .2644 .66459 Mtetra
.646 .763 .934 r
.2644 .66459 .27417 .67268 .28904 .6683 .27932 .66016 Mtetra
.27932 .66016 .28904 .6683 .30398 .66388 .29432 .6557 Mtetra
.647 .763 .934 r
.29432 .6557 .30398 .66388 .31902 .65942 .3094 .65121 Mtetra
.3094 .65121 .31902 .65942 .33414 .6549 .32457 .64666 Mtetra
.648 .764 .933 r
.32457 .64666 .33414 .6549 .34935 .6503 .33984 .64205 Mtetra
.651 .765 .933 r
.33984 .64205 .34935 .6503 .36465 .64556 .35519 .63732 Mtetra
.655 .768 .933 r
.35519 .63732 .36465 .64556 .38005 .64058 .37064 .63241 Mtetra
.663 .773 .931 r
.37064 .63241 .38005 .64058 .39554 .63515 .38618 .62718 Mtetra
.678 .783 .929 r
.38618 .62718 .39554 .63515 .41115 .62894 .40183 .62135 Mtetra
.703 .799 .924 r
.40183 .62135 .41115 .62894 .42687 .62128 .4176 .61445 Mtetra
.746 .825 .913 r
.4176 .61445 .42687 .62128 .44271 .61105 .43349 .6056 Mtetra
.808 .861 .888 r
.43349 .6056 .44271 .61105 .45868 .59651 .4495 .59339 Mtetra
.882 .898 .838 r
.4495 .59339 .45868 .59651 .47474 .5754 .46563 .57574 Mtetra
.943 .921 .76 r
.46563 .57574 .47474 .5754 .49083 .54599 .48184 .55045 Mtetra
.973 .923 .674 r
.48184 .55045 .49083 .54599 .50682 .50912 .49801 .51679 Mtetra
.977 .918 .613 r
.49801 .51679 .50682 .50912 .52261 .46966 .51402 .47764 Mtetra
.972 .921 .603 r
.51402 .47764 .52261 .46966 .53816 .43413 .52979 .43923 Mtetra
.966 .938 .658 r
.52979 .43923 .53816 .43413 .55359 .40646 .54538 .40726 Mtetra
.941 .946 .757 r
.54538 .40726 .55359 .40646 .56899 .38672 .56088 .38361 Mtetra
.881 .916 .845 r
.56088 .38361 .56899 .38672 .58445 .37289 .57641 .36701 Mtetra
.807 .863 .89 r
.57641 .36701 .58445 .37289 .6 .36283 .59201 .35522 Mtetra
.748 .815 .905 r
.59201 .35522 .6 .36283 .61566 .35494 .60772 .34632 Mtetra
.71 .783 .909 r
.60772 .34632 .61566 .35494 .63142 .34826 .62353 .33905 Mtetra
.689 .764 .909 r
.62353 .33905 .63142 .34826 .64727 .34221 .63944 .33266 Mtetra
.677 .753 .909 r
.63944 .33266 .64727 .34221 .66323 .33648 .65546 .32673 Mtetra
.671 .748 .908 r
.65546 .32673 .66323 .33648 .67928 .33091 .67157 .32102 Mtetra
.667 .745 .908 r
.67157 .32102 .67928 .33091 .69543 .32541 .68778 .31542 Mtetra
.665 .743 .908 r
.68778 .31542 .69543 .32541 .71168 .31993 .70409 .30986 Mtetra
.665 .742 .908 r
.70409 .30986 .71168 .31993 .72801 .31444 .72049 .30431 Mtetra
.664 .742 .908 r
.72049 .30431 .72801 .31444 .74445 .30894 .73699 .29874 Mtetra
.73699 .29874 .74445 .30894 .76097 .30342 .75358 .29316 Mtetra
.664 .741 .908 r
.75358 .29316 .76097 .30342 .7776 .29787 .77028 .28754 Mtetra
.77028 .28754 .7776 .29787 .79432 .29228 .78706 .2819 Mtetra
.78706 .2819 .79432 .29228 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66085 Mtetra
.23965 .66085 .24958 .66899 .2644 .66459 .25453 .65641 Mtetra
.25453 .65641 .2644 .66459 .27932 .66016 .2695 .65194 Mtetra
.646 .763 .934 r
.2695 .65194 .27932 .66016 .29432 .6557 .28455 .64744 Mtetra
.28455 .64744 .29432 .6557 .3094 .65121 .29968 .6429 Mtetra
.647 .763 .934 r
.29968 .6429 .3094 .65121 .32457 .64666 .31491 .63832 Mtetra
.648 .764 .933 r
.31491 .63832 .32457 .64666 .33984 .64205 .33022 .63368 Mtetra
.649 .765 .933 r
.33022 .63368 .33984 .64205 .35519 .63732 .34563 .62895 Mtetra
.653 .767 .933 r
.34563 .62895 .35519 .63732 .37064 .63241 .36113 .62409 Mtetra
.658 .77 .932 r
.36113 .62409 .37064 .63241 .38618 .62718 .37672 .61897 Mtetra
.669 .777 .93 r
.37672 .61897 .38618 .62718 .40183 .62135 .39243 .61342 Mtetra
.689 .79 .927 r
.39243 .61342 .40183 .62135 .4176 .61445 .40824 .60707 Mtetra
.722 .81 .92 r
.40824 .60707 .4176 .61445 .43349 .6056 .42417 .59925 Mtetra
.775 .842 .903 r
.42417 .59925 .43349 .6056 .4495 .59339 .44023 .58886 Mtetra
.845 .88 .866 r
.44023 .58886 .4495 .59339 .46563 .57574 .45641 .57412 Mtetra
.915 .912 .802 r
.45641 .57412 .46563 .57574 .48184 .55045 .47271 .55276 Mtetra
.962 .924 .716 r
.47271 .55276 .48184 .55045 .49801 .51679 .48902 .52304 Mtetra
.977 .92 .638 r
.48902 .52304 .49801 .51679 .51402 .47764 .50525 .48583 Mtetra
.975 .918 .6 r
.50525 .48583 .51402 .47764 .52979 .43923 .52125 .44602 Mtetra
.969 .929 .622 r
.52125 .44602 .52979 .43923 .54538 .40726 .53703 .41016 Mtetra
.958 .946 .705 r
.53703 .41016 .54538 .40726 .56088 .38361 .55267 .38222 Mtetra
.916 .936 .806 r
.55267 .38222 .56088 .38361 .57641 .36701 .56828 .36225 Mtetra
.844 .89 .873 r
.56828 .36225 .57641 .36701 .59201 .35522 .58394 .34824 Mtetra
.774 .837 .9 r
.58394 .34824 .59201 .35522 .60772 .34632 .5997 .33801 Mtetra
.726 .797 .907 r
.5997 .33801 .60772 .34632 .62353 .33905 .61556 .32997 Mtetra
.698 .772 .909 r
.61556 .32997 .62353 .33905 .63944 .33266 .63153 .32313 Mtetra
.682 .758 .909 r
.63153 .32313 .63944 .33266 .65546 .32673 .64761 .31693 Mtetra
.673 .75 .909 r
.64761 .31693 .65546 .32673 .67157 .32102 .66378 .31106 Mtetra
.669 .746 .908 r
.66378 .31106 .67157 .32102 .68778 .31542 .68005 .30534 Mtetra
.666 .744 .908 r
.68005 .30534 .68778 .31542 .70409 .30986 .69642 .2997 Mtetra
.665 .743 .908 r
.69642 .2997 .70409 .30986 .72049 .30431 .71289 .29407 Mtetra
.664 .742 .908 r
.71289 .29407 .72049 .30431 .73699 .29874 .72945 .28843 Mtetra
.72945 .28843 .73699 .29874 .75358 .29316 .74612 .28278 Mtetra
.664 .741 .908 r
.74612 .28278 .75358 .29316 .77028 .28754 .76288 .2771 Mtetra
.76288 .2771 .77028 .28754 .78706 .2819 .77973 .2714 Mtetra
.77973 .2714 .78706 .2819 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66085 .22963 .65264 Mtetra
.22963 .65264 .23965 .66085 .25453 .65641 .24456 .64814 Mtetra
.24456 .64814 .25453 .65641 .2695 .65194 .25957 .64363 Mtetra
.646 .763 .934 r
.25957 .64363 .2695 .65194 .28455 .64744 .27467 .63908 Mtetra
.27467 .63908 .28455 .64744 .29968 .6429 .28986 .6345 Mtetra
.647 .763 .934 r
.28986 .6345 .29968 .6429 .31491 .63832 .30514 .62988 Mtetra
.30514 .62988 .31491 .63832 .33022 .63368 .3205 .62521 Mtetra
.648 .764 .933 r
.3205 .62521 .33022 .63368 .34563 .62895 .33596 .62047 Mtetra
.651 .765 .933 r
.33596 .62047 .34563 .62895 .36113 .62409 .35152 .61562 Mtetra
.655 .768 .933 r
.35152 .61562 .36113 .62409 .37672 .61897 .36717 .61058 Mtetra
.663 .773 .931 r
.36717 .61058 .37672 .61897 .39243 .61342 .38292 .60521 Mtetra
.678 .783 .929 r
.38292 .60521 .39243 .61342 .40824 .60707 .39878 .59925 Mtetra
.703 .799 .924 r
.39878 .59925 .40824 .60707 .42417 .59925 .41475 .5922 Mtetra
.746 .825 .913 r
.41475 .5922 .42417 .59925 .44023 .58886 .43086 .58319 Mtetra
.808 .861 .888 r
.43086 .58319 .44023 .58886 .45641 .57412 .44709 .57079 Mtetra
.882 .898 .838 r
.44709 .57079 .45641 .57412 .47271 .55276 .46345 .55292 Mtetra
.943 .921 .76 r
.46345 .55292 .47271 .55276 .48902 .52304 .47989 .52735 Mtetra
.973 .923 .674 r
.47989 .52735 .48902 .52304 .50525 .48583 .49629 .49336 Mtetra
.977 .918 .612 r
.49629 .49336 .50525 .48583 .52125 .44602 .51253 .45385 Mtetra
.972 .921 .603 r
.51253 .45385 .52125 .44602 .53703 .41016 .52853 .4151 Mtetra
.966 .938 .658 r
.52853 .4151 .53703 .41016 .55267 .38222 .54433 .38282 Mtetra
.941 .946 .757 r
.54433 .38282 .55267 .38222 .56828 .36225 .56005 .35892 Mtetra
.881 .916 .845 r
.56005 .35892 .56828 .36225 .58394 .34824 .57579 .34212 Mtetra
.807 .862 .89 r
.57579 .34212 .58394 .34824 .5997 .33801 .5916 .33015 Mtetra
.748 .814 .905 r
.5916 .33015 .5997 .33801 .61556 .32997 .60752 .32109 Mtetra
.71 .782 .908 r
.60752 .32109 .61556 .32997 .63153 .32313 .62354 .31367 Mtetra
.689 .764 .909 r
.62354 .31367 .63153 .32313 .64761 .31693 .63967 .30712 Mtetra
.677 .753 .909 r
.63967 .30712 .64761 .31693 .66378 .31106 .65591 .30104 Mtetra
.671 .748 .908 r
.65591 .30104 .66378 .31106 .68005 .30534 .67224 .29518 Mtetra
.667 .745 .908 r
.67224 .29518 .68005 .30534 .69642 .2997 .68867 .28943 Mtetra
.665 .743 .908 r
.68867 .28943 .69642 .2997 .71289 .29407 .70521 .28372 Mtetra
.665 .742 .908 r
.70521 .28372 .71289 .29407 .72945 .28843 .72184 .27802 Mtetra
.664 .742 .908 r
.72184 .27802 .72945 .28843 .74612 .28278 .73857 .2723 Mtetra
.73857 .2723 .74612 .28278 .76288 .2771 .75539 .26656 Mtetra
.664 .741 .908 r
.75539 .26656 .76288 .2771 .77973 .2714 .77232 .26079 Mtetra
.77232 .26079 .77973 .2714 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64814 .23447 .63979 Mtetra
.23447 .63979 .24456 .64814 .25957 .64363 .24954 .63522 Mtetra
.24954 .63522 .25957 .64363 .27467 .63908 .26469 .63063 Mtetra
.646 .763 .934 r
.26469 .63063 .27467 .63908 .28986 .6345 .27993 .626 Mtetra
.27993 .626 .28986 .6345 .30514 .62988 .29526 .62134 Mtetra
.647 .763 .934 r
.29526 .62134 .30514 .62988 .3205 .62521 .31068 .61664 Mtetra
.648 .764 .933 r
.31068 .61664 .3205 .62521 .33596 .62047 .3262 .61187 Mtetra
.649 .765 .933 r
.3262 .61187 .33596 .62047 .35152 .61562 .3418 .60702 Mtetra
.653 .767 .933 r
.3418 .60702 .35152 .61562 .36717 .61058 .35751 .60202 Mtetra
.658 .77 .932 r
.35751 .60202 .36717 .61058 .38292 .60521 .37331 .59677 Mtetra
.669 .777 .93 r
.37331 .59677 .38292 .60521 .39878 .59925 .38922 .59108 Mtetra
.689 .79 .927 r
.38922 .59108 .39878 .59925 .41475 .5922 .40524 .58458 Mtetra
.722 .81 .92 r
.40524 .58458 .41475 .5922 .43086 .58319 .42139 .57661 Mtetra
.775 .842 .903 r
.42139 .57661 .43086 .58319 .44709 .57079 .43767 .56604 Mtetra
.845 .881 .866 r
.43767 .56604 .44709 .57079 .46345 .55292 .45409 .5511 Mtetra
.915 .913 .802 r
.45409 .5511 .46345 .55292 .47989 .52735 .47061 .52949 Mtetra
.962 .925 .716 r
.47061 .52949 .47989 .52735 .49629 .49336 .48717 .49946 Mtetra
.977 .92 .638 r
.48717 .49946 .49629 .49336 .51253 .45385 .50362 .46189 Mtetra
.975 .918 .6 r
.50362 .46189 .51253 .45385 .52853 .4151 .51986 .42172 Mtetra
.969 .929 .623 r
.51986 .42172 .52853 .4151 .54433 .38282 .53586 .38553 Mtetra
.958 .945 .705 r
.53586 .38553 .54433 .38282 .56005 .35892 .55172 .35732 Mtetra
.915 .936 .806 r
.55172 .35732 .56005 .35892 .57579 .34212 .56754 .33713 Mtetra
.844 .89 .873 r
.56754 .33713 .57579 .34212 .5916 .33015 .58342 .32292 Mtetra
.774 .836 .9 r
.58342 .32292 .5916 .33015 .60752 .32109 .59939 .31252 Mtetra
.726 .796 .907 r
.59939 .31252 .60752 .32109 .62354 .31367 .61547 .30432 Mtetra
.698 .772 .909 r
.61547 .30432 .62354 .31367 .63967 .30712 .63166 .29733 Mtetra
.682 .758 .909 r
.63166 .29733 .63967 .30712 .65591 .30104 .64795 .29097 Mtetra
.673 .75 .909 r
.64795 .29097 .65591 .30104 .67224 .29518 .66435 .28495 Mtetra
.669 .746 .908 r
.66435 .28495 .67224 .29518 .68867 .28943 .68084 .27908 Mtetra
.666 .744 .908 r
.68084 .27908 .68867 .28943 .70521 .28372 .69744 .27327 Mtetra
.665 .743 .908 r
.69744 .27327 .70521 .28372 .72184 .27802 .71414 .26749 Mtetra
.664 .742 .908 r
.71414 .26749 .72184 .27802 .73857 .2723 .73094 .2617 Mtetra
.73094 .2617 .73857 .2723 .75539 .26656 .74783 .25589 Mtetra
.664 .741 .908 r
.74783 .25589 .75539 .26656 .77232 .26079 .76483 .25006 Mtetra
.76483 .25006 .77232 .26079 .78935 .25498 .78193 .24419 Mtetra
.78193 .24419 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63522 .2394 .62673 Mtetra
.2394 .62673 .24954 .63522 .26469 .63063 .2546 .62209 Mtetra
.646 .763 .934 r
.2546 .62209 .26469 .63063 .27993 .626 .2699 .61742 Mtetra
.2699 .61742 .27993 .626 .29526 .62134 .28528 .61271 Mtetra
.647 .763 .934 r
.28528 .61271 .29526 .62134 .31068 .61664 .30076 .60796 Mtetra
.30076 .60796 .31068 .61664 .3262 .61187 .31632 .60316 Mtetra
.648 .764 .933 r
.31632 .60316 .3262 .61187 .3418 .60702 .33198 .59829 Mtetra
.651 .765 .933 r
.33198 .59829 .3418 .60702 .35751 .60202 .34774 .59331 Mtetra
.655 .768 .933 r
.34774 .59331 .35751 .60202 .37331 .59677 .3636 .58814 Mtetra
.663 .773 .931 r
.3636 .58814 .37331 .59677 .38922 .59108 .37956 .58263 Mtetra
.678 .783 .929 r
.37956 .58263 .38922 .59108 .40524 .58458 .39564 .57652 Mtetra
.703 .799 .924 r
.39564 .57652 .40524 .58458 .42139 .57661 .41183 .56932 Mtetra
.746 .825 .913 r
.41183 .56932 .42139 .57661 .43767 .56604 .42815 .56015 Mtetra
.808 .861 .888 r
.42815 .56015 .43767 .56604 .45409 .5511 .44462 .54756 Mtetra
.882 .899 .838 r
.44462 .54756 .45409 .5511 .47061 .52949 .46121 .52945 Mtetra
.943 .921 .76 r
.46121 .52945 .47061 .52949 .48717 .49946 .47788 .5036 Mtetra
.973 .924 .674 r
.47788 .5036 .48717 .49946 .50362 .46189 .49453 .46927 Mtetra
.977 .918 .612 r
.49453 .46927 .50362 .46189 .51986 .42172 .51101 .42939 Mtetra
.972 .921 .603 r
.51101 .42939 .51986 .42172 .53586 .38553 .52724 .39029 Mtetra
.966 .938 .658 r
.52724 .39029 .53586 .38553 .55172 .35732 .54326 .35771 Mtetra
.941 .946 .758 r
.54326 .35771 .55172 .35732 .56754 .33713 .5592 .33357 Mtetra
.881 .916 .845 r
.5592 .33357 .56754 .33713 .58342 .32292 .57515 .31655 Mtetra
.807 .862 .89 r
.57515 .31655 .58342 .32292 .59939 .31252 .59118 .3044 Mtetra
.748 .814 .905 r
.59118 .3044 .59939 .31252 .61547 .30432 .60731 .29517 Mtetra
.71 .782 .908 r
.60731 .29517 .61547 .30432 .63166 .29733 .62356 .28759 Mtetra
.689 .764 .909 r
.62356 .28759 .63166 .29733 .64795 .29097 .63991 .28089 Mtetra
.677 .753 .909 r
.63991 .28089 .64795 .29097 .66435 .28495 .65637 .27465 Mtetra
.671 .748 .908 r
.65637 .27465 .66435 .28495 .68084 .27908 .67293 .26863 Mtetra
.667 .745 .908 r
.67293 .26863 .68084 .27908 .69744 .27327 .68959 .26273 Mtetra
.665 .743 .908 r
.68959 .26273 .69744 .27327 .71414 .26749 .70635 .25686 Mtetra
.665 .742 .908 r
.70635 .25686 .71414 .26749 .73094 .2617 .72322 .25099 Mtetra
.664 .742 .908 r
.72322 .25099 .73094 .2617 .74783 .25589 .74019 .24511 Mtetra
.74019 .24511 .74783 .25589 .76483 .25006 .75726 .23921 Mtetra
.664 .741 .908 r
.75726 .23921 .76483 .25006 .78193 .24419 .77443 .23328 Mtetra
.77443 .23328 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21528 Mtetra
.646 .762 .934 r
.18391 .63205 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62673 .22915 .61815 Mtetra
.22915 .61815 .2394 .62673 .2546 .62209 .24441 .61346 Mtetra
.24441 .61346 .2546 .62209 .2699 .61742 .25975 .60873 Mtetra
.646 .763 .934 r
.25975 .60873 .2699 .61742 .28528 .61271 .27519 .60398 Mtetra
.27519 .60398 .28528 .61271 .30076 .60796 .29072 .59919 Mtetra
.647 .763 .934 r
.29072 .59919 .30076 .60796 .31632 .60316 .30634 .59435 Mtetra
.648 .764 .933 r
.30634 .59435 .31632 .60316 .33198 .59829 .32206 .58945 Mtetra
.649 .765 .933 r
.32206 .58945 .33198 .59829 .34774 .59331 .33787 .58447 Mtetra
.653 .767 .933 r
.33787 .58447 .34774 .59331 .3636 .58814 .35378 .57933 Mtetra
.658 .77 .932 r
.35378 .57933 .3636 .58814 .37956 .58263 .3698 .57395 Mtetra
.669 .777 .93 r
.3698 .57395 .37956 .58263 .39564 .57652 .38593 .56811 Mtetra
.689 .79 .927 r
.38593 .56811 .39564 .57652 .41183 .56932 .40217 .56146 Mtetra
.722 .811 .92 r
.40217 .56146 .41183 .56932 .42815 .56015 .41854 .55333 Mtetra
.775 .842 .903 r
.41854 .55333 .42815 .56015 .44462 .54756 .43505 .54258 Mtetra
.845 .881 .867 r
.43505 .54258 .44462 .54756 .46121 .52945 .45169 .52742 Mtetra
.916 .913 .802 r
.45169 .52742 .46121 .52945 .47788 .5036 .46846 .50555 Mtetra
.962 .925 .715 r
.46846 .50555 .47788 .5036 .49453 .46927 .48526 .47521 Mtetra
.977 .921 .638 r
.48526 .47521 .49453 .46927 .51101 .42939 .50196 .43729 Mtetra
.975 .918 .6 r
.50196 .43729 .51101 .42939 .52724 .39029 .51844 .39674 Mtetra
.969 .929 .623 r
.51844 .39674 .52724 .39029 .54326 .35771 .53467 .36023 Mtetra
.958 .945 .706 r
.53467 .36023 .54326 .35771 .5592 .33357 .55074 .33174 Mtetra
.915 .936 .806 r
.55074 .33174 .5592 .33357 .57515 .31655 .56679 .31131 Mtetra
.844 .89 .872 r
.56679 .31131 .57515 .31655 .59118 .3044 .58288 .29691 Mtetra
.774 .836 .899 r
.58288 .29691 .59118 .3044 .60731 .29517 .59907 .28633 Mtetra
.726 .796 .907 r
.59907 .28633 .60731 .29517 .62356 .28759 .61537 .27796 Mtetra
.698 .772 .909 r
.61537 .27796 .62356 .28759 .63991 .28089 .63178 .27081 Mtetra
.682 .758 .909 r
.63178 .27081 .63991 .28089 .65637 .27465 .6483 .2643 Mtetra
.673 .75 .908 r
.6483 .2643 .65637 .27465 .67293 .26863 .66493 .25811 Mtetra
.669 .746 .908 r
.66493 .25811 .67293 .26863 .68959 .26273 .68165 .25208 Mtetra
.666 .744 .908 r
.68165 .25208 .68959 .26273 .70635 .25686 .69849 .24612 Mtetra
.665 .743 .908 r
.69849 .24612 .70635 .25686 .72322 .25099 .71542 .24017 Mtetra
.664 .742 .908 r
.71542 .24017 .72322 .25099 .74019 .24511 .73246 .23422 Mtetra
.73246 .23422 .74019 .24511 .75726 .23921 .7496 .22825 Mtetra
.664 .741 .908 r
.7496 .22825 .75726 .23921 .77443 .23328 .76684 .22224 Mtetra
.76684 .22224 .77443 .23328 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21528 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63205 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60873 .2495 .59995 Mtetra
.646 .763 .934 r
.2495 .59995 .25975 .60873 .27519 .60398 .26499 .59515 Mtetra
.26499 .59515 .27519 .60398 .29072 .59919 .28057 .59031 Mtetra
.647 .763 .934 r
.28057 .59031 .29072 .59919 .30634 .59435 .29625 .58543 Mtetra
.29625 .58543 .30634 .59435 .32206 .58945 .31202 .5805 Mtetra
.648 .764 .933 r
.31202 .5805 .32206 .58945 .33787 .58447 .32789 .57549 Mtetra
.651 .765 .933 r
.32789 .57549 .33787 .58447 .35378 .57933 .34386 .57037 Mtetra
.655 .768 .933 r
.34386 .57037 .35378 .57933 .3698 .57395 .35993 .56506 Mtetra
.663 .773 .931 r
.35993 .56506 .3698 .57395 .38593 .56811 .37611 .55941 Mtetra
.678 .783 .929 r
.37611 .55941 .38593 .56811 .40217 .56146 .3924 .55315 Mtetra
.703 .799 .924 r
.3924 .55315 .40217 .56146 .41854 .55333 .40882 .54579 Mtetra
.746 .825 .913 r
.40882 .54579 .41854 .55333 .43505 .54258 .42537 .53645 Mtetra
.808 .861 .888 r
.42537 .53645 .43505 .54258 .45169 .52742 .44207 .52366 Mtetra
.882 .899 .838 r
.44207 .52366 .45169 .52742 .46846 .50555 .4589 .50531 Mtetra
.943 .922 .76 r
.4589 .50531 .46846 .50555 .48526 .47521 .47582 .47917 Mtetra
.973 .924 .673 r
.47582 .47917 .48526 .47521 .50196 .43729 .49271 .4445 Mtetra
.977 .918 .612 r
.49271 .4445 .50196 .43729 .51844 .39674 .50944 .40425 Mtetra
.972 .921 .603 r
.50944 .40425 .51844 .39674 .53467 .36023 .52591 .3648 Mtetra
.966 .938 .659 r
.52591 .3648 .53467 .36023 .55074 .33174 .54216 .33191 Mtetra
.941 .945 .758 r
.54216 .33191 .55074 .33174 .56679 .31131 .55832 .30751 Mtetra
.881 .916 .845 r
.55832 .30751 .56679 .31131 .58288 .29691 .57449 .29028 Mtetra
.807 .862 .89 r
.57449 .29028 .58288 .29691 .59907 .28633 .59075 .27793 Mtetra
.748 .814 .905 r
.59075 .27793 .59907 .28633 .61537 .27796 .6071 .26853 Mtetra
.71 .782 .908 r
.6071 .26853 .61537 .27796 .63178 .27081 .62357 .26078 Mtetra
.689 .764 .909 r
.62357 .26078 .63178 .27081 .6483 .2643 .64015 .25392 Mtetra
.677 .753 .909 r
.64015 .25392 .6483 .2643 .66493 .25811 .65684 .24751 Mtetra
.671 .748 .908 r
.65684 .24751 .66493 .25811 .68165 .25208 .67363 .24134 Mtetra
.667 .745 .908 r
.67363 .24134 .68165 .25208 .69849 .24612 .69053 .23527 Mtetra
.665 .743 .908 r
.69053 .23527 .69849 .24612 .71542 .24017 .70754 .22924 Mtetra
.665 .742 .908 r
.70754 .22924 .71542 .24017 .73246 .23422 .72464 .22321 Mtetra
.664 .742 .908 r
.72464 .22321 .73246 .23422 .7496 .22825 .74185 .21716 Mtetra
.74185 .21716 .7496 .22825 .76684 .22224 .75917 .21109 Mtetra
.664 .741 .908 r
.75917 .21109 .76684 .22224 .78419 .21621 .77659 .20498 Mtetra
.77659 .20498 .78419 .21621 .80164 .21014 .79412 .19885 Mtetra
.79412 .19885 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .5959 Mtetra
.22368 .5959 .2341 .60473 .2495 .59995 .23913 .59108 Mtetra
.23913 .59108 .2495 .59995 .26499 .59515 .25468 .58622 Mtetra
.646 .763 .934 r
.25468 .58622 .26499 .59515 .28057 .59031 .27032 .58134 Mtetra
.27032 .58134 .28057 .59031 .29625 .58543 .28605 .57641 Mtetra
.647 .763 .934 r
.28605 .57641 .29625 .58543 .31202 .5805 .30188 .57144 Mtetra
.648 .764 .933 r
.30188 .57144 .31202 .5805 .32789 .57549 .3178 .5664 Mtetra
.649 .765 .933 r
.3178 .5664 .32789 .57549 .34386 .57037 .33383 .56127 Mtetra
.653 .767 .933 r
.33383 .56127 .34386 .57037 .35993 .56506 .34996 .556 Mtetra
.658 .77 .932 r
.34996 .556 .35993 .56506 .37611 .55941 .36619 .55047 Mtetra
.669 .777 .93 r
.36619 .55047 .37611 .55941 .3924 .55315 .38254 .54448 Mtetra
.689 .79 .927 r
.38254 .54448 .3924 .55315 .40882 .54579 .399 .53768 Mtetra
.722 .811 .92 r
.399 .53768 .40882 .54579 .42537 .53645 .4156 .52938 Mtetra
.775 .842 .903 r
.4156 .52938 .42537 .53645 .44207 .52366 .43234 .51844 Mtetra
.845 .881 .867 r
.43234 .51844 .44207 .52366 .4589 .50531 .44923 .50306 Mtetra
.916 .913 .801 r
.44923 .50306 .4589 .50531 .47582 .47917 .46624 .48093 Mtetra
.962 .925 .715 r
.46624 .48093 .47582 .47917 .49271 .4445 .48329 .45026 Mtetra
.977 .921 .638 r
.48329 .45026 .49271 .4445 .50944 .40425 .50024 .41198 Mtetra
.975 .918 .6 r
.50024 .41198 .50944 .40425 .52591 .3648 .51697 .37107 Mtetra
.97 .929 .623 r
.51697 .37107 .52591 .3648 .54216 .33191 .53344 .33422 Mtetra
.958 .945 .706 r
.53344 .33422 .54216 .33191 .55832 .30751 .54974 .30544 Mtetra
.915 .935 .806 r
.54974 .30544 .55832 .30751 .57449 .29028 .56601 .28478 Mtetra
.843 .89 .872 r
.56601 .28478 .57449 .29028 .59075 .27793 .58233 .27017 Mtetra
.774 .836 .899 r
.58233 .27017 .59075 .27793 .6071 .26853 .59875 .25941 Mtetra
.726 .796 .907 r
.59875 .25941 .6071 .26853 .62357 .26078 .61527 .25087 Mtetra
.698 .772 .909 r
.61527 .25087 .62357 .26078 .64015 .25392 .63191 .24354 Mtetra
.682 .758 .909 r
.63191 .24354 .64015 .25392 .65684 .24751 .64866 .23687 Mtetra
.673 .75 .908 r
.64866 .23687 .65684 .24751 .67363 .24134 .66552 .23051 Mtetra
.669 .746 .908 r
.66552 .23051 .67363 .24134 .69053 .23527 .68249 .22432 Mtetra
.666 .744 .908 r
.68249 .22432 .69053 .23527 .70754 .22924 .69956 .21819 Mtetra
.665 .743 .908 r
.69956 .21819 .70754 .22924 .72464 .22321 .71674 .21207 Mtetra
.664 .742 .908 r
.71674 .21207 .72464 .22321 .74185 .21716 .73402 .20595 Mtetra
.73402 .20595 .74185 .21716 .75917 .21109 .75141 .19981 Mtetra
.664 .741 .908 r
.75141 .19981 .75917 .21109 .77659 .20498 .76891 .19363 Mtetra
.76891 .19363 .77659 .20498 .79412 .19885 .78651 .18743 Mtetra
.78651 .18743 .79412 .19885 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .5959 .21314 .58698 Mtetra
.21314 .58698 .22368 .5959 .23913 .59108 .22865 .5821 Mtetra
.22865 .5821 .23913 .59108 .25468 .58622 .24425 .5772 Mtetra
.646 .763 .934 r
.24425 .5772 .25468 .58622 .27032 .58134 .25995 .57226 Mtetra
.25995 .57226 .27032 .58134 .28605 .57641 .27573 .56728 Mtetra
.647 .763 .934 r
.27573 .56728 .28605 .57641 .30188 .57144 .29162 .56226 Mtetra
.29162 .56226 .30188 .57144 .3178 .5664 .3076 .55719 Mtetra
.648 .764 .933 r
.3076 .55719 .3178 .5664 .33383 .56127 .32369 .55204 Mtetra
.651 .765 .933 r
.32369 .55204 .33383 .56127 .34996 .556 .33987 .54678 Mtetra
.655 .768 .933 r
.33987 .54678 .34996 .556 .36619 .55047 .35616 .54132 Mtetra
.663 .773 .931 r
.35616 .54132 .36619 .55047 .38254 .54448 .37256 .53552 Mtetra
.678 .783 .929 r
.37256 .53552 .38254 .54448 .399 .53768 .38908 .52911 Mtetra
.703 .799 .924 r
.38908 .52911 .399 .53768 .4156 .52938 .40573 .52158 Mtetra
.746 .825 .913 r
.40573 .52158 .4156 .52938 .43234 .51844 .42251 .51206 Mtetra
.808 .861 .888 r
.42251 .51206 .43234 .51844 .44923 .50306 .43945 .49906 Mtetra
.882 .899 .838 r
.43945 .49906 .44923 .50306 .46624 .48093 .45653 .48048 Mtetra
.943 .922 .759 r
.45653 .48048 .46624 .48093 .48329 .45026 .4737 .45404 Mtetra
.973 .924 .673 r
.4737 .45404 .48329 .45026 .50024 .41198 .49085 .41902 Mtetra
.977 .918 .612 r
.49085 .41902 .50024 .41198 .51697 .37107 .50783 .3784 Mtetra
.972 .921 .603 r
.50783 .3784 .51697 .37107 .53344 .33422 .52454 .33858 Mtetra
.966 .938 .659 r
.52454 .33858 .53344 .33422 .54974 .30544 .54103 .30538 Mtetra
.941 .945 .758 r
.54103 .30538 .54974 .30544 .56601 .28478 .55742 .28072 Mtetra
.881 .915 .845 r
.55742 .28072 .56601 .28478 .58233 .27017 .57382 .26327 Mtetra
.807 .862 .889 r
.57382 .26327 .58233 .27017 .59875 .25941 .5903 .25073 Mtetra
.748 .814 .905 r
.5903 .25073 .59875 .25941 .61527 .25087 .60688 .24115 Mtetra
.71 .782 .908 r
.60688 .24115 .61527 .25087 .63191 .24354 .62358 .23322 Mtetra
.689 .764 .909 r
.62358 .23322 .63191 .24354 .64866 .23687 .6404 .22619 Mtetra
.677 .753 .909 r
.6404 .22619 .64866 .23687 .66552 .23051 .65732 .21962 Mtetra
.671 .748 .908 r
.65732 .21962 .66552 .23051 .68249 .22432 .67436 .21327 Mtetra
.667 .745 .908 r
.67436 .21327 .68249 .22432 .69956 .21819 .6915 .20703 Mtetra
.665 .743 .908 r
.6915 .20703 .69956 .21819 .71674 .21207 .70875 .20083 Mtetra
.665 .742 .908 r
.70875 .20083 .71674 .21207 .73402 .20595 .72611 .19462 Mtetra
.664 .742 .908 r
.72611 .19462 .73402 .20595 .75141 .19981 .74357 .1884 Mtetra
.74357 .1884 .75141 .19981 .76891 .19363 .76114 .18215 Mtetra
.664 .741 .908 r
.76114 .18215 .76891 .19363 .78651 .18743 .77882 .17587 Mtetra
.77882 .17587 .78651 .18743 .80423 .18118 .79661 .16956 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .5821 .21805 .57303 Mtetra
.21805 .57303 .22865 .5821 .24425 .5772 .23371 .56807 Mtetra
.23371 .56807 .24425 .5772 .25995 .57226 .24946 .56308 Mtetra
.646 .763 .934 r
.24946 .56308 .25995 .57226 .27573 .56728 .2653 .55805 Mtetra
.2653 .55805 .27573 .56728 .29162 .56226 .28125 .55298 Mtetra
.647 .763 .934 r
.28125 .55298 .29162 .56226 .3076 .55719 .29729 .54787 Mtetra
.648 .764 .933 r
.29729 .54787 .3076 .55719 .32369 .55204 .31343 .54269 Mtetra
.649 .765 .933 r
.31343 .54269 .32369 .55204 .33987 .54678 .32967 .53741 Mtetra
.653 .767 .933 r
.32967 .53741 .33987 .54678 .35616 .54132 .34602 .53199 Mtetra
.658 .77 .932 r
.34602 .53199 .35616 .54132 .37256 .53552 .36248 .52631 Mtetra
.669 .777 .93 r
.36248 .52631 .37256 .53552 .38908 .52911 .37905 .52017 Mtetra
.689 .79 .927 r
.37905 .52017 .38908 .52911 .40573 .52158 .39575 .5132 Mtetra
.722 .811 .92 r
.39575 .5132 .40573 .52158 .42251 .51206 .41258 .50473 Mtetra
.775 .842 .903 r
.41258 .50473 .42251 .51206 .43945 .49906 .42956 .4936 Mtetra
.845 .881 .867 r
.42956 .4936 .43945 .49906 .45653 .48048 .4467 .47799 Mtetra
.916 .913 .801 r
.4467 .47799 .45653 .48048 .4737 .45404 .46396 .45559 Mtetra
.962 .925 .715 r
.46396 .45559 .4737 .45404 .49085 .41902 .48127 .42459 Mtetra
.977 .921 .637 r
.48127 .42459 .49085 .41902 .50783 .3784 .49848 .38594 Mtetra
.975 .918 .6 r
.49848 .38594 .50783 .3784 .52454 .33858 .51546 .34465 Mtetra
.97 .929 .623 r
.51546 .34465 .52454 .33858 .54103 .30538 .53217 .30746 Mtetra
.958 .945 .706 r
.53217 .30746 .54103 .30538 .55742 .28072 .54871 .2784 Mtetra
.915 .935 .806 r
.54871 .2784 .55742 .28072 .57382 .26327 .56521 .2575 Mtetra
.843 .889 .872 r
.56521 .2575 .57382 .26327 .5903 .25073 .58176 .24268 Mtetra
.774 .836 .899 r
.58176 .24268 .5903 .25073 .60688 .24115 .59841 .23173 Mtetra
.726 .796 .907 r
.59841 .23173 .60688 .24115 .62358 .23322 .61517 .223 Mtetra
.698 .772 .909 r
.61517 .223 .62358 .23322 .6404 .22619 .63204 .21551 Mtetra
.682 .758 .909 r
.63204 .21551 .6404 .22619 .65732 .21962 .64903 .20866 Mtetra
.673 .75 .908 r
.64903 .20866 .65732 .21962 .67436 .21327 .66614 .20213 Mtetra
.669 .746 .908 r
.66614 .20213 .67436 .21327 .6915 .20703 .68335 .19576 Mtetra
.666 .744 .908 r
.68335 .19576 .6915 .20703 .70875 .20083 .70067 .18946 Mtetra
.665 .743 .908 r
.70067 .18946 .70875 .20083 .72611 .19462 .7181 .18317 Mtetra
.664 .742 .908 r
.7181 .18317 .72611 .19462 .74357 .1884 .73564 .17687 Mtetra
.73564 .17687 .74357 .1884 .76114 .18215 .75328 .17055 Mtetra
.664 .741 .908 r
.75328 .17055 .76114 .18215 .77882 .17587 .77104 .16419 Mtetra
.77104 .16419 .77882 .17587 .79661 .16956 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56385 Mtetra
.20734 .56385 .21805 .57303 .23371 .56807 .22305 .55884 Mtetra
.22305 .55884 .23371 .56807 .24946 .56308 .23885 .55379 Mtetra
.646 .763 .934 r
.23885 .55379 .24946 .56308 .2653 .55805 .25476 .54871 Mtetra
.25476 .54871 .2653 .55805 .28125 .55298 .27076 .54359 Mtetra
.647 .763 .934 r
.27076 .54359 .28125 .55298 .29729 .54787 .28686 .53843 Mtetra
.28686 .53843 .29729 .54787 .31343 .54269 .30305 .53321 Mtetra
.648 .764 .933 r
.30305 .53321 .31343 .54269 .32967 .53741 .31936 .52791 Mtetra
.651 .765 .933 r
.31936 .52791 .32967 .53741 .34602 .53199 .33576 .5225 Mtetra
.655 .768 .933 r
.33576 .5225 .34602 .53199 .36248 .52631 .35228 .51689 Mtetra
.663 .773 .931 r
.35228 .51689 .36248 .52631 .37905 .52017 .36891 .51093 Mtetra
.678 .783 .929 r
.36891 .51093 .37905 .52017 .39575 .5132 .38566 .50436 Mtetra
.703 .799 .924 r
.38566 .50436 .39575 .5132 .41258 .50473 .40254 .49666 Mtetra
.746 .825 .913 r
.40254 .49666 .41258 .50473 .42956 .4936 .41957 .48695 Mtetra
.808 .862 .888 r
.41957 .48695 .42956 .4936 .4467 .47799 .43675 .47374 Mtetra
.882 .899 .838 r
.43675 .47374 .4467 .47799 .46396 .45559 .45409 .45491 Mtetra
.943 .922 .759 r
.45409 .45491 .46396 .45559 .48127 .42459 .47152 .42817 Mtetra
.973 .924 .673 r
.47152 .42817 .48127 .42459 .49848 .38594 .48893 .39279 Mtetra
.977 .918 .612 r
.48893 .39279 .49848 .38594 .51546 .34465 .50617 .35179 Mtetra
.972 .921 .604 r
.50617 .35179 .51546 .34465 .53217 .30746 .52313 .31161 Mtetra
.966 .938 .659 r
.52313 .31161 .53217 .30746 .54871 .2784 .53987 .2781 Mtetra
.941 .945 .758 r
.53987 .2781 .54871 .2784 .56521 .2575 .55649 .25316 Mtetra
.881 .915 .845 r
.55649 .25316 .56521 .2575 .58176 .24268 .57313 .23549 Mtetra
.807 .862 .889 r
.57313 .23549 .58176 .24268 .59841 .23173 .58984 .22275 Mtetra
.748 .814 .905 r
.58984 .22275 .59841 .23173 .61517 .223 .60666 .21298 Mtetra
.71 .782 .908 r
.60666 .21298 .61517 .223 .63204 .21551 .6236 .20487 Mtetra
.689 .764 .909 r
.6236 .20487 .63204 .21551 .64903 .20866 .64065 .19766 Mtetra
.677 .753 .909 r
.64065 .19766 .64903 .20866 .66614 .20213 .65782 .19091 Mtetra
.671 .748 .908 r
.65782 .19091 .66614 .20213 .68335 .19576 .6751 .18439 Mtetra
.667 .745 .908 r
.6751 .18439 .68335 .19576 .70067 .18946 .6925 .17797 Mtetra
.665 .743 .908 r
.6925 .17797 .70067 .18946 .7181 .18317 .71 .17159 Mtetra
.665 .742 .908 r
.71 .17159 .7181 .18317 .73564 .17687 .72761 .16521 Mtetra
.664 .742 .908 r
.72761 .16521 .73564 .17687 .75328 .17055 .74533 .15881 Mtetra
.74533 .15881 .75328 .17055 .77104 .16419 .76317 .15237 Mtetra
.664 .741 .908 r
.76317 .15237 .77104 .16419 .78891 .1578 .78111 .14591 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56385 .1965 .55458 Mtetra
.1965 .55458 .20734 .56385 .22305 .55884 .21227 .5495 Mtetra
.21227 .5495 .22305 .55884 .23885 .55379 .22813 .5444 Mtetra
.22813 .5444 .23885 .55379 .25476 .54871 .24409 .53926 Mtetra
.646 .763 .934 r
.24409 .53926 .25476 .54871 .27076 .54359 .26015 .53409 Mtetra
.26015 .53409 .27076 .54359 .28686 .53843 .2763 .52887 Mtetra
.647 .763 .934 r
.2763 .52887 .28686 .53843 .30305 .53321 .29256 .52361 Mtetra
.648 .764 .933 r
.29256 .52361 .30305 .53321 .31936 .52791 .30892 .51828 Mtetra
.649 .765 .933 r
.30892 .51828 .31936 .52791 .33576 .5225 .32539 .51285 Mtetra
.653 .767 .933 r
.32539 .51285 .33576 .5225 .35228 .51689 .34196 .50728 Mtetra
.658 .77 .932 r
.34196 .50728 .35228 .51689 .36891 .51093 .35865 .50144 Mtetra
.669 .777 .931 r
.35865 .50144 .36891 .51093 .38566 .50436 .37546 .49514 Mtetra
.689 .79 .927 r
.37546 .49514 .38566 .50436 .40254 .49666 .39239 .488 Mtetra
.722 .811 .92 r
.39239 .488 .40254 .49666 .41957 .48695 .40947 .47935 Mtetra
.775 .842 .903 r
.40947 .47935 .41957 .48695 .43675 .47374 .4267 .46802 Mtetra
.845 .881 .867 r
.4267 .46802 .43675 .47374 .45409 .45491 .44409 .45218 Mtetra
.916 .914 .801 r
.44409 .45218 .45409 .45491 .47152 .42817 .46161 .42949 Mtetra
.962 .925 .715 r
.46161 .42949 .47152 .42817 .48893 .39279 .47919 .39817 Mtetra
.977 .921 .637 r
.47919 .39817 .48893 .39279 .50617 .35179 .49666 .35914 Mtetra
.975 .918 .6 r
.49666 .35914 .50617 .35179 .52313 .31161 .5139 .31748 Mtetra
.97 .929 .624 r
.5139 .31748 .52313 .31161 .53987 .2781 .53087 .27994 Mtetra
.958 .945 .707 r
.53087 .27994 .53987 .2781 .55649 .25316 .54765 .25058 Mtetra
.915 .935 .806 r
.54765 .25058 .55649 .25316 .57313 .23549 .56439 .22943 Mtetra
.843 .889 .872 r
.56439 .22943 .57313 .23549 .58984 .22275 .58118 .2144 Mtetra
.774 .836 .899 r
.58118 .2144 .58984 .22275 .60666 .21298 .59806 .20325 Mtetra
.726 .796 .907 r
.59806 .20325 .60666 .21298 .6236 .20487 .61506 .19434 Mtetra
.698 .772 .909 r
.61506 .19434 .6236 .20487 .64065 .19766 .63218 .18666 Mtetra
.682 .758 .909 r
.63218 .18666 .64065 .19766 .65782 .19091 .64942 .17963 Mtetra
.673 .75 .908 r
.64942 .17963 .65782 .19091 .6751 .18439 .66677 .17293 Mtetra
.669 .746 .908 r
.66677 .17293 .6751 .18439 .6925 .17797 .68423 .16638 Mtetra
.666 .744 .908 r
.68423 .16638 .6925 .17797 .71 .17159 .70181 .15989 Mtetra
.665 .743 .908 r
.70181 .15989 .71 .17159 .72761 .16521 .71949 .15342 Mtetra
.664 .742 .908 r
.71949 .15342 .72761 .16521 .74533 .15881 .73729 .14693 Mtetra
.73729 .14693 .74533 .15881 .76317 .15237 .75521 .14042 Mtetra
.664 .741 .908 r
.75521 .14042 .76317 .15237 .78111 .14591 .77323 .13388 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .5495 .20137 .54006 Mtetra
.20137 .54006 .21227 .5495 .22813 .5444 .21728 .5349 Mtetra
.21728 .5349 .22813 .5444 .24409 .53926 .2333 .52971 Mtetra
.646 .763 .934 r
.2333 .52971 .24409 .53926 .26015 .53409 .24942 .52448 Mtetra
.24942 .52448 .26015 .53409 .2763 .52887 .26563 .51921 Mtetra
.647 .763 .934 r
.26563 .51921 .2763 .52887 .29256 .52361 .28195 .51389 Mtetra
.28195 .51389 .29256 .52361 .30892 .51828 .29837 .50852 Mtetra
.648 .764 .933 r
.29837 .50852 .30892 .51828 .32539 .51285 .3149 .50307 Mtetra
.651 .765 .933 r
.3149 .50307 .32539 .51285 .34196 .50728 .33153 .4975 Mtetra
.655 .768 .933 r
.33153 .4975 .34196 .50728 .35865 .50144 .34828 .49173 Mtetra
.663 .773 .931 r
.34828 .49173 .35865 .50144 .37546 .49514 .36514 .48561 Mtetra
.678 .783 .929 r
.36514 .48561 .37546 .49514 .39239 .488 .38213 .47887 Mtetra
.703 .799 .924 r
.38213 .47887 .39239 .488 .40947 .47935 .39926 .471 Mtetra
.746 .825 .913 r
.39926 .471 .40947 .47935 .4267 .46802 .41654 .46109 Mtetra
.808 .862 .888 r
.41654 .46109 .4267 .46802 .44409 .45218 .43397 .44767 Mtetra
.882 .9 .838 r
.43397 .44767 .44409 .45218 .46161 .42949 .45157 .42857 Mtetra
.943 .922 .759 r
.45157 .42857 .46161 .42949 .47919 .39817 .46927 .40153 Mtetra
.973 .924 .673 r
.46927 .40153 .47919 .39817 .49666 .35914 .48695 .36579 Mtetra
.977 .918 .612 r
.48695 .36579 .49666 .35914 .5139 .31748 .50446 .32441 Mtetra
.972 .921 .604 r
.50446 .32441 .5139 .31748 .53087 .27994 .52169 .28386 Mtetra
.966 .938 .66 r
.52169 .28386 .53087 .27994 .54765 .25058 .53867 .25002 Mtetra
.941 .945 .758 r
.53867 .25002 .54765 .25058 .56439 .22943 .55554 .22482 Mtetra
.881 .915 .845 r
.55554 .22482 .56439 .22943 .58118 .2144 .57242 .20691 Mtetra
.807 .862 .889 r
.57242 .20691 .58118 .2144 .59806 .20325 .58937 .19396 Mtetra
.748 .814 .905 r
.58937 .19396 .59806 .20325 .61506 .19434 .60643 .184 Mtetra
.71 .782 .908 r
.60643 .184 .61506 .19434 .63218 .18666 .62361 .1757 Mtetra
.689 .764 .909 r
.62361 .1757 .63218 .18666 .64942 .17963 .64092 .16831 Mtetra
.677 .753 .909 r
.64092 .16831 .64942 .17963 .66677 .17293 .65834 .16138 Mtetra
.671 .748 .908 r
.65834 .16138 .66677 .17293 .68423 .16638 .67587 .15467 Mtetra
.667 .745 .908 r
.67587 .15467 .68423 .16638 .70181 .15989 .69352 .14807 Mtetra
.665 .743 .908 r
.69352 .14807 .70181 .15989 .71949 .15342 .71128 .1415 Mtetra
.665 .742 .908 r
.71128 .1415 .71949 .15342 .73729 .14693 .72916 .13492 Mtetra
.664 .742 .908 r
.72916 .13492 .73729 .14693 .75521 .14042 .74715 .12833 Mtetra
.74715 .12833 .75521 .14042 .77323 .13388 .76526 .12171 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54006 .19034 .53051 Mtetra
.19034 .53051 .20137 .54006 .21728 .5349 .20631 .5253 Mtetra
.20631 .5253 .21728 .5349 .2333 .52971 .22239 .52004 Mtetra
.22239 .52004 .2333 .52971 .24942 .52448 .23856 .51475 Mtetra
.646 .763 .934 r
.23856 .51475 .24942 .52448 .26563 .51921 .25484 .50943 Mtetra
.25484 .50943 .26563 .51921 .28195 .51389 .27122 .50406 Mtetra
.647 .763 .934 r
.27122 .50406 .28195 .51389 .29837 .50852 .2877 .49864 Mtetra
.648 .764 .933 r
.2877 .49864 .29837 .50852 .3149 .50307 .30429 .49315 Mtetra
.649 .765 .933 r
.30429 .49315 .3149 .50307 .33153 .4975 .32098 .48757 Mtetra
.653 .767 .933 r
.32098 .48757 .33153 .4975 .34828 .49173 .33779 .48183 Mtetra
.658 .77 .932 r
.33779 .48183 .34828 .49173 .36514 .48561 .35471 .47583 Mtetra
.669 .777 .931 r
.35471 .47583 .36514 .48561 .38213 .47887 .37176 .46936 Mtetra
.689 .79 .927 r
.37176 .46936 .38213 .47887 .39926 .471 .38894 .46204 Mtetra
.722 .811 .92 r
.38894 .46204 .39926 .471 .41654 .46109 .40626 .4532 Mtetra
.775 .843 .903 r
.40626 .4532 .41654 .46109 .43397 .44767 .42375 .44166 Mtetra
.845 .882 .867 r
.42375 .44166 .43397 .44767 .45157 .42857 .4414 .42559 Mtetra
.916 .914 .801 r
.4414 .42559 .45157 .42857 .46927 .40153 .45919 .40262 Mtetra
.962 .925 .715 r
.45919 .40262 .46927 .40153 .48695 .36579 .47704 .37095 Mtetra
.977 .921 .637 r
.47704 .37095 .48695 .36579 .50446 .32441 .49479 .33155 Mtetra
.975 .918 .6 r
.49479 .33155 .50446 .32441 .52169 .28386 .5123 .2895 Mtetra
.97 .929 .624 r
.5123 .2895 .52169 .28386 .53867 .25002 .52953 .25161 Mtetra
.958 .945 .707 r
.52953 .25161 .53867 .25002 .55554 .22482 .54656 .22196 Mtetra
.915 .935 .807 r
.54656 .22196 .55554 .22482 .57242 .20691 .56355 .20055 Mtetra
.843 .889 .872 r
.56355 .20055 .57242 .20691 .58937 .19396 .58058 .1853 Mtetra
.774 .836 .899 r
.58058 .1853 .58937 .19396 .60643 .184 .59771 .17395 Mtetra
.726 .796 .907 r
.59771 .17395 .60643 .184 .62361 .1757 .61495 .16484 Mtetra
.698 .772 .909 r
.61495 .16484 .62361 .1757 .64092 .16831 .63232 .15698 Mtetra
.682 .758 .909 r
.63232 .15698 .64092 .16831 .65834 .16138 .64981 .14976 Mtetra
.673 .75 .908 r
.64981 .14976 .65834 .16138 .67587 .15467 .66742 .14286 Mtetra
.669 .746 .908 r
.66742 .14286 .67587 .15467 .69352 .14807 .68514 .13612 Mtetra
.666 .744 .908 r
.68514 .13612 .69352 .14807 .71128 .1415 .70298 .12945 Mtetra
.665 .743 .908 r
.70298 .12945 .71128 .1415 .72916 .13492 .72093 .12278 Mtetra
.664 .742 .908 r
.72093 .12278 .72916 .13492 .74715 .12833 .739 .1161 Mtetra
.739 .1161 .74715 .12833 .76526 .12171 .75719 .1094 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53051 .17919 .52086 Mtetra
.17919 .52086 .19034 .53051 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52004 .21135 .51026 Mtetra
.21135 .51026 .22239 .52004 .23856 .51475 .22758 .50492 Mtetra
.646 .763 .934 r
.22758 .50492 .23856 .51475 .25484 .50943 .24392 .49953 Mtetra
.24392 .49953 .25484 .50943 .27122 .50406 .26036 .49411 Mtetra
.647 .763 .934 r
.26036 .49411 .27122 .50406 .2877 .49864 .2769 .48863 Mtetra
.2769 .48863 .2877 .49864 .30429 .49315 .29355 .4831 Mtetra
.648 .764 .933 r
.29355 .4831 .30429 .49315 .32098 .48757 .31031 .47749 Mtetra
.651 .765 .933 r
.31031 .47749 .32098 .48757 .33779 .48183 .32718 .47175 Mtetra
.655 .768 .933 r
.32718 .47175 .33779 .48183 .35471 .47583 .34416 .46582 Mtetra
.663 .773 .931 r
.34416 .46582 .35471 .47583 .37176 .46936 .36127 .45953 Mtetra
.678 .783 .929 r
.36127 .45953 .37176 .46936 .38894 .46204 .3785 .45261 Mtetra
.703 .799 .924 r
.3785 .45261 .38894 .46204 .40626 .4532 .39588 .44455 Mtetra
.746 .825 .913 r
.39588 .44455 .40626 .4532 .42375 .44166 .41341 .43445 Mtetra
.808 .862 .888 r
.41341 .43445 .42375 .44166 .4414 .42559 .43111 .4208 Mtetra
.882 .9 .838 r
.43111 .4208 .4414 .42559 .45919 .40262 .44898 .40144 Mtetra
.943 .923 .759 r
.44898 .40144 .45919 .40262 .47704 .37095 .46695 .37408 Mtetra
.973 .924 .672 r
.46695 .37408 .47704 .37095 .49479 .33155 .48491 .33798 Mtetra
.977 .918 .612 r
.48491 .33798 .49479 .33155 .5123 .2895 .5027 .2962 Mtetra
.972 .921 .604 r
.5027 .2962 .5123 .2895 .52953 .25161 .5202 .25528 Mtetra
.966 .938 .66 r
.5202 .25528 .52953 .25161 .54656 .22196 .53744 .22112 Mtetra
.941 .945 .759 r
.53744 .22112 .54656 .22196 .56355 .20055 .55456 .19564 Mtetra
.881 .915 .845 r
.55456 .19564 .56355 .20055 .58058 .1853 .57168 .1775 Mtetra
.807 .861 .889 r
.57168 .1775 .58058 .1853 .59771 .17395 .58888 .16433 Mtetra
.748 .814 .904 r
.58888 .16433 .59771 .17395 .61495 .16484 .6062 .15416 Mtetra
.71 .782 .908 r
.6062 .15416 .61495 .16484 .63232 .15698 .62363 .14568 Mtetra
.689 .764 .909 r
.62363 .14568 .63232 .15698 .64981 .14976 .64119 .13809 Mtetra
.677 .753 .909 r
.64119 .13809 .64981 .14976 .66742 .14286 .65887 .13096 Mtetra
.671 .748 .908 r
.65887 .13096 .66742 .14286 .68514 .13612 .67666 .12407 Mtetra
.667 .745 .908 r
.67666 .12407 .68514 .13612 .70298 .12945 .69458 .11727 Mtetra
.665 .743 .908 r
.69458 .11727 .70298 .12945 .72093 .12278 .71261 .1105 Mtetra
.665 .742 .908 r
.71261 .1105 .72093 .12278 .739 .1161 .73076 .10374 Mtetra
.664 .742 .908 r
.73076 .10374 .739 .1161 .75719 .1094 .74902 .09694 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51026 .20018 .50037 Mtetra
.20018 .50037 .21135 .51026 .22758 .50492 .21648 .49496 Mtetra
.21648 .49496 .22758 .50492 .24392 .49953 .23287 .48952 Mtetra
.646 .763 .934 r
.23287 .48952 .24392 .49953 .26036 .49411 .24937 .48403 Mtetra
.24937 .48403 .26036 .49411 .2769 .48863 .26598 .4785 Mtetra
.647 .763 .934 r
.26598 .4785 .2769 .48863 .29355 .4831 .28269 .47292 Mtetra
.648 .764 .933 r
.28269 .47292 .29355 .4831 .31031 .47749 .29951 .46727 Mtetra
.649 .765 .933 r
.29951 .46727 .31031 .47749 .32718 .47175 .31644 .46152 Mtetra
.653 .767 .933 r
.31644 .46152 .32718 .47175 .34416 .46582 .33349 .45561 Mtetra
.658 .77 .932 r
.33349 .45561 .34416 .46582 .36127 .45953 .35066 .44944 Mtetra
.669 .777 .931 r
.35066 .44944 .36127 .45953 .3785 .45261 .36795 .44279 Mtetra
.689 .79 .927 r
.36795 .44279 .3785 .45261 .39588 .44455 .38538 .4353 Mtetra
.722 .811 .92 r
.38538 .4353 .39588 .44455 .41341 .43445 .40296 .42626 Mtetra
.775 .843 .903 r
.40296 .42626 .41341 .43445 .43111 .4208 .42071 .41451 Mtetra
.845 .882 .867 r
.42071 .41451 .43111 .4208 .44898 .40144 .43863 .39818 Mtetra
.916 .914 .801 r
.43863 .39818 .44898 .40144 .46695 .37408 .4567 .37492 Mtetra
.962 .926 .714 r
.4567 .37492 .46695 .37408 .48491 .33798 .47483 .34291 Mtetra
.977 .921 .637 r
.47483 .34291 .48491 .33798 .5027 .2962 .49287 .30312 Mtetra
.975 .918 .6 r
.49287 .30312 .5027 .2962 .5202 .25528 .51066 .26068 Mtetra
.97 .929 .624 r
.51066 .26068 .5202 .25528 .53744 .22112 .52815 .22244 Mtetra
.958 .945 .707 r
.52815 .22244 .53744 .22112 .55456 .19564 .54544 .19249 Mtetra
.915 .934 .807 r
.54544 .19249 .55456 .19564 .57168 .1775 .56268 .17082 Mtetra
.843 .889 .872 r
.56268 .17082 .57168 .1775 .58888 .16433 .57996 .15534 Mtetra
.774 .836 .899 r
.57996 .15534 .58888 .16433 .6062 .15416 .59734 .14378 Mtetra
.726 .796 .907 r
.59734 .14378 .6062 .15416 .62363 .14568 .61484 .13447 Mtetra
.698 .772 .909 r
.61484 .13447 .62363 .14568 .64119 .13809 .63247 .12641 Mtetra
.682 .758 .909 r
.63247 .12641 .64119 .13809 .65887 .13096 .65022 .11899 Mtetra
.673 .75 .908 r
.65022 .11899 .65887 .13096 .67666 .12407 .66809 .1119 Mtetra
.669 .746 .908 r
.66809 .1119 .67666 .12407 .69458 .11727 .68608 .10497 Mtetra
.666 .744 .908 r
.68608 .10497 .69458 .11727 .71261 .1105 .70419 .09809 Mtetra
.665 .743 .908 r
.70419 .09809 .71261 .1105 .73076 .10374 .72241 .09122 Mtetra
.664 .742 .908 r
.72241 .09122 .73076 .10374 .74902 .09694 .74076 .08434 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50037 .18889 .49037 Mtetra
.18889 .49037 .20018 .50037 .21648 .49496 .20524 .48489 Mtetra
.20524 .48489 .21648 .49496 .23287 .48952 .2217 .47939 Mtetra
.646 .763 .934 r
.2217 .47939 .23287 .48952 .24937 .48403 .23826 .47384 Mtetra
.23826 .47384 .24937 .48403 .26598 .4785 .25492 .46825 Mtetra
.647 .763 .934 r
.25492 .46825 .26598 .4785 .28269 .47292 .2717 .46261 Mtetra
.2717 .46261 .28269 .47292 .29951 .46727 .28858 .45691 Mtetra
.648 .764 .933 r
.28858 .45691 .29951 .46727 .31644 .46152 .30558 .45113 Mtetra
.651 .765 .933 r
.30558 .45113 .31644 .46152 .33349 .45561 .32269 .44523 Mtetra
.655 .768 .933 r
.32269 .44523 .33349 .45561 .35066 .44944 .33992 .43912 Mtetra
.663 .773 .931 r
.33992 .43912 .35066 .44944 .36795 .44279 .35727 .43265 Mtetra
.678 .783 .929 r
.35727 .43265 .36795 .44279 .38538 .4353 .37476 .42555 Mtetra
.703 .799 .924 r
.37476 .42555 .38538 .4353 .40296 .42626 .3924 .4173 Mtetra
.746 .825 .913 r
.3924 .4173 .40296 .42626 .42071 .41451 .41019 .40699 Mtetra
.808 .862 .888 r
.41019 .40699 .42071 .41451 .43863 .39818 .42816 .3931 Mtetra
.882 .9 .838 r
.42816 .3931 .43863 .39818 .4567 .37492 .4463 .37347 Mtetra
.943 .923 .759 r
.4463 .37347 .4567 .37492 .47483 .34291 .46456 .34579 Mtetra
.973 .924 .672 r
.46456 .34579 .47483 .34291 .49287 .30312 .48282 .30932 Mtetra
.977 .918 .612 r
.48282 .30932 .49287 .30312 .51066 .26068 .50089 .26715 Mtetra
.972 .921 .604 r
.50089 .26715 .51066 .26068 .52815 .22244 .51866 .22585 Mtetra
.966 .938 .66 r
.51866 .22585 .52815 .22244 .54544 .19249 .53617 .19136 Mtetra
.941 .944 .759 r
.53617 .19136 .54544 .19249 .56268 .17082 .55355 .1656 Mtetra
.881 .915 .845 r
.55355 .1656 .56268 .17082 .57996 .15534 .57093 .14721 Mtetra
.807 .861 .889 r
.57093 .14721 .57996 .15534 .59734 .14378 .58838 .13382 Mtetra
.748 .814 .904 r
.58838 .13382 .59734 .14378 .61484 .13447 .60595 .12344 Mtetra
.71 .782 .908 r
.60595 .12344 .61484 .13447 .63247 .12641 .62365 .11475 Mtetra
.689 .764 .909 r
.62365 .11475 .63247 .12641 .65022 .11899 .64147 .10697 Mtetra
.677 .753 .909 r
.64147 .10697 .65022 .11899 .66809 .1119 .65941 .09964 Mtetra
.671 .748 .908 r
.65941 .09964 .66809 .1119 .68608 .10497 .67748 .09254 Mtetra
.667 .745 .908 r
.67748 .09254 .68608 .10497 .70419 .09809 .69567 .08554 Mtetra
.665 .743 .908 r
.69567 .08554 .70419 .09809 .72241 .09122 .71397 .07857 Mtetra
.665 .742 .908 r
.71397 .07857 .72241 .09122 .74076 .08434 .7324 .0716 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .48489 .19387 .47471 Mtetra
.19387 .47471 .20524 .48489 .2217 .47939 .21039 .46913 Mtetra
.21039 .46913 .2217 .47939 .23826 .47384 .22701 .46352 Mtetra
.646 .763 .934 r
.22701 .46352 .23826 .47384 .25492 .46825 .24374 .45787 Mtetra
.24374 .45787 .25492 .46825 .2717 .46261 .26058 .45217 Mtetra
.647 .763 .934 r
.26058 .45217 .2717 .46261 .28858 .45691 .27753 .44642 Mtetra
.648 .764 .933 r
.27753 .44642 .28858 .45691 .30558 .45113 .29459 .4406 Mtetra
.649 .765 .933 r
.29459 .4406 .30558 .45113 .32269 .44523 .31176 .43468 Mtetra
.653 .767 .933 r
.31176 .43468 .32269 .44523 .33992 .43912 .32906 .42859 Mtetra
.658 .77 .932 r
.32906 .42859 .33992 .43912 .35727 .43265 .34647 .42224 Mtetra
.669 .777 .931 r
.34647 .42224 .35727 .43265 .37476 .42555 .36402 .41541 Mtetra
.689 .79 .927 r
.36402 .41541 .37476 .42555 .3924 .4173 .38171 .40772 Mtetra
.722 .811 .92 r
.38171 .40772 .3924 .4173 .41019 .40699 .39956 .39848 Mtetra
.775 .843 .903 r
.39956 .39848 .41019 .40699 .42816 .3931 .41757 .3865 Mtetra
.845 .882 .867 r
.41757 .3865 .42816 .3931 .4463 .37347 .43577 .36992 Mtetra
.916 .914 .801 r
.43577 .36992 .4463 .37347 .46456 .34579 .45413 .34636 Mtetra
.962 .926 .714 r
.45413 .34636 .46456 .34579 .48282 .30932 .47255 .314 Mtetra
.977 .921 .637 r
.47255 .314 .48282 .30932 .50089 .26715 .49088 .27382 Mtetra
.975 .918 .6 r
.49088 .27382 .50089 .26715 .51866 .22585 .50896 .23099 Mtetra
.97 .929 .625 r
.50896 .23099 .51866 .22585 .53617 .19136 .52673 .19239 Mtetra
.958 .945 .707 r
.52673 .19239 .53617 .19136 .55355 .1656 .54428 .16213 Mtetra
.915 .934 .807 r
.54428 .16213 .55355 .1656 .57093 .14721 .56178 .1402 Mtetra
.843 .889 .872 r
.56178 .1402 .57093 .14721 .58838 .13382 .57932 .12449 Mtetra
.774 .836 .899 r
.57932 .12449 .58838 .13382 .60595 .12344 .59696 .1127 Mtetra
.726 .796 .907 r
.59696 .1127 .60595 .12344 .62365 .11475 .61472 .10319 Mtetra
.698 .772 .909 r
.61472 .10319 .62365 .11475 .64147 .10697 .63262 .09492 Mtetra
.682 .758 .909 r
.63262 .09492 .64147 .10697 .65941 .09964 .65063 .0873 Mtetra
.673 .75 .908 r
.65063 .0873 .65941 .09964 .67748 .09254 .66878 .08 Mtetra
.669 .746 .908 r
.66878 .08 .67748 .09254 .69567 .08554 .68704 .07286 Mtetra
.666 .744 .908 r
.68704 .07286 .69567 .08554 .71397 .07857 .70543 .06578 Mtetra
.665 .743 .908 r
.70543 .06578 .71397 .07857 .7324 .0716 .72394 .0587 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46913 .19895 .45876 Mtetra
.19895 .45876 .21039 .46913 .22701 .46352 .21563 .45308 Mtetra
.646 .763 .934 r
.21563 .45308 .22701 .46352 .24374 .45787 .23242 .44737 Mtetra
.23242 .44737 .24374 .45787 .26058 .45217 .24933 .44161 Mtetra
.647 .763 .934 r
.24933 .44161 .26058 .45217 .27753 .44642 .26634 .4358 Mtetra
.26634 .4358 .27753 .44642 .29459 .4406 .28346 .42992 Mtetra
.648 .764 .933 r
.28346 .42992 .29459 .4406 .31176 .43468 .30071 .42397 Mtetra
.651 .765 .933 r
.30071 .42397 .31176 .43468 .32906 .42859 .31806 .41788 Mtetra
.655 .768 .933 r
.31806 .41788 .32906 .42859 .34647 .42224 .33554 .41159 Mtetra
.663 .773 .931 r
.33554 .41159 .34647 .42224 .36402 .41541 .35315 .40494 Mtetra
.678 .783 .929 r
.35315 .40494 .36402 .41541 .38171 .40772 .3709 .39765 Mtetra
.703 .799 .924 r
.3709 .39765 .38171 .40772 .39956 .39848 .3888 .38919 Mtetra
.746 .826 .913 r
.3888 .38919 .39956 .39848 .41757 .3865 .40687 .37866 Mtetra
.808 .862 .888 r
.40687 .37866 .41757 .3865 .43577 .36992 .42512 .36454 Mtetra
.882 .9 .838 r
.42512 .36454 .43577 .36992 .45413 .34636 .44355 .34463 Mtetra
.943 .923 .759 r
.44355 .34463 .45413 .34636 .47255 .314 .4621 .31662 Mtetra
.973 .924 .672 r
.4621 .31662 .47255 .314 .49088 .27382 .48065 .27977 Mtetra
.977 .918 .612 r
.48065 .27977 .49088 .27382 .50896 .23099 .49902 .2372 Mtetra
.972 .921 .604 r
.49902 .2372 .50896 .23099 .52673 .19239 .51708 .19553 Mtetra
.966 .938 .66 r
.51708 .19553 .52673 .19239 .54428 .16213 .53486 .16069 Mtetra
.941 .944 .759 r
.53486 .16069 .54428 .16213 .56178 .1402 .55251 .13465 Mtetra
.881 .914 .845 r
.55251 .13465 .56178 .1402 .57932 .12449 .57015 .116 Mtetra
.807 .861 .889 r
.57015 .116 .57932 .12449 .59696 .1127 .58787 .10239 Mtetra
.748 .814 .904 r
.58787 .10239 .59696 .1127 .61472 .10319 .6057 .0918 Mtetra
.71 .782 .908 r
.6057 .0918 .61472 .10319 .63262 .09492 .62366 .08289 Mtetra
.689 .764 .909 r
.62366 .08289 .63262 .09492 .65063 .0873 .64175 .0749 Mtetra
.677 .753 .909 r
.64175 .0749 .65063 .0873 .66878 .08 .65997 .06736 Mtetra
.671 .748 .908 r
.65997 .06736 .66878 .08 .68704 .07286 .67832 .06005 Mtetra
.667 .745 .908 r
.67832 .06005 .68704 .07286 .70543 .06578 .69679 .05284 Mtetra
.665 .743 .908 r
.69679 .05284 .70543 .06578 .72394 .0587 .71538 .04566 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45396 Mtetra
.17073 .45396 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45308 .20411 .44252 Mtetra
.20411 .44252 .21563 .45308 .23242 .44737 .22097 .43673 Mtetra
.646 .763 .934 r
.22097 .43673 .23242 .44737 .24933 .44161 .23794 .43091 Mtetra
.23794 .43091 .24933 .44161 .26634 .4358 .25501 .42504 Mtetra
.647 .763 .934 r
.25501 .42504 .26634 .4358 .28346 .42992 .27221 .41911 Mtetra
.648 .764 .933 r
.27221 .41911 .28346 .42992 .30071 .42397 .28951 .4131 Mtetra
.649 .765 .933 r
.28951 .4131 .30071 .42397 .31806 .41788 .30694 .407 Mtetra
.653 .767 .933 r
.30694 .407 .31806 .41788 .33554 .41159 .32449 .40073 Mtetra
.658 .77 .932 r
.32449 .40073 .33554 .41159 .35315 .40494 .34216 .39419 Mtetra
.669 .777 .931 r
.34216 .39419 .35315 .40494 .3709 .39765 .35997 .38717 Mtetra
.689 .79 .927 r
.35997 .38717 .3709 .39765 .3888 .38919 .37793 .37928 Mtetra
.722 .811 .92 r
.37793 .37928 .3888 .38919 .40687 .37866 .39604 .36983 Mtetra
.775 .843 .903 r
.39604 .36983 .40687 .37866 .42512 .36454 .41434 .35762 Mtetra
.845 .882 .867 r
.41434 .35762 .42512 .36454 .44355 .34463 .43283 .34078 Mtetra
.916 .915 .801 r
.43283 .34078 .44355 .34463 .4621 .31662 .45148 .31691 Mtetra
.962 .926 .714 r
.45148 .31691 .4621 .31662 .48065 .27977 .4702 .28419 Mtetra
.977 .921 .636 r
.4702 .28419 .48065 .27977 .49902 .2372 .48884 .24362 Mtetra
.975 .918 .6 r
.48884 .24362 .49902 .2372 .51708 .19553 .50721 .20039 Mtetra
.97 .929 .625 r
.50721 .20039 .51708 .19553 .53486 .16069 .52526 .16143 Mtetra
.958 .944 .708 r
.52526 .16143 .53486 .16069 .55251 .13465 .54309 .13085 Mtetra
.915 .934 .807 r
.54309 .13085 .55251 .13465 .57015 .116 .56086 .10865 Mtetra
.843 .888 .872 r
.56086 .10865 .57015 .116 .58787 .10239 .57866 .09269 Mtetra
.774 .836 .899 r
.57866 .09269 .58787 .10239 .6057 .0918 .59657 .08068 Mtetra
.727 .796 .907 r
.59657 .08068 .6057 .0918 .62366 .08289 .6146 .07095 Mtetra
.698 .772 .909 r
.6146 .07095 .62366 .08289 .64175 .0749 .63277 .06247 Mtetra
.682 .758 .909 r
.63277 .06247 .64175 .0749 .65997 .06736 .65106 .05463 Mtetra
.673 .75 .908 r
.65106 .05463 .65997 .06736 .67832 .06005 .66949 .04712 Mtetra
.669 .746 .908 r
.66949 .04712 .67832 .06005 .69679 .05284 .68804 .03976 Mtetra
.666 .744 .908 r
.68804 .03976 .69679 .05284 .71538 .04566 .70671 .03246 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45396 .15895 .44341 Mtetra
.15895 .44341 .17073 .45396 .18737 .44826 .17565 .43763 Mtetra
.17565 .43763 .18737 .44826 .20411 .44252 .19246 .43182 Mtetra
.19246 .43182 .20411 .44252 .22097 .43673 .20938 .42597 Mtetra
.646 .763 .934 r
.20938 .42597 .22097 .43673 .23794 .43091 .22641 .42008 Mtetra
.22641 .42008 .23794 .43091 .25501 .42504 .24355 .41414 Mtetra
.647 .763 .934 r
.24355 .41414 .25501 .42504 .27221 .41911 .26081 .40815 Mtetra
.26081 .40815 .27221 .41911 .28951 .4131 .27819 .40209 Mtetra
.648 .764 .933 r
.27819 .40209 .28951 .4131 .30694 .407 .29568 .39595 Mtetra
.651 .765 .933 r
.29568 .39595 .30694 .407 .32449 .40073 .31329 .38968 Mtetra
.655 .768 .933 r
.31329 .38968 .32449 .40073 .34216 .39419 .33103 .3832 Mtetra
.663 .773 .931 r
.33103 .3832 .34216 .39419 .35997 .38717 .34891 .37635 Mtetra
.678 .783 .929 r
.34891 .37635 .35997 .38717 .37793 .37928 .36692 .36886 Mtetra
.703 .799 .924 r
.36692 .36886 .37793 .37928 .39604 .36983 .3851 .3602 Mtetra
.746 .826 .913 r
.3851 .3602 .39604 .36983 .41434 .35762 .40344 .34944 Mtetra
.808 .862 .888 r
.40344 .34944 .41434 .35762 .43283 .34078 .42198 .33507 Mtetra
.882 .901 .838 r
.42198 .33507 .43283 .34078 .45148 .31691 .4407 .31487 Mtetra
.943 .923 .759 r
.4407 .31487 .45148 .31691 .4702 .28419 .45956 .28653 Mtetra
.973 .924 .672 r
.45956 .28653 .4702 .28419 .48884 .24362 .47842 .2493 Mtetra
.977 .918 .611 r
.47842 .2493 .48884 .24362 .50721 .20039 .49709 .20632 Mtetra
.972 .921 .604 r
.49709 .20632 .50721 .20039 .52526 .16143 .51545 .16426 Mtetra
.966 .938 .661 r
.51545 .16426 .52526 .16143 .54309 .13085 .53352 .12909 Mtetra
.941 .944 .759 r
.53352 .12909 .54309 .13085 .56086 .10865 .55144 .10275 Mtetra
.881 .914 .845 r
.55144 .10275 .56086 .10865 .57866 .09269 .56935 .08385 Mtetra
.807 .861 .889 r
.56935 .08385 .57866 .09269 .59657 .08068 .58734 .07 Mtetra
.748 .814 .904 r
.58734 .07 .59657 .08068 .6146 .07095 .60544 .05918 Mtetra
.71 .782 .908 r
.60544 .05918 .6146 .07095 .63277 .06247 .62368 .05005 Mtetra
.689 .764 .909 r
.62368 .05005 .63277 .06247 .65106 .05463 .64205 .04184 Mtetra
.677 .753 .909 r
.64205 .04184 .65106 .05463 .66949 .04712 .66055 .03408 Mtetra
.671 .748 .908 r
.66055 .03408 .66949 .04712 .68804 .03976 .67918 .02655 Mtetra
.667 .745 .908 r
.67918 .02655 .68804 .03976 .70671 .03246 .69794 .01912 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43763 .16379 .42688 Mtetra
.16379 .42688 .17565 .43763 .19246 .43182 .18066 .421 Mtetra
.18066 .421 .19246 .43182 .20938 .42597 .19765 .41508 Mtetra
.19765 .41508 .20938 .42597 .22641 .42008 .21474 .40911 Mtetra
.646 .763 .934 r
.21474 .40911 .22641 .42008 .24355 .41414 .23195 .40311 Mtetra
.23195 .40311 .24355 .41414 .26081 .40815 .24928 .39705 Mtetra
.647 .763 .934 r
.24928 .39705 .26081 .40815 .27819 .40209 .26672 .39093 Mtetra
.648 .764 .933 r
.26672 .39093 .27819 .40209 .29568 .39595 .28428 .38474 Mtetra
.649 .765 .933 r
.28428 .38474 .29568 .39595 .31329 .38968 .30196 .37845 Mtetra
.652 .767 .933 r
.30196 .37845 .31329 .38968 .33103 .3832 .31977 .37199 Mtetra
.658 .77 .932 r
.31977 .37199 .33103 .3832 .34891 .37635 .33771 .36525 Mtetra
.669 .777 .931 r
.33771 .36525 .34891 .37635 .36692 .36886 .35579 .35803 Mtetra
.689 .79 .927 r
.35579 .35803 .36692 .36886 .3851 .3602 .37402 .34993 Mtetra
.722 .811 .92 r
.37402 .34993 .3851 .3602 .40344 .34944 .39242 .34026 Mtetra
.775 .843 .903 r
.39242 .34026 .40344 .34944 .42198 .33507 .411 .32781 Mtetra
.845 .882 .867 r
.411 .32781 .42198 .33507 .4407 .31487 .42979 .31069 Mtetra
.916 .915 .801 r
.42979 .31069 .4407 .31487 .45956 .28653 .44874 .28651 Mtetra
.962 .926 .714 r
.44874 .28651 .45956 .28653 .47842 .2493 .46778 .25343 Mtetra
.977 .921 .636 r
.46778 .25343 .47842 .2493 .49709 .20632 .48673 .21245 Mtetra
.975 .918 .6 r
.48673 .21245 .49709 .20632 .51545 .16426 .5054 .16883 Mtetra
.97 .929 .625 r
.5054 .16883 .51545 .16426 .53352 .12909 .52375 .1295 Mtetra
.958 .944 .708 r
.52375 .1295 .53352 .12909 .55144 .10275 .54187 .09861 Mtetra
.915 .934 .807 r
.54187 .09861 .55144 .10275 .56935 .08385 .55991 .07613 Mtetra
.843 .888 .872 r
.55991 .07613 .56935 .08385 .58734 .07 .57799 .05992 Mtetra
.774 .836 .899 r
.57799 .05992 .58734 .07 .60544 .05918 .59617 .04768 Mtetra
.727 .796 .907 r
.59617 .04768 .60544 .05918 .62368 .05005 .61448 .03772 Mtetra
.698 .772 .909 r
.61448 .03772 .62368 .05005 .64205 .04184 .63293 .02901 Mtetra
.682 .758 .909 r
.63293 .02901 .64205 .04184 .66055 .03408 .65151 .02095 Mtetra
.673 .75 .908 r
.65151 .02095 .66055 .03408 .67918 .02655 .67022 .01322 Mtetra
.669 .746 .908 r
.67022 .01322 .67918 .02655 .69794 .01912 .68906 .00563 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooeKlD]`0
07oo0000Egoo003EOol30003Ool02EKlD_aBo5;lE_`005;lOol0001FOol00=9oo`<000Aoo`0;D]aF
o5;lE_aBg5KlD]`005;LE_`0001FOol00=1oo`8000=oo`09E_aBo5KlD_aFo5;lE_aBo5Kl009Bo005
001Bo5;lD_`0001EOol00<eoo`<000=oo`0CD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]`005;LE_aB
g7oo0000E7oo003;Ool20003Ool8E_`015;lE_aBo5Kl15;l00<005;lD_`00U;l00<007ooOol0DWoo
0038Ool3000077oo001oogooE_aK75;lEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5Kl001Fo5;L
E_aoo`00Dgoo001WOol20002Ool2001IOol20004Ool00`00EaaFo003Ea`6E_`00e;lE_aBo002D_`0
1EKlD_aBo5;l000015;l00=oo`00Ool0DGoo001XOol01000Oomoo`00Egoo0`001Goo01eFo5/LE_aK
75KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo000E_aBg5KlD]aoo`00059oo`00JGoo
0P00EWoo0P001goo00=K75/lE_`00eLL00EFo5LLEaaFo5;l00=Fo0=Bo007E_aBo5;lD_aFo5;l0000
1E;l00=oo`00Ool0D7oo001YOol2001COol30007Ool00ellFaaO?002Fa`01UKlFaaFo5/LE_aG709F
o00BD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5Kl0Woo00<007ooOol0CWoo001XOol0
1000Oomoo`00D7oo0P0027oo0e/L00EK?5/LFaaK75LL00=Fo003EaaFo5Kl009Fo004D_aFo5KlE_`3
D_`01EKlD_aBo5;l00001U;l00=oo`00Ool0Cgoo001WOol20002Ool2001<Ool30008Ool01f=LGc]S
G5/LGcaK75ll009K709G700LE_aG75KlEaaFo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl001Fo5;L
E_aBg5KlD]aFo7oo001?Ool00;Ioo`<0009oo`03001oogoo00Aoo`ESG003FcaK75/L009K7004EaaK
75/LEa`3E_`02ELLE_aFo5;lE_aBo5KlD_aFo003D_`00eKlD_`00007D_`2001?Ool00;Aoo`8000Yo
o`0/HeaO>f=LGc]SG5lkHeaO>e/LEaaK75LLFaaG75/LE_aG75KlEaaBo5LLD_aFo5;lE_aBg5KlD_aF
o5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LOol004ioo`00/Goo0`002goo0V]k1V=L0Ull00=K75LL
Fa`00U/L00=G75/LE_`01eKl00=Bo5KlD_`00U;l00EFo5;lD_aBo00000UBo003Ool007oo04aoo`00
[goo0P003Goo00M[VfMjJi][Nf=LGc]SG002Gc`09U/kGcaO?5/LEaaK75LLFaaFo5/LD_aG75;lEaaB
o5LLD_aFo5;lE_aBg5KlD_aFo5;LE_`005KlD]aFo5;LE_aBg5KlD]aFo7oo000AOol5000gOol00:ao
o`<000ioo`9[N`04Ji][Nf]kJg/8Gc`00eLLE_aG7002Ea`00eKlEaaFo005E_`3D_`00eKlD_aBo003
D_`00`00D_aBo008D_`00goo001oo`0?Ool01@00Oomoogoo0000=goo002ZOol2000@Ool02V^KIgY[
Vf]kJi]WNVMlHe]O?5/k0ell02IK>ellFaaK75KlFaaFo5/LE_aK75;lE_aBo5KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_`005KlD]aFo5;LE_aBg5KlD]aFo5;LE_aoo`0047oo00<007ooOol0>7oo002WOol30002
Ool00`00Oomoo`0<Ool2Jg/026^KJg][Nf]kIgaWFfMkIe/3Gc`015/LFcaK75/L0ULL00AFo5LLEaaG
70AFo004D_aFo5KlE_`3D_`01EKlD_aBo5;l000025;l00EBg5;lD_aBo00000Moo`H000Aoo`03001o
ogoo03Moo`00YGoo0P004goo01Ug^G>HJi][Nf^KHe]WO6=KIgaSFfMlHe]O?5/LGcaK75llFaaO?5Kl
FaaFo5LLE_aG7002E_`06e;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LOol0000AOol00`00Oomoo`0fOol00:9oo`<001Aoo`Ec^@07Ie]WO6MKIg]WFfMlIe/00V=L
00IK?5/LFaaK75/lFa`2E_`01ELLE_aFo5KlEa`015Kl00ABo5KlD_aFo0=Bo003E_aBo00000IBo005
D]aBo5;lD_aBg002D_`00goo001oo`0@Ool00`00Oomoo`0eOol007Eoo`@002Moo`8001Moo`0DLiQg
^G>hMkU_VW>jHe]WO6=KIgaO>f=LGc]SG5/LGcaK75llEaaK709G700RE_aG75KlEaaFo5LLD]aFo5;l
E_aBg5KlD_aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L000=Ool01@00Oomo
ogoo0000=goo001dOol00`00Oomoo`02Ool00`00Oomoo`0QOol3000HOol4LkT5KiX7He`2Fa`01ELL
FaaK75/LEa`00UKl00=G75KlE_`00UKl00IBo5KlD_aFo5;lE_`5D_`00`00D_aBo006D_`025;LD_aB
o5;lD]aBo7oo000=Ool3000hOol007Aoo`03001oogoo009oo`03001oogoo01ioo`<001Yoo`06LiQg
^G>hMkU_VW>j0fnJ00m[Vf]kHeaO>f=LGc]SG5/kGcaG75/LEaaK75LLFa`00ULL029Bo5LLD_aG75;l
EaaBg5KlD_aFo5;LE_aBo5KlD]aFo5;L001Bg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol004Mo
o`00M7oo00<007ooOol00Woo00<007ooOol077oo0P000Woo00<007ooOol05goo17>i1FnJ00=[Vf]k
Jg/00f=L1Ell0U/L00AG75/LEaaG70QFo0=Bo003E_aBo5;l00ABo003001Bo5;l00MBo007D]aBo5;l
D_aBg7oo0000Agoo001dOol00`00Oomoo`02Ool00`00Oomoo`0IOol3000MOol01WNeNmIg]G^fKiYc
^P9_VP06IgY[Vf]kJi]WNV^K0Ull02mK>ellGcaO?5/kGcaFo5/LE_aK75KlFaaBo5LLD_aG75;lE_aB
o5KlD]aFo5;lE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0004Io
o`00M7oo00<007ooOol00Woo00<007ooOol05goo0P0087oo00=k]WNeNkH00WNg0VnJ00=[Nf^KJg/0
0V]k00=[VfMKIg/01Ull0U/L0ULL00AFo5LLEaaG70AFo004D_aFo5KlE_`3D_`00eKlD_aBo002D_`0
0`00D_aBo009D_`015;LD_aBo5;l0Woo00<007ooOol0@goo001dOol00`00Oomoo`02Ool00`00Oomo
o`0DOol3000QOol04G_FMkEk]WNeMmQg]gNhIgY[Vf]kJi]WNV^KHe]WO6=KIg`00Ull00AK>ellFaaK
?09K7004E_aK75KlFa`2E_`08U;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aoo`00AGoo001eOol4000EOol2000TOol00gNeNkIk]P03MkL2
LkT3Jg/02FMlIe]WNfMKIgaWFfMkFaaK?003Fa`00e/lFaaG7002Ea`4E_`025;lE_aFo5KlD_aFo5;l
E_`3D_`015KlD_aBo0001E;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aoo`00A7oo002;Ool3000U
Ool087NeNkIg]G_FMkMg^7>HMkUc^7NiLiQWO6=KIgaSFfMlHe]WO5lkHeaK75/lFaaO?5/LFcaFo5LL
E_aG75KlEa`2E_`08U;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aoo`00@goo0029Ool20002Ool00`00Oomoo`0SOol3NkH3MkL4LkT2KiX0
1FMkIe]WO6MKIg/00f=L0U/L00=K?5/LFa`00U/L0eKl00=G75KlE_`00UKl00ABo5KlD_aFo0=Bo003
E_aBo5;l009Bo003001Bo5;l00EBo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo0000@goo0026Ool3
000YOol02g^fMkEkeWNgMkQg]gNiLkQg^G>HLkX00fnJ03QWO6=KHeaO>f=LGc]SG5lkFaaG75/LEaaK
75LLFaaFo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`00@Woo0024Ool2000/Ool2NkH00gNeMkMg]`04LkT6KiX6
He`2Gc`3Fa`015LLFaaK75/L1UKl00IBo5KlD_aFo5;lE_`6D_`00`00D_aBo007D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aoo`00045oo`00PGoo0`00;Goo00Yg]G_FMkEg^7NgMkUc^7NiLiQc^P=_VP08
LkY_VV^KIgYSG5lkHeaK>`=O?00`Fc]K75LLFaaG75/LE_aK75;lEaaBo5LLD_aG75;lE_aBg5KlD_aF
o5;LE_aBg5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`00@Goo
001nOol3000`Ool01W^cNi=k]7^dNkIg]@9k]PI_VP9[N`03Ji][Nell00MO?0=G7003E_aG75LL00EF
o004D_aFo5;lE_`3D_`00eKlD_aBo002D_`00`00D_aBo009D_`01E;LD_aBo5;lD]`00e;l00ABg5;l
Ool0041oo`00O7oo0P00<Woo00Yk/g^CNk=g]7^eMkEk]WNeMmQg]`9_VP08LkY[Nf^KIgY[Vf]kIgaS
F`=O?004Fc]O?5llFc`2Fa`015KlFaaFo5/L0UKl02QBo5KlD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5Kl
D]`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol003moo`00NGoo
0`000Woo0P00<7oo00EkTg^cNkAk]7Ne00=k]PAg]`=[N`06Ji][NfMkIe]WO6MK0ell0e/L00=K?5Kl
Ea`00ULL15Kl00ABo5KlE_aFo0=Bo005E_aBo5;lD_aFo002D_`00`00D_aBo003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`0003moo`00Mgoo0P00=Woo02AkTg^cNi9k]G^dNkIg
]G_FMkMg^7NgMmQc^7NiIgY[Vf=KIgaSFfMlHe]WO6=KGcaK75/lFaaO?5/LFcaFo5/LE_aG75KlEa`2
E_`09e;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LOol0000nOol007Aoo`<003Qoo`9k/`9k]0=k]P04MkEg]gNgMkL4LkT0
1fMKIg]WFfMlIe]WNfMK009SG09K7005FcaK75/LFaaG7003E_`00eLLE_aFo002E_`015;lE_aBo5Kl
0e;l00=Fo5;lD_`00U;l00<005;lD_`01E;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2
Ool00`00Oomoo`0kOol0079oo`8003Yoo`03Nk=kTW^e009k]00JMkEkeWNeMkQg]gOHMkMg^G>HMkU_
VVnjHe]WO6=KIgaO>f=LGc]SG5/LGcaK75/lEaaK709G700^E_aG75KlEaaFo5LLD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo7oo000mOol006moo`<003aoo`9k/`9k]09k]P03MkEg]gNg009g]`=c^@E_VPMSG005EaaK75/L
FaaG7002Fa`00eLLE_aFo004E_`01U;lE_aBo5KlD_aFo0MBo003001Bo5;l00IBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00U;l0Woo00<007ooOol0>Woo001]Ool200000goo001oo`0kOol06W^B
Nk=k]7^dMkAkeWNeNkIg]gOHMkMg^G>HMkU_VVnjKiYc^VnJJi]WNV=LGc]SG5lkHe`2Gc`01ULLFaaG
75/LEaaK709G700[D_aG75;lEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`00Woo00<007ooOol0>Goo001ZOol3
0010Ool01g^cNi=k]7^dNkIg]G^f00=g]`=c^@E_VP9[N`04Ji]SG6=LHe`5Gc`01ELLFaaK75/LE_`0
0ULL1UKl0U;l00EFo5;lD_aBo5Kl00EBo003001Bo5;l00ABo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aoo`0003]oo`00Igoo0`00@Woo00Qk/g^CNk=kTW^cNi=k/g^B0W^d00ik
]WNeNmI_VVnjKiYc^VnJJi]WNV^KJg][Ve/k0ell03UK>ellGcaO?5KlFaaFo5/LE_aK75;lEaaBo5LL
D_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo0000>Woo001UOol20015Ool3Ni8017^bNi=k/g^c0g^d00Ak
]G^fMkMg]`=_VP9[N`05Ji][Nf]kIe]WO006Gc`00e/LFcaFo003Ea`01EKlEaaFo5KlD_`00eKl0e;l
00EFo5;lD_aBo5Kl00=Bo003001Bo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00ABg5;lD_`003Yoo`00HWoo0`00Agoo00Mk/W^BNk=kTW^cNi9k/`02Nk@04GNeNmIg]GNhMkMgf7Ng
Ji]WNV^KJg][Vf=KIgaSFfMlFc/00Ull00=K?5/LGc`00U/L03AFo5/LE_aG75KlEaaBo5KlD_aFo5;l
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]`003Uoo`00H7oo0P00BGoo0W^B00=k/W^BNk<00W^c0g^d00=k]WNe
MkL00gNg0W>i00U[Vf]kJg]WFfMlIe]WNfMKIg`00e/L00EK?5/LFaaK75LL00=Fo003EaaFo5Kl009F
o004D_aFo5;lE_`3D_`00eKlD_aBo003D_`00`00D_aBo004D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol003Qoo`00GGoo0`0000=oo`00Ool0B7oo029kTW^cNi9k
/g^BNk=kTg^dMkAkeWNeNkIg]gOHMkMg^G>HMkUc^7NiHe]WO6=KIgaSFfMlGc]SG5/LGcaK75/lEaaK
709G700cE_aG75KlEaaFo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo00003Qoo`00Fgoo0P00
CGoo00AkTW^bNi9kTP9k/`06Ni=k]7^dNkAg]G^f17Ng17>i0VnJ00=WFfMkIe/01F=L00EG75/LFaaK
75LL009K7003EaaFo5Kl00AFo006D_aFo5;lE_aBo5Kl1e;l00<005;lD_`00U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000=goo000^Ool4000VOol3
001?Ool07GncNi9k/g^BNk=kTg^cMkAk]7NeNkIg]gOHMkMg^7>HMkUc^7NiKiYc^VnJKkYO>f=LGc]S
G5lkHe`00Ull00IG75/LEaaK75LLFa`2Ea`0<e;lEaaBo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo000E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LOol0000ROol3000AOol002eoo`03001oogoo009oo`03001oogoo025oo`80055oo`07Nk9k
TW^BNi9k/g^CNk<00g^d00=k]W^eMkL00WNg17>i16nJ00=[Nf^KHe`00V=L1Ell00EG75/LFaaK75Kl
009G70IFo09Bo003E_aBo5;l00MBo003001Bo5;l00ABo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo02=oo`03001oogoo00moo`00<Woo00<007ooOol0
7Goo1000Dgoo00MkTW^bNi9k/g^CNk=kTP02Nk@04W^fMkEgf7NgMkQcV7NiLkQg^FnJLkY_VVnjIgY[
Vf]kJi]WNP=O?00nFc]O?5llGcaFo5/LE_aK75KlFaaBo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_`005KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lOol002=oo`03001oogoo00moo`009Goo1P001goo00<007ooOol077oo0`00E7oo
0g^B00Ek/W^CNk=k/g^b009kTP08Nk=k]7^dNkAk]G^fMkEk]P=_VP9[N`06Ji][Nf]kJg]WO6MK1Ell
00=K75/lE_`00eLL00EFo5LLE_aFo5;l00=Fo0=Bo003E_aBo5;l00EBo003001Bo5;l00IBo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo021oo`03001o
o`00011oo`00;Woo100077oo0`00Egoo00]k/W^BNk=kTW^bNi9o/g^BNk=kTW^c009k]00AMkAkeWNe
NkIg]gOHMkM[VfMjJi][Nf^KIgYWO6=KIgaK>`02Gc`00e/lFaaO?002Fa`0>EKlFaaFo5LLE_aG75;l
E_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000QOol00`00Ool0000@Ool002io
o`03001oogoo01Yoo`<005Uoo`9kTP05Nk9kTW^CNi9k/P03Ni8027^cNkAk]7^dNkIg]G^fNkD2MkL2
LkT02F^KJg][NfMKIgaWFfMkIe]WO003Fa`01E/lFaaK75/LEa`00eKl00=G75KlE_`00UKl00ABo5Kl
E_aFo0=Bo003E_aBo5;l00=Bo003001Bo5;l00ABo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l008001moo`05001oogooOol0000?Ool002ioo`03001o
ogoo01Qoo`8005aoo`0TNi9o/g^BOk=kTWncNi9k/g^BNk=kTg^dMkAk]7NeNkIg]GOHMkMg^G>HMkUc
^7NiHe]WO6=KIgaSFfMlGc]SG5/LGcaK75/l0U/L0ULL00AFo5LLE_aG709Fo00cD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0001ioo`05001oogooOol0000?Ool002ioo`D001=o
o`<005eoo`06Ni9k/W^CNi=kTW^b0g^B00=k/W^CNk@00W^d00=g]G^fNkD00gNg17>i0VnJ00=WFfMk
Ie/016=L00=K?5/LFa`00U/L00AG75/LFaaG70=Fo009EaaFo5KlD_aFo5;lE_aBo5Kl00MBo003001B
o5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aB
o5;lD_aBg5;lOol001eoo`<00004Ool00000000>Ool004Aoo`80061oo`0YOkAkTgncNi9o/g^BNk9k
TW^cNi=k/gNdNkAg]G^fMkEgf7NgMkQcV7NiLkQg^FnJLkY_VVnjGc]SG5lkHeaO>f=LGc]K75LLFaaG
75/LEaaK7002Ea`0>5;lEaaBo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o7oo0009Ool4000TOol0045oo`<00003Ool007oo05moo`9kT`03Ni9k/g^B009kTP03Nk9kTW^c00=k
]003NkIk]G^f009g]`Ac^@A_VP03Jg][Vf=L00ASG09O?003FaaG75/L009K70=G70EFo004D_aFo5;l
E_`:D_`00`00D_aBo003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`025;LD_aBo5;lD]aBo7oo0007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003moo`8006Ao
o`0;Ni=o]7^BOk=kTW^bNi9k/g^BNk=kTP02Nk@04g^fMkEkeWNgMkQcV7NiLkQg^FnJLkY_VVnjIgY[
Vf]kJi]O>f=L009O?013Fc]O?5llFaaG75/LE_aK75KlFaaBo5LLD_aG75;lEaaBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg000D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol00Woo00<007ooOol08Goo000l
Ool3001VOol2Ni<01G^cNi9kTW^BNk800W^B00Ak/g^bNi9kTP9k/`06Ni=k]7^dNkIg]G^f0fnJ0V]k
00E[Vf]kJg][Nf^K00MO?003EaaFo5LL009G7003E_aG75Kl00EFo0=Bo003E_aBo5;l00IBo003001B
o5;l00EBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo007D]aB
o5;lD_aBg7oo00001Woo00<007ooOol00Woo00<007ooOol08Goo000jOol2001XOol08WndNi=o]7^B
Ok=kTWncNi9k/g^BOk=kTW^cNi9k/g^CNkAg]7_FMkEk]WNgMmQg]f^KIgY[Vf]kJi]WNV^KHe]WO5/k
0ell00QK75llFaaK75KlFaaFo5/L0UKl03IBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L
001Bg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_`2Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003Moo`<0
06Yoo`06Ni=k/g^BNi=kTW^b0g^B00Mk/W^BNi9kTW^cNi=k/`02Nk@00gNeNkIk]@02MkL2LkT02F^K
Jg][Nf]kIgaWFfMkIe]WO003Fa`00e/lFaaK7002Ea`015KlEaaFo5LL15Kl00ABo5KlE_aFo0=Bo003
E_aBo5;l00ABo003001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`04Ool00`00Oomoo`02Ool00`00Oomoo`0Q
Ool003Eoo`800003Ool007oo06Uoo`1WNi=o]7^COk=kTWncNi9k/g^BOk=kTW^cNi9k/g^CNk=g]7^d
MkEk]WNeMmQg]gNhLiQg^G>hMkUSFfMlHe]WO6=KIgaO>f=LFaaO?5/LFcaK75llE_aG75KlEaaFo5LL
D_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol08Goo000bOol3001^Ool01G^cNi=kTg^BNk800g^B00Ik
/g^BNi9kTW^bNi<2Nk<2Nk@00g^fNkEg]`02MkL4LkT2KiX00fMKIg]WF`05He`4Fa`015LLFaaFo5LL
0eKl00UG75;lE_aBo5KlD_aFo5;lE_`025;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`30004Ool4000TOol0
02moo`<0071oo`0@OkAkTgndNi9o/g^COkAkTgncNi9k/W^BNk=kTg^cNi82Nk@06g^fMkEgf7NgMkQc
V7NiLkQg^FnJLkY_VVnjGc]SG5lkHeaO>f=LGc]SG5LLFaaG75/LEaaK7002Ea`0?E;lEaaBo5LLD]aF
o5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002aoo`00;Goo
0P00Lgoo0W^C00=kTW^cNi@00W^C00Ik/g^BNi9kTW^bNi83Nk<2Nk@00g^eNkIg]`02MkL3LkT4KiX0
0f]kJi]SG005He`2Gc`015LLFaaK75/L0eLL1EKl00ABo5KlD_aFo0UBo08000EBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_ao
ogoo0000:goo000ZOol3001dOol047^COkAkTgneNiAo]7^COkAkTWncNi9k/g^BNk=kTW^c0W^d01Eg
]G_FMkMg^7NgMkUc^7NiKiYc^VnJKkYWNV^KJg][VelkHeaO>ellFc/00Ull01IK75LLFaaFo5/LE_aK
75;lEaaBo5LLD_aG75;LE_aBo5KlD]aFo5;LE_aBg0<0000ZD]aFo000E_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
0Woo00<007ooOol0:7oo000XOol200000goo001oo`1dOol3NkH027^DNkEkTg^cNi9kTg^BNk82Ni82
Nk<01G^CNkAk]7^cNi<00W^d00=k]WNeNkH016nJ00=[Nf^KJg/00V]k00=[VellGc`01Ell00=G75Kl
Ea`00ULL00EFo5LLE_aFo5;l00=Fo0=Bo003E_aBo000008000EBo003001Bo5;l00ABo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;L
D_aoo`00:Woo000VOol2001hOol09W^fMiEk]W^DNkEkTgndNi=o/g^BOk=kTW^cNi9k/g^CNk=kTW^c
Ni=k]7NdNkAg]G^fMkMgf7NgMkQWNV^KJg][VfMjJi]SFfMlFc/3Gc`04U/LGcaK75/LE_aK75KlEaaF
o5LLD_aFo5;lE_aBo5KlD]aFo080000aD]aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]`00Woo00<007ooOol09goo000VOol2001hOol2NkH017^FNkEkU7^c0W^C00=kTW^bNi800W^B00Mk
/W^BNi9kTW^bNi=k/`02Nk@00gNeNkIk]@03MkL2LkT3Jg/01FMlIe]WNfMKIg`00e/L00EK?5/LFaaK
75LL00=Fo003EaaFo5Kl009Fo003D_aFo0000080009Bo003E_aBo5;l00IBo005D]`005;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00ABg7ooOol002Qoo`009Woo0`00MWoo01EgUG^fMiEk]G^DOkEkTgndNi9o/g^BNk=kTWnc
Ni9k/W^BNk=kTW^cMk@00W^d01Ek]WNeMmQg]gNhLiQg^G>hMkUSFfMlHe]WO6=KIgaO>f=LFaaO?5/L
Fc`00U/L0ULL00AFo5LLE_aG709Fo0<0000jE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`0
05;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg7oo000XOol002Ioo`04001oogoo001eOol01G^fNiIk]W^DNkD00g^C
00Ek/g^BNi9kTW^c00=kTP04Nk9kTW^cNk<2Nk@00g^fNkEg]`03MkL3LkT2KiX00fMKIg]WF`05He`4
Fa`015LLFaaK75LL0UKl0`0000MFo5;lE_aBo5KlD_aFo00<D_`01@00D_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09o
o`03001oogoo02Eoo`009Goo00<007ooOol00Woo00<007ooOol0LGoo01Ak]WNENkIkU7neNiAo]7^C
Ok=kTW^bNi=o/g^BNk9kTW^cNi9k/g^B0g^d01Yg]GOHMkMg^7NgMkUc^7NiKiYc^VnJKkY_VV=LGc]S
G5lkHeaO>f=LEaaK75LLFaaG75/L0`00045G75;lEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0002Moo`009Goo00<007ooOol00goo00<0
07ooOol0Kgoo00Ik]W^FNkIk]W^eNi@2Ni<01G^cNi9kTg^CNk<00g^B00=k/W^BNi800W^c0W^d00=k
]G^fMkL00WNg0g>i1FnJ00=[Vf]kHe`00f=L0ell00=G75/L00000P000ULL1UKl0U;l00=Fo5;lD_`0
3U;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`0UOol002Eoo`03001oogoo00Aoo`03001oogoo
06ioo`0DMiEk]WNEOkEkU7^eNi=o]7^BNkEkTgndNi9o/g^BOk=kTW^cNi9k/`9k]00AMkAkeWNgMkQg
]gNiLkQg^FnJLkY_VVnjKiY[Vf]kJi]WNP03Gc`00e/kGc`000020000AU/LE_aK75KlFaaBo5LLD_aG
75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;L0Woo00<007ooOol08goo000UOol20006Ool2001]Ool047^FNkIk]W^fNiAk]G^CNk=kTg^eNi=k
]7^BNi=kTW^b0g^B00Ik/g^CNkAk]7^cNi<2Nk@00g^fMkEk]P04KiX00f]kJi][N`02Jg/016MlIe]O
?5ll0P0000AO?5/LFcaFo0=G7005E_aG75KlE_aBo003E_`3D_`00eKlD_aBo00:D_`01E;LD_aBo000
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lOol0000UOol002Eoo`03001oogoo00Moo`03001oogoo06Yoo`0XNkIg
UG^fNiAk]G^DNkIgUG^eNiAo]7^COk=kTWncNi9k/g^BNk=kTg^cNi9k/g^CNkAg]7^dMkEk]WNgMmQg
]gNhIgY[Vf]kJi]WNVMlHe/3000015llFcaK75ll0U/L04UFo5/LE_aG75KlEaaBo5KlD_aFo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0
000TOol002Eoo`03001oogoo00Qoo`03001oogoo06Qoo`=k]P08NiIg]gNGNkIkUW^fNiAk]09kT`03
Ni9k/g^B009kTP07Nk9kTg^BNi9k/W^CNk<00W^d00=g]G^fNkD00gNg0W>i0V]k00IWF`00000006MK
Ig`3Fa`01E/lFaaK75/LEa`00eKl00=G75KlE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005
D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`0002=oo`009Goo00<007ooOol0
2Goo00<007ooOol0IWoo01Yg^G>HMkUcV7NhMiMk^7NENkIkU7neNi=o]7^BOk=kTW^bNi9k/g^BNk9k
TW^cNi9k/gNd0W^d00Qk]WNeMmQg]gNhLiQg^G>h0`0000aSFfMlHe]WO5lkHeaK75llFaaK?5LLFa`2
Ea`015KlEaaFo5LL0UKl049Bo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000SOol002Aoo`8000aoo`03001oogoo06Eoo`9cV@05
LiQcVGNGMkMkUP02NkH01G^eNiAkTg^CNk<00g^B00Ik/g^BNi=kTW^bNi82Nk<2Nk@00g^fNkEk]P03
MkL30002KiX00fMKIg]WF`06He`3Fa`015LLFaaK75LL1UKl00ABo5KlD_aFo0iBo009D]aBo5;lD_aB
g5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`015;LD_aoo`008Woo000TOol00`00Oomoo`0<Ool00`00Oomoo`1SOol0
6W>HMkUcV7NiMiMk^7NENkIgUGneNiAo]7^COk=kTW^bNi9o]7^BOk=kTW^cNi9k/g^BNk<2Nk@00gNe
NmIg]`03000057>hMkU_VW>jKiY_^VnJHeaO>f=LGc]SG5lkGcaK>e/LEaaK75LLFa`2Ea`0AE;lEaaB
o5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0OOol002Aoo`03001oogoo00eoo`03001oogoo065oo`9c
V@05LiQcVGNGMkMgU`02NkH01W^eNiAk]G^CNkAkTP9kT`05NkAkTW^CNi9k/P02Ni82Nk<2Nk@01G^e
00000000MkL017>i16nJ00=[Vf]kHe`00V=L15ll00EG75/LFaaK75Kl009G70IFo09Bo003E_aBo5;l
00iBo009D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol0000QOol002Aoo`03001oogoo00io
o`03001oogoo05moo`0LLiQg^G>HMkUgUg^hMiMk]WNENkIkU7^eNi=o]7^BOk=kU7ndNi=o/g^BOk=k
TW^cNi9k/g^CNk@200003gNeMkQg]gNiLkQg^G>HLkY_VVnjKiY[Vf]kJi][NP03Gc`0De/kGcaO?5ll
E_aK75KlFaaFo5/LD_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000087oo000TOol00`00Oomoo`0?Ool0
0`00Oomoo`1NOol01W>ILiQcVG>IMkMgU`=k]P08NiAk]G^DNkAkTg^eNiAk]09kT`03Ni9k/g^B009k
TP07Nk<00000001k/g^CNk<00W^d00=g]G^fNkD00fnJ00=[Nf^KJg/00V]k00=WO6MKGc`00ell0U/L
00=K?5KlEa`00ULL00EFo5LLE_aFo5;l00=Fo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`0
1U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol07Goo000TOol2000AOol00`00
Oomoo`1LOol05gNiLiQg^G>HNkQgUgNhMiEk]WNENkEkU7ndNi=k]W^DOkEkTgndNi9o/g^BNk800`00
06]k/g^BNk=kTg^cMkAk]7NeNkIg]GOHMkMg^6]jJi][Nf^KHe]WO6=KIgaSFellFaaK?5/LGcaK75/l
E_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0001moo`008goo00<007ooOol04Woo00<0
07ooOol0FWoo00M[Nf]jJg][NgNgMiMg]`02NkH027^FNkEkU7^eNiIk]W^DNkD3Ni<02W^c00000000
Nk9kTg^cNi9k/W^C0W^c0W^d00=k]W^eNkH00WNg17>i00EWFfMlIe]WNfMK009SG09K7003FcaK75/L
009K70=Fo009EaaFo5KlD_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`0
1U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol001ioo`006Woo10001Goo00<007ooOol04goo
00<007ooOol0F7oo01=[Vf]jJg][NW>JKgU_VW>HMkUcV7NhMiMk^7NENkIgUGneNiAo]00300002Wnc
Ni9k/g^BNk9kTW^cNi9k/g^B0W^d01=k]WNeNmIg]gNhMkMg^G>hMkU_VW>jHe]WO5lkHeaO>f=LGc]O
?002Fa`0CeLLFaaG75/LE_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03001oogoo01]o
o`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol057oo00<007ooOol0EGoo0V]k00=[
NV]kJg/016nJ00IcVG>HLiUgUgNgMiL2NkH03W^e00000000NkAkTW^CNi9k/W^BNi=kTW^bNi83Nk<2
Nk@00g^eNkIg]`02MkL3LkT4KiX7He`3Fa`015LLFaaK75/L1UKl00ABo5KlD_aFo0iBo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000MOol001Uoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo01Eoo`03001oogoo05=oo`0@JgY[Vf]jJg][NV^KKgU_VVmiMkUc
V7NiMiMk^7NGNkH300003g^eNi=o]7^BOk=kTWncNi9o/g^BOk=kTW^cNi9k/`02Nk@04WNeNmIg]gNh
MkMg^G>hMkU_VW>jKiY_^V]jJi]O>f=LGc]SG09O?01EFc]K75LLFaaG75/LE_aK75;lEaaBo5LLD_aF
o5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg7oo000077oo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool2000G
Ool2001BOol2He`016]jJg][Nf]k0fnJ00IcVG>HLiUcVGNgMiL200001G^fNiAk]G^DNk@00W^C00Ik
TW^bNi=kTg^BNk82Ni82Nk<01G^CNkAk]7^fMkD00gNg0W>i16nJ00A[Nf^KJg][N`MO?0=G7003E_aG
75LL00EFo0=Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00000e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lOol0000KOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Qoo`03001o
ogoo04eoo`0>HeaO>f=LGeaSG6]jJi]_NFnJKgUg^G>HMkUcV0<0000VMiEk]WNENkEkU7ndNi=o/g^B
Ok=kTgncNi9o/g^BNk=kTW^cNi=k]7NdNmIg]GNhMkMgf7>hMkU_VW>jKiY[Vf]jJi][Nf^KHe]WO09O
?004Fc]O?5/LFc`2Fa`015KlFaaFo5/L0UKl04aBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`0
01]oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol0Bgoo1f=L
16nJ00acV000000007NGMkMgUg^fNiIk]G^DNkD2Ni<01W^DNkEkU7^CNi9k/`=kTP06Nk=kTg^cNkAk
/W^C0g^d00=g]G^fMkL00WNg0V]k00i[Vf]kJg]WFfMlIe]WNfMKFcaK75/lFaaK?5Kl0eLL15Kl00AB
o5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`015;LD_aoo`006Woo000IOol00`00Oomoo`02Ool01@00Oomoogoo00007Goo
00<007ooOol0B7oo00]OG6=LGc]SG5mLHeaO>f=LHe]WO6=K00<0000MLiQg^GNGMkQgUg^fMiEk]W^D
OkEkTgndMiEo]G^DOkAkTWncNi9k/W^BNk=kTg^cNi9k/g^CNk=g]002Nk@0JG^fMkEgf7NgMkUcV6^K
Jg][Vf=KIgaSFfMlHe]SG5lkFcaK75llFaaK?5KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlOol00007Ool5000=Ool001Yoo`@000Aoo`8001eoo`03001oogoo04Ioo`9K?0IS
G005Ie/00000001[NP03Jg/02GNGMkMgUgNgNiIk]W^DNkEkU002NkH01G^eNiAk]G^CNk<00g^B00Mk
/W^BNi9kTW^bNi9k/`03Nk@00g^fNkEg]`02MkL4LkT016MKIgaWFfMk16=L00=K75/lFa`00e/L0eKl
00UG75KlE_aBo5KlD_aFo5;lE_`035;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo003D]aoo`0000Moo`05001oogooOol0000=Ool0029oo`03001oogoo01eo
o`03001oogoo04=oo`08FceK?5/mFaaK?E/lHeaO>`<0000QHe]WO6]jJg][NV^KKgU_VVmiLiYgUG^f
MiEk^7NGNkIgUG^fNiAk]G^COk=kTW^bNi9k/g^BNk9kTW^cNi9k/g^B00=k]00HMkEgf7NgMmQcV7Ni
LkQg^FnJLkY_VV=LGc]SG5lkHeaO>f=LEaaK75LLFaaG75/L0ULL055Bo5LLD_aG75;lE_aBg5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol03Woo000ROol00`00Oomoo`0NOol00`00
Oomoo`10Ool00e/lFceK?002Fc`00e/mFc`0000200001FMKIg]WFfMlJgX00f]k16nJ00IcV7>ILiUg
]gNGMkL2NkH027^DNkEkU7^dNi9kTg^BNk83Ni8017^bNi9kTW^c0g^d00Ak]GNgMkMg]`Ac^@=_VP9[
N`ASG0=O?09K7004EaaK75LLEa`6E_`00e;lE_aBo002D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l0Woo00<007ooOol01Goo00<007oo
Ool03Goo000ROol00`00Oomoo`0OOol00`00Oomoo`0mOol01eLmEaaG?E/lFceK75/m0080000VFcaO
GE/lIgaSFfMlJgY[Nf]jJi][NVnJKgUcVW>HMiUcV7NiMiMg^7NENkIgUG^eNiAo]7^BOk=kTWncNi=o
/g^BOk=kTW^cNi9k/`9k]00AMkEkeWNgMmQg]gNiLkQ_^VnJLkY_VV^KJgY[Vf]kGcaK>`03Gc`0FU/k
GcaFo5/LE_aK75KlFaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol000Qo
o`03001oogoo00aoo`008Woo00<007ooOol087oo00<007ooOol0>Goo00=G7ELLEad00ULM00=G75LM
00000P000Ull00IOG5llGcaO?5mLJgX3Jg/00f]jKiY_VP02KiX3LiT027NGMkMgUg^fNiIk]G^DNkD2
Ni<01W^BNkAkTg^CNi9k/P=kTP05Nk=k]7^dNkAk]P03MkL2LkT4KiX2Jg/016^KJg]WNfMK15ll00=K
?5/LFc`00ULL00EFo5LLEaaG75;l00=Fo0=Bo005E_aBo5;lD_aFo008D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l009oo`03001oogoo00Io
o`03001oogoo00]oo`008Goo0P008goo00<007ooOol0=Woo00IBo5LMD_aG?ELLEcd30000@eLmFcaO
G5/lGeeK?5mLFcaSG5mLHea[NV^KJgY_VVmiLiY_NGNILiQg^GNGMkQgUg^fMiEk]W^DOkEkTgncNi9o
]G^COkAkTWncNi9k/g^BNk=kTg^dMkAk/g^CNkAg]7_FMkEgegNgMmQg]f^KJgY[Vf]kIgaSFfMlHe]W
O5/LGcaK75/l009K701EE_aK75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`00Woo00D007ooOomoo`0000=oo`03001oogoo00]oo`008Goo00<007ooOol08goo00<007oo
Ool0<Woo0e<M00=G7E<MDad00`000ULM00EK?ELLEceO?5mL009O?0MSG0A_VP=cV@0<MiMg]gNGMkMk
UW^fNiAk]G^DNi=kU7^e0W^C00=kTW^cNi800W^B00Ik/W^CNi9kTW^bNi<3Nk@00gNeNkIg]`02MkL2
LkT01f^KJg]WNfMKIgaWFfMk009SG005FaaK?5/LFcaK7002E_`00eLLE_aFo002E_`015;lE_aBo5Kl
0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]`0
009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`00e;LD_aBo0020004Ool3000>Ool0025oo`03001oogoo02Aoo`03001oogoo02moo`05
DaeBo5<MD_aG7@030000BeLMD_aK?ELLFceG75/mEaaK?ELLHeaO>f=LGeaSG5lkHeaOG6MlHe]WO6=K
MiUcV7NiLiQg^7NGNkQgUG^fMiEo]G^DOkAgUGneNiAo]7^COk=kTW^bNi9k/g^CNk9kTW^cNi=k/gNd
NkAg]G^fMkMgf7NgMkUcV7NiLkQWO6=KIgaSFf=LGc]SG5lkFcaK75llEaaK7002Ea`015KlEaaFo5LL
0UKl055Bg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000057oo000QOol00`00
Oomoo`0UOol00`00Oomoo`0[Ool3Dad00e;mDad000020002Dad02ULMDaaG7ELMFceG75LmEaaK?ELL
0U/l1V=L00AWNfMKIgaWF`=[N`05JgYg]gNGMkMgU`02NkH01W^eNiAk]G^FNkEkU09kT`05NkAkTW^B
Ni9k/P03Ni800g^bNi9k/`03Nk@00g^fNkEg]`02MkL3LkT3KiX7He`00e/LEaaK7002Fa`00eLLFaaF
o005E_`015;lE_aBo5Kl45;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lOol0000COol0025oo`03001oogoo02Ioo`03001oogoo02Qoo`04C_aC
7DklDad30000>5<MD_aC7E<LEaeC75LMDaaG7E<LFceG75/mFcaK?E/LFceK?5/mGc]SG6=KIgaSFfMl
He][Nf]jJi][NVnJKgUcVVmiNkIgUG^fMiMg^7NENkIkU7^eNi=o]7^BOk=kTW^cNi9o/g^BNk=kTW^c
Ni82Nk@04W^fMkEgf7NgMmMcV7NiLkQ_^VnJLkY[Nf^KGc]SG5lkHeaK>`9O?01MFaaG75/LEaaK75Kl
FaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`0001=oo`00
8Goo0P00:7oo0P009Goo00EBoE<MD_eC7E;m008000=C7@05D_eC7E<MDaeC7003Ead015<LEaeG7E/m
0e/l00YK?E/lFcaK?5/mIe]WNfMKIgaWF`=[N`03JgY_VVnJ009_VP=cV@08MiMg]gNGNkIkU7^eNiAk
]09kT`06Ni9k/W^BNi=kTW^b0W^B00Ik/g^dNkAk]W^eNkH2MkL2LkT4KiX3Jg/00f^KGcaO?005Gc`0
0eLLE_aG7002Ea`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol0019oo`008Goo00<0
07ooOol0:Goo00<007ooOol087oo00AC7DklDae>o0<0000lC_aC7DklEaeBo5<MD_aG7E;lDaeC75LM
DaaG7ELLEceG75/mFaaK?E/lFceK75mMFcaOG6=KIgaSFf]kJgY[Vf]jJg]_NG>JKgU_VW>HMkUcV7Nh
MiMk]WNFNkEkU7ndNi=o/g^BOk=kTgncNi9o/g^BNk=kTW^c0W^d015g]G_FMkMgeg>HMkU_VVnjKiYc
^V]kJi][NV^KHe]WO5/k00=O?008FaaO?5/LFaaFo5/LE_aK709Fo01ED_aFo5;lE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl00004Woo000POol00`00Oomoo`0[Ool00`00Oomo
o`0LOol015<MD_eBoE;m0`0000MBoE<MD_eC7E;mDaeBo@03Dad01E;mDaeC7E<MEa`00eLM00AG75LM
EaeK?@9K?003GcaOG5ll009O?003GeaO?6]k009[N`03JgY[NfnJ00=_VP9cV@08LiQg]gNGNkIkUW^e
NiAk]@9kT`06Ni9k/g^CNi=kTW^b0g^B00=k/g^dNk@00W^c0g^d00=k]WNgMkL00WNg0f]k00][VfMK
Ig]WFfMlIe]K?5/LFcaK75/l009G7004E_aG75KlEa`4E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`00e;LOol0000AOol0021oo`03001oogoo02aoo`03001oogoo01Ioo`06Dae>o5<MC_aC
7Dkl0`00069>o5<MC_aC7E;lDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lEaeG75LmEaaG?ELLEceG75mL
FcaOGE/lGeaK?5mMFcaSG5lkJi][NV]kKgUcVVmiKiYcV7NiLiQg^7NGNkQgUW^fNiAo]G^COkAkTWnc
NiAo]7^BOk=kTW^cNi9k/g^CNk=kTW^cNi=k]7NdNmIg]GOGMkMgf7>hMkU[NV^KHe]WO6=KIgaSFf=L
Gc]O?5/LFcaK75llE_aG75KlEaaFo5LL0UKl05EBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`0
05;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LOol0000@Ool0021oo`03001oo`0002eoo`03001oogoo01=oo`03D_eC7Dkm
009Bo@<00003D_eC7E;m009Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d2Dad01ULMDaeC7E<MEaeG70=G
7@04EaaG?ELLGe`3Gc`00emLHeaSG004He`4KiX2LiT02G>HMkMgUgNgNiIk]W^DNkEkU002Ni<01G^e
NiAkTg^BNk<00g^B00Ik/W^CNi9kTW^cNi<3Nk@017NeMkMg]gNg17>i00AWFfMkIe]WO0ASG008FaaK
?5/LFaaG75/LE_aG70IFo004D_aFo5;lE_`>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo080011oo`0087oo0P00;goo00<007oo
Ool03goo00E>oE<MC_aC7Dkm00<00030C_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<M
D_aG7E;lEaeBo5LMD_aG7ELLFceG75/mEaaK?ELLGeaK?5mMGeaSG5lkHeaOG6=LHe]WO6miKiY_NGNi
LiQgVGNGNkQgUW^fMiEo]G^DOkAkTg^fNiAk]G^COk=kTW^bNi9k/g^BNk9kTW^cNi=k/gNdNkAg]G_F
MkMgf7NgMkUcV7NiKiY_^VnJHeaO>f=LGc]SG5lkHeaG75/LEaaK75LLFaaBo5LLD_aG75;lEaaBg5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`003goo0005Ool50005
Ool20005Ool40006Ool00`00Oomoo`0_Ool00`00Oomoo`0<Ool015<MC_eBoE;m0`0000=BoE<MC_d0
0U;m00EC7DkmD_eBoE<M00=Bo@03DaeBoE;m009C7@05D_eC7E<MDaeBo@02Dad00eLMDaeG7@02Ead0
1eLLEceG75/mEaaG?ELL00ISG00GIg]WFfMlIe]WNfMKLiUcV7>IMiMg]gNGNkIkUW^eNiAk]G^FNkIk
U7^eNi=k/`03Ni801g^bNi9kTW^BNk9kTg^c00=k]004NkIg]gNgMkL3LkT3KiX00f^KJg]SG003He`3
Gc`01ULLFaaK75LLE_aG70IFo0=Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0Woo00<007ooOol037oo0004
Ool200001Goo000007oo000017oo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
<7oo00<007ooOol027oo00EC7DklDae>oE<M0080001?C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeG75/mEaaK?E/LFceK?6=LGc]S
G5mLIgaSFfMlHe]WO6=KJi][NV]kKgUcVVmiMiUcV7^hMiMg^7NENkIgUW^eNiAo]7^BOk=kTWncNi9k
/W^BNk=kTW^cNi800W^d00mkeWNeMmQg]gNiLiQg^FnJKkY_VV^KJg][Vf]jJi/00Ull06EK>ellGcaO
?5KlFaaFo5/LE_aK75;lEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001B
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aoo`0000ioo`0017oo0P000Woo00<007oo00003goo00<007ooOol00goo00<007oo
Ool0<Goo00<007ooOol01Goo00A>oE;mD_eC7@<00006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeBo@03Ead015<LEaeG7ELM0e/l00]K?E/lFcaK
?5/mIe]WNfMKIgaWFfMk009[N`03JgY[NfnJ009_VP=cV@0<MiMg]gNGNkIkUW^eNiAk]7^BNi=kTW^b
0W^C00EkTW^bNi9kTW^c00=k]003NkEg]gNg00=c^@=_VP07Ji][Nf^KJg][VfMKIg/00ell00AK?5/L
FcaFo0=G7005E_aG75KlE_aBo003E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002
D_`00goo001oo`0<Ool000Aoo`80009oo`03001oo`0000moo`03001oogoo009oo`8003Aoo`08001o
ogooOom>o5<MC_eC7@<0001CDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<M
C_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEaeC75LmEaaG?E/LFceK?5/mFaaK?E/lGeaSFfMl
He]WO6]jJi][NV]kKgUcVVmiMiUcV7NiMiMg^7NGNkIgUW^fNiAo]G^COk=kTWndNi=o/g^BOk=kTW^c
Ni9k/`02Nk@0NG^BNk=k]7^dMkEkeWNgMmMg]f^KJg][Vf]jIgaSFfMlHe]WO5/LFcaK75llFaaK?5Kl
EaaFo5LLE_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aoo`0000aoo`0017oo0P000Woo00<007oo00002goo10001Goo00<007ooOol0<Woo00=B
oE<MC_d00U;m00IC7@00000005<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d0
2U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7E;m00=G7@04EaaG7ELMEad3Fc`01UmLGcaO
?5llGeaO?0=[N`03JgY[NfnJ00=_VP9cV@08LiQg]gNGMkMkUW^fNiAk]@9kT`06Ni9k]G^CNi=kTW^b
0g^B00Ek/g^BNi9kTW^c009k]003NkEk]WNe009g]`=c^@06Ie]WO6MKIg]WFfMl0V=L00=K75/lFa`0
0e/L0eKl00UG75KlE_aBo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;l
D]aBo7oo000<Ool000=oo`<00005Ool00000Ool0000;Ool00`00Oomoo`06Ool00`00Oomoo`0`Ool0
1E<MC_aC7DkmDad00`0007=C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG?ELLEceG75LmEaaG?E/lGeeK
?5mLFcaOGE/lHeaO>f^KJgY[NfmiLiY_NFnJLiQg^G>HMkQgUg^hMiIk]WNEOkEkU7ndNiAo]G^COkAk
TWncNi9k/g^BNk=kTW^cNi9k/g^CNkAg]7_FMkEgegNgNmQc^7NiKiYc^V=KIgaSFf=LGc]SG5lkHeaG
75/LEaaK7002Ea`0H5KlEaaFo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlOol000]oo`001Goo00<007ooOol00Woo00<007ooOol02Goo00<0
07ooOol01Woo00<007ooOol0;Goo00EC7DkmD_eBoE<M00<00006Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@9C
7@06EaeC7E<MDaeG7E<M0eLM00AG75LmEaaK?@=O?003GeaO?6=L00ASG0A_VP9cV@0=LiQg]gNGMkMk
UW^fNiIk]G^DNi=kUW^eNi@00W^C00Ek/g^BNi9kTW^b00=kTP06Nk9kTg^dNkAk]WNe0gNg0W>i16nJ
1V=L0Ull0U/L00=G75/LFa`01eKl00=Bo5KlD_`03e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]aBo08000Yo
o`001Woo100037oo1@0017oo00<007ooOol0:goo00A>o5<MC_eC7@<0001bDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeBo5/mEaaK?ELLFceG75/mFcaOGEmLHeaO>f=LGeaSG6=KIgaS
FfMlLiQg^G>HMiUgUg^hMiMk]WNENkIkU7^eMiEo]G^DOkAkTgndNi9k/W^BNk=kTW^bNi9k/g^CNk=g
]7^dMkEgegNgNmQc^7NiLiQc^VnJKkY[NV^KGc]SG5lk0ell06MK>ellE_aK75KlFaaFo5LLD_aG75;l
EaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
Ool0000:Ool001moo`03001oogoo02Qoo`05C_eBoE;mDae>o@0200001U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC
7@03D_d00e<MD_eC7@02Dad015;mDaeC7ELM0U<M0ULM00QC75LmEaaK?ELLEceG75/m1V=L00AWFfMl
Ie]WN`9[N`0DJgY[NgNGMkMgUg^fNiIk]WNGMkMkUW^fNiAk]G^CNkAkTW^CNi9k/`=kTP03Nk9kTW^c
009k]003MkEk]WNg009g]`9c^@=_VP05Jg][Vf]kJi][N`05Gc`01E/LFcaG75LLE_`00eLL00ABo5Kl
E_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]`0000000Uoo`007Woo
0P009Goo00M>oE<MC_aC7DkmDae>o0030000IDklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<M
D_aC7E;lDaeC75LMDaaG7E<LEaeC75/mEaaK?ELLFceK?5/mGc]SG5mLIgaSFfMlHe]WO6]jJi][NV]k
KgUcVVmiMiUcV7NiMiMg^7NGNkIkU7^eNi=o]7^COk=kTWndNi9o/g^BNk=kTW^cNi800W^d01EkeWNg
NmQg]gNiLiQc^VnJKkY[NV^KJg][Vf]jIgaSFellFc]O?5/LFc`00U/L06AFo5/LE_aG75KlEaaBo5Kl
D_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
Ool000Uoo`007Woo00<007ooOol08Woo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<L00=G7@04DaaK?5/lFcd3Fc`0
1e/mFcaWNfMKIgaWFfMk009[N`03JgY[NfnJ00=_VP9cV@08LiQg]gNGNkIkUW^eNiAk]09kT`06Ni9k
/W^BNi=kTW^b0W^B00=k/g^dNk@00W^c0W^d00=k]WNeMkL00WNg00m[Nf^KJg][VfMKIgaWFfMkIe]K
?5/LFcaK75/lFa`00UKl00=G75KlE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00009Ool001ioo`03001oogoo021oo`05C_aC7DkmDae>
o0030000KDklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeB
o5LMDaaG7E<LEaeG75LmEaaK?E/lFceK75/mFcaOG5/lIgaSFfMlJgY[Vf]jJg][NW>JKgU_VW>HMkUc
V7NhMiMk^7NFNkIkU7ndNi=o]7^BOk=kTgncNi9o/g^BNk=kTW^cNi9k/g^B00=k]00DMkEkeWNgMmMc
V7NiLkQWO6=KIgaSFfMlGc]SG5lkFcaK75llEaaK709G7004E_aG75KlEa`2E_`0Ee;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg004Ool00`00Oomoo`07Ool0
01ioo`03001oogoo01ioo`9Bo@03Dae>o@0000800005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>
oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7ELL00=G7@04EaaK?5/l
Fcd3Gc`00emLGcaO?002Jg/00f]jJg][N`03KiX2LiT027>HLiUgUgNgNiIk]W^DNkD2Ni<01W^BNk=k
U7^CNi9k/`=kTP03Nk=kTW^B009k/`9k]004MkEk]WNgMkL3LkT4KiX6He`00e/LEaaK7002Fa`00eLL
E_aFo005E_`015;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`7Ool00`00Oomoo`06Ool001io
o`03001oogoo01]oo`04Dae>oE<MC_`30000LTklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7ELLEceG75LmEaaG?ELLGeeK?5mL
FcaOGE/lGeaO>f=LJgY[Nf]jLiY_NFnJLiQg^G>HMiUgUg^hMiMk]WNEOkEkTgndNi=o]G^DOkAkTWnc
Ni9k/W^BOk=kTW^cNi9k/`9k]00AMkEkeWNeMmMg]gNiLkQ_^VnJLkY_VV^KJgYSG5lkHeaK>`02Gc`0
GE/LEaaK75KlFaaFo5LLD_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo00:Ool00`00Oomoo`06Ool001eoo`8001Qoo`06Dae>oE;mD_eC7Dkm0`0000E>oE;mD_eC
7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00QC7E;mDaeBoE<M
D_eC7E;m15<M00=G7E<MDad00ULM00EG75LMEaaK?ELL009O?003GeaO?6=L00ESG0A_VP0ALiUcV7>I
MiMg]gNGNkIkUW^eNiAk]W^FNkIkU7^eNi=k/`03Ni802W^cNi9kTW^BNk=kTg^dMkEk]WNe0WNg0W>i
16nJ00A[Vf]kJi][N`IO?003EaaFo5LL009G70AFo004D_aFo5KlE_`3D_`00eKlD_aBo00:D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l
3Woo00<007ooOol01Woo000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@800029C_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>
o5<MD_aC7E;lEaeBo5LMD_aG7ELLFceG75/mEaaK?ELLFceOG6=LGc]SG5mLHeaO>fMlHe]WO6=KMkUc
V7NILiQk^7NGMkQgUG^fMiMk]WNENkIkU7^eNi=o]7^BNk9kTWncNi9k/W^BNk=kTg^dMkAkeWNeNmIg
]gNiLkQ_^VnJLkY[Nf^KJgY[Vf]kIgaSF`03Gc`025/LGcaK75/LE_aK75KlFa`2E_`0Be;lE_aBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg00COol00`00Oomoo`06Ool001eoo`03001oogoo01=oo`9Bo@03
Dae>oE;m00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7E;mD_eBoE<MD_d3Dad00e;mDaeC7@04Dad02ELMDaaG7ELLFceG75LmEaaK
?@02Fc`4He`01fMKIgaWFfMkIe][Nf]j009[N`03MkMgUgNg009cV@0<MiMg]g^FNkIkUW^eNiAk]7^B
Ni=kTW^d0g^B00Mk/W^BNk=k]7^fMkEk]P02Nk@057NeMkMg]gNgJg][Vf]kJi]WFfMkIe]WO6MKFcaK
75/lFaaK?5/LEa`3E_`00eLLE_aFo002E_`015;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_`005;lD]`00e;l00IBg5;lD_aBo5;LD_`EOol00`00Oomoo`06Ool001eoo`03001oogoo015o
o`04C_eC7DklDad30000UE<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7ELL
FceG75/mFcaK?E/LFceK?6MlHe]WO6=KIgaSFf^KJgY[Nf]jLiY_NFnJLiQg^G>HMkQgUG^fMiIk]G^D
OkAkTgncNi9o]7^BOk=kTW^cNi9k/gNdNk=kTg^cMkAk]7NeNmIg]g_HLkQg^G>HMkUSFfMlHe]WO6=K
HeaO>ellFaaK?5LLFa`00ULL00AFo5LLE_aG709Fo015D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;L01Moo`03001o
ogoo00Ioo`007Goo0P003goo00ABoE<MC_eBo@<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;m
DaeBo@=C7@05D_eC7E<MDaeC7003Ead015<LEaeK?5/m0e/l00MK?E/lGcaO?6MlIe]WN`02Jg/00f]j
Jg][N`03KiX2LiT027>HMkMgUg^fNiIk]W^DNkD2Ni<01W^BNkAkTg^CNi9k/P9kTP03Nk=k/W^C009k
/`9k]004NkIg]gNgMkL3LkT2KiX00fMKIgaSG004He`3Fa`00eLLFaaK7007E_`015;lE_aBo5Kl3U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`077oo00<007ooOol01Woo000MOol00`00Oomo
o`09Ool01TklDae>oE<MC_aC7@<00024Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MC_aG7E;l
DaeBo5LMD_aC7E<LEaeC75LmEaaG?E/lFceK75/mFcaOG5/lGeeK?5mLJgY[Vf]jJg][NW>JKgU_VVmi
MkUcV7NIMiMk]WNFNkIkU7neNi=o]7^BOkEkTgncNi9o/g^BNk=kTWncNi9k/g^B0W^d00mkeWNeNmQg
]gNiLiQg^FnJKkY_VW>jGc]SG5lkHe`00Ull04YK>e/LEaaK75KlFaaFo5LLD_aG75;lEaaBo5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`007goo
00<007ooOol01Goo000MOol00`00Oomoo`07Ool2D_d00e<MC_eBo@030002D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@04EaaG7ELM
Ge`3Gc`00emLGcaO?002He`00f]jJg][N`04KiX02W>ILiQcVGNGMkMkUW^fNiIk]G^D0W^C00Ek]G^C
Ni=kTW^c00=kTP03Nk9kTW^c009k/`9k]003MkEg]gNg00=c^@A_VP03Jg][Vf]k00IO?0=G7003E_aG
75Kl00EFo0=Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`017oo00<007ooOol077oo00<007oo
Ool01Goo000MOol00`00Oomoo`05Ool014kmDae>o5<M0`0008UC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MD_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG7ELLEceG75LmEaaK?ELLGeaK?5mM
FcaOG5lkHeaOG6=LGc]cVVmiKiY_NGNiLiQgVGNGNkQgUW^fMiEo]G^DNkIgUG^fNiAo]7^COk=kTW^c
Ni9o/g^BNk=kTW^c009k]00DMkEkeWNgMmMcV7NiKiY_^VnJJi][Nf^KJgYWO6=KGcaK>ellFaaK?09K
700oE_aK75KlFaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;L00Qoo`03001oogoo01]oo`03001oogoo00Eoo`007Goo00@007ooOom>o@9Bo@04Dae>
oE;mD_d20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m
00IC7E;mDaeBoE<MD_d2Dad03ULMDaeC7E<MEaeG75LMEaaK?ELLEceG75mLGc`6He`01VMlIe]WNfMK
LiUcV09cV@0:MkMgUg^fNiIk]W^DNkIkUW^fNi@2Ni<01G^cNi9kTW^BNk<00g^B00Ek/g^dNkAk]7^f
009g]`9c^@=_VP0>Ji][Nf^KIe]WO6MKIg]WFe/lFaaK?5/LFcaK709Fo003EaaFo5Kl009Fo004D_aF
o5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lD_aBo0aoo`03001oogoo01]oo`03001oogoo00Eo
o`0077oo00P007ooDae>oE<MC_aC7Dkm0`000:I>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeBo5/mEaaK?ELLFceG75/mEaaS
G5lkHeaOG6=LGc]WO6=KIgaSFf^KJgY[Nf]jNkQgUg^fMiEk]WNGMkQgUG^fMiIk]G^COkAkTWncNi=o
/g^BNk9kTW^cNi=k]7NdNk=kTg^dMkEkeWNgMmMg]gNiLkQg^F=KIgaSFfMlHe]SG5lkFcaK75llEaaK
709G7004E_aG75KlEa`2E_`0;e;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`04Goo00<0
07ooOol06Woo00<007ooOol01Goo000LOol00`00Dae>o@02D_d300000e;mDae>o@02D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad0
1E;mDaeG7ELMDa`00ULM00EK?ELLEceG75/m00=K?0=SG007Ie]WO6MKIg]WFf]kJgX00V]k0VnJ0g>I
00agUgNgNiIk]W^FNkEkTg^dNi9kTg^BNk<3Ni801W^bNi=kTW^BNk9kT`9k]004NkIg]GNgMkL3LkT0
16nJKkYWFfMk1F=L00=K75LLFa`00U/L0eKl00=G75KlE_`00UKl00ABo5KlD_aFo0aBo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoogoo01Eoo`03001oogoo
01Uoo`03001oogoo00Eoo`004Woo1@001Goo00<004km00000P000:M>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MD_aG
7E<LEaeC75LMDaaG7E/LFceK?5/mFaaK?E/lFceSFfMlHe]WO6=KJi][NV]kJgYcVVmiKiYcV7NiLiQg
^7NGNkIgUW^fNiAo]7^COk=kTWndNi9o/g^BNk=kTg^bNi9k/g^CNk=g]7_FMkEgegNgNmQc^7NiKiYc
^VnJKkYO>f=LGc]SG5/k009O?00cFaaG75/LEaaK75;lEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5Kl01Yoo`03001oogoo01Qoo`03001oogoo00Eoo`0057oo00<007ooOol01Goo0P0000=BoE<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eB
oE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMDa`00eLM0e/l00YK?E/lFcaO?5mLIe]W
NfMKJg][NP9[N`=_VP9cV@08LiQg]gNGNkIkUW^fNiAk]09kT`06Ni9k]G^CNi=kTW^b0g^B00=k/W^B
Nk<00W^d00Ag]GNgMkMg]`=c^@06KkY_VVnJJg][Vf]k1Ull00=G75KlEa`00ULL15Kl00ABo5KlE_aF
o0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg5;lD_`077oo
00<007ooOol06Goo00<007ooOol017oo000DOol00`00Oomoo`06Ool0Z@00Oom>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E;lDaeBo5LMEaaG?ELLEceG75LmFaaK?E/lGeaK?5mMFcaOG5/lJi][NV]kJgYcVVmiKiYc
V7NiLiQg^7NGNkQgUW^fMiEo]G^COkAkU7neNi=o/g^BOk=kTWncNi9k/g^BNk=kTW^dMkEkeWNgNmQc
^7NiLiQc^VnJKkY[NV^KJg]WO6=K00=O?00^FaaO?5/LFaaFo5/LE_aK75;lE_aBo5KlD_aFo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`Q
Ool00`00Oomoo`0HOol00`00Oomoo`04Ool001Aoo`03001oogoo00Moo`800003D_eC7Dkm009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<M
D_eC7E;mDaeBoE<MD_eC7E;m0U<M00=G7E<MDad00ULM00AG75LMEaeG7@=O?004GeaO?5llGc`4He`4
KiX05G>ILiQg]gNGMkMkUW^fNiIk]G^FNkIkU7^eNiAkTg^BNk9kTW^CNi9k/P02Ni8017^cNkAk]7^f
0WNg0g>i015_^VnJKiY[Nf^KJg]WNfMKIgaWFe/lFaaK?5/LFcaK75LL00=Fo003EaaBo5Kl009Fo004
D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L02Ioo`03001oogoo01Moo`03001o
ogoo00Aoo`0057oo00<007ooOol02Goo0:d007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E;lEceG75Lm
EaaK?ELLFceK?5mMFcaOG5lkHeaOG6=LGc]WO6=KIgaSFgNiLiQgVGNGNkQgUg^fMiEk]WNGNkIgUGne
NiAo]7^BOk=kTWncNi9o/g^BNk=kTW^cNkAk/g^BNkAg]G_FMkEkf7NgMmM[NV^KJg]WO6=KIgaSFf=L
Gc]O?5/LFcaG75/L009G700RE_aG75KlEaaBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`XOol00`00Oomoo`0GOol00`00Oomoo`04Ool001Aoo`03
001oogoo00Yoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d2Dad03ULMDaeC7E<MEaeC7ELmEaaK?ELL
EceG75/mEa`6He`06FMlIe]WNfMKJg][NV]kMiMg]gNGNkIkUW^fMiMk]W^FNkEkU7^eNi=k/g^BNi=k
TW^b00=kTP04Nk=k]7^BNk<2Nk@00g^fMkEg]`02MkL3LkT00fMkIe]WO005He`3Fa`015LLFaaFo5LL
15Kl00IBo5KlD_aFo5;lE_`:D_`01E;LD_aBo5;lD]`00e;l00=Bg5;lOol0:goo00<007ooOol05Woo
00<007ooOol017oo000BOol3000=Ool0Y@00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMDaaK?ELLFceG
75/mFcaK?E/LHeaOG6=LHe]WO6=KIgaSFf^KJgY[NfmiLiY_NGNILiQg^GNGMkQgUG^fNiAk]G^COkAk
TWndNi9o/g^BNk=kTW^cNi=k/g^BNk=k]7_FMkEkeWNgMmMc^7NiLkQ_^VnJLkYO>f=LGc]SG002Gc`0
8E/kFaaG75/LEaaK75;lEaaBo5LLD_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg00aOol00`00Oomoo`0EOol00`00Oomoo`04Ool001Aoo`03001oogoo00aoo`800006Oom>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7DkmD_eBoE<MD_eC
7E;mDaeBo@=C7@05D_eC7E<MEaeC7003Ead015<LEaeK?5/m0e/l00]K?E/lFcaWFfMlIe]WNfMKJg][
NV]k00=_VP=cV@0<LiQgUg^FNkIkU7^eNiAk]7^BNkEkTg^c0g^B00Ek/W^CNi9kTW^c009k]003MkEk
]WNg009g]`9c^@9_VP04KkY[Nf^KJg/6Gc`3Ea`00eKlEaaFo005E_`3D_`00eKlD_aBo00:D_`fOol0
0`00Oomoo`0DOol00`00Oomoo`04Ool002Eoo`2V001oodklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG7E<LEaeC75LmEaaG?E/l
FceK75/mFcaK?E/lGeeSFfMlHe][Vf]jJg][NW>JKgU_VW>HMkUcV7NhMiMk]WNFNkEkU7ndNi=k]G^C
OkAkTW^bNi9k/g^BNk9kTW^cNi9k]7NeNmIg]gOGMkMg^G>hKkY_VW>jJg][Vf]jIgaSFellFc]O?5/L
Fc`2Fa`05EKlFaaFo5/LD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg00jOol00`00Oomo
o`0EOol00`00Oomoo`03Ool002Ioo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG7003Ead01ELL
EaeK?5/mFc`00Ull00IOG5llGcaO?6]kJgX2Jg/3KiX2LiT047>HMiMgUg^fNiIk]G^DNkEkTg^fNiAk
]7^BNi=kTW^b0g^B00Ek/W^CNkAk]7^f00=g]`9c^@9_VP06KkY[Nf^KIg]WO6MK0VMk00IK?5/LFcaK
75/lFa`2E_`00eLLE_aFo002E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`00U;l?Goo00<007ooOol057oo
00<007ooOol00goo000WOol0YP00Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lEaeG75LmEaaG?ELLEceK?5mLFcaOGE/lGeaK
?6=LGeaSG5lkLiY_NFnJLiQg^G>HMkQgUg^hMiIk]W^DOkEgUW^fNiAo]7^COk=kTWncNi9k/W^BNk=k
TW^cMk=k/g^BNkAg/g_FMkEgegNgNmQ[Nf^KHe]WO6=KIgaSFf=LGc]K?5/LGcaG75/L0ULL00mFo5LL
E_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]`0@7oo00<007ooOol04goo00<007ooOol00goo000XOol2
00001GooD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;m
DaeBoE<MD_eC7E;m0U<M00IG7E<MDaeC7ELMEa`2Ead01E/mEaaG?EllGe`00Ull1F=L00=WO6MKIg/0
0W>I00acV7>IMiMg]g^FNkIgUgNgNiIk]W^FNkD2Ni<02g^BNk9kTg^CNi9k/W^BNk=k]7^bNi<00g^d
00Ag]G^fMkMg]`9c^@04KiY_^VMKIg/5He`00e/LEaaK7002Fa`00eLLE_aFo003E_`01E;lE_aBo5Kl
D_`0AWoo00<007ooOol04Woo00<007ooOol00goo000ZOol0WP00OomC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeBo5/mEaaK?ELLFceG
75/mEaaSG5lkHeaOG6=LGc]WO6=KIga[NV^KJgY[NgNGNkQgUgNILiQk^7NGNkIgUGneNi=o]7^BOk=k
TgncNi9o/g^BNk=kTW^cNi9k/gNcNkAg]G_FMkMkf7>hMkU_VW>jKiY_^UlkHeaO>f=LFc/2Gc`02e/L
EaaK75KlFaaFo5LLD_aG75;lEa`0BWoo00<007ooOol04Woo00<007ooOol00goo000[Ool01P00OomB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00=C7E;mD_d00U<M00EBoE<M
DaeC7E;m009C7@09EaeC75LMEaeK?ELLEceG75/m00=K?0=SG004Ie]WO6MKIg/2Jg/00f]jJg]_VP02
KiX2LiT01WNgMiMk]W^FNkIkU09kT`05Nk=kTg^CNi9k/P02Ni8017^cNk9kTW^c0W^d00=g]G^fMkL0
0WNg0W>i00I_^VnJKiY[Nf^KJg/6Gc`00eLLE_aG7002Ea`3E_a=Ool00`00Oomoo`0AOol00`00Oomo
o`03Ool002aoo`2J001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
DaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeK75/mFcaK?E/LFceK?5/mHe]WO6=KIgaSFf^KJgY[Nfmi
LiY_NGNILiQg^GNGMkQgUG^fNiAo]7^COk=kU7ndNi9o/g^BNk=kTWncNi9k/g^BNkAg]G_FMkEkf7Ng
MkUc^7>jKiY[Vf]jJi][NfMlHe/3Gc`025/LGcaK75/LE_aK75KlFaa@Ool00`00Oomoo`0@Ool00`00
Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE<M
D_eC7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMDa`00eLM0e/l00]K?E/lFcaO?5mLIe]WNfMKJg][NV]k
00A_VP9cV@9gU`07NiIk]W^FNkEkTg^dNi@00W^C00Ek/g^BNi9kTW^c009kTP05Nk=k]7^dNkIg]@02
MkL2LkT01VnjKiY[Vf]kJi]WF`9WN`08IgaWFe/lFaaK?5/LFcaK75Eoo`03001oogoo011oo`03001o
ogoo009oo`00;goo09`005<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
DaeBo5LMD_aC7E;lEaeG75LmEaaG?ELLEceK75/mFcaOG5/lGeeK?5mLFca[Vf]jJg]_NG>JKgU_VW>H
MkUcV7NhMiMk]WNFNkEkTgndNiAk]G^COk=kTW^bNi9o/g^BNk9kTW^cNkAk/g^BNk=k]7_FMkEkf7Ng
MkUc^7NiHe]WO6=KIgaSFf=LGc]O?5/LFcaGOol00`00Oomoo`0@Ool00`00Oomoo`02Ool0031oo`05
001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m
0U<M00=G7E<MDad00ULM00AG75LMEaeG7@=O?004GeaO?5llGc`3He`4KiX2LiT03G>HMiMgUg^fNiIk
]W^DNkIkUW^eNi=k]7^B009kT`07Nk=kTW^BNi9k/g^dNi800W^c0W^d00Ag]G^fMkMg]`9c^@9_VP03
Ig]WO6=L00ASG5Yoo`03001oogoo00moo`03001oogoo009oo`00<Goo09H007ooOomC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E;lEceG75LmEaaK?ELLFceK?5mM
FcaOG5lkHeaOG6=LHe]WO6=KIgacV7NiLiQgVGNGNkQgUW^fMiMk^7NFNkEkU7ndNi9o/g^BOk=kTW^b
Ni9k/g^BNk=kTW^cNi9k]7NeNmIg]gOGLkQg^FnJKkY_VW>jGc]SG5lkHeaMOol00`00Oomoo`0>Ool0
0`00Oomoo`02Ool0039oo`05001oogooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<M
D_eC7E;mDaeBo@9C7@0>EaeC7E<MDaeG7E<MEceG75/mEaaG?ELLFceG70ESG004Ie]WO6MKIg/2Jg/0
36]jJg]gUgNgLiQcVGNGMkMkUW^fNiAk]@9kT`07Ni9k]7^BNi=kTW^bNi<00W^B00Ek/g^CNkAk]7^f
009g]`=c^@9_VP04KkY[Nf^KJg]OOol00`00Oomoo`0>Ool00`00Oomoo`02Ool003=oo`80002?OomC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LFceG75/mEaaK
?E/lFceK76=LGeaSG6=KIgaSFfMlJgY[Vf]jJg]_NG>JLiQgVG>HNkQgUg^fNiAo]G^COk=kTWneNi=o
/g^BOk=kTW^bNi9k/g^BNk=g/g_FMkEgegNgMkUc^6njKiY[Vf]kJi][NP1QOol00`00Oomoo`0=Ool0
0`00Oomoo`02Ool003Eoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3
Dad01E;mDaeC7E<MDa`00eLM00AC75LMFcaK?@=K?006FceK?5/lIe]WO6MK0f]k00E[NV]kKiY_VVmj
009cV@09MkMgUg^fNiIk]G^DNi=kU7^e009kT`08Ni9k/W^BNi=kTW^bNi=k/`9k]003MkEg]gNg009c
^@9_VP03Ji][Nf^K06Aoo`03001oogoo00aoo`03001oogoo009oo`00=Woo08/007ooDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5<MDaaG7E<LEceG75LmFcaK?E/LFceK?5mLFcaO
GE/lJg][NV^KJgY[NfmiLiY_NGNILiQk^7NGMkQgUGneNiAo]7NEOkEkU7ndNi9o/g^BNk=kTWncNi9k
/g^BNkAkTW^cMk=keWNeMmMg]gNiLkQg^@1VOol00`00Oomoo`0;Ool00`00Oomoo`02Ool003Moo`04
001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG7003Ead0
15LLEaeG7EmL0ell00MOG5llHeaSG6]kJgY[N`02KiX016mjLiUcVGNg0WNG00YkUW^fNiAk]G^FNkEk
U7^CNi9k/`=kTP07Nk9kTW^cNk=k]7^BNk<00W^d00=g]G^eMkL00g>iIgoo00<007ooOol037oo00<0
07ooOol00Goo000hOol20000QE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG
7ELLEceG75LmEaaK?ELLGeaK?5mMGeaSG5lkHeaOG6=LKgUcVVmiKiYcV7NiMiMg^7NGNkIgUgNhMiEk
]W^DNkEkTgncNi9k/W^COk=kTW^cNi9k/g^BNk=kTW^dMkEkeWNgNmQc^7Ni06Uoo`03001oogoo00]o
o`03001oogoo005oo`00>Woo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d2
Dad03ELMDaeC7E<MEaeG75LmEaaK?ELLEceG75/m00ISG004Ie]WO6MKIg/2LiT3MiL02W>IMiMgUgNG
NkIkU7^eNi=k]7^B0W^C00=k/g^BNi800W^c0W^B00Ak/g^dNkAk]@9g]`9c^F]oo`03001oogoo00Yo
o`03001oogoo005oo`00>goo088007ooOomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LM
DaaG7ELLFceG75/mEaaK?E/lFceO>f=LGeaWO6=KIgaSFfMlJgY[VfmiKiY_NGNiLiQg^7NGNkIgUW^e
NiAo]7^BNkEkTgndNi9k/W^BOk=kTW^cNi9k/g^dNmIg]G_HLkQg^Feoo`03001oogoo00Uoo`03001o
ogoo005oo`00?7oo00<007ooOol00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<L
00=G7@04EaaG?ELLFcd3Fc`01e/mIe]WNfMKIgaWFfMk009[N`05KgY_VVnJLiUcV002MiL02GNgNiIk
]W^DNkAkTg^eNi=k]003Ni801G^cNi9kTW^BNk<00W^d00Ag]G^dNkAk]Fioo`03001oogoo00Uoo`03
001oogoo005oo`00?Goo0P0007eooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75LM
FaaK?E/lFceK75/mFcaOG6=KIgaSFf]kJgY[Vf]jKiY_NG>JLiQgVGNGNkQgUW^fNiAo]G^CNkIkU7nd
Ni=o/g^BNk=kTW^bNi9k/g^BNkAkTW^cNkAkeWNe06moo`03001oogoo00Qoo`03001oogoo005oo`00
?goo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d03U<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMDa`00eLM0e/l00IOG5ll
GcaO?5mLGc`3Jg/046]jKiY_VVnJLiQcVGNGMkMkUW^fNiIk]G^FNkIkU7^d0W^C00=kTW^bNi800W^B
00Ek/W^CNkAkTW^c009k]003MkEoogoo06moo`03001oogoo00Moo`03001oogoo005oo`00@7oo07X0
07ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeG75LmEaaG?ELLEceG75mMFcaOG5/lGeeK?6=LGc]S
G5mLKiY_NG>JLiQgVG>HNkQgUg^fMiEo]GNGNkIgUGneNi=o]7^BOk=kTgncNi9k/g^BNk=kTW^cNi9k
]7NeLgoo00<007ooOol01goo0@000Goo0Goo0011Ool01P00Oomooe;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d015<MD_eC7E;m15<M
00=G7E<MDad00ULM00EG75LMEaaK?ELL009O?003GeaSG6=L00=SG004Ig]WFfMlLiP2LiT03GNgMiMk
]W^FNkIgUg^fNiIk]G^DNi=kTW^c009kT`07Ni9k/W^BNk=kTW^bNi<00W^d00=k]WooOol0LGoo00<0
07ooOol01goo0@000Goo0Goo0012Ool20000MGooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaK?ELL
FceG75/mEaaSG5mLHeaO>f=LGeaWO6=KIga[NV]kJgYcVVmiMiUcV7NiMiMg^7NENkIkU7ndNi=o/g^D
OkAkTWncNi9k/g^BNk=kTW^cMk=keP1eOol00`00Oomoo`06Ool10001Ool1Ool004Aoo`05001ooe;m
Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eBoE;m
DaeBo@=C7@03D_eC7E<M00AC7@0:EaeC75LMEaaK?ELLEceK?5/mFc`3He`01FMKIg]WFfMlJgX00V]k
00=_VVmjKiX00W>I00acV7NGNiIk]W^DNkEkTg^eNiAkTg^BNk83Ni800g^bNi9k/`02Nk@00g^COomo
o`1dOol00`00Oomoo`05Ool10001Ool1Ool004Eoo`1c001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG
7E<LFceK75/mFcaK?E/LFceSFfMlHe]WO6]jJg][NW>JKgU_VW>HMkUcV7NhMiMk]WNFNkEkTg^fNiAk
]G^COk=kTWncNi9o/g^BNk=kTW^dNi80Mgoo00<007ooOol01Goo0@000Goo0Goo0016Ool01@00OomB
oE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;m
DaeBo@=C7@05D_eC7E<MDaeC7003Ead015LLEaeG7E/m0e/l00IOG5llGcaO?5mLJgX2Jg/00fnJKgY_
VP02LiT047>HMiMgUg^fNiIk]G^DNkIkU7^eNi=k]7^BNi=kTW^c0W^B00Ak/g^bNi9k/gQoo`03001o
ogoo00Aoo`40005oo`5oo`00Agoo0P0006iooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeG75LmEaaG?ELLEceG75LmFcaOGE/l
GeaK?5mMGeaSG5lkLiY_NFnJKgUg^G>HMkQgUg^hMiIk]W^DNkQgUW^eNiAo]7^BNk9kTWncNi9k/W^B
Ok=kTW^cNWoo00<007ooOol00goo0@000Goo0Goo0019Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02E<MD_eC7E;mDaeBoE<MD_eG7@03Dad00eLMEaaG
7@02Ead015LLEceG75/m0ell16=L015WO6MKIg]WFg>ILiQcVGNGMkMkUW^fMiMg]g^FNkEkU7^d00=k
T`05Nk=kTW^BNi9k/P02Ni800g^cOomoo`1iOol00`00Oomoo`03Ool10001Ool004Yoo`1/001ooe<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LM
D_aG7E;lEaeBo5/mEaaK?ELLFceG75/mGc]SG5mLHeaO>fMlHe]WO6=KJi][NV]kKgUcVW>HMiUgUg^h
MiMk]W^DOkEkTgncNiAo]7^BOk=kTWncNi9k/g^BO7oo00<007ooOol00goo0@000Goo001;Ool01000
OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d00e<MD_eC7@02
Dad015;mDaeC7ELM0U<M0ULM00EC75LmEaaK?ELL009K?00;FceSG6=LHeaWO6MKIg]WFf]kJgY[N`02
KiX026mjLiUcVGNgMiMk]W^FNkD2Ni<01W^DNkAkTW^CNi9k/P=kTP03Nk=oogoo07]oo`03001oogoo
009oo`40005oo`00C7oo0P0006MC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7E/lFceK75/mFcaK?E/LIgaSFfMlJgY[Vf]j
Jg]_NG>JKgUgVG>HNkQgUgNhMiEo]G^DOkAkU7neNi=o/g^BOk=kTW^bNi9k/`1oOol01@00Oomoogoo
00000Goo001>Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<M
D_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7003Ead015LLEaeK?5/m0U/l00AO?5mLGcaO?09[N`05JgY[
Nf]kKiY_NP03LiT2MiL01W^FNkIkU7^fNiIk]@9kT`07Ni9k/g^CNi=kTW^bNi<0P7oo00@007ooOol0
005oo`00Cgoo06H007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>
o5LMD_aC7E;lEaeBo5LmEaaG?ELLEceG75LmFcaOG5/lGeeK?5mLGc]SG6]jJg][NW>JKgU_VW>HMkUg
UgNhMiMk]W^DMkQgUGneNiAo]7^BOk=kTWncNi9k/g^BNk:0Ool01000Oomoo`000Goo001@Ool00`00
Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@IC7@0:
EaeG75LMEaeK?ELLEceO?5mLGc`6He`00fnJKgY_VP02LiT047>HMiMgUg^fNiIgUg^FNkIkU7^eNi=k
/g^BNi=kTW^b0W^BPWoo00<007oo00000Goo001AOol20000HDklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMD_aG7ELLFceG75/mEaaK?ELLHeaO>f=LGeaS
G5lkIgaSFfMlJgY[Vf]jKiY_NGNiLiQg^7NGNkIkU7^eNi=o/g^BOkAkTWncNi9o/g^B08=oo`40005o
o`400000Dgoo00H004kmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d00e<MD_eC7@02
Dad01E;mDaeC7ELMDad00eLM00AG75LmEaaK?@=K?0=SG004Ie]WO6MKIg/2Jg/046]jKiY_VW>ILiQc
VGNGNkIkUW^eNiAk]7^DNkEkTg^c0g^BQGoo0P00001DOol0G`00OomC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeBo5<MDaaG7E<LEaeC75LMDaaK?E/lFceK75/mFcaK?F=KIgaS
Ff]kJgY[Vf]jKiY_NG>JLiQgVGNGNkQgUW^eNiAo]7NFNkEkTgndNi9k/W^BOk<0QGoo0P00001EOol0
1P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeC
7003Ead01ELLFcaK?5/mFc`00Ull00=OG5llJg/00V]k011[NVnJKiY_VW>HLiUgUgNgNiIk]W^DNkEk
UW^eNiAk]09kTP03Ni=k/W^B08Eoo`800000EWoo05`007ooOom>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;l
Dae>o5<MD_aC7E;lEaeBo5<MD_aG7ELLEaeG75LmEaaG7ELLGeeK?5mLFcaOGE/lHeaO>f=LGe]_VVmi
LiYcV7NILiQk^7NGNkIgUg^hMiMk]W^DOkAkTgncNi=o/g^BPWoo10000Woo001GOol2000017ooD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC
7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d2Dad00eLMDaeC7@02Ead01ELLEaeG75/m
Ea`00Ull00=OG6=LHe`00f=L00AWNfMKIgacV09cV@09MkMgUg>IMiMg]gNGNkIkU7^e009kT`04NiEk
]7^BNi9nOol40006Ool005Uoo`1H001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG
7E;lEaeBo5LMD_aK?ELLFceG75/mEaaK?EmKHeaO>f=LGe]WO6=KIga[NV]kJgYcVVmiMiUcV7^hMiMg
^7NEOkEkTgndNiAo]7^BNk9kOol4000:Ool005Yoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@03DaeB
oE;m009C7@03D_eC7E<M00AC7@09EaeC75LMEaeK?ELLEceG75/m009K?09SG005Ie]WNfMKIga[NP02
Jg/01FnJKgY_VW>IMkL00WNG00IkUW^eNiAkTg^ENkD2Ni<00g^BOomoo`1eOol4000>Ool005]oo`1F
001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MDaaG7E<LEaeC75LMDaaK?E/LFceK?5/m
FaaK?F=KIgaSFfMlJgY[Nf]jLiY_NFnJLiQg^GNGMkQgUg^fNiAk]WNEOkEkTgndNi9o]7=oo`@0019o
o`00G7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EC75LMEaeG7ELL009G
7@05FceK?5/lFcaOG003Gc`01emLJgY[Nf]kKiY_NVnJ009cV@=gU`06NkIkU7NGNiIk]G^D0W^C00=k
]7ooOol0Kgoo0`005Woo001NOol0DP00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5Lm
EaaG7ELLEceG75LMFcaOGE/lGeaK?5mMGe]SG5lkLiY_NFnJKgUg^G>HMkQgUg^hMiIg^7NENkIkU7^e
Ni=o]G^CKGoo10006Goo001OOol01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_d4Dad00eLMDaeG
7@02Ead015LLEceG75/m0ell16=L00IWO6MKIg]WFg>ILiP2MiL02WNgLiQgUgNGNkIkU7^eNi=k/g^C
JWoo10007Goo001POol0C`00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaK?ELL
FceG75/mGc]SG5mKHeaO>fMlHe]WO6=KJi][NVnJKgUcVW>HMiUgUg^fMiIk]G^DOkAkU7nd06Ioo`@0
025oo`00HGoo0P0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00EC7DkmD_eBoE<M00=Bo@03DaeBoE<M009C7@04D_eC7E<MEad3Dad01ULMDaaG7ELLFceG709K
?00:FceSG6=LHeaWO6MKIg]WFf]kJgX3KiX02G>HLiUgUgNgNiIk]G^ENkAkUP02Ni=ROol4000UOol0
06=oo`1;001C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75LMFcaK?E/LFceK?5/mFaaWO6=K
Iga[NV^KJgY[NfmiLiY_NGNILiQk^7NFNkIkU7neMiIk]G^C061oo`<002Uoo`00I7oo00<005<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC
7E;mDaeBo@=C7@05D_eC7E<MEaeC7003Ead015LLEaeK?5/m0U/l15ll0V]k00E[NV]kKiY_VVmj009c
V@09MkMgUg^fMiMg]gNGNkIkUG^d05aoo`@002aoo`00IGoo04P007ooC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;l
DaeG75LmEaaG7ELLEceG75mLFcaOGE/lGeaO>f=LGe]SG6miLiY_NGNILiQg^GNGMiUgUg^hMiMk]W^D
OkAIOol4000`Ool006Ioo`800005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00eC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eG7@03Dad00eLMEaaG7@02Ead00eLLEceG
7002Gc`5He`00fMKIgaWF`03LiT016mjLiUcVGNg0WNG00=kUW^eNi<0EGoo1000=7oo001XOol0A@00
OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7E;lDaeBo5LMD_aG7E;lEaeG75/mEaaK?ELLFceG76=LGc]SG5mKIgaSFfMlHe][Nf]jJi]_NFnJ
LiQk^7NGMkQgUGneNi=k]P1AOol4000hOol006Uoo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE;mD_eC7E;m0e<M00EBoE<MDaeG7E<L00=G7@04EaaG
?ELLFcd3Fc`01U/mFcaWNfMKIga[NP=[N`04KgY_VW>ILiT3MiL00g^fNiAk]P1>Ool4000lOol006Yo
o`12001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7DklDaeBo5<MD_aG7E;lEaeC75LMDaaG7E<LFceK?5/mFaaK?E/lGeaK?5mMJgY[Nf]jLiY_NFnJLiQg
^GNGMkQgUg^fNiAg^7NEBgoo0`00@7oo001[Ool20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG7003Ead00eLLEaeO?005
Gc`3He`01VnJKgY_VVnJLiUcV09gU`04MkMkUWNGNiI8Ool40013Ool006eoo`0n001oodkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5LM
EaaG?ELLFceG75/mFcaOG5/lHeaOFf=LGc]WO6=KIgaSFgNiLiQg^7NGNkQcV7NhMiMk]TAoo`@004Mo
o`00KWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeB
oE<MD_eC7E;m0U<M00aG7E<MDaeC7ELMEaaK?ELLFceG75/mEa`4He`01VMlIe]WNfMKJg][NP=_VP04
LiQcVGNGNkI1Ool4001;Ool006moo`0k001oogooDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMEaaK?ELLFceK75/mFcaSG5lkIgaSFfMl
He][Vf]jKiY_NG>JLiQgVGNGNkQgUP0mOol4001?Ool0071oo`800003OomC7Dkm009Bo@06Dae>oE;m
D_eC7Dkm0U;m00YC7DkmD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeC7003Ead015<LFcaK?5/m
0e/l00MWO6MKIg]WFf]kJgY[N`02KiX01G>HLiUgUgNgNiH0>goo0`00Dgoo001bOol0=`00C_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeC75LMDaaG7ELL
EaeG75/mFcaK?E/lGeeK?5mLFca[Vf]jJg]_NG>JLiQgVG>HNkQgUg^f03Moo`@005Ioo`00Lgoo00@0
05;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELM
EaeG7003Ead00eLLGcaO?003Gc`4He`2KiX01W>HLiUcVGNgMiMcVCAoo`@005Yoo`00M7oo03@004km
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMEaaG7ELL
EceG75/mEaaK?EmKHeaO>f=LGe]SG6=KIga[NV]kJgYcVVmiMiUcV31oo`@005ioo`00MGoo0P0000IC
7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00=C7E;mDad00U<M00ABoE<MDaeG7@=C7@05FceG
75/mEaaK?@02Fc`3He`016MkIe]WO6]j0V]k00A_VVmjLiUcVBeoo`@0069oo`00Mgoo030005<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeK75/mFcaK
?E/LFceK?6MlHe]WO6]jJg][NV^KKgU_VW>HMiTYOol4001VOol007Qoo`03001C7Dkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMDa`00eLM0e/l00=K?EllGc`00Ull
00I[NV]kJg][NfmjKiX2LiTWOol3001ZOol007Uoo`0]001C7DklDae>oE<MC_aC7DklDae>o5<MD_aC
7DklDaeBo5<MC_aG7E;lDaeBo5LMEaaG7ELLEceG75LMEaaOGE/lGeaK?5mMGe]SG5lkHea_NFnJLiQg
VG>H02=oo`@006eoo`00NWoo00<007ooC_d00U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m
0U<M00=G7E<MDad00ULM00EG75LMEaaK?ELL009O?0ESG09WF`9[N`03JgYoogoo01ioo`@0075oo`00
Ngoo0P0002M>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5LMD_aG7E;lFceG75/m
EaaK?ELLHeaOFf=LGc]WO6=KIga[NV^KJgX07Goo1000MGoo001mOol01P00C_eBoE;mDae>o@9Bo@06
DaeBoE;mD_eC7E;m0e<M00EBoE<MEaeG7E<L009G7@05FceG75/mFcaK?@02Fc`016MKIgaWFfMK0V]k
00=[NWooOol067oo1000NGoo001nOol09000C_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeB
o5LMDaaG7E<LEaeC75/mFaaK?E/lGeaK?5mMFcaOG6]jJi][NQMoo`@007eoo`00Ogoo00D007ooD_eB
oE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7ELL00=G7@IO?0=SG1Eoo`<0085oo`00P7oo
0P0001iC7DklDae>o5<MD_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMEaaG7ELLFceG75/mFcaOGE/lHeaO
>f=LGe/BOol40024Ool0089oo`04001BoE;mDad3D_d00e<MD_eC7@02Dad015;mDaeC7ELM0U<M00MG
75/mEaaK?ELLFceG7003He`@Ool40028Ool008=oo`0J001C7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG
7E<LEaeC75LMEaaK?ELLFceK?5/mFaaK?@eoo`@008aoo`00Q7oo00T007ooD_eC7E;mDaeBoE<MD_d0
0e<M00EBoELMEaeG7E<L009G7@04FceK?5/lFc`;Ool4002@Ool008Eoo`80000BD_aC7DklDaeBo5<M
D_aG7E;lDaeBo5LMEaaG7ELLEceG75LM2Woo0`00U7oo0027Ool02000D_eC7E;mDaeBoE<MD_d2Dad0
0eLMDaeC7@02Ead00eLLOomoo`06Ool4002GOol008Qoo`0=001Bo5<MC_aC7E;lDaeBo5LMD_aG7E;l
Ead01Woo1000Vgoo0029Ool01000OomC7E;m0e<M00=BoGooOol017oo1000Wgoo002:Ool200000e<M
D_aC7@04Ool4002SOol008aoo`800003Ool0000000800:Moo`00SGoo0P00Zgoo003oOolkOol00?mo
oc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.654 .767 .933 r
.38974 .79873 .39807 .80538 .41198 .80137 .40369 .79478 Mtetra
.66 .771 .932 r
.40369 .79478 .41198 .80137 .42597 .79701 .41772 .79057 Mtetra
.673 .779 .93 r
.41772 .79057 .42597 .79701 .44004 .79203 .43183 .7859 Mtetra
.695 .793 .926 r
.43183 .7859 .44004 .79203 .45419 .78589 .44603 .78038 Mtetra
.732 .816 .917 r
.44603 .78038 .45419 .78589 .46843 .7777 .46031 .7733 Mtetra
.789 .85 .896 r
.46031 .7733 .46843 .7777 .48275 .76597 .47468 .7635 Mtetra
.861 .888 .854 r
.47468 .7635 .48275 .76597 .49713 .74865 .48912 .74916 Mtetra
.928 .916 .784 r
.48912 .74916 .49713 .74865 .5115 .72379 .50359 .72815 Mtetra
.968 .924 .696 r
.50359 .72815 .5115 .72379 .52577 .69128 .51802 .69914 Mtetra
.977 .919 .623 r
.51802 .69914 .52577 .69128 .53987 .65467 .5323 .66374 Mtetra
.972 .919 .594 r
.5323 .66374 .53987 .65467 .5538 .62011 .5464 .62722 Mtetra
.966 .934 .63 r
.5464 .62722 .5538 .62011 .56763 .59232 .56035 .59554 Mtetra
.951 .95 .724 r
.56035 .59554 .56763 .59232 .58146 .57233 .57425 .57163 Mtetra
.902 .932 .825 r
.57425 .57163 .58146 .57233 .59537 .55855 .5882 .55492 Mtetra
.827 .88 .882 r
.5882 .55492 .59537 .55855 .60937 .54888 .60224 .54338 Mtetra
.762 .828 .903 r
.60224 .54338 .60937 .54888 .62347 .54165 .61637 .53503 Mtetra
.718 .79 .909 r
.61637 .53503 .62347 .54165 .63766 .53578 .6306 .52853 Mtetra
.693 .768 .909 r
.6306 .52853 .63766 .53578 .65193 .53063 .64492 .52302 Mtetra
.679 .756 .909 r
.64492 .52302 .65193 .53063 .66629 .52587 .65932 .51804 Mtetra
.672 .749 .909 r
.65932 .51804 .66629 .52587 .68073 .5213 .67381 .51334 Mtetra
.668 .745 .908 r
.67381 .51334 .68073 .5213 .69525 .51682 .68838 .50877 Mtetra
.666 .743 .908 r
.68838 .50877 .69525 .51682 .70985 .51237 .70302 .50425 Mtetra
.665 .742 .908 r
.70302 .50425 .70985 .51237 .72452 .50793 .71775 .49976 Mtetra
.664 .742 .908 r
.71775 .49976 .72452 .50793 .73927 .50349 .73255 .49527 Mtetra
.73255 .49527 .73927 .50349 .75409 .49903 .74743 .49077 Mtetra
.664 .741 .908 r
.74743 .49077 .75409 .49903 .76899 .49456 .76238 .48624 Mtetra
.76238 .48624 .76899 .49456 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.651 .766 .933 r
.38133 .79199 .38974 .79873 .40369 .79478 .39532 .78807 Mtetra
.656 .769 .932 r
.39532 .78807 .40369 .79478 .41772 .79057 .40939 .78397 Mtetra
.666 .775 .931 r
.40939 .78397 .41772 .79057 .43183 .7859 .42355 .77951 Mtetra
.682 .785 .928 r
.42355 .77951 .43183 .7859 .44603 .78038 .43778 .77443 Mtetra
.711 .803 .922 r
.43778 .77443 .44603 .78038 .46031 .7733 .45211 .76819 Mtetra
.758 .832 .909 r
.45211 .76819 .46031 .7733 .47468 .7635 .46652 .75987 Mtetra
.824 .869 .879 r
.46652 .75987 .47468 .7635 .48912 .74916 .48102 .74798 Mtetra
.897 .905 .822 r
.48102 .74798 .48912 .74916 .50359 .72815 .49558 .73047 Mtetra
.952 .923 .74 r
.49558 .73047 .50359 .72815 .51802 .69914 .51013 .70536 Mtetra
.976 .922 .656 r
.51013 .70536 .51802 .69914 .5323 .66374 .52459 .67256 Mtetra
.975 .918 .602 r
.52459 .67256 .5323 .66374 .5464 .62722 .53887 .63563 Mtetra
.969 .924 .604 r
.53887 .63563 .5464 .62722 .56035 .59554 .55296 .60077 Mtetra
.962 .944 .672 r
.55296 .60077 .56035 .59554 .57425 .57163 .56697 .57274 Mtetra
.932 .946 .778 r
.56697 .57274 .57425 .57163 .5882 .55492 .58097 .55254 Mtetra
.865 .908 .859 r
.58097 .55254 .5882 .55492 .60224 .54338 .59504 .53861 Mtetra
.792 .852 .896 r
.59504 .53861 .60224 .54338 .61637 .53503 .60921 .5288 Mtetra
.737 .807 .907 r
.60921 .5288 .61637 .53503 .6306 .52853 .62348 .52145 Mtetra
.704 .778 .909 r
.62348 .52145 .6306 .52853 .64492 .52302 .63784 .51547 Mtetra
.685 .761 .909 r
.63784 .51547 .64492 .52302 .65932 .51804 .65229 .51021 Mtetra
.675 .752 .909 r
.65229 .51021 .65932 .51804 .67381 .51334 .66682 .50534 Mtetra
.67 .747 .908 r
.66682 .50534 .67381 .51334 .68838 .50877 .68144 .50066 Mtetra
.667 .744 .908 r
.68144 .50066 .68838 .50877 .70302 .50425 .69614 .49607 Mtetra
.665 .743 .908 r
.69614 .49607 .70302 .50425 .71775 .49976 .71091 .49152 Mtetra
.664 .742 .908 r
.71091 .49152 .71775 .49976 .73255 .49527 .72577 .48697 Mtetra
.72577 .48697 .73255 .49527 .74743 .49077 .7407 .48242 Mtetra
.7407 .48242 .74743 .49077 .76238 .48624 .75571 .47785 Mtetra
.664 .741 .908 r
.75571 .47785 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46866 Mtetra
.78597 .46866 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.65 .765 .933 r
.37283 .78516 .38133 .79199 .39532 .78807 .38687 .78126 Mtetra
.654 .767 .933 r
.38687 .78126 .39532 .78807 .40939 .78397 .40099 .77721 Mtetra
.66 .771 .932 r
.40099 .77721 .40939 .78397 .42355 .77951 .41519 .77291 Mtetra
.673 .779 .93 r
.41519 .77291 .42355 .77951 .43778 .77443 .42947 .76814 Mtetra
.695 .793 .926 r
.42947 .76814 .43778 .77443 .45211 .76819 .44383 .76251 Mtetra
.732 .816 .917 r
.44383 .76251 .45211 .76819 .46652 .75987 .45829 .75531 Mtetra
.789 .85 .896 r
.45829 .75531 .46652 .75987 .48102 .74798 .47284 .74537 Mtetra
.861 .888 .854 r
.47284 .74537 .48102 .74798 .49558 .73047 .48746 .73086 Mtetra
.928 .917 .783 r
.48746 .73086 .49558 .73047 .51013 .70536 .50212 .70963 Mtetra
.968 .925 .696 r
.50212 .70963 .51013 .70536 .52459 .67256 .51673 .68034 Mtetra
.977 .919 .623 r
.51673 .68034 .52459 .67256 .53887 .63563 .53119 .64463 Mtetra
.972 .919 .594 r
.53119 .64463 .53887 .63563 .55296 .60077 .54547 .60779 Mtetra
.966 .934 .63 r
.54547 .60779 .55296 .60077 .56697 .57274 .55959 .57584 Mtetra
.951 .949 .725 r
.55959 .57584 .56697 .57274 .58097 .55254 .57367 .5517 Mtetra
.902 .932 .825 r
.57367 .5517 .58097 .55254 .59504 .53861 .58779 .53481 Mtetra
.827 .88 .882 r
.58779 .53481 .59504 .53861 .60921 .5288 .60199 .52312 Mtetra
.762 .827 .903 r
.60199 .52312 .60921 .5288 .62348 .52145 .61629 .51465 Mtetra
.718 .79 .909 r
.61629 .51465 .62348 .52145 .63784 .51547 .63069 .50802 Mtetra
.693 .768 .909 r
.63069 .50802 .63784 .51547 .65229 .51021 .64519 .5024 Mtetra
.679 .756 .909 r
.64519 .5024 .65229 .51021 .66682 .50534 .65977 .49732 Mtetra
.672 .749 .909 r
.65977 .49732 .66682 .50534 .68144 .50066 .67444 .4925 Mtetra
.668 .745 .908 r
.67444 .4925 .68144 .50066 .69614 .49607 .68919 .48782 Mtetra
.666 .743 .908 r
.68919 .48782 .69614 .49607 .71091 .49152 .70401 .4832 Mtetra
.665 .742 .908 r
.70401 .4832 .71091 .49152 .72577 .48697 .71892 .4786 Mtetra
.664 .742 .908 r
.71892 .4786 .72577 .48697 .7407 .48242 .73391 .47399 Mtetra
.73391 .47399 .7407 .48242 .75571 .47785 .74897 .46938 Mtetra
.664 .741 .908 r
.74897 .46938 .75571 .47785 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46866 .77935 .46009 Mtetra
.77935 .46009 .78597 .46866 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.649 .764 .933 r
.36426 .77824 .37283 .78516 .38687 .78126 .37834 .77434 Mtetra
.651 .766 .933 r
.37834 .77434 .38687 .78126 .40099 .77721 .3925 .77034 Mtetra
.656 .769 .932 r
.3925 .77034 .40099 .77721 .41519 .77291 .40674 .76613 Mtetra
.666 .775 .931 r
.40674 .76613 .41519 .77291 .42947 .76814 .42107 .76158 Mtetra
.682 .785 .928 r
.42107 .76158 .42947 .76814 .44383 .76251 .43548 .75639 Mtetra
.711 .804 .922 r
.43548 .75639 .44383 .76251 .45829 .75531 .44997 .75004 Mtetra
.758 .832 .909 r
.44997 .75004 .45829 .75531 .47284 .74537 .46457 .74159 Mtetra
.824 .869 .879 r
.46457 .74159 .47284 .74537 .48746 .73086 .47925 .72955 Mtetra
.897 .905 .822 r
.47925 .72955 .48746 .73086 .50212 .70963 .49399 .71184 Mtetra
.952 .923 .74 r
.49399 .71184 .50212 .70963 .51673 .68034 .50873 .68648 Mtetra
.975 .923 .656 r
.50873 .68648 .51673 .68034 .53119 .64463 .52337 .65337 Mtetra
.975 .918 .601 r
.52337 .65337 .53119 .64463 .54547 .60779 .53783 .61612 Mtetra
.969 .924 .604 r
.53783 .61612 .54547 .60779 .55959 .57584 .55211 .58096 Mtetra
.962 .943 .673 r
.55211 .58096 .55959 .57584 .57367 .5517 .56629 .55267 Mtetra
.931 .946 .778 r
.56629 .55267 .57367 .5517 .58779 .53481 .58046 .53227 Mtetra
.865 .908 .859 r
.58046 .53227 .58779 .53481 .60199 .52312 .59471 .51818 Mtetra
.792 .852 .896 r
.59471 .51818 .60199 .52312 .61629 .51465 .60905 .50824 Mtetra
.737 .807 .907 r
.60905 .50824 .61629 .51465 .63069 .50802 .62349 .50076 Mtetra
.704 .778 .909 r
.62349 .50076 .63069 .50802 .64519 .5024 .63802 .49466 Mtetra
.685 .761 .909 r
.63802 .49466 .64519 .5024 .65977 .49732 .65265 .48929 Mtetra
.675 .752 .909 r
.65265 .48929 .65977 .49732 .67444 .4925 .66737 .48431 Mtetra
.67 .747 .908 r
.66737 .48431 .67444 .4925 .68919 .48782 .68217 .47951 Mtetra
.667 .744 .908 r
.68217 .47951 .68919 .48782 .70401 .4832 .69705 .47481 Mtetra
.665 .743 .908 r
.69705 .47481 .70401 .4832 .71892 .4786 .71201 .47015 Mtetra
.664 .742 .908 r
.71201 .47015 .71892 .4786 .73391 .47399 .72705 .46549 Mtetra
.72705 .46549 .73391 .47399 .74897 .46938 .74217 .46082 Mtetra
.74217 .46082 .74897 .46938 .76412 .46474 .75737 .45614 Mtetra
.664 .741 .908 r
.75737 .45614 .76412 .46474 .77935 .46009 .77266 .45144 Mtetra
.77266 .45144 .77935 .46009 .79466 .45541 .78802 .44671 Mtetra
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44197 Mtetra
.80347 .44197 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.648 .764 .933 r
.3556 .77125 .36426 .77824 .37834 .77434 .36973 .76734 Mtetra
.65 .765 .933 r
.36973 .76734 .37834 .77434 .3925 .77034 .38393 .76335 Mtetra
.654 .767 .933 r
.38393 .76335 .3925 .77034 .40674 .76613 .39822 .75921 Mtetra
.66 .771 .932 r
.39822 .75921 .40674 .76613 .42107 .76158 .41259 .75481 Mtetra
.673 .779 .93 r
.41259 .75481 .42107 .76158 .43548 .75639 .42704 .74993 Mtetra
.695 .793 .926 r
.42704 .74993 .43548 .75639 .44997 .75004 .44158 .74419 Mtetra
.732 .816 .917 r
.44158 .74419 .44997 .75004 .46457 .74159 .45622 .73687 Mtetra
.789 .85 .897 r
.45622 .73687 .46457 .74159 .47925 .72955 .47095 .72678 Mtetra
.861 .888 .854 r
.47095 .72678 .47925 .72955 .49399 .71184 .48575 .7121 Mtetra
.929 .917 .783 r
.48575 .7121 .49399 .71184 .50873 .68648 .5006 .69064 Mtetra
.968 .925 .696 r
.5006 .69064 .50873 .68648 .52337 .65337 .5154 .66107 Mtetra
.977 .919 .623 r
.5154 .66107 .52337 .65337 .53783 .61612 .53006 .62504 Mtetra
.972 .919 .594 r
.53006 .62504 .53783 .61612 .55211 .58096 .54451 .58789 Mtetra
.966 .934 .631 r
.54451 .58789 .55211 .58096 .56629 .55267 .55882 .55565 Mtetra
.951 .949 .725 r
.55882 .55565 .56629 .55267 .58046 .53227 .57307 .53128 Mtetra
.902 .931 .825 r
.57307 .53128 .58046 .53227 .59471 .51818 .58736 .51421 Mtetra
.827 .88 .882 r
.58736 .51421 .59471 .51818 .60905 .50824 .60174 .50237 Mtetra
.762 .827 .903 r
.60174 .50237 .60905 .50824 .62349 .50076 .61622 .49376 Mtetra
.718 .79 .908 r
.61622 .49376 .62349 .50076 .63802 .49466 .63079 .48702 Mtetra
.693 .768 .909 r
.63079 .48702 .63802 .49466 .65265 .48929 .64547 .48128 Mtetra
.679 .756 .909 r
.64547 .48128 .65265 .48929 .66737 .48431 .66023 .47608 Mtetra
.672 .749 .909 r
.66023 .47608 .66737 .48431 .68217 .47951 .67508 .47115 Mtetra
.668 .745 .908 r
.67508 .47115 .68217 .47951 .69705 .47481 .69001 .46636 Mtetra
.666 .743 .908 r
.69001 .46636 .69705 .47481 .71201 .47015 .70503 .46162 Mtetra
.665 .742 .908 r
.70503 .46162 .71201 .47015 .72705 .46549 .72012 .4569 Mtetra
.664 .742 .908 r
.72012 .4569 .72705 .46549 .74217 .46082 .7353 .45219 Mtetra
.7353 .45219 .74217 .46082 .75737 .45614 .75056 .44745 Mtetra
.664 .741 .908 r
.75056 .44745 .75737 .45614 .77266 .45144 .7659 .4427 Mtetra
.7659 .4427 .77266 .45144 .78802 .44671 .78132 .43793 Mtetra
.78132 .43793 .78802 .44671 .80347 .44197 .79683 .43313 Mtetra
.79683 .43313 .80347 .44197 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42347 Mtetra
.8281 .42347 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.647 .763 .934 r
.34685 .76418 .3556 .77125 .36973 .76734 .36103 .76025 Mtetra
.649 .764 .933 r
.36103 .76025 .36973 .76734 .38393 .76335 .37528 .75626 Mtetra
.651 .766 .933 r
.37528 .75626 .38393 .76335 .39822 .75921 .38961 .75215 Mtetra
.656 .769 .932 r
.38961 .75215 .39822 .75921 .41259 .75481 .40403 .74785 Mtetra
.666 .775 .931 r
.40403 .74785 .41259 .75481 .42704 .74993 .41852 .7432 Mtetra
.682 .785 .928 r
.41852 .7432 .42704 .74993 .44158 .74419 .43311 .7379 Mtetra
.711 .804 .922 r
.43311 .7379 .44158 .74419 .45622 .73687 .44779 .73142 Mtetra
.758 .832 .909 r
.44779 .73142 .45622 .73687 .47095 .72678 .46256 .72284 Mtetra
.824 .869 .879 r
.46256 .72284 .47095 .72678 .48575 .7121 .47743 .71064 Mtetra
.897 .905 .822 r
.47743 .71064 .48575 .7121 .5006 .69064 .49235 .69273 Mtetra
.952 .923 .74 r
.49235 .69273 .5006 .69064 .5154 .66107 .50729 .66712 Mtetra
.975 .923 .655 r
.50729 .66712 .5154 .66107 .53006 .62504 .52212 .63371 Mtetra
.975 .918 .601 r
.52212 .63371 .53006 .62504 .54451 .58789 .53678 .59613 Mtetra
.969 .924 .604 r
.53678 .59613 .54451 .58789 .55882 .55565 .55124 .56066 Mtetra
.962 .943 .673 r
.55124 .56066 .55882 .55565 .57307 .53128 .56559 .53211 Mtetra
.931 .946 .778 r
.56559 .53211 .57307 .53128 .58736 .51421 .57994 .51151 Mtetra
.865 .908 .859 r
.57994 .51151 .58736 .51421 .60174 .50237 .59436 .49724 Mtetra
.792 .852 .896 r
.59436 .49724 .60174 .50237 .61622 .49376 .60888 .48716 Mtetra
.737 .807 .907 r
.60888 .48716 .61622 .49376 .63079 .48702 .6235 .47956 Mtetra
.704 .778 .909 r
.6235 .47956 .63079 .48702 .64547 .48128 .63822 .47333 Mtetra
.685 .761 .909 r
.63822 .47333 .64547 .48128 .66023 .47608 .65303 .46785 Mtetra
.675 .752 .909 r
.65303 .46785 .66023 .47608 .67508 .47115 .66793 .46275 Mtetra
.67 .747 .908 r
.66793 .46275 .67508 .47115 .69001 .46636 .68291 .45784 Mtetra
.667 .744 .908 r
.68291 .45784 .69001 .46636 .70503 .46162 .69798 .45302 Mtetra
.665 .743 .908 r
.69798 .45302 .70503 .46162 .72012 .4569 .71313 .44824 Mtetra
.664 .742 .908 r
.71313 .44824 .72012 .4569 .7353 .45219 .72836 .44347 Mtetra
.72836 .44347 .7353 .45219 .75056 .44745 .74368 .43868 Mtetra
.74368 .43868 .75056 .44745 .7659 .4427 .75908 .43388 Mtetra
.664 .741 .908 r
.75908 .43388 .7659 .4427 .78132 .43793 .77456 .42906 Mtetra
.77456 .42906 .78132 .43793 .79683 .43313 .79013 .42422 Mtetra
.79013 .42422 .79683 .43313 .81242 .42831 .80578 .41934 Mtetra
.80578 .41934 .81242 .42831 .8281 .42347 .82151 .41445 Mtetra
.82151 .41445 .8281 .42347 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.647 .763 .934 r
.33802 .75703 .34685 .76418 .36103 .76025 .35225 .75308 Mtetra
.648 .764 .933 r
.35225 .75308 .36103 .76025 .37528 .75626 .36654 .74908 Mtetra
.65 .765 .933 r
.36654 .74908 .37528 .75626 .38961 .75215 .38092 .74499 Mtetra
.654 .767 .933 r
.38092 .74499 .38961 .75215 .40403 .74785 .39538 .74075 Mtetra
.66 .772 .932 r
.39538 .74075 .40403 .74785 .41852 .7432 .40992 .73624 Mtetra
.673 .779 .93 r
.40992 .73624 .41852 .7432 .43311 .7379 .42455 .73126 Mtetra
.695 .793 .926 r
.42455 .73126 .43311 .7379 .44779 .73142 .43927 .7254 Mtetra
.732 .816 .917 r
.43927 .7254 .44779 .73142 .46256 .72284 .45409 .71796 Mtetra
.789 .85 .897 r
.45409 .71796 .46256 .72284 .47743 .71064 .46901 .70772 Mtetra
.861 .889 .854 r
.46901 .70772 .47743 .71064 .49235 .69273 .484 .69286 Mtetra
.929 .917 .783 r
.484 .69286 .49235 .69273 .50729 .66712 .49904 .67117 Mtetra
.968 .925 .696 r
.49904 .67117 .50729 .66712 .52212 .63371 .51404 .64131 Mtetra
.977 .919 .623 r
.51404 .64131 .52212 .63371 .53678 .59613 .52889 .60496 Mtetra
.972 .919 .594 r
.52889 .60496 .53678 .59613 .55124 .56066 .54354 .56748 Mtetra
.966 .934 .631 r
.54354 .56748 .55124 .56066 .56559 .53211 .55802 .53496 Mtetra
.951 .949 .725 r
.55802 .53496 .56559 .53211 .57994 .51151 .57245 .51036 Mtetra
.902 .931 .825 r
.57245 .51036 .57994 .51151 .59436 .49724 .58692 .4931 Mtetra
.827 .88 .882 r
.58692 .4931 .59436 .49724 .60888 .48716 .60148 .4811 Mtetra
.762 .827 .903 r
.60148 .4811 .60888 .48716 .6235 .47956 .61614 .47236 Mtetra
.718 .79 .908 r
.61614 .47236 .6235 .47956 .63822 .47333 .6309 .46549 Mtetra
.693 .768 .909 r
.6309 .46549 .63822 .47333 .65303 .46785 .64575 .45963 Mtetra
.679 .756 .909 r
.64575 .45963 .65303 .46785 .66793 .46275 .6607 .45431 Mtetra
.672 .749 .909 r
.6607 .45431 .66793 .46275 .68291 .45784 .67574 .44927 Mtetra
.668 .745 .908 r
.67574 .44927 .68291 .45784 .69798 .45302 .69086 .44435 Mtetra
.666 .743 .908 r
.69086 .44435 .69798 .45302 .71313 .44824 .70607 .4395 Mtetra
.665 .742 .908 r
.70607 .4395 .71313 .44824 .72836 .44347 .72135 .43466 Mtetra
.664 .742 .908 r
.72135 .43466 .72836 .44347 .74368 .43868 .73673 .42983 Mtetra
.73673 .42983 .74368 .43868 .75908 .43388 .75218 .42497 Mtetra
.664 .741 .908 r
.75218 .42497 .75908 .43388 .77456 .42906 .76773 .4201 Mtetra
.76773 .4201 .77456 .42906 .79013 .42422 .78335 .41521 Mtetra
.78335 .41521 .79013 .42422 .80578 .41934 .79906 .41029 Mtetra
.79906 .41029 .80578 .41934 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.647 .763 .934 r
.32911 .74981 .33802 .75703 .35225 .75308 .34337 .74583 Mtetra
.34337 .74583 .35225 .75308 .36654 .74908 .35772 .74181 Mtetra
.649 .764 .933 r
.35772 .74181 .36654 .74908 .38092 .74499 .37214 .73772 Mtetra
.651 .766 .933 r
.37214 .73772 .38092 .74499 .39538 .74075 .38665 .73351 Mtetra
.656 .769 .932 r
.38665 .73351 .39538 .74075 .40992 .73624 .40124 .7291 Mtetra
.666 .775 .931 r
.40124 .7291 .40992 .73624 .42455 .73126 .41591 .72434 Mtetra
.682 .785 .928 r
.41591 .72434 .42455 .73126 .43927 .7254 .43068 .71893 Mtetra
.711 .804 .922 r
.43068 .71893 .43927 .7254 .45409 .71796 .44554 .71234 Mtetra
.758 .832 .909 r
.44554 .71234 .45409 .71796 .46901 .70772 .4605 .70362 Mtetra
.824 .87 .879 r
.4605 .70362 .46901 .70772 .484 .69286 .47556 .69125 Mtetra
.897 .905 .822 r
.47556 .69125 .484 .69286 .49904 .67117 .49068 .67313 Mtetra
.953 .924 .74 r
.49068 .67313 .49904 .67117 .51404 .64131 .50581 .64726 Mtetra
.975 .923 .655 r
.50581 .64726 .51404 .64131 .52889 .60496 .52084 .61354 Mtetra
.975 .918 .601 r
.52084 .61354 .52889 .60496 .54354 .56748 .53569 .57563 Mtetra
.969 .924 .604 r
.53569 .57563 .54354 .56748 .55802 .53496 .55034 .53984 Mtetra
.962 .943 .673 r
.55034 .53984 .55802 .53496 .57245 .51036 .56488 .51104 Mtetra
.931 .946 .779 r
.56488 .51104 .57245 .51036 .58692 .4931 .57941 .49022 Mtetra
.865 .908 .859 r
.57941 .49022 .58692 .4931 .60148 .4811 .59401 .47579 Mtetra
.792 .852 .896 r
.59401 .47579 .60148 .4811 .61614 .47236 .60871 .46556 Mtetra
.737 .807 .907 r
.60871 .46556 .61614 .47236 .6309 .46549 .62351 .45782 Mtetra
.704 .778 .909 r
.62351 .45782 .6309 .46549 .64575 .45963 .63841 .45147 Mtetra
.685 .761 .909 r
.63841 .45147 .64575 .45963 .6607 .45431 .65341 .44587 Mtetra
.675 .752 .909 r
.65341 .44587 .6607 .45431 .67574 .44927 .6685 .44065 Mtetra
.67 .747 .908 r
.6685 .44065 .67574 .44927 .69086 .44435 .68367 .43562 Mtetra
.667 .744 .908 r
.68367 .43562 .69086 .44435 .70607 .4395 .69893 .43068 Mtetra
.665 .743 .908 r
.69893 .43068 .70607 .4395 .72135 .43466 .71428 .42578 Mtetra
.664 .742 .908 r
.71428 .42578 .72135 .43466 .73673 .42983 .72971 .42088 Mtetra
.72971 .42088 .73673 .42983 .75218 .42497 .74522 .41598 Mtetra
.74522 .41598 .75218 .42497 .76773 .4201 .76082 .41105 Mtetra
.664 .741 .908 r
.76082 .41105 .76773 .4201 .78335 .41521 .77651 .40611 Mtetra
.77651 .40611 .78335 .41521 .79906 .41029 .79228 .40114 Mtetra
.79228 .40114 .79906 .41029 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38607 Mtetra
.84012 .38607 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .763 .934 r
.3201 .74251 .32911 .74981 .34337 .74583 .33442 .73851 Mtetra
.647 .763 .934 r
.33442 .73851 .34337 .74583 .35772 .74181 .34881 .73446 Mtetra
.648 .764 .933 r
.34881 .73446 .35772 .74181 .37214 .73772 .36328 .73035 Mtetra
.65 .765 .933 r
.36328 .73035 .37214 .73772 .38665 .73351 .37783 .72616 Mtetra
.654 .767 .933 r
.37783 .72616 .38665 .73351 .40124 .7291 .39247 .72181 Mtetra
.66 .772 .932 r
.39247 .72181 .40124 .7291 .41591 .72434 .40719 .7172 Mtetra
.673 .779 .93 r
.40719 .7172 .41591 .72434 .43068 .71893 .422 .71211 Mtetra
.695 .793 .926 r
.422 .71211 .43068 .71893 .44554 .71234 .43691 .70613 Mtetra
.732 .817 .917 r
.43691 .70613 .44554 .71234 .4605 .70362 .45191 .69856 Mtetra
.789 .85 .897 r
.45191 .69856 .4605 .70362 .47556 .69125 .46702 .68817 Mtetra
.861 .889 .855 r
.46702 .68817 .47556 .69125 .49068 .67313 .48221 .67312 Mtetra
.929 .917 .783 r
.48221 .67312 .49068 .67313 .50581 .64726 .49745 .65119 Mtetra
.968 .925 .696 r
.49745 .65119 .50581 .64726 .52084 .61354 .51264 .62105 Mtetra
.977 .919 .622 r
.51264 .62105 .52084 .61354 .53569 .57563 .52769 .58437 Mtetra
.972 .919 .595 r
.52769 .58437 .53569 .57563 .55034 .53984 .54253 .54656 Mtetra
.967 .934 .631 r
.54253 .54656 .55034 .53984 .56488 .51104 .55721 .51375 Mtetra
.951 .949 .725 r
.55721 .51375 .56488 .51104 .57941 .49022 .57182 .48891 Mtetra
.902 .931 .825 r
.57182 .48891 .57941 .49022 .59401 .47579 .58648 .47146 Mtetra
.827 .88 .882 r
.58648 .47146 .59401 .47579 .60871 .46556 .60121 .4593 Mtetra
.762 .827 .903 r
.60121 .4593 .60871 .46556 .62351 .45782 .61606 .45042 Mtetra
.718 .79 .908 r
.61606 .45042 .62351 .45782 .63841 .45147 .631 .44342 Mtetra
.693 .768 .909 r
.631 .44342 .63841 .45147 .65341 .44587 .64605 .43743 Mtetra
.679 .756 .909 r
.64605 .43743 .65341 .44587 .6685 .44065 .66118 .43199 Mtetra
.672 .749 .909 r
.66118 .43199 .6685 .44065 .68367 .43562 .67641 .42682 Mtetra
.668 .745 .908 r
.67641 .42682 .68367 .43562 .69893 .43068 .69173 .42179 Mtetra
.666 .743 .908 r
.69173 .42179 .69893 .43068 .71428 .42578 .70713 .41681 Mtetra
.665 .742 .908 r
.70713 .41681 .71428 .42578 .72971 .42088 .72262 .41185 Mtetra
.664 .742 .908 r
.72262 .41185 .72971 .42088 .74522 .41598 .73819 .40689 Mtetra
.73819 .40689 .74522 .41598 .76082 .41105 .75385 .40191 Mtetra
.664 .741 .908 r
.75385 .40191 .76082 .41105 .77651 .40611 .7696 .39692 Mtetra
.7696 .39692 .77651 .40611 .79228 .40114 .78543 .39189 Mtetra
.78543 .39189 .79228 .40114 .80814 .39614 .80135 .38685 Mtetra
.80135 .38685 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38607 .83346 .37667 Mtetra
.83346 .37667 .84012 .38607 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .763 .934 r
.31101 .73514 .3201 .74251 .33442 .73851 .32537 .7311 Mtetra
.647 .763 .934 r
.32537 .7311 .33442 .73851 .34881 .73446 .33981 .72702 Mtetra
.33981 .72702 .34881 .73446 .36328 .73035 .35433 .7229 Mtetra
.649 .764 .933 r
.35433 .7229 .36328 .73035 .37783 .72616 .36893 .7187 Mtetra
.651 .766 .933 r
.36893 .7187 .37783 .72616 .39247 .72181 .38361 .71439 Mtetra
.656 .769 .932 r
.38361 .71439 .39247 .72181 .40719 .7172 .39838 .70987 Mtetra
.666 .775 .931 r
.39838 .70987 .40719 .7172 .422 .71211 .41324 .705 Mtetra
.682 .785 .928 r
.41324 .705 .422 .71211 .43691 .70613 .42819 .69947 Mtetra
.711 .804 .922 r
.42819 .69947 .43691 .70613 .45191 .69856 .44324 .69275 Mtetra
.758 .832 .909 r
.44324 .69275 .45191 .69856 .46702 .68817 .45839 .68389 Mtetra
.824 .87 .879 r
.45839 .68389 .46702 .68817 .48221 .67312 .47364 .67135 Mtetra
.897 .906 .822 r
.47364 .67135 .48221 .67312 .49745 .65119 .48896 .65302 Mtetra
.953 .924 .74 r
.48896 .65302 .49745 .65119 .51264 .62105 .5043 .62689 Mtetra
.975 .923 .655 r
.5043 .62689 .51264 .62105 .52769 .58437 .51953 .59285 Mtetra
.975 .918 .601 r
.51953 .59285 .52769 .58437 .54253 .54656 .53458 .5546 Mtetra
.969 .924 .604 r
.53458 .5546 .54253 .54656 .55721 .51375 .54942 .5185 Mtetra
.962 .943 .674 r
.54942 .5185 .55721 .51375 .57182 .48891 .56415 .48943 Mtetra
.931 .945 .779 r
.56415 .48943 .57182 .48891 .58648 .47146 .57887 .4684 Mtetra
.865 .907 .859 r
.57887 .4684 .58648 .47146 .60121 .4593 .59365 .45379 Mtetra
.792 .852 .896 r
.59365 .45379 .60121 .4593 .61606 .45042 .60853 .44341 Mtetra
.737 .807 .907 r
.60853 .44341 .61606 .45042 .631 .44342 .62352 .43554 Mtetra
.704 .778 .909 r
.62352 .43554 .631 .44342 .64605 .43743 .63861 .42906 Mtetra
.685 .761 .909 r
.63861 .42906 .64605 .43743 .66118 .43199 .6538 .42332 Mtetra
.675 .752 .909 r
.6538 .42332 .66118 .43199 .67641 .42682 .66908 .41798 Mtetra
.67 .747 .908 r
.66908 .41798 .67641 .42682 .69173 .42179 .68445 .41283 Mtetra
.667 .744 .908 r
.68445 .41283 .69173 .42179 .70713 .41681 .69991 .40777 Mtetra
.665 .743 .908 r
.69991 .40777 .70713 .41681 .72262 .41185 .71546 .40274 Mtetra
.664 .742 .908 r
.71546 .40274 .72262 .41185 .73819 .40689 .73109 .39772 Mtetra
.73109 .39772 .73819 .40689 .75385 .40191 .74681 .39268 Mtetra
.74681 .39268 .75385 .40191 .7696 .39692 .76262 .38763 Mtetra
.664 .741 .908 r
.76262 .38763 .7696 .39692 .78543 .39189 .77851 .38256 Mtetra
.77851 .38256 .78543 .39189 .80135 .38685 .79449 .37746 Mtetra
.79449 .37746 .80135 .38685 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .763 .934 r
.30182 .72769 .31101 .73514 .32537 .7311 .31623 .72361 Mtetra
.31623 .72361 .32537 .7311 .33981 .72702 .33071 .7195 Mtetra
.647 .763 .934 r
.33071 .7195 .33981 .72702 .35433 .7229 .34528 .71535 Mtetra
.648 .764 .933 r
.34528 .71535 .35433 .7229 .36893 .7187 .35993 .71114 Mtetra
.65 .765 .933 r
.35993 .71114 .36893 .7187 .38361 .71439 .37466 .70684 Mtetra
.654 .767 .933 r
.37466 .70684 .38361 .71439 .39838 .70987 .38948 .70239 Mtetra
.66 .772 .932 r
.38948 .70239 .39838 .70987 .41324 .705 .40438 .69766 Mtetra
.673 .779 .93 r
.40438 .69766 .41324 .705 .42819 .69947 .41938 .69245 Mtetra
.695 .793 .926 r
.41938 .69245 .42819 .69947 .44324 .69275 .43448 .68636 Mtetra
.732 .817 .917 r
.43448 .68636 .44324 .69275 .45839 .68389 .44968 .67865 Mtetra
.789 .85 .897 r
.44968 .67865 .45839 .68389 .47364 .67135 .46498 .6681 Mtetra
.862 .889 .855 r
.46498 .6681 .47364 .67135 .48896 .65302 .48037 .65286 Mtetra
.929 .918 .783 r
.48037 .65286 .48896 .65302 .5043 .62689 .49581 .63069 Mtetra
.968 .925 .695 r
.49581 .63069 .5043 .62689 .51953 .59285 .51121 .60026 Mtetra
.977 .92 .622 r
.51121 .60026 .51953 .59285 .53458 .5546 .52647 .56324 Mtetra
.972 .919 .595 r
.52647 .56324 .53458 .5546 .54942 .5185 .54151 .5251 Mtetra
.967 .933 .632 r
.54151 .5251 .54942 .5185 .56415 .48943 .55637 .49199 Mtetra
.951 .949 .726 r
.55637 .49199 .56415 .48943 .57887 .4684 .57118 .46691 Mtetra
.902 .931 .825 r
.57118 .46691 .57887 .4684 .59365 .45379 .58602 .44927 Mtetra
.827 .879 .882 r
.58602 .44927 .59365 .45379 .60853 .44341 .60094 .43695 Mtetra
.762 .827 .903 r
.60094 .43695 .60853 .44341 .62352 .43554 .61597 .42792 Mtetra
.718 .79 .908 r
.61597 .42792 .62352 .43554 .63861 .42906 .63111 .42078 Mtetra
.693 .768 .909 r
.63111 .42078 .63861 .42906 .6538 .42332 .64635 .41467 Mtetra
.679 .756 .909 r
.64635 .41467 .6538 .42332 .66908 .41798 .66168 .4091 Mtetra
.672 .749 .909 r
.66168 .4091 .66908 .41798 .68445 .41283 .6771 .40381 Mtetra
.668 .745 .908 r
.6771 .40381 .68445 .41283 .69991 .40777 .69262 .39865 Mtetra
.666 .743 .908 r
.69262 .39865 .69991 .40777 .71546 .40274 .70822 .39354 Mtetra
.665 .742 .908 r
.70822 .39354 .71546 .40274 .73109 .39772 .72391 .38845 Mtetra
.664 .742 .908 r
.72391 .38845 .73109 .39772 .74681 .39268 .73969 .38336 Mtetra
.73969 .38336 .74681 .39268 .76262 .38763 .75556 .37825 Mtetra
.664 .741 .908 r
.75556 .37825 .76262 .38763 .77851 .38256 .77152 .37313 Mtetra
.77152 .37313 .77851 .38256 .79449 .37746 .78757 .36797 Mtetra
.78757 .36797 .79449 .37746 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .763 .934 r
.29254 .72017 .30182 .72769 .31623 .72361 .30699 .71605 Mtetra
.30699 .71605 .31623 .72361 .33071 .7195 .32153 .7119 Mtetra
.647 .763 .934 r
.32153 .7119 .33071 .7195 .34528 .71535 .33615 .70772 Mtetra
.33615 .70772 .34528 .71535 .35993 .71114 .35084 .70349 Mtetra
.649 .764 .933 r
.35084 .70349 .35993 .71114 .37466 .70684 .36562 .69918 Mtetra
.651 .766 .933 r
.36562 .69918 .37466 .70684 .38948 .70239 .38049 .69476 Mtetra
.656 .769 .932 r
.38049 .69476 .38948 .70239 .40438 .69766 .39544 .69014 Mtetra
.666 .775 .931 r
.39544 .69014 .40438 .69766 .41938 .69245 .41049 .68515 Mtetra
.682 .785 .928 r
.41049 .68515 .41938 .69245 .43448 .68636 .42563 .6795 Mtetra
.711 .804 .922 r
.42563 .6795 .43448 .68636 .44968 .67865 .44087 .67265 Mtetra
.758 .832 .909 r
.44087 .67265 .44968 .67865 .46498 .6681 .45622 .66364 Mtetra
.824 .87 .879 r
.45622 .66364 .46498 .6681 .48037 .65286 .47167 .65093 Mtetra
.898 .906 .822 r
.47167 .65093 .48037 .65286 .49581 .63069 .4872 .63238 Mtetra
.953 .924 .739 r
.4872 .63238 .49581 .63069 .51121 .60026 .50274 .60598 Mtetra
.975 .923 .655 r
.50274 .60598 .51121 .60026 .52647 .56324 .51819 .57162 Mtetra
.975 .918 .601 r
.51819 .57162 .52647 .56324 .54151 .5251 .53344 .53303 Mtetra
.969 .924 .605 r
.53344 .53303 .54151 .5251 .55637 .49199 .54848 .49661 Mtetra
.962 .943 .674 r
.54848 .49661 .55637 .49199 .57118 .46691 .5634 .46727 Mtetra
.931 .945 .779 r
.5634 .46727 .57118 .46691 .58602 .44927 .57831 .44602 Mtetra
.865 .907 .859 r
.57831 .44602 .58602 .44927 .60094 .43695 .59328 .43123 Mtetra
.792 .852 .896 r
.59328 .43123 .60094 .43695 .61597 .42792 .60835 .42069 Mtetra
.737 .807 .907 r
.60835 .42069 .61597 .42792 .63111 .42078 .62353 .41268 Mtetra
.704 .778 .909 r
.62353 .41268 .63111 .42078 .64635 .41467 .63882 .40607 Mtetra
.685 .761 .909 r
.63882 .40607 .64635 .41467 .66168 .4091 .6542 .4002 Mtetra
.675 .752 .909 r
.6542 .4002 .66168 .4091 .6771 .40381 .66968 .39473 Mtetra
.67 .747 .908 r
.66968 .39473 .6771 .40381 .69262 .39865 .68525 .38945 Mtetra
.667 .744 .908 r
.68525 .38945 .69262 .39865 .70822 .39354 .70092 .38426 Mtetra
.665 .743 .908 r
.70092 .38426 .70822 .39354 .72391 .38845 .71667 .3791 Mtetra
.664 .742 .908 r
.71667 .3791 .72391 .38845 .73969 .38336 .73251 .37395 Mtetra
.73251 .37395 .73969 .38336 .75556 .37825 .74844 .36878 Mtetra
.74844 .36878 .75556 .37825 .77152 .37313 .76446 .3636 Mtetra
.664 .741 .908 r
.76446 .3636 .77152 .37313 .78757 .36797 .78056 .35839 Mtetra
.78056 .35839 .78757 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72017 .30699 .71605 .29767 .70841 Mtetra
.646 .763 .934 r
.29767 .70841 .30699 .71605 .32153 .7119 .31225 .70422 Mtetra
.31225 .70422 .32153 .7119 .33615 .70772 .32692 .70001 Mtetra
.647 .763 .934 r
.32692 .70001 .33615 .70772 .35084 .70349 .34166 .69575 Mtetra
.648 .764 .933 r
.34166 .69575 .35084 .70349 .36562 .69918 .35649 .69143 Mtetra
.65 .765 .933 r
.35649 .69143 .36562 .69918 .38049 .69476 .37141 .68701 Mtetra
.654 .767 .933 r
.37141 .68701 .38049 .69476 .39544 .69014 .38641 .68245 Mtetra
.66 .772 .932 r
.38641 .68245 .39544 .69014 .41049 .68515 .40151 .67761 Mtetra
.673 .779 .93 r
.40151 .67761 .41049 .68515 .42563 .6795 .4167 .67228 Mtetra
.695 .793 .926 r
.4167 .67228 .42563 .6795 .44087 .67265 .43199 .66606 Mtetra
.732 .817 .917 r
.43199 .66606 .44087 .67265 .45622 .66364 .44738 .65821 Mtetra
.789 .851 .897 r
.44738 .65821 .45622 .66364 .47167 .65093 .46288 .6475 Mtetra
.862 .889 .855 r
.46288 .6475 .47167 .65093 .4872 .63238 .47848 .63206 Mtetra
.929 .918 .783 r
.47848 .63206 .4872 .63238 .50274 .60598 .49413 .60965 Mtetra
.968 .925 .695 r
.49413 .60965 .50274 .60598 .51819 .57162 .50974 .57892 Mtetra
.977 .92 .622 r
.50974 .57892 .51819 .57162 .53344 .53303 .52521 .54156 Mtetra
.972 .919 .595 r
.52521 .54156 .53344 .53303 .54848 .49661 .54045 .50308 Mtetra
.967 .933 .632 r
.54045 .50308 .54848 .49661 .5634 .46727 .55552 .46967 Mtetra
.951 .949 .726 r
.55552 .46967 .5634 .46727 .57831 .44602 .57052 .44435 Mtetra
.901 .93 .825 r
.57052 .44435 .57831 .44602 .59328 .43123 .58555 .42651 Mtetra
.827 .879 .882 r
.58555 .42651 .59328 .43123 .60835 .42069 .60066 .41402 Mtetra
.762 .827 .903 r
.60066 .41402 .60835 .42069 .62353 .41268 .61589 .40484 Mtetra
.718 .79 .908 r
.61589 .40484 .62353 .41268 .63882 .40607 .63122 .39756 Mtetra
.693 .768 .909 r
.63122 .39756 .63882 .40607 .6542 .4002 .64665 .39132 Mtetra
.679 .756 .909 r
.64665 .39132 .6542 .4002 .66968 .39473 .66219 .38561 Mtetra
.672 .749 .909 r
.66219 .38561 .66968 .39473 .68525 .38945 .67781 .38019 Mtetra
.668 .745 .908 r
.67781 .38019 .68525 .38945 .70092 .38426 .69353 .3749 Mtetra
.666 .743 .908 r
.69353 .3749 .70092 .38426 .71667 .3791 .70934 .36966 Mtetra
.665 .742 .908 r
.70934 .36966 .71667 .3791 .73251 .37395 .72525 .36444 Mtetra
.664 .742 .908 r
.72525 .36444 .73251 .37395 .74844 .36878 .74124 .35921 Mtetra
.74124 .35921 .74844 .36878 .76446 .3636 .75732 .35397 Mtetra
.664 .741 .908 r
.75732 .35397 .76446 .3636 .78056 .35839 .77349 .3487 Mtetra
.77349 .3487 .78056 .35839 .79676 .35315 .78976 .34341 Mtetra
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70841 .28825 .70069 Mtetra
.646 .763 .934 r
.28825 .70069 .29767 .70841 .31225 .70422 .30288 .69646 Mtetra
.30288 .69646 .31225 .70422 .32692 .70001 .31759 .69221 Mtetra
.647 .763 .934 r
.31759 .69221 .32692 .70001 .34166 .69575 .33239 .68791 Mtetra
.33239 .68791 .34166 .69575 .35649 .69143 .34727 .68357 Mtetra
.649 .764 .933 r
.34727 .68357 .35649 .69143 .37141 .68701 .36223 .67915 Mtetra
.651 .766 .933 r
.36223 .67915 .37141 .68701 .38641 .68245 .37729 .67462 Mtetra
.656 .769 .932 r
.37729 .67462 .38641 .68245 .40151 .67761 .39243 .66988 Mtetra
.666 .775 .931 r
.39243 .66988 .40151 .67761 .4167 .67228 .40767 .66477 Mtetra
.682 .785 .928 r
.40767 .66477 .4167 .67228 .43199 .66606 .42301 .659 Mtetra
.711 .804 .922 r
.42301 .659 .43199 .66606 .44738 .65821 .43845 .65201 Mtetra
.758 .832 .909 r
.43845 .65201 .44738 .65821 .46288 .6475 .454 .64285 Mtetra
.824 .87 .879 r
.454 .64285 .46288 .6475 .47848 .63206 .46966 .62996 Mtetra
.898 .906 .822 r
.46966 .62996 .47848 .63206 .49413 .60965 .48539 .61119 Mtetra
.953 .924 .739 r
.48539 .61119 .49413 .60965 .50974 .57892 .50115 .58451 Mtetra
.975 .923 .655 r
.50115 .58451 .50974 .57892 .52521 .54156 .51681 .54983 Mtetra
.975 .918 .601 r
.51681 .54983 .52521 .54156 .54045 .50308 .53227 .51089 Mtetra
.969 .924 .605 r
.53227 .51089 .54045 .50308 .55552 .46967 .54751 .47415 Mtetra
.962 .943 .674 r
.54751 .47415 .55552 .46967 .57052 .44435 .56263 .44453 Mtetra
.931 .945 .779 r
.56263 .44453 .57052 .44435 .58555 .42651 .57773 .42306 Mtetra
.865 .907 .859 r
.57773 .42306 .58555 .42651 .60066 .41402 .5929 .40809 Mtetra
.792 .852 .895 r
.5929 .40809 .60066 .41402 .61589 .40484 .60817 .39739 Mtetra
.737 .806 .907 r
.60817 .39739 .61589 .40484 .63122 .39756 .62355 .38923 Mtetra
.704 .778 .909 r
.62355 .38923 .63122 .39756 .64665 .39132 .63903 .38248 Mtetra
.685 .761 .909 r
.63903 .38248 .64665 .39132 .66219 .38561 .65462 .37648 Mtetra
.675 .752 .909 r
.65462 .37648 .66219 .38561 .67781 .38019 .6703 .37087 Mtetra
.67 .747 .908 r
.6703 .37087 .67781 .38019 .69353 .3749 .68608 .36546 Mtetra
.667 .744 .908 r
.68608 .36546 .69353 .3749 .70934 .36966 .70195 .36013 Mtetra
.665 .743 .908 r
.70195 .36013 .70934 .36966 .72525 .36444 .71791 .35484 Mtetra
.664 .742 .908 r
.71791 .35484 .72525 .36444 .74124 .35921 .73396 .34955 Mtetra
.73396 .34955 .74124 .35921 .75732 .35397 .75011 .34424 Mtetra
.75011 .34424 .75732 .35397 .77349 .3487 .76634 .33892 Mtetra
.664 .741 .908 r
.76634 .33892 .77349 .3487 .78976 .34341 .78267 .33357 Mtetra
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Mtetra
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .70069 .27873 .69289 Mtetra
.27873 .69289 .28825 .70069 .30288 .69646 .29341 .68862 Mtetra
.646 .763 .934 r
.29341 .68862 .30288 .69646 .31759 .69221 .30817 .68432 Mtetra
.30817 .68432 .31759 .69221 .33239 .68791 .32302 .68 Mtetra
.647 .763 .934 r
.32302 .68 .33239 .68791 .34727 .68357 .33795 .67562 Mtetra
.648 .764 .933 r
.33795 .67562 .34727 .68357 .36223 .67915 .35297 .67119 Mtetra
.65 .765 .933 r
.35297 .67119 .36223 .67915 .37729 .67462 .36807 .66666 Mtetra
.654 .767 .933 r
.36807 .66666 .37729 .67462 .39243 .66988 .38326 .66198 Mtetra
.66 .772 .932 r
.38326 .66198 .39243 .66988 .40767 .66477 .39855 .65702 Mtetra
.673 .779 .93 r
.39855 .65702 .40767 .66477 .42301 .659 .41394 .65157 Mtetra
.695 .793 .926 r
.41394 .65157 .42301 .659 .43845 .65201 .42942 .64521 Mtetra
.732 .817 .917 r
.42942 .64521 .43845 .65201 .454 .64285 .44502 .63722 Mtetra
.789 .851 .897 r
.44502 .63722 .454 .64285 .46966 .62996 .46073 .62634 Mtetra
.862 .89 .855 r
.46073 .62634 .46966 .62996 .48539 .61119 .47654 .61071 Mtetra
.929 .918 .783 r
.47654 .61071 .48539 .61119 .50115 .58451 .4924 .58804 Mtetra
.968 .925 .695 r
.4924 .58804 .50115 .58451 .51681 .54983 .50824 .557 Mtetra
.977 .92 .622 r
.50824 .557 .51681 .54983 .53227 .51089 .52391 .5193 Mtetra
.972 .919 .595 r
.52391 .5193 .53227 .51089 .54751 .47415 .53937 .48048 Mtetra
.967 .933 .632 r
.53937 .48048 .54751 .47415 .56263 .44453 .55464 .44677 Mtetra
.951 .948 .726 r
.55464 .44677 .56263 .44453 .57773 .42306 .56984 .4212 Mtetra
.901 .93 .825 r
.56984 .4212 .57773 .42306 .5929 .40809 .58506 .40315 Mtetra
.827 .879 .882 r
.58506 .40315 .5929 .40809 .60817 .39739 .60038 .39049 Mtetra
.762 .827 .903 r
.60038 .39049 .60817 .39739 .62355 .38923 .6158 .38116 Mtetra
.718 .79 .908 r
.6158 .38116 .62355 .38923 .63903 .38248 .63133 .37374 Mtetra
.693 .768 .909 r
.63133 .37374 .63903 .38248 .65462 .37648 .64697 .36735 Mtetra
.679 .756 .909 r
.64697 .36735 .65462 .37648 .6703 .37087 .66271 .36151 Mtetra
.672 .749 .908 r
.66271 .36151 .6703 .37087 .68608 .36546 .67854 .35595 Mtetra
.668 .745 .908 r
.67854 .35595 .68608 .36546 .70195 .36013 .69447 .35052 Mtetra
.666 .743 .908 r
.69447 .35052 .70195 .36013 .71791 .35484 .7105 .34514 Mtetra
.665 .742 .908 r
.7105 .34514 .71791 .35484 .73396 .34955 .72661 .33979 Mtetra
.664 .742 .908 r
.72661 .33979 .73396 .34955 .75011 .34424 .74282 .33442 Mtetra
.74282 .33442 .75011 .34424 .76634 .33892 .75912 .32904 Mtetra
.664 .741 .908 r
.75912 .32904 .76634 .33892 .78267 .33357 .77552 .32363 Mtetra
.77552 .32363 .78267 .33357 .7991 .32819 .79201 .31819 Mtetra
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .685 Mtetra
.26911 .685 .27873 .69289 .29341 .68862 .28384 .68069 Mtetra
.646 .763 .934 r
.28384 .68069 .29341 .68862 .30817 .68432 .29865 .67636 Mtetra
.29865 .67636 .30817 .68432 .32302 .68 .31355 .67199 Mtetra
.647 .763 .934 r
.31355 .67199 .32302 .68 .33795 .67562 .32853 .66758 Mtetra
.32853 .66758 .33795 .67562 .35297 .67119 .3436 .66312 Mtetra
.649 .764 .933 r
.3436 .66312 .35297 .67119 .36807 .66666 .35876 .65859 Mtetra
.651 .766 .933 r
.35876 .65859 .36807 .66666 .38326 .66198 .374 .65393 Mtetra
.656 .769 .932 r
.374 .65393 .38326 .66198 .39855 .65702 .38934 .64907 Mtetra
.666 .775 .931 r
.38934 .64907 .39855 .65702 .41394 .65157 .40477 .64384 Mtetra
.682 .786 .928 r
.40477 .64384 .41394 .65157 .42942 .64521 .42031 .63794 Mtetra
.711 .804 .922 r
.42031 .63794 .42942 .64521 .44502 .63722 .43596 .63081 Mtetra
.758 .833 .909 r
.43596 .63081 .44502 .63722 .46073 .62634 .45171 .62149 Mtetra
.825 .87 .879 r
.45171 .62149 .46073 .62634 .47654 .61071 .46758 .60842 Mtetra
.898 .906 .822 r
.46758 .60842 .47654 .61071 .4924 .58804 .48353 .58943 Mtetra
.953 .924 .739 r
.48353 .58943 .4924 .58804 .50824 .557 .49951 .56246 Mtetra
.975 .923 .654 r
.49951 .56246 .50824 .557 .52391 .5193 .51539 .52745 Mtetra
.975 .918 .601 r
.51539 .52745 .52391 .5193 .53937 .48048 .53106 .48816 Mtetra
.969 .924 .605 r
.53106 .48816 .53937 .48048 .55464 .44677 .54652 .45109 Mtetra
.962 .943 .675 r
.54652 .45109 .55464 .44677 .56984 .4212 .56184 .4212 Mtetra
.931 .945 .779 r
.56184 .4212 .56984 .4212 .58506 .40315 .57715 .3995 Mtetra
.865 .907 .859 r
.57715 .3995 .58506 .40315 .60038 .39049 .59251 .38433 Mtetra
.792 .851 .895 r
.59251 .38433 .60038 .39049 .6158 .38116 .60798 .37347 Mtetra
.737 .806 .907 r
.60798 .37347 .6158 .38116 .63133 .37374 .62356 .36516 Mtetra
.704 .778 .909 r
.62356 .36516 .63133 .37374 .64697 .36735 .63925 .35827 Mtetra
.685 .761 .909 r
.63925 .35827 .64697 .36735 .66271 .36151 .65504 .35213 Mtetra
.675 .752 .909 r
.65504 .35213 .66271 .36151 .67854 .35595 .67093 .34638 Mtetra
.67 .747 .908 r
.67093 .34638 .67854 .35595 .69447 .35052 .68692 .34083 Mtetra
.667 .744 .908 r
.68692 .34083 .69447 .35052 .7105 .34514 .70301 .33536 Mtetra
.665 .743 .908 r
.70301 .33536 .7105 .34514 .72661 .33979 .71918 .32993 Mtetra
.664 .742 .908 r
.71918 .32993 .72661 .33979 .74282 .33442 .73546 .32449 Mtetra
.73546 .32449 .74282 .33442 .75912 .32904 .75182 .31905 Mtetra
.75182 .31905 .75912 .32904 .77552 .32363 .76828 .31358 Mtetra
.664 .741 .908 r
.76828 .31358 .77552 .32363 .79201 .31819 .78484 .30809 Mtetra
.78484 .30809 .79201 .31819 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .685 .25939 .67704 Mtetra
.25939 .67704 .26911 .685 .28384 .68069 .27417 .67269 Mtetra
.27417 .67269 .28384 .68069 .29865 .67636 .28904 .66831 Mtetra
.646 .763 .934 r
.28904 .66831 .29865 .67636 .31355 .67199 .30398 .66389 Mtetra
.30398 .66389 .31355 .67199 .32853 .66758 .31902 .65945 Mtetra
.647 .763 .934 r
.31902 .65945 .32853 .66758 .3436 .66312 .33414 .65496 Mtetra
.648 .764 .933 r
.33414 .65496 .3436 .66312 .35876 .65859 .34934 .65041 Mtetra
.65 .765 .933 r
.34934 .65041 .35876 .65859 .374 .65393 .36464 .64576 Mtetra
.654 .767 .933 r
.36464 .64576 .374 .65393 .38934 .64907 .38003 .64095 Mtetra
.66 .772 .932 r
.38003 .64095 .38934 .64907 .40477 .64384 .39552 .63587 Mtetra
.673 .779 .93 r
.39552 .63587 .40477 .64384 .42031 .63794 .4111 .63029 Mtetra
.695 .794 .926 r
.4111 .63029 .42031 .63794 .43596 .63081 .42679 .6238 Mtetra
.732 .817 .917 r
.42679 .6238 .43596 .63081 .45171 .62149 .4426 .61565 Mtetra
.789 .851 .897 r
.4426 .61565 .45171 .62149 .46758 .60842 .45852 .60461 Mtetra
.862 .89 .855 r
.45852 .60461 .46758 .60842 .48353 .58943 .47455 .58877 Mtetra
.929 .918 .783 r
.47455 .58877 .48353 .58943 .49951 .56246 .49063 .56585 Mtetra
.968 .925 .695 r
.49063 .56585 .49951 .56246 .51539 .52745 .50669 .5345 Mtetra
.977 .92 .622 r
.50669 .5345 .51539 .52745 .53106 .48816 .52259 .49645 Mtetra
.972 .919 .595 r
.52259 .49645 .53106 .48816 .54652 .45109 .53826 .45728 Mtetra
.967 .933 .632 r
.53826 .45728 .54652 .45109 .56184 .4212 .55374 .42326 Mtetra
.951 .948 .726 r
.55374 .42326 .56184 .4212 .57715 .3995 .56914 .39743 Mtetra
.901 .93 .825 r
.56914 .39743 .57715 .3995 .59251 .38433 .58457 .37918 Mtetra
.827 .879 .882 r
.58457 .37918 .59251 .38433 .60798 .37347 .60009 .36634 Mtetra
.762 .827 .903 r
.60009 .36634 .60798 .37347 .62356 .36516 .61571 .35685 Mtetra
.718 .79 .908 r
.61571 .35685 .62356 .36516 .63925 .35827 .63145 .34928 Mtetra
.693 .768 .909 r
.63145 .34928 .63925 .35827 .65504 .35213 .6473 .34275 Mtetra
.679 .756 .909 r
.6473 .34275 .65504 .35213 .67093 .34638 .66324 .33676 Mtetra
.672 .749 .908 r
.66324 .33676 .67093 .34638 .68692 .34083 .67929 .33106 Mtetra
.668 .745 .908 r
.67929 .33106 .68692 .34083 .70301 .33536 .69544 .32549 Mtetra
.666 .743 .908 r
.69544 .32549 .70301 .33536 .71918 .32993 .71168 .31997 Mtetra
.665 .742 .908 r
.71168 .31997 .71918 .32993 .73546 .32449 .72801 .31447 Mtetra
.664 .742 .908 r
.72801 .31447 .73546 .32449 .75182 .31905 .74445 .30896 Mtetra
.74445 .30896 .75182 .31905 .76828 .31358 .76097 .30343 Mtetra
.664 .741 .908 r
.76097 .30343 .76828 .31358 .78484 .30809 .7776 .29787 Mtetra
.7776 .29787 .78484 .30809 .80149 .30256 .79432 .29229 Mtetra
.79432 .29229 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Mtetra
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27535 Mtetra
.84507 .27535 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .66459 Mtetra
.2644 .66459 .27417 .67269 .28904 .66831 .27932 .66017 Mtetra
.646 .763 .934 r
.27932 .66017 .28904 .66831 .30398 .66389 .29431 .65571 Mtetra
.29431 .65571 .30398 .66389 .31902 .65945 .3094 .65123 Mtetra
.647 .763 .934 r
.3094 .65123 .31902 .65945 .33414 .65496 .32457 .6467 Mtetra
.32457 .6467 .33414 .65496 .34934 .65041 .33983 .64212 Mtetra
.649 .764 .933 r
.33983 .64212 .34934 .65041 .36464 .64576 .35518 .63747 Mtetra
.651 .766 .933 r
.35518 .63747 .36464 .64576 .38003 .64095 .37062 .63269 Mtetra
.656 .769 .932 r
.37062 .63269 .38003 .64095 .39552 .63587 .38616 .6277 Mtetra
.666 .775 .931 r
.38616 .6277 .39552 .63587 .4111 .63029 .4018 .62234 Mtetra
.682 .786 .928 r
.4018 .62234 .4111 .63029 .42679 .6238 .41754 .6163 Mtetra
.711 .804 .923 r
.41754 .6163 .42679 .6238 .4426 .61565 .43339 .60903 Mtetra
.758 .833 .909 r
.43339 .60903 .4426 .61565 .45852 .60461 .44936 .59955 Mtetra
.825 .871 .879 r
.44936 .59955 .45852 .60461 .47455 .58877 .46545 .58629 Mtetra
.898 .907 .822 r
.46545 .58629 .47455 .58877 .49063 .56585 .48163 .56706 Mtetra
.953 .925 .739 r
.48163 .56706 .49063 .56585 .50669 .5345 .49782 .53982 Mtetra
.975 .923 .654 r
.49782 .53982 .50669 .5345 .52259 .49645 .51393 .50446 Mtetra
.975 .918 .601 r
.51393 .50446 .52259 .49645 .53826 .45728 .52983 .46482 Mtetra
.969 .924 .605 r
.52983 .46482 .53826 .45728 .55374 .42326 .5455 .42742 Mtetra
.962 .943 .675 r
.5455 .42742 .55374 .42326 .56914 .39743 .56103 .39724 Mtetra
.931 .945 .779 r
.56103 .39724 .56914 .39743 .58457 .37918 .57654 .37531 Mtetra
.865 .906 .859 r
.57654 .37531 .58457 .37918 .60009 .36634 .59211 .35995 Mtetra
.792 .851 .895 r
.59211 .35995 .60009 .36634 .61571 .35685 .60779 .34892 Mtetra
.737 .806 .907 r
.60779 .34892 .61571 .35685 .63145 .34928 .62357 .34045 Mtetra
.704 .778 .909 r
.62357 .34045 .63145 .34928 .6473 .34275 .63947 .33341 Mtetra
.685 .761 .909 r
.63947 .33341 .6473 .34275 .66324 .33676 .65548 .32712 Mtetra
.675 .752 .909 r
.65548 .32712 .66324 .33676 .67929 .33106 .67158 .32123 Mtetra
.67 .747 .908 r
.67158 .32123 .67929 .33106 .69544 .32549 .68779 .31553 Mtetra
.667 .744 .908 r
.68779 .31553 .69544 .32549 .71168 .31997 .70409 .30992 Mtetra
.665 .743 .908 r
.70409 .30992 .71168 .31997 .72801 .31447 .72049 .30434 Mtetra
.664 .742 .908 r
.72049 .30434 .72801 .31447 .74445 .30896 .73699 .29876 Mtetra
.73699 .29876 .74445 .30896 .76097 .30343 .75358 .29316 Mtetra
.75358 .29316 .76097 .30343 .7776 .29787 .77028 .28755 Mtetra
.664 .741 .908 r
.77028 .28755 .7776 .29787 .79432 .29229 .78706 .2819 Mtetra
.78706 .2819 .79432 .29229 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27535 .83803 .26477 Mtetra
.83803 .26477 .84507 .27535 .86218 .26963 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .66459 .25453 .65641 Mtetra
.25453 .65641 .2644 .66459 .27932 .66017 .2695 .65194 Mtetra
.2695 .65194 .27932 .66017 .29431 .65571 .28454 .64744 Mtetra
.646 .763 .934 r
.28454 .64744 .29431 .65571 .3094 .65123 .29968 .64291 Mtetra
.29968 .64291 .3094 .65123 .32457 .6467 .31491 .63835 Mtetra
.647 .763 .934 r
.31491 .63835 .32457 .6467 .33983 .64212 .33022 .63374 Mtetra
.648 .764 .933 r
.33022 .63374 .33983 .64212 .35518 .63747 .34562 .62906 Mtetra
.65 .765 .933 r
.34562 .62906 .35518 .63747 .37062 .63269 .36112 .62429 Mtetra
.654 .767 .933 r
.36112 .62429 .37062 .63269 .38616 .6277 .37671 .61936 Mtetra
.66 .772 .932 r
.37671 .61936 .38616 .6277 .4018 .62234 .3924 .61414 Mtetra
.673 .779 .93 r
.3924 .61414 .4018 .62234 .41754 .6163 .40819 .60843 Mtetra
.695 .794 .926 r
.40819 .60843 .41754 .6163 .43339 .60903 .42409 .60179 Mtetra
.732 .817 .917 r
.42409 .60179 .43339 .60903 .44936 .59955 .44011 .59349 Mtetra
.789 .851 .897 r
.44011 .59349 .44936 .59955 .46545 .58629 .45625 .58227 Mtetra
.862 .89 .855 r
.45625 .58227 .46545 .58629 .48163 .56706 .4725 .56622 Mtetra
.929 .919 .783 r
.4725 .56622 .48163 .56706 .49782 .53982 .48881 .54304 Mtetra
.968 .926 .694 r
.48881 .54304 .49782 .53982 .51393 .50446 .50509 .51137 Mtetra
.977 .92 .622 r
.50509 .51137 .51393 .50446 .52983 .46482 .52122 .47297 Mtetra
.972 .919 .595 r
.52122 .47297 .52983 .46482 .5455 .42742 .53712 .43344 Mtetra
.967 .933 .633 r
.53712 .43344 .5455 .42742 .56103 .39724 .55281 .39912 Mtetra
.951 .948 .727 r
.55281 .39912 .56103 .39724 .57654 .37531 .56842 .37303 Mtetra
.901 .93 .825 r
.56842 .37303 .57654 .37531 .59211 .35995 .58406 .35456 Mtetra
.827 .879 .882 r
.58406 .35456 .59211 .35995 .60779 .34892 .59978 .34154 Mtetra
.762 .827 .903 r
.59978 .34154 .60779 .34892 .62357 .34045 .61562 .33189 Mtetra
.718 .79 .908 r
.61562 .33189 .62357 .34045 .63947 .33341 .63157 .32416 Mtetra
.693 .768 .909 r
.63157 .32416 .63947 .33341 .65548 .32712 .64763 .31748 Mtetra
.679 .756 .909 r
.64763 .31748 .65548 .32712 .67158 .32123 .66379 .31135 Mtetra
.672 .749 .908 r
.66379 .31135 .67158 .32123 .68779 .31553 .68006 .3055 Mtetra
.668 .745 .908 r
.68006 .3055 .68779 .31553 .70409 .30992 .69643 .29977 Mtetra
.666 .743 .908 r
.69643 .29977 .70409 .30992 .72049 .30434 .71289 .29411 Mtetra
.665 .742 .908 r
.71289 .29411 .72049 .30434 .73699 .29876 .72946 .28846 Mtetra
.664 .742 .908 r
.72946 .28846 .73699 .29876 .75358 .29316 .74612 .28279 Mtetra
.74612 .28279 .75358 .29316 .77028 .28755 .76288 .27711 Mtetra
.664 .741 .908 r
.76288 .27711 .77028 .28755 .78706 .2819 .77973 .2714 Mtetra
.77973 .2714 .78706 .2819 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65641 .24456 .64815 Mtetra
.24456 .64815 .25453 .65641 .2695 .65194 .25957 .64363 Mtetra
.25957 .64363 .2695 .65194 .28454 .64744 .27467 .63908 Mtetra
.646 .763 .934 r
.27467 .63908 .28454 .64744 .29968 .64291 .28986 .63451 Mtetra
.28986 .63451 .29968 .64291 .31491 .63835 .30514 .6299 Mtetra
.647 .763 .934 r
.30514 .6299 .31491 .63835 .33022 .63374 .3205 .62525 Mtetra
.3205 .62525 .33022 .63374 .34562 .62906 .33596 .62055 Mtetra
.649 .764 .933 r
.33596 .62055 .34562 .62906 .36112 .62429 .35151 .61576 Mtetra
.651 .766 .933 r
.35151 .61576 .36112 .62429 .37671 .61936 .36715 .61086 Mtetra
.656 .769 .932 r
.36715 .61086 .37671 .61936 .3924 .61414 .3829 .60574 Mtetra
.666 .775 .931 r
.3829 .60574 .3924 .61414 .40819 .60843 .39874 .60024 Mtetra
.682 .786 .928 r
.39874 .60024 .40819 .60843 .42409 .60179 .41469 .59407 Mtetra
.711 .804 .923 r
.41469 .59407 .42409 .60179 .44011 .59349 .43076 .58664 Mtetra
.758 .833 .909 r
.43076 .58664 .44011 .59349 .45625 .58227 .44695 .577 Mtetra
.825 .871 .879 r
.44695 .577 .45625 .58227 .4725 .56622 .46326 .56354 Mtetra
.898 .907 .822 r
.46326 .56354 .4725 .56622 .48881 .54304 .47966 .54408 Mtetra
.953 .925 .739 r
.47966 .54408 .48881 .54304 .50509 .51137 .49609 .51654 Mtetra
.975 .923 .654 r
.49609 .51654 .50509 .51137 .52122 .47297 .51243 .48084 Mtetra
.975 .918 .601 r
.51243 .48084 .52122 .47297 .53712 .43344 .52856 .44084 Mtetra
.97 .924 .605 r
.52856 .44084 .53712 .43344 .55281 .39912 .54446 .4031 Mtetra
.962 .943 .675 r
.54446 .4031 .55281 .39912 .56842 .37303 .5602 .37263 Mtetra
.931 .944 .779 r
.5602 .37263 .56842 .37303 .58406 .35456 .57592 .35046 Mtetra
.865 .906 .859 r
.57592 .35046 .58406 .35456 .59978 .34154 .5917 .33491 Mtetra
.792 .851 .895 r
.5917 .33491 .59978 .34154 .61562 .33189 .60759 .3237 Mtetra
.737 .806 .906 r
.60759 .3237 .61562 .33189 .63157 .32416 .62359 .31507 Mtetra
.704 .777 .909 r
.62359 .31507 .63157 .32416 .64763 .31748 .6397 .30787 Mtetra
.685 .761 .909 r
.6397 .30787 .64763 .31748 .66379 .31135 .65592 .30144 Mtetra
.675 .752 .909 r
.65592 .30144 .66379 .31135 .68006 .3055 .67225 .29539 Mtetra
.67 .747 .908 r
.67225 .29539 .68006 .3055 .69643 .29977 .68868 .28954 Mtetra
.667 .744 .908 r
.68868 .28954 .69643 .29977 .71289 .29411 .70521 .28378 Mtetra
.665 .743 .908 r
.70521 .28378 .71289 .29411 .72946 .28846 .72184 .27805 Mtetra
.664 .742 .908 r
.72184 .27805 .72946 .28846 .74612 .28279 .73857 .27231 Mtetra
.73857 .27231 .74612 .28279 .76288 .27711 .7554 .26656 Mtetra
.7554 .26656 .76288 .27711 .77973 .2714 .77232 .26079 Mtetra
.664 .741 .908 r
.77232 .26079 .77973 .2714 .79669 .26566 .78935 .25499 Mtetra
.78935 .25499 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63908 .26469 .63063 Mtetra
.26469 .63063 .27467 .63908 .28986 .63451 .27993 .62601 Mtetra
.646 .763 .934 r
.27993 .62601 .28986 .63451 .30514 .6299 .29526 .62136 Mtetra
.29526 .62136 .30514 .6299 .3205 .62525 .31068 .61667 Mtetra
.647 .763 .934 r
.31068 .61667 .3205 .62525 .33596 .62055 .32619 .61193 Mtetra
.648 .764 .933 r
.32619 .61193 .33596 .62055 .35151 .61576 .3418 .60712 Mtetra
.65 .765 .933 r
.3418 .60712 .35151 .61576 .36715 .61086 .3575 .60222 Mtetra
.654 .767 .933 r
.3575 .60222 .36715 .61086 .3829 .60574 .37329 .59716 Mtetra
.66 .772 .932 r
.37329 .59716 .3829 .60574 .39874 .60024 .38919 .59181 Mtetra
.673 .78 .93 r
.38919 .59181 .39874 .60024 .41469 .59407 .4052 .58595 Mtetra
.695 .794 .926 r
.4052 .58595 .41469 .59407 .43076 .58664 .42131 .57917 Mtetra
.732 .817 .917 r
.42131 .57917 .43076 .58664 .44695 .577 .43755 .57071 Mtetra
.789 .851 .897 r
.43755 .57071 .44695 .577 .46326 .56354 .45391 .55931 Mtetra
.862 .89 .855 r
.45391 .55931 .46326 .56354 .47966 .54408 .47039 .54304 Mtetra
.929 .919 .783 r
.47039 .54304 .47966 .54408 .49609 .51654 .48694 .51959 Mtetra
.968 .926 .694 r
.48694 .51959 .49609 .51654 .51243 .48084 .50346 .4876 Mtetra
.977 .92 .621 r
.50346 .4876 .51243 .48084 .52856 .44084 .51982 .44884 Mtetra
.972 .919 .595 r
.51982 .44884 .52856 .44084 .54446 .4031 .53594 .40896 Mtetra
.967 .933 .633 r
.53594 .40896 .54446 .4031 .5602 .37263 .55186 .37432 Mtetra
.951 .948 .727 r
.55186 .37432 .5602 .37263 .57592 .35046 .56769 .34796 Mtetra
.901 .93 .825 r
.56769 .34796 .57592 .35046 .5917 .33491 .58354 .32928 Mtetra
.827 .879 .882 r
.58354 .32928 .5917 .33491 .60759 .3237 .59948 .31607 Mtetra
.762 .827 .903 r
.59948 .31607 .60759 .3237 .62359 .31507 .61553 .30625 Mtetra
.718 .79 .908 r
.61553 .30625 .62359 .31507 .6397 .30787 .63169 .29836 Mtetra
.693 .768 .909 r
.63169 .29836 .6397 .30787 .65592 .30144 .64797 .29152 Mtetra
.679 .756 .909 r
.64797 .29152 .65592 .30144 .67225 .29539 .66436 .28524 Mtetra
.672 .749 .908 r
.66436 .28524 .67225 .29539 .68868 .28954 .68085 .27923 Mtetra
.668 .745 .908 r
.68085 .27923 .68868 .28954 .70521 .28378 .69745 .27335 Mtetra
.666 .743 .908 r
.69745 .27335 .70521 .28378 .72184 .27805 .71414 .26753 Mtetra
.665 .742 .908 r
.71414 .26753 .72184 .27805 .73857 .27231 .73094 .26172 Mtetra
.664 .742 .908 r
.73094 .26172 .73857 .27231 .7554 .26656 .74783 .2559 Mtetra
.74783 .2559 .7554 .26656 .77232 .26079 .76483 .25006 Mtetra
.664 .741 .908 r
.76483 .25006 .77232 .26079 .78935 .25499 .78193 .24419 Mtetra
.78193 .24419 .78935 .25499 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62673 Mtetra
.2394 .62673 .24954 .63523 .26469 .63063 .2546 .62209 Mtetra
.2546 .62209 .26469 .63063 .27993 .62601 .2699 .61742 Mtetra
.646 .763 .934 r
.2699 .61742 .27993 .62601 .29526 .62136 .28528 .61272 Mtetra
.28528 .61272 .29526 .62136 .31068 .61667 .30075 .60798 Mtetra
.647 .763 .934 r
.30075 .60798 .31068 .61667 .32619 .61193 .31632 .6032 Mtetra
.31632 .6032 .32619 .61193 .3418 .60712 .33198 .59837 Mtetra
.649 .764 .933 r
.33198 .59837 .3418 .60712 .3575 .60222 .34774 .59346 Mtetra
.651 .766 .933 r
.34774 .59346 .3575 .60222 .37329 .59716 .36359 .58842 Mtetra
.656 .769 .932 r
.36359 .58842 .37329 .59716 .38919 .59181 .37954 .58316 Mtetra
.666 .775 .931 r
.37954 .58316 .38919 .59181 .4052 .58595 .3956 .57753 Mtetra
.682 .786 .928 r
.3956 .57753 .4052 .58595 .42131 .57917 .41177 .5712 Mtetra
.711 .804 .923 r
.41177 .5712 .42131 .57917 .43755 .57071 .42805 .56363 Mtetra
.758 .833 .909 r
.42805 .56363 .43755 .57071 .45391 .55931 .44447 .55381 Mtetra
.825 .871 .88 r
.44447 .55381 .45391 .55931 .47039 .54304 .46101 .54015 Mtetra
.898 .907 .822 r
.46101 .54015 .47039 .54304 .48694 .51959 .47764 .52044 Mtetra
.953 .925 .739 r
.47764 .52044 .48694 .51959 .50346 .4876 .49431 .49261 Mtetra
.975 .923 .654 r
.49431 .49261 .50346 .4876 .51982 .44884 .51089 .45656 Mtetra
.975 .918 .601 r
.51089 .45656 .51982 .44884 .53594 .40896 .52726 .41619 Mtetra
.97 .924 .606 r
.52726 .41619 .53594 .40896 .55186 .37432 .54338 .37811 Mtetra
.962 .943 .676 r
.54338 .37811 .55186 .37432 .56769 .34796 .55935 .34735 Mtetra
.931 .944 .779 r
.55935 .34735 .56769 .34796 .58354 .32928 .57528 .32494 Mtetra
.865 .906 .859 r
.57528 .32494 .58354 .32928 .59948 .31607 .59128 .30918 Mtetra
.792 .851 .895 r
.59128 .30918 .59948 .31607 .61553 .30625 .60738 .2978 Mtetra
.737 .806 .906 r
.60738 .2978 .61553 .30625 .63169 .29836 .6236 .289 Mtetra
.704 .777 .909 r
.6236 .289 .63169 .29836 .64797 .29152 .63994 .28164 Mtetra
.685 .761 .909 r
.63994 .28164 .64797 .29152 .66436 .28524 .65638 .27504 Mtetra
.675 .752 .909 r
.65638 .27504 .66436 .28524 .68085 .27923 .67294 .26884 Mtetra
.67 .747 .908 r
.67294 .26884 .68085 .27923 .69745 .27335 .6896 .26284 Mtetra
.667 .744 .908 r
.6896 .26284 .69745 .27335 .71414 .26753 .70636 .25692 Mtetra
.665 .743 .908 r
.70636 .25692 .71414 .26753 .73094 .26172 .72322 .25102 Mtetra
.664 .742 .908 r
.72322 .25102 .73094 .26172 .74783 .2559 .74019 .24513 Mtetra
.74019 .24513 .74783 .2559 .76483 .25006 .75726 .23922 Mtetra
.75726 .23922 .76483 .25006 .78193 .24419 .77443 .23328 Mtetra
.664 .741 .908 r
.77443 .23328 .78193 .24419 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21528 Mtetra
.646 .762 .934 r
.18391 .63205 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62673 .22915 .61815 Mtetra
.22915 .61815 .2394 .62673 .2546 .62209 .24441 .61346 Mtetra
.24441 .61346 .2546 .62209 .2699 .61742 .25975 .60874 Mtetra
.25975 .60874 .2699 .61742 .28528 .61272 .27519 .60399 Mtetra
.646 .763 .934 r
.27519 .60399 .28528 .61272 .30075 .60798 .29072 .5992 Mtetra
.29072 .5992 .30075 .60798 .31632 .6032 .30634 .59438 Mtetra
.647 .763 .934 r
.30634 .59438 .31632 .6032 .33198 .59837 .32206 .58951 Mtetra
.648 .764 .933 r
.32206 .58951 .33198 .59837 .34774 .59346 .33787 .58457 Mtetra
.65 .765 .933 r
.33787 .58457 .34774 .59346 .36359 .58842 .35377 .57954 Mtetra
.654 .767 .933 r
.35377 .57954 .36359 .58842 .37954 .58316 .36978 .57433 Mtetra
.66 .772 .932 r
.36978 .57433 .37954 .58316 .3956 .57753 .3859 .56885 Mtetra
.673 .78 .93 r
.3859 .56885 .3956 .57753 .41177 .5712 .40212 .56284 Mtetra
.695 .794 .926 r
.40212 .56284 .41177 .5712 .42805 .56363 .41846 .55591 Mtetra
.732 .817 .917 r
.41846 .55591 .42805 .56363 .44447 .55381 .43492 .54728 Mtetra
.789 .851 .897 r
.43492 .54728 .44447 .55381 .46101 .54015 .45151 .53569 Mtetra
.862 .89 .855 r
.45151 .53569 .46101 .54015 .47764 .52044 .46823 .5192 Mtetra
.929 .919 .783 r
.46823 .5192 .47764 .52044 .49431 .49261 .48501 .49548 Mtetra
.968 .926 .694 r
.48501 .49548 .49431 .49261 .51089 .45656 .50178 .46316 Mtetra
.977 .92 .621 r
.50178 .46316 .51089 .45656 .52726 .41619 .51838 .42404 Mtetra
.972 .919 .595 r
.51838 .42404 .52726 .41619 .54338 .37811 .53474 .38379 Mtetra
.967 .933 .633 r
.53474 .38379 .54338 .37811 .55935 .34735 .55088 .34883 Mtetra
.951 .948 .727 r
.55088 .34883 .55935 .34735 .57528 .32494 .56693 .32221 Mtetra
.901 .929 .825 r
.56693 .32221 .57528 .32494 .59128 .30918 .583 .3033 Mtetra
.827 .878 .882 r
.583 .3033 .59128 .30918 .60738 .2978 .59916 .2899 Mtetra
.762 .826 .903 r
.59916 .2899 .60738 .2978 .6236 .289 .61543 .2799 Mtetra
.718 .79 .908 r
.61543 .2799 .6236 .289 .63994 .28164 .63182 .27184 Mtetra
.693 .768 .909 r
.63182 .27184 .63994 .28164 .65638 .27504 .64832 .26484 Mtetra
.679 .756 .909 r
.64832 .26484 .65638 .27504 .67294 .26884 .66494 .2584 Mtetra
.672 .749 .908 r
.66494 .2584 .67294 .26884 .6896 .26284 .68166 .25223 Mtetra
.668 .745 .908 r
.68166 .25223 .6896 .26284 .70636 .25692 .69849 .2462 Mtetra
.666 .743 .908 r
.69849 .2462 .70636 .25692 .72322 .25102 .71542 .24021 Mtetra
.665 .742 .908 r
.71542 .24021 .72322 .25102 .74019 .24513 .73246 .23424 Mtetra
.664 .742 .908 r
.73246 .23424 .74019 .24513 .75726 .23922 .7496 .22826 Mtetra
.7496 .22826 .75726 .23922 .77443 .23328 .76684 .22225 Mtetra
.664 .741 .908 r
.76684 .22225 .77443 .23328 .7917 .22731 .78419 .21621 Mtetra
.78419 .21621 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21528 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63205 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .60399 .26499 .59516 Mtetra
.646 .763 .934 r
.26499 .59516 .27519 .60399 .29072 .5992 .28057 .59032 Mtetra
.28057 .59032 .29072 .5992 .30634 .59438 .29625 .58545 Mtetra
.647 .763 .934 r
.29625 .58545 .30634 .59438 .32206 .58951 .31202 .58054 Mtetra
.31202 .58054 .32206 .58951 .33787 .58457 .32789 .57557 Mtetra
.649 .764 .933 r
.32789 .57557 .33787 .58457 .35377 .57954 .34385 .57052 Mtetra
.651 .766 .933 r
.34385 .57052 .35377 .57954 .36978 .57433 .35992 .56534 Mtetra
.656 .769 .932 r
.35992 .56534 .36978 .57433 .3859 .56885 .37609 .55995 Mtetra
.666 .775 .931 r
.37609 .55995 .3859 .56885 .40212 .56284 .39236 .55417 Mtetra
.682 .786 .928 r
.39236 .55417 .40212 .56284 .41846 .55591 .40876 .54769 Mtetra
.711 .804 .923 r
.40876 .54769 .41846 .55591 .43492 .54728 .42527 .53995 Mtetra
.758 .833 .909 r
.42527 .53995 .43492 .54728 .45151 .53569 .44192 .52995 Mtetra
.825 .871 .88 r
.44192 .52995 .45151 .53569 .46823 .5192 .45869 .51609 Mtetra
.898 .907 .822 r
.45869 .51609 .46823 .5192 .48501 .49548 .47557 .49613 Mtetra
.953 .925 .739 r
.47557 .49613 .48501 .49548 .50178 .46316 .49248 .46799 Mtetra
.975 .923 .653 r
.49248 .46799 .50178 .46316 .51838 .42404 .50931 .4316 Mtetra
.975 .918 .601 r
.50931 .4316 .51838 .42404 .53474 .38379 .52592 .39085 Mtetra
.97 .924 .606 r
.52592 .39085 .53474 .38379 .55088 .34883 .54228 .35242 Mtetra
.962 .943 .676 r
.54228 .35242 .55088 .34883 .56693 .32221 .55847 .32137 Mtetra
.931 .944 .78 r
.55847 .32137 .56693 .32221 .583 .3033 .57463 .29871 Mtetra
.865 .906 .859 r
.57463 .29871 .583 .3033 .59916 .2899 .59085 .28274 Mtetra
.792 .851 .895 r
.59085 .28274 .59916 .2899 .61543 .2799 .60717 .27117 Mtetra
.737 .806 .906 r
.60717 .27117 .61543 .2799 .63182 .27184 .62362 .2622 Mtetra
.704 .777 .909 r
.62362 .2622 .63182 .27184 .64832 .26484 .64018 .25467 Mtetra
.685 .761 .909 r
.64018 .25467 .64832 .26484 .66494 .2584 .65686 .24792 Mtetra
.675 .752 .909 r
.65686 .24792 .66494 .2584 .68166 .25223 .67364 .24155 Mtetra
.67 .747 .908 r
.67364 .24155 .68166 .25223 .69849 .2462 .69054 .23538 Mtetra
.667 .744 .908 r
.69054 .23538 .69849 .2462 .71542 .24021 .70754 .22929 Mtetra
.665 .743 .908 r
.70754 .22929 .71542 .24021 .73246 .23424 .72464 .22324 Mtetra
.664 .742 .908 r
.72464 .22324 .73246 .23424 .7496 .22826 .74186 .21718 Mtetra
.74186 .21718 .7496 .22826 .76684 .22225 .75917 .2111 Mtetra
.75917 .2111 .76684 .22225 .78419 .21621 .77659 .20499 Mtetra
.664 .741 .908 r
.77659 .20499 .78419 .21621 .80164 .21014 .79412 .19885 Mtetra
.79412 .19885 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .5959 Mtetra
.22368 .5959 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59516 .25468 .58623 Mtetra
.25468 .58623 .26499 .59516 .28057 .59032 .27032 .58134 Mtetra
.646 .763 .934 r
.27032 .58134 .28057 .59032 .29625 .58545 .28605 .57642 Mtetra
.28605 .57642 .29625 .58545 .31202 .58054 .30188 .57147 Mtetra
.647 .763 .934 r
.30188 .57147 .31202 .58054 .32789 .57557 .3178 .56646 Mtetra
.648 .764 .933 r
.3178 .56646 .32789 .57557 .34385 .57052 .33382 .56138 Mtetra
.65 .765 .933 r
.33382 .56138 .34385 .57052 .35992 .56534 .34995 .5562 Mtetra
.654 .767 .933 r
.34995 .5562 .35992 .56534 .37609 .55995 .36617 .55086 Mtetra
.66 .772 .932 r
.36617 .55086 .37609 .55995 .39236 .55417 .38251 .54522 Mtetra
.673 .78 .93 r
.38251 .54522 .39236 .55417 .40876 .54769 .39895 .53907 Mtetra
.695 .794 .926 r
.39895 .53907 .40876 .54769 .42527 .53995 .41552 .53198 Mtetra
.732 .817 .917 r
.41552 .53198 .42527 .53995 .44192 .52995 .43221 .52318 Mtetra
.789 .851 .897 r
.43221 .52318 .44192 .52995 .45869 .51609 .44904 .51139 Mtetra
.862 .891 .855 r
.44904 .51139 .45869 .51609 .47557 .49613 .466 .49467 Mtetra
.929 .919 .783 r
.466 .49467 .47557 .49613 .49248 .46799 .48303 .47067 Mtetra
.968 .926 .694 r
.48303 .47067 .49248 .46799 .50931 .4316 .50004 .43802 Mtetra
.977 .92 .621 r
.50004 .43802 .50931 .4316 .52592 .39085 .5169 .39853 Mtetra
.972 .919 .595 r
.5169 .39853 .52592 .39085 .54228 .35242 .5335 .35792 Mtetra
.967 .933 .634 r
.5335 .35792 .54228 .35242 .55847 .32137 .54988 .32263 Mtetra
.951 .948 .727 r
.54988 .32263 .55847 .32137 .57463 .29871 .56616 .29573 Mtetra
.901 .929 .825 r
.56616 .29573 .57463 .29871 .59085 .28274 .58245 .2766 Mtetra
.827 .878 .882 r
.58245 .2766 .59085 .28274 .60717 .27117 .59883 .26299 Mtetra
.762 .826 .903 r
.59883 .26299 .60717 .27117 .62362 .2622 .61533 .25281 Mtetra
.719 .79 .908 r
.61533 .25281 .62362 .2622 .64018 .25467 .63195 .24459 Mtetra
.693 .768 .909 r
.63195 .24459 .64018 .25467 .65686 .24792 .64868 .23742 Mtetra
.679 .756 .909 r
.64868 .23742 .65686 .24792 .67364 .24155 .66554 .23081 Mtetra
.672 .749 .908 r
.66554 .23081 .67364 .24155 .69054 .23538 .6825 .22447 Mtetra
.668 .745 .908 r
.6825 .22447 .69054 .23538 .70754 .22929 .69957 .21827 Mtetra
.666 .743 .908 r
.69957 .21827 .70754 .22929 .72464 .22324 .71674 .21212 Mtetra
.665 .742 .908 r
.71674 .21212 .72464 .22324 .74186 .21718 .73403 .20597 Mtetra
.664 .742 .908 r
.73403 .20597 .74186 .21718 .75917 .2111 .75141 .19982 Mtetra
.75141 .19982 .75917 .2111 .77659 .20499 .76891 .19364 Mtetra
.664 .741 .908 r
.76891 .19364 .77659 .20499 .79412 .19885 .78651 .18743 Mtetra
.78651 .18743 .79412 .19885 .81176 .19267 .80423 .18118 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .5959 .21314 .58698 Mtetra
.21314 .58698 .22368 .5959 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58623 .24425 .5772 Mtetra
.24425 .5772 .25468 .58623 .27032 .58134 .25995 .57226 Mtetra
.646 .763 .934 r
.25995 .57226 .27032 .58134 .28605 .57642 .27573 .56729 Mtetra
.27573 .56729 .28605 .57642 .30188 .57147 .29162 .56228 Mtetra
.647 .763 .934 r
.29162 .56228 .30188 .57147 .3178 .56646 .3076 .55723 Mtetra
.3076 .55723 .3178 .56646 .33382 .56138 .32368 .55212 Mtetra
.649 .764 .933 r
.32368 .55212 .33382 .56138 .34995 .5562 .33986 .54693 Mtetra
.651 .766 .933 r
.33986 .54693 .34995 .5562 .36617 .55086 .35615 .5416 Mtetra
.656 .769 .932 r
.35615 .5416 .36617 .55086 .38251 .54522 .37254 .53606 Mtetra
.666 .775 .931 r
.37254 .53606 .38251 .54522 .39895 .53907 .38904 .53013 Mtetra
.682 .786 .928 r
.38904 .53013 .39895 .53907 .41552 .53198 .40566 .52349 Mtetra
.711 .804 .923 r
.40566 .52349 .41552 .53198 .43221 .52318 .42241 .51559 Mtetra
.758 .833 .909 r
.42241 .51559 .43221 .52318 .44904 .51139 .43929 .5054 Mtetra
.825 .871 .88 r
.43929 .5054 .44904 .51139 .466 .49467 .4563 .49132 Mtetra
.898 .908 .822 r
.4563 .49132 .466 .49467 .48303 .47067 .47343 .47111 Mtetra
.953 .925 .738 r
.47343 .47111 .48303 .47067 .50004 .43802 .4906 .44266 Mtetra
.975 .923 .653 r
.4906 .44266 .50004 .43802 .5169 .39853 .50768 .40591 Mtetra
.975 .918 .601 r
.50768 .40591 .5169 .39853 .5335 .35792 .52454 .36479 Mtetra
.97 .924 .606 r
.52454 .36479 .5335 .35792 .54988 .32263 .54114 .32601 Mtetra
.962 .943 .676 r
.54114 .32601 .54988 .32263 .56616 .29573 .55757 .29465 Mtetra
.931 .944 .78 r
.55757 .29465 .56616 .29573 .58245 .2766 .57396 .27175 Mtetra
.865 .906 .859 r
.57396 .27175 .58245 .2766 .59883 .26299 .5904 .25556 Mtetra
.792 .851 .895 r
.5904 .25556 .59883 .26299 .61533 .25281 .60696 .2438 Mtetra
.737 .806 .906 r
.60696 .2438 .61533 .25281 .63195 .24459 .62363 .23465 Mtetra
.704 .777 .909 r
.62363 .23465 .63195 .24459 .64868 .23742 .64043 .22695 Mtetra
.685 .761 .909 r
.64043 .22695 .64868 .23742 .66554 .23081 .65734 .22002 Mtetra
.675 .752 .909 r
.65734 .22002 .66554 .23081 .6825 .22447 .67437 .21348 Mtetra
.67 .747 .908 r
.67437 .21348 .6825 .22447 .69957 .21827 .69151 .20714 Mtetra
.667 .744 .908 r
.69151 .20714 .69957 .21827 .71674 .21212 .70875 .20088 Mtetra
.665 .743 .908 r
.70875 .20088 .71674 .21212 .73403 .20597 .72611 .19465 Mtetra
.664 .742 .908 r
.72611 .19465 .73403 .20597 .75141 .19982 .74357 .18842 Mtetra
.74357 .18842 .75141 .19982 .76891 .19364 .76114 .18216 Mtetra
.76114 .18216 .76891 .19364 .78651 .18743 .77882 .17588 Mtetra
.664 .741 .908 r
.77882 .17588 .78651 .18743 .80423 .18118 .79661 .16956 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .5772 .23371 .56807 Mtetra
.23371 .56807 .24425 .5772 .25995 .57226 .24946 .56308 Mtetra
.24946 .56308 .25995 .57226 .27573 .56729 .2653 .55806 Mtetra
.646 .763 .934 r
.2653 .55806 .27573 .56729 .29162 .56228 .28125 .553 Mtetra
.28125 .553 .29162 .56228 .3076 .55723 .29729 .54789 Mtetra
.647 .763 .934 r
.29729 .54789 .3076 .55723 .32368 .55212 .31342 .54274 Mtetra
.648 .764 .933 r
.31342 .54274 .32368 .55212 .33986 .54693 .32966 .53752 Mtetra
.65 .765 .933 r
.32966 .53752 .33986 .54693 .35615 .5416 .34601 .5322 Mtetra
.654 .767 .933 r
.34601 .5322 .35615 .5416 .37254 .53606 .36246 .5267 Mtetra
.66 .772 .932 r
.36246 .5267 .37254 .53606 .38904 .53013 .37902 .52091 Mtetra
.673 .78 .93 r
.37902 .52091 .38904 .53013 .40566 .52349 .39569 .5146 Mtetra
.695 .794 .926 r
.39569 .5146 .40566 .52349 .42241 .51559 .41249 .50734 Mtetra
.732 .817 .917 r
.41249 .50734 .42241 .51559 .43929 .5054 .42943 .49837 Mtetra
.789 .852 .897 r
.42943 .49837 .43929 .5054 .4563 .49132 .4465 .48638 Mtetra
.862 .891 .855 r
.4465 .48638 .4563 .49132 .47343 .47111 .4637 .46942 Mtetra
.929 .92 .783 r
.4637 .46942 .47343 .47111 .4906 .44266 .48099 .44514 Mtetra
.968 .926 .694 r
.48099 .44514 .4906 .44266 .50768 .40591 .49826 .41215 Mtetra
.977 .92 .621 r
.49826 .41215 .50768 .40591 .52454 .36479 .51537 .37228 Mtetra
.972 .919 .595 r
.51537 .37228 .52454 .36479 .54114 .32601 .53223 .3313 Mtetra
.967 .933 .634 r
.53223 .3313 .54114 .32601 .55757 .29465 .54885 .29568 Mtetra
.951 .947 .728 r
.54885 .29568 .55757 .29465 .57396 .27175 .56536 .26851 Mtetra
.901 .929 .825 r
.56536 .26851 .57396 .27175 .5904 .25556 .58188 .24914 Mtetra
.827 .878 .881 r
.58188 .24914 .5904 .25556 .60696 .2438 .5985 .23533 Mtetra
.762 .826 .902 r
.5985 .23533 .60696 .2438 .62363 .23465 .61523 .22496 Mtetra
.719 .79 .908 r
.61523 .22496 .62363 .23465 .64043 .22695 .63208 .21655 Mtetra
.693 .768 .909 r
.63208 .21655 .64043 .22695 .65734 .22002 .64906 .20921 Mtetra
.679 .756 .909 r
.64906 .20921 .65734 .22002 .67437 .21348 .66615 .20243 Mtetra
.672 .749 .908 r
.66615 .20243 .67437 .21348 .69151 .20714 .68336 .19592 Mtetra
.668 .745 .908 r
.68336 .19592 .69151 .20714 .70875 .20088 .70067 .18954 Mtetra
.666 .743 .908 r
.70067 .18954 .70875 .20088 .72611 .19465 .7181 .18321 Mtetra
.665 .742 .908 r
.7181 .18321 .72611 .19465 .74357 .18842 .73564 .17689 Mtetra
.664 .742 .908 r
.73564 .17689 .74357 .18842 .76114 .18216 .75328 .17056 Mtetra
.75328 .17056 .76114 .18216 .77882 .17588 .77104 .1642 Mtetra
.664 .741 .908 r
.77104 .1642 .77882 .17588 .79661 .16956 .78891 .1578 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56807 .22305 .55884 Mtetra
.22305 .55884 .23371 .56807 .24946 .56308 .23885 .55379 Mtetra
.23885 .55379 .24946 .56308 .2653 .55806 .25476 .54872 Mtetra
.646 .763 .934 r
.25476 .54872 .2653 .55806 .28125 .553 .27076 .5436 Mtetra
.27076 .5436 .28125 .553 .29729 .54789 .28685 .53845 Mtetra
.647 .763 .934 r
.28685 .53845 .29729 .54789 .31342 .54274 .30305 .53325 Mtetra
.30305 .53325 .31342 .54274 .32966 .53752 .31935 .52799 Mtetra
.649 .764 .933 r
.31935 .52799 .32966 .53752 .34601 .5322 .33575 .52265 Mtetra
.651 .766 .933 r
.33575 .52265 .34601 .5322 .36246 .5267 .35226 .51717 Mtetra
.656 .769 .932 r
.35226 .51717 .36246 .5267 .37902 .52091 .36888 .51147 Mtetra
.666 .775 .931 r
.36888 .51147 .37902 .52091 .39569 .5146 .38561 .50538 Mtetra
.682 .786 .929 r
.38561 .50538 .39569 .5146 .41249 .50734 .40247 .49858 Mtetra
.711 .804 .923 r
.40247 .49858 .41249 .50734 .42943 .49837 .41946 .4905 Mtetra
.758 .833 .909 r
.41946 .4905 .42943 .49837 .4465 .48638 .43658 .48013 Mtetra
.825 .871 .88 r
.43658 .48013 .4465 .48638 .4637 .46942 .45385 .46583 Mtetra
.898 .908 .822 r
.45385 .46583 .4637 .46942 .48099 .44514 .47123 .44536 Mtetra
.953 .926 .738 r
.47123 .44536 .48099 .44514 .49826 .41215 .48866 .41659 Mtetra
.975 .923 .653 r
.48866 .41659 .49826 .41215 .51537 .37228 .506 .37948 Mtetra
.975 .918 .601 r
.506 .37948 .51537 .37228 .53223 .3313 .52312 .33798 Mtetra
.97 .924 .606 r
.52312 .33798 .53223 .3313 .54885 .29568 .53997 .29884 Mtetra
.962 .942 .676 r
.53997 .29884 .54885 .29568 .56536 .26851 .55664 .26718 Mtetra
.931 .943 .78 r
.55664 .26718 .56536 .26851 .58188 .24914 .57326 .24401 Mtetra
.865 .905 .859 r
.57326 .24401 .58188 .24914 .5985 .23533 .58994 .22761 Mtetra
.792 .851 .895 r
.58994 .22761 .5985 .23533 .61523 .22496 .60673 .21565 Mtetra
.737 .806 .906 r
.60673 .21565 .61523 .22496 .63208 .21655 .62365 .20631 Mtetra
.704 .777 .909 r
.62365 .20631 .63208 .21655 .64906 .20921 .64068 .19843 Mtetra
.685 .761 .909 r
.64068 .19843 .64906 .20921 .66615 .20243 .65784 .19132 Mtetra
.675 .752 .909 r
.65784 .19132 .66615 .20243 .68336 .19592 .67511 .18461 Mtetra
.67 .747 .908 r
.67511 .18461 .68336 .19592 .70067 .18954 .6925 .17809 Mtetra
.667 .744 .908 r
.6925 .17809 .70067 .18954 .7181 .18321 .71 .17165 Mtetra
.665 .743 .908 r
.71 .17165 .7181 .18321 .73564 .17689 .72761 .16524 Mtetra
.664 .742 .908 r
.72761 .16524 .73564 .17689 .75328 .17056 .74534 .15882 Mtetra
.74534 .15882 .75328 .17056 .77104 .1642 .76317 .15238 Mtetra
.76317 .15238 .77104 .1642 .78891 .1578 .78111 .14591 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .55379 .22813 .5444 Mtetra
.22813 .5444 .23885 .55379 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27076 .5436 .26015 .5341 Mtetra
.646 .763 .934 r
.26015 .5341 .27076 .5436 .28685 .53845 .2763 .52889 Mtetra
.2763 .52889 .28685 .53845 .30305 .53325 .29256 .52364 Mtetra
.647 .763 .934 r
.29256 .52364 .30305 .53325 .31935 .52799 .30892 .51834 Mtetra
.648 .764 .933 r
.30892 .51834 .31935 .52799 .33575 .52265 .32538 .51296 Mtetra
.65 .765 .933 r
.32538 .51296 .33575 .52265 .35226 .51717 .34195 .50748 Mtetra
.654 .767 .933 r
.34195 .50748 .35226 .51717 .36888 .51147 .35863 .50183 Mtetra
.66 .772 .932 r
.35863 .50183 .36888 .51147 .38561 .50538 .37542 .49589 Mtetra
.673 .78 .93 r
.37542 .49589 .38561 .50538 .40247 .49858 .39234 .48941 Mtetra
.695 .794 .926 r
.39234 .48941 .40247 .49858 .41946 .4905 .40938 .48198 Mtetra
.732 .817 .917 r
.40938 .48198 .41946 .4905 .43658 .48013 .42656 .47282 Mtetra
.789 .852 .897 r
.42656 .47282 .43658 .48013 .45385 .46583 .44388 .46063 Mtetra
.862 .891 .855 r
.44388 .46063 .45385 .46583 .47123 .44536 .46134 .44342 Mtetra
.93 .92 .783 r
.46134 .44342 .47123 .44536 .48866 .41659 .47889 .41885 Mtetra
.968 .926 .693 r
.47889 .41885 .48866 .41659 .506 .37948 .49643 .38552 Mtetra
.977 .92 .621 r
.49643 .38552 .506 .37948 .52312 .33798 .51381 .34527 Mtetra
.972 .919 .595 r
.51381 .34527 .52312 .33798 .53997 .29884 .53091 .30391 Mtetra
.967 .933 .634 r
.53091 .30391 .53997 .29884 .55664 .26718 .54778 .26795 Mtetra
.951 .947 .728 r
.54778 .26795 .55664 .26718 .57326 .24401 .56453 .2405 Mtetra
.901 .929 .825 r
.56453 .2405 .57326 .24401 .58994 .22761 .5813 .22089 Mtetra
.827 .878 .881 r
.5813 .22089 .58994 .22761 .60673 .21565 .59815 .20687 Mtetra
.762 .826 .902 r
.59815 .20687 .60673 .21565 .62365 .20631 .61512 .19631 Mtetra
.719 .79 .908 r
.61512 .19631 .62365 .20631 .64068 .19843 .63222 .18771 Mtetra
.693 .768 .909 r
.63222 .18771 .64068 .19843 .65784 .19132 .64944 .18019 Mtetra
.679 .756 .909 r
.64944 .18019 .65784 .19132 .67511 .18461 .66678 .17322 Mtetra
.672 .749 .908 r
.66678 .17322 .67511 .18461 .6925 .17809 .68424 .16653 Mtetra
.668 .745 .908 r
.68424 .16653 .6925 .17809 .71 .17165 .70181 .15997 Mtetra
.666 .743 .908 r
.70181 .15997 .71 .17165 .72761 .16524 .7195 .15346 Mtetra
.665 .742 .908 r
.7195 .15346 .72761 .16524 .74534 .15882 .7373 .14695 Mtetra
.664 .742 .908 r
.7373 .14695 .74534 .15882 .76317 .15238 .75521 .14043 Mtetra
.75521 .14043 .76317 .15238 .78111 .14591 .77323 .13388 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54006 Mtetra
.20137 .54006 .21227 .54951 .22813 .5444 .21728 .5349 Mtetra
.21728 .5349 .22813 .5444 .24409 .53927 .2333 .52971 Mtetra
.2333 .52971 .24409 .53927 .26015 .5341 .24942 .52448 Mtetra
.646 .763 .934 r
.24942 .52448 .26015 .5341 .2763 .52889 .26563 .51922 Mtetra
.26563 .51922 .2763 .52889 .29256 .52364 .28195 .51392 Mtetra
.647 .763 .934 r
.28195 .51392 .29256 .52364 .30892 .51834 .29837 .50856 Mtetra
.29837 .50856 .30892 .51834 .32538 .51296 .31489 .50315 Mtetra
.649 .764 .933 r
.31489 .50315 .32538 .51296 .34195 .50748 .33152 .49765 Mtetra
.651 .766 .933 r
.33152 .49765 .34195 .50748 .35863 .50183 .34826 .49202 Mtetra
.656 .769 .932 r
.34826 .49202 .35863 .50183 .37542 .49589 .36512 .48616 Mtetra
.665 .775 .931 r
.36512 .48616 .37542 .49589 .39234 .48941 .38209 .4799 Mtetra
.682 .786 .929 r
.38209 .4799 .39234 .48941 .40938 .48198 .39919 .47293 Mtetra
.711 .804 .923 r
.39919 .47293 .40938 .48198 .42656 .47282 .41642 .46467 Mtetra
.758 .833 .91 r
.41642 .46467 .42656 .47282 .44388 .46063 .4338 .4541 Mtetra
.825 .872 .88 r
.4338 .4541 .44388 .46063 .46134 .44342 .45132 .43957 Mtetra
.898 .908 .822 r
.45132 .43957 .46134 .44342 .47889 .41885 .46897 .41883 Mtetra
.953 .926 .738 r
.46897 .41883 .47889 .41885 .49643 .38552 .48667 .38974 Mtetra
.975 .923 .653 r
.48667 .38974 .49643 .38552 .51381 .34527 .50428 .35226 Mtetra
.975 .918 .601 r
.50428 .35226 .51381 .34527 .53091 .30391 .52166 .31037 Mtetra
.97 .924 .606 r
.52166 .31037 .53091 .30391 .54778 .26795 .53877 .27087 Mtetra
.963 .942 .677 r
.53877 .27087 .54778 .26795 .56453 .2405 .55568 .2389 Mtetra
.931 .943 .78 r
.55568 .2389 .56453 .2405 .5813 .22089 .57255 .21548 Mtetra
.865 .905 .859 r
.57255 .21548 .5813 .22089 .59815 .20687 .58947 .19884 Mtetra
.792 .85 .895 r
.58947 .19884 .59815 .20687 .61512 .19631 .6065 .18668 Mtetra
.737 .806 .906 r
.6065 .18668 .61512 .19631 .63222 .18771 .62366 .17715 Mtetra
.704 .777 .909 r
.62366 .17715 .63222 .18771 .64944 .18019 .64095 .16908 Mtetra
.685 .761 .909 r
.64095 .16908 .64944 .18019 .66678 .17322 .65835 .16178 Mtetra
.675 .752 .909 r
.65835 .16178 .66678 .17322 .68424 .16653 .67588 .15489 Mtetra
.67 .747 .908 r
.67588 .15489 .68424 .16653 .70181 .15997 .69353 .14818 Mtetra
.667 .744 .908 r
.69353 .14818 .70181 .15997 .7195 .15346 .71129 .14156 Mtetra
.665 .743 .908 r
.71129 .14156 .7195 .15346 .7373 .14695 .72916 .13496 Mtetra
.664 .742 .908 r
.72916 .13496 .7373 .14695 .75521 .14043 .74715 .12835 Mtetra
.74715 .12835 .75521 .14043 .77323 .13388 .76526 .12172 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54006 .19034 .53052 Mtetra
.19034 .53052 .20137 .54006 .21728 .5349 .20631 .5253 Mtetra
.20631 .5253 .21728 .5349 .2333 .52971 .22239 .52004 Mtetra
.22239 .52004 .2333 .52971 .24942 .52448 .23856 .51476 Mtetra
.23856 .51476 .24942 .52448 .26563 .51922 .25484 .50944 Mtetra
.646 .763 .934 r
.25484 .50944 .26563 .51922 .28195 .51392 .27122 .50407 Mtetra
.27122 .50407 .28195 .51392 .29837 .50856 .2877 .49867 Mtetra
.647 .763 .934 r
.2877 .49867 .29837 .50856 .31489 .50315 .30428 .49321 Mtetra
.648 .764 .933 r
.30428 .49321 .31489 .50315 .33152 .49765 .32098 .48768 Mtetra
.65 .765 .933 r
.32098 .48768 .33152 .49765 .34826 .49202 .33778 .48204 Mtetra
.654 .767 .933 r
.33778 .48204 .34826 .49202 .36512 .48616 .35469 .47622 Mtetra
.66 .772 .932 r
.35469 .47622 .36512 .48616 .38209 .4799 .37172 .47011 Mtetra
.673 .78 .93 r
.37172 .47011 .38209 .4799 .39919 .47293 .38888 .46347 Mtetra
.695 .794 .926 r
.38888 .46347 .39919 .47293 .41642 .46467 .40617 .45585 Mtetra
.732 .817 .918 r
.40617 .45585 .41642 .46467 .4338 .4541 .4236 .4465 Mtetra
.789 .852 .898 r
.4236 .4465 .4338 .4541 .45132 .43957 .44118 .43409 Mtetra
.862 .891 .855 r
.44118 .43409 .45132 .43957 .46897 .41883 .45891 .41664 Mtetra
.93 .92 .782 r
.45891 .41664 .46897 .41883 .48667 .38974 .47673 .39177 Mtetra
.968 .926 .693 r
.47673 .39177 .48667 .38974 .50428 .35226 .49454 .35808 Mtetra
.977 .92 .62 r
.49454 .35808 .50428 .35226 .52166 .31037 .51219 .31745 Mtetra
.972 .919 .595 r
.51219 .31745 .52166 .31037 .53877 .27087 .52956 .27571 Mtetra
.967 .933 .635 r
.52956 .27571 .53877 .27087 .55568 .2389 .54669 .23942 Mtetra
.952 .947 .728 r
.54669 .23942 .55568 .2389 .57255 .21548 .56369 .21168 Mtetra
.901 .928 .825 r
.56369 .21168 .57255 .21548 .58947 .19884 .5807 .19182 Mtetra
.827 .878 .881 r
.5807 .19182 .58947 .19884 .6065 .18668 .59779 .17758 Mtetra
.762 .826 .902 r
.59779 .17758 .6065 .18668 .62366 .17715 .61501 .16682 Mtetra
.719 .79 .908 r
.61501 .16682 .62366 .17715 .64095 .16908 .63236 .15803 Mtetra
.693 .768 .909 r
.63236 .15803 .64095 .16908 .65835 .16178 .64983 .15032 Mtetra
.679 .756 .909 r
.64983 .15032 .65835 .16178 .67588 .15489 .66743 .14316 Mtetra
.672 .749 .908 r
.66743 .14316 .67588 .15489 .69353 .14818 .68515 .13628 Mtetra
.668 .745 .908 r
.68515 .13628 .69353 .14818 .71129 .14156 .70298 .12953 Mtetra
.666 .743 .908 r
.70298 .12953 .71129 .14156 .72916 .13496 .72094 .12283 Mtetra
.665 .742 .908 r
.72094 .12283 .72916 .13496 .74715 .12835 .739 .11613 Mtetra
.664 .742 .908 r
.739 .11613 .74715 .12835 .76526 .12172 .75719 .10941 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52004 .21135 .51027 Mtetra
.21135 .51027 .22239 .52004 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50944 .24392 .49954 Mtetra
.646 .763 .934 r
.24392 .49954 .25484 .50944 .27122 .50407 .26036 .49412 Mtetra
.26036 .49412 .27122 .50407 .2877 .49867 .2769 .48865 Mtetra
.647 .763 .934 r
.2769 .48865 .2877 .49867 .30428 .49321 .29355 .48314 Mtetra
.29355 .48314 .30428 .49321 .32098 .48768 .3103 .47757 Mtetra
.649 .764 .933 r
.3103 .47757 .32098 .48768 .33778 .48204 .32717 .47191 Mtetra
.651 .766 .933 r
.32717 .47191 .33778 .48204 .35469 .47622 .34415 .46611 Mtetra
.656 .769 .932 r
.34415 .46611 .35469 .47622 .37172 .47011 .36124 .46008 Mtetra
.665 .775 .931 r
.36124 .46008 .37172 .47011 .38888 .46347 .37846 .45365 Mtetra
.682 .786 .929 r
.37846 .45365 .38888 .46347 .40617 .45585 .3958 .44651 Mtetra
.711 .804 .923 r
.3958 .44651 .40617 .45585 .4236 .4465 .41329 .43805 Mtetra
.758 .833 .91 r
.41329 .43805 .4236 .4465 .44118 .43409 .43093 .42727 Mtetra
.825 .872 .88 r
.43093 .42727 .44118 .43409 .45891 .41664 .44871 .41251 Mtetra
.898 .908 .822 r
.44871 .41251 .45891 .41664 .47673 .39177 .46663 .3915 Mtetra
.953 .926 .738 r
.46663 .3915 .47673 .39177 .49454 .35808 .48461 .36208 Mtetra
.975 .924 .652 r
.48461 .36208 .49454 .35808 .51219 .31745 .5025 .32422 Mtetra
.975 .918 .6 r
.5025 .32422 .51219 .31745 .52956 .27571 .52016 .28195 Mtetra
.97 .924 .607 r
.52016 .28195 .52956 .27571 .54669 .23942 .53753 .24208 Mtetra
.963 .942 .677 r
.53753 .24208 .54669 .23942 .56369 .21168 .5547 .20979 Mtetra
.931 .943 .78 r
.5547 .20979 .56369 .21168 .5807 .19182 .57182 .1861 Mtetra
.865 .905 .859 r
.57182 .1861 .5807 .19182 .59779 .17758 .58899 .16924 Mtetra
.792 .85 .895 r
.58899 .16924 .59779 .17758 .61501 .16682 .60627 .15686 Mtetra
.737 .806 .906 r
.60627 .15686 .61501 .16682 .63236 .15803 .62368 .14713 Mtetra
.704 .777 .909 r
.62368 .14713 .63236 .15803 .64983 .15032 .64122 .13886 Mtetra
.685 .761 .909 r
.64122 .13886 .64983 .15032 .66743 .14316 .65888 .13137 Mtetra
.675 .752 .909 r
.65888 .13137 .66743 .14316 .68515 .13628 .67667 .12428 Mtetra
.67 .747 .908 r
.67667 .12428 .68515 .13628 .70298 .12953 .69458 .11738 Mtetra
.667 .744 .908 r
.69458 .11738 .70298 .12953 .72094 .12283 .71261 .11056 Mtetra
.665 .743 .908 r
.71261 .11056 .72094 .12283 .739 .11613 .73076 .10377 Mtetra
.664 .742 .908 r
.73076 .10377 .739 .11613 .75719 .10941 .74902 .09696 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50037 Mtetra
.20018 .50037 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49954 .23287 .48952 Mtetra
.23287 .48952 .24392 .49954 .26036 .49412 .24937 .48404 Mtetra
.646 .763 .934 r
.24937 .48404 .26036 .49412 .2769 .48865 .26598 .47852 Mtetra
.26598 .47852 .2769 .48865 .29355 .48314 .28269 .47295 Mtetra
.647 .763 .934 r
.28269 .47295 .29355 .48314 .3103 .47757 .29951 .46733 Mtetra
.648 .764 .933 r
.29951 .46733 .3103 .47757 .32717 .47191 .31644 .46163 Mtetra
.65 .765 .933 r
.31644 .46163 .32717 .47191 .34415 .46611 .33348 .45582 Mtetra
.654 .767 .933 r
.33348 .45582 .34415 .46611 .36124 .46008 .35063 .44984 Mtetra
.66 .772 .932 r
.35063 .44984 .36124 .46008 .37846 .45365 .36791 .44355 Mtetra
.673 .78 .93 r
.36791 .44355 .37846 .45365 .3958 .44651 .38532 .43673 Mtetra
.695 .794 .926 r
.38532 .43673 .3958 .44651 .41329 .43805 .40286 .42893 Mtetra
.732 .817 .918 r
.40286 .42893 .41329 .43805 .43093 .42727 .42055 .41937 Mtetra
.789 .852 .898 r
.42055 .41937 .43093 .42727 .44871 .41251 .4384 .40674 Mtetra
.862 .892 .855 r
.4384 .40674 .44871 .41251 .46663 .3915 .4564 .38903 Mtetra
.93 .92 .782 r
.4564 .38903 .46663 .3915 .48461 .36208 .4745 .36386 Mtetra
.968 .927 .693 r
.4745 .36386 .48461 .36208 .5025 .32422 .4926 .32982 Mtetra
.977 .92 .62 r
.4926 .32982 .5025 .32422 .52016 .28195 .51053 .28879 Mtetra
.972 .919 .595 r
.51053 .28879 .52016 .28195 .53753 .24208 .52817 .24667 Mtetra
.968 .933 .635 r
.52817 .24667 .53753 .24208 .5547 .20979 .54556 .21003 Mtetra
.952 .947 .728 r
.54556 .21003 .5547 .20979 .57182 .1861 .56282 .182 Mtetra
.901 .928 .825 r
.56282 .182 .57182 .1861 .58899 .16924 .58008 .16189 Mtetra
.827 .877 .881 r
.58008 .16189 .58899 .16924 .60627 .15686 .59743 .14743 Mtetra
.762 .826 .902 r
.59743 .14743 .60627 .15686 .62368 .14713 .6149 .13646 Mtetra
.719 .79 .908 r
.6149 .13646 .62368 .14713 .64122 .13886 .6325 .12747 Mtetra
.693 .768 .909 r
.6325 .12747 .64122 .13886 .65888 .13137 .65024 .11955 Mtetra
.679 .756 .909 r
.65024 .11955 .65888 .13137 .67667 .12428 .6681 .1122 Mtetra
.672 .749 .908 r
.6681 .1122 .67667 .12428 .69458 .11738 .68609 .10512 Mtetra
.668 .745 .908 r
.68609 .10512 .69458 .11738 .71261 .11056 .70419 .09817 Mtetra
.666 .743 .908 r
.70419 .09817 .71261 .11056 .73076 .10377 .72242 .09127 Mtetra
.665 .742 .908 r
.72242 .09127 .73076 .10377 .74902 .09696 .74076 .08437 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50037 .18889 .49037 Mtetra
.18889 .49037 .20018 .50037 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48952 .2217 .47939 Mtetra
.2217 .47939 .23287 .48952 .24937 .48404 .23826 .47384 Mtetra
.646 .763 .934 r
.23826 .47384 .24937 .48404 .26598 .47852 .25492 .46826 Mtetra
.25492 .46826 .26598 .47852 .28269 .47295 .2717 .46263 Mtetra
.647 .763 .934 r
.2717 .46263 .28269 .47295 .29951 .46733 .28858 .45696 Mtetra
.28858 .45696 .29951 .46733 .31644 .46163 .30557 .45121 Mtetra
.649 .764 .933 r
.30557 .45121 .31644 .46163 .33348 .45582 .32268 .44538 Mtetra
.651 .766 .933 r
.32268 .44538 .33348 .45582 .35063 .44984 .3399 .43941 Mtetra
.656 .769 .932 r
.3399 .43941 .35063 .44984 .36791 .44355 .35724 .43321 Mtetra
.665 .775 .931 r
.35724 .43321 .36791 .44355 .38532 .43673 .37471 .4266 Mtetra
.682 .786 .929 r
.37471 .4266 .38532 .43673 .40286 .42893 .39231 .41926 Mtetra
.711 .804 .923 r
.39231 .41926 .40286 .42893 .42055 .41937 .41006 .41061 Mtetra
.758 .833 .91 r
.41006 .41061 .42055 .41937 .4384 .40674 .42797 .39962 Mtetra
.825 .872 .88 r
.42797 .39962 .4384 .40674 .4564 .38903 .44603 .38462 Mtetra
.898 .909 .822 r
.44603 .38462 .4564 .38903 .4745 .36386 .46423 .36332 Mtetra
.953 .926 .738 r
.46423 .36332 .4745 .36386 .4926 .32982 .48249 .33357 Mtetra
.975 .924 .652 r
.48249 .33357 .4926 .32982 .51053 .28879 .50067 .29533 Mtetra
.975 .918 .6 r
.50067 .29533 .51053 .28879 .52817 .24667 .51861 .25266 Mtetra
.97 .924 .607 r
.51861 .25266 .52817 .24667 .54556 .21003 .53625 .21243 Mtetra
.963 .942 .677 r
.53625 .21243 .54556 .21003 .56282 .182 .55369 .17982 Mtetra
.931 .943 .78 r
.55369 .17982 .56282 .182 .58008 .16189 .57106 .15585 Mtetra
.865 .905 .859 r
.57106 .15585 .58008 .16189 .59743 .14743 .58849 .13875 Mtetra
.792 .85 .895 r
.58849 .13875 .59743 .14743 .6149 .13646 .60603 .12615 Mtetra
.737 .806 .906 r
.60603 .12615 .6149 .13646 .6325 .12747 .62369 .11621 Mtetra
.704 .777 .909 r
.62369 .11621 .6325 .12747 .65024 .11955 .6415 .10774 Mtetra
.685 .761 .909 r
.6415 .10774 .65024 .11955 .6681 .1122 .65943 .10005 Mtetra
.675 .752 .909 r
.65943 .10005 .6681 .1122 .68609 .10512 .67749 .09276 Mtetra
.67 .747 .908 r
.67749 .09276 .68609 .10512 .70419 .09817 .69567 .08566 Mtetra
.667 .744 .908 r
.69567 .08566 .70419 .09817 .72242 .09127 .71398 .07863 Mtetra
.665 .743 .908 r
.71398 .07863 .72242 .09127 .74076 .08437 .7324 .07163 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47384 .22701 .46353 Mtetra
.22701 .46353 .23826 .47384 .25492 .46826 .24374 .45788 Mtetra
.646 .763 .934 r
.24374 .45788 .25492 .46826 .2717 .46263 .26058 .45219 Mtetra
.26058 .45219 .2717 .46263 .28858 .45696 .27752 .44645 Mtetra
.647 .763 .934 r
.27752 .44645 .28858 .45696 .30557 .45121 .29458 .44066 Mtetra
.648 .764 .933 r
.29458 .44066 .30557 .45121 .32268 .44538 .31176 .43479 Mtetra
.65 .765 .933 r
.31176 .43479 .32268 .44538 .3399 .43941 .32904 .4288 Mtetra
.654 .767 .933 r
.32904 .4288 .3399 .43941 .35724 .43321 .34645 .42264 Mtetra
.66 .772 .932 r
.34645 .42264 .35724 .43321 .37471 .4266 .36398 .41617 Mtetra
.673 .78 .93 r
.36398 .41617 .37471 .4266 .39231 .41926 .38165 .40916 Mtetra
.695 .794 .926 r
.38165 .40916 .39231 .41926 .41006 .41061 .39945 .40117 Mtetra
.732 .817 .918 r
.39945 .40117 .41006 .41061 .42797 .39962 .41741 .39141 Mtetra
.789 .852 .898 r
.41741 .39141 .42797 .39962 .44603 .38462 .43553 .37854 Mtetra
.862 .892 .855 r
.43553 .37854 .44603 .38462 .46423 .36332 .45381 .36057 Mtetra
.93 .921 .782 r
.45381 .36057 .46423 .36332 .48249 .33357 .4722 .33508 Mtetra
.968 .927 .693 r
.4722 .33508 .48249 .33357 .50067 .29533 .49059 .30068 Mtetra
.977 .92 .62 r
.49059 .30068 .50067 .29533 .51861 .25266 .50881 .25926 Mtetra
.972 .919 .595 r
.50881 .25926 .51861 .25266 .53625 .21243 .52674 .21675 Mtetra
.968 .933 .635 r
.52674 .21675 .53625 .21243 .55369 .17982 .5444 .17976 Mtetra
.952 .947 .729 r
.5444 .17976 .55369 .17982 .57106 .15585 .56192 .15143 Mtetra
.901 .928 .825 r
.56192 .15143 .57106 .15585 .58849 .13875 .57944 .13107 Mtetra
.827 .877 .881 r
.57944 .13107 .58849 .13875 .60603 .12615 .59705 .11637 Mtetra
.762 .826 .902 r
.59705 .11637 .60603 .12615 .62369 .11621 .61479 .10518 Mtetra
.719 .79 .908 r
.61479 .10518 .62369 .11621 .6415 .10774 .63265 .09598 Mtetra
.693 .768 .909 r
.63265 .09598 .6415 .10774 .65943 .10005 .65066 .08786 Mtetra
.679 .756 .909 r
.65066 .08786 .65943 .10005 .67749 .09276 .66879 .0803 Mtetra
.672 .749 .908 r
.66879 .0803 .67749 .09276 .69567 .08566 .68705 .07302 Mtetra
.668 .745 .908 r
.68705 .07302 .69567 .08566 .71398 .07863 .70544 .06586 Mtetra
.666 .743 .908 r
.70544 .06586 .71398 .07863 .7324 .07163 .72394 .05875 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45788 .23242 .44737 Mtetra
.646 .763 .934 r
.23242 .44737 .24374 .45788 .26058 .45219 .24932 .44162 Mtetra
.24932 .44162 .26058 .45219 .27752 .44645 .26634 .43582 Mtetra
.647 .763 .934 r
.26634 .43582 .27752 .44645 .29458 .44066 .28346 .42997 Mtetra
.28346 .42997 .29458 .44066 .31176 .43479 .3007 .42405 Mtetra
.649 .764 .933 r
.3007 .42405 .31176 .43479 .32904 .4288 .31805 .41804 Mtetra
.651 .766 .933 r
.31805 .41804 .32904 .4288 .34645 .42264 .33553 .41188 Mtetra
.656 .769 .932 r
.33553 .41188 .34645 .42264 .36398 .41617 .35313 .4055 Mtetra
.665 .775 .931 r
.35313 .4055 .36398 .41617 .38165 .40916 .37085 .3987 Mtetra
.682 .786 .929 r
.37085 .3987 .38165 .40916 .39945 .40117 .38872 .39117 Mtetra
.711 .804 .923 r
.38872 .39117 .39945 .40117 .41741 .39141 .40673 .38232 Mtetra
.758 .834 .91 r
.40673 .38232 .41741 .39141 .43553 .37854 .42491 .3711 Mtetra
.825 .872 .88 r
.42491 .3711 .43553 .37854 .45381 .36057 .44326 .35585 Mtetra
.899 .909 .822 r
.44326 .35585 .45381 .36057 .4722 .33508 .46175 .33426 Mtetra
.953 .926 .738 r
.46175 .33426 .4722 .33508 .49059 .30068 .4803 .30417 Mtetra
.975 .924 .652 r
.4803 .30417 .49059 .30068 .50881 .25926 .49878 .26554 Mtetra
.975 .918 .6 r
.49878 .26554 .50881 .25926 .52674 .21675 .51701 .22247 Mtetra
.97 .924 .607 r
.51701 .22247 .52674 .21675 .5444 .17976 .53493 .18187 Mtetra
.963 .942 .678 r
.53493 .18187 .5444 .17976 .56192 .15143 .55264 .14893 Mtetra
.931 .943 .78 r
.55264 .14893 .56192 .15143 .57944 .13107 .57028 .12469 Mtetra
.864 .904 .859 r
.57028 .12469 .57944 .13107 .59705 .11637 .58797 .10734 Mtetra
.792 .85 .895 r
.58797 .10734 .59705 .11637 .61479 .10518 .60578 .09451 Mtetra
.738 .806 .906 r
.60578 .09451 .61479 .10518 .63265 .09598 .62371 .08436 Mtetra
.704 .777 .909 r
.62371 .08436 .63265 .09598 .65066 .08786 .64178 .07567 Mtetra
.685 .761 .909 r
.64178 .07567 .65066 .08786 .66879 .0803 .65999 .06777 Mtetra
.675 .752 .909 r
.65999 .06777 .66879 .0803 .68705 .07302 .67833 .06027 Mtetra
.67 .747 .908 r
.67833 .06027 .68705 .07302 .70544 .06586 .69679 .05295 Mtetra
.667 .744 .908 r
.69679 .05295 .70544 .06586 .72394 .05875 .71538 .04572 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45396 Mtetra
.17073 .45396 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44737 .22097 .43674 Mtetra
.22097 .43674 .23242 .44737 .24932 .44162 .23794 .43092 Mtetra
.646 .763 .934 r
.23794 .43092 .24932 .44162 .26634 .43582 .25501 .42505 Mtetra
.25501 .42505 .26634 .43582 .28346 .42997 .2722 .41914 Mtetra
.647 .763 .934 r
.2722 .41914 .28346 .42997 .3007 .42405 .28951 .41316 Mtetra
.648 .764 .933 r
.28951 .41316 .3007 .42405 .31805 .41804 .30693 .40711 Mtetra
.65 .765 .933 r
.30693 .40711 .31805 .41804 .33553 .41188 .32447 .40094 Mtetra
.653 .767 .933 r
.32447 .40094 .33553 .41188 .35313 .4055 .34214 .3946 Mtetra
.66 .772 .932 r
.34214 .3946 .35313 .4055 .37085 .3987 .35993 .38794 Mtetra
.673 .78 .93 r
.35993 .38794 .37085 .3987 .38872 .39117 .37786 .38073 Mtetra
.695 .794 .926 r
.37786 .38073 .38872 .39117 .40673 .38232 .39593 .37253 Mtetra
.732 .818 .918 r
.39593 .37253 .40673 .38232 .42491 .3711 .41417 .36255 Mtetra
.789 .852 .898 r
.41417 .36255 .42491 .3711 .44326 .35585 .43257 .34945 Mtetra
.862 .892 .855 r
.43257 .34945 .44326 .35585 .46175 .33426 .45114 .33121 Mtetra
.93 .921 .782 r
.45114 .33121 .46175 .33426 .4803 .30417 .46983 .3054 Mtetra
.968 .927 .692 r
.46983 .3054 .4803 .30417 .49878 .26554 .48852 .27063 Mtetra
.977 .92 .62 r
.48852 .27063 .49878 .26554 .51701 .22247 .50704 .2288 Mtetra
.972 .919 .596 r
.50704 .2288 .51701 .22247 .53493 .18187 .52526 .1859 Mtetra
.968 .933 .635 r
.52526 .1859 .53493 .18187 .55264 .14893 .5432 .14857 Mtetra
.952 .947 .729 r
.5432 .14857 .55264 .14893 .57028 .12469 .561 .11993 Mtetra
.901 .928 .825 r
.561 .11993 .57028 .12469 .58797 .10734 .57879 .0993 Mtetra
.827 .877 .881 r
.57879 .0993 .58797 .10734 .60578 .09451 .59666 .08437 Mtetra
.762 .826 .902 r
.59666 .08437 .60578 .09451 .62371 .08436 .61467 .07295 Mtetra
.719 .79 .908 r
.61467 .07295 .62371 .08436 .64178 .07567 .63281 .06354 Mtetra
.693 .768 .909 r
.63281 .06354 .64178 .07567 .65999 .06777 .65109 .0552 Mtetra
.679 .756 .909 r
.65109 .0552 .65999 .06777 .67833 .06027 .6695 .04742 Mtetra
.672 .749 .908 r
.6695 .04742 .67833 .06027 .69679 .05295 .68805 .03992 Mtetra
.668 .745 .908 r
.68805 .03992 .69679 .05295 .71538 .04572 .70672 .03255 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45396 .15895 .44341 Mtetra
.15895 .44341 .17073 .45396 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43182 Mtetra
.19246 .43182 .20411 .44252 .22097 .43674 .20938 .42597 Mtetra
.20938 .42597 .22097 .43674 .23794 .43092 .22641 .42008 Mtetra
.646 .763 .934 r
.22641 .42008 .23794 .43092 .25501 .42505 .24355 .41415 Mtetra
.24355 .41415 .25501 .42505 .2722 .41914 .26081 .40817 Mtetra
.647 .763 .934 r
.26081 .40817 .2722 .41914 .28951 .41316 .27818 .40214 Mtetra
.27818 .40214 .28951 .41316 .30693 .40711 .29567 .39603 Mtetra
.649 .764 .933 r
.29567 .39603 .30693 .40711 .32447 .40094 .31328 .38983 Mtetra
.651 .766 .933 r
.31328 .38983 .32447 .40094 .34214 .3946 .33101 .38349 Mtetra
.656 .769 .932 r
.33101 .38349 .34214 .3946 .35993 .38794 .34888 .37691 Mtetra
.665 .775 .931 r
.34888 .37691 .35993 .38794 .37786 .38073 .36687 .36992 Mtetra
.682 .786 .929 r
.36687 .36992 .37786 .38073 .39593 .37253 .38501 .36219 Mtetra
.711 .804 .923 r
.38501 .36219 .39593 .37253 .41417 .36255 .4033 .35312 Mtetra
.758 .834 .91 r
.4033 .35312 .41417 .36255 .43257 .34945 .42176 .34167 Mtetra
.825 .872 .88 r
.42176 .34167 .43257 .34945 .45114 .33121 .4404 .32616 Mtetra
.899 .909 .822 r
.4404 .32616 .45114 .33121 .46983 .3054 .45919 .30427 Mtetra
.953 .927 .737 r
.45919 .30427 .46983 .3054 .48852 .27063 .47805 .27383 Mtetra
.975 .924 .652 r
.47805 .27383 .48852 .27063 .50704 .2288 .49683 .23482 Mtetra
.975 .918 .6 r
.49683 .23482 .50704 .2288 .52526 .1859 .51536 .19134 Mtetra
.97 .924 .607 r
.51536 .19134 .52526 .1859 .5432 .14857 .53358 .15036 Mtetra
.963 .942 .678 r
.53358 .15036 .5432 .14857 .561 .11993 .55157 .1171 Mtetra
.931 .942 .78 r
.55157 .1171 .561 .11993 .57879 .0993 .56948 .09257 Mtetra
.864 .904 .859 r
.56948 .09257 .57879 .0993 .59666 .08437 .58744 .07497 Mtetra
.792 .85 .895 r
.58744 .07497 .59666 .08437 .61467 .07295 .60552 .0619 Mtetra
.738 .806 .906 r
.60552 .0619 .61467 .07295 .63281 .06354 .62373 .05152 Mtetra
.704 .777 .909 r
.62373 .05152 .63281 .06354 .65109 .0552 .64208 .04262 Mtetra
.685 .761 .909 r
.64208 .04262 .65109 .0552 .6695 .04742 .66057 .0345 Mtetra
.675 .752 .909 r
.66057 .0345 .6695 .04742 .68805 .03992 .67919 .02677 Mtetra
.67 .747 .908 r
.67919 .02677 .68805 .03992 .70672 .03255 .69795 .01923 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43182 .18066 .421 Mtetra
.18066 .421 .19246 .43182 .20938 .42597 .19765 .41508 Mtetra
.19765 .41508 .20938 .42597 .22641 .42008 .21474 .40912 Mtetra
.21474 .40912 .22641 .42008 .24355 .41415 .23195 .40311 Mtetra
.646 .763 .934 r
.23195 .40311 .24355 .41415 .26081 .40817 .24928 .39707 Mtetra
.24928 .39707 .26081 .40817 .27818 .40214 .26672 .39097 Mtetra
.647 .763 .934 r
.26672 .39097 .27818 .40214 .29567 .39603 .28428 .3848 Mtetra
.648 .764 .933 r
.28428 .3848 .29567 .39603 .31328 .38983 .30195 .37856 Mtetra
.65 .765 .933 r
.30195 .37856 .31328 .38983 .33101 .38349 .31976 .3722 Mtetra
.653 .767 .933 r
.31976 .3722 .33101 .38349 .34888 .37691 .33769 .36566 Mtetra
.66 .772 .932 r
.33769 .36566 .34888 .37691 .36687 .36992 .35575 .3588 Mtetra
.673 .78 .93 r
.35575 .3588 .36687 .36992 .38501 .36219 .37395 .35139 Mtetra
.695 .794 .926 r
.37395 .35139 .38501 .36219 .4033 .35312 .3923 .34298 Mtetra
.732 .818 .918 r
.3923 .34298 .4033 .35312 .42176 .34167 .41082 .33277 Mtetra
.789 .852 .898 r
.41082 .33277 .42176 .34167 .4404 .32616 .42952 .31943 Mtetra
.862 .892 .855 r
.42952 .31943 .4404 .32616 .45919 .30427 .44839 .3009 Mtetra
.93 .921 .782 r
.44839 .3009 .45919 .30427 .47805 .27383 .46738 .27477 Mtetra
.968 .927 .692 r
.46738 .27477 .47805 .27383 .49683 .23482 .48639 .23962 Mtetra
.977 .92 .62 r
.48639 .23962 .49683 .23482 .51536 .19134 .50522 .19739 Mtetra
.972 .919 .596 r
.50522 .19739 .51536 .19134 .53358 .15036 .52374 .15409 Mtetra
.968 .933 .636 r
.52374 .15409 .53358 .15036 .55157 .1171 .54197 .1164 Mtetra
.952 .947 .729 r
.54197 .1164 .55157 .1171 .56948 .09257 .56004 .08746 Mtetra
.901 .927 .825 r
.56004 .08746 .56948 .09257 .58744 .07497 .57811 .06656 Mtetra
.827 .877 .881 r
.57811 .06656 .58744 .07497 .60552 .0619 .59626 .05138 Mtetra
.762 .826 .902 r
.59626 .05138 .60552 .0619 .62373 .05152 .61454 .03973 Mtetra
.719 .79 .908 r
.61454 .03973 .62373 .05152 .64208 .04262 .63297 .03008 Mtetra
.693 .768 .909 r
.63297 .03008 .64208 .04262 .66057 .0345 .65153 .02152 Mtetra
.679 .756 .909 r
.65153 .02152 .66057 .0345 .67919 .02677 .67024 .01352 Mtetra
.672 .749 .908 r
.67024 .01352 .67919 .02677 .69795 .01923 .68907 .00579 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooeKlD]`0
07oo0000Egoo003EOol30003Ool02EKlD_aFo5;lE_`005KlOol0001FOol00=9oo`<000Aoo`0;D_aG
75;lE_aBg5KlD_`005;LOol0001FOol00=1oo`8000=oo`03E_aBo5Kl009Fo00;D_aFo5;lE_aBo5Kl
001Fo5;lOol0001EOol00<eoo`<000Aoo`0BFaaFo5KlD_aG75;lE_aBo5LLD_aFo5;L001Bo5KlD]ao
o`00E7oo003;Ool20005Ool015KlEaaFo5LL0UKl00ABo5KlE_aFo0=Bo007E_`005;lD_aFo7oo0000
E7oo0038Ool300000goo001oo`02Ool05eLLE_aK75KlEaaFo5/LD_aFo5;lEaaBo5KlD_aFo5;lE_`0
05KlD_aFo7oo0000Dgoo001WOol20002Ool2001IOol20004Ool00`00OomK7002Fa`03ELLE_aG75Kl
EaaFo5LLD_aFo5;lE_aBo5Kl00=Bo007001Bo5;lD_aFo7oo0000DWoo001XOol01000Oomoo`00Egoo
0`001Goo01eK75/lFaaK?5/LFcaK75LLE_aK75KlEaaBo5LLD_aFo5;lE_aBo5KlD_aFo000E_aBg5Kl
D]aoo`00059oo`00JGoo0P00EWoo0P001goo00=O?6=LFa`01U/L1eKl00YBo5KlD_aFo5;lE_aBo000
D_aFo0=Bo003Ool007oo051oo`00JGoo0P00Dgoo0`0027oo01iO>f=LGc]K?5/LFcaK75/lE_aK75Kl
EaaBo5LLE_aG75;lE_aBo5KlD]aFo5;lE_`005KlD]aFo5;LE_`2Ool00`00Oomoo`1>Ool006Qoo`04
001oogoo001@Ool20009Ool2Gc`016=LGcaO?5ll0e/L00AG75/LEaaK70IFo008D_aFo5;lE_aBo5Kl
D_`000IBo003Ool007oo04moo`00Igoo0P000Woo0P00C7oo0`002Woo02ESG5lkHeaO>f=LGc]SG5Kl
FaaFo5/LE_aK75KlFaaFo5LLD_aG75;lE_aBg5KlD_aFo5;LE_`005KlD]aFo5;LE_aBg5KlOol0001?
Ool00;Ioo`<0009oo`03001oogoo00Moo`9WN`0>HeaO?5llGcaSG5/lGcaG75/LEaaK75LLFaaG70=F
o00:D_aFo5KlE_aBo5KlD_aFo5;l0007D_`2001?Ool00;Aoo`8000eoo`0YIg][NfMkJgaO>f=LGc]O
?5/LGcaK6ellE_aK75KlFaaFo5LLE_aG75;lE_aBo5LLD_aFo5;LE_aBo5Kl001Fo5;lE_aBg5KlD]aF
o5;LOol0001>Ool00;5oo`<000ioo`=WN`0AJg]WNfMkFcaO?5/lGcaK?5llFcaO?5KlEaaFo5LLE_aG
7004E_`015;lE_aBo5Kl0e;l00<005;lD_`01e;l00=oo`00Ool0C7oo002_Ool2000?Ool05f]lIg][
NfMkJgaWNf]kHe]WO5/LGcaK6ellFaaO?5/LFcaFo5LLE_aK75KlEa`00UKl01ABo5KlD_aFo5;lE_aB
g5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aoo`004Goo1@00=goo002/Ool3000@Ool01W>jLiUWNfMkJg]W
N`=SG005He]SG5/lGcaK?005Fa`015KlEaaFo5LL15Kl00YBo5KlD_aFo5;lE_aBo000D_aFo0QBo003
Ool007oo00moo`05001oogooOol0000gOol00:Yoo`80019oo`0CLkY_VG>jKiUc^V=KIeaSFfMlHe]W
G6=KIgaK75/lFaaK?5/LFc`00U/L01aFo5LLD_aG75KlEaaBo5KlD_aFo5;lE_aBg5Kl001Fo5;LE_aB
g5KlD]aFo5;LE_aBg5KlOol0011oo`03001oogoo03Qoo`00Ygoo0`000Woo00<007ooOol03goo00Ic
VG>iLkUc^V^JKiX2He`016=KHeaSG6=L0Ull1e/L1eKl00QBo5KlD_aFo5;lE_aBo0000e;l00=Fo5;l
D_`01U;l00<007ooOol01Goo1P0017oo00<007ooOol0=goo002UOol2000FOol076nILkY_VG>jJiY_
Vf]jKi]SFfMLHe]SG5lkHeaO>e/lFaaK?5/LFcaFo5/LE_aG75KlEaaBo5LL0UKl01EBg5KlD_aFo5;L
E_`005KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg7oo00004Goo00<007ooOol0=Woo002ROol3000GOol0
1G>ILkUc^G>jJiX00VnJ00E_Vf^JKiYO?6=L00=O?009HeaO?5/LEaaK75LLFaaG75/L00AFo00:D_aF
o5KlE_aBo5KlD_aFo5;l000=D_`00goo001oo`0@Ool00`00Oomoo`0eOol007Eoo`@002Moo`8001Uo
o`0fKiUc^VnILkY[VVnKJgY_Vf^JKi]WNf]lGc]SG5lkHeaO>ellFa]K75KlFaaFo5/LE_aK75;lEaaB
o5KlD_aG75;lE_aBg5KlD_aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg0003Goo00D007oo
Oomoo`0003Moo`00M7oo00<007ooOol00Woo00<007ooOol08Goo0`006Woo0gNf00Yk]V^JKiY_VVnK
JiY_VVMkJg]WN`9O?009HeaK?5llFcaO?5/lFaaG75/L009G7003E_aG75;l00=Fo004D_aFo5KlE_`3
D_`00`00D_aBo006D_`025;LD_aBo5;lD]aBo7oo000=Ool3000hOol007Aoo`03001oogoo009oo`03
001oogoo01ioo`<001eoo`0iNmMg]W_GLkQg^6]jKi][VV]kIg][O6MkJg]WNellFaaO?5/KGcaK75ll
Fa]K75KlEaaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD_`005;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aoo`0004Moo`00M7oo00<007ooOol00Woo00<007ooOol077oo0P000Woo00<007ooOol0
6Woo0WNf00=k]WNfMkP00gNh0VMk00a[NfMkIg]WNf=LHe]O?5/lGcaK?5llFc`2Fa`01ELLE_aG75Kl
Ea`00UKl00QBo5KlD_aFo5;lE_aBo5Kl0U;l00<005KlD_`01e;l00MBg5;lD_aBo5;LOol00017Ool0
07Aoo`03001oogoo009oo`03001oogoo01Uoo`<0025oo`0NMkIkegNfMkQc]gOHLkQc^VnIJgaWNf]k
Ig]WO6=KIeaSFellFaaO?5/LFcaK75/lE_aK75KlEaaFo5/L0UKl01]Bo5KlD_aFo5;lE_aBo5KlD]`0
05;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg7oo0000AWoo001dOol00`00Oomoo`02Ool00`00
Oomoo`0GOol2000SOol00gNfNkIg]P04MkP2LkT00g>jIg]WN`02He`01F=KHeaSG6=LHe/01e/L00AF
o5LLE_aG70AFo004D_aFo5;lE_`3D_`01EKl001Bo5;lE_`025;l00ABg5;lD_aBo09oo`03001oogoo
04=oo`00M7oo00<007ooOol00Woo00<007ooOol057oo0`0097oo03ig]W_GMkIg^7>gMmQc^7>jKiUc
^VnILkYSFfMlHe]WG6=KIgaSFf=LGc]K?5/LFcaK75/lFaaG75;lEaaFo5LLD_aG75;lE_aBo5KlD_aF
o5;LE_aBg000D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aoo`00AGoo001eOol4000EOol2
000WOol00g^fMkIg]P03MkP2LkT01W>jLiUc^FnJKi]SF`=SG0=O?003HeaK75/L009K7003EaaK75LL
00MFo006D_aFo5;lE_aBo5Kl0U;l00<005KlD_`02e;l00IBg5;lD_aBo7oo0014Ool008]oo`<002Qo
o`0QNmMg]W_GLkMgf7>hLkY_VG>jKiUc^V]jKi][VVnKJgYSG5lkHeaO>f=LGc]SG5KlFaaFo5/LE_aK
75KlEaaBo5LL009Fo00ND_aG75;lE_aBg5KlD_aFo5;L001Bg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aoo`00@goo0029Ool20002Ool00`00Oomoo`0VOol3Nk<02W^eNkAc^G>iLkYcVG>i
KiY_Vf^J0VnJ00E[NfMkGcaO?6=L009O?00;FcaO?5LLFaaG75/LEaaK75LLE_aBo003E_`02E;lE_aB
o5KlD_aFo5;lE_`0000;D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool0@Woo0026Ool3000/Ool087^C
NkAgTg_EMkAkegNfLkY_VG>jJgY_Vf^JKi][NV]lIg][NelkHeaO>ellFa]O?5/LGcaFo5/LE_aK75Kl
Fa`2E_`08E;lEaaBo5KlD_aFo5;lE_aBg5KlD_`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LOol00012Ool008Aoo`8002moo`=k/`04NkAk]GNfNkH2MkH01VnJKi][VVnJIg][N`=W
N`0?Jg]K?5llFcaO?5/lGcaK?5llE_aG75KlEaaFo5LL009Fo004D_aFo5;lE_`3D_`01EKlD_aBo000
E_`025;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol00011Ool0085oo`<0031oo`15NkAgTg^dMkAk
]GNfNmMg]W_GLkMgf7>hMkQWNf]lIg][NfMkJgaSFfMLFa]O?5/LGcaK6ellFaaK?5KlFaaFo5LLE_aK
75;lE_aBo5KlD_aFo5;lE_aBo5KlD]`005;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aoo`00045oo`00OWoo0`00<goo0g^c0W^e00=k]WNfMkH017Nh00=c^G>jIg/00VMk00=[Nf=K
He`00V=L00=K?5llFc`015/L00EG75KlEaaFo5LL009Fo006D_aFo5;lE_aBo5Kl0e;l00=Fo000D_`0
2U;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo0010Ool007aoo`8003Eoo`18Mi=k]7^CNkEg]7_GMkIk
egNfMmQc^7NhKiUc^VnIJg]WNfMlHe]WG6=KIgaSFfMLFaaK?5/LFcaK75/lFaaG75KlEaaFo5LLD_aG
75;lE_aBo5KlD_aFo5;LE_aBg000D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aoo`00?goo001iOol30002Ool2000cOol3Nk<00g^eNkIg]P02MkH4MkP01W>jLiUc^G>iHeaS
F`=SG004He]SG5llHe`6Fa`8E_`01U;lE_aBo5KlD_aFo09Bo003001Fo5;l00]Bo005D]aBo5;lD_aB
g003D_`00e;LOol0000oOol007Moo`8003Uoo`0MNkAkTg^dMkAkeGNfNmMg]WOHLkQg^7>gLkY_VG>j
KiU_Vf^JIeaSFfMlHe]SG5lkHeaO>e/lFaaK?002Fa`0:eKlFaaFo5LLD_aG75KlEaaBo5KlD_aFo5;L
E_aBo5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00
03ioo`00M7oo0`00>goo0g^c00Ak]GNfMkIg]PAg^006LkYcVG>iLkU_Vf^J0VnJ00E_VellGcaO?6=L
00=O?007FaaG75/LEaaK75LLFa`01UKl00IBo5KlD_aFo5;lE_`2D_`00`00D_aBo009D_`01E;LD_aB
o5;lD]`00e;l00ABg5;lD_aBo09oo`03001oogoo03]oo`00LWoo0P00?Goo01akTg^dMi=k/g^BNkAg
Tg^dMkAk]GNdLkY_VG>jJgY_Vf^JKi][NVnKIg][NelkHeaO>f=LGc]O?09K700^E_aK75KlFaaFo5/L
D_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD_`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo7oo000mOol006moo`<003moo`9kTP03Nk9kTW^c009k/`04NkAk]G^eNkH2
MkH00fnJKi][VP02KiX01FnKIg]WNfMkHe`00Ull00QK?5llFcaO?5/lFaaG75/L0ULL00EFo5LLE_aF
o5;l00=Fo0=Bo005E_aBo5;lD_`00008D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo09o
o`03001oogoo03Yoo`00KGoo0P0000=oo`00Ool0?goo04]kTW^bNi9k/gNCNkAkTg^eMkAkeGNfNmMc
]gOHJiY_Vf]jJgaWNf]kIg][O6MkGcaK6ellFaaO?5/KGcaK75LLE_aK75KlEaaFo5LLD_aFo5;lE_aB
o5KlD]aFo5;lE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`00Woo00<007ooOol0>Goo001ZOol30013Ool017^BNk9kTW^b0g^c0g^e0gNf17Nh00I[NfMk
Ig]WNf]kIg/2He`01UllFcaO?5/lGcaK?09K7005EaaFo5LLE_aG7002E_`01U;lE_aBo5KlD_aFo0=B
o003E_aBo00000IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0003]o
o`00Igoo0`00AWoo051k/W^BNk=kTW^dNi=k]7NdNmEg]7_GMkIgf7>hMkQc]g>jKiU[NfMkJgaSFfML
He]WO6=KGcaK6ellFaaK?5/LFcaFo5LLE_aK75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_`005Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`00>Woo001U
Ool20018Ool017^bNi9kTW^B0g^c0W^e00=k]7NfMkH017Nh00Ic^W>ILkUc^F=LHe/3He`00f=KHeaS
G007Fa`8E_`01U;lE_aBo5KlD_aFo0=Bo003001Bo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00ABg5;lD_`003Yoo`00HWoo0`00BWoo059kTW^bNi9k/g^CNkAgTg_EMkAkegNfMmQc
^7NhLkMgf6nILkY_VFnKJiYWG6=KIgaSFfMLHe]SG5lkFcaK75/lFaaK?5KlFaaFo5LLD_aG75KlEaaB
o5KlD_aFo5;LE_aBo5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`003Uoo`00H7oo0P00CGoo0W^B17^c00Ek]G^dNkEg]W^f00Ag^005LiUc
^G>iKi][VP02KiX01F=LHe]SG5llHe`00Ull15/L00AG75/LEaaK70IFo00:D_aFo5;lE_aBo5KlD_aF
o5;l000:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000hOol005eoo`<0
0003Ool007oo04]oo`1DNk9kTW^cNi9k]7NCNkAg]7^eMkIkeg>hMkQc]gOHKiUc^VnILkY[VVnKJgY_
Vf^JHeaO>f=LGc]SG5lkHeaFo5/LE_aK75KlFaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aF
o000E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o000>7oo001KOol2001AOol00g^BNk9kTP03Nk<00g^BNk9kTP02Nk<3NkD01G>ILkUc^G>jJiX00VnJ
00E_Vf^JIg]WNf=L00AO?00:FcaO?5LLFaaG75/LEaaK75KlEa`2E_`025;lE_aFo5KlD_aFo5;lE_`3
D_`00`00D_aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`00e;LOol0000gOol002ioo`@002Ioo`<0059oo`1GNi9k/W^BNk=kTW^bNi9k/g^BNkAkTg^eMkAk
eGNfNmMg]W_GJiY_Vf]jKi][VV]kIg][O6MkGcaK6ellFaaO?5/KGcaFo5/LE_aK75KlEaaFo5LLD_aF
o5;lEaaBo5KlD]aFo5;lE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00029oo`<0015oo`00;Goo00<007ooOol00Woo00<007oo
Ool08Goo0P00EGoo00Qk/W^BNk9kTW^bNi9k/W^B0g^c0W^e00Ak]7NfMkIk]P9g^003KiY_VfMk009W
N`0AJg]WNf=LHeaO?5/lGcaK?5llFcaO?5KlEaaFo5LLE_aG7004E_`015;lE_aBo5Kl0e;l00=Fo5;l
00001U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=oo`00
Ool08goo00<007ooOol03goo000bOol00`00Oomoo`0MOol4001FOol0FG^bNi9k/W^BNk9kTW^bNi9k
/g^CNkAg]7_EMkAkegNfNmMg]WNhLkMgf6MkJg]WNf]lIg]WG6=KIgaSFellFa]O?5/LFcaK75/lE_aG
75KlFaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo00008goo00<007ooOol03goo000U
Ool60007Ool00`00Oomoo`0LOol3001HOol2Ni<00g^BNk9kTP02Ni802W^cNi9k/g^cNkEk]7^eMkIk
]WNf0gNh00EcVG>iIg][NfMk00=SG003He]SG6=L00IK7003EaaFo5LL00AFo008D_aFo5;lE_aBo5Kl
D_aFo0=Bo003001Bo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo003Ool007oo021oo`03001oo`00011oo`00;Woo100077oo0`00Fgoo02]o/g^BOk=kTW^b
Ni9k/g^BNkAgTg_EMkAk]GNfNmMg]WNhLkMgf6nILkY_VG>jKiUWG6=KIgaSFfMLHe]SG5lkFcaK75/l
FaaK?5/LEaaFo5LLD_aG7002E_`0;E;lE_aBo5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000QOol00`00
Ool0000@Ool002ioo`03001oogoo01Yoo`<005eoo`9kT`07Nk9kTW^BNi9k/g^BNk800W^c00Ek]7^e
MkIk]WNf00=g^005LiUc^G>iLkYcV@02KiX01F=LHe]SG5llHe`00Ull15/L00=G75/LEa`01eKl00YB
o5KlD_aFo5;lE_aBo5KlD_`000YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L009Bo08001moo`05001oogooOol0000?Ool002ioo`03001oogoo01Qoo`80061oo`1MNi9o
/g^BNk9kTW^bNi9k/gNCNkAg]7^eMkAkegNfNmMc]gOHKiUc^VnILkY_VFnKJgY_Vf^JHeaO>f=LGc]S
G5lkHeaFo5/LE_aK75KlFaaFo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo000E_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]ao
o`0001ioo`05001oogooOol0000?Ool002ioo`D001=oo`<0065oo`03Ni=k/g^B009kTP04Nk9kTW^b
Ni82Nk<2NkD00g^fMkIg]P02MkP01G>ILkUc^G>jJiX00VnJ00E_Vf^JIg]WNf=L00=O?00:HeaK?5ll
EaaK75LLFaaG75/LEa`3E_`025;lE_aFo5KlD_aFo5;lE_`3D_`00`00D_aBo002D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo000MOol3
000017oo000000003Woo0014Ool2001TOol0GgncNi9k/W^BNk9kTW^cNi9k]7^CNk=kTW^cNi=k]7Nd
NmEg]W_GMkIkef^JKi][NVnKJiY[NfMkJgaWNf=LGc]O?5/LGcaK6ellE_aK75KlFaaFo5LLE_aG75;l
E_aBo5LLD_aFo5;LE_aBo5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo00002Goo100097oo0011Ool300000goo
001oo`1ROol02G^cNi=kTW^BNk9kTW^bNi9k/`03Ni84Nk<01G^eNkAg]WNfNkH00WNh00=_VVnKIg/0
0VMk019[NfMkIg]WNellFcaO?5/lGcaK?5llE_aG75KlEaaFo5LLD_`3E_`015;lE_aBo5Kl0e;l00AF
o5;lD_`000EBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008
D]aBo5;lD_aBg5;lOol000Moo`03001oogoo009oo`03001oogoo025oo`00?goo0P00J7oo065kTWnc
Ni9o/g^BNk9kTWncNi9k/W^BNk=kTW^dMi=keGNdNmMg]W_GMkIg^7>gMmQWNf]kIg][O6MkJg]WNfMl
He]O?5/KGcaK75/lFaaK?5KlEaaFo5/LE_aG75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;L001Bg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LOol00007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003aoo`<006Uoo`9kT`06Ni9k/W^B
Ni9kTg^b0g^B00=k/g^BNk<00W^c00Ek]7^eMkIk]WNf00=g^004LiUc^FMkJg/2Ig/2He`00f=KHeaS
G006Fa`00eLLE_aG7004E_`025;lE_aBo5KlD_aFo5;lE_`3D_`00eKl001Bo006D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01e;LD_aBo5;lD]aoo`0000Ioo`03
001oogoo009oo`03001oogoo025oo`00>Woo0P00K7oo02mo/g^BOk=kTWncNi9o/g^BNk9kTW^cNi9k
/gNCNkAg]7^eMkIkegNfMkQc]gOHKiUc^VnILkY_VFMLHe]WO6=KIeaSFf=LGc]K?5/LFcaK75/lFaaG
75KlEaaBo5LL009Fo00`D_aFo5;lE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l0Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol08Goo000gOol3001]Ool2Ni<01G^bNi9k]7^CNk<00g^B
00=k/W^BNk800g^c00Ak]GNfNkIg]PAg^09c^@09LkYcVFnJKiYSG6=KHeaO?6=L009O?0AK7003EaaK
75LL00MFo004D_aFo5;lE_`3D_`015KlD_aBo0002E;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo0005Ool00`00Oomoo`02Ool00`00Oomoo`0Q
Ool003Eoo`800003Ool007oo06eoo`1SNi9o/g^CNkAkTWncNi9k/W^BNk9kTW^cNi9k]7^CNkEg]7_G
MkIkeg>gMmQc^7>jKiUc^VnIKi][NVnKJiYSG5lkHeaO>f=LGc]SG5KlFaaFo5/LE_aK75;lEaaFo5LL
D_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo025oo`00<Woo0`00LGoo0W^e00EkUG^dNiAk/g^C009kTP04Nk9kTW^b
Ni83Nk<017^eNkIg]WNf0gNh0W>i00Ic^W>IKiY_VVnKJiX2Ig/03V=LGcaO?5llHeaK?5llEaaK75LL
FaaG75/LD_`3E_`025;lE_aFo5KlD_aFo5;lE_`4D_`00`00D_aBo005D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0`0017oo100097oo
000_Ool3001dOol0J7^fNiEk]7^COk=kTWncNi9o/g^BNk=kTW^cNi=k]7^BNk=kTg^dMkAkeGNdLkY_
VG>jKiU_Vf]jKi][VV]kIg][O6MkHeaO>ellFaaO?5/KGcaFo5/LE_aK75KlEaaBo5LLD_aFo5;lEaaB
o5KlD]aFo5;lE_aBg5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000/Ool002eoo`8007Ioo`05NkEk
UG^eNiAk]002Ni<00g^BNk9kTP02Ni8017^cNi9kTW^B17^c00Ik]G^dMkIg]W^fMkH2KiX01FnKIg]W
NfMkJg/00fMk00iO?5/lGcaK?5llFcaO?5KlEaaFo5LLE_aG75;l0eKl00ABo5KlD_aFo0=Bo004E_aB
o0000005D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lOomoo`0002]oo`00:Woo0`00N7oo03]kUG^eNi=o]7^COk=kTWncNi9k
/W^BNk=kTW^bNi9k/g^BNkAgTg_EMkAk]GNfNmMg]WNhLkMgf6MkJg]WNf]lIg][NfMkIgaSFellFa]O
?5/LFcaK75/lE_aG75KlFaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;L00<0000ZD]aFo000E_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5Kl0Woo00<007ooOol0:7oo000XOol200000goo001oo`1gOol01G^ENkEk]G^dNi@00W^C
00Ek/g^BNi9kTW^b00=kTP03Nk9kTW^b009k/`05NkAk]GNfNkIg]P03MkP017>ILkUWNf]k0VMk0V=L
00=SFf=LHe`01U/L00=G75KlEa`015Kl00EBo5KlD_aFo5;l00<000=Bo003E_aBo00000IBo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
15;LD_aoo`00:Woo000VOol2001lOol0<g^eMiEo]7^CNkAkTWncNi9k/W^BOk=kTW^bNi9k/W^BNk=g
Tg^dMkAk]GNdNmMg]W_GLkMgf7>hLkY_VG>jKiUWG6=KIgaSFfMLHe]SG5llFcaK75/lFaaK?5/LEaaF
o5LLD_aG7002E_`0=E;lE_`00000D]aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`0
0Woo00<007ooOol09goo000VOol2001kOol3NkD01G^DNkAkTg^cNi<00W^B00Qk/g^BNi9kTW^bNi9k
/W^B0W^c0W^e00=k]WNfMkH00gNh0W>i00Uc^W>IKiY_VV=LHe]SG5llHe`00Ull15/L00=G75/LEa`0
1EKl0`0000=Fo5;lE_`00e;l00=Fo5;lD_`00e;l00<005;lD_`015;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aoogoo000XOol0
02Ioo`<007Yoo`0bMiEk]W^CNkAkTgncNi9k/W^BOkAkTW^bNi9k/W^BNk=kTW^dNi=k]GNdNmEg]W_G
LkMgf7>hLkY_VG>jKiU_Vf]jKi][VV=LGc]SG5llHeaO>f=LE_aK75KlFaaFo5/LD_aG70<0000jEaaB
o5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000XOol002Io
o`04001oogoo001hOol2NkD017^ENkAkU7^c0W^C00=kU7^dNi<00W^B00Ak/W^BNi9kTP=k/`9k]@9g
]PAg^003LkUc^V^J009_VP05Ki][VVMkIg]SG004Gc`01U/lGcaG75/LEaaK70<000=Fo008D_aFo5;l
E_aBo5KlD_aFo0QBo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l0Woo00<007ooOol09Goo000UOol00`00Oomo
o`02Ool00`00Oomoo`1eOol0;G^fNiEk]7^COkAkUG^eNi=o]7^COk=kTWncNi9k/W^BNk=kTW^dNi9k
/g^BNkAg]7_EMkAk]FnILkY[VVnKJgY_Vf^JJg]WNf]lIg][Ne/KGcaK75llFa]O?0030000@E/LE_aG
75;lEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_`005KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o7oo00009goo000UOol00`00Oomoo`03Ool00`00Oomoo`1cOol01W^eNiEk]GNfNkMkU@9k]@05NkAk
U7^CNi=k/P03Ni801W^cNi9k/g^BNk=kTP9k/`05NkEk]7^eMkIk]P02MkP00fnJKi][VP02Ig/00f]k
Ig]WN`02He`00e/lGc`0000200001ellE_aG75KlEaaFo5LL009Fo006D_aFo5;lE_aBo5Kl0e;l00=F
o5;lD_`01U;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`0UOol002Eoo`03001oogoo00Aoo`03
001oogoo075oo`0YMkQcV7NhMiIk]gNFNkEgUGndNi=k]7^BOk=kTW^bNi9k/g^BNk=kTW^cNi9k/gNC
NmEg]7^eMkAkegNfMkQc]gOHLkQ[NfMkJgaWNf]kHe]WO0030000AUllFaaK?5LLFcaFo5LLE_aK75Kl
EaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
0Woo00<007ooOol08goo000UOol20006Ool2001aOol3MiP00g^gMiIk]@02NkD017^DNkAkTg^c0g^B
00Mk/W^BNi9kTW^bNi9k/P02Nk<01G^dNkEk]G^fMkH017Nh0W>i00A[NfMkHeaSG080009SG0MK70IF
o008D_aFo5;lE_aBo5KlD_aFo0=Bo003E_aBo5;l00EBo003001Bg5;l009Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo
00009Goo000UOol00`00Oomoo`07Ool00`00Oomoo`1]Ool09G>HMkQcV7^gMiIk]gNENkIkTg^dNi=o
/g^BNk9kTW^bNi9k/W^BNk9kTW^cNi9k]7NdNkEg]7_GMkIkeg>gMmQc^7>jKiUc^VnI00<00008He]W
G6=KHeaO?5/lEaaK?09K7015E_aK75KlEaaBo5LLE_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002Aoo`009Goo00<007ooOol027oo00<0
07ooOol0Jgoo0gNH00=k]gNFMkL00W^e00EkUG^dNiAk/g^C009kTP08Nk=kTg^BNi9k/W^BNk9kTP9k
/`9k]@03NkIg]WNf00=g^09c^@<00006KiYSG6=KHeaO?6=L0ell00IK75LLFaaG75/LEa`7E_`015;l
E_aBo5Kl0e;l00=Fo5;lD_`02E;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo7ooOol0000SOol002Eoo`03
001oogoo00Uoo`03001oogoo06Uoo`0QLiQg^7>HMkQgUW^gMiEk]W^ENkAkTgndNi9k/W^BOkAkTWnc
Ni9o/g^BNk9kTW^cNi=k]GNdNmEg]W_GMkIgf7>h00<0000<KiU_Vf]jKi][VV=LGc]SG5llHeaO>ell
0U/L04QFo5/LE_aK75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000SOol002Aoo`8000aoo`03001oogoo06Qoo`9gV009
MkQgUWNgMkIk]G^ENkEkU7^d009kT`06NiAk]7^CNi=kTW^b0g^B0g^c0W^e0gNf0`0000=c^G>jJiX0
0VnJ00E_Vf^JIg]WNf=L009O?00:FcaO?5/lGcaK?5/LEaaK75KlEa`4E_`015;lE_aFo5Kl0e;l00=F
o5;lD_`01U;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000ROol002Aoo`03001o
ogoo00aoo`03001oogoo06Ioo`0LMkQcV7NhMiIk]gNFNkIkUG^eNi=o]7^COk=gUGndNi=o/g^BOk=k
TW^bNi9k/g^BNkAkTW^cNi830000FgNdNmMg]W_GJiY_Vf]jKi]WNf]kIg][O6MkJg]K6ellFaaO?5/K
GcaK75LLE_aK75KlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L009oo`03001oogoo01moo`0097oo00<007ooOol03Goo00<0
07ooOol0I7oo0WNH00Ig^7NHMkMg]W^gNiD2NkD01W^dNiAk]G^eNkAkU09kT`08Nk=kTW^BNi9k/g^B
Nk=kTP<0009k/`04NkAk]GNfNkH4MkP3Ig/00f]kIg]WN`02He`015/lGcaK?5ll0e/L00EG75KlEaaF
o5LL009Fo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo003D]aoo`00025oo`0097oo00<007ooOol03Woo00<007ooOol0HWoo01U_Vf]jKi][NW^gMiIk
]g^ENkEgUG^gMiIk]gNENkIkTg^dNi9o/g^BNk9kTW^bNi9k/`020000IG^BNk=gTg^dMkAk]GNfNmMg
]WNhLkMgf6nILkYWNf]lIg]WG6=KIgaSFfMLEaaK?5/LFcaG75/lE_aG75KlFaaFo5LLD_aFo5;lE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g7oo000087oo000TOol00`00Oomoo`0?Ool00`00Oomoo`1POol016nJJgY_VV]j0g>I0gNH00=k]gNF
MkL00W^e00EkU7^dNiAk/g^C009kTP07Nk800000001k/W^BNk800g^c0W^e00=k]WNfMkP00WNh00Ec
VG>iLkUc^V=K00=SG004He]SG5llHe`6Fa`6E_`025;lE_aBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006
D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol07Goo000TOol2000AOol0
0`00Oomoo`1NOol05FnKJgY_Vf]jLiY_VG>JKiUg^7>HMkQgUW^gMiIk]W^ENkAkTgncNi9k/P030000
7g^bNi9k/W^BNk=kTW^dNi=k]GNdNmMg]W_GLkMgf7>hLkY_VG>jJiY_Vf=KIgaSFf=LGc]SG5llFcaG
75/l009K701:E_aK75KlEaaBo5LLE_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol001moo`008goo00<007ooOol04Woo00<0
07ooOol0G7oo00E_VV]jKiY[NVnJ00=cV@9gV009MkQgUWNgMkIk]G^ENkAkU7^d00<00008Nk9kTW^C
Ni9k/W^BNk9kTP=k/`04NkEk]WNfMkH3MkP2LkT01G>jJiY_VVnJKi/00ell00YSG5llGcaO?5/LEaaK
75LLFaaG70MFo006D_aFo5;lE_aBo5Kl3U;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo
000NOol001Yoo`@000Eoo`03001oogoo01=oo`03001oogoo05Yoo`0AKi][NVnKJgY_VfnILiY_VGNh
LiQg^7>HNkMgUW^gNiEk]@0300008gncNi9o/g^BOk=kTWncNi9k/W^BNk=kTg^dMkAkeGNfNmMg]WOH
LkQc^VnILkY_VFnKJgY_VfMkJg]O>f=LGcaSG5/KGc`00U/L04]Fo5/LE_aK75KlEaaBo5KlD_aG75;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]`00Woo00<007ooOol06goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0DOol00`00Oomoo`1HOol2He`00fnJJgY_VP03LiT2MiP01GNhMiQg]gNfNkL00`0000Uk]7^DNi=k
Tg^dNiAk]7^CNk800g^B17^c00Ak]GNfMkIg]P9g^09c^@05LkYcVFnJKiY_V`03Ig/03F]kIg]O?5/l
GcaK?5llFcaO?5KlEaaFo5LL00AFo004D_aFo5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo00007Goo000IOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`1FOol03F=lHe]WO6=KHga_VG>JKiUcVW>HMkQcV7^g
00<0000aNkEgUGndNi=o/g^BNkIkTg^dNi9o/g^BNk9kTW^cNi9k]7NCNk=kTW^dMi=keGNdNmMg]W_G
MkI_Vf]jKi]WNf]kIg][W6MkIeaSFellFaaO?5/KGcaK75/lE_aK75KlEa`00UKl04MBo5KlD_aFo5;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aoo`0001aoo`006Goo00<007ooOol00Woo00<007ooOol00Woo0P005goo0P00E7oo00QS
Ff=LHeaSG6=KHeaWNf]k0VMk00=gV7NhMiP00P0000Mk]gNFNkEk]G^dNiAk]002NkD017^DNkAkU7^c
0g^B00Ik/W^BNi9kTW^bNi83Nk<01G^dNkEg]W^fMkH00gNh0fMk00=[Nf=KHe`00V=L00=K?5llFc`0
15/L00=G75KlEa`015Kl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo00006goo000IOol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0HOol00`00Oomoo`1@Ool02f=KHgaSFfMlHe]SO6MKJgaWNf]kJgX00`00081g
UW^gMiIk]gNENkIgUW^gMiIk]W^ENkAkTgncNi9k/W^BNk9kTW^bNi9k/W^BNk=gTg^dMkAk]GNfNmMg
]WNhLkMgf6nILkY_VFMlHe]WG6=KIgaSFfMLEaaK?5/LFcaG75/lFaaG75;lEaaFo5LLD_aFo5;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg0006goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
0`00Oomoo`1=Ool00elmFcaK?002He`01F=KIg]WNf]kIg/00`0000=[NVnJLiT00g>I00]gV7NhMiIg
]gNfNkEkUG^dNiAk]7^C009kTP07Nk9kTW^BNi9k/W^BNk800g^c0W^e00=k]WNfMkH00WNh0g>i00=_
Vf^JHe`00V=L00ASFellGcaSG0AK7003EaaK75LL00MFo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`0
1U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol001Yoo`006Goo00<0
07ooOol00Woo00D007ooOomoo`0001eoo`03001oogoo04Yoo`09FcaOGE/lGceK?5mMFca[NfMK00<0
0028Ie]_Vf]jKi]_VG>JKiUcVW>HMkQcV7^gMiIk]g^ENkEkTgndNi9k/W^BNk9kTWncNi9k/W^BNk=k
TW^dNi=k]GNdNmMg]W_GLkMgf6nILkY_VFnKJiY_Vf]jKi]O?6=LGc]SG5llHeaFo5/LEaaK75KlFaaF
o5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0007Ool5000=Ool001Yoo`@000Aoo`8001eo
o`03001oogoo04Moo`9K?006GceK?5/lFcaO?E/l0`000fMk00A_VV]jKiY[NPAcV@0=MkQgV7NgMkIk
]g^ENkEkU7^dNiAkTg^BNk800W^C00=kTW^bNi800W^B0W^c0g^e0WNf0WNh0g>i00Ec^V^JKiY_VVnK
009WN`0<GcaSG5llGcaK?5llEaaK75LLFaaG75/L0UKl00QBo5KlE_aFo5;lE_aBo5Kl25;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`0000Moo`05
001oogooOol0000=Ool0029oo`03001oogoo01eoo`03001oogoo04Aoo`07EaaG?ELLGeeK?5lmFc`0
0`0003iO?6=LGca[NfMKKi][NVnKJgYcVVnILiY_VGNhLiQg^7NFNkMgUW^eMiEo]7^COk=kTWncNiAo
/g^BOk=kTW^bNi9k/g^CNkAg]7_EMkIkeg>gMmQ_VG>jKiUc^V^JKi][NVnKIg][NfMkJiaK75llFaaO
?5/LGcaFo5/L0ULL04mFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol00007Ool00`00
Oomoo`0>Ool0029oo`03001oogoo01ioo`03001oogoo041oo`03EaeG?ELL009G7@03EceG70000080
0005GcaOG5mLGeaO?002Ge`016nJJgY_VV]j17>I00Ig^7NHMiQg]W^gMiH2NkD01W^dNiAk]7^CNkAk
U09kT`0;Nk9kTW^BNi9k/g^BNk=kTW^cNi9k/`02NkD01G^dMkIg]W^fJiX00VnJ01U[NfMkIg]WNf]k
He]SG5/lGcaK?5llFcaO?5KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo003D_`00eKlD_aBo006D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l0Woo00<007ooOol0
1Goo00<007ooOol03Goo000ROol00`00Oomoo`0OOol00`00Oomoo`0mOol01eLMD_aG7ELLEceG75/m
0080002FEaaK?EllHeaO?6=LGcaSG5llIgaSFf=lHe]cVVnILiY_VGNhLiQg^7>HNkMgUW^gMiEk]W^C
NkAkTW^fNiAk]7^BOk=kTW^bNi9k/g^BNkAkTW^cNi9k]7NCNmEg]7_GMkIkeg>hMkQc]f^LIg][NfMk
JiaSFfMLHe]O?5/LGcaK75/lFaaK?5KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aoo`0027oo00<007ooOol037oo000ROol00`00Oomoo`0POol00`00Oomoo`0iOol01eLMDaeG7E<M
EaeC7ELM00<0009G7@03FceK75/m009OG005GcaOG6=LHeaSF`02He`00f]kIg]cV@02LiT3MiP00g^g
MiIg]`02NkD02G^DNkAkU7^eNiAk]7^CNk=kT`02Ni803G^bNi9k/W^BNk=kTW^bNk=k]G^dNkEg]W^f
00=g^006LkYc^FMkIg]SG6=K0f=L00=SFe/LFa`01E/L1UKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aB
o006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0Woo
00<007ooOol01Woo00<007ooOol02goo000QOol2000SOol00`00Oomoo`0fOol01U;lDaeBo5LMD_aG
7@<0002JEaeG75/mEaaK?ELLFceG75/mEaaSO6=KIgaSFf=lHe][O6MkJg]WFf]lLiQg^7>HMkQgUW^g
MiIk]W^ENkMgUW^fNiEk]7^COk=kTW^bNi9k/W^BNk=kTW^bNi9k/gNCNkAg]7^eMkIkegNfMkQc]g>j
KiUc^VnIIgaSFfMLHe]WO5llHeaO>e/lFaaK?5LLFaaG75/LD_aG75KlEaaBo5KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]`2Ool01@00Oomoogoo00000goo00<007ooOol02goo000QOol00`00Oomoo`0S
Ool00`00Oomoo`0bOol01U;mDaeC7E<MD_eC7@<0000;EaeC7ELMEaaG7E/lFceK75/mFcaK?@03Fc`0
1F=LHe]SG6=LJg/00fMk015[Nf]jKiY[NVnJMiIg]gNfMkQgV7NgMkIk]g^ENkAkU7^d009kT`03Ni9k
/W^B009kTP06Nk9kTW^bNi9k/g^d0W^e00=k]WNfMkP00WNh0g>i00E_Vf^JKiY_VV=L00=O?008HeaO
?5/LEaaK75LLFaaG70EFo006D_aFo5;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L009Bo08000Aoo`<000ioo`008Goo00<007ooOol097oo00<007oo
Ool0;goo00EC7E;lDaeBo5<M00<0001;DaeBo5LMDaaG?E<LEaeC75LmEaaK?ELLGeeK?5lmFcaOGE/l
HgaSFf]lIg][NfMKJga[NVnKJgY_VfnILiY_VGNhLiQg^7NFNkMkUG^eNi=o]7^BOk=kTW^bNi9o/g^B
Ok=kTW^cNi9k]7^CNkEg]7_GMkIg^7>gMmQ_VG>jKiU_Vf^JKi][NV^LIg]SG5lkHeaK75ll009K701G
EaaK75KlFaaG75KlD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0001Aoo`00
8Goo00<007ooOol09Goo00<007ooOol0:goo00EC7E;mDaeBoE<M00<000IC7@03EaeG75LM009G7@04
EaaG7E/lGcd3Fc`01ElmFcaK?5/lJg/00fMk00I[Nf]jKiY[NVnJKiT3LiT2MiP01gNfNkMgUW^eNiAk
]7^D009kT`08Nk9kTg^CNi9k/W^BNk9kTP9k/`=k]@04MkIg^7NhMkP3LkT01FnKJiY_VVnJJg/00fMk
00]O?5/lGcaK?5llFcaK75LLFaaFo5LL009Fo004D_aFo5KlE_`3D_`00eKlD_aBo00:D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0001=o
o`008Goo00<007ooOol09Woo00<007ooOol0:7oo00A>o5<MC_aC7@<0001CDaeBo5<MD_aG7E;lEaeB
o5LMD_aG7E<LEceC75LMEaaK?E/lGceK?5mMFcaO?E/lHeaO?6]kIe][O6]jKi][NVnKJgYcVVnILiYc
V7NhLiQk]gNFNkEgUGndNiAo/g^BOk=kU7ncNi9o/g^BNk9kTW^cNi=k]7NdNmEkTg^dMkAkeGNfNmMg
]VnKJiY_VfMkJiaWNf]kIg]WO6=KGcaK75llFaaO?002Fa`015KlEaaFo5/L0UKl051Bo5KlD_aFo5;l
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`004goo000QOol2000XOol2000UOol00e;mDaeBo@02
D_d200001U<MD_eC7E;mDaeBo@MC7@9G7@05EaaG7ELMEceG7002Ead00elmFcaK?002Ge`02EllGeaO
G5mLJgY_VV]jKiY[NP03LiT3MiP02W^gMiIk]G^eNkAkU7^dNi=k/g^D0W^C00ik/W^BNi9kTW^cNi9k
/g^BNk=kTW^cNkAk]G^d0WNf0gNh00=WNf]kIg/00VMk00MSG6=KHeaK?5llFcaO?003Fa`00eLLE_aG
7004E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol0019oo`008Goo00<007ooOol0:Goo
00<007ooOol087oo00AC7DklDae>o0<0001JC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG
75LmEaaK?ELLEceG75/mEaaSG5llHeaO?6=LGcaSG6=KHga[NVnKJgYcVVnILiYcV7NhLiQg^7NFNkMg
UG^fNiAk]7^BOk=kUG^dNi9o/g^BNk9kTW^cNi9k/W^BNk=kTW^dMi=keGNdNmMg]WOHLkQg^6nILkYW
Nf]kHe]WO6=KIeaSFfMlFaaK?5LLFcaK75/l0ULL05EFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_`0000BOol0021oo`03001oogoo02]oo`03001oogoo01aoo`04Dae>
oE;mD_d300000e;mDaeBo@02D_d025<MD_eC7E;mDaeBoE<MD_d4Dad01ULMDaeG7ELMEceG709G7@06
EceK75/mFcaOG5ll0emL00ESFf=LHeaSG6=K00=cV@06KiUgV7NHMkQgUWNg0W^e00UkU7^dNiAk]G^E
NkAkU7^cNi<00W^B00ek/g^BNi9kTW^cNi9k/W^cNkEk]7^eMkIk]P02MkP017>iLkYc^G>i0V=L00AS
Ff=LHeaSG09O?0AK7003EaaK75LL00EFo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003
D]aoo`00015oo`0087oo00<007ooOol0;7oo00<007ooOol05Woo00IC7DkmDae>o5<MC_d30000I4kl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeC75LMD_aG7ELLEceG75/mEaaK?ELL
FceG76=LGcaWO6=KHgaSFfMlHe][NfMKJgaWNgNhLiQg^7>HNkMgUW^fNiEk]gNFNkIkUG^eNi=o/g^B
Nk9kTW^bNi9k/W^BNk9kTW^cMi=k]7NdNkEg]W_GLkQg^7>gLkY_VG>jJiY_Vf^JKi]O>f=LGcaSG5lk
HeaG75/LE_aK75LLFaaBo5LL0UKl05=Bo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aoo`00011oo`0087oo00<007oo0000;Goo00<007ooOol04goo00=BoE<MC_d00U;m0`0000=B
oE<MC_d00U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M019G7E<MEaeC7ELMDaeG7E/l
FceK75/mFcaK?E/LFceK?6=LHe/3He`056=KIg]WNf]kIg]_VV]jKiY[NWNgMkIg^7NHMkMg]W^gNiEk
]G^DNk@2Ni<00g^BNk9kT`02Ni802G^bNi9k/W^BNk=k]7^eMkIk]P03MkP02G>jLkUc^FnJKi][VVnJ
Ig][N`04Gc`02E/lGcaG75/LEaaK75LLFaaBo003E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`2000@Ool0021oo`8002moo`03001oogoo00moo`05C_eC7DklDae>o@030000`4kmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E<LEceG75/m
EaaK?ELLFceK?5mMFcaSO6=KIgaWNf]kIe][O6MkKi][NVnKJgYcVVnIMkQcV7NhMiIk]g^ENkEgUGnd
NiAo/g^BOk=kTW^bNi9k/W^BNk=kTW^dNi=k]GNdNmMc^7NhLkMc^VnILkY[VVnKJiY_VfMkJiaWNf]k
FaaO?5/LGcaK75llE_aG75KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lOol000moo`001Goo1@001Goo0P001Goo10001Woo00<007ooOol0;goo00<007oo
Ool037oo00AC7DkmD_eBo@<00003D_eC7Dkm009Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;mDaeB
oE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@04EaaG7ELMGcd3Fc`01ElmFcaK?5/lGcd00fMk00I[
NfMkKiY[NVnJJgX3LiT2MiP00gNfNkMgUP02NkD02G^dNiAkTg^CNk9kTW^CNi9k/P03Ni82Nk<01g^e
NkAk/g^cNkEk]7^f009g]P03KiY_Vf^J009WN`03Jg]WNfMk009SG003FcaO?5/l00=K700:E_aG75Kl
EaaFo5LLD_aFo5;lE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo09oo`03001oogoo00aoo`0017oo0P00
00Eoo`00001oo`0000Aoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo031oo`03
001oogoo00Qoo`05Dae>o5<MC_eC7@020000adkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMDaaG?E<LEaeC75/mEaaO?E/lGeeK?5lm
FcaSG5llHeaWFf]lIg]_Vf]jKi][NW>JKiUcVW>HMkQcV7^gMiIk]GNENkIkU7^dNi9o/g^BNkAkTWnc
Ni9k/W^BNk=kTg^dNi9k/g^CNkEg]7_EMkIkeW>gMmQc^6]kIg][W6MkIgaSFfMlHe]WO5LLFcaK75/l
EaaK?5KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aoo`0000ioo`0017oo0P000Woo00<007oo00003goo00<007ooOol00goo00<007ooOol0<Goo00<0
07ooOol01Goo00A>oE;mD_eC7@<00006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<M
D_eBoE;mDad00e;m00AC7E;mDaeBo@QC7@06EaeG75LMEaeG?ELL0ULM00=O?E/lFc`00UmL00UO?5mL
GeaOG5llKiY[NVnJJgX00g>I0gNH00=k]gNFMkL00W^e00QkU7^dNiAk/g^DNkAkTg^b0g^B00Ek/g^B
Nk=kTW^b009k/`03NkAk]GNf009g]P9g^09c^@03LkYc^F=L009SG004He]SG5llHe`6Fa`6E_`025;l
E_aBo5KlD_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo00aoo`0017oo0P000Woo00<007oo00003goo
00<007ooOol00Woo0P00=7oo00P007ooOomoodklDae>oE<M0`0006mC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeB
o5LmEaaK?ELLEceG75/mEaaSG5llHeaO?6=LGcaSG5llHgaSFfnKJgYcVVnILiYcV7NhLiQk]gNFNkMg
UG^fNiEk]7^COk=kUG^dNi=o/g^BNk9kTW^bNi9k/W^BNk=kTW^dMkAkeGNdNmIg]WOHLkQc^VnILkY_
VFnKJiYWO6=KHeaO>f=LGcaK?5LLFc`00U/L00IFo5/LE_aG75;lEa`2E_`0EE;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0000aoo`0017oo0P000Woo00<007oo0000
2goo10001Goo00<007ooOol0<Woo00=BoE<MC_d00U;m00IC7@00000005<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@IC
7@04EaeC7ELmEa`2Ead01ULmEaaK?E/lGeaO?0=OG005He]SG6=LHeaSF`03LiT04FnIMiQgV7NhMiIg
]gNfNkEkUG^dNiAk]7^ENkAkU7^cNi<00W^B00Ik/W^BNi9kTW^bNi82Nk<017^eNkAg]WNf0gNh00=c
^G>jLkT00VnJ00E_Vf^JGcaO?6=L00=O?007FaaG75/LEaaK75LLFa`00UKl00QBo5KlE_aFo5;lE_aB
o5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;l
D_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00ABg5;lOol000aoo`000goo0`0000Eoo`00001oo`0000]oo`03001oogoo
00Ioo`03001oogoo031oo`05Dae>o5<MC_eC7@030000Le<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LM
DaaG7E;lEaeC75LmEaaK?ELLFceG75/mEaaSG5llHeaSFf=lHe]WO6=KJg]WFf]lIg]g^7>HMkQgUW^g
MiIk]W^ENkEgUW^gNiEk]G^COkAkTW^bNi9k/W^BNk9kTW^bNi9k/gNCNmEg]7_FMkIkeg>hMkQ_VG>j
KiU_Vf^JKi][VV]kIg]SG5llHeaK75ll009K701PE_aK75LLEaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`002goo0005Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0]Ool01E<MC_eBoE;mDad00`0000IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d4Dad045LMDaeG7E<MEaeC7E/mFaaK?E/lFceK75/mFcaSG6=K
0f=L00USFfMkIg][NfMkKiY[NVnJKiT00W>I00Ug^7NHMiQg]W^gMiIk]G^DNk@00W^C00ikTW^bNi9k
Tg^BNk9kTW^bNi9k/g^dNkEg]W^f0WNh00=c^G>jLkT00VnJ015_Vf^JIg]WNf]kIg]O?5/lGcaK?5ll
FcaG75KlEaaFo5LL00AFo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aB
g5;l0P002Woo0006Ool4000<Ool50004Ool00`00Oomoo`0[Ool014klDae>oE<M0`00085C7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG?E<LFceG75/mEaaK?E/lGeeK
?6=lHe]WO6MkJg]WFf]lIg]_Vf]jKi]_VG>JKiUcVW>HMkQcV7^gMiIk]GNEOkAkU7ncNi9o/g^BOk=k
TWncNi9k/g^BNkAg]7^eMi=k]7NdNkEg]W_GMkI_Vf^JKi]WNf]kIg][W6MkIgaSFellFaaO?5LLFcaK
75LLE_aK75KlEa`00UKl05UBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001F
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aoo`0000Yoo`007goo00<007ooOol0:7oo00E>oE;mD_eC7Dkm00800006Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@04EaaG7ELMEad3
Fc`01ElmFcaK?5/lGcd00fMk00I[NfMkKiY[NVnJJgX3LiT3MiP01W^gMiIg]g^eNkAkU09kT`05Nk9k
U7^CNi=k/P03Ni8017^bNk=k/W^B0W^c00Ak]G^dNkIg]P=g^0=WN`03Jg]SFf=L009SG003He]K75/L
00EK70IFo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00P00
2Goo000NOol2000UOol01dkmDae>o5<MC_eC7Dkl00<0003RC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E<LEceC75LMDaaG?ELLEceK?5mMFcaO?E/lGeeO?6=L
Ie][O6MkKi][NVnKJgYcVVnILiYcV7NhLiQg^7NFNkMgUG^fNiAk]7^BOk=kU7ncNi9o/g^BNk9kTW^c
Ni=k/W^BNkAkTg^eMkAkegNfNmIc]gOHKiUc^VnILkYSFfMlHe]WO6=KHeaO>e/lFaaK?5LLFaaG75/L
D_aG75KlEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo7oo0009Ool001ioo`03001oogoo029oo`06Dae>oE;mD_eC7Dkm0`0000E>oE;mD_eC7Dkm009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m1e<M00EG75LMEaeG?ELL009G7@06
EceK?5/lFcaOG5ll0emL00EO?6nJJgY_VV]j00=cV@=gV00=MkQgUWNgMkIk]G^DNkAkTg^cNiEk]7^C
Nk<00g^B00Ek/W^BNi9kTW^b009k/`04NkAk]GNfMkH2MkP3LkT00g>jJiY_VP02He`3Gc`026=LGcaK
75LLFaaG75/LEa`5E_`01U;lE_aBo5KlD_aFo0iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo00000Uoo`007Woo
00<007ooOol087oo00E>o5<MC_eC7Dkl00<00024C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E;lEaeG75/mEaaG?ELLFceG75LmGcaSG5ll
HeaO?6=LGcaSO6=KIgaSFg>JKiUcVVnIMkQcV7NhMiIk]gNFNkIkUG^dNi=k]W^ENkAkTgncNi9k/W^B
Nk=kTW^bNi9k/g^CNk=g]7_EMkIkeW>gMmQc^7>jKiUc^V^JKi][VVnKGcaSG5lkHeaK75ll0U/L05eG
75/LE_aK75LLE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`017oo00<007ooOol01goo000NOol00`00Oomoo`0NOol2D_d00e<MC_d0000200001DkmD_eB
oE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;m
DaeBo@9C7@06EaeC7ELMDaeG7ELL0ULM00IG?ELLFceK?5/mGc`3Ge`01F=KHeaSG6=LHe/00VMk019[
NfMkMiQgV7NhMiQg]gNfNkMkUGNgMiIk]G^ENkEkU7^cNi<2Ni801W^bNi9kTW^BNk9kTP9k/`04NkEk
]7NfMkH2MkP2LkT01FnKJiY_VVnJKi/00fMk00]O?5/lGcaK?5llFcaG75KlEaaFo5LL009Fo004D_aF
o5KlE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo0Moo`03001oogoo00Ioo`007Woo
00<007ooOol06goo00AC7DkmDae>o0<0002BC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMD_aK?ELLFceG
75/mEaaK?ELLIgaSFf=lHe]WO6=KJg]WFf]lIg]_Vf]jKi][NW^gMiIk]g>HMkQgUW^gNiEk]G^COkAk
TW^bNi9k/W^BNk9kTW^bNi9k/gNCNmEg]7_FMkIgf7>hLkY_VFnKJiY_Vf^JJiaWNf]kIg]WO6=KGcaK
75llFaaK?5LLFaaFo5LLE_aK709Fo01@D_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo0Yoo`03001oogoo00Ioo`007Goo0P0067oo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mDaeBoE<MD_eC
7E;mDaeBo@=C7@05D_eC7E<MEaeC7@03Ead02ELLFceK?5/mFaaK?E/lGceK?003He`3Ig/01V]kIg]_
VV]jKiY[NP=cV@05LiQgV7NFNkMkU@02NkD01W^dNi=kTg^BNk9kT`9kTP03Nk9kTW^b009k/`05NkAk
/W^cNk=k]002MkH4MkP00f]kIg]WN`02He`00f=KHeaSG006Fa`00eLLE_aG7004E_`015;lE_aBo5Kl
0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L009Bo0ioo`03001oogoo00Ioo`007Woo00<007ooOol057oo00I>o5<MC_eC
7DklDad20000U4klDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lDaeC75LMDaaG?E<LEaeC75/mEaaK?E/l
GeeK?5lmFcaOGFMkJg]WFf]lIg]_Vf]jKi][NW>JKiUcVVnIMkQcV7^gMiIk]GNEOkAkU7ncNi9o/g^D
Ok=kTWncNi9k/gNCNkAkTW^cMi=k]7NdNkEg]W_GLkQg^7>gLkY_VG>jHe]WO6=KIgaSFf=LGcaK?5LL
FcaK75/l0ULL04]Fo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`04goo00<007ooOol01Woo000M
Ool00`00Oomoo`0COol2D_d00e<MC_eBo@030002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeB
o@EC7@9G7@05EaaG7ELMEaeG7002Fc`03elmFcaK?5/lGceO?5mLIg][NfMkKiY[NVnJJgY_VP02LiT0
1FnIMiQgV7^gMiH00g^e00EkU7^dNi=k]7^D009kT`08Nk9kTW^BNi9k/W^BNk9kTP9k/`03NkEg]W^f
00=g^009LkYc^G>iKiY_Vf=KHeaO?6=L009O?0AK7003EaaK75LL00EFo006D_aFo5;lE_aBo5Kl35;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo009D]aBo5;lD_aBg5;l001Bo5;L00=Bo006D]aBo5;lD_aBg5;l5Goo00<007ooOol01Woo000M
Ool00`00Oomoo`0AOol014kmDae>o5<M0`000>9C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeB
o5LMD_aG7E;lEaeC75LMDaaG?ELLEceG75mMFcaO?E/lHeaO?6=LGcaSG5llKi][NVnKJgY_VfnILiY_
VGNhLiQg^7NFNkMgUG^fNiAk]7^BNkIkU7^dNi9o/g^BNk9kTWncNi9k/g^BNkAkTg^eMkAkeg>hMkQc
]g>jKiUc^V^JKi][VVnKGc]SG5llHeaO>f=LEaaK75KlFaaG75/LE_aG75;lE_aBo5LLD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aB
g1Moo`03001oogoo00Ioo`007Goo0P003goo00ABoE<MC_eBo@<0009Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
35<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@MC7@03EaeG?ELL009G7@03EceG75LM009OG005GcaOG5mL
GeaO?002He`00fnJJgY_VP02LiT01VnIMiQgV7NhMiIg]`9k]@08NiEk]7^DNkEkU7^dNi=k/`=kTP05
Nk9kTW^BNi9k/P02Nk<00g^dNkIg]P02MkP02G>jLkUc^G>iKi][VVnJIg][N`04Gc`025/lGcaG75/L
EaaK75KlEa`4E_`015;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`077oo
00<007ooOol01Woo000MOol00`00Oomoo`09Ool01TklDae>oE<MC_aC7@<0002SDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7ELLEceG75/mEaaG?ELL
FceO?6=LGcaSG5llHgaSFfMlHe]SO6nILiY_VG>JLiQg^7>HNkMgUW^fNiEk]gNFNkIkUG^dNi=o/g^B
Nk9kTW^bNi9k/W^BNk=kTg^cMkAkeGNfMkQc]g>jKiUc^VnIKi][VV]kIg][W6MkJg]K75llFaaO?5/L
GcaFo5LLE_aK75KlEa`00UKl03aBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo7oo000OOol00`00Oomoo`05Ool001eoo`03001oogoo00Moo`9Bo@03Dae>
oE;m00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0<DaeBoE;mD_eC7E;mDaeB
oE<MD_eC7E;m0U<M00AG7E<MEaeC7@9G7@07EceG75/mFcaK?E/LFcd00UmL00QSFf=LHeaSG6=KHeaW
Nf]k0VMk00mgV7NhLiQg]gNFMkQcV7NgMiMk]g^ENkAkU7^cNi<00W^B00Ik/W^CNi9kTW^bNi82Nk<0
1G^eNk=k/g^dNkH00gNf00E_Vf^JIg]WNf]k009WN`9SG003FcaO?5/l00=K7004E_aG75KlEa`4E_`0
1U;lE_aBo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`017oo00<007ooOol077oo00<007ooOol01Goo
000MOol00`00Oomoo`05Ool014kmDae>o5<M0`000>1C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeC75LMD_aG7ELLFceG75/mEaaK?ELL
FceSFf=lHe]WO6=KHgaWFf]lIe][Nf]jKi][NW>JKiUg^7>HMkQgUW^gNiEk]G^COkAkTWncNi9o/g^C
Nk9kTW^bNi9k/gNCNk=kTW^cMkAkeGNfNmIg]WOHLkQc^VnIJiaWNfMlHe]WO6=KIgaG75/lFaaK?5LL
FcaFo5LLD_aG75KlEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
27oo00<007ooOol06goo00<007ooOol01Goo000MOol01000Oomoodkm0U;m00AC7DkmD_eBo@80009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;m
DaeBo@=C7@0@D_eC7E<MEaeC7ELMDaeG7ELLEaeK?5/mFaaK?E/lGc`2Fc`2He`016=KIg]WNf]k0VMk
00=[NVnJJgX00g>I00QcV7NHMiMk]gNFNkEkU7^d0W^C00]kTW^dNi=kTg^BNk9kTW^bNk=k/W^B009k
/`04NkEg]WNfMkH2MkP2LkT00g>jLkUSG002He`016=KGcaO?6=L15/L00=G75/LE_`01EKl00ABo5Kl
D_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`<Ool00`00Oomoo`0KOol00`00Oomoo`05Ool001aoo`08001o
oe<MC_eC7DklDae>o@<0003MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aG7E<LEceC75LMDaaG?E<LGceK?5mMFcaO?E/l
GeeK?6]kIe][O6MKJg][NVnKJgY_VfnILiYcV7NhLiQk]gNFNkEgUGndNiAo/g^BOkAkTgncNi9o/g^B
Nk=kTW^bNi9k/gNCNmEg]7_FMkIkeg>hMkQ_VG>jKiU_Vf^JKi]O?6=LGc]SG5llHeaFo5/LEaaK75Kl
FaaG75KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg00AOol00`00Oomoo`0JOol00`00
Oomoo`05Ool001aoo`03001C7Dkm009Bo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1U<M00=G7ELL
Ead00ULM00AG75LMEaeO?0=K?005GcaK?5mLGea[N`02Ig/016]jKiY[NVnJ0W>I00UcV7NHMiQk]gNF
MkMk]G^dNi@00W^C00]k]G^DNi=kTg^bNi9k/W^BNk9kTW^b009k/`04NkAg]WNfNkH2MkP00g>iLkYc
^@02KiX01FnKIg]WNellHe`00Ull00QK?5llEaaK75LLFaaFo5LL0UKl00ABo5KlE_aFo0=Bo003E_aB
o5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]ao
ogoo01Eoo`03001oogoo01Uoo`03001oogoo00Eoo`004Woo1@001Goo00<004km00000P000=a>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMD_aG7E<LEceG75LmEaaK?ELLGceK?5mMGcaSG5llHeaO?6=L
JgY_Vf]jKi]_VG>JLiQg^7>HNkMgUW^gMiEk]W^DNkAgUG^fNiAk]7^BOk=kTW^bNi9k/W^BNk=kTW^d
MkAk]GNfNmMc^7NhKiUc^VnIKi][VVnKIg][NfMkJiaK75llFaaO?5/LGcaFo5/LE_aG75KlFaaBo5Kl
D_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo1Yoo`03001oogoo01Qoo`03001oogoo00Eoo`0057oo00<007ooOol01Goo
0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@IC7@06EceG75LMEaeG?ELL
0ULM00=OG5llGe`00UmL00IO?5mLHeaSG6=KHe`2LiT02VnIMiQgV7NhMiIg]gNGNkEgUWNg0W^e00Ak
UG^dNi=k/`9kTP03Ni=k/W^B009kTP9k/`08NkEg]W^fNkAk]GNfNkIg]P9_VP0:Ki]WNfMkIg][Nf=K
HeaK?5llFc`3Fa`035KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg5;lD_`077oo00<007ooOol06Goo00<007ooOol017oo
000DOol00`00Oomoo`06Ool0fP00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MDaaG7E;lEaeC
75LmEaaK?ELLEceG75/mEaaSG5llHeaO?6=lHe]WO6=KHgaWFf]lIe]g^7>HMkQgUW^gMiIg^7>HNkMg
UW^fNiEk]7^COk=kTW^bNi9o/g^BNk9kTW^cNi=k]G^BNkAkTg^eMkAkegNfMmQc]gOHIg][NfMkIgaS
FfMlHe]WO5/LFcaG75/lFaaK?5;lEaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`QOol00`00Oomoo`0HOol00`00Oomoo`04
Ool001Aoo`03001oogoo00Moo`800003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m019C7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<M
D_d2Dad03ULMDaeG7E<MEaeK75/mFcaK?E/LFceK?5/mHe/3He`02F=KHeaWNf]kIg]_VV]jKiY_V@02
LiT02WNhLiQg]gNGNkEkUG^eNiAk/g^C0W^B00Ek/g^BNi9kTW^b009k/`06Ni9k/g^cNkEk]7^f0WNf
0WNh0g>i00=SG6=KHe`00V=L0Ull15/L00=G75/LE_`01EKl00IBo5KlD_aFo5;lE_`<D_`01E;LD_aB
o5;lD]`00e;l00=Bg7ooOol097oo00<007ooOol05goo00<007ooOol017oo000DOol00`00Oomoo`09
Ool0d@00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeBo5LmDaaG7ELLFceG75/mEaaK?E/l
GceSFfMlHe][NfMKJgaWFfnKJgY_VfnILiY_VG>JLiQg^7NFNkMkUG^eNi=o]7^CNk9kTWndNi9k/W^B
Nk=kTW^bNi9k/g^CNk=g]7_GMkIkeW>gMmQ_VG>jKiU_Vf^JKi]O>f=LGcaSG5lkHeaG75/LE_aK75LL
FaaBo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_`0:7oo00<007ooOol05goo00<007ooOol017oo000DOol00`00Oomoo`0:Ool01000OomC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;m
DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMEa`00eLM00AK75/mFcaO?0=K?005GcaK?6Mk
Ig][N`02Ig/00f]jKiY[NP03LiT01G>HMiQgUg^gNiD00W^e00Ik]7^DNi=kU7^dNi<2Ni801G^bNi9k
TW^BNk800W^c00Ak]7^fMkIg]P=g^09c^@05Ki][VVnJIg][N`04Gc`015/lGcaG75/L0ULL00=Fo5LL
D_`00eKl00ABo5KlD_aFo0QBo005D]aBo5;lD_aBg003D_`00e;LD_aoo`0[Ool00`00Oomoo`0FOol0
0`00Oomoo`04Ool0019oo`<000eoo`2c001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lEaeBo5LmDaaG7E<L
EceC75LMFcaOGE/lGceK?5mMFcaSG5llJgaWFf]kJgY_Vf]jLiY_VG>JLiQg^7>HNkMgUW^eMiEo]7^D
Ok=gUGndNiAk/W^BNk9kTW^bNi9k/W^BNk=gTg_EMkIkeWNfMmQc^7>jKiU_Vf^JKi]WNf^LIg][Ne/L
GcaK75llFaaO?5KlEaaFo5/LE_aG7002E_`04e;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;L035oo`03001oogoo01Eoo`03001oogoo00Aoo`0057oo00<007ooOol037oo0P0000Ioodkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m
00QC7E;mDaeBoE<MD_eC7E;m1U<M0eLM00AG75LMEaeG?@=K?09O?0=OG005GcaOG6]jKiY[NP03LiT0
1G>HMiQgV7^gMiH00g^e00QkU7^dNkEk]7^DNi=kTW^b0g^B00Ek/W^BNk9k/g^e00=g]P9g^09c^@05
Ki][VVnJIg][N`02Ig/2He`00e/lGcaK?003Fa`015KlEaaFo5LL15Kl00IBo5KlD_aFo5;lE_`8D_`f
Ool00`00Oomoo`0DOol00`00Oomoo`04Ool002Eoo`2m001oodklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aK
?ELLEceG75/mEaaG?ELLHeaO?6=LGcaSG5llHeaSFfMlHe]cVVnILiY_VGNhLiQg^7NFNkMgUG^fMiIk
]gNENkIkU7^dNi9o/g^BOk=kTW^bNi9k/gNCNkAkTW^cMi=keGNdNmIg]WOHLkQgf6MkJiaWNfMlHe]W
O6=KIgaG75/lFaaK?5LLFcaFo5LLD_aG75KlEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;L03Yoo`03001o
ogoo01Eoo`03001oogoo00=oo`009Woo00<007ooOol00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@AC7@0:EaeC
7ELMEaeG?ELLEaeK?5/mFa`3Ge`01EllHeaSG6=LHe/00VMk01E[NfMkMiQgV7NhMiIg]gNHMkQgUWNg
MiMk]G^DNkAkTg^bNi9kTg^BNk800g^B00=k/g^BNk<00W^c00Ak]7^eMkIk]P9g^003LkUc^W>i00=S
G004He]O?5llHe`4Fa`00eLLFaaFo005E_`015;lE_aBo5Kl0e;l00=Fo7ooOol0>goo00<007ooOol0
57oo00<007ooOol00goo000WOol0]`00Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMDaaG7E;lEaeG75/mEaaK?ELL
FceG75/mHe]SG6=KIgaSFf]kIe][O6MKKi][NVnKKiUcVW>HMkQcV7^gMiIk]W^ENkAkTgncNi9k]7^B
Ok=kTW^bNi9k]7^BNk=gTg^dMkAk]GNfNmMc^7OHKiUc^VnIKi][VVnKGcaSG5lkHeaO?6=LE_aK75LL
FaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg010Ool00`00Oomoo`0COol00`00Oomoo`03Ool002Qo
o`800005OomBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eB
oE;mDaeBoE<MD_eC7E;m0e<M011BoE<MDaeG7E<MEaeC7ELMEaaG7E/lFceK75/mFcaK?@9K?09SG009
He]WNfMkJg]WNfmjJgY_VVnI009cV@0=MkQcV7NgMiMk]g^ENkAkU7^cNiAk]7^CNk<00g^B00=k/W^B
Nk800g^c00=k]G^dNkH00WNh00=c^G>jLkT00VnJ00E_VfMkIg]O?6=L009O?004FcaO?5LLFa`2Ea`0
1EKlEaaFo5KlD_`00UKlAWoo00<007ooOol04Woo00<007ooOol00goo000ZOol0Z`00OomC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeB
o5LMDaaG?E<LEaeC75LmEaaK?ELLGeeK?5lmFcaOGE/lJg]WFf]lIe]_Vf]jKi][NW>JKiUg^7>HMkQg
UW^gNiEk]G^COkAkUG^dNi=o/g^BNk9kTW^cNi9k/W^BNkAk/g^eMkAkegNfMmQ_VG>jKiU_Vf^JJiaW
Nf]kIg][W5/LGcaK75llFaaO?5KlFaaFo5LLE_aK701:Ool00`00Oomoo`0BOol00`00Oomoo`03Ool0
02]oo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eB
oE;mDaeBoE<MD_eC7E;m1U<M00=G7ELLEad00ULM00AG75LMFcaO?0=K?00:GcaK?5mLGea[NfMkKgY[
NVnJJgX3LiT03G>HMiQgUg^gMiIk]G^DNkAkUG^dNiAk/g^C009kTP0>Nk9kTW^BNi9k/W^cNkEk]7^e
MkIk]GNfNkIg]P9_VP0:Jg]WNfMkIg][Nf=KHeaK?5llFc`3Fa`00eKlEaaFo01=Ool00`00Oomoo`0A
Ool00`00Oomoo`03Ool002aoo`2:001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7E;lDae>o5<MD_aC7DklEaeBo5LMD_aG7E;lEaeC75LmDaaG?ELLFceK?5lmFcaOGEllHeaO
?6=LGca_Vf]jKi][NW>JKiUcVW>HMkQgUW^gMiIk]GNEOkAkUG^eNi=o]7^CNk9kTW^bNi=k/W^B0g^c
01Qg]7_ENk=k/gNdNmMg]WOHLkMc^VnIJg]WNfMlHe]WO6=KIgaK75/lEaaK?5/LFca@Ool00`00Oomo
o`0@Ool00`00Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@IC7@06EceG75LMEaeG?ELL0ULM00=OG5llGe`0
0UmL00EO?6=LHeaSG6=K00=cV@0<KiUgV7NHNkMgUWNgNkEk]gNFNkEkU7^d0W^C00=kTW^cNi<00W^B
00Uk/W^BNk=kTW^bNi9k/g^dNkH00WNf00=g^7>jLkT00W>i00=SG6=KHe`00V=L0ellEGoo00<007oo
Ool047oo00<007ooOol00Woo000_Ool0W000Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E<LEaeBo5LMDaaG?ELLFceG75LmEaaK?ELLHeaO?6=LHe]S
G6=KIgaSFf]kIe][O6MKMkQcV7^gMiIk]g>HMkQgUW^eMiEo]7^DOk=kTWndNi=o/g^BNk9kTW^cNi9k
/g^BNk=gTg_EMkIkeW>gMmQ_VG>jKiU_Vf^JKi]O>f=LGcaSG5Moo`03001oogoo011oo`03001oogoo
009oo`00<7oo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d04U<MC_eBoE;mDaeBoE<MD_eC
7E;mDaeBoE<MD_eC7E;mDaeBo@9C7@0>EaeC7ELMDaeG7E/LFceK?5/mFaaK?E/lFceSF`=SG00AHe]W
NfMkJg]WNfmjJgYcVFnILiUgV7NhMiIg]g^ENkEkU002Ni<03G^bNi=kTg^BNk9kTW^bNi9k/W^BNk9k
/g^e009g]P9g^0=c^@06Ki][VVnJIg][NfMkFWoo00<007ooOol03goo00<007ooOol00Woo000aOol0
U`00Oomooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG
7E<LEaeBo5LmDaaG7ELLFceG75/mEaaOGE/lGceSFfMlIe][NfMKJgaWFfnKJgY_VfnILiYcV7NhLiQk
]gNENkIkU7^dNi9o/g^DOk=kTWncNi9k/g^BNk9kTW^cMi=k]7NdNmIg]WOHKiUc^VnIKi][VV]kIg][
W6Mk05aoo`03001oogoo00ioo`03001oogoo009oo`00<Woo00D007ooOomC7Dkm009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d03U<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMEa`00eLM00AG
75/lFcaO?0=K?00:GcaWNfMkIg][Nf]jKgY[NVnJKiT2LiT03GNhLiQg]gNGNkEkUG^dNi=k/g^ENkAk
Tg^b00=kTP06Nk9kTW^bNi9k/g^d0WNf00Ik]GNfMkIg]VnKJiX2Ig/00f]kOomoo`1LOol00`00Oomo
o`0>Ool00`00Oomoo`02Ool003=oo`800024OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeB
o5<MC_aC7E;lDaeBo5<MD_aG7E;lEceC75LMDaaG?ELLEceG75mMFcaO?E/lGeeO?6=LGcaSG6]jKi][
NVnKKiUcVVnIMkQcV7NhMiIk]W^ENkAkTg^fNiEk]7^BOk=kTW^bNi9o/g^BNk=kTW^d0W^c00YgTg^d
MkAkeWNfMmQc^7>jKiUc^V1oo`03001oogoo00eoo`03001oogoo009oo`00=Goo00@007ooDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@MC7@03EaeG?ELL009G7@06
EceG75/lFcaOG5ll0emL00ESFf=LJgY_VV]j009cV@0=MkQcV7NHMiMk]g^ENkEgUg^gNiEk]G^DNk<0
0g^B00Mk/W^BNi9kTW^bNk=k/P02Nk<00g^dMkIg]P02MkP2LkT00g>jOomoo`1POol00`00Oomoo`0<
Ool00`00Oomoo`02Ool003Ioo`20001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>
o5<MD_aG7E;lEaeBo5LMD_aG7ELLEceG75/mEaaG?ELLHeaO?6=LGcaSG6=KHeaSFfMlHe]cVVnIMkQc
V7NhLiQk]g>HMkQgUW^gNiEk]G^COk=kTg^bNi9o/g^BNk9kTP9k/`0;Nk9kTW^dNk=k]GNfNmMc^7OH
KiUc^P1TOol00`00Oomoo`0;Ool00`00Oomoo`02Ool003Moo`04001ooe<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00aC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_d2Dad015LMDaeG7E<M0ULM00IG?ELLEaeK?5/m
Fa`2Ge`00f=LHe]SG002He`02F=KIg]WNfnJJgY_NV]jLiUcV002MiP01W^gMiIk]G^ENkAkT`9kTP05
NkAkTg^BNi9k/P03Ni82Nk<00g^eMkIk]P02MkP00g>iLkYoo`1TOol00`00Oomoo`0<Ool00`00Oomo
o`01Ool003Qoo`80001nDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG
7E<LEaeBo5LMEaaK?ELLFceG75/mEaaWO6=KHeaSFfMlHe][NfMKKi][NVnKJgYcVVnIMkQcV7^gMiIk
]GNEOkAkU7ncNi=o]7^CNk9kTW^cNi9k/W^B0g^c00Ig]7_GLkQgf6nILkYWOol00`00Oomoo`0;Ool0
0`00Oomoo`01Ool003Yoo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M
015BoE<MDaeG7E<MEaeC7ELMEaaG7E/lFceK75/mFcaO?5/l00=SG0=WN`06Jg][NVmjJgYcVFnI0WNH
00eg^7NFMkMkUG^eNiAkTg^ENkAkU7^CNi9k/P03Ni8017^bNi9k/g^d0W^c00=k]GNfNmH0JGoo00<0
07ooOol02Woo00<007ooOol00Goo000kOol0O`00Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aC7E;lDaeBo5LMDaaG?E<LEaeC75LmDaaO?E/lGeeK?5lmFcaOGFMKJg]WFf]lJgY_Vf]jLiY_VG>J
LiQg^7NFNkMgUG^fNiAk]7NEOkAkU7ncNi9o/g^CNk9kTW^bNi9k/gNC009k/`04NkEg]7_GMkIZOol0
0`00Oomoo`09Ool00`00Oomoo`01Ool003aoo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeB
oE<MD_eC7E;m1U<M00=G7ELLEad00ULM00AG75LMEaeO?0=K?003GeaO?5mL009OG00DJgY_NV]jLiU_
VG>IMiQg^7NFMkMgUg^eNiEk]7^ENkEkU7^dNi=k/P=kTP05Nk9kTW^bNk=k/P02Nk<00g^dNmIg]P1[
Ool00`00Oomoo`09Ool00`00Oomoo`01Ool003eoo`80001oOomC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
C_aC7E;lEaeBo5LMD_aG7ELLFceG75LmEaaK?ELLHeaO?6=LGcaSG5llHeaSFf=LHe]cVVnILiY_VGNh
LiQk]gNFNkIkUG^gMiIk]W^DNkAkTWncNi9o/g^BOk=kTW^cMi=k/W^BNk=g]7_EMkH0KGoo00<007oo
Ool027oo00<007ooOol00Goo000oOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeB
o@AC7@04EaeC7ELMEa`2Ead01ULmFaaK?E/lGeaO?09OG005HeaSFf=LHea[N`03Ig/04GNhLiQg]gNG
NkMcV7NgMiMk]G^ENkAkU7^cNi9k]7^CNk800g^B00Ek/W^BNk=k/g^e009g]Vioo`03001oogoo00Mo
o`03001oogoo005oo`00@7oo07d007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeC75LMD_aG7E<L
EaeBo5/mEaaK?ELLFceG75/mHe]WO6=KHeaSFf]lIe][NfMKKi][NW>JKgUcVW>HMkQgUW^gNiEk]G^C
Ok=kTg^dNi9o/g^BNk9kTWncNi9k/gNCNmEg]7_F071oo`03001oogoo00Moo`40005oo`5oo`00@Goo
00H007ooOomBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMDad00eLM00UG75/mFcaK?E/L
FceK?5llHe/00V=L00I[NfMkIg]WNfnJJgX3LiT037>HMiQgUg^gNiEk]G^DNkAkTg^eNiAk/`=kTP03
Nk9kTW^b009k/`03NkAk/g^c071oo`03001oogoo00Moo`40005oo`5oo`00@Woo0P0007QoodkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>
o5<MD_aC7E;lDaeBo5<MD_aC7E<LEaeC75LmDaaG7ELLFceG75lmFcaOGE/lGceK?6]lIe][Nf]jKi][
NVnKKgUcVVnIMkQcV7^gMiIk]GNEOkAkUG^eNi=o/g^BNk9kTWncNi9k/W^BNkAkTW^cMi=bOol00`00
Oomoo`06Ool10001Ool1Ool004Aoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d5Dad2Ead015LL
EaeG7ELM0e/l00]O?5/lFcaK?5mLGcaOG6]jKiY[NVmj009cV@0@KiUgV7NHNkMgUW^eNiEk]7NFNkEk
UG^dNi=kTW^CNk<3Ni800g^cNi9k/P02Nk=cOol00`00Oomoo`05Ool10001Ool1Ool004Eoo`1f001o
odkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7E;lEceG75/mEaaG?E/lGeeK?5lmGcaSG5llHeaSFfMlHe]S
G6miLiY_VGNhLiQg^7NFNkMgUG^fMiIk]GNEOkAkU7ncNi=o/g^CNk9kTW^cNi9k/g^BNkAdOol00`00
Oomoo`05Ool10001Ool1Ool004Ioo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00AC7E;mDaeBo@IC7@04EaeC7ELmEa`2
Ead00eLmEaaOG002Ge`02EllGeaSG6=LHe]SG6MkJg]WN`02MiP03WNhMiIg]gNHMkQgUWNgNiEk]G^D
Ni=kTW^cNi<2Ni8017^bNi9kTW^B0W^cMGoo00<007ooOol017oo0@000Goo0Goo0017Ool20000Kgoo
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
Dae>o5<MD_aC7E;lEaeC75LMD_aG7E<LEceG75/mEaaK?ELLHeaO?6=LHe]WO6=KHeaWFf]lIe]_Vf]j
Ki]_VG>JLiQg^7>HNkMgUG^fNiAk]7^BOkAkTgncNi9k/W^BNk9kTP02Nk=gOol00`00Oomoo`03Ool1
0001Ool1Ool004Uoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m15<M00eG7E<MEaeC7ELMDaeK?E/LFceK?5/mFaaK
?@02He`02F=KIg]WNf]kIg]_NV]jKiY_V@02LiT03GNhLiQg]gNGNkEkUG^dNi=k]G^DNi=kTW^b00=k
TP03Nk9k/g^c07Qoo`03001oogoo00=oo`40005oo`00BWoo06l007ooDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEceC75LM
DaaG?E<LFceG75/mEaaO?E/lGeeK?6]kIe][O6MKJg][NVnKJgYcVVmiMkQcV7^gMiIk]W^ENkAkTg^f
NiAo/g^BOk=kTWncNi9k/W^BNk<0NGoo00<007ooOol00goo0@000Goo001;Ool01000OomC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@03
D_eC7E<M009C7@=G7@04EaaG7ELMGc`3Fc`01EllFcaOG5mLJg/00VMk00=[NVnJJgX00W>I01Ag^7>H
MkMgUg^gNiEk]G^DNkEkUG^dNi=k/W^BNi=kTW^bNi9k/g^BNWoo00<007ooOol00Woo0@000Goo001<
Ool20000JU<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC
7DklDaeBo5LMD_aG7E;lEaeBo5LmDaaG7ELLFceG75lmFcaOGEllHeaO?6=LGcaSG6]jKi][NW>JKgUc
VW>HMkQgUW^gNiEk]GNFNkMkUG^dNi9o/g^BNkAkTWncNi9k/g^BO7oo00D007ooOomoo`00005oo`00
CWoo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<M
D_eC7E;mDaeBoE<MD_d6Dad2Ead01ULmEaaG7ELMEceO?0=OG005GcaOG6=LHeaSF`03LiT057>HMiQg
Ug^gMiIgV7NGNkMkUG^eNiAk/g^BNkAkTg^bNi9k/W^BNk9mOol01000Oomoo`000Goo001?Ool0J000
Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
EaeBo5LMDaaG7E;lFceG75LmEaaK?ELLFceO?6=LGcaSG6=KIgaSFf]kIe][O6]jKi]_NG>JKiUg^7>H
NkMgUW^fMiEo]7^CNkAkTgncNi9k/W^BNk9nOol01000Oomoo`000Goo001@Ool00`00Oom>o@02D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00iG
7E<MEaeC7ELMDaeK?E/lFceK75/mFcaK?F=K0f=L16Mk00E[NVmjJgYcVFnI009gV00>NkMgUW^eNiEk
]7^CNkEkU7^cNi=kTW^CNk9kTWmoo`03001oo`00005oo`00DGoo0P0006A>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E<LFceG75/m
EaaOGE/lGceK?5mMIe][NfMKJgaWFfnKJgYcVVnILiYcV7NhMiIk]gNENkIkU7^fNi=o]7^CNk9kTWnc
Ni9k/X1oo`40005oo`400000Dgoo00H004kmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03
D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeG7003Ead015LLEaeK?5ll0e/l0Ull01=OG6MkIg]W
NfmjJgYcVFnILiUgV7NhMiIg]g^ENkEkU7NgNiEk]002Ni<017^BNk=kTW^BPWoo0P00001DOol0HP00
OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LM
DaaG?E<LEceG75/mFcaO?E/lHeaO?6=LGcaSG5llKi][NVnKKiUcVW>HMkQcV7^gMiIk]W^ENkMgUGnd
NiAo/g^BOkAkTg^cNi:2Ool2000005Eoo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;m
Dad00e;m00IC7E;mDaeBoE<MD_d7Dad01ELLEaeG7ELmEa`00ULM00IOG5llGeaO?5mLGc`3He`03FnI
LiUgV7NhLiQg]gNGMiQcV7NgMiMk]G^D009kT`04NkAkTg^BNi:3Ool2000005Ioo`1O001oogooC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeC75LMD_aG7E<LEaeG75/mEaaG
?ELLFceG76=LGcaSG6=KHeaSFfMlIe][Nf]jKi][NW>JKgUg^7>HMkQgUW^fNiAk]7^BNkIkU7ncNi9k
/P1oOol40002Ool005Moo`800004OomBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<M
D_eC7E;mDaeBo@9C7@0>EaeC7ELMDaeG7E/LFceK?5/mFaaK?E/lHeaSF`9SG0=WN`03JgY_VV]j00=c
V@0=LiQgV7NGNkMkUG^dNiEk]G^DNi=kTW^bNi<0Ngoo10001Woo001IOol0F`00Oom>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeBo5LMDaaG7ELLFceG75/mFcaOGE/l
GceK?6]lIe][Nf]jKi][NVnKKgUcVW>HMkQgUW^gNiEk]7NFNkIkUG^dNi9o/g^C07Qoo`@000Yoo`00
FWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELM
EaeG7003Ead015LLFcaK?5ll0e/l00MOG5llGea[NVnJJgY_NP02LiT03W>HMiQgUg^gMiIk]GNGNkEk
UG^dNiAk/g^DNi=dOol4000>Ool005]oo`1H001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E;lEaeBo5LMDaaG7E<LEaeG75LmEaaOGE/lGceO?6=LGcaSG6=KIgaSFf=LKgUcVVnIMkQc
V7^gMiIg^7>HNkMkUG^fNi=o/g^BOk=aOol4000BOol005aoo`800003OomC7Dkm009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00QC7E;mD_eBoE<MD_eC7E;m1e<M00=G7ELmEa`00ULM00IG?ELLGeaO?5mLGc`3He`00f=KHeaWN`02
Ig/2MiP037>IKiUgV7NHNkMkUG^eNiEk]7^CNkAkTfioo`<001Ioo`00GWoo05D007ooDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E<LEaeBo5LMEaaG?ELLFceG75/mEaaK?ELLHeaSFfMlHe]S
G6MKJgaWFfnKJgYcVVnILiYcV7NhMiIk]WNEOkAkTg^fNi9o/`1ZOol4000IOol005moo`04001ooe<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<M
C_eBoE;mDae>oE<MD_eC7E;mDaeBoE<MD_d3Dad03E;mEaeC7ELMDaeG7E<MFceK75/mFcaK?E/L009K
?003HeaSFfMk00=WN`05KgY[NW>IKiUcV@02MiP027NFNkEkUG^eNiAk]G^DNk=WOol4000MOol0061o
o`1B001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LFceG75/mFcaO
?E/lGeeK?6]kIe][O6MKKi][NVnKKiUcVVmiMkQcV7^gMiEk]W^DNkMgUGndNi=SOol4000QOol0065o
o`800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>
oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m1E<M0ULM00AG75LMEaeO?0=K?00:GcaK?5mL
GcaOG5llKgY[NVnJKiT2LiT02WNHLiQg]g^ENkEkUGNgNiEk]7^CH7oo10009Goo001SOol0CP00Dae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aG7ELLEceG75/mEaaO?E/lGeeO?6=LGcaSG5llHeaS
FfMlKiUcVVmiLiYcV7NhMiIg^7>HNkMgUW^fNiAo/eeoo`<002Uoo`00I7oo00<005<MC_d00U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M
00=Bo@04DaeBoE<MD_d4Dad01ULMDaeG7ELMEceG709G7@06EceO?5mLGcaOG6=K0f=L16Mk00]cV7NH
LiUgV7>HMiQgUg^eNiAkTg^E05Uoo`@002aoo`00IGoo04/007ooC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeB
o5LMDaaG7E;lEaeC75/mEaaK?ELLFceG76MlHe]SG6=KIgaWFf]kIe][O6]jKi]_NG>JLiQg^7NFNkMk
UG^dMiD0EWoo1000<7oo001VOol200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@AC7@04EaeC7ELMEa`2Ead0
1U/mFaaK?E/lGcaK?0=SG0AWN`0<JgY_NW>ILiUcV7NHMiMk]g^ENkAgUg^eDWoo1000=7oo001XOol0
A`00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeC75lmFcaOGE/lGceK?5mMIe][NfMKKi][
NVnKJgYcVW>HMkQgUW^gMiIk]WNFNkH0Cgoo1000>7oo001YOol01P00OomBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@EC7@05
EaaG7ELMEaeG7002Ead03UllFcaK?5/lGeaO?5mLGca_VV]jKgY[NW>IKiT2MiP01W^gMiIgV7NGNkMk
UD]oo`@003aoo`00JWoo04@007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aK?ELLEceG75/mEaaG?EllHeaO
?6=LGcaWO6=KHeaSFg>JKiUg^7>HLiY_VGNhLiQk]g^EBGoo0`00@7oo001[Ool20002D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeB
o@9C7@04EaeC7ELMDad2Ead01eLmEaaK?E/lFceO?5mL009SG003He]SG6=L009WN`09KgY[NW>IKiUc
VGNHNkMgUW^e04Eoo`@004=oo`00KGoo040007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lFceG75/mEaaK?ELL
FceSFfMlHe]SG6MKJgaWFfnKJgYcVVnILiYcV7NhMiIk]T9oo`@004Moo`00KWoo00D007ooD_eC7Dkm
009Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<M
DaeG7E<M00=G7@05EaaK?E/lFceK7002Fc`00ellFcaWN`03Ig/01FmjJgY_VVnILiT00WNH00=gUWNg
NiD0?Woo1000Bgoo001_Ool0?@00Oomooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7E/lGceK?5lmFcaSG5llHeaO
?6nKJgY_VfnILiY_NGNhLiQk]gNE03]oo`@004moo`00L7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d8Dad2Ead015LmEaaG7E/l0Ull00AO
G5llGeaO?0=SG008KiUcVG>IMiQcV7NgMiMgV3Qoo`<005=oo`00LWoo03T004kmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeC75LMD_aK?ELL
EceG75/mGcaSG5llHeaSFf=LHe]WO6MKJg]WFfnKJgYcVVmiMkP0=Goo1000EWoo001cOol01000D_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad03ULM
DaeG7E<MEaeC7E/mFcaK?E/LFceK?5/mHe/2He`4Ig/00fnJJgYcV@02LiT00g>HOomoo`0_Ool4001J
Ool007Aoo`0f001>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MD_aC7E<LEaeBo5LMDaaG7E<LFceG75/mEaaO?E/lGceK?6]lIe][NfMKKi][NVnKKgUcVW>H;Woo
1000GWoo001eOol200001U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeB
o@=C7@05D_eC7E<MEaeG7003Ead015LLFcaK?5ll0e/l00MOG5llIg]WNfnJJgY_NP02LiT00g>HMiQo
o`0YOol4001ROol007Moo`0b001C7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
Dae>o5<MD_aG7E;lEaeBo5LMDaaG7ELLEceG75lmFcaO?EllHeaO?6=LGca_Vf]jKi]_NG>JKiUg^2Mo
o`@006Ioo`00N7oo00<005<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC
7E;m1U<M00]G?ELLEaeG7ELmEaaG7EllGeaO?5mL009SG003He]SG6Mk009WN`03KgYoogoo02=oo`<0
06Yoo`00NGoo02h005<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeC
75LMD_aG7E<LEceG75/mEaaK?ELLFceG76=LHe]WO6=KHeaWFf]lIe]_Vb9oo`@006eoo`00NWoo00<0
07ooC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;mDaeBo@=C7@0<D_eC7E<MEaeC7ELMDaeG
7E/LFceK?5/m0e/l00=SG6=KHe`00fMk00=_NV]jOol07Goo1000LGoo001kOol20000:DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaO?E/lGceK?5lm
FcaO?FMKJgaWFfnKJgX06goo1000MGoo001mOol01P00C_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;m
DaeBoE<MD_d6Dad01ULMEaaG7ELMEceG709K?008GcaK?5mLGcaOG5llKgY[NQQoo`@007Uoo`00OWoo
02H004klDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG?ELLFceG75Lm
EaaSG5llHeaO?6=LHe]SG6=K5Goo1000OGoo001oOol01P00OomBoE;mDae>o@9Bo@0:DaeBoE;mD_eC
7E;mDaeBoE<MD_d2Dad03ULMDaeG7E<MEceG75LMFcaK?E/LFceK?6=LHe/2He`COol30021Ool0081o
o`80000PDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E<LEaeBo5LMDaaK?ELLFceG75/m
FcaO?E/lHeaSFa1oo`@008Aoo`00PWoo00@005;mD_eC7@=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<M
EaeG7ELL00=G7@04EaaK?5/lGc`3Fc`=Ool40028Ool008=oo`0L001C7DklDae>o5<MC_aC7DklDaeB
o5<MD_aC7E;lEaeBo5LMDaaG7E<LEaeG75LmEaaO?E/lGcd;Ool4002<Ool008Aoo`04001ooe;mDad3
D_d015<MD_eC7E;m25<M00IG?ELLEaeG7ELmEa`9Ool4002@Ool008Eoo`80000DC_aC7DklDae>o5<M
C_aC7E;lDae>o5<MDaaG7E;lEaeC75LmEaaK?@Qoo`<009Aoo`00Qgoo00`005;mDaeBoE<MD_eC7E;m
DaeBoE<MD_d2Dad015LMDaeG7E<M1Woo1000Ugoo0028Ool03@00C_aC7DklDae>o5<MD_aC7E;lDaeB
o5<M00Ioo`@009]oo`00RGoo00P007ooDaeBoE<MD_eC7E;m1Woo1000Wgoo002:Ool200000e<MC_aC
7@04Ool4002SOol008aoo`800003Ool0000000800:Moo`00SGoo0P00Zgoo003oOolkOol00?mooc]o
o`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.651 .765 .933 r
.38973 .79884 .39807 .80554 .41197 .80166 .40368 .795 Mtetra
.655 .768 .933 r
.40368 .795 .41197 .80166 .42595 .79758 .41771 .79099 Mtetra
.662 .773 .931 r
.41771 .79099 .42595 .79758 .44001 .79309 .43181 .78668 Mtetra
.677 .782 .929 r
.43181 .78668 .44001 .79309 .45415 .78789 .44599 .78185 Mtetra
.702 .798 .924 r
.44599 .78185 .45415 .78789 .46837 .78138 .46026 .77603 Mtetra
.743 .823 .914 r
.46026 .77603 .46837 .78138 .48268 .77252 .47461 .76845 Mtetra
.805 .859 .89 r
.47461 .76845 .48268 .77252 .49704 .7597 .48903 .75778 Mtetra
.878 .897 .841 r
.48903 .75778 .49704 .7597 .51144 .7408 .50351 .74211 Mtetra
.941 .922 .764 r
.50351 .74211 .51144 .7408 .52578 .71408 .51798 .7193 Mtetra
.972 .925 .675 r
.51798 .7193 .52578 .71408 .53998 .68016 .53236 .68853 Mtetra
.976 .919 .608 r
.53236 .68853 .53998 .68016 .55399 .6434 .54655 .65228 Mtetra
.969 .921 .592 r
.54655 .65228 .55399 .6434 .56785 .61002 .56056 .61634 Mtetra
.964 .939 .644 r
.56056 .61634 .56785 .61002 .58166 .58398 .57446 .58625 Mtetra
.944 .951 .747 r
.57446 .58625 .58166 .58398 .59551 .56553 .58837 .56405 Mtetra
.886 .924 .842 r
.58837 .56405 .59551 .56553 .60947 .55283 .60236 .54866 Mtetra
.811 .868 .89 r
.60236 .54866 .60947 .55283 .62353 .54381 .61645 .53797 Mtetra
.75 .818 .906 r
.61645 .53797 .62353 .54381 .63769 .53694 .63065 .53011 Mtetra
.711 .785 .909 r
.63065 .53011 .63769 .53694 .65196 .53125 .64495 .52387 Mtetra
.689 .765 .909 r
.64495 .52387 .65196 .53125 .66631 .5262 .65934 .51849 Mtetra
.677 .754 .909 r
.65934 .51849 .66631 .5262 .68074 .52147 .67382 .51357 Mtetra
.671 .748 .908 r
.67382 .51357 .68074 .52147 .69526 .51691 .68838 .50889 Mtetra
.667 .745 .908 r
.68838 .50889 .69526 .51691 .70985 .51242 .70303 .50432 Mtetra
.666 .743 .908 r
.70303 .50432 .70985 .51242 .72452 .50796 .71775 .4998 Mtetra
.665 .742 .908 r
.71775 .4998 .72452 .50796 .73927 .5035 .73255 .49529 Mtetra
.664 .742 .908 r
.73255 .49529 .73927 .5035 .75409 .49904 .74743 .49078 Mtetra
.74743 .49078 .75409 .49904 .76899 .49456 .76238 .48625 Mtetra
.664 .741 .908 r
.76238 .48625 .76899 .49456 .78397 .49006 .77742 .48171 Mtetra
.77742 .48171 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84469 .47184 .83836 .46331 Mtetra
.83836 .46331 .84469 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.649 .765 .933 r
.38132 .79207 .38973 .79884 .40368 .795 .39532 .78823 Mtetra
.652 .766 .933 r
.39532 .78823 .40368 .795 .41771 .79099 .40939 .78427 Mtetra
.658 .77 .932 r
.40939 .78427 .41771 .79099 .43181 .78668 .42353 .78008 Mtetra
.669 .777 .931 r
.42353 .78008 .43181 .78668 .44599 .78185 .43776 .77551 Mtetra
.687 .789 .927 r
.43776 .77551 .44599 .78185 .46026 .77603 .45207 .7702 Mtetra
.72 .809 .92 r
.45207 .7702 .46026 .77603 .47461 .76845 .46646 .76357 Mtetra
.772 .84 .904 r
.46646 .76357 .47461 .76845 .48903 .75778 .48094 .75458 Mtetra
.841 .879 .869 r
.48094 .75458 .48903 .75778 .50351 .74211 .49549 .7416 Mtetra
.912 .912 .806 r
.49549 .7416 .50351 .74211 .51798 .7193 .51006 .7225 Mtetra
.961 .926 .719 r
.51006 .7225 .51798 .7193 .53236 .68853 .52459 .69552 Mtetra
.976 .922 .637 r
.52459 .69552 .53236 .68853 .54655 .65228 .53897 .66129 Mtetra
.973 .918 .592 r
.53897 .66129 .54655 .65228 .56056 .61634 .55316 .62421 Mtetra
.966 .928 .609 r
.55316 .62421 .56056 .61634 .57446 .58625 .56719 .59055 Mtetra
.957 .948 .692 r
.56719 .59055 .57446 .58625 .58837 .56405 .58116 .56427 Mtetra
.92 .943 .8 r
.58116 .56427 .58837 .56405 .60236 .54866 .59519 .54563 Mtetra
.848 .897 .871 r
.59519 .54563 .60236 .54866 .61645 .53797 .60931 .53277 Mtetra
.778 .841 .9 r
.60931 .53277 .61645 .53797 .63065 .53011 .62354 .52362 Mtetra
.728 .799 .908 r
.62354 .52362 .63065 .53011 .64495 .52387 .63788 .51663 Mtetra
.699 .773 .909 r
.63788 .51663 .64495 .52387 .65934 .51849 .65231 .51083 Mtetra
.682 .759 .909 r
.65231 .51083 .65934 .51849 .67382 .51357 .66684 .50567 Mtetra
.673 .75 .909 r
.66684 .50567 .67382 .51357 .68838 .50889 .68145 .50083 Mtetra
.669 .746 .908 r
.68145 .50083 .68838 .50889 .70303 .50432 .69614 .49616 Mtetra
.666 .744 .908 r
.69614 .49616 .70303 .50432 .71775 .4998 .71092 .49156 Mtetra
.665 .743 .908 r
.71092 .49156 .71775 .4998 .73255 .49529 .72577 .487 Mtetra
.664 .742 .908 r
.72577 .487 .73255 .49529 .74743 .49078 .7407 .48243 Mtetra
.7407 .48243 .74743 .49078 .76238 .48625 .75571 .47786 Mtetra
.664 .741 .908 r
.75571 .47786 .76238 .48625 .77742 .48171 .7708 .47327 Mtetra
.7708 .47327 .77742 .48171 .79253 .47714 .78597 .46866 Mtetra
.78597 .46866 .79253 .47714 .80773 .47255 .80122 .46403 Mtetra
.80122 .46403 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.648 .764 .933 r
.37283 .78522 .38132 .79207 .39532 .78823 .38687 .78137 Mtetra
.651 .765 .933 r
.38687 .78137 .39532 .78823 .40939 .78427 .40098 .77743 Mtetra
.655 .768 .933 r
.40098 .77743 .40939 .78427 .42353 .78008 .41517 .77333 Mtetra
.662 .773 .931 r
.41517 .77333 .42353 .78008 .43776 .77551 .42944 .76893 Mtetra
.677 .782 .929 r
.42944 .76893 .43776 .77551 .45207 .7702 .4438 .76399 Mtetra
.702 .798 .925 r
.4438 .76399 .45207 .7702 .46646 .76357 .45824 .75806 Mtetra
.743 .823 .914 r
.45824 .75806 .46646 .76357 .48094 .75458 .47276 .75036 Mtetra
.805 .859 .89 r
.47276 .75036 .48094 .75458 .49549 .7416 .48737 .73954 Mtetra
.878 .897 .841 r
.48737 .73954 .49549 .7416 .51006 .7225 .50202 .72368 Mtetra
.941 .922 .764 r
.50202 .72368 .51006 .7225 .52459 .69552 .51668 .70065 Mtetra
.972 .925 .675 r
.51668 .70065 .52459 .69552 .53897 .66129 .53124 .66959 Mtetra
.976 .919 .608 r
.53124 .66959 .53897 .66129 .55316 .62421 .54562 .63302 Mtetra
.969 .921 .592 r
.54562 .63302 .55316 .62421 .56719 .59055 .5598 .59677 Mtetra
.964 .939 .644 r
.5598 .59677 .56719 .59055 .58116 .56427 .57388 .56641 Mtetra
.944 .951 .748 r
.57388 .56641 .58116 .56427 .59519 .54563 .58796 .544 Mtetra
.886 .923 .842 r
.58796 .544 .59519 .54563 .60931 .53277 .60211 .52844 Mtetra
.811 .868 .89 r
.60211 .52844 .60931 .53277 .62354 .52362 .61637 .5176 Mtetra
.75 .818 .906 r
.61637 .5176 .62354 .52362 .63788 .51663 .63075 .50962 Mtetra
.711 .785 .909 r
.63075 .50962 .63788 .51663 .65231 .51083 .64522 .50326 Mtetra
.689 .765 .909 r
.64522 .50326 .65231 .51083 .66684 .50567 .65979 .49777 Mtetra
.677 .754 .909 r
.65979 .49777 .66684 .50567 .68145 .50083 .67445 .49274 Mtetra
.671 .748 .908 r
.67445 .49274 .68145 .50083 .69614 .49616 .68919 .48795 Mtetra
.667 .745 .908 r
.68919 .48795 .69614 .49616 .71092 .49156 .70402 .48327 Mtetra
.666 .743 .908 r
.70402 .48327 .71092 .49156 .72577 .487 .71892 .47863 Mtetra
.665 .742 .908 r
.71892 .47863 .72577 .487 .7407 .48243 .73391 .47401 Mtetra
.664 .742 .908 r
.73391 .47401 .7407 .48243 .75571 .47786 .74897 .46939 Mtetra
.74897 .46939 .75571 .47786 .7708 .47327 .76412 .46475 Mtetra
.664 .741 .908 r
.76412 .46475 .7708 .47327 .78597 .46866 .77935 .46009 Mtetra
.77935 .46009 .78597 .46866 .80122 .46403 .79466 .45541 Mtetra
.79466 .45541 .80122 .46403 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.648 .764 .933 r
.36425 .77829 .37283 .78522 .38687 .78137 .37834 .77443 Mtetra
.649 .765 .933 r
.37834 .77443 .38687 .78137 .40098 .77743 .3925 .7705 Mtetra
.652 .766 .933 r
.3925 .7705 .40098 .77743 .41517 .77333 .40673 .76644 Mtetra
.658 .77 .932 r
.40673 .76644 .41517 .77333 .42944 .76893 .42105 .76216 Mtetra
.669 .777 .931 r
.42105 .76216 .42944 .76893 .4438 .76399 .43545 .75748 Mtetra
.687 .789 .927 r
.43545 .75748 .4438 .76399 .45824 .75806 .44993 .75206 Mtetra
.72 .809 .92 r
.44993 .75206 .45824 .75806 .47276 .75036 .4645 .74532 Mtetra
.772 .84 .904 r
.4645 .74532 .47276 .75036 .48737 .73954 .47916 .73619 Mtetra
.841 .879 .869 r
.47916 .73619 .48737 .73954 .50202 .72368 .49389 .72305 Mtetra
.913 .912 .805 r
.49389 .72305 .50202 .72368 .51668 .70065 .50865 .70373 Mtetra
.961 .926 .719 r
.50865 .70373 .51668 .70065 .53124 .66959 .52336 .67649 Mtetra
.976 .922 .636 r
.52336 .67649 .53124 .66959 .54562 .63302 .53793 .64195 Mtetra
.973 .918 .592 r
.53793 .64195 .54562 .63302 .5598 .59677 .5523 .60456 Mtetra
.967 .928 .609 r
.5523 .60456 .5598 .59677 .57388 .56641 .56651 .57059 Mtetra
.958 .948 .693 r
.56651 .57059 .57388 .56641 .58796 .544 .58066 .54407 Mtetra
.92 .942 .8 r
.58066 .54407 .58796 .544 .60211 .52844 .59485 .52524 Mtetra
.848 .897 .871 r
.59485 .52524 .60211 .52844 .61637 .5176 .60915 .51223 Mtetra
.778 .841 .9 r
.60915 .51223 .61637 .5176 .63075 .50962 .62355 .50294 Mtetra
.728 .799 .908 r
.62355 .50294 .63075 .50962 .64522 .50326 .63806 .49583 Mtetra
.699 .773 .909 r
.63806 .49583 .64522 .50326 .65979 .49777 .65268 .48991 Mtetra
.682 .759 .909 r
.65268 .48991 .65979 .49777 .67445 .49274 .66738 .48463 Mtetra
.673 .75 .909 r
.66738 .48463 .67445 .49274 .68919 .48795 .68217 .47969 Mtetra
.669 .746 .908 r
.68217 .47969 .68919 .48795 .70402 .48327 .69705 .4749 Mtetra
.666 .744 .908 r
.69705 .4749 .70402 .48327 .71892 .47863 .71201 .4702 Mtetra
.665 .743 .908 r
.71201 .4702 .71892 .47863 .73391 .47401 .72705 .46551 Mtetra
.664 .742 .908 r
.72705 .46551 .73391 .47401 .74897 .46939 .74217 .46084 Mtetra
.74217 .46084 .74897 .46939 .76412 .46475 .75737 .45615 Mtetra
.664 .741 .908 r
.75737 .45615 .76412 .46475 .77935 .46009 .77266 .45144 Mtetra
.77266 .45144 .77935 .46009 .79466 .45541 .78802 .44672 Mtetra
.78802 .44672 .79466 .45541 .81005 .45071 .80347 .44197 Mtetra
.80347 .44197 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.647 .763 .934 r
.3556 .77128 .36425 .77829 .37834 .77443 .36972 .7674 Mtetra
.648 .764 .933 r
.36972 .7674 .37834 .77443 .3925 .7705 .38393 .76346 Mtetra
.651 .765 .933 r
.38393 .76346 .3925 .7705 .40673 .76644 .39821 .75943 Mtetra
.655 .768 .933 r
.39821 .75943 .40673 .76644 .42105 .76216 .41257 .75523 Mtetra
.662 .773 .931 r
.41257 .75523 .42105 .76216 .43545 .75748 .42702 .75072 Mtetra
.677 .782 .929 r
.42702 .75072 .43545 .75748 .44993 .75206 .44155 .74568 Mtetra
.702 .798 .925 r
.44155 .74568 .44993 .75206 .4645 .74532 .45616 .73964 Mtetra
.743 .823 .914 r
.45616 .73964 .4645 .74532 .47916 .73619 .47087 .73181 Mtetra
.805 .859 .89 r
.47087 .73181 .47916 .73619 .49389 .72305 .48566 .72084 Mtetra
.878 .898 .841 r
.48566 .72084 .49389 .72305 .50865 .70373 .5005 .7048 Mtetra
.941 .922 .764 r
.5005 .7048 .50865 .70373 .52336 .67649 .51534 .68152 Mtetra
.972 .925 .675 r
.51534 .68152 .52336 .67649 .53793 .64195 .53009 .65017 Mtetra
.976 .919 .608 r
.53009 .65017 .53793 .64195 .5523 .60456 .54466 .61328 Mtetra
.969 .921 .592 r
.54466 .61328 .5523 .60456 .56651 .57059 .55903 .57671 Mtetra
.964 .939 .644 r
.55903 .57671 .56651 .57059 .58066 .54407 .57328 .54609 Mtetra
.944 .95 .748 r
.57328 .54609 .58066 .54407 .59485 .52524 .58753 .52346 Mtetra
.886 .923 .842 r
.58753 .52346 .59485 .52524 .60915 .51223 .60186 .50772 Mtetra
.811 .868 .89 r
.60186 .50772 .60915 .51223 .62355 .50294 .6163 .49673 Mtetra
.75 .818 .905 r
.6163 .49673 .62355 .50294 .63806 .49583 .63085 .48862 Mtetra
.711 .784 .909 r
.63085 .48862 .63806 .49583 .65268 .48991 .6455 .48214 Mtetra
.689 .765 .909 r
.6455 .48214 .65268 .48991 .66738 .48463 .66025 .47653 Mtetra
.677 .754 .909 r
.66025 .47653 .66738 .48463 .68217 .47969 .67509 .47139 Mtetra
.671 .748 .908 r
.67509 .47139 .68217 .47969 .69705 .4749 .69002 .46648 Mtetra
.667 .745 .908 r
.69002 .46648 .69705 .4749 .71201 .4702 .70503 .46169 Mtetra
.666 .743 .908 r
.70503 .46169 .71201 .4702 .72705 .46551 .72012 .45694 Mtetra
.665 .742 .908 r
.72012 .45694 .72705 .46551 .74217 .46084 .7353 .4522 Mtetra
.664 .742 .908 r
.7353 .4522 .74217 .46084 .75737 .45615 .75056 .44746 Mtetra
.75056 .44746 .75737 .45615 .77266 .45144 .7659 .44271 Mtetra
.664 .741 .908 r
.7659 .44271 .77266 .45144 .78802 .44672 .78132 .43793 Mtetra
.78132 .43793 .78802 .44672 .80347 .44197 .79683 .43314 Mtetra
.79683 .43314 .80347 .44197 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42347 Mtetra
.8281 .42347 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.647 .763 .934 r
.34685 .7642 .3556 .77128 .36972 .7674 .36103 .7603 Mtetra
.648 .764 .933 r
.36103 .7603 .36972 .7674 .38393 .76346 .37528 .75634 Mtetra
.649 .765 .933 r
.37528 .75634 .38393 .76346 .39821 .75943 .38961 .75231 Mtetra
.652 .766 .933 r
.38961 .75231 .39821 .75943 .41257 .75523 .40402 .74816 Mtetra
.658 .77 .932 r
.40402 .74816 .41257 .75523 .42702 .75072 .41851 .74378 Mtetra
.668 .777 .931 r
.41851 .74378 .42702 .75072 .44155 .74568 .43308 .73899 Mtetra
.687 .789 .927 r
.43308 .73899 .44155 .74568 .45616 .73964 .44774 .73347 Mtetra
.72 .809 .92 r
.44774 .73347 .45616 .73964 .47087 .73181 .46249 .7266 Mtetra
.772 .84 .904 r
.46249 .7266 .47087 .73181 .48566 .72084 .47734 .71734 Mtetra
.841 .879 .869 r
.47734 .71734 .48566 .72084 .5005 .7048 .49225 .70402 Mtetra
.913 .913 .805 r
.49225 .70402 .5005 .7048 .51534 .68152 .5072 .68449 Mtetra
.961 .926 .718 r
.5072 .68449 .51534 .68152 .53009 .65017 .52211 .65698 Mtetra
.976 .922 .636 r
.52211 .65698 .53009 .65017 .54466 .61328 .53687 .62213 Mtetra
.972 .918 .592 r
.53687 .62213 .54466 .61328 .55903 .57671 .55142 .58441 Mtetra
.967 .928 .61 r
.55142 .58441 .55903 .57671 .57328 .54609 .56581 .55015 Mtetra
.958 .948 .693 r
.56581 .55015 .57328 .54609 .58753 .52346 .58014 .52338 Mtetra
.919 .942 .8 r
.58014 .52338 .58753 .52346 .60186 .50772 .59451 .50435 Mtetra
.848 .897 .871 r
.59451 .50435 .60186 .50772 .6163 .49673 .60898 .49117 Mtetra
.778 .841 .9 r
.60898 .49117 .6163 .49673 .63085 .48862 .62356 .48175 Mtetra
.728 .799 .908 r
.62356 .48175 .63085 .48862 .6455 .48214 .63826 .47451 Mtetra
.699 .773 .909 r
.63826 .47451 .6455 .48214 .66025 .47653 .65305 .46847 Mtetra
.682 .759 .909 r
.65305 .46847 .66025 .47653 .67509 .47139 .66794 .46308 Mtetra
.673 .75 .909 r
.66794 .46308 .67509 .47139 .69002 .46648 .68292 .45801 Mtetra
.669 .746 .908 r
.68292 .45801 .69002 .46648 .70503 .46169 .69798 .45311 Mtetra
.666 .744 .908 r
.69798 .45311 .70503 .46169 .72012 .45694 .71313 .44829 Mtetra
.665 .743 .908 r
.71313 .44829 .72012 .45694 .7353 .4522 .72836 .44349 Mtetra
.664 .742 .908 r
.72836 .44349 .7353 .4522 .75056 .44746 .74368 .4387 Mtetra
.74368 .4387 .75056 .44746 .7659 .44271 .75908 .43389 Mtetra
.664 .741 .908 r
.75908 .43389 .7659 .44271 .78132 .43793 .77456 .42906 Mtetra
.77456 .42906 .78132 .43793 .79683 .43314 .79013 .42422 Mtetra
.79013 .42422 .79683 .43314 .81242 .42831 .80578 .41935 Mtetra
.80578 .41935 .81242 .42831 .8281 .42347 .82151 .41445 Mtetra
.82151 .41445 .8281 .42347 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.647 .763 .934 r
.33802 .75705 .34685 .7642 .36103 .7603 .35224 .75312 Mtetra
.35224 .75312 .36103 .7603 .37528 .75634 .36654 .74914 Mtetra
.648 .764 .933 r
.36654 .74914 .37528 .75634 .38961 .75231 .38092 .7451 Mtetra
.651 .765 .933 r
.38092 .7451 .38961 .75231 .40402 .74816 .39537 .74097 Mtetra
.655 .768 .933 r
.39537 .74097 .40402 .74816 .41851 .74378 .40991 .73666 Mtetra
.662 .773 .931 r
.40991 .73666 .41851 .74378 .43308 .73899 .42453 .73206 Mtetra
.677 .782 .929 r
.42453 .73206 .43308 .73899 .44774 .73347 .43924 .7269 Mtetra
.702 .798 .925 r
.43924 .7269 .44774 .73347 .46249 .7266 .45404 .72075 Mtetra
.743 .824 .914 r
.45404 .72075 .46249 .7266 .47734 .71734 .46893 .71278 Mtetra
.805 .86 .89 r
.46893 .71278 .47734 .71734 .49225 .70402 .4839 .70167 Mtetra
.878 .898 .841 r
.4839 .70167 .49225 .70402 .5072 .68449 .49894 .68543 Mtetra
.941 .922 .763 r
.49894 .68543 .5072 .68449 .52211 .65698 .51398 .66191 Mtetra
.972 .925 .674 r
.51398 .66191 .52211 .65698 .53687 .62213 .52892 .63026 Mtetra
.976 .919 .607 r
.52892 .63026 .53687 .62213 .55142 .58441 .54368 .59304 Mtetra
.969 .921 .592 r
.54368 .59304 .55142 .58441 .56581 .55015 .55823 .55615 Mtetra
.964 .939 .645 r
.55823 .55615 .56581 .55015 .58014 .52338 .57267 .52525 Mtetra
.944 .95 .748 r
.57267 .52525 .58014 .52338 .59451 .50435 .5871 .5024 Mtetra
.886 .923 .842 r
.5871 .5024 .59451 .50435 .60898 .49117 .6016 .48649 Mtetra
.811 .868 .89 r
.6016 .48649 .60898 .49117 .62356 .48175 .61622 .47535 Mtetra
.75 .818 .905 r
.61622 .47535 .62356 .48175 .63826 .47451 .63095 .4671 Mtetra
.711 .784 .909 r
.63095 .4671 .63826 .47451 .65305 .46847 .64579 .46049 Mtetra
.689 .765 .909 r
.64579 .46049 .65305 .46847 .66794 .46308 .66072 .45477 Mtetra
.677 .754 .909 r
.66072 .45477 .66794 .46308 .68292 .45801 .67575 .44951 Mtetra
.671 .748 .908 r
.67575 .44951 .68292 .45801 .69798 .45311 .69087 .44448 Mtetra
.667 .745 .908 r
.69087 .44448 .69798 .45311 .71313 .44829 .70607 .43957 Mtetra
.666 .743 .908 r
.70607 .43957 .71313 .44829 .72836 .44349 .72136 .4347 Mtetra
.665 .742 .908 r
.72136 .4347 .72836 .44349 .74368 .4387 .73673 .42984 Mtetra
.664 .742 .908 r
.73673 .42984 .74368 .4387 .75908 .43389 .75219 .42498 Mtetra
.75219 .42498 .75908 .43389 .77456 .42906 .76773 .42011 Mtetra
.664 .741 .908 r
.76773 .42011 .77456 .42906 .79013 .42422 .78335 .41521 Mtetra
.78335 .41521 .79013 .42422 .80578 .41935 .79906 .41029 Mtetra
.79906 .41029 .80578 .41935 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.646 .763 .934 r
.32911 .74982 .33802 .75705 .35224 .75312 .34337 .74586 Mtetra
.647 .763 .934 r
.34337 .74586 .35224 .75312 .36654 .74914 .35772 .74186 Mtetra
.648 .764 .933 r
.35772 .74186 .36654 .74914 .38092 .7451 .37214 .7378 Mtetra
.649 .765 .933 r
.37214 .7378 .38092 .7451 .39537 .74097 .38664 .73367 Mtetra
.652 .766 .933 r
.38664 .73367 .39537 .74097 .40991 .73666 .40123 .72941 Mtetra
.658 .77 .932 r
.40123 .72941 .40991 .73666 .42453 .73206 .4159 .72493 Mtetra
.668 .777 .931 r
.4159 .72493 .42453 .73206 .43924 .7269 .43065 .72003 Mtetra
.687 .789 .927 r
.43065 .72003 .43924 .7269 .45404 .72075 .4455 .71439 Mtetra
.72 .809 .92 r
.4455 .71439 .45404 .72075 .46893 .71278 .46043 .7074 Mtetra
.772 .841 .904 r
.46043 .7074 .46893 .71278 .4839 .70167 .47546 .69799 Mtetra
.841 .88 .869 r
.47546 .69799 .4839 .70167 .49894 .68543 .49057 .68451 Mtetra
.913 .913 .805 r
.49057 .68451 .49894 .68543 .51398 .66191 .50571 .66476 Mtetra
.961 .926 .718 r
.50571 .66476 .51398 .66191 .52892 .63026 .52082 .63698 Mtetra
.976 .922 .636 r
.52082 .63698 .52892 .63026 .54368 .59304 .53578 .6018 Mtetra
.972 .918 .592 r
.53578 .6018 .54368 .59304 .55823 .55615 .55052 .56375 Mtetra
.967 .928 .61 r
.55052 .56375 .55823 .55615 .57267 .52525 .5651 .52918 Mtetra
.958 .948 .693 r
.5651 .52918 .57267 .52525 .5871 .5024 .57961 .50217 Mtetra
.919 .942 .8 r
.57961 .50217 .5871 .5024 .6016 .48649 .59416 .48293 Mtetra
.848 .896 .871 r
.59416 .48293 .6016 .48649 .61622 .47535 .60881 .46959 Mtetra
.778 .841 .9 r
.60881 .46959 .61622 .47535 .63095 .4671 .62358 .46003 Mtetra
.728 .799 .908 r
.62358 .46003 .63095 .4671 .64579 .46049 .63845 .45265 Mtetra
.699 .773 .909 r
.63845 .45265 .64579 .46049 .66072 .45477 .65343 .44649 Mtetra
.682 .758 .909 r
.65343 .44649 .66072 .45477 .67575 .44951 .66851 .44098 Mtetra
.673 .75 .909 r
.66851 .44098 .67575 .44951 .69087 .44448 .68368 .43579 Mtetra
.669 .746 .908 r
.68368 .43579 .69087 .44448 .70607 .43957 .69894 .43077 Mtetra
.666 .744 .908 r
.69894 .43077 .70607 .43957 .72136 .4347 .71428 .42583 Mtetra
.665 .743 .908 r
.71428 .42583 .72136 .4347 .73673 .42984 .72971 .42091 Mtetra
.664 .742 .908 r
.72971 .42091 .73673 .42984 .75219 .42498 .74522 .41599 Mtetra
.74522 .41599 .75219 .42498 .76773 .42011 .76082 .41106 Mtetra
.664 .741 .908 r
.76082 .41106 .76773 .42011 .78335 .41521 .77651 .40611 Mtetra
.77651 .40611 .78335 .41521 .79906 .41029 .79228 .40114 Mtetra
.79228 .40114 .79906 .41029 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38607 Mtetra
.84012 .38607 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .763 .934 r
.3201 .74252 .32911 .74982 .34337 .74586 .33441 .73852 Mtetra
.647 .763 .934 r
.33441 .73852 .34337 .74586 .35772 .74186 .34881 .73449 Mtetra
.34881 .73449 .35772 .74186 .37214 .7378 .36328 .73041 Mtetra
.648 .764 .933 r
.36328 .73041 .37214 .7378 .38664 .73367 .37783 .72627 Mtetra
.651 .765 .933 r
.37783 .72627 .38664 .73367 .40123 .72941 .39246 .72204 Mtetra
.655 .768 .933 r
.39246 .72204 .40123 .72941 .4159 .72493 .40718 .71763 Mtetra
.662 .773 .932 r
.40718 .71763 .4159 .72493 .43065 .72003 .42198 .71291 Mtetra
.677 .782 .929 r
.42198 .71291 .43065 .72003 .4455 .71439 .43687 .70764 Mtetra
.702 .798 .925 r
.43687 .70764 .4455 .71439 .46043 .7074 .45185 .70137 Mtetra
.743 .824 .914 r
.45185 .70137 .46043 .7074 .47546 .69799 .46693 .69327 Mtetra
.805 .86 .89 r
.46693 .69327 .47546 .69799 .49057 .68451 .4821 .68199 Mtetra
.878 .898 .841 r
.4821 .68199 .49057 .68451 .50571 .66476 .49733 .66555 Mtetra
.941 .923 .763 r
.49733 .66555 .50571 .66476 .52082 .63698 .51257 .64179 Mtetra
.972 .925 .674 r
.51257 .64179 .52082 .63698 .53578 .6018 .52771 .60984 Mtetra
.976 .919 .607 r
.52771 .60984 .53578 .6018 .55052 .56375 .54267 .57228 Mtetra
.969 .921 .592 r
.54267 .57228 .55052 .56375 .5651 .52918 .55742 .53507 Mtetra
.964 .939 .645 r
.55742 .53507 .5651 .52918 .57961 .50217 .57204 .50389 Mtetra
.944 .95 .748 r
.57204 .50389 .57961 .50217 .59416 .48293 .58665 .48081 Mtetra
.886 .923 .842 r
.58665 .48081 .59416 .48293 .60881 .46959 .60134 .46472 Mtetra
.811 .868 .89 r
.60134 .46472 .60881 .46959 .62358 .46003 .61614 .45342 Mtetra
.75 .818 .905 r
.61614 .45342 .62358 .46003 .63845 .45265 .63105 .44504 Mtetra
.711 .784 .909 r
.63105 .44504 .63845 .45265 .65343 .44649 .64608 .4383 Mtetra
.689 .765 .909 r
.64608 .4383 .65343 .44649 .66851 .44098 .6612 .43245 Mtetra
.677 .754 .909 r
.6612 .43245 .66851 .44098 .68368 .43579 .67642 .42707 Mtetra
.671 .748 .908 r
.67642 .42707 .68368 .43579 .69894 .43077 .69173 .42192 Mtetra
.667 .745 .908 r
.69173 .42192 .69894 .43077 .71428 .42583 .70713 .41688 Mtetra
.666 .743 .908 r
.70713 .41688 .71428 .42583 .72971 .42091 .72262 .41189 Mtetra
.665 .742 .908 r
.72262 .41189 .72971 .42091 .74522 .41599 .73819 .40691 Mtetra
.664 .742 .908 r
.73819 .40691 .74522 .41599 .76082 .41106 .75385 .40192 Mtetra
.75385 .40192 .76082 .41106 .77651 .40611 .7696 .39692 Mtetra
.664 .741 .908 r
.7696 .39692 .77651 .40611 .79228 .40114 .78543 .3919 Mtetra
.78543 .3919 .79228 .40114 .80814 .39614 .80135 .38685 Mtetra
.80135 .38685 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38607 .83346 .37667 Mtetra
.83346 .37667 .84012 .38607 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .763 .934 r
.31101 .73515 .3201 .74252 .33441 .73852 .32537 .73111 Mtetra
.32537 .73111 .33441 .73852 .34881 .73449 .3398 .72704 Mtetra
.647 .763 .934 r
.3398 .72704 .34881 .73449 .36328 .73041 .35432 .72294 Mtetra
.648 .764 .933 r
.35432 .72294 .36328 .73041 .37783 .72627 .36892 .71878 Mtetra
.649 .765 .933 r
.36892 .71878 .37783 .72627 .39246 .72204 .3836 .71455 Mtetra
.652 .766 .933 r
.3836 .71455 .39246 .72204 .40718 .71763 .39837 .71018 Mtetra
.658 .77 .932 r
.39837 .71018 .40718 .71763 .42198 .71291 .41322 .70559 Mtetra
.668 .777 .931 r
.41322 .70559 .42198 .71291 .43687 .70764 .42816 .70058 Mtetra
.687 .789 .927 r
.42816 .70058 .43687 .70764 .45185 .70137 .44319 .69482 Mtetra
.72 .809 .92 r
.44319 .69482 .45185 .70137 .46693 .69327 .45832 .6877 Mtetra
.772 .841 .904 r
.45832 .6877 .46693 .69327 .4821 .68199 .47354 .67815 Mtetra
.841 .88 .869 r
.47354 .67815 .4821 .68199 .49733 .66555 .48885 .66448 Mtetra
.913 .913 .805 r
.48885 .66448 .49733 .66555 .51257 .64179 .50419 .64451 Mtetra
.961 .926 .718 r
.50419 .64451 .51257 .64179 .52771 .60984 .5195 .61645 Mtetra
.976 .922 .636 r
.5195 .61645 .52771 .60984 .54267 .57228 .53466 .58095 Mtetra
.972 .918 .592 r
.53466 .58095 .54267 .57228 .55742 .53507 .5496 .54256 Mtetra
.967 .928 .61 r
.5496 .54256 .55742 .53507 .57204 .50389 .56437 .50769 Mtetra
.958 .948 .694 r
.56437 .50769 .57204 .50389 .58665 .48081 .57906 .48042 Mtetra
.919 .942 .8 r
.57906 .48042 .58665 .48081 .60134 .46472 .5938 .46098 Mtetra
.848 .896 .871 r
.5938 .46098 .60134 .46472 .61614 .45342 .60864 .44747 Mtetra
.778 .841 .9 r
.60864 .44747 .61614 .45342 .63105 .44504 .62359 .43775 Mtetra
.728 .799 .908 r
.62359 .43775 .63105 .44504 .64608 .4383 .63866 .43025 Mtetra
.699 .773 .909 r
.63866 .43025 .64608 .4383 .6612 .43245 .65383 .42396 Mtetra
.682 .758 .909 r
.65383 .42396 .6612 .43245 .67642 .42707 .6691 .41832 Mtetra
.673 .75 .909 r
.6691 .41832 .67642 .42707 .69173 .42192 .68446 .41301 Mtetra
.669 .746 .908 r
.68446 .41301 .69173 .42192 .70713 .41688 .69992 .40786 Mtetra
.666 .744 .908 r
.69992 .40786 .70713 .41688 .72262 .41189 .71546 .40279 Mtetra
.665 .743 .908 r
.71546 .40279 .72262 .41189 .73819 .40691 .73109 .39774 Mtetra
.664 .742 .908 r
.73109 .39774 .73819 .40691 .75385 .40192 .74681 .3927 Mtetra
.74681 .3927 .75385 .40192 .7696 .39692 .76262 .38764 Mtetra
.664 .741 .908 r
.76262 .38764 .7696 .39692 .78543 .3919 .77851 .38256 Mtetra
.77851 .38256 .78543 .3919 .80135 .38685 .79449 .37746 Mtetra
.79449 .37746 .80135 .38685 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Mtetra
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .763 .934 r
.30182 .7277 .31101 .73515 .32537 .73111 .31623 .72362 Mtetra
.31623 .72362 .32537 .73111 .3398 .72704 .33071 .71952 Mtetra
.647 .763 .934 r
.33071 .71952 .3398 .72704 .35432 .72294 .34528 .71538 Mtetra
.34528 .71538 .35432 .72294 .36892 .71878 .35993 .7112 Mtetra
.648 .764 .933 r
.35993 .7112 .36892 .71878 .3836 .71455 .37466 .70696 Mtetra
.651 .765 .933 r
.37466 .70696 .3836 .71455 .39837 .71018 .38947 .70261 Mtetra
.655 .768 .933 r
.38947 .70261 .39837 .71018 .41322 .70559 .40437 .69809 Mtetra
.662 .773 .932 r
.40437 .69809 .41322 .70559 .42816 .70058 .41936 .69326 Mtetra
.677 .782 .929 r
.41936 .69326 .42816 .70058 .44319 .69482 .43444 .68788 Mtetra
.702 .798 .925 r
.43444 .68788 .44319 .69482 .45832 .6877 .44962 .68148 Mtetra
.743 .824 .914 r
.44962 .68148 .45832 .6877 .47354 .67815 .46489 .67324 Mtetra
.805 .86 .89 r
.46489 .67324 .47354 .67815 .48885 .66448 .48026 .6618 Mtetra
.878 .898 .841 r
.48026 .6618 .48885 .66448 .50419 .64451 .49569 .64516 Mtetra
.941 .923 .763 r
.49569 .64516 .50419 .64451 .5195 .61645 .51113 .62114 Mtetra
.972 .925 .674 r
.51113 .62114 .5195 .61645 .53466 .58095 .52648 .58889 Mtetra
.976 .919 .607 r
.52648 .58889 .53466 .58095 .5496 .54256 .54163 .55099 Mtetra
.969 .921 .592 r
.54163 .55099 .5496 .54256 .56437 .50769 .55658 .51345 Mtetra
.964 .938 .645 r
.55658 .51345 .56437 .50769 .57906 .48042 .57139 .48199 Mtetra
.944 .95 .748 r
.57139 .48199 .57906 .48042 .5938 .46098 .58619 .45868 Mtetra
.886 .922 .842 r
.58619 .45868 .5938 .46098 .60864 .44747 .60107 .44239 Mtetra
.811 .868 .889 r
.60107 .44239 .60864 .44747 .62359 .43775 .61606 .43094 Mtetra
.75 .818 .905 r
.61606 .43094 .62359 .43775 .63866 .43025 .63116 .42241 Mtetra
.711 .784 .909 r
.63116 .42241 .63866 .43025 .65383 .42396 .64638 .41554 Mtetra
.689 .765 .909 r
.64638 .41554 .65383 .42396 .6691 .41832 .6617 .40956 Mtetra
.677 .754 .909 r
.6617 .40956 .6691 .41832 .68446 .41301 .67712 .40405 Mtetra
.671 .748 .908 r
.67712 .40405 .68446 .41301 .69992 .40786 .69263 .39877 Mtetra
.667 .745 .908 r
.69263 .39877 .69992 .40786 .71546 .40279 .70823 .39361 Mtetra
.666 .743 .908 r
.70823 .39361 .71546 .40279 .73109 .39774 .72392 .38849 Mtetra
.665 .742 .908 r
.72392 .38849 .73109 .39774 .74681 .3927 .7397 .38338 Mtetra
.664 .742 .908 r
.7397 .38338 .74681 .3927 .76262 .38764 .75556 .37826 Mtetra
.75556 .37826 .76262 .38764 .77851 .38256 .77152 .37313 Mtetra
.664 .741 .908 r
.77152 .37313 .77851 .38256 .79449 .37746 .78757 .36797 Mtetra
.78757 .36797 .79449 .37746 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Mtetra
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .762 .934 r
.29254 .72017 .30182 .7277 .31623 .72362 .30699 .71606 Mtetra
.646 .763 .934 r
.30699 .71606 .31623 .72362 .33071 .71952 .32153 .71192 Mtetra
.32153 .71192 .33071 .71952 .34528 .71538 .33614 .70774 Mtetra
.647 .763 .934 r
.33614 .70774 .34528 .71538 .35993 .7112 .35084 .70353 Mtetra
.648 .764 .933 r
.35084 .70353 .35993 .7112 .37466 .70696 .36562 .69927 Mtetra
.649 .765 .933 r
.36562 .69927 .37466 .70696 .38947 .70261 .38048 .69492 Mtetra
.652 .766 .933 r
.38048 .69492 .38947 .70261 .40437 .69809 .39543 .69045 Mtetra
.658 .77 .932 r
.39543 .69045 .40437 .69809 .41936 .69326 .41047 .68574 Mtetra
.668 .777 .931 r
.41047 .68574 .41936 .69326 .43444 .68788 .4256 .68062 Mtetra
.687 .789 .927 r
.4256 .68062 .43444 .68788 .44962 .68148 .44082 .67474 Mtetra
.72 .809 .92 r
.44082 .67474 .44962 .68148 .46489 .67324 .45615 .66748 Mtetra
.772 .841 .904 r
.45615 .66748 .46489 .67324 .48026 .6618 .47157 .65777 Mtetra
.841 .88 .869 r
.47157 .65777 .48026 .6618 .49569 .64516 .48708 .64392 Mtetra
.913 .913 .805 r
.48708 .64392 .49569 .64516 .51113 .62114 .50263 .62372 Mtetra
.961 .927 .718 r
.50263 .62372 .51113 .62114 .52648 .58889 .51814 .59538 Mtetra
.976 .922 .636 r
.51814 .59538 .52648 .58889 .54163 .55099 .53351 .55955 Mtetra
.972 .918 .592 r
.53351 .55955 .54163 .55099 .55658 .51345 .54865 .52082 Mtetra
.967 .928 .61 r
.54865 .52082 .55658 .51345 .57139 .48199 .56362 .48564 Mtetra
.958 .947 .694 r
.56362 .48564 .57139 .48199 .58619 .45868 .57851 .45811 Mtetra
.919 .942 .8 r
.57851 .45811 .58619 .45868 .60107 .44239 .59343 .43846 Mtetra
.848 .896 .871 r
.59343 .43846 .60107 .44239 .61606 .43094 .60846 .42478 Mtetra
.778 .841 .9 r
.60846 .42478 .61606 .43094 .63116 .42241 .6236 .41491 Mtetra
.728 .799 .908 r
.6236 .41491 .63116 .42241 .64638 .41554 .63886 .40726 Mtetra
.699 .773 .909 r
.63886 .40726 .64638 .41554 .6617 .40956 .65423 .40084 Mtetra
.682 .758 .909 r
.65423 .40084 .6617 .40956 .67712 .40405 .6697 .39507 Mtetra
.673 .75 .909 r
.6697 .39507 .67712 .40405 .69263 .39877 .68526 .38963 Mtetra
.669 .746 .908 r
.68526 .38963 .69263 .39877 .70823 .39361 .70092 .38435 Mtetra
.666 .744 .908 r
.70092 .38435 .70823 .39361 .72392 .38849 .71667 .37915 Mtetra
.665 .743 .908 r
.71667 .37915 .72392 .38849 .7397 .38338 .73251 .37397 Mtetra
.664 .742 .908 r
.73251 .37397 .7397 .38338 .75556 .37826 .74844 .3688 Mtetra
.74844 .3688 .75556 .37826 .77152 .37313 .76446 .3636 Mtetra
.664 .741 .908 r
.76446 .3636 .77152 .37313 .78757 .36797 .78056 .35839 Mtetra
.78056 .35839 .78757 .36797 .8037 .36279 .79676 .35315 Mtetra
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72017 .30699 .71606 .29767 .70841 Mtetra
.646 .763 .934 r
.29767 .70841 .30699 .71606 .32153 .71192 .31225 .70423 Mtetra
.31225 .70423 .32153 .71192 .33614 .70774 .32692 .70002 Mtetra
.647 .763 .934 r
.32692 .70002 .33614 .70774 .35084 .70353 .34166 .69578 Mtetra
.34166 .69578 .35084 .70353 .36562 .69927 .35649 .69149 Mtetra
.648 .764 .933 r
.35649 .69149 .36562 .69927 .38048 .69492 .3714 .68713 Mtetra
.651 .765 .933 r
.3714 .68713 .38048 .69492 .39543 .69045 .3864 .68267 Mtetra
.655 .768 .933 r
.3864 .68267 .39543 .69045 .41047 .68574 .40149 .67804 Mtetra
.662 .773 .932 r
.40149 .67804 .41047 .68574 .4256 .68062 .41667 .6731 Mtetra
.677 .782 .929 r
.41667 .6731 .4256 .68062 .44082 .67474 .43194 .66759 Mtetra
.702 .798 .925 r
.43194 .66759 .44082 .67474 .45615 .66748 .44732 .66106 Mtetra
.743 .824 .914 r
.44732 .66106 .45615 .66748 .47157 .65777 .46279 .65267 Mtetra
.805 .86 .89 r
.46279 .65267 .47157 .65777 .48708 .64392 .47836 .64106 Mtetra
.879 .899 .841 r
.47836 .64106 .48708 .64392 .50263 .62372 .494 .62422 Mtetra
.941 .923 .763 r
.494 .62422 .50263 .62372 .51814 .59538 .50965 .59995 Mtetra
.972 .926 .674 r
.50965 .59995 .51814 .59538 .53351 .55955 .52521 .56738 Mtetra
.975 .919 .607 r
.52521 .56738 .53351 .55955 .54865 .52082 .54057 .52914 Mtetra
.969 .921 .592 r
.54057 .52914 .54865 .52082 .56362 .48564 .55572 .49127 Mtetra
.964 .938 .646 r
.55572 .49127 .56362 .48564 .57851 .45811 .57073 .45952 Mtetra
.944 .95 .749 r
.57073 .45952 .57851 .45811 .59343 .43846 .58572 .43597 Mtetra
.886 .922 .842 r
.58572 .43597 .59343 .43846 .60846 .42478 .60079 .4195 Mtetra
.811 .867 .889 r
.60079 .4195 .60846 .42478 .6236 .41491 .61597 .40788 Mtetra
.75 .818 .905 r
.61597 .40788 .6236 .41491 .63886 .40726 .63127 .3992 Mtetra
.711 .784 .909 r
.63127 .3992 .63886 .40726 .65423 .40084 .64669 .39219 Mtetra
.689 .765 .909 r
.64669 .39219 .65423 .40084 .6697 .39507 .66221 .38608 Mtetra
.677 .754 .909 r
.66221 .38608 .6697 .39507 .68526 .38963 .67783 .38043 Mtetra
.671 .748 .908 r
.67783 .38043 .68526 .38963 .70092 .38435 .69354 .37502 Mtetra
.667 .745 .908 r
.69354 .37502 .70092 .38435 .71667 .37915 .70935 .36973 Mtetra
.666 .743 .908 r
.70935 .36973 .71667 .37915 .73251 .37397 .72525 .36447 Mtetra
.665 .742 .908 r
.72525 .36447 .73251 .37397 .74844 .3688 .74124 .35923 Mtetra
.664 .742 .908 r
.74124 .35923 .74844 .3688 .76446 .3636 .75732 .35398 Mtetra
.75732 .35398 .76446 .3636 .78056 .35839 .77349 .34871 Mtetra
.664 .741 .908 r
.77349 .34871 .78056 .35839 .79676 .35315 .78976 .34342 Mtetra
.78976 .34342 .79676 .35315 .81306 .34789 .80611 .33809 Mtetra
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70841 .28825 .70069 Mtetra
.28825 .70069 .29767 .70841 .31225 .70423 .30288 .69647 Mtetra
.646 .763 .934 r
.30288 .69647 .31225 .70423 .32692 .70002 .31759 .69222 Mtetra
.31759 .69222 .32692 .70002 .34166 .69578 .33239 .68794 Mtetra
.647 .763 .934 r
.33239 .68794 .34166 .69578 .35649 .69149 .34727 .68362 Mtetra
.648 .764 .934 r
.34727 .68362 .35649 .69149 .3714 .68713 .36223 .67924 Mtetra
.649 .765 .933 r
.36223 .67924 .3714 .68713 .3864 .68267 .37728 .67478 Mtetra
.652 .766 .933 r
.37728 .67478 .3864 .68267 .40149 .67804 .39242 .67019 Mtetra
.658 .77 .932 r
.39242 .67019 .40149 .67804 .41667 .6731 .40765 .66536 Mtetra
.668 .777 .931 r
.40765 .66536 .41667 .6731 .43194 .66759 .42297 .66012 Mtetra
.687 .789 .928 r
.42297 .66012 .43194 .66759 .44732 .66106 .4384 .65411 Mtetra
.72 .81 .921 r
.4384 .65411 .44732 .66106 .46279 .65267 .45392 .64672 Mtetra
.772 .841 .905 r
.45392 .64672 .46279 .65267 .47836 .64106 .46954 .63685 Mtetra
.841 .88 .87 r
.46954 .63685 .47836 .64106 .494 .62422 .48526 .62282 Mtetra
.913 .914 .805 r
.48526 .62282 .494 .62422 .50965 .59995 .50102 .60238 Mtetra
.961 .927 .718 r
.50102 .60238 .50965 .59995 .52521 .56738 .51675 .57375 Mtetra
.976 .922 .635 r
.51675 .57375 .52521 .56738 .54057 .52914 .53233 .53759 Mtetra
.972 .918 .592 r
.53233 .53759 .54057 .52914 .55572 .49127 .54768 .49851 Mtetra
.967 .928 .611 r
.54768 .49851 .55572 .49127 .57073 .45952 .56285 .46301 Mtetra
.958 .947 .694 r
.56285 .46301 .57073 .45952 .58572 .43597 .57793 .43522 Mtetra
.919 .941 .8 r
.57793 .43522 .58572 .43597 .60079 .4195 .59306 .41536 Mtetra
.848 .896 .871 r
.59306 .41536 .60079 .4195 .61597 .40788 .60828 .4015 Mtetra
.778 .841 .9 r
.60828 .4015 .61597 .40788 .63127 .3992 .62362 .39147 Mtetra
.728 .799 .908 r
.62362 .39147 .63127 .3992 .64669 .39219 .63907 .38368 Mtetra
.699 .773 .909 r
.63907 .38368 .64669 .39219 .66221 .38608 .65464 .37712 Mtetra
.682 .758 .909 r
.65464 .37712 .66221 .38608 .67783 .38043 .67032 .37121 Mtetra
.673 .75 .909 r
.67032 .37121 .67783 .38043 .69354 .37502 .68609 .36563 Mtetra
.669 .746 .908 r
.68609 .36563 .69354 .37502 .70935 .36973 .70195 .36022 Mtetra
.666 .744 .908 r
.70195 .36022 .70935 .36973 .72525 .36447 .71791 .35489 Mtetra
.665 .743 .908 r
.71791 .35489 .72525 .36447 .74124 .35923 .73396 .34957 Mtetra
.664 .742 .908 r
.73396 .34957 .74124 .35923 .75732 .35398 .75011 .34426 Mtetra
.75011 .34426 .75732 .35398 .77349 .34871 .76634 .33893 Mtetra
.664 .741 .908 r
.76634 .33893 .77349 .34871 .78976 .34342 .78267 .33358 Mtetra
.78267 .33358 .78976 .34342 .80611 .33809 .7991 .3282 Mtetra
.7991 .3282 .80611 .33809 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .70069 .27873 .69289 Mtetra
.27873 .69289 .28825 .70069 .30288 .69647 .29341 .68863 Mtetra
.646 .763 .934 r
.29341 .68863 .30288 .69647 .31759 .69222 .30817 .68433 Mtetra
.30817 .68433 .31759 .69222 .33239 .68794 .32302 .68001 Mtetra
.647 .763 .934 r
.32302 .68001 .33239 .68794 .34727 .68362 .33795 .67566 Mtetra
.33795 .67566 .34727 .68362 .36223 .67924 .35296 .67125 Mtetra
.648 .764 .933 r
.35296 .67125 .36223 .67924 .37728 .67478 .36806 .66678 Mtetra
.651 .765 .933 r
.36806 .66678 .37728 .67478 .39242 .67019 .38325 .66221 Mtetra
.655 .768 .933 r
.38325 .66221 .39242 .67019 .40765 .66536 .39854 .65745 Mtetra
.662 .773 .932 r
.39854 .65745 .40765 .66536 .42297 .66012 .41391 .65239 Mtetra
.677 .782 .929 r
.41391 .65239 .42297 .66012 .4384 .65411 .42938 .64676 Mtetra
.702 .798 .925 r
.42938 .64676 .4384 .65411 .45392 .64672 .44496 .64009 Mtetra
.743 .824 .914 r
.44496 .64009 .45392 .64672 .46954 .63685 .46063 .63156 Mtetra
.805 .86 .89 r
.46063 .63156 .46954 .63685 .48526 .62282 .47641 .61977 Mtetra
.879 .899 .841 r
.47641 .61977 .48526 .62282 .50102 .60238 .49227 .60272 Mtetra
.941 .923 .763 r
.49227 .60272 .50102 .60238 .51675 .57375 .50813 .57818 Mtetra
.972 .926 .673 r
.50813 .57818 .51675 .57375 .53233 .53759 .52391 .5453 Mtetra
.975 .919 .607 r
.52391 .5453 .53233 .53759 .54768 .49851 .53948 .50671 Mtetra
.969 .921 .593 r
.53948 .50671 .54768 .49851 .56285 .46301 .55484 .4685 Mtetra
.964 .938 .646 r
.55484 .4685 .56285 .46301 .57793 .43522 .57005 .43645 Mtetra
.944 .95 .749 r
.57005 .43645 .57793 .43522 .59306 .41536 .58524 .41267 Mtetra
.886 .922 .842 r
.58524 .41267 .59306 .41536 .60828 .4015 .60051 .396 Mtetra
.811 .867 .889 r
.60051 .396 .60828 .4015 .62362 .39147 .61589 .38421 Mtetra
.75 .818 .905 r
.61589 .38421 .62362 .39147 .63907 .38368 .63139 .37539 Mtetra
.711 .784 .909 r
.63139 .37539 .63907 .38368 .65464 .37712 .647 .36823 Mtetra
.689 .765 .909 r
.647 .36823 .65464 .37712 .67032 .37121 .66273 .36198 Mtetra
.677 .754 .909 r
.66273 .36198 .67032 .37121 .68609 .36563 .67856 .35619 Mtetra
.671 .748 .908 r
.67856 .35619 .68609 .36563 .70195 .36022 .69448 .35065 Mtetra
.667 .745 .908 r
.69448 .35065 .70195 .36022 .71791 .35489 .7105 .34521 Mtetra
.666 .743 .908 r
.7105 .34521 .71791 .35489 .73396 .34957 .72661 .33982 Mtetra
.665 .742 .908 r
.72661 .33982 .73396 .34957 .75011 .34426 .74282 .33444 Mtetra
.664 .742 .908 r
.74282 .33444 .75011 .34426 .76634 .33893 .75912 .32905 Mtetra
.75912 .32905 .76634 .33893 .78267 .33358 .77552 .32363 Mtetra
.664 .741 .908 r
.77552 .32363 .78267 .33358 .7991 .3282 .79201 .3182 Mtetra
.79201 .3182 .7991 .3282 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Mtetra
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .68501 Mtetra
.26911 .68501 .27873 .69289 .29341 .68863 .28384 .6807 Mtetra
.28384 .6807 .29341 .68863 .30817 .68433 .29865 .67636 Mtetra
.646 .763 .934 r
.29865 .67636 .30817 .68433 .32302 .68001 .31355 .672 Mtetra
.31355 .672 .32302 .68001 .33795 .67566 .32853 .66761 Mtetra
.647 .763 .934 r
.32853 .66761 .33795 .67566 .35296 .67125 .3436 .66317 Mtetra
.648 .764 .934 r
.3436 .66317 .35296 .67125 .36806 .66678 .35875 .65868 Mtetra
.649 .765 .933 r
.35875 .65868 .36806 .66678 .38325 .66221 .37399 .6541 Mtetra
.652 .766 .933 r
.37399 .6541 .38325 .66221 .39854 .65745 .38933 .64939 Mtetra
.658 .77 .932 r
.38933 .64939 .39854 .65745 .41391 .65239 .40475 .64444 Mtetra
.668 .777 .931 r
.40475 .64444 .41391 .65239 .42938 .64676 .42028 .63907 Mtetra
.687 .789 .928 r
.42028 .63907 .42938 .64676 .44496 .64009 .4359 .63293 Mtetra
.72 .81 .921 r
.4359 .63293 .44496 .64009 .46063 .63156 .45163 .62539 Mtetra
.772 .841 .905 r
.45163 .62539 .46063 .63156 .47641 .61977 .46747 .61537 Mtetra
.841 .88 .87 r
.46747 .61537 .47641 .61977 .49227 .60272 .48339 .60114 Mtetra
.913 .914 .805 r
.48339 .60114 .49227 .60272 .50813 .57818 .49937 .58046 Mtetra
.961 .927 .717 r
.49937 .58046 .50813 .57818 .52391 .5453 .51532 .55154 Mtetra
.976 .922 .635 r
.51532 .55154 .52391 .5453 .53948 .50671 .53112 .51503 Mtetra
.972 .918 .592 r
.53112 .51503 .53948 .50671 .55484 .4685 .54668 .4756 Mtetra
.967 .928 .611 r
.54668 .4756 .55484 .4685 .57005 .43645 .56206 .43979 Mtetra
.958 .947 .695 r
.56206 .43979 .57005 .43645 .58524 .41267 .57734 .41173 Mtetra
.919 .941 .8 r
.57734 .41173 .58524 .41267 .60051 .396 .59267 .39165 Mtetra
.848 .896 .871 r
.59267 .39165 .60051 .396 .61589 .38421 .60809 .3776 Mtetra
.778 .841 .9 r
.60809 .3776 .61589 .38421 .63139 .37539 .62363 .36742 Mtetra
.728 .799 .908 r
.62363 .36742 .63139 .37539 .647 .36823 .63929 .35948 Mtetra
.699 .773 .909 r
.63929 .35948 .647 .36823 .66273 .36198 .65507 .35277 Mtetra
.682 .758 .909 r
.65507 .35277 .66273 .36198 .67856 .35619 .67095 .34672 Mtetra
.673 .75 .909 r
.67095 .34672 .67856 .35619 .69448 .35065 .68693 .341 Mtetra
.669 .746 .908 r
.68693 .341 .69448 .35065 .7105 .34521 .70301 .33545 Mtetra
.666 .744 .908 r
.70301 .33545 .7105 .34521 .72661 .33982 .71919 .32998 Mtetra
.665 .743 .908 r
.71919 .32998 .72661 .33982 .74282 .33444 .73546 .32452 Mtetra
.664 .742 .908 r
.73546 .32452 .74282 .33444 .75912 .32905 .75182 .31906 Mtetra
.75182 .31906 .75912 .32905 .77552 .32363 .76828 .31359 Mtetra
.664 .741 .908 r
.76828 .31359 .77552 .32363 .79201 .3182 .78484 .30809 Mtetra
.78484 .30809 .79201 .3182 .80859 .31273 .80149 .30256 Mtetra
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Mtetra
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .68501 .25939 .67704 Mtetra
.25939 .67704 .26911 .68501 .28384 .6807 .27417 .67269 Mtetra
.27417 .67269 .28384 .6807 .29865 .67636 .28904 .66831 Mtetra
.646 .763 .934 r
.28904 .66831 .29865 .67636 .31355 .672 .30398 .6639 Mtetra
.30398 .6639 .31355 .672 .32853 .66761 .31901 .65947 Mtetra
.647 .763 .934 r
.31901 .65947 .32853 .66761 .3436 .66317 .33413 .65499 Mtetra
.33413 .65499 .3436 .66317 .35875 .65868 .34934 .65047 Mtetra
.648 .764 .933 r
.34934 .65047 .35875 .65868 .37399 .6541 .36463 .64588 Mtetra
.651 .765 .933 r
.36463 .64588 .37399 .6541 .38933 .64939 .38002 .64119 Mtetra
.655 .768 .933 r
.38002 .64119 .38933 .64939 .40475 .64444 .3955 .63631 Mtetra
.662 .773 .932 r
.3955 .63631 .40475 .64444 .42028 .63907 .41107 .63112 Mtetra
.677 .782 .929 r
.41107 .63112 .42028 .63907 .4359 .63293 .42675 .62535 Mtetra
.702 .798 .925 r
.42675 .62535 .4359 .63293 .45163 .62539 .44253 .61855 Mtetra
.743 .824 .914 r
.44253 .61855 .45163 .62539 .46747 .61537 .45842 .60986 Mtetra
.805 .86 .89 r
.45842 .60986 .46747 .61537 .48339 .60114 .47441 .5979 Mtetra
.879 .899 .841 r
.47441 .5979 .48339 .60114 .49937 .58046 .49048 .58063 Mtetra
.941 .923 .763 r
.49048 .58063 .49937 .58046 .51532 .55154 .50657 .55582 Mtetra
.972 .926 .673 r
.50657 .55582 .51532 .55154 .53112 .51503 .52257 .52261 Mtetra
.975 .919 .607 r
.52257 .52261 .53112 .51503 .54668 .4756 .53837 .48367 Mtetra
.969 .921 .593 r
.53837 .48367 .54668 .4756 .56206 .43979 .55393 .44512 Mtetra
.964 .938 .646 r
.55393 .44512 .56206 .43979 .57734 .41173 .56935 .41278 Mtetra
.944 .949 .749 r
.56935 .41278 .57734 .41173 .59267 .39165 .58475 .38875 Mtetra
.886 .922 .842 r
.58475 .38875 .59267 .39165 .60809 .3776 .60022 .37188 Mtetra
.811 .867 .889 r
.60022 .37188 .60809 .3776 .62363 .36742 .6158 .35992 Mtetra
.75 .817 .905 r
.6158 .35992 .62363 .36742 .63929 .35948 .63151 .35094 Mtetra
.711 .784 .909 r
.63151 .35094 .63929 .35948 .65507 .35277 .64733 .34363 Mtetra
.689 .765 .909 r
.64733 .34363 .65507 .35277 .67095 .34672 .66326 .33723 Mtetra
.677 .754 .909 r
.66326 .33723 .67095 .34672 .68693 .341 .6793 .33131 Mtetra
.671 .748 .908 r
.6793 .33131 .68693 .341 .70301 .33545 .69544 .32562 Mtetra
.667 .745 .908 r
.69544 .32562 .70301 .33545 .71919 .32998 .71168 .32004 Mtetra
.666 .743 .908 r
.71168 .32004 .71919 .32998 .73546 .32452 .72802 .3145 Mtetra
.665 .742 .908 r
.72802 .3145 .73546 .32452 .75182 .31906 .74445 .30897 Mtetra
.664 .742 .908 r
.74445 .30897 .75182 .31906 .76828 .31359 .76097 .30344 Mtetra
.76097 .30344 .76828 .31359 .78484 .30809 .7776 .29788 Mtetra
.664 .741 .908 r
.7776 .29788 .78484 .30809 .80149 .30256 .79432 .29229 Mtetra
.79432 .29229 .80149 .30256 .81824 .29701 .81113 .28667 Mtetra
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28103 Mtetra
.82805 .28103 .83509 .29142 .85203 .2858 .84507 .27535 Mtetra
.84507 .27535 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .66459 Mtetra
.2644 .66459 .27417 .67269 .28904 .66831 .27932 .66017 Mtetra
.27932 .66017 .28904 .66831 .30398 .6639 .29431 .65572 Mtetra
.646 .763 .934 r
.29431 .65572 .30398 .6639 .31901 .65947 .3094 .65124 Mtetra
.3094 .65124 .31901 .65947 .33413 .65499 .32457 .64672 Mtetra
.647 .763 .934 r
.32457 .64672 .33413 .65499 .34934 .65047 .33983 .64217 Mtetra
.648 .764 .934 r
.33983 .64217 .34934 .65047 .36463 .64588 .35518 .63755 Mtetra
.649 .765 .933 r
.35518 .63755 .36463 .64588 .38002 .64119 .37062 .63286 Mtetra
.652 .766 .933 r
.37062 .63286 .38002 .64119 .3955 .63631 .38615 .62802 Mtetra
.658 .77 .932 r
.38615 .62802 .3955 .63631 .41107 .63112 .40178 .62295 Mtetra
.668 .777 .931 r
.40178 .62295 .41107 .63112 .42675 .62535 .4175 .61744 Mtetra
.687 .789 .928 r
.4175 .61744 .42675 .62535 .44253 .61855 .43334 .61117 Mtetra
.72 .81 .921 r
.43334 .61117 .44253 .61855 .45842 .60986 .44928 .60348 Mtetra
.772 .841 .905 r
.44928 .60348 .45842 .60986 .47441 .5979 .46533 .59328 Mtetra
.841 .881 .87 r
.46533 .59328 .47441 .5979 .49048 .58063 .48147 .57886 Mtetra
.913 .914 .805 r
.48147 .57886 .49048 .58063 .50657 .55582 .49768 .55794 Mtetra
.961 .927 .717 r
.49768 .55794 .50657 .55582 .52257 .52261 .51385 .52871 Mtetra
.976 .922 .635 r
.51385 .52871 .52257 .52261 .53837 .48367 .52987 .49186 Mtetra
.972 .918 .592 r
.52987 .49186 .53837 .48367 .55393 .44512 .54566 .45208 Mtetra
.967 .928 .611 r
.54566 .45208 .55393 .44512 .56935 .41278 .56124 .41594 Mtetra
.958 .947 .695 r
.56124 .41594 .56935 .41278 .58475 .38875 .57674 .38761 Mtetra
.919 .941 .8 r
.57674 .38761 .58475 .38875 .60022 .37188 .59227 .36731 Mtetra
.848 .895 .871 r
.59227 .36731 .60022 .37188 .6158 .35992 .6079 .35307 Mtetra
.778 .84 .9 r
.6079 .35307 .6158 .35992 .63151 .35094 .62364 .34272 Mtetra
.728 .799 .908 r
.62364 .34272 .63151 .35094 .64733 .34363 .63952 .33462 Mtetra
.699 .773 .909 r
.63952 .33462 .64733 .34363 .66326 .33723 .6555 .32777 Mtetra
.682 .758 .909 r
.6555 .32777 .66326 .33723 .6793 .33131 .6716 .32157 Mtetra
.673 .75 .909 r
.6716 .32157 .6793 .33131 .69544 .32562 .6878 .31571 Mtetra
.669 .746 .908 r
.6878 .31571 .69544 .32562 .71168 .32004 .7041 .31001 Mtetra
.666 .744 .908 r
.7041 .31001 .71168 .32004 .72802 .3145 .7205 .30439 Mtetra
.665 .743 .908 r
.7205 .30439 .72802 .3145 .74445 .30897 .73699 .29878 Mtetra
.664 .742 .908 r
.73699 .29878 .74445 .30897 .76097 .30344 .75359 .29318 Mtetra
.75359 .29318 .76097 .30344 .7776 .29788 .77028 .28755 Mtetra
.664 .741 .908 r
.77028 .28755 .7776 .29788 .79432 .29229 .78706 .2819 Mtetra
.78706 .2819 .79432 .29229 .81113 .28667 .80395 .27623 Mtetra
.80395 .27623 .81113 .28667 .82805 .28103 .82094 .27052 Mtetra
.82094 .27052 .82805 .28103 .84507 .27535 .83803 .26477 Mtetra
.83803 .26477 .84507 .27535 .86218 .26963 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .66459 .25453 .65641 Mtetra
.25453 .65641 .2644 .66459 .27932 .66017 .2695 .65194 Mtetra
.2695 .65194 .27932 .66017 .29431 .65572 .28454 .64745 Mtetra
.646 .763 .934 r
.28454 .64745 .29431 .65572 .3094 .65124 .29968 .64292 Mtetra
.29968 .64292 .3094 .65124 .32457 .64672 .3149 .63836 Mtetra
.647 .763 .934 r
.3149 .63836 .32457 .64672 .33983 .64217 .33022 .63377 Mtetra
.33022 .63377 .33983 .64217 .35518 .63755 .34562 .62912 Mtetra
.648 .764 .933 r
.34562 .62912 .35518 .63755 .37062 .63286 .36111 .62441 Mtetra
.651 .765 .933 r
.36111 .62441 .37062 .63286 .38615 .62802 .3767 .61959 Mtetra
.655 .768 .933 r
.3767 .61959 .38615 .62802 .40178 .62295 .39238 .61458 Mtetra
.662 .773 .932 r
.39238 .61458 .40178 .62295 .4175 .61744 .40816 .60926 Mtetra
.677 .782 .929 r
.40816 .60926 .4175 .61744 .43334 .61117 .42405 .60336 Mtetra
.702 .798 .925 r
.42405 .60336 .43334 .61117 .44928 .60348 .44004 .59641 Mtetra
.743 .824 .914 r
.44004 .59641 .44928 .60348 .46533 .59328 .45614 .58756 Mtetra
.805 .861 .89 r
.45614 .58756 .46533 .59328 .48147 .57886 .47236 .57541 Mtetra
.879 .899 .841 r
.47236 .57541 .48147 .57886 .49768 .55794 .48865 .55792 Mtetra
.941 .924 .763 r
.48865 .55792 .49768 .55794 .51385 .52871 .50497 .53284 Mtetra
.972 .926 .673 r
.50497 .53284 .51385 .52871 .52987 .49186 .52119 .49931 Mtetra
.975 .919 .607 r
.52119 .49931 .52987 .49186 .54566 .45208 .53722 .46 Mtetra
.969 .921 .593 r
.53722 .46 .54566 .45208 .56124 .41594 .553 .42111 Mtetra
.964 .938 .647 r
.553 .42111 .56124 .41594 .57674 .38761 .56863 .38846 Mtetra
.944 .949 .749 r
.56863 .38846 .57674 .38761 .59227 .36731 .58424 .36419 Mtetra
.886 .922 .842 r
.58424 .36419 .59227 .36731 .6079 .35307 .59992 .34711 Mtetra
.811 .867 .889 r
.59992 .34711 .6079 .35307 .62364 .34272 .61571 .33497 Mtetra
.75 .817 .905 r
.61571 .33497 .62364 .34272 .63952 .33462 .63163 .32583 Mtetra
.711 .784 .909 r
.63163 .32583 .63952 .33462 .6555 .32777 .64766 .31837 Mtetra
.689 .765 .909 r
.64766 .31837 .6555 .32777 .6716 .32157 .66381 .31182 Mtetra
.677 .754 .909 r
.66381 .31182 .6716 .32157 .6878 .31571 .68007 .30574 Mtetra
.671 .748 .908 r
.68007 .30574 .6878 .31571 .7041 .31001 .69643 .29991 Mtetra
.667 .745 .908 r
.69643 .29991 .7041 .31001 .7205 .30439 .7129 .29418 Mtetra
.666 .743 .908 r
.7129 .29418 .7205 .30439 .73699 .29878 .72946 .28849 Mtetra
.665 .742 .908 r
.72946 .28849 .73699 .29878 .75359 .29318 .74612 .28281 Mtetra
.664 .742 .908 r
.74612 .28281 .75359 .29318 .77028 .28755 .76288 .27712 Mtetra
.76288 .27712 .77028 .28755 .78706 .2819 .77973 .27141 Mtetra
.664 .741 .908 r
.77973 .27141 .78706 .2819 .80395 .27623 .79669 .26567 Mtetra
.79669 .26567 .80395 .27623 .82094 .27052 .81375 .25989 Mtetra
.81375 .25989 .82094 .27052 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65641 .24456 .64815 Mtetra
.24456 .64815 .25453 .65641 .2695 .65194 .25957 .64363 Mtetra
.25957 .64363 .2695 .65194 .28454 .64745 .27467 .63909 Mtetra
.27467 .63909 .28454 .64745 .29968 .64292 .28986 .63452 Mtetra
.646 .763 .934 r
.28986 .63452 .29968 .64292 .3149 .63836 .30513 .62991 Mtetra
.30513 .62991 .3149 .63836 .33022 .63377 .3205 .62527 Mtetra
.647 .763 .934 r
.3205 .62527 .33022 .63377 .34562 .62912 .33596 .62059 Mtetra
.648 .764 .934 r
.33596 .62059 .34562 .62912 .36111 .62441 .3515 .61585 Mtetra
.649 .765 .933 r
.3515 .61585 .36111 .62441 .3767 .61959 .36715 .61103 Mtetra
.652 .766 .933 r
.36715 .61103 .3767 .61959 .39238 .61458 .38288 .60606 Mtetra
.658 .77 .932 r
.38288 .60606 .39238 .61458 .40816 .60926 .39872 .60085 Mtetra
.668 .777 .931 r
.39872 .60085 .40816 .60926 .42405 .60336 .41466 .59522 Mtetra
.687 .789 .928 r
.41466 .59522 .42405 .60336 .44004 .59641 .4307 .5888 Mtetra
.72 .81 .921 r
.4307 .5888 .44004 .59641 .45614 .58756 .44686 .58095 Mtetra
.772 .841 .905 r
.44686 .58095 .45614 .58756 .47236 .57541 .46313 .57059 Mtetra
.841 .881 .87 r
.46313 .57059 .47236 .57541 .48865 .55792 .4795 .55595 Mtetra
.913 .914 .805 r
.4795 .55595 .48865 .55792 .50497 .53284 .49594 .53479 Mtetra
.961 .927 .717 r
.49594 .53479 .50497 .53284 .52119 .49931 .51234 .50526 Mtetra
.976 .922 .635 r
.51234 .50526 .52119 .49931 .53722 .46 .52859 .46806 Mtetra
.972 .918 .592 r
.52859 .46806 .53722 .46 .553 .42111 .54461 .42791 Mtetra
.967 .928 .612 r
.54461 .42791 .553 .42111 .56863 .38846 .56041 .39144 Mtetra
.958 .947 .695 r
.56041 .39144 .56863 .38846 .58424 .36419 .57612 .36283 Mtetra
.919 .941 .8 r
.57612 .36283 .58424 .36419 .59992 .34711 .59186 .34231 Mtetra
.848 .895 .871 r
.59186 .34231 .59992 .34711 .61571 .33497 .6077 .32788 Mtetra
.778 .84 .9 r
.6077 .32788 .61571 .33497 .63163 .32583 .62366 .31735 Mtetra
.728 .799 .908 r
.62366 .31735 .63163 .32583 .64766 .31837 .63975 .3091 Mtetra
.699 .773 .909 r
.63975 .3091 .64766 .31837 .66381 .31182 .65595 .30209 Mtetra
.682 .758 .909 r
.65595 .30209 .66381 .31182 .68007 .30574 .67227 .29574 Mtetra
.673 .75 .909 r
.67227 .29574 .68007 .30574 .69643 .29991 .68869 .28972 Mtetra
.669 .746 .908 r
.68869 .28972 .69643 .29991 .7129 .29418 .70522 .28388 Mtetra
.666 .744 .908 r
.70522 .28388 .7129 .29418 .72946 .28849 .72184 .2781 Mtetra
.665 .743 .908 r
.72184 .2781 .72946 .28849 .74612 .28281 .73857 .27234 Mtetra
.664 .742 .908 r
.73857 .27234 .74612 .28281 .76288 .27712 .7554 .26658 Mtetra
.7554 .26658 .76288 .27712 .77973 .27141 .77232 .2608 Mtetra
.664 .741 .908 r
.77232 .2608 .77973 .27141 .79669 .26567 .78935 .25499 Mtetra
.78935 .25499 .79669 .26567 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63909 .26469 .63064 Mtetra
.26469 .63064 .27467 .63909 .28986 .63452 .27993 .62602 Mtetra
.646 .763 .934 r
.27993 .62602 .28986 .63452 .30513 .62991 .29526 .62137 Mtetra
.29526 .62137 .30513 .62991 .3205 .62527 .31068 .61668 Mtetra
.647 .763 .934 r
.31068 .61668 .3205 .62527 .33596 .62059 .32619 .61196 Mtetra
.32619 .61196 .33596 .62059 .3515 .61585 .34179 .60719 Mtetra
.648 .764 .933 r
.34179 .60719 .3515 .61585 .36715 .61103 .35749 .60234 Mtetra
.651 .765 .933 r
.35749 .60234 .36715 .61103 .38288 .60606 .37328 .59739 Mtetra
.655 .768 .933 r
.37328 .59739 .38288 .60606 .39872 .60085 .38917 .59225 Mtetra
.662 .773 .932 r
.38917 .59225 .39872 .60085 .41466 .59522 .40517 .58679 Mtetra
.677 .782 .929 r
.40517 .58679 .41466 .59522 .4307 .5888 .42127 .58075 Mtetra
.702 .798 .925 r
.42127 .58075 .4307 .5888 .44686 .58095 .43748 .57365 Mtetra
.743 .824 .914 r
.43748 .57365 .44686 .58095 .46313 .57059 .4538 .56464 Mtetra
.805 .861 .89 r
.4538 .56464 .46313 .57059 .4795 .55595 .47024 .5523 Mtetra
.879 .9 .841 r
.47024 .5523 .4795 .55595 .49594 .53479 .48677 .53458 Mtetra
.941 .924 .763 r
.48677 .53458 .49594 .53479 .51234 .50526 .50332 .50922 Mtetra
.972 .926 .673 r
.50332 .50922 .51234 .50526 .52859 .46806 .51978 .47535 Mtetra
.975 .919 .606 r
.51978 .47535 .52859 .46806 .54461 .42791 .53604 .43568 Mtetra
.97 .921 .593 r
.53604 .43568 .54461 .42791 .56041 .39144 .55205 .39644 Mtetra
.964 .938 .647 r
.55205 .39644 .56041 .39144 .57612 .36283 .5679 .36349 Mtetra
.944 .949 .749 r
.5679 .36349 .57612 .36283 .59186 .34231 .58372 .33896 Mtetra
.886 .921 .842 r
.58372 .33896 .59186 .34231 .6077 .32788 .59961 .32167 Mtetra
.811 .867 .889 r
.59961 .32167 .6077 .32788 .62366 .31735 .61562 .30935 Mtetra
.75 .817 .905 r
.61562 .30935 .62366 .31735 .63975 .3091 .63175 .30003 Mtetra
.711 .784 .909 r
.63175 .30003 .63975 .3091 .65595 .30209 .64801 .29242 Mtetra
.689 .765 .909 r
.64801 .29242 .65595 .30209 .67227 .29574 .66438 .28571 Mtetra
.677 .754 .909 r
.66438 .28571 .67227 .29574 .68869 .28972 .68086 .27948 Mtetra
.671 .748 .908 r
.68086 .27948 .68869 .28972 .70522 .28388 .69745 .27349 Mtetra
.667 .745 .908 r
.69745 .27349 .70522 .28388 .72184 .2781 .71414 .2676 Mtetra
.666 .743 .908 r
.71414 .2676 .72184 .2781 .73857 .27234 .73094 .26176 Mtetra
.665 .742 .908 r
.73094 .26176 .73857 .27234 .7554 .26658 .74783 .25592 Mtetra
.664 .742 .908 r
.74783 .25592 .7554 .26658 .77232 .2608 .76483 .25007 Mtetra
.76483 .25007 .77232 .2608 .78935 .25499 .78193 .2442 Mtetra
.664 .741 .908 r
.78193 .2442 .78935 .25499 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62673 Mtetra
.2394 .62673 .24954 .63523 .26469 .63064 .2546 .62209 Mtetra
.2546 .62209 .26469 .63064 .27993 .62602 .2699 .61743 Mtetra
.2699 .61743 .27993 .62602 .29526 .62137 .28528 .61273 Mtetra
.646 .763 .934 r
.28528 .61273 .29526 .62137 .31068 .61668 .30075 .608 Mtetra
.30075 .608 .31068 .61668 .32619 .61196 .31632 .60323 Mtetra
.647 .763 .934 r
.31632 .60323 .32619 .61196 .34179 .60719 .33198 .59842 Mtetra
.648 .764 .934 r
.33198 .59842 .34179 .60719 .35749 .60234 .34773 .59355 Mtetra
.649 .765 .933 r
.34773 .59355 .35749 .60234 .37328 .59739 .36358 .58859 Mtetra
.652 .766 .933 r
.36358 .58859 .37328 .59739 .38917 .59225 .37953 .58349 Mtetra
.658 .77 .932 r
.37953 .58349 .38917 .59225 .40517 .58679 .39557 .57814 Mtetra
.668 .777 .931 r
.39557 .57814 .40517 .58679 .42127 .58075 .41173 .57236 Mtetra
.687 .789 .928 r
.41173 .57236 .42127 .58075 .43748 .57365 .42799 .56579 Mtetra
.72 .81 .921 r
.42799 .56579 .43748 .57365 .4538 .56464 .44437 .55779 Mtetra
.772 .841 .905 r
.44437 .55779 .4538 .56464 .47024 .5523 .46087 .54725 Mtetra
.841 .881 .87 r
.46087 .54725 .47024 .5523 .48677 .53458 .47748 .5324 Mtetra
.913 .915 .805 r
.47748 .5324 .48677 .53458 .50332 .50922 .49414 .51098 Mtetra
.961 .927 .717 r
.49414 .51098 .50332 .50922 .51978 .47535 .51079 .48114 Mtetra
.976 .922 .634 r
.51079 .48114 .51978 .47535 .53604 .43568 .52728 .44358 Mtetra
.972 .918 .592 r
.52728 .44358 .53604 .43568 .55205 .39644 .54353 .40307 Mtetra
.967 .928 .612 r
.54353 .40307 .55205 .39644 .5679 .36349 .55955 .36627 Mtetra
.958 .947 .695 r
.55955 .36627 .5679 .36349 .58372 .33896 .57548 .33738 Mtetra
.919 .94 .801 r
.57548 .33738 .58372 .33896 .59961 .32167 .59144 .31662 Mtetra
.848 .895 .871 r
.59144 .31662 .59961 .32167 .61562 .30935 .60749 .302 Mtetra
.778 .84 .899 r
.60749 .302 .61562 .30935 .63175 .30003 .62367 .29129 Mtetra
.728 .799 .908 r
.62367 .29129 .63175 .30003 .64801 .29242 .63998 .28287 Mtetra
.699 .773 .909 r
.63998 .28287 .64801 .29242 .66438 .28571 .65641 .2757 Mtetra
.682 .758 .909 r
.65641 .2757 .66438 .28571 .68086 .27948 .67295 .26919 Mtetra
.673 .75 .909 r
.67295 .26919 .68086 .27948 .69745 .27349 .68961 .26302 Mtetra
.669 .746 .908 r
.68961 .26302 .69745 .27349 .71414 .2676 .70636 .25701 Mtetra
.666 .744 .908 r
.70636 .25701 .71414 .2676 .73094 .26176 .72323 .25107 Mtetra
.665 .743 .908 r
.72323 .25107 .73094 .26176 .74783 .25592 .74019 .24516 Mtetra
.664 .742 .908 r
.74019 .24516 .74783 .25592 .76483 .25007 .75726 .23923 Mtetra
.75726 .23923 .76483 .25007 .78193 .2442 .77443 .23329 Mtetra
.664 .741 .908 r
.77443 .23329 .78193 .2442 .79913 .23829 .7917 .22732 Mtetra
.7917 .22732 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21528 Mtetra
.646 .762 .934 r
.18391 .63206 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62673 .22915 .61815 Mtetra
.22915 .61815 .2394 .62673 .2546 .62209 .24441 .61346 Mtetra
.24441 .61346 .2546 .62209 .2699 .61743 .25975 .60874 Mtetra
.25975 .60874 .2699 .61743 .28528 .61273 .27519 .60399 Mtetra
.646 .763 .934 r
.27519 .60399 .28528 .61273 .30075 .608 .29072 .59921 Mtetra
.29072 .59921 .30075 .608 .31632 .60323 .30634 .5944 Mtetra
.647 .763 .934 r
.30634 .5944 .31632 .60323 .33198 .59842 .32205 .58954 Mtetra
.32205 .58954 .33198 .59842 .34773 .59355 .33786 .58464 Mtetra
.648 .764 .933 r
.33786 .58464 .34773 .59355 .36358 .58859 .35377 .57966 Mtetra
.651 .765 .933 r
.35377 .57966 .36358 .58859 .37953 .58349 .36977 .57457 Mtetra
.655 .768 .933 r
.36977 .57457 .37953 .58349 .39557 .57814 .38588 .56929 Mtetra
.662 .773 .932 r
.38588 .56929 .39557 .57814 .41173 .57236 .40209 .56369 Mtetra
.677 .782 .929 r
.40209 .56369 .41173 .57236 .42799 .56579 .41841 .5575 Mtetra
.702 .798 .925 r
.41841 .5575 .42799 .56579 .44437 .55779 .43484 .55024 Mtetra
.743 .824 .914 r
.43484 .55024 .44437 .55779 .46087 .54725 .4514 .54106 Mtetra
.805 .861 .891 r
.4514 .54106 .46087 .54725 .47748 .5324 .46807 .52853 Mtetra
.879 .9 .841 r
.46807 .52853 .47748 .5324 .49414 .51098 .48483 .51057 Mtetra
.942 .924 .762 r
.48483 .51057 .49414 .51098 .51079 .48114 .50162 .48492 Mtetra
.972 .926 .672 r
.50162 .48492 .51079 .48114 .52728 .44358 .51833 .45072 Mtetra
.975 .919 .606 r
.51833 .45072 .52728 .44358 .54353 .40307 .53482 .41068 Mtetra
.97 .921 .593 r
.53482 .41068 .54353 .40307 .55955 .36627 .55107 .37108 Mtetra
.965 .938 .647 r
.55107 .37108 .55955 .36627 .57548 .33738 .56714 .33782 Mtetra
.944 .949 .75 r
.56714 .33782 .57548 .33738 .59144 .31662 .58318 .31303 Mtetra
.886 .921 .842 r
.58318 .31303 .59144 .31662 .60749 .302 .59929 .29553 Mtetra
.811 .867 .889 r
.59929 .29553 .60749 .302 .62367 .29129 .61552 .28302 Mtetra
.75 .817 .905 r
.61552 .28302 .62367 .29129 .63998 .28287 .63188 .27353 Mtetra
.711 .784 .909 r
.63188 .27353 .63998 .28287 .65641 .2757 .64836 .26574 Mtetra
.689 .765 .909 r
.64836 .26574 .65641 .2757 .67295 .26919 .66496 .25888 Mtetra
.677 .754 .909 r
.66496 .25888 .67295 .26919 .68961 .26302 .68168 .25248 Mtetra
.671 .748 .908 r
.68168 .25248 .68961 .26302 .70636 .25701 .6985 .24633 Mtetra
.667 .745 .908 r
.6985 .24633 .70636 .25701 .72323 .25107 .71543 .24028 Mtetra
.666 .743 .908 r
.71543 .24028 .72323 .25107 .74019 .24516 .73246 .23428 Mtetra
.665 .742 .908 r
.73246 .23428 .74019 .24516 .75726 .23923 .7496 .22828 Mtetra
.664 .742 .908 r
.7496 .22828 .75726 .23923 .77443 .23329 .76684 .22226 Mtetra
.76684 .22226 .77443 .23329 .7917 .22732 .78419 .21622 Mtetra
.664 .741 .908 r
.78419 .21622 .7917 .22732 .80908 .22131 .80164 .21015 Mtetra
.80164 .21015 .80908 .22131 .82657 .21528 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63206 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .60399 .26499 .59516 Mtetra
.26499 .59516 .27519 .60399 .29072 .59921 .28057 .59033 Mtetra
.646 .763 .934 r
.28057 .59033 .29072 .59921 .30634 .5944 .29625 .58547 Mtetra
.29625 .58547 .30634 .5944 .32205 .58954 .31202 .58057 Mtetra
.647 .763 .934 r
.31202 .58057 .32205 .58954 .33786 .58464 .32789 .57562 Mtetra
.648 .764 .934 r
.32789 .57562 .33786 .58464 .35377 .57966 .34385 .57061 Mtetra
.649 .765 .933 r
.34385 .57061 .35377 .57966 .36977 .57457 .35991 .56551 Mtetra
.652 .766 .933 r
.35991 .56551 .36977 .57457 .38588 .56929 .37607 .56027 Mtetra
.658 .77 .932 r
.37607 .56027 .38588 .56929 .40209 .56369 .39234 .55478 Mtetra
.668 .777 .931 r
.39234 .55478 .40209 .56369 .41841 .5575 .40872 .54886 Mtetra
.687 .789 .928 r
.40872 .54886 .41841 .5575 .43484 .55024 .42521 .54213 Mtetra
.72 .81 .921 r
.42521 .54213 .43484 .55024 .4514 .54106 .44182 .53397 Mtetra
.772 .842 .905 r
.44182 .53397 .4514 .54106 .46807 .52853 .45855 .52323 Mtetra
.842 .881 .87 r
.45855 .52323 .46807 .52853 .48483 .51057 .47539 .50817 Mtetra
.913 .915 .805 r
.47539 .50817 .48483 .51057 .50162 .48492 .4923 .48649 Mtetra
.961 .928 .717 r
.4923 .48649 .50162 .48492 .51833 .45072 .50919 .45633 Mtetra
.976 .922 .634 r
.50919 .45633 .51833 .45072 .53482 .41068 .52593 .41841 Mtetra
.972 .918 .592 r
.52593 .41841 .53482 .41068 .55107 .37108 .54241 .37753 Mtetra
.967 .928 .612 r
.54241 .37753 .55107 .37108 .56714 .33782 .55867 .34039 Mtetra
.958 .947 .696 r
.55867 .34039 .56714 .33782 .58318 .31303 .57483 .31122 Mtetra
.919 .94 .801 r
.57483 .31122 .58318 .31303 .59929 .29553 .59101 .29022 Mtetra
.848 .895 .871 r
.59101 .29022 .59929 .29553 .61552 .28302 .60728 .27539 Mtetra
.778 .84 .899 r
.60728 .27539 .61552 .28302 .63188 .27353 .62369 .26451 Mtetra
.728 .799 .908 r
.62369 .26451 .63188 .27353 .64836 .26574 .64022 .25591 Mtetra
.699 .773 .909 r
.64022 .25591 .64836 .26574 .66496 .25888 .65688 .24857 Mtetra
.682 .758 .909 r
.65688 .24857 .66496 .25888 .68168 .25248 .67366 .2419 Mtetra
.673 .75 .909 r
.67366 .2419 .68168 .25248 .6985 .24633 .69055 .23556 Mtetra
.669 .746 .908 r
.69055 .23556 .6985 .24633 .71543 .24028 .70754 .22939 Mtetra
.666 .744 .908 r
.70754 .22939 .71543 .24028 .73246 .23428 .72465 .22329 Mtetra
.665 .743 .908 r
.72465 .22329 .73246 .23428 .7496 .22828 .74186 .2172 Mtetra
.664 .742 .908 r
.74186 .2172 .7496 .22828 .76684 .22226 .75917 .21111 Mtetra
.75917 .21111 .76684 .22226 .78419 .21622 .77659 .205 Mtetra
.664 .741 .908 r
.77659 .205 .78419 .21622 .80164 .21015 .79412 .19885 Mtetra
.79412 .19885 .80164 .21015 .8192 .20404 .81176 .19268 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .5959 Mtetra
.22368 .5959 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59516 .25468 .58623 Mtetra
.25468 .58623 .26499 .59516 .28057 .59033 .27032 .58135 Mtetra
.646 .763 .934 r
.27032 .58135 .28057 .59033 .29625 .58547 .28605 .57643 Mtetra
.28605 .57643 .29625 .58547 .31202 .58057 .30188 .57148 Mtetra
.647 .763 .934 r
.30188 .57148 .31202 .58057 .32789 .57562 .3178 .56649 Mtetra
.3178 .56649 .32789 .57562 .34385 .57061 .33382 .56145 Mtetra
.648 .764 .933 r
.33382 .56145 .34385 .57061 .35991 .56551 .34994 .55633 Mtetra
.651 .765 .933 r
.34994 .55633 .35991 .56551 .37607 .56027 .36616 .55109 Mtetra
.655 .768 .933 r
.36616 .55109 .37607 .56027 .39234 .55478 .38249 .54567 Mtetra
.662 .773 .932 r
.38249 .54567 .39234 .55478 .40872 .54886 .39892 .53992 Mtetra
.676 .782 .93 r
.39892 .53992 .40872 .54886 .42521 .54213 .41547 .53358 Mtetra
.701 .798 .925 r
.41547 .53358 .42521 .54213 .44182 .53397 .43213 .52616 Mtetra
.743 .824 .915 r
.43213 .52616 .44182 .53397 .45855 .52323 .44892 .5168 Mtetra
.805 .861 .891 r
.44892 .5168 .45855 .52323 .47539 .50817 .46583 .50406 Mtetra
.879 .9 .842 r
.46583 .50406 .47539 .50817 .4923 .48649 .48284 .48587 Mtetra
.942 .924 .762 r
.48284 .48587 .4923 .48649 .50919 .45633 .49988 .45993 Mtetra
.972 .926 .672 r
.49988 .45993 .50919 .45633 .52593 .41841 .51683 .42538 Mtetra
.975 .919 .606 r
.51683 .42538 .52593 .41841 .54241 .37753 .53357 .38497 Mtetra
.97 .921 .593 r
.53357 .38497 .54241 .37753 .55867 .34039 .55006 .345 Mtetra
.965 .938 .648 r
.55006 .345 .55867 .34039 .57483 .31122 .56636 .31143 Mtetra
.944 .949 .75 r
.56636 .31143 .57483 .31122 .59101 .29022 .58263 .28638 Mtetra
.886 .921 .842 r
.58263 .28638 .59101 .29022 .60728 .27539 .59897 .26866 Mtetra
.811 .867 .889 r
.59897 .26866 .60728 .27539 .62369 .26451 .61542 .25595 Mtetra
.75 .817 .905 r
.61542 .25595 .62369 .26451 .64022 .25591 .63201 .24628 Mtetra
.711 .784 .909 r
.63201 .24628 .64022 .25591 .65688 .24857 .64872 .23832 Mtetra
.689 .765 .909 r
.64872 .23832 .65688 .24857 .67366 .2419 .66556 .23129 Mtetra
.677 .754 .909 r
.66556 .23129 .67366 .2419 .69055 .23556 .68251 .22473 Mtetra
.671 .748 .908 r
.68251 .22473 .69055 .23556 .70754 .22939 .69957 .2184 Mtetra
.667 .745 .908 r
.69957 .2184 .70754 .22939 .72465 .22329 .71675 .21219 Mtetra
.666 .743 .908 r
.71675 .21219 .72465 .22329 .74186 .2172 .73403 .20601 Mtetra
.665 .742 .908 r
.73403 .20601 .74186 .2172 .75917 .21111 .75142 .19984 Mtetra
.664 .742 .908 r
.75142 .19984 .75917 .21111 .77659 .205 .76891 .19365 Mtetra
.76891 .19365 .77659 .205 .79412 .19885 .78652 .18743 Mtetra
.664 .741 .908 r
.78652 .18743 .79412 .19885 .81176 .19268 .80423 .18119 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .5959 .21314 .58698 Mtetra
.21314 .58698 .22368 .5959 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58623 .24425 .5772 Mtetra
.24425 .5772 .25468 .58623 .27032 .58135 .25994 .57227 Mtetra
.25994 .57227 .27032 .58135 .28605 .57643 .27573 .5673 Mtetra
.646 .763 .934 r
.27573 .5673 .28605 .57643 .30188 .57148 .29162 .5623 Mtetra
.29162 .5623 .30188 .57148 .3178 .56649 .3076 .55726 Mtetra
.647 .763 .934 r
.3076 .55726 .3178 .56649 .33382 .56145 .32368 .55217 Mtetra
.648 .764 .934 r
.32368 .55217 .33382 .56145 .34994 .55633 .33986 .54702 Mtetra
.649 .765 .933 r
.33986 .54702 .34994 .55633 .36616 .55109 .35614 .54177 Mtetra
.652 .766 .933 r
.35614 .54177 .36616 .55109 .38249 .54567 .37252 .53639 Mtetra
.658 .77 .932 r
.37252 .53639 .38249 .54567 .39892 .53992 .38901 .53075 Mtetra
.668 .777 .931 r
.38901 .53075 .39892 .53992 .41547 .53358 .40562 .52467 Mtetra
.687 .789 .928 r
.40562 .52467 .41547 .53358 .43213 .52616 .42234 .51778 Mtetra
.72 .81 .921 r
.42234 .51778 .43213 .52616 .44892 .5168 .43918 .50944 Mtetra
.772 .842 .905 r
.43918 .50944 .44892 .5168 .46583 .50406 .45616 .49852 Mtetra
.842 .881 .87 r
.45616 .49852 .46583 .50406 .48284 .48587 .47324 .48324 Mtetra
.913 .915 .805 r
.47324 .48324 .48284 .48587 .49988 .45993 .49041 .46129 Mtetra
.961 .928 .716 r
.49041 .46129 .49988 .45993 .51683 .42538 .50755 .43081 Mtetra
.976 .922 .634 r
.50755 .43081 .51683 .42538 .53357 .38497 .52454 .39252 Mtetra
.972 .918 .592 r
.52454 .39252 .53357 .38497 .55006 .345 .54127 .35127 Mtetra
.967 .928 .612 r
.54127 .35127 .55006 .345 .56636 .31143 .55777 .31378 Mtetra
.958 .947 .696 r
.55777 .31378 .56636 .31143 .58263 .28638 .57415 .28432 Mtetra
.919 .94 .801 r
.57415 .28432 .58263 .28638 .59897 .26866 .59056 .26308 Mtetra
.848 .895 .871 r
.59056 .26308 .59897 .26866 .61542 .25595 .60707 .24804 Mtetra
.778 .84 .899 r
.60707 .24804 .61542 .25595 .63201 .24628 .62371 .23697 Mtetra
.728 .799 .908 r
.62371 .23697 .63201 .24628 .64872 .23832 .64047 .22819 Mtetra
.699 .773 .909 r
.64047 .22819 .64872 .23832 .66556 .23129 .65737 .22068 Mtetra
.682 .758 .909 r
.65737 .22068 .66556 .23129 .68251 .22473 .67439 .21383 Mtetra
.673 .75 .909 r
.67439 .21383 .68251 .22473 .69957 .2184 .69152 .20733 Mtetra
.669 .746 .908 r
.69152 .20733 .69957 .2184 .71675 .21219 .70876 .20098 Mtetra
.666 .744 .908 r
.70876 .20098 .71675 .21219 .73403 .20601 .72611 .1947 Mtetra
.665 .743 .908 r
.72611 .1947 .73403 .20601 .75142 .19984 .74357 .18844 Mtetra
.664 .742 .908 r
.74357 .18844 .75142 .19984 .76891 .19365 .76114 .18218 Mtetra
.76114 .18218 .76891 .19365 .78652 .18743 .77882 .17589 Mtetra
.664 .741 .908 r
.77882 .17589 .78652 .18743 .80423 .18119 .79661 .16956 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .5772 .23371 .56807 Mtetra
.23371 .56807 .24425 .5772 .25994 .57227 .24946 .56308 Mtetra
.24946 .56308 .25994 .57227 .27573 .5673 .2653 .55806 Mtetra
.646 .763 .934 r
.2653 .55806 .27573 .5673 .29162 .5623 .28124 .55301 Mtetra
.28124 .55301 .29162 .5623 .3076 .55726 .29728 .54791 Mtetra
.647 .763 .934 r
.29728 .54791 .3076 .55726 .32368 .55217 .31342 .54278 Mtetra
.31342 .54278 .32368 .55217 .33986 .54702 .32966 .53759 Mtetra
.648 .764 .933 r
.32966 .53759 .33986 .54702 .35614 .54177 .346 .53232 Mtetra
.651 .765 .933 r
.346 .53232 .35614 .54177 .37252 .53639 .36244 .52694 Mtetra
.655 .768 .933 r
.36244 .52694 .37252 .53639 .38901 .53075 .379 .52137 Mtetra
.662 .773 .932 r
.379 .52137 .38901 .53075 .40562 .52467 .39566 .51546 Mtetra
.676 .782 .93 r
.39566 .51546 .40562 .52467 .42234 .51778 .41244 .50896 Mtetra
.701 .798 .925 r
.41244 .50896 .42234 .51778 .43918 .50944 .42934 .50137 Mtetra
.743 .824 .915 r
.42934 .50137 .43918 .50944 .45616 .49852 .44637 .49182 Mtetra
.805 .861 .891 r
.44637 .49182 .45616 .49852 .47324 .48324 .46353 .47888 Mtetra
.879 .9 .842 r
.46353 .47888 .47324 .48324 .49041 .46129 .48079 .46044 Mtetra
.942 .925 .762 r
.48079 .46044 .49041 .46129 .50755 .43081 .49808 .4342 Mtetra
.972 .926 .672 r
.49808 .4342 .50755 .43081 .52454 .39252 .51529 .3993 Mtetra
.975 .919 .606 r
.51529 .3993 .52454 .39252 .54127 .35127 .53229 .35851 Mtetra
.97 .921 .594 r
.53229 .35851 .54127 .35127 .55777 .31378 .54902 .31818 Mtetra
.965 .938 .648 r
.54902 .31818 .55777 .31378 .57415 .28432 .56556 .28429 Mtetra
.944 .948 .75 r
.56556 .28429 .57415 .28432 .59056 .26308 .58206 .25898 Mtetra
.886 .921 .842 r
.58206 .25898 .59056 .26308 .60707 .24804 .59863 .24102 Mtetra
.811 .866 .889 r
.59863 .24102 .60707 .24804 .62371 .23697 .61532 .22811 Mtetra
.75 .817 .905 r
.61532 .22811 .62371 .23697 .64047 .22819 .63214 .21826 Mtetra
.711 .784 .909 r
.63214 .21826 .64047 .22819 .65737 .22068 .64909 .21012 Mtetra
.689 .765 .909 r
.64909 .21012 .65737 .22068 .67439 .21383 .66617 .20291 Mtetra
.677 .754 .909 r
.66617 .20291 .67439 .21383 .69152 .20733 .68337 .19617 Mtetra
.671 .748 .908 r
.68337 .19617 .69152 .20733 .70876 .20098 .70068 .18967 Mtetra
.667 .745 .908 r
.70068 .18967 .70876 .20098 .72611 .1947 .7181 .18328 Mtetra
.666 .743 .908 r
.7181 .18328 .72611 .1947 .74357 .18844 .73564 .17693 Mtetra
.665 .742 .908 r
.73564 .17693 .74357 .18844 .76114 .18218 .75328 .17058 Mtetra
.664 .742 .908 r
.75328 .17058 .76114 .18218 .77882 .17589 .77104 .16421 Mtetra
.77104 .16421 .77882 .17589 .79661 .16956 .78891 .15781 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56807 .22305 .55884 Mtetra
.22305 .55884 .23371 .56807 .24946 .56308 .23885 .5538 Mtetra
.23885 .5538 .24946 .56308 .2653 .55806 .25476 .54872 Mtetra
.25476 .54872 .2653 .55806 .28124 .55301 .27075 .54361 Mtetra
.646 .763 .934 r
.27075 .54361 .28124 .55301 .29728 .54791 .28685 .53846 Mtetra
.28685 .53846 .29728 .54791 .31342 .54278 .30305 .53327 Mtetra
.647 .763 .934 r
.30305 .53327 .31342 .54278 .32966 .53759 .31935 .52804 Mtetra
.648 .764 .934 r
.31935 .52804 .32966 .53759 .346 .53232 .33575 .52274 Mtetra
.649 .765 .933 r
.33575 .52274 .346 .53232 .36244 .52694 .35225 .51734 Mtetra
.652 .766 .933 r
.35225 .51734 .36244 .52694 .379 .52137 .36887 .5118 Mtetra
.658 .77 .932 r
.36887 .5118 .379 .52137 .39566 .51546 .38559 .50601 Mtetra
.668 .777 .931 r
.38559 .50601 .39566 .51546 .41244 .50896 .40243 .49977 Mtetra
.687 .789 .928 r
.40243 .49977 .41244 .50896 .42934 .50137 .41939 .49272 Mtetra
.72 .81 .921 r
.41939 .49272 .42934 .50137 .44637 .49182 .43647 .4842 Mtetra
.772 .842 .905 r
.43647 .4842 .44637 .49182 .46353 .47888 .45369 .47308 Mtetra
.842 .882 .87 r
.45369 .47308 .46353 .47888 .48079 .46044 .47103 .45757 Mtetra
.914 .915 .805 r
.47103 .45757 .48079 .46044 .49808 .4342 .48845 .43534 Mtetra
.961 .928 .716 r
.48845 .43534 .49808 .4342 .51529 .3993 .50586 .40453 Mtetra
.976 .922 .634 r
.50586 .40453 .51529 .3993 .53229 .35851 .5231 .36587 Mtetra
.972 .918 .592 r
.5231 .36587 .53229 .35851 .54902 .31818 .54009 .32424 Mtetra
.968 .928 .613 r
.54009 .32424 .54902 .31818 .56556 .28429 .55684 .28641 Mtetra
.958 .947 .696 r
.55684 .28641 .56556 .28429 .58206 .25898 .57346 .25665 Mtetra
.919 .94 .801 r
.57346 .25665 .58206 .25898 .59863 .24102 .59011 .23516 Mtetra
.848 .894 .871 r
.59011 .23516 .59863 .24102 .61532 .22811 .60685 .21991 Mtetra
.778 .84 .899 r
.60685 .21991 .61532 .22811 .63214 .21826 .62372 .20864 Mtetra
.728 .799 .907 r
.62372 .20864 .63214 .21826 .64909 .21012 .64073 .19967 Mtetra
.699 .773 .909 r
.64073 .19967 .64909 .21012 .66617 .20291 .65787 .19198 Mtetra
.682 .758 .909 r
.65787 .19198 .66617 .20291 .68337 .19617 .67513 .18496 Mtetra
.673 .75 .909 r
.67513 .18496 .68337 .19617 .70068 .18967 .69251 .17827 Mtetra
.669 .746 .908 r
.69251 .17827 .70068 .18967 .7181 .18328 .71001 .17175 Mtetra
.666 .744 .908 r
.71001 .17175 .7181 .18328 .73564 .17693 .72762 .16529 Mtetra
.665 .743 .908 r
.72762 .16529 .73564 .17693 .75328 .17058 .74534 .15885 Mtetra
.664 .742 .908 r
.74534 .15885 .75328 .17058 .77104 .16421 .76317 .1524 Mtetra
.76317 .1524 .77104 .16421 .78891 .15781 .78112 .14592 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .5538 .22813 .5444 Mtetra
.22813 .5444 .23885 .5538 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27075 .54361 .26015 .5341 Mtetra
.646 .763 .934 r
.26015 .5341 .27075 .54361 .28685 .53846 .2763 .5289 Mtetra
.2763 .5289 .28685 .53846 .30305 .53327 .29256 .52366 Mtetra
.647 .763 .934 r
.29256 .52366 .30305 .53327 .31935 .52804 .30892 .51837 Mtetra
.30892 .51837 .31935 .52804 .33575 .52274 .32538 .51303 Mtetra
.648 .764 .933 r
.32538 .51303 .33575 .52274 .35225 .51734 .34195 .50761 Mtetra
.651 .765 .933 r
.34195 .50761 .35225 .51734 .36887 .5118 .35862 .50207 Mtetra
.655 .768 .933 r
.35862 .50207 .36887 .5118 .38559 .50601 .3754 .49634 Mtetra
.662 .773 .932 r
.3754 .49634 .38559 .50601 .40243 .49977 .3923 .49028 Mtetra
.676 .782 .93 r
.3923 .49028 .40243 .49977 .41939 .49272 .40932 .48361 Mtetra
.701 .798 .925 r
.40932 .48361 .41939 .49272 .43647 .4842 .42647 .47584 Mtetra
.743 .825 .915 r
.42647 .47584 .43647 .4842 .45369 .47308 .44374 .4661 Mtetra
.805 .861 .891 r
.44374 .4661 .45369 .47308 .47103 .45757 .46115 .45295 Mtetra
.879 .901 .842 r
.46115 .45295 .47103 .45757 .48845 .43534 .47867 .43425 Mtetra
.942 .925 .762 r
.47867 .43425 .48845 .43534 .50586 .40453 .49623 .40771 Mtetra
.972 .926 .672 r
.49623 .40771 .50586 .40453 .5231 .36587 .51371 .37245 Mtetra
.975 .919 .606 r
.51371 .37245 .5231 .36587 .54009 .32424 .53097 .33128 Mtetra
.97 .921 .594 r
.53097 .33128 .54009 .32424 .55684 .28641 .54795 .29058 Mtetra
.965 .938 .648 r
.54795 .29058 .55684 .28641 .57346 .25665 .56474 .25637 Mtetra
.944 .948 .75 r
.56474 .25637 .57346 .25665 .59011 .23516 .58148 .23078 Mtetra
.886 .92 .842 r
.58148 .23078 .59011 .23516 .60685 .21991 .59829 .21259 Mtetra
.811 .866 .889 r
.59829 .21259 .60685 .21991 .62372 .20864 .61522 .19947 Mtetra
.75 .817 .905 r
.61522 .19947 .62372 .20864 .64073 .19967 .63228 .18943 Mtetra
.712 .784 .909 r
.63228 .18943 .64073 .19967 .65787 .19198 .64948 .1811 Mtetra
.689 .765 .909 r
.64948 .1811 .65787 .19198 .67513 .18496 .6668 .1737 Mtetra
.677 .754 .909 r
.6668 .1737 .67513 .18496 .69251 .17827 .68425 .16679 Mtetra
.671 .748 .908 r
.68425 .16679 .69251 .17827 .71001 .17175 .70182 .16011 Mtetra
.667 .745 .908 r
.70182 .16011 .71001 .17175 .72762 .16529 .7195 .15353 Mtetra
.666 .743 .908 r
.7195 .15353 .72762 .16529 .74534 .15885 .7373 .14699 Mtetra
.665 .742 .908 r
.7373 .14699 .74534 .15885 .76317 .1524 .75521 .14045 Mtetra
.664 .742 .908 r
.75521 .14045 .76317 .1524 .78112 .14592 .77323 .1339 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54006 Mtetra
.20137 .54006 .21227 .54951 .22813 .5444 .21728 .5349 Mtetra
.21728 .5349 .22813 .5444 .24409 .53927 .2333 .52971 Mtetra
.2333 .52971 .24409 .53927 .26015 .5341 .24942 .52449 Mtetra
.24942 .52449 .26015 .5341 .2763 .5289 .26563 .51923 Mtetra
.646 .763 .934 r
.26563 .51923 .2763 .5289 .29256 .52366 .28195 .51393 Mtetra
.28195 .51393 .29256 .52366 .30892 .51837 .29837 .50859 Mtetra
.647 .763 .934 r
.29837 .50859 .30892 .51837 .32538 .51303 .31489 .5032 Mtetra
.648 .764 .934 r
.31489 .5032 .32538 .51303 .34195 .50761 .33152 .49774 Mtetra
.649 .765 .933 r
.33152 .49774 .34195 .50761 .35862 .50207 .34826 .49219 Mtetra
.652 .767 .933 r
.34826 .49219 .35862 .50207 .3754 .49634 .3651 .48649 Mtetra
.658 .77 .932 r
.3651 .48649 .3754 .49634 .3923 .49028 .38206 .48053 Mtetra
.668 .777 .931 r
.38206 .48053 .3923 .49028 .40932 .48361 .39914 .47413 Mtetra
.687 .789 .928 r
.39914 .47413 .40932 .48361 .42647 .47584 .41634 .4669 Mtetra
.72 .81 .921 r
.41634 .4669 .42647 .47584 .44374 .4661 .43368 .4582 Mtetra
.772 .842 .905 r
.43368 .4582 .44374 .4661 .46115 .45295 .45116 .44687 Mtetra
.842 .882 .87 r
.45116 .44687 .46115 .45295 .47867 .43425 .46876 .43112 Mtetra
.914 .916 .805 r
.46876 .43112 .47867 .43425 .49623 .40771 .48644 .40861 Mtetra
.961 .928 .716 r
.48644 .40861 .49623 .40771 .51371 .37245 .50411 .37747 Mtetra
.976 .922 .634 r
.50411 .37747 .51371 .37245 .53097 .33128 .52163 .33844 Mtetra
.972 .918 .592 r
.52163 .33844 .53097 .33128 .54795 .29058 .53888 .29642 Mtetra
.968 .928 .613 r
.53888 .29642 .54795 .29058 .56474 .25637 .55588 .25824 Mtetra
.958 .946 .697 r
.55588 .25824 .56474 .25637 .58148 .23078 .57275 .22818 Mtetra
.919 .939 .801 r
.57275 .22818 .58148 .23078 .59829 .21259 .58964 .20644 Mtetra
.848 .894 .871 r
.58964 .20644 .59829 .21259 .61522 .19947 .60662 .19096 Mtetra
.778 .84 .899 r
.60662 .19096 .61522 .19947 .63228 .18943 .62374 .17949 Mtetra
.728 .798 .907 r
.62374 .17949 .63228 .18943 .64948 .1811 .641 .17033 Mtetra
.699 .773 .909 r
.641 .17033 .64948 .1811 .6668 .1737 .65838 .16245 Mtetra
.682 .758 .909 r
.65838 .16245 .6668 .1737 .68425 .16679 .6759 .15524 Mtetra
.673 .75 .909 r
.6759 .15524 .68425 .16679 .70182 .16011 .69354 .14837 Mtetra
.669 .746 .908 r
.69354 .14837 .70182 .16011 .7195 .15353 .71129 .14165 Mtetra
.666 .744 .908 r
.71129 .14165 .7195 .15353 .7373 .14699 .72917 .13501 Mtetra
.665 .743 .908 r
.72917 .13501 .7373 .14699 .75521 .14045 .74715 .12838 Mtetra
.664 .742 .908 r
.74715 .12838 .75521 .14045 .77323 .1339 .76526 .12173 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54006 .19034 .53052 Mtetra
.19034 .53052 .20137 .54006 .21728 .5349 .20631 .5253 Mtetra
.20631 .5253 .21728 .5349 .2333 .52971 .22239 .52005 Mtetra
.22239 .52005 .2333 .52971 .24942 .52449 .23856 .51476 Mtetra
.23856 .51476 .24942 .52449 .26563 .51923 .25484 .50944 Mtetra
.646 .763 .934 r
.25484 .50944 .26563 .51923 .28195 .51393 .27121 .50408 Mtetra
.27121 .50408 .28195 .51393 .29837 .50859 .2877 .49869 Mtetra
.647 .763 .934 r
.2877 .49869 .29837 .50859 .31489 .5032 .30428 .49325 Mtetra
.30428 .49325 .31489 .5032 .33152 .49774 .32097 .48774 Mtetra
.648 .764 .933 r
.32097 .48774 .33152 .49774 .34826 .49219 .33777 .48217 Mtetra
.651 .765 .933 r
.33777 .48217 .34826 .49219 .3651 .48649 .35468 .47647 Mtetra
.655 .768 .933 r
.35468 .47647 .3651 .48649 .38206 .48053 .3717 .47057 Mtetra
.662 .773 .932 r
.3717 .47057 .38206 .48053 .39914 .47413 .38884 .46434 Mtetra
.676 .782 .93 r
.38884 .46434 .39914 .47413 .41634 .4669 .40611 .45749 Mtetra
.701 .798 .925 r
.40611 .45749 .41634 .4669 .43368 .4582 .42351 .44954 Mtetra
.743 .825 .915 r
.42351 .44954 .43368 .4582 .45116 .44687 .44104 .43961 Mtetra
.805 .862 .891 r
.44104 .43961 .45116 .44687 .46876 .43112 .45871 .42623 Mtetra
.879 .901 .842 r
.45871 .42623 .46876 .43112 .48644 .40861 .4765 .40727 Mtetra
.942 .925 .762 r
.4765 .40727 .48644 .40861 .50411 .37747 .49433 .38042 Mtetra
.972 .926 .671 r
.49433 .38042 .50411 .37747 .52163 .33844 .51208 .3448 Mtetra
.975 .919 .606 r
.51208 .3448 .52163 .33844 .53888 .29642 .52961 .30324 Mtetra
.97 .921 .594 r
.52961 .30324 .53888 .29642 .55588 .25824 .54685 .26217 Mtetra
.965 .938 .649 r
.54685 .26217 .55588 .25824 .57275 .22818 .56389 .22762 Mtetra
.944 .948 .75 r
.56389 .22762 .57275 .22818 .58964 .20644 .58088 .20176 Mtetra
.886 .92 .842 r
.58088 .20176 .58964 .20644 .60662 .19096 .59793 .18333 Mtetra
.811 .866 .889 r
.59793 .18333 .60662 .19096 .62374 .17949 .61511 .17 Mtetra
.75 .817 .905 r
.61511 .17 .62374 .17949 .641 .17033 .63242 .15975 Mtetra
.712 .784 .909 r
.63242 .15975 .641 .17033 .65838 .16245 .64987 .15123 Mtetra
.689 .765 .909 r
.64987 .15123 .65838 .16245 .6759 .15524 .66745 .14364 Mtetra
.677 .754 .909 r
.66745 .14364 .6759 .15524 .69354 .14837 .68516 .13654 Mtetra
.671 .748 .908 r
.68516 .13654 .69354 .14837 .71129 .14165 .70299 .12966 Mtetra
.667 .745 .908 r
.70299 .12966 .71129 .14165 .72917 .13501 .72094 .1229 Mtetra
.666 .743 .908 r
.72094 .1229 .72917 .13501 .74715 .12838 .73901 .11616 Mtetra
.665 .742 .908 r
.73901 .11616 .74715 .12838 .76526 .12173 .75719 .10943 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52005 .21135 .51027 Mtetra
.21135 .51027 .22239 .52005 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50944 .24392 .49954 Mtetra
.24392 .49954 .25484 .50944 .27121 .50408 .26036 .49412 Mtetra
.646 .763 .934 r
.26036 .49412 .27121 .50408 .2877 .49869 .2769 .48867 Mtetra
.2769 .48867 .2877 .49869 .30428 .49325 .29355 .48317 Mtetra
.647 .763 .934 r
.29355 .48317 .30428 .49325 .32097 .48774 .3103 .47762 Mtetra
.648 .764 .934 r
.3103 .47762 .32097 .48774 .33777 .48217 .32716 .472 Mtetra
.649 .765 .933 r
.32716 .472 .33777 .48217 .35468 .47647 .34414 .46628 Mtetra
.652 .767 .933 r
.34414 .46628 .35468 .47647 .3717 .47057 .36122 .46042 Mtetra
.658 .77 .932 r
.36122 .46042 .3717 .47057 .38884 .46434 .37843 .45429 Mtetra
.668 .777 .931 r
.37843 .45429 .38884 .46434 .40611 .45749 .39576 .44771 Mtetra
.687 .789 .928 r
.39576 .44771 .40611 .45749 .42351 .44954 .41321 .4403 Mtetra
.72 .81 .921 r
.41321 .4403 .42351 .44954 .44104 .43961 .43081 .4314 Mtetra
.772 .842 .905 r
.43081 .4314 .44104 .43961 .45871 .42623 .44854 .41986 Mtetra
.842 .882 .87 r
.44854 .41986 .45871 .42623 .4765 .40727 .46641 .40387 Mtetra
.914 .916 .805 r
.46641 .40387 .4765 .40727 .49433 .38042 .48437 .38108 Mtetra
.961 .928 .716 r
.48437 .38108 .49433 .38042 .51208 .3448 .50232 .34959 Mtetra
.976 .922 .633 r
.50232 .34959 .51208 .3448 .52961 .30324 .52011 .31017 Mtetra
.972 .918 .592 r
.52011 .31017 .52961 .30324 .54685 .26217 .53763 .26776 Mtetra
.968 .928 .613 r
.53763 .26776 .54685 .26217 .56389 .22762 .55489 .22923 Mtetra
.958 .946 .697 r
.55489 .22923 .56389 .22762 .58088 .20176 .57201 .19887 Mtetra
.919 .939 .801 r
.57201 .19887 .58088 .20176 .59793 .18333 .58915 .17686 Mtetra
.848 .894 .871 r
.58915 .17686 .59793 .18333 .61511 .17 .60639 .16116 Mtetra
.778 .84 .899 r
.60639 .16116 .61511 .17 .63242 .15975 .62376 .14948 Mtetra
.728 .798 .907 r
.62376 .14948 .63242 .15975 .64987 .15123 .64127 .14012 Mtetra
.699 .773 .909 r
.64127 .14012 .64987 .15123 .66745 .14364 .65891 .13204 Mtetra
.682 .758 .909 r
.65891 .13204 .66745 .14364 .68516 .13654 .67669 .12464 Mtetra
.673 .75 .909 r
.67669 .12464 .68516 .13654 .70299 .12966 .69459 .11757 Mtetra
.669 .746 .908 r
.69459 .11757 .70299 .12966 .72094 .1229 .71262 .11066 Mtetra
.666 .744 .908 r
.71262 .11066 .72094 .1229 .73901 .11616 .73076 .10382 Mtetra
.665 .743 .908 r
.73076 .10382 .73901 .11616 .75719 .10943 .74903 .09699 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50037 Mtetra
.20018 .50037 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49954 .23287 .48952 Mtetra
.23287 .48952 .24392 .49954 .26036 .49412 .24937 .48405 Mtetra
.646 .763 .934 r
.24937 .48405 .26036 .49412 .2769 .48867 .26597 .47853 Mtetra
.26597 .47853 .2769 .48867 .29355 .48317 .28269 .47297 Mtetra
.647 .763 .934 r
.28269 .47297 .29355 .48317 .3103 .47762 .2995 .46736 Mtetra
.2995 .46736 .3103 .47762 .32716 .472 .31643 .4617 Mtetra
.648 .764 .933 r
.31643 .4617 .32716 .472 .34414 .46628 .33347 .45595 Mtetra
.651 .765 .933 r
.33347 .45595 .34414 .46628 .36122 .46042 .35062 .45008 Mtetra
.655 .768 .933 r
.35062 .45008 .36122 .46042 .37843 .45429 .36789 .44402 Mtetra
.662 .773 .932 r
.36789 .44402 .37843 .45429 .39576 .44771 .38528 .43761 Mtetra
.676 .782 .93 r
.38528 .43761 .39576 .44771 .41321 .4403 .4028 .43058 Mtetra
.701 .798 .925 r
.4028 .43058 .41321 .4403 .43081 .4314 .42045 .42244 Mtetra
.743 .825 .915 r
.42045 .42244 .43081 .4314 .44854 .41986 .43825 .4123 Mtetra
.805 .862 .891 r
.43825 .4123 .44854 .41986 .46641 .40387 .45619 .39869 Mtetra
.879 .901 .842 r
.45619 .39869 .46641 .40387 .48437 .38108 .47425 .37946 Mtetra
.942 .925 .762 r
.47425 .37946 .48437 .38108 .50232 .34959 .49237 .35229 Mtetra
.972 .927 .671 r
.49237 .35229 .50232 .34959 .52011 .31017 .5104 .3163 Mtetra
.975 .919 .606 r
.5104 .3163 .52011 .31017 .53763 .26776 .5282 .27435 Mtetra
.97 .921 .594 r
.5282 .27435 .53763 .26776 .55489 .22923 .54572 .2329 Mtetra
.965 .938 .649 r
.54572 .2329 .55489 .22923 .57201 .19887 .56302 .19802 Mtetra
.944 .948 .751 r
.56302 .19802 .57201 .19887 .58915 .17686 .58026 .17188 Mtetra
.885 .92 .842 r
.58026 .17188 .58915 .17686 .60639 .16116 .59757 .1532 Mtetra
.811 .866 .889 r
.59757 .1532 .60639 .16116 .62376 .14948 .615 .13965 Mtetra
.75 .817 .905 r
.615 .13965 .62376 .14948 .64127 .14012 .63257 .12919 Mtetra
.712 .784 .909 r
.63257 .12919 .64127 .14012 .65891 .13204 .65028 .12047 Mtetra
.689 .765 .909 r
.65028 .12047 .65891 .13204 .67669 .12464 .66812 .11269 Mtetra
.677 .754 .909 r
.66812 .11269 .67669 .12464 .69459 .11757 .6861 .10538 Mtetra
.671 .748 .908 r
.6861 .10538 .69459 .11757 .71262 .11066 .7042 .09831 Mtetra
.667 .745 .908 r
.7042 .09831 .71262 .11066 .73076 .10382 .72242 .09134 Mtetra
.666 .743 .908 r
.72242 .09134 .73076 .10382 .74903 .09699 .74077 .0844 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50037 .18889 .49037 Mtetra
.18889 .49037 .20018 .50037 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48952 .2217 .47939 Mtetra
.2217 .47939 .23287 .48952 .24937 .48405 .23826 .47385 Mtetra
.23826 .47385 .24937 .48405 .26597 .47853 .25492 .46827 Mtetra
.646 .763 .934 r
.25492 .46827 .26597 .47853 .28269 .47297 .2717 .46265 Mtetra
.2717 .46265 .28269 .47297 .2995 .46736 .28858 .45698 Mtetra
.647 .763 .934 r
.28858 .45698 .2995 .46736 .31643 .4617 .30557 .45126 Mtetra
.648 .764 .934 r
.30557 .45126 .31643 .4617 .33347 .45595 .32267 .44547 Mtetra
.649 .765 .933 r
.32267 .44547 .33347 .45595 .35062 .45008 .33989 .43959 Mtetra
.652 .767 .933 r
.33989 .43959 .35062 .45008 .36789 .44402 .35723 .43354 Mtetra
.658 .77 .932 r
.35723 .43354 .36789 .44402 .38528 .43761 .37468 .42724 Mtetra
.668 .777 .931 r
.37468 .42724 .38528 .43761 .4028 .43058 .39227 .42047 Mtetra
.687 .789 .928 r
.39227 .42047 .4028 .43058 .42045 .42244 .40998 .41288 Mtetra
.72 .81 .921 r
.40998 .41288 .42045 .42244 .43825 .4123 .42784 .40378 Mtetra
.772 .842 .905 r
.42784 .40378 .43825 .4123 .45619 .39869 .44585 .39202 Mtetra
.842 .882 .87 r
.44585 .39202 .45619 .39869 .47425 .37946 .46399 .37578 Mtetra
.914 .916 .805 r
.46399 .37578 .47425 .37946 .49237 .35229 .48223 .35268 Mtetra
.961 .928 .716 r
.48223 .35268 .49237 .35229 .5104 .3163 .50047 .32085 Mtetra
.976 .922 .633 r
.50047 .32085 .5104 .3163 .5282 .27435 .51855 .28105 Mtetra
.972 .918 .592 r
.51855 .28105 .5282 .27435 .54572 .2329 .53635 .23824 Mtetra
.968 .928 .613 r
.53635 .23824 .54572 .2329 .56302 .19802 .55387 .19935 Mtetra
.958 .946 .697 r
.55387 .19935 .56302 .19802 .58026 .17188 .57126 .16868 Mtetra
.919 .939 .801 r
.57126 .16868 .58026 .17188 .59757 .1532 .58865 .14641 Mtetra
.848 .894 .87 r
.58865 .14641 .59757 .1532 .615 .13965 .60614 .13047 Mtetra
.778 .839 .899 r
.60614 .13047 .615 .13965 .63257 .12919 .62377 .11857 Mtetra
.728 .798 .907 r
.62377 .11857 .63257 .12919 .65028 .12047 .64155 .10901 Mtetra
.699 .773 .909 r
.64155 .10901 .65028 .12047 .66812 .11269 .65946 .10072 Mtetra
.682 .758 .909 r
.65946 .10072 .66812 .11269 .6861 .10538 .67751 .09311 Mtetra
.674 .75 .909 r
.67751 .09311 .6861 .10538 .7042 .09831 .69568 .08584 Mtetra
.669 .746 .908 r
.69568 .08584 .7042 .09831 .72242 .09134 .71398 .07873 Mtetra
.666 .744 .908 r
.71398 .07873 .72242 .09134 .74077 .0844 .73241 .07168 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47385 .22701 .46353 Mtetra
.22701 .46353 .23826 .47385 .25492 .46827 .24374 .45788 Mtetra
.646 .763 .934 r
.24374 .45788 .25492 .46827 .2717 .46265 .26058 .4522 Mtetra
.26058 .4522 .2717 .46265 .28858 .45698 .27752 .44647 Mtetra
.647 .763 .934 r
.27752 .44647 .28858 .45698 .30557 .45126 .29458 .44069 Mtetra
.29458 .44069 .30557 .45126 .32267 .44547 .31175 .43486 Mtetra
.648 .764 .933 r
.31175 .43486 .32267 .44547 .33989 .43959 .32904 .42893 Mtetra
.651 .765 .933 r
.32904 .42893 .33989 .43959 .35723 .43354 .34644 .42289 Mtetra
.655 .768 .933 r
.34644 .42289 .35723 .43354 .37468 .42724 .36396 .41664 Mtetra
.662 .773 .932 r
.36396 .41664 .37468 .42724 .39227 .42047 .38161 .41005 Mtetra
.676 .782 .93 r
.38161 .41005 .39227 .42047 .40998 .41288 .39939 .40283 Mtetra
.701 .798 .925 r
.39939 .40283 .40998 .41288 .42784 .40378 .41731 .39449 Mtetra
.743 .825 .915 r
.41731 .39449 .42784 .40378 .44585 .39202 .43538 .38414 Mtetra
.805 .862 .891 r
.43538 .38414 .44585 .39202 .46399 .37578 .45359 .37029 Mtetra
.879 .901 .842 r
.45359 .37029 .46399 .37578 .48223 .35268 .47194 .35079 Mtetra
.942 .926 .762 r
.47194 .35079 .48223 .35268 .50047 .32085 .49034 .32329 Mtetra
.972 .927 .671 r
.49034 .32329 .50047 .32085 .51855 .28105 .50867 .28693 Mtetra
.975 .919 .605 r
.50867 .28693 .51855 .28105 .53635 .23824 .52676 .24458 Mtetra
.97 .921 .594 r
.52676 .24458 .53635 .23824 .55387 .19935 .54455 .20275 Mtetra
.965 .938 .649 r
.54455 .20275 .55387 .19935 .57126 .16868 .56212 .16753 Mtetra
.944 .948 .751 r
.56212 .16753 .57126 .16868 .58865 .14641 .57963 .1411 Mtetra
.885 .92 .842 r
.57963 .1411 .58865 .14641 .60614 .13047 .59719 .12217 Mtetra
.811 .866 .889 r
.59719 .12217 .60614 .13047 .62377 .11857 .61488 .10839 Mtetra
.75 .817 .905 r
.61488 .10839 .62377 .11857 .64155 .10901 .63272 .09772 Mtetra
.712 .784 .909 r
.63272 .09772 .64155 .10901 .65946 .10072 .6507 .08879 Mtetra
.689 .765 .909 r
.6507 .08879 .65946 .10072 .67751 .09311 .66882 .08079 Mtetra
.677 .754 .909 r
.66882 .08079 .67751 .09311 .69568 .08584 .68707 .07328 Mtetra
.671 .748 .908 r
.68707 .07328 .69568 .08584 .71398 .07873 .70544 .066 Mtetra
.667 .745 .908 r
.70544 .066 .71398 .07873 .73241 .07168 .72395 .05882 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45788 .23242 .44738 Mtetra
.23242 .44738 .24374 .45788 .26058 .4522 .24932 .44163 Mtetra
.646 .763 .934 r
.24932 .44163 .26058 .4522 .27752 .44647 .26634 .43583 Mtetra
.26634 .43583 .27752 .44647 .29458 .44069 .28346 .42999 Mtetra
.647 .763 .934 r
.28346 .42999 .29458 .44069 .31175 .43486 .3007 .4241 Mtetra
.648 .764 .934 r
.3007 .4241 .31175 .43486 .32904 .42893 .31805 .41813 Mtetra
.649 .765 .933 r
.31805 .41813 .32904 .42893 .34644 .42289 .33552 .41206 Mtetra
.652 .767 .933 r
.33552 .41206 .34644 .42289 .36396 .41664 .35311 .40584 Mtetra
.658 .77 .932 r
.35311 .40584 .36396 .41664 .38161 .41005 .37082 .39935 Mtetra
.668 .777 .931 r
.37082 .39935 .38161 .41005 .39939 .40283 .38867 .39239 Mtetra
.687 .789 .928 r
.38867 .39239 .39939 .40283 .41731 .39449 .40665 .38459 Mtetra
.72 .81 .921 r
.40665 .38459 .41731 .39449 .43538 .38414 .42478 .37528 Mtetra
.772 .842 .905 r
.42478 .37528 .43538 .38414 .45359 .37029 .44307 .3633 Mtetra
.842 .882 .87 r
.44307 .3633 .45359 .37029 .47194 .35079 .4615 .3468 Mtetra
.914 .916 .805 r
.4615 .3468 .47194 .35079 .49034 .32329 .48003 .3234 Mtetra
.961 .929 .715 r
.48003 .3234 .49034 .32329 .50867 .28693 .49856 .29121 Mtetra
.976 .923 .633 r
.49856 .29121 .50867 .28693 .52676 .24458 .51694 .25102 Mtetra
.972 .918 .592 r
.51694 .25102 .52676 .24458 .54455 .20275 .53502 .20782 Mtetra
.968 .928 .614 r
.53502 .20782 .54455 .20275 .56212 .16753 .55282 .16856 Mtetra
.958 .946 .697 r
.55282 .16856 .56212 .16753 .57963 .1411 .57048 .13757 Mtetra
.919 .939 .801 r
.57048 .13757 .57963 .1411 .59719 .12217 .58814 .11503 Mtetra
.848 .894 .87 r
.58814 .11503 .59719 .12217 .61488 .10839 .6059 .09885 Mtetra
.778 .839 .899 r
.6059 .09885 .61488 .10839 .63272 .09772 .62379 .08672 Mtetra
.728 .798 .907 r
.62379 .08672 .63272 .09772 .6507 .08879 .64184 .07694 Mtetra
.699 .773 .909 r
.64184 .07694 .6507 .08879 .66882 .08079 .66002 .06845 Mtetra
.682 .758 .909 r
.66002 .06845 .66882 .08079 .68707 .07328 .67835 .06063 Mtetra
.674 .75 .909 r
.67835 .06063 .68707 .07328 .70544 .066 .6968 .05314 Mtetra
.669 .746 .908 r
.6968 .05314 .70544 .066 .72395 .05882 .71539 .04582 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45397 Mtetra
.17073 .45397 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44738 .22097 .43674 Mtetra
.22097 .43674 .23242 .44738 .24932 .44163 .23794 .43092 Mtetra
.646 .763 .934 r
.23794 .43092 .24932 .44163 .26634 .43583 .25501 .42506 Mtetra
.25501 .42506 .26634 .43583 .28346 .42999 .2722 .41916 Mtetra
.647 .763 .934 r
.2722 .41916 .28346 .42999 .3007 .4241 .28951 .4132 Mtetra
.28951 .4132 .3007 .4241 .31805 .41813 .30693 .40718 Mtetra
.648 .764 .933 r
.30693 .40718 .31805 .41813 .33552 .41206 .32446 .40107 Mtetra
.651 .765 .933 r
.32446 .40107 .33552 .41206 .35311 .40584 .34212 .39484 Mtetra
.655 .768 .933 r
.34212 .39484 .35311 .40584 .37082 .39935 .35991 .38841 Mtetra
.662 .773 .932 r
.35991 .38841 .37082 .39935 .38867 .39239 .37782 .38162 Mtetra
.676 .782 .93 r
.37782 .38162 .38867 .39239 .40665 .38459 .39587 .3742 Mtetra
.701 .798 .925 r
.39587 .3742 .40665 .38459 .42478 .37528 .41406 .36566 Mtetra
.743 .825 .915 r
.41406 .36566 .42478 .37528 .44307 .3633 .43241 .35508 Mtetra
.805 .862 .891 r
.43241 .35508 .44307 .3633 .4615 .3468 .45091 .34099 Mtetra
.879 .902 .842 r
.45091 .34099 .4615 .3468 .48003 .3234 .46955 .3212 Mtetra
.942 .926 .762 r
.46955 .3212 .48003 .3234 .49856 .29121 .48825 .29338 Mtetra
.972 .927 .671 r
.48825 .29338 .49856 .29121 .51694 .25102 .50688 .25663 Mtetra
.975 .919 .605 r
.50688 .25663 .51694 .25102 .53502 .20782 .52527 .21388 Mtetra
.97 .921 .594 r
.52527 .21388 .53502 .20782 .55282 .16856 .54335 .17166 Mtetra
.965 .938 .65 r
.54335 .17166 .55282 .16856 .57048 .13757 .56119 .13611 Mtetra
.944 .947 .751 r
.56119 .13611 .57048 .13757 .58814 .11503 .57897 .10938 Mtetra
.885 .919 .842 r
.57897 .10938 .58814 .11503 .6059 .09885 .59681 .09019 Mtetra
.811 .866 .889 r
.59681 .09019 .6059 .09885 .62379 .08672 .61477 .07618 Mtetra
.75 .817 .905 r
.61477 .07618 .62379 .08672 .64184 .07694 .63287 .06528 Mtetra
.712 .784 .908 r
.63287 .06528 .64184 .07694 .66002 .06845 .65113 .05613 Mtetra
.689 .764 .909 r
.65113 .05613 .66002 .06845 .67835 .06063 .66953 .04791 Mtetra
.677 .754 .909 r
.66953 .04791 .67835 .06063 .6968 .05314 .68806 .04018 Mtetra
.671 .748 .908 r
.68806 .04018 .6968 .05314 .71539 .04582 .70673 .03268 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45397 .15895 .44341 Mtetra
.15895 .44341 .17073 .45397 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43183 Mtetra
.19246 .43183 .20411 .44252 .22097 .43674 .20938 .42598 Mtetra
.20938 .42598 .22097 .43674 .23794 .43092 .22641 .42009 Mtetra
.22641 .42009 .23794 .43092 .25501 .42506 .24355 .41416 Mtetra
.646 .763 .934 r
.24355 .41416 .25501 .42506 .2722 .41916 .26081 .40818 Mtetra
.26081 .40818 .2722 .41916 .28951 .4132 .27818 .40216 Mtetra
.647 .763 .934 r
.27818 .40216 .28951 .4132 .30693 .40718 .29567 .39608 Mtetra
.648 .764 .934 r
.29567 .39608 .30693 .40718 .32446 .40107 .31328 .38993 Mtetra
.649 .765 .933 r
.31328 .38993 .32446 .40107 .34212 .39484 .331 .38367 Mtetra
.652 .767 .933 r
.331 .38367 .34212 .39484 .35991 .38841 .34886 .37726 Mtetra
.658 .77 .932 r
.34886 .37726 .35991 .38841 .37782 .38162 .36684 .37057 Mtetra
.668 .777 .931 r
.36684 .37057 .37782 .38162 .39587 .3742 .38495 .36341 Mtetra
.687 .789 .928 r
.38495 .36341 .39587 .3742 .41406 .36566 .40321 .35541 Mtetra
.72 .81 .921 r
.40321 .35541 .41406 .36566 .43241 .35508 .42163 .34588 Mtetra
.772 .842 .905 r
.42163 .34588 .43241 .35508 .45091 .34099 .4402 .33366 Mtetra
.842 .883 .87 r
.4402 .33366 .45091 .34099 .46955 .3212 .45892 .31689 Mtetra
.914 .917 .805 r
.45892 .31689 .46955 .3212 .48825 .29338 .47776 .29319 Mtetra
.961 .929 .715 r
.47776 .29319 .48825 .29338 .50688 .25663 .49659 .26064 Mtetra
.976 .923 .633 r
.49659 .26064 .50688 .25663 .52527 .21388 .51527 .22004 Mtetra
.972 .918 .592 r
.51527 .22004 .52527 .21388 .54335 .17166 .53365 .17644 Mtetra
.968 .928 .614 r
.53365 .17644 .54335 .17166 .56119 .13611 .55174 .13682 Mtetra
.958 .946 .698 r
.55174 .13682 .56119 .13611 .57897 .10938 .56968 .10551 Mtetra
.919 .938 .801 r
.56968 .10551 .57897 .10938 .59681 .09019 .58761 .08269 Mtetra
.848 .893 .87 r
.58761 .08269 .59681 .09019 .61477 .07618 .60564 .06626 Mtetra
.778 .839 .899 r
.60564 .06626 .61477 .07618 .63287 .06528 .62381 .0539 Mtetra
.728 .798 .907 r
.62381 .0539 .63287 .06528 .65113 .05613 .64213 .04389 Mtetra
.699 .773 .909 r
.64213 .04389 .65113 .05613 .66953 .04791 .6606 .03517 Mtetra
.682 .758 .909 r
.6606 .03517 .66953 .04791 .68806 .04018 .67921 .02713 Mtetra
.674 .75 .909 r
.67921 .02713 .68806 .04018 .70673 .03268 .69796 .01942 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43183 .18066 .421 Mtetra
.18066 .421 .19246 .43183 .20938 .42598 .19765 .41508 Mtetra
.19765 .41508 .20938 .42598 .22641 .42009 .21474 .40912 Mtetra
.21474 .40912 .22641 .42009 .24355 .41416 .23195 .40312 Mtetra
.646 .763 .934 r
.23195 .40312 .24355 .41416 .26081 .40818 .24927 .39708 Mtetra
.24927 .39708 .26081 .40818 .27818 .40216 .26671 .39098 Mtetra
.647 .763 .934 r
.26671 .39098 .27818 .40216 .29567 .39608 .28427 .38484 Mtetra
.28427 .38484 .29567 .39608 .31328 .38993 .30195 .37863 Mtetra
.648 .764 .933 r
.30195 .37863 .31328 .38993 .331 .38367 .31975 .37233 Mtetra
.651 .765 .933 r
.31975 .37233 .331 .38367 .34886 .37726 .33767 .36591 Mtetra
.655 .768 .933 r
.33767 .36591 .34886 .37726 .36684 .37057 .35572 .35927 Mtetra
.662 .773 .932 r
.35572 .35927 .36684 .37057 .38495 .36341 .37391 .35228 Mtetra
.676 .782 .93 r
.37391 .35228 .38495 .36341 .40321 .35541 .39223 .34466 Mtetra
.701 .799 .925 r
.39223 .34466 .40321 .35541 .42163 .34588 .41071 .3359 Mtetra
.743 .825 .915 r
.41071 .3359 .42163 .34588 .4402 .33366 .42935 .32509 Mtetra
.805 .862 .891 r
.42935 .32509 .4402 .33366 .45892 .31689 .44815 .31074 Mtetra
.879 .902 .842 r
.44815 .31074 .45892 .31689 .47776 .29319 .46709 .29067 Mtetra
.942 .926 .762 r
.46709 .29067 .47776 .29319 .49659 .26064 .4861 .2625 Mtetra
.972 .927 .67 r
.4861 .2625 .49659 .26064 .51527 .22004 .50503 .22537 Mtetra
.975 .919 .605 r
.50503 .22537 .51527 .22004 .53365 .17644 .52373 .18221 Mtetra
.97 .921 .594 r
.52373 .18221 .53365 .17644 .55174 .13682 .5421 .1396 Mtetra
.965 .938 .65 r
.5421 .1396 .55174 .13682 .56968 .10551 .56024 .1037 Mtetra
.944 .947 .751 r
.56024 .1037 .56968 .10551 .58761 .08269 .5783 .07667 Mtetra
.885 .919 .842 r
.5783 .07667 .58761 .08269 .60564 .06626 .59641 .05722 Mtetra
.811 .865 .888 r
.59641 .05722 .60564 .06626 .62381 .0539 .61465 .04296 Mtetra
.75 .817 .904 r
.61465 .04296 .62381 .0539 .64213 .04389 .63303 .03183 Mtetra
.712 .784 .908 r
.63303 .03183 .64213 .04389 .6606 .03517 .65157 .02245 Mtetra
.689 .764 .909 r
.65157 .02245 .6606 .03517 .67921 .02713 .67026 .01401 Mtetra
.677 .754 .909 r
.67026 .01401 .67921 .02713 .69796 .01942 .68909 .00605 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooeKlD_`0
07oo0000Egoo003EOol30003Ool00eKlD_aFo002E_`01000E_aoo`00EWoo003BOol30004Ool02eKl
EaaFo5KlD_aG75;l001Bo7oo0000EWoo003@Ool20003Ool01ELLE_aFo5KlEa`015Kl00MBo5Kl001F
o5;lOol0001EOol00<eoo`<000Aoo`0BFaaG75LLE_aG75KlEaaFo5LLD_aFo5;l001Bo5KlD]aoo`00
E7oo003;Ool20005Ool5Fa`01ELLE_aFo5KlEa`00UKl00QBo5Kl001Fo5;lE_aoo`00E7oo0038Ool3
00000goo001oo`02Ool05e/LEaaK75LLFaaG75/LE_aG75KlEaaBo5LLD_aFo5;lE_`005KlD_aFo7oo
0000Dgoo001WOol20002Ool2001IOol20004Ool00`00Oomoo`02Gc`7Fa`8E_`00e;l001Bo002D_`0
0eKlOol0001BOol006Qoo`04001oogoo001GOol30007Ool2Gc`06E/kGeaO?5/LEaaK75LLFaaFo5/L
D_aG75;lEaaBo5LLD_aFo000E_aBg5KlD_aoo`00059oo`00JGoo0P00EWoo0P0027oo1ell0e/L0eLL
25Kl00ABo000D_aFo0=Bo003Ool007oo051oo`00JGoo0P00Dgoo0`002Goo00EWO6MKGcaK>emL009O
?00FFc]OG5KlFaaFo5/LE_aK75KlEaaBo5KlD_aG75;lE_`005KlD_aFo5;LE_`2Ool00`00Oomoo`1>
Ool006Qoo`04001oogoo001@Ool2000;Ool00fMlIe]WN`05Gc`00e/lFaaK?002Ea`01EKlEaaG75LL
D_`00eKl00ABo5KlE_`000=Bo005E_aBo5;lOol0001@Ool006Moo`80009oo`8004aoo`<000]oo`0<
He]WO6MKIgaSFfMlFaaO?5/LGcaK75ll0U/L01IFo5/LE_aG75KlEaaBo5LLD_aFo5;lEa`005KlD]aF
o5;LE_aBg5KlOol004moo`00]Woo0`000Woo00<007ooOol027oo00=WNfMlIe/00VMk00YWO6=LHeaK
75/lFaaK?5/LFcaK709Fo006EaaFo5KlE_aG75;l0eKl00ABo000D_aFo0=Bo004E_aBo000001?Ool0
0;Aoo`8000moo`0>KiUc^VMKIgaSFfMlHc]SG5lkHeaK75llFaaO?09K709G700EE_aG75KlEaaFo5LL
D]aFo5;lE_`005KlD_aFo5;LE_aBg5KlD]aoo`0004ioo`00/Goo0`0047oo00=_VVnjKiX00VMk1V=L
00=K?5/LFc`01E/L0UKl00=G75KlE_`00UKl00QBo5KlD_`005;lE_aBo5Kl1E;l00=oo`00Ool0C7oo
002_Ool2000BOol0:VnILkY_VW>jKiUSG6<kHeaO>f=LHc]SG5lkFaaG75/LEaaK75LLFaaFo5LLE_aG
75;lEaaBo5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlOol0015oo`D003Moo`00[7oo0`004goo00=_
VVnjKiX00VnJ00=[Vf]kHe`01F=L0Ull1e/L25Kl00ABo000D_aFo0QBo003Ool007oo00moo`05001o
ogooOol0000gOol00:Yoo`8001Eoo`0>KiUc^VnJLkY_VFnKJgY[Vf]jHeaS>f=LFc]OG09O?00NFc]K
75LLFaaG75/LE_aK75;lEaaBo5LLD_aG75;lE_`005KlD_aFo5;LE_aBg5KlD]aFo5;LE_aoo`0047oo
00<007ooOol0>7oo002WOol30002Ool00`00Oomoo`0AOol00fnJKkY_VP02KiX01V^KJg][Vf]kJi][
N`QO?0=G7003E_aG75LL00EFo004D_aFo5;l0003D_`00eKlD_aBo006D_`00`00Oomoo`05Ool60004
Ool00`00Oomoo`0gOol00:Eoo`8001Qoo`0>MkMkefnJLkY_VFnKJgY[Vf]jKi][NVMlHe]OG09O?004
Fc]OG5/LGc`2Fa`015KlFaaFo5/L0UKl01EBo5LLD_aFo5;lEa`005KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg7oo00004Goo00<007ooOol0=Woo002ROol3000JOol4MkL01V^KJg][Vf]kJi][N`9WN`0:IgaO
?5llGcaK?5/LFcaK75/lE_`3Ea`4E_`025;lE_aFo5KlD_`005;lE_`3D_`00eKlD_aBo005D_`00goo
001oo`0@Ool00`00Oomoo`0eOol007Eoo`@002Moo`8001aoo`0MNmMg]gOGMkMg^G>hJi][NVnKIe]W
O6=KIgaWFfMlFaaO?5/LGcaK75llFaaO?5KlEaaFo5LLE_aG7002E_`055;lEaaBo5Kl001Fo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;L000=Ool01@00Oomoogoo0000=goo001dOol00`00Oomoo`02Ool0
0`00Oomoo`0QOol3000NOol3MkL01WNiLkQc^G>iMkUWF`9WN`03IgaWFfMk009SG006FaaK?5/LFcaK
75/l0U/L0eKl00=G75KlE_`00UKl00ABo5KlD_`000=Bo003E_aBo5;l00QBo003Ool007oo00aoo`<0
03Qoo`00M7oo00<007ooOol00Woo00<007ooOol07Woo0`0087oo01Ag]gOGMkMkeg>hMkUc^7NiKiYc
^V=KIgaWFf=LGc]SG6<kHeaK75ll0U/L021G75/LEaaK75KlEaaFo5LLE_aG75;lE_aBg5KlD_`005;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aoo`00Agoo001dOol00`00Oomoo`02Ool00`00Oomoo`0L
Ool20002Ool00`00Oomoo`0MOol4MkL017>hLkUc^GNi0fnJ00=_^V=LHe`01V=L1e/L00=G75KlE_`0
15Kl00IBo5KlD_aFo000E_`=D_`00goo001oo`16Ool007Aoo`03001oogoo009oo`03001oogoo01Uo
o`<002Aoo`0CMmMg]g_GLkQg^G>hMkU_VW>jKiUc^V]jJi]O>f=LHc]SG5lkHe`00Ull00IG75/LEaaK
75LLFa`2Ea`06e;lEaaBo5LLD_aFo5;lE_aBg000D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
Ool00016Ool007Aoo`03001oogoo009oo`03001oogoo01Moo`8002Ioo`=g]`04LkQc^G>iMkT3KiX0
1FnjJg][Vf]kJi/00f=L15ll1E/L00=Fo5LLEa`01UKl0U;l00EFo000D_aBo5Kl00aBo09oo`03001o
ogoo04=oo`00M7oo00<007ooOol00Woo00<007ooOol057oo0`00:7oo019g/g^dMkEkeWNeNmI_VW>j
KiUc^V]jJi][NVnKJgY[Ve/kGe`2Gc`09U/kGeaO?5/LE_aK75KlFaaFo5/LD_aG75;lEaaBo5KlD_aF
o5;l001Bg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo7oo0015Ool007Eoo`@001Eoo`8002Yo
o`=k]0=k]@9g]`0:KiY_^V]kJi][Nf^KJg][VfMkIg`5Gc`015/lFaaG75Kl0eLL00EFo5LLE_aFo5;l
00=Fo09Bo003001Fo5;l00mBo003Ool007oo04=oo`00Rgoo0`00;7oo01Uk]7^cNmIg]G_FMkEgegNg
NmM[NV^KJgY_Vf]jJi]SFfMlIe]O?5/kGeaK75llFaaO?002Fa`08UKlFaaFo5LLE_aG75;lE_aBo5LL
D_aFo5;L001Bo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aoo`00@goo0029Ool20002
Ool00`00Oomoo`0YOol3Nk@2NkD02GNeMkMg]gNgLkQc^F]kJi][N`02Ig/03FMlIe]WNfMkFcaK75/l
FaaK?5/LFcaK75LL00=Fo003EaaFo5Kl009Fo005D_aFo5KlE_`00002D_`00eKlD_aBo00:D_`01E;L
D_aBo7oo0000@goo0026Ool3000`Ool06W^cNkAg]G_FMkEkeWNgNmMc^7NiLkQg^G>hIgaSFfMlIe]W
O6=KHeaS>ellFaaO?5/LGc`2Fa`2Ea`08EKlEaaFo5LLE_aG75;lE_aBo5KlD_`005;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LOol00012Ool008Aoo`80039oo`=k]003NkEg]G^e00=g
]`9c^@07MkUc^6nJKiYWO6MKIg/01F=L00=K?5/LFc`015/L00=Fo5LLE_`00UKl00UG75;lE_aBo5Kl
D_aFo000E_`035;l00EBg5;lD_aBo5;L009Bo003Ool007oo041oo`00PGoo0`00=7oo045k]7NcNmIg
]G_FMkMkegNgMkUc^7NiLkQc^VnILkY_VV=LGc]SG6<kHeaO>f=LHc]K75LLFaaG75/LEaaK75KlEaaF
o5LLD_aG75;LE_aBo5KlD]`005;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_ao
o`00045oo`00OWoo0`00=Woo0g^d00=g]G^eNkD00WNg0W>i00Qg^G>hKiY_VVnjKiY[Vf]k1V=L0Ull
1U/L1eKl00EBo5KlD_aFo00000mBo008D]aBo5;lD_aBg5;lOol0041oo`00O7oo0P00>Goo01Ig/g^d
MkEkeWNeNmMg]gNiLkQg^G>hLkY_VG>jKiY[Vf]jKi][NV=LGc]SG09O?00/Fc]OG5LLFaaG75/LE_aK
75KlEaaBo5LLD_aG75;lEaaBg5KlD_`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlOol003moo`00NGoo0`000Woo0P00=Woo00=kTW^bNi800W^c0W^d0g^e00]g]FnJKiY_
^VnJJi][Nf^KJg][Vf]k00MO?09G7004E_aG75LLEa`8E_`2D_`00`00E_aBo00?D_`01e;LD_aBo5;l
D]aoo`0003moo`00Mgoo0P00?Goo00Ak/W^BNk=gTP9k/`0CNkAg]G_FMkEgegNgLkY_VV^KJgY_Vf]j
Ji][NVMlIe]O?5/kGe`00Ull02]K75llE_aK75KlFaaFo5/LE_aG75;lE_aBo5LLD_aFo5;L001Bo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LOol0000nOol007Aoo`<003io
o`03Nk9kTW^B009k/`9k]09k]@03MkEk]GNg009g]`09Ji][Nf^KJg][Vf]kIgaWFfMk00=O?005FcaK
75/lFaaK?002Ea`015KlEaaFo5LL15Kl00EBo5KlE_aFo000009Bo003E_aBo5;l00IBo005D]aBo5;l
D_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol0>goo001bOol20011Ool0B7^BNk9gTW^cNi9k]7Nc
NmIg]G_FMkMkegNgMkUc^6nKJgY[Vf=KIgaWFfMlHe]WO5/LGcaK75llFaaO?5/LGcaFo5LLE_aG75Kl
EaaBo5LLD_aFo5;LE_aBo000D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lOol003eoo`00Kgoo0`00@Woo0g^B00Ik/g^BNkAk]7^eMkD2NkD2MkL2LkT01WNiLkQc^FMk
IgaWF`9WN`09IgaSG6=LFaaK?5/LFcaK75/l009K7003E_aG75Kl009Fo009EaaBo5KlD_aFo5;lE_aB
o00000=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`00e;LD_aBo002Ool00`00Oomoo`0jOol0
06eoo`800003Ool007oo049oo`0MNk9kTW^cNi9k]7NcNkAg]G_FMkEkegNgMmMc^7NiLkQg^FnILkYW
FfMlHe]SG6=KHeaO>f=LFaaO?002Fa`0:ELLFaaG75LLE_aG75KlEaaBo5LLD]aFo5;lE_aBg5Kl001F
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`00Woo00<007ooOol0
>Goo001ZOol30017Ool017^BNk9kTW^c0W^d00=g]G^eNkD00gNg00Ic^GNiLkQc^FnJKkX2KiX8He`7
Fa`7E_`01U;lE_aBo5KlD_`000iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo0000>goo001WOol3
0019Ool0CG^BNk9kTW^cMk=k]7^cNmIg]G_FMkMgeg>hMkUc^7NiKiUc^VnJLkY[NVnKHe]SG5lkHeaS
FellFc]OG5LLFaaG75/LEaaK75KlEaaBo5LLD_aG75;lE_aBg5KlD_aFo000E_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo0000>Woo001UOol2001<Ool017^b
Ni9k/g^c0W^d0g^e0WNg00Ic^GNiLkQc^FnJKkX2KiX01F]kJi][Nf^KJg/01Ull0e/L00AFo5LLEaaG
70QFo0=Bo003001Bo5;l00iBo005D]aBo5;lD_aBg003D_`015;LD_aBo000>Woo001ROol3001=Ool0
7G^bNi9k/gNBNk9kTW^bMi9k/g^BNkAg]G_FMkEkeVnILkY_VW>jJgY_Vf]jJi][NVMlIe]O?5/kGe`0
0Ull031K>e/LE_aK75KlFaaFo5/LD_aG75;lEaaBo5LLD_aFo5;LE_`005KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L000iOol0061oo`80051oo`=kTP03
Nk9kTW^B009k/`06Ni9k]7^dNkEg]G^e17Ng00Q[Nf^KJg][Vf]kIgaWFfMk15ll00=K75/lFa`00eLL
00EFo5LLEaaG75;l00=Fo008D_aFo5;lE_aBo000D_aFo0QBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00ABg5;lOol003Qoo`00GGoo0`0000=oo`00Ool0CWoo029kTW^bNi9k/W^BNk9kTW^c
Ni9k/gNcNmIg]G_FMkEkegNgMmMc^7NiJgY[Vf=KIgaWFfMlHe]WO5/LGcaK75llFaaO?09K700]E_aK
75KlEaaFo5LLD_aG75;lE_aBo5LLD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo00003Qoo`00Fgoo0P00E7oo0W^B00Mk/W^BNi9kTW^cNi9k
/`02Nk@00gNeNkEk]@04MkL01WNiLkQc^FMkIgaWF`9WN`0:IgaSG6=LFaaK?5/LFcaK75/lFa`2E_`0
0eLLE_aFo002E_`025;lE_aFo5KlD_aFo5;l0003D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo003D]aoo`0003Moo`00;Woo10009Woo0`00EWoo02AkTWncNi9k/W^BNk9k
TW^cMi9k]7NeNmIg]G_GMkMgegNgMkUc^7NiKiUc^VMKIgaSFf=LHe]SG5lkHeaK75llFaaO?5LLFa`2
Ea`015KlEaaFo5LL0UKl02MBg5KlD_aFo5;LE_`005KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00008Woo0`004Goo000]Ool00`00Oomoo`02
Ool00`00Oomoo`0QOol2001HOol00g^BNk9kTP02Ni8017^bNi9k/g^c0W^d0W^e17Ng00Eg^G>hLkU_
VVnj009_VPQSG0IK70=Fo003EaaFo5Kl009Fo006D_aFo5;lE_aBo0003U;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`00goo001oo`0SOol00`00Oomoo`0?Ool0039oo`03001oogoo01eoo`@0
05Yoo`08Ok=kTW^bNi5k/W^BNk=gTP9k/`1;NmIg]G_FMkMgegNgMkUc^7NiLkQc^VnJLkY[NVnKHe]S
G5lkHeaSFf=LFc]OG5LLFaaG75/LEaaK75;lEaaBo5LLD_aG75;lE_aBg5KlD_aFo000E_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0002=o
o`03001oogoo00moo`009Goo1P001goo00<007ooOol077oo0`00Fgoo00Ik/W^BNi9kTW^bNi83Nk<2
Nk@2NkD4MkL017>hLkUc^Fnj0VnJ00A[Nf^KJg][V`=SG0AO?0AK70=G70IFo003D_aFo5;l009Bo003
001Bo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=oo`00Ool087oo00<007oo
000047oo000^Ool4000LOol3001NOol077^BNk=kTG^bNi9k/WNBNk=kTW^dMi9k/g^BNkAg/g^dLkQg
^G>hLkY_VW>jKiU_Vf]jJi][NVnK0Ull03UK>emLGcaO?5/kFaaFo5/LE_aK75KlEaaBo5LLD_aFo5;l
EaaBo5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg7oo00008Goo00<007oo000047oo000^Ool00`00Oomoo`0JOol3001QOol2
Ni800g^bNi9kTP02Nk<3Ni800g^cNi9k]002Nk@017NeNkEk]Fnj0fnJ00M[Vf]kJi][Nf^KIe]WN`05
Gc`00e/lFaaG7002Ea`01EKlEaaG75KlD_`00eKl00QBo5KlD_aFo5;l001Bo5Kl35;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo002000OOol01@00Oomoogoo00003goo000^Ool0
0`00Oomoo`0HOol2001SOol07g^cNi9k/W^BNk9kTW^bNi9k/W^BNk=kTW^cMk=k]7^cNmIg]G_GMkMg
egNfKi][NV^KJgY_VfMKIgaSFemL009O?004FaaO?5/LGc`2Fa`015KlFaaFo5LL0UKl02eBo5LLD_aF
o5;lEaaBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg7oo00007Woo00D007ooOomoo`0000moo`00;Woo1@004goo0`00IGoo
00=kTW^bNi800W^B00Mk/W^BNi9kTW^bNi9k/`03Nk@3NkD3MkL01WNiLkQ[Vf]kIgaWF`9WN`0:IgaW
Fe/lFaaK?5/LFcaK75/lFa`2E_`00eLLE_aFo002E_`025;lE_aFo5KlD_aFo5;l0003D_`00eKlD_aB
o006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol001eoo`<0
0004Ool00000000>Ool004Aoo`8006Moo`0XNi9o/g^BNk9kTWncNi9k/W^ANk9kTW^cMi9k]7^cNkAg
]G_FMkMgegNfMkUc^7NiLkQWO6MKIgaSFfMlIe]SG5lkGcaK75llFaaO?5LLFa`2Ea`015KlEaaFo5LL
0UKl02aBg5KlD_aFo5;LE_`005KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`002Goo100097oo0011Ool300000goo001oo`1V
Ool01G^bNi9kTW^CNk800g^B00Ak/W^BNk=k/P=k]09k]@Ag]`05LkQc^G>iKkY_VP02Ig/00fMlHeaS
G004He`6Fa`3E_`00eLLE_aFo002E_`015;lE_aBo5Kl0U;l00<005;lD_`02e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo0007Ool00`00Oomoo`02Ool00`00Oomo
o`0QOol003moo`8006]oo`0<Ok=kTW^dNi=o/g^BNk9kTG^bNi9k/gNB0W^c051k]7NeNmIg]gOGMkIk
eg>hMkUc^7>jKiYc^VnILkYSFf=LGc]SG6=KHeaK>emLEaaK75LLFaaG75/LD_aG75;lEaaBo5LLD_aF
o5;LE_aBo5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`001goo00<007ooOol00Woo00<007ooOol08Goo000lOol3
001]Ool017^DNkAkTg^c0g^B00Ek/W^BNi9k/W^c00=k]003NkEg]GNg009g]`04LkQc^G>iKkX3KiX0
0fnjJg][V`03He`4Gc`4Fa`3Ea`6E_`00e;lE_aBo002D_`00eKl001Bo00:D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol00006Ool00`00Oomoo`02Ool0
0`00Oomoo`0QOol003Yoo`8006moo`0PNiAk]G^COkAkTW^cNi9k/W^BNk9gTW^cNi9k]7NcNmIg]GOG
MkIkeg>hMkUc^7>jKiYc^VnILkY[NV^KJgY_V`9O?00lFc]OG5llGcaK>e/LE_aK75KlFaaFo5LLD_aG
75;lE_aBo5LLD_aFo5;LE_aBo000D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l0Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol08Goo000gOol3001aOol2Nk@01G^cNi=kTW^BNk800g^B00Mk/g^BNi9kTW^bNi9k/`02
Nk@017NeNkEk]Fnj0fnJ00M[Vf]kJi][Nf^KIe]WN`05Gc`00e/lFaaG7002Ea`01EKlEaaG75KlD_`0
0eKl0e;l00EFo5;lD_`005Kl00aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo003Ool007oo00Aoo`03001oogoo009oo`03001oogoo025oo`00=Goo0P0000=oo`00
Ool0L7oo02=k]G^DOkAkTg^dNi9o/g^BNk9kTW^cNi9k/W^BNk9kTW^cMk=k]7^cNmIg]G_GMkMgegNf
Ki][NV^KJgY_VfMKIgaSFemL009O?00:FaaO?5/LGcaFo5/LE_aK75KlEa`2E_`0;e;lEaaBo5KlD_aF
o5;LE_aBg000D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
8Goo000bOol3001eOol01W^dNkEkTg^cNi9k/P=kTP08Nk9kTW^BNi9k/W^BNk=k/P9k]0=k]@=g]`06
MkUc^6^KJg]WO6MK0VMk00UWO6MKFcaK75/lFaaK?5/LFc`00eKl00=G75KlE_`00UKl00ABo5KlD_aF
o0=Bo003E_`005;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo003D]aBo5;l00<000Aoo`@002Aoo`00;goo0`00Mgoo02QkU7^eNi=k]7^COk=kTW^bNi5k/W^B
Nk9kTG^bNi9k/gNBNkAk/g^dMkEkeWNgMmMg]WNiLkQg^G>hIgaWFfMlHe]WO6MKHeaO>ellFaaO?09K
7008EaaK75KlEaaFo5LLE_aG709Fo00aD]aFo5;lE_aBg5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo
0000;7oo000]Ool2001jOol01G^eNiAk/g^CNk800g^B00Ek/W^BNi9kTW^b009kTP04Nk9k/g^dNk@2
NkD01GNeMkMg]gNgLkP00W>i00E_^VnJIg]WNfMl00ISG0IK70=Fo003EaaFo5Kl009Fo005D_aFo5;l
E_aBo002000=D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aoogoo0000:goo000ZOol3001kOol047^eNiAk]7^COkAkTW^cNi5k/W^CNk=kTG^bNi9k/WNB
0W^c02Ik]7NcNmIg]GOGMkIkeg>hMkUc^7>jKiYc^VnILkYSFf=LGc]SG6=KHeaK>emLEaaK75LLFaaG
75/LD_aG75;lEaaBo5LLD_aFo5;L0`0002YBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`2Ool00`00Oomo
o`0XOol002Qoo`800003Ool007oo07]oo`04NiAk]7^CNk<3Ni801G^cNi=kTW^BNk800g^B00Mk/g^B
NkAk]7^eMkEk]@02MkL017>hLkUc^Fnj0fnJ00=_^V]kJi/00f=L15ll15/L0eLL1EKl0`000e;l00=F
o5;l00002U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QB
g5;lD_aBo5;LD_aoo`00:Woo000VOol2001oOol097^DNkEkTgndNi=k]G^DNkEkTg^dNi9k/W^BNk9k
TW^cNi9k]7NcNkAg]G_FMkIkeg>hMkUc^7>jKiYc^VnILkY[NV^KJgY_V`9O?00>Fc]OG5llGcaK>e/L
E_aK75KlFaaFo5LLD_aG7080000aD_aG75;lE_aBg5KlD_aFo5;L001Bg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`0
0Woo00<007ooOol09goo000VOol2001oOol2Nk@02G^fNiIk]W^dNkEkTg^cNi9k/P03Ni800g^bNi9k
/`02Nk@01G^BNk=k/W^dMkD00W^e00I_^VnJKiY_VV^KJg/3Ji/00fMKIg]O?003Gc`00e/LFcaK7003
Ea`00eKlEa`000020003E_`3D_`01eKlD_aBo5;lE_aBo00000YBo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002Ool00`00Oomoo`0VOol002Io
o`<007eoo`0_MkQgUg^hMiIk]W^DNkEkU7^dNi=o/g^BNk9kTW^bNi9k/g^BNk9kTW^cMi9k]7^cNmIg
]G_GMkMgegNfKi][NV^KJgY_VfMKIgaSFfMlFaaO?5/LGcaK75llE_aK70030000>ULLE_aFo5;lEaaB
o5KlD_aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00:7oo000VOol01000Oomo
o`00Ngoo0WNg00Ug^7^FNkIk]W^eNiAk/g^CNk<00g^B00Qk/W^BNi9kTW^bNi9k/g^b0W^c0g^e0gNg
00Ig^G>hJi][VfMlIe/2Ig/01fMlHeaSG5/LFcaK75/l00<0009Fo003EaaFo5Kl009Fo004D_aFo5;l
E_`3D_`00eKlD_aBo002D_`00`00D_aBo005D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l0Woo00<007ooOol09Goo000UOol00`00Oomo
o`02Ool00`00Oomoo`1hOol05GNGNkQgUg^fMiEk]G^DNkEkTgndNi9k/W^ANk9kTW^cNi5k/W^BNk9g
TP02Nk<04g^dMkEkeWNgMmMg]WNiLkQg^G>hIgaWFfMlHe]WO6=KHeaO>f=L00<00011FaaG75/LE_aG
75KlEaaFo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0
000WOol002Eoo`03001oogoo00=oo`03001oogoo07Ioo`03MkMg^7NG00=k]P05NiAk]7^CNk=kT`02
Ni801G^bNi9kTW^BNk800W^B00Ak/W^cNi9k]09k]@05MkEg]gNgMkMc^002LkT01FnjKiYWNfMkIg`0
0V=L0`0000=SG5/LFa`015/L1UKl00IBo5KlD_aFo5;lE_`8D_`01@00D_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003
Ool007oo02Eoo`009Goo00<007ooOol017oo00<007ooOol0MGoo02Ek^7NGMkQgUG^fNiAk]G^DOkAk
Tg^cNi5k/W^CNk=kTW^bNi9k/W^BNk=kTW^dMk=keWNeMmMg]W_GLkQg^G>hLkY_VW>jKiUc^P030000
AV=LHe]SG5/kGeaG75/LEaaK75LLFaaBo5LLD_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aB
g5Kl001Fo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00<007ooOol08goo000UOol20006Ool2001dOol00gNhMiMg
]`02NkH02G^FNkAk]7^cNi=k/g^BNk=kT`02Ni802g^bNi9kTW^BNk=kTW^cNkAk]GNeNkD00WNg00Ac
^7>iLkUg^@=_VP800004Ji]SG6=LHe`4Gc`4Fa`3Ea`6E_`00e;lE_aBo002D_`00eKlD_aBo005D_`0
0`00D_aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0002Eoo`009Goo00<007ooOol01goo00<007ooOol0L7oo
029k^7NGMkQgUg^fMiIk]G^DNkEkTg^dNi9k]G^CNkAkTWncNi9k/W^BNk9kTW^cMk=k]7NeNmIg]W_G
LkQg^G>hMkU_VP<00004JgY[Vf]jKi/2Gc`0BE/kGeaO?5llFc]K75KlFaaFo5/LE_aK75;lEaaBo5Kl
D_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002Aoo`00
9Goo00<007ooOol027oo00<007ooOol0Kgoo011gUgNgMkMk]W^FNkIk]7^eNi=k/g^CNkEkTg^cNi9k
/`=kTP0:Nk9kTW^cNk9k]7^BNk=k/W^dNk<2NkD300000fnJJi][N`03Ji/00fMKIg]O?003Gc`00e/L
FcaK7003Ea`3E_`00eLLD_aFo002E_`3D_`01EKlD_aBo5;lE_`01e;l00<005;LD_`00U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo7ooOol0000SOol002Eoo`03001oogoo00Uoo`03001oogoo06eoo`0MMiMg^7NGNkQgUW^fNiAk
]G^DNkIgUG^eNiAk]7^COk=kTW^bNi5k/W^BNk=gTW^bNi9k/gNBNkAk/`03000067NgMmMg]VnKJgY[
Vf]jIgaWFfMlHe]WO5/LGcaK75llFaaO?5/LEaaFo5LLE_aG709Fo00lD_aG75;lE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`008goo000TOol2000<Ool00`00
Oomoo`1[Ool4KiX01G^FNkIk]WNhMiL00g^f00AkU7^cNi=k/`=kTP03Nk9kTW^c009k/P03Ni9k/g^b
00<0009k]@09MkEg]gNgMkUc^7>iIg]WO6MK009WN`07IgaSG6=LFaaK?5/LFc`00e/L0UKl00=G75Kl
E_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00QBo003001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`008Woo
000TOol00`00Oomoo`0<Ool00`00Oomoo`1YOol06FmjKiY_NG>JLiQc^G>HNkQgUgNhMiEk]W^DNkEk
TgndNi9k/g^ANk9kTW^bNi5k/W^B00<0000JNk=k]7NeNmIg]GOGMkIg^G>hMkU_VG>jIe]WO6=KHeaS
Ff=LGc]SG5/LGcaG75/LEaaK709G700oE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L009oo`03001oogoo01moo`0097oo00<007ooOol0
3Goo00<007ooOol0Igoo16nJ17>I00UgUgNgNkIk]W^FNkAkTg^cNi<00W^B00Ak/W^BNi9kTP<00003
Nk9k/g^B009k]003NkEg]GNg009g]`04LkQc^FnJKkX3KiX7He`7Fa`5E_`01U;lE_aBo5KlD_aFo0iB
o003001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`00e;LOol0000QOol002Aoo`03001oogoo00ioo`03001oogoo06Eoo`0F
KgY_VVmiLiYcV7>iLiQg^GNGMkQgUG^fMiIk]G^DOkAkTg^cNi9k/W^BNk@20000IG^BNk9kTW^cNi9k
]7NcNmIg]GOGMkIkeg>hMkUc^7>jKiYc^VnIKi][NV=LGc]SG6=KGcaK>emLEaaK75LLFaaFo5/LE_aG
75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`005;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg7oo000087oo000TOol00`00Oomoo`0?Ool00`00Oomoo`1SOol4KiX4LiT01GNGMkMg]g^f
NiH00W^d00Ek/g^CNk=kTW^c00<00007Nk=kTW^BNi9k/W^BNk<00W^d00Eg]G^eMkMg]g>h009c^@06
KkY_VVnJKiY[Vf]k0V^K1ell0ULL00AFo5LLEaaG70AFo004D_aFo5;lE_`3D_`00eKlD_aBo00:D_`0
1E;L001Bo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo09oo`03001oogoo01eoo`0097oo0P004Goo00<007ooOol0HGoo019_
NVnJKgUcVW>HLkUcV7NiMiMg^7NGNkIgUW^fNiAk]G^CNk@300007g^dNi=o/g^BNk9kTW^bNi9k/gNc
NkAg]G_FMkIkeg>hMkUc^7>jKiYc^V]jKi][NV^KJgYWO6MKGcaK>emL009O?01:FaaO?5KlFaaFo5/L
E_aK75;lEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lOol001moo`008goo00<007ooOol04Woo00<007ooOol0Ggoo00AWFfMlIe]WO0Ec
V@9g]`05NkIkUW^fNkAk]@0300001G^eNiAk/g^CNk<00g^B00Mk/W^BNk=k/W^dNi9k/`02Nk@00g^c
NkEk]@03MkL2Ji/01F]kJi][VfMlIe/00VMk00IK?5/LFcaK75/lFa`3Ea`3E_`00eLLD_aFo002E_`0
15;lE_aBo5Kl35;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo000NOol001Yoo`@000Eo
o`03001oogoo01=oo`03001oogoo05eoo`0>He]WO6=KIga[NV^KLiQg^G>HMkQgUg^hMiIk]P<0000_
NkIgUG^fNiAk]G^COkAkTW^cNi5k/W^BNk=gTW^bNi9k/gNBNkAk/g_FMkEkeWNgMmMc^7NiJgY[Vf=K
IgaWFfMlHe]SG6=KGcaK75llFaaO?5/LEaaFo5LLE_aG7002E_`0?e;lEaaBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg002Ool00`00Oomoo`0K
Ool001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Aoo`03001oogoo05Yoo`05IgaW
FfMlIe]WO005Jg/2MkL01gNh00000000MkQgUgNg009k]P05NiAk]7^CNk=kT`02Ni801G^bNi9kTW^B
Nk800W^B00Ak/W^dNk=k]09k]@=g]`07MkUc^7>iIg]WO6MKIg/01F=L00=K?5/LFc`00e/L0UKl00=G
75KlE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01@00D_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L009Bo003Ool007oo01aoo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
5Goo00<007ooOol0F7oo00]WO6=KIgaSFfMlJgY[VfMjJi][NVnJ00<0000FLkUcV7^hMiMg^7NENkIg
UW^eNiAo]7^CNk=kTW^bNi9k/W^BNk9kTW^bMi82Nk<06G^dMkEkeWNgMmMg]WNiLkQg^FnILkY_VW>j
Gc]SG6=KHeaO>f=LHe]K75LLFaaG75/L009G7017D_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000LOol001Uo
o`03001oogoo009oo`03001oogoo009oo`8001Moo`8005Moo`05GeaO?6MlIe]WO005Jg/20002KiX3
LiT01GNGMkMg]g^fNiH00W^d00Ek]G^CNk=kTW^b00=kTP04Nk9kTW^BNi82Nk<2Nk@02G^eMkMg]gNg
MkUc^7>iKiY_^P02KiX2Ji/5He`2Gc`3Fa`2Ea`8E_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`0
0e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0JOol001Uoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo01Qoo`03001oogoo059oo`09FcaOGE/lGeeK?5mMJgY[VfMj00<0000^KgUcVVmj
LkUcV7NiMiMg^7NGNkIgUW^fNiAk]G^CNkAkTWncNi9k]7^BOk=kTW^bNi9k/g^BNkAg/g_FMkEgegNf
NmMc^7NiLkQc^VnJLkY[NVnKJgYSG5lkHe`2Gc`0D5/kGeaO?5/LE_aK75KlFaaFo5LLD_aG75;lEaaB
o5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;L000KOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Uoo`03001o
ogoo04moo`9O?004GeaO?5llGc`2Ge`300000f]kKiY_VP02KiX4LiT2MkL03GNhNiIk]W^dNkEkU7^c
Ni=k/g^BNk=kTW^c00=kTP03Nk9kTW^d009k]005MkEg]gNgMkMc^002LkT00fnjKiY_VP02Ji/00f]k
Ji][V`06Gc`015/lFaaG75Kl0eLL15Kl00ABo5KlD_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aB
g002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol001Yoo`006Goo00<007ooOol00Woo00D007ooOomo
o`0001eoo`03001oogoo04aoo`07EaaK?ELLGeeK?5mMFc`00`0008QO>f=LGea_VVmiLiY_NW>iLiQg
^G>HMkQgUg^hMiIk]WNENkEkU7^dNi=o/g^BNkAkTgncNi9k/W^BNk9kTW^cMk=k]7^BNk=g/g^dMkEk
eGNeLkY_VW>jJgY_Vf]jJi][NVMlIe]O?5/kGeaK75llFaaO?5KlFaaFo5/LE_aG75KlEaaBo5KlD_aG
75;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlOol000Moo`D000eoo`006Woo100017oo0P007Goo00<007ooOol0Agoo00QG?ELLFceG
75LmEaaK?ELL0`0000MOG6=LHeaSG5mLIgaWF`03KiX3LiT2MkL03GNhMiMk]W^fNkEkU7^dNi=k/g^D
NkAkTg^c00=kTP07Nk9kTW^cNi9k/W^BNk<00W^d00=k/g^eNkD00gNg0V^K00E[Nf^KIg]WO6MK009W
N`09FcaK75/lFaaK?5/LFcaFo5LL00=Fo003EaaBo5Kl009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol00007Ool01@00Oomoogoo
00003Goo000ROol00`00Oomoo`0MOol00`00Oomoo`14Ool01e<LEaeC75/mEaaK?ELL00<0000nEaaS
G5mLHeaO>f=LGeaWO6=KIgaSFfMlLiQg^G>HLkUgUg^hMiMk]WNENkIkU7^eNi=o]7^DNkEkTgndNi9k
/g^ANk9kTW^cNi5k/W^BNk=gTW^dNk=keGNeNmIg]gOGLkQg^G>hMkUSFfMlIe]WO6=KHeaSFellFaaO
?09K701?EaaK75KlEaaFo5LLE_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol03Woo
000ROol00`00Oomoo`0NOol00`00Oomoo`10Ool2Ead01E<MEaeG7ELMDad00`0000EG75LmFcaK?E/l
00=SG006Ie]WO6MKIgaWFfMl16]k00Ag]gNhMiMg]`9k]P05NiAk]7^dNkIkUP02Nk@01G^cNi=kTW^B
Nk800g^B00Mk/W^BNi9k/W^dNk=k]002NkD2MkL027>hMkUc^7>iKiY_^VMKIg/6He`5Fa`2E_`00eLL
E_aFo002E_`01U;lE_aBo5KlD_aFo0iBo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o09oo`03001oogoo00Eoo`03001oogoo00eoo`008Woo00<007ooOol07goo00<007ooOol0?Goo00MC
7E;lEaeC75LMDaaG7@020000;E<LEaeK?5/mFaaK?E/lFceK75/mHe]WO6=KIgaSFfMlIgY[Vf]jJg]_
NG>JKgY_VW>HMkUgUgNhMiMk]WNFNkEkU7ndNi=k/g^BNk9kTW^bNi9k/W^BNk9gTP02Nk<04g^dMkEk
eWNgMmMg]WNiLkQg^FnILkY_VW>jGc]SG6=KHeaO>f=L009O?004EaaK75LLFa`2Ea`0C5;lEaaBo5LL
D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0027oo00<007ooOol037oo000ROol00`00Oomoo`0POol00`00
Oomoo`0iOol00e<MD_eC7@02Dad00e;mDad000020003Ead015LLEaeK?5/m0e/l00MK?EllGcaWFfMl
Ie]WO004Jg/4KiX3LiT02gNgMiMg^7^FNkIk]7^eNi=k/g^BNk<00g^B00Mk/W^BNi9kTW^cNi9k]002
NkD3MkL01gNiLkQc^FnJKkY_VVnj009[V`=SG0AO?0=K709G70QFo0=Bo003E_aBo5;l00iBo005D]aB
o5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo09oo`03001oogoo00Ioo`03001oogoo00]oo`00
8Goo0P008goo00<007ooOol0=Woo00I>o5<MD_aC7E;lEad30000AELMDaaG7E<LEceG75LMDaaG?E/l
FceK75mMFcaOGE/lGeeSFfMlIgY[Vf]jJg]WNW>JKgY_VW>HMkUcV7NhMiMk^7NFNkIkU7^eNi=k]7^B
Ok=kTW^dNi9o/g^BNk9kTG^cNi9k]7NcNmIg]GOGMkIg^G>hMkU_VG>jKiYc^V]jKi][NV^KFc]OG002
Gc`0De/kGeaO?5/LE_aK75KlFaaFo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`00Woo00D007oo
Oomoo`0000=oo`03001oogoo00]oo`008Goo00<007ooOol08goo00<007ooOol0<Woo00IBoE<MD_eC
7E;mDad30003Dad01E;mEaeG7ELMEa`00eLM00AG75LMGcaOG0=O?003GeaO?5ll00E[N`A_VP=cV@0>
MiMg^7NGNkIk]7^eNiAk/g^CNk=kTW^cNi9k/`=kTP06Nk9kTW^cNkAk]GNe0W^d00Ik]GNeNkE_VVnj
KiX3Ji/016]kJi]WNfMl15ll00QK75/lFaaG75KlEaaFo5LL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`20004
Ool3000>Ool0025oo`03001oogoo02Aoo`03001oogoo02moo`05Dae>o5<MC_aC7@030000Y5<MD_aC
7E;lEaeBo5LMD_aG?ELLEaeC75LmEaaK?ELLFceK?5mMFcaOGE/lGeeO>f=LJgY[NfMjLiY_NVnJKgUg
^G>HLkUgUg^hMiMk]WNENkEkU7^dNi=o/g^BNkEkTgncNi9k/W^ANk9kTW^cMk=k/W^BNk=g/g^dMkEk
eGNfNmMg]f^KJgY_Vf]jIgaSFfMlIe]WO5/LGcaK75llFaaO?5/LEaaFo5LLE_aG75KlEaaBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg7oo000DOol0025oo`03001oogoo02Eoo`03001oogoo02]oo`9Bo@03
DaeBoE;m00<00004DaeBoE<MD_d2Dad01ULMDaeC7E<MEaeC7@=G7@09EaaG?ELLFceG75LmGcaOG5ll
00=SG003GeaSG6=L00A_VP=cV@0>MiMg^7NGMkMk]W^eNiAk]7^CNk=kU7^eNi=k/`=kTP03Nk9kTW^c
009k/P05Ni9k/g^dNkAg]@02NkD2MkL017>iLkQg^G>h0VMk00=WO6MKIg/00V=L00AK75/lFaaK?0=K
7005EaaFo5KlE_aG7002E_`01U;lE_aBo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0BOol0025oo`03001oogoo02Ioo`03001o
ogoo02Qoo`04C_aC7DklDad30000Ze<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E;lFceG75/m
EaaK?ELLFceG75/mGeaSG5lkHeaOG6=LGc]WO6=KIgaSFgNiLiQc^G>HNkQgUgNhMiEk]W^DNkEkTgnd
MiIk]G^DOkAkTW^cNi5k/W^BNk=gTW^bNi9k/gNBNkAg/g_EMkEkegNgMmMc^7NiLkQc^VnIIgaWFf=L
Gc]SG6=KHeaO>e/LEaaK75LLFaaFo5LLE_aG75;lEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
Ool0000COol0025oo`8002Qoo`8002Eoo`03D_eC7Dkm009Bo@80009Bo@06DaeBoE;mD_eC7E;m0e<M
00ABoE<MDaeG7@9C7@9G7@08DaeG?ELLFceG75LmEaaK?@9K?09SG007GeaSG6=LIgaWFfMlIe/016]k
00Ig^7NGMkMgUg^fNi@2Nk@01W^fNiIk]G^dNk=kT`9kTP05Nk9kTW^BNi9k/P02Ni800g^bNkAk/`03
NkD2MkL01g>hMkUc^6njKiY_^VnJ00ISG09O?0EK70MFo09Bo003E_aBo5;l00iBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aBg5;lOol0019oo`008Goo00<007ooOol0
:Goo00<007ooOol087oo00AC7DklDae>o0<0001HC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;l
DaeC75LMDaaG7E<LEaeC75/mEaaK?E/LFceK?5/mFaaK?EmLHeaSFfMlHe]WO6=KJi][NV]kIgYcVVmj
KiY_NGNiMiMg^7NGNkIgUW^fNiAk]G^CNk=kTW^bNi9k/W^BNk9kTW^bMi9k/gNcNkAg]G_FMkMgeg>h
MkUc^7>jKiUc^VnJJi][NV=LHe]SG5/kGe`2Gc`0Ee/kFaaFo5/LE_aK75;lEaaBo5LLD_aFo5;lE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`0000BOol0021oo`03001oogoo02]oo`03001oogoo01aoo`04
Dae>oE;mD_d300000e;mDae>o@02D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<M
00=G7@04DaeK?5/lFcd3Fc`025/mFcaK?6MKIgaWFfMlIe/4Jg/4KiX2LiT02gNgMiMg^7^FNkIk]7^e
Ni=k/g^BNk<00g^B00Ak/W^BNi9kTP9k/`04NkAk]G^eMkD2MkL01WNiLkQ_^VnJKkY_VP=[V`03Jg]O
?5ll00AO?003FcaK75LL009G7005E_aG75KlE_aBo003E_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00004Goo000POol0
0`00Oomoo`0/Ool00`00Oomoo`0FOol01U<MC_eC7DklDae>o@<0001LC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aG7E;lDaeBo5LMDaaG7E<LEaeG75LMDaaG?E/lFceK75/mFcaOGE/l
GeeSFfMlHe][Vf]jJg]WNV^KKgY_VVmiMkUcV7NhMiMk^7NFNkIgUG^eNiAk]7^BOk=kTW^bNi=o/g^B
Nk9kTG^cNi9k]7NcNmIg]GOGMkIg^G>hLkY_VG>jKiY[Vf]jKi][NVMlHe]OG09O?01KFaaO?5/LGcaF
o5/LE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000047oo000P
Ool00`00Ool0000]Ool00`00Oomoo`0COol00e;mDae>o@02D_d300000e;mDae>o@02D_d01E<MC_eB
oE;mDad00e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeG7003Ead015LLEaeG7EmL
0ell00AOG5llGcaO?0E[N`A_VP9cV@03MiMg^7NG009k]P09NkEkU7^cNi=k/g^BNk=kTg^c00=kTP06
Nk9kTW^dNkAk/g^B0g^d00=g]GNgMkL00WNg0f^K00aWFfMkIg]WO6MKFcaK75/lFaaK?5/LFc`3E_`0
0eLLE_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo080011oo`0087oo0P00;goo00<0
07ooOol03goo00E>oE<MC_aC7Dkm00<0001VC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7ELLEaeC75LmEaaG7ELLFceG75mMFcaOGE/lGeeK
?6=LGea[NfMjJi]_NVnJKgUcVW>HLkUgUg^hMiMk]WNENkIkU7^eNi=o/g^BNkEkTgndNi9k/W^ANk9k
TW^cNi5k/W^BNk=g/g^dMkEkeGNfNmMg]gNiLkQg^FMKIgaSFfMlHe]SG5lkGcaK75ll0U/L00IG75/L
E_aG75KlEa`2E_`0D5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000?Ool000Eo
o`D000Eoo`8000Eoo`@000Ioo`03001oogoo02moo`03001oogoo00aoo`04Dae>oE;mD_d300000e;m
Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02E<MD_eC7E;mDaeBoE<MD_eG
7@03Dad00eLMDaeC7@02Ead025LLEceG75/mEaaG?ELLGe`2Gc`2He`015mLHeaSG6=L16nJ0W>I00Ag
UgNhMiMg]`9k]P08NiAk]G^CNk=kU7^eNi=k/`=kTP07Nk9kTW^cNi9k/W^BNk<00W^d00=k/g^eMkL0
0WNg00Ic^G>hMkU_VVnjKiX7He`6Fa`6E_`015;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0Woo00<007ooOol037oo0004Ool2
00001Goo000007oo000017oo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0<7oo
00<007ooOol027oo00EC7DklDae>oE<M00800037C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E;lEaeG75/mEaaK?ELL
FceG75/mEaaSG5lkHeaOG6=LGc]SG6=KIgaSFfMlLiQc^G>HNkQgUgNhMiEk]WNFNkEkU7^fMiIk]G^D
OkAkTg^cNi5k/W^BNk9kTG^bNi9k/gNBNkAg/g_EMkEkegNgMkUc^7NiKiYc^VnIKi][NV=LGc]SG6=K
GcaK>emLEaaK75LLFaaFo5/LD_aG75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg7oo00003Woo0004Ool20002Ool00`00Ool0000?Ool00`00Oomoo`03Ool00`00Oomoo`0aOol0
0`00Oomoo`05Ool014kmD_eBoE<M0`0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7E;mD_eBoE<MD_d3Dad015;mDaeC7ELM0e<M00UG7E<MEaeG75/mEaaG
?ELLFcd00e/l00USG5mLHeaSG6MlIe]WO6MKIg`00f]k00ig^7NGMkMgUg^fNiIg]gNGNkIkUW^eNkAk
/g^C0W^B00ak/W^BNi9kTW^bNi9k/g^bNkAk/g^dNkD2MkL027>iLkQg^FnJKkY_VV^KJg/2Ji/7Gc`2
Ea`00eKlEaaG7005E_`015;lE_aBo5Kl45;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
2E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool037oo0004Ool20002Ool00`00Ool0000?
Ool00`00Oomoo`02Ool2000dOol02000OomoogooC_aC7DkmDad30000Ke<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC
7E;lEaeC75LMDaaG7E<LEaeG75/mEaaK?E/lFceK75/mGeaSG5lkIgaSFfMlHe]WO6]jJg]WNW>JKgY_
VVmiMkUcV7NhMiMk^7NFNkIkU7^eNi=k]7^BNk9kTW^cNi9k/W^BNk9gTW^cMk=k]7NeNmIg]gNiLkQg
^FnJLkY_VFnKJgY[Vf]jIgaWFellFc]OG002Gc`01U/LGcaFo5/LE_aK709Fo01ED_aG75;lE_aBo5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000037oo0004Ool20002Ool00`00Ool0
000;Ool40005Ool00`00Oomoo`0bOol00e;mDae>o@02D_d01U<M00000000Dae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeB
oE<MD_d3Dad01E;mDaeC7ELMDad00eLM00AC7ELMFcaK?@=K?008FceK?5/lIe]WO6MKIgaWF`A[N`A_
VP=cV@0>MiMg^7^FNkIk]7^eNi=k/g^BNk9kTW^cNi9k/`=kTP9k/`9k]003NkEk/g^d009k]@05KiY_
^VnJJi][N`02Ji/03FMlIe]WNfMkFcaK75/lFaaK?5/LFcaFo5LL00AFo004D_aFo5KlE_`3D_`00eKl
D_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
001Bo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00QBg5;lD_aBo5;LD_aoo`0037oo0003Ool300001Goo000007oo00002goo00<007ooOol01Woo00<0
07ooOol0<7oo00EC7DklDae>oE<M00<0001gDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG
7E;lEaeC75LMDaaG7E<LEceK?5/mFaaK?E/lGeeK?5mMHe]WO6=KJi][NV]kIgY[VfmjKiY_NGNiLiQc
^GNGNkQgUg^fMiEk]G^DNkAkTgncNi=k]7^BOk=kTW^bNi5k/g^BNkAg/g^cMk=k]7NeNmIg]gOGMkIg
^G>hJi][NVMlIe]WO6=KHeaSFellFaaO?002Fa`01ULLFaaFo5LLE_aG709Fo01DD]aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`002goo0005Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0]Ool01E<MC_eBoE;mDad00`0000IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<M
D_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMEa`00eLM00AG75LMEaeOG0=O?004
GeaO?5llGc`5Jg/4KiX3LiT00gNhMiMk]P02NkH027^DNk=kTg^cNiAk/g^CNk<3Ni801W^bNi9kTW^B
Nk9kTP9k]00;NkEg]GNgMkMg^G>hLkUc^6MlIe]WN`05He`6Fa`2E_`00eLLE_aFo002E_`015;lE_aB
o5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;l
D_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00ABg5;l000000Yoo`001Woo100037oo1@0017oo00<007ooOol0:goo00A>
o5<MC_eC7@<00021Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;l
EaeBo5LMDaaG?ELLEaeC75/mEaaOGE/lGeeK?5mMFcaSG5mLJg]WNV^KKgY_VVmiLiYcV7>iLiQk^7NG
MkQgUG^fNiAk]G^COkAkU7^dNi=o/g^BNk9kTG^bNi9k/W^ANk9kTW^dMk=keWNeMmMg]W_GLkQg^G>h
LkY_VW>jGc]SG6=KHeaO>emLGcaK75LLFaaG75/L009G701ID_aG75;lEaaBo5KlD]aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000:Ool001moo`03001oogoo02Qoo`05C_eB
oE;mDae>o@0200001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eBoE<MD_eC7E;mDaeBoE<M
D_d4Dad03ELMDaeC7E<MEaeG75LMEaaK?ELLEceG75mL009O?09SG004GeaSG6=LHe`4KiX3LiT00gNh
MiMg]`02NkH027^FNkEkTg^cNiIk]G^CNk<3Ni801g^bNi9kTW^BNk9kTW^c009k]00:MkEg]gNgMmMc
^7>iLkQ_^VnJKkX2Ji/2He`5Gc`3Fa`2Ea`6E_`00e;lE_aBo002D_`00eKlD_aBo00:D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00000e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o003D]`0000000Uoo`007Woo0P009Goo00M>oE<MC_aC7DkmDae>o0030000OTklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeBo5/mEaaK?ELL
FceG75/mEaaSG5lkHeaOG6=LGc]SG6=KIgaSFfMlLiQc^G>HMkUgUgNhMiMk]WNFNkEkU7^fMiIk]G^D
OkAkTg^cNi5k/W^BNk=kTG^bNi9k/gNcNkAg]G_EMkIkeg>hMkUc^7>jKiYc^V]jKi][NV^KFc]OG09O
?01RFc]OG5llFaaFo5/LE_aK75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lOol000Uoo`007Woo00<007ooOol08Woo00IC7DkmD_eBoE<MC_d300001Dkm
D_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE;mD_eC7E;m0e<M00=BoE<M
Dad015<M00YG7E<MEaeG7E/mEaaG?ELLFceG709K?009HeaOG6=LHeaWO6MKIgaWFfMl00A[N`0=MiMg
]gNGNkIkUW^fMiMk]W^FNkIk]7^cNi<00W^B00Ek/W^BNi9kTW^b009kTP0<Nk9k]7^cNkEg]gOGLkQc
^G>hKkY_VVnj0V^K00A[Nf^KIg]WO0AO?008FaaK?5/LEaaFo5LLE_aG70AFo004D_aFo5;lE_`3D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00009Ool001ioo`03001oogoo021oo`05C_aC7Dkm
Dae>o0030000hdklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7E;lDaeBo5<MDaaG7E<LEaeC75LMDaaK?ELLFceK?5/mFaaK?E/lFceSFfMlHe]WO6=K
Iga[NV]kIgY[VfmjKiY_NGNiLiQc^GNGNkQgUW^fNiAk]G^CNkAkTW^bNi=k/g^BNk9kTW^bMi9k]7Nc
Nk=gTW^dMk=keGNeNmMg]gOGJgY_Vf]jIgaSFfMlIe]WO5/LGcaK75llFaaO?5/LEaaFo5LLE_aG75;l
EaaBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`017oo00<007ooOol01goo
000NOol00`00Oomoo`0NOol2D_d00e<MC_d0000200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@=G
7@04DaeG7ELMFcd3Fc`025/mFcaK?5llGeaWFfMlIe/5Jg/3KiX4LiT02WNhNiIk]W^fNkEkTg^cNi9k
/g^C0W^B00Ak/W^BNi9kTP9k/`04Ni9k/W^dNk<3NkD2MkL00g>hMkUc^002Ig/00fMlIg]WN`02He`0
15/LFcaK75/l0e/L00eG75KlE_aFo5LLD_aFo5;lE_aBo5KlD_aFo00<D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l1goo00<007ooOol0
1Woo000NOol00`00Oomoo`0KOol015<MC_eC7Dkl0`00099>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklEaeBo5<MD_aG7E;lDaeC
75LMDaaG7E<LEceG75/mFaaK?E/lGeeK?5mMFcaOGE/lJi][NV]kIgY[VfmjKiY_NG>JLiQc^G>HNkQg
Ug^fMiEk]G^DNkAkTgncNiAk]7^BOk=kTW^bNi5k/g^BNk9gTW^cMk=k]7NeNmIg]gOGLkQgfG>hLkY_
VFMlIe]SG5lkHeaSFf=LEaaK75LLFaaG75/L0ULL051Bo5LLD_aG75;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;l2Woo00<007ooOol01Woo000MOol2000HOol01U<MC_eBoE;mDae>o@<00005C_eB
oE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eB
oE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM00AG75LMEaeG7@=O?006GeaO
?5llGcaSG5mL0f]k16nJ0g>I00=g^7NGNkH00W^f00QkU7^eNi=k/g^DNk=kTg^c0g^B00Ak/W^BNi9k
TP9k/`03NkAk]G^e00=g]`06MkUc^6njKiY_^VnJ16=L0ell15/L00=Fo5LLEa`01EKl0e;l00=Fo5;l
D_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo0io
o`03001oogoo00Ioo`007Woo00<007ooOol057oo00I>o5<MC_eC7DklDad20000STklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LFceG75/mFcaOGE/lGeeK?6=LGeaS
G5lkHea_NVnJKgUcVW>HLkUcV7^hMiMg^7NENkIkU7^eNi=o]7^DNkEkTgncNi9k/W^ANk9kTW^bNi5k
/g^BNkAg/g_FMkMgegNfMmUc^7NiKiUc^VnJJi][NVnK0Ull055K>emLGcaO?5/kFaaFo5/LE_aK75;l
EaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]`04goo00<007ooOol01Woo000MOol00`00Oomoo`0COol2D_d00e<M
C_eBo@030002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@9C7@0=EaeC7E<M
DaeG7E<MEceG75/mEaaG?ELLFcd00Ull0V=L00QOG6=LHeaSG6MKIgaWFfMl17>I00agUgNgNkIk]W^F
NkEk]7^fNiIk]G^CNk<3Ni802W^bNi9kTW^BNk9kTW^cNkAk]GNe0WNg00Ig^G>hLkU_VVnjJg/3Ji/2
Ig/4Gc`00e/LFcaK7003Ea`01EKlEaaFo5KlD_`00eKl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo009D]aBo5;l
D_aBg5;l001Bo5;L00=Bo006D]aBo5;lD_aBg5;l5Goo00<007ooOol01Woo000MOol00`00Oomoo`0A
Ool014kmDae>o5<M0`000>9C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeB
o5LMD_aG7E<LEaeC75/mEaaK?ELLFceG75/mGc]SG5mLHeaO>f=LHe]WO6=KIga[NV]kIgY[VgNGMkQg
Ug^fMiIg^7NGNkIgUW^eNiAo]7^CNk=kTG^bNi9k/W^ANk9kTW^cMk=k]7NeMmMg]WOILkQg^FnILkY[
NV^KJgY_VfMKIgaSFfMlFaaO?5/LGcaK75llFaaG75KlEaaFo5LLD_aFo5;lEaaBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg1Moo`03001oogoo
00Ioo`007Goo0P003goo00ABoE<MC_eBo@<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<M00=G7@05DaeG?ELLFceG7002Fc`02E/mGeaS
G6=LIgaWFfMlIe]WO004Jg/3KiX2LiT027NgMiMg^7^FNkIk]7^cNi<2Ni804g^bNi=kTW^BNk9kTW^c
Nk9k]7^BNk=k]7^eMkEk]GNgMmMc^7>i009[V`=WN`07IgaSG6=LFaaK?5/LFc`00e/L0UKl00UG75Kl
E_aBo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l00=Bg7ooOol0
6Woo00<007ooOol01Woo000MOol00`00Oomoo`09Ool01TklDae>oE<MC_aC7@<0003QDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG
7E<LFceK?5/mFaaK?E/lFceK76MlHe]WO6=KIga[NV]kIgY[VfmjKiY_NGNiLiQc^GNGNkQgUW^fNiAk
]G^CNkAkTWndNi=k/g^BNk9kTW^cMi9k]7^BNk=g/g^dMkEkeGNfNmMg]gNiLkQgfFMKIgaSFf=LHe]S
G5lkHeaG75/LEaaK75LLFaaFo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aoo`0001moo`03001oogoo00Eoo`007Goo00<007ooOol01goo0U;m00=C
7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MD_eC
7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<M00=G7@04EaaK?5/lFcd3Fc`01EmLGcaWO6MKIg`0
1F]k0VnJ0g>I00=gUgNhMiL00W^f00Uk]G^CNk=kTg^eNi=k/g^BNk800W^B00Mk/W^cNi9k/g^bNkAg
]@02NkD027OGMkMc^G>hMkU_VVnjKiX5He`2Gc`6Fa`6E_`00e;lE_aBo00?D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7ooOol0
0Woo00<007ooOol077oo00<007ooOol01Goo000MOol00`00Oomoo`05Ool014kmDae>o5<M0`000:5C
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7E;lEaeBo5<MD_aG7ELLEaeC75LmEaaG7E<LFceK?5/mFcaOGE/lGeeK?5mMJgY[NfMjJi][NVnJKgUc
VW>HLkUcV7^hMiMk]WNENkEkU7^dNi=o/g^CNkAkTWncNi9k/WNBNk=kTW^bMi9k]7NcNmEg]G_GMkMg
^G>hMmU_VW>jKiU_Vf]jHeaO>emL009O?00mFc]OG5llFaaFo5/LE_aK75;lEaaBo5KlD_aG75;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`027oo00<007ooOol06goo00<007ooOol01Goo000M
Ool01000Oomoodkm0U;m00AC7DkmD_eBo@80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00=G7E<M
Dad00ULM00EG75LMEaeG7ELL009O?004GeaO?5llGc`2Ge`016=LJg][Nf]k0fnJ0g>I00=g^7NGMkL0
0W^f00QkU7^cNi=k/g^DNk=kTg^c0g^B00Ak/W^BNi9k/P9k/`9k]@0:MmMg]gNgLkQg^FnJKkY_VV^K
Jg/2Ji/5Gc`01E/LFcaK75LLE_`00eLL00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`<Ool00`00
Oomoo`0KOol00`00Oomoo`05Ool001aoo`08001ooe<MC_eC7DklDae>o@<0003MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aG7E;lEaeBo5LMD_aG7ELLEaeC75LmEaaK?ELLGeeK?5mMFcaSG5mLHeaO>f=LGea_VVmiLiYcV7>i
LiQk^7NGMkQgUG^fNiAk]GNENkIkU7^eNi=o/g^BNk9kTGncNi9k/W^ANk=g/g^dMkEkegNgMmMc^7OI
KiYc^VnIKi][NV^KJgYWO6MKIgaK75llFaaO?5/LGcaK75LLE_aG75KlEaaBo5LLD_aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg00AOol00`00Oomoo`0JOol00`00Oomoo`05Ool001aoo`03001C7Dkm009Bo@<00003
D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00EG7E<MDaeC7ELM009C7@08EaaK?ELLEceG
75/mEaaG?@9SG008GeaSG6=LHeaOG6MlIe]WO0AcV@06MiMg]gNGNkIkUWNg0W^f00AkUW^eNi=k/`=k
TP08Nk=kTW^BNi9k/W^BNkAk/P9k/`03NkAk]G^e00=g]`05Ji][Nf^KIg]WO002Ig/2He`015/LFcaK
75/l0e/L00UG75KlE_aFo5LLD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`05goo00<007ooOol06Goo00<007ooOol01Goo000BOol5
0005Ool00`00C_d000020000g4kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeC
75LMEaaK?ELLFceG75/mFaaK?EmLHeaO>f=LHe]WO6=KIga[NV]kIgY[VgNGMkQgUgNiLiQg^7NGNkIg
UW^eNiAo]7^BNk=kTGndNi9k/W^ANk9kTW^dNi5k/gNcNkAg/g_FMkEgegNfMmUc^7NiHe]WO6MKHeaO
>f=LHe]SG5LLFaaG75/LEaaK75KlEaaFo5LLD_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl6Woo00<007ooOol067oo00<007oo
Ool01Goo000DOol00`00Oomoo`05Ool200000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7DkmD_eBoE<MD_eC
7E;mDaeBo@=C7@05D_eC7E<MEaeC7@03Ead015<MEaeG7E/m0e/l00UK?E/lFcaK?6MlIe]WO6MKIg`0
16]k0fnJ0g>I00MgUg^fNiIk]W^dNk=kT`02Ni802W^cNi9kTW^BNk9kTW^cNi9k/g^B0W^d00Yk]GNe
MkMg]gNiLkQc^FnJKkY_VPESG09O?0IK70IFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00U;l77oo00<007ooOol06Goo00<007ooOol017oo000DOol00`00Oomoo`06Ool0
/P00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5LMDaaG7E<LEaeC75LmEaaK
?E/LFceK?5/mFaaOGE/lIgaSFfMlJgY[NfMjJi]_NVnJKgUg^G>HLkUgUg^hMiIk]W^DNkEkTg^cNi9k
]G^CNk=kTG^bNi9k/g^ANk9kTW^dMk=k]7NeNmEg]W_GLkQg^FnILkY_VV^KJgYSG6=KGcaK>emL0Ull
02IFo5/LE_aK75KlFaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5Kl8Goo00<007ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07
Ool200000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL
00=G7@04EaaG7ELMFcd2Fc`6Gc`4Jg/4KiX3LiT03GNhNiIk]W^fNkEkU7^cNkAk]G^CNk=kTW^b00=k
TP03Nk9kTW^c009k]009MkEk]GNgMmMc^7>iKiY_^VnJ00=[V`03Jg]O?5ll009O?004FcaK75/lE_`3
Ea`01EKlEaaFo5KlD_`00eKl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo003D]aoogoo02Ao
o`03001oogoo01Moo`03001oogoo00Aoo`0057oo00<007ooOol02Goo0=4007ooDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7DklEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LEceG75mMFcaOGE/lGeeK?5mMGeaSG6Mj
Ji]_NVnJKgUcVW>HLkUcV7^hMiMk]WNENkEkU7^dMiEk]G^DNkAkTW^bNi9k/W^BNk9kTW^cMk=k]7Ne
NmEg]G_GLkQg^FnILkY_VV^KJgY_Vf]jIgaSFfMlFaaO?5/LGcaK75llE_aG75KlEaaFo5LLD_aFo5;l
EaaBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl02Qoo`03001oogoo01Moo`03
001oogoo00Aoo`0057oo00<007ooOol02Woo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;m
DaeBoE<MD_d2Dad01ULMDaeC7E<MEaeG70=G7@03EaaG?ELL00AO?003HeaOG6=L009SG0A_VP=cV@03
MkQgUg^f009k]P08NiAk]G^fNkEkU7^cNi=k/`=kTP06Nk9kTW^BNk9k]7^c0W^e00Ik]7^cNkEg]gOG
MkL3Ji/3Ig/01FMlHeaSG5/LFc`015/L0eKl00UG75KlE_aBo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`0
1U;l00=Bg5;lOol0:goo00<007ooOol05Woo00<007ooOol017oo000BOol3000=Ool0b000OomC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMD_aG7ELLFceG75/mEaaK?ELLFceO>f=LGeaSG5lk
HeaSFfMlHe]WO7>HLkUcV7NiMiMg^7NENkIgUgNhMiEk]W^DNkEkTgncNi9k]7^BOk=kTW^bMi9k]7Nc
Nk=gTW^dMk=keGNeNmMg]gNiLkQgfFMKIgaSFf=LHe]SG5lkHeaG75/LEaaK75LLFaaFo5LLE_aG75;l
EaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]`aOol00`00Oomoo`0EOol00`00Oomoo`04Ool0
01Aoo`03001oogoo00aoo`800006Oom>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00=C7E;mDad00U<M00EBoE<M
DaeG7E<M00=G7@09EaaG?ELLFceG75LmFcaK?EmL009SG005IgaWFfMlIe]WO004Jg/037NGMkMcVG>I
MiMg]gNGNkIkU7^eNi=k/`=kTP05Nk=kTW^BNi9k/`02Ni803G^bNk=k/g^dNkEgegNgLkUc^7NiKiY_
^VnJ00ESG09O?0IK70IFo003D_aFo5;l00MBo3Ioo`03001oogoo01Aoo`03001oogoo00Aoo`009Goo
0:P007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75LMEaaK?ELLFceK75/mFcaK?E/L
IgaSFfMlHe]WO6]jJg]WNV^KKgY_VW>HMkUcV7NhMiMk]WNFNkEkU7ndNi=k/g^COk=kTW^bNi5k/g^B
Nk9gTW^cMk=k]7NeNmIg]gOGLkQgfFnJLkY_VFnKJgYSG5lkGe`2Gc`04e/kGeaFo5/LE_aK75KlFaaB
o5LLD_aFo5;lEaaBo5KlD]aFo5;l03Yoo`03001oogoo01Eoo`03001oogoo00=oo`009Woo00<007oo
Ool00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<M
C_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMDad00eLM0e/l00AK?E/lFcaK?09O
?003IgaWFf]k00A[N`=_VP9cV@0;MkMgUgNhNiIk]W^dNk=kTg^BNkAk/`03Ni801W^bNi9kTW^BNk=k
TP9k]00:NkEg]gNgLkQg^FnJKkY_VV^KJg/2Ji/4Gc`00e/lFaaK?002Ea`01EKlEaaG75LLD_`00eKl
0e;l00=Fo7ooOol0>goo00<007ooOol057oo00<007ooOol00goo000WOol0]`00Oomooe<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5LMD_aC7E;lEaeC75LMDaaG?ELLEaeK75/mFcaK?E/lGeeK?5mMFca[Vf]jJg]WNV^KKgY_VVmi
MkUcV7NhMiMg^7NFNkIkU7^eNi=k]7^DOkAkTW^cNi5k/W^BNk9kTG^cNi9k]7NcNmIg]GOGLkQgfFnJ
LkY_VFnKJgY[Vf]jIgaWFfMlFaaO?5/LGcaK75llE_aG75KlEaaFo5LLD_aG75;lE_aBo010Ool00`00
Oomoo`0COol00`00Oomoo`03Ool002Qoo`800005OomBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05
D_eG7ELMEaeG7003Ead00eLLGcaO?004Gc`00f=LGea[N`02Jg/3KiX2LiT017NgMiMg^7^F0W^f00Ik
]G^CNk=k]7^eNi<2Ni801g^bNi9kTW^BNk9kTW^c009k]004MkEk]7^dNkD3MkL01F^KJg][VfMkIg`0
0VMk0V=L00=K75/lFa`00e/L00=Fo5LLE_`00UKl00=G77ooOol0@goo00<007ooOol04Woo00<007oo
Ool00goo000ZOol0Z`00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeBo5LmEaaG7E<LEceG75/mEaaOGE/lGeeO
>f=LGeaSG5lkHea_NVnJKgUcVW>HLkUgUgNhMiMk]WNENkEkU7^fMiEk]G^CNk=kTW^bNi9k/g^ANk9k
TW^cMk=k]7^BNk=g/g_FMkEgegNfMmUc^7NiHe]WO6MKHeaO>f=LHe]SG5LLFaaG75/LEaaK701:Ool0
0`00Oomoo`0BOol00`00Oomoo`03Ool002]oo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00EG7E<MDaeC
7ELM009C7@08EaaK?ELLEceG75/mEaaG?@9SG008GeaSG6=LHeaWFfMlIe]WO09cV@03MiMg^7NG00=k
]P0BMiMk]W^fNkEkU7^cNi9k/W^BNk=kTW^bNi9k/g^bNkAkTW^c0W^d00Ug]GNgMkMg^G>hLkU_VVnj
KiX016=L0ell0e/LCGoo00<007ooOol04Goo00<007ooOol00goo000/Ool0W`00OomC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LM
D_aG7E;lEaeC75LMEaaK?ELLFceG75/mFaaK?EmLHeaO>fMlHe]WO6=KIga[NV]kKgUcVVmjLiUcV7Ni
MiMg^7NENkIkU7^dNi=o/g^CNkAkTW^bNi9k/WNBNk9kTW^cMi9k]7NeNmEg]W_GLkQg^FnILkY_VV^K
JgY_V`02Gc`015/kGeaO?5llD7oo00<007ooOol047oo00<007ooOol00goo000]Ool20002D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m
0e<M00EBoE<MDaeG7E<M00=G7@05DaeG7ELLFceG7002Fc`02E/mFcaK?6MKIgaWFfMlIe]WO002Jg/4
KiX3LiT02gNgNkIk]W^DNkEkTg^cNiAk/g^CNk<00W^B0W^b0W^B00]k/W^dNk=k]GNgMmMc^7>iKiY_
^VnJ00=[V`9WN`=O?5=oo`03001oogoo011oo`03001oogoo009oo`00;goo09h005<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lEaeC
75LMDaaG7E<LEaeK?5/mFaaK?E/lFceK?5mMHe]WO6=KJi][NV]kIgYcVVmjKiYcV7NiLiQg^7NGNkIg
UW^eNi=o]7^DNkAkTgncNi9k/W^ANk9kTW^bMi9k/gNcNmEg]G_GLkQg^FnILkY_VV^KJgYWO6MKIgaS
FfMlEGoo00<007ooOol047oo00<007ooOol00Woo000`Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL
00=G7@05EaaG7E/lFceK?006Gc`4Jg/3KiX3LiT02gNgMiMk]W^FNkEk]7^cNiIk]G^CNk<00g^B00Ak
/g^BNi9kTP9k/`08NkAk]G^dNk=k]GNgMmMg]`9[V`05IgaWNfMkIg]WO01GOol00`00Oomoo`0?Ool0
0`00Oomoo`02Ool0035oo`2I001oogooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5LMDaaG?ELLEaeC75LmEaaOG5/lGeeK?5mLFcaSG5mL
HeaO>g>JKgY_VW>HMkUcV7NhMiMk]WNFNkIkU7^fMiIk]G^DOkAkTW^cNi5o/g^BNk9kTG^cNi9k]7NB
Nk=g/g_EMkEkegNgMkUc^7>jKiYWO6=K05Yoo`03001oogoo00ioo`03001oogoo009oo`00<Woo00D0
07ooOomC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC
7E;mDaeBo@9C7@06EaeC7E<MDaeG7ELL0eLM00=G75LmEa`00ell0V=L00EOG6=LHeaWO6MK009_VP=c
V@0;MiMg^7^FNkIgUgNhNiIk]W^dNk=kT`02Ni8027^cNi9kTW^BNk9kTW^dNi82Nk<02W^dNkEgegNg
LkUc^6njKiY_^VnJFgoo00<007ooOol03Woo00<007ooOol00Woo000cOol20000TgooDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeBo5LMEaaK
?ELLFceG75/mEaaSG5lkHeaOG6=LGc]WO6=KIgaSFgNiLiQcVGNGMkQcV7>IMiMg^7NFNkIkU7^eNi=k
/g^BNk9kTW^cNi5k/W^BNk=kTG^cNi9k]7NeNmMg]gOGLkQgfFnJLkY_V@1MOol00`00Oomoo`0=Ool0
0`00Oomoo`02Ool003Eoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@06DaeBoE;mD_eC7E;m0e<M00EBoE<MDaeG7E<M00=G7@04EaaG?ELLFcd3Fc`026=LGeaSG6MKIgaW
FfMkIe/3Jg/2KiX3LiT02WNhMiMk]W^fNkEkTg^cNi9k/g^C0W^B00Uk/W^BNk=kTW^bNi9k]7^cNkD0
0WNg00Ac^7NiKiY_^V1oo`03001oogoo00aoo`03001oogoo009oo`00=Woo08l007ooDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75LMDaaK
?E/lFceK75/mFcaK?F=KIgaSFfMlHe][Vf]jJg]_NG>JKgYcVG>HMkQgUg^fMiEk]G^DNkAkTWncNiAk
]7^BNk9kTW^bNi5k/W^BNk=g/g_FMkMgeg>hMmU_VW>j069oo`03001oogoo00]oo`03001oogoo009o
o`00=goo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeB
oE<MD_d3Dad01E;mEaeG7ELMDa`00eLM00AG75/lFcaK?@9K?09O?003Ie]WNfMK00=[N`=_VP=cV@0<
MiMg]g^fNkIkU7^eNi=k]G^DNk=kTW^b0g^B00Uk/W^BNk=k/g^dNi9k]7NeNkD00WNgHgoo00<007oo
Ool037oo00<007ooOol00Goo000hOol20000RE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7E;lEaeBo5<MD_aG7ELLEaeC75LmEaaG7E/LFceK?5mLFcaOGE/lGeaK?6^KJgY[Nfmi
LiY_NW>ILiQg^GNGMkQgUG^fNiAk]G^CNkIkU7^eNi=o/g^BNk=kTG^bNi9k/WNBNkAkTW^dMk=keWNe
MmL0IGoo00<007ooOol02goo00<007ooOol00Goo000jOol00`00Oom>o@02D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00=G7E<MDad00ULM00AG75LMEaeG7@MO
?003HeaOG6=L00A_VP9cV@0@MiMg]gNGNkIkUW^eNkAk]W^DNkEkTg^cNi9k/g^BNk82Ni82Nk801G^B
Nk9k/g^eMkD00WNgIWoo00<007ooOol02Woo00<007ooOol00Goo000kOol0Q`00Oomooe<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeBo5LMEaaG7E<LFceG75/mFcaOGE/l
GeaO>f=LGeaSG6=KIgaSFfMlLiQg^G>HMkQgUg^fMiIg^7NGNkIgUW^eNiAo]7^BNk9kTWncNi9k/W^A
Nk9kTW^cMk=k]7NeMmMg]P1XOol00`00Oomoo`09Ool00`00Oomoo`01Ool003aoo`03001oogoo009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00U;m0U<M00ABoE<MDaeG7@=C7@0:EaeC7E<MEaaK
?ELLEceG75/mEa`3He`01UmLHeaWFfMlIe]WN`=[N`9_VP9cV@0;MkMgUgNhNiIk]G^dNk=kTg^BNi=k
/`03Ni8027^cNi9kTW^bNkAg]G^eMkMYOol00`00Oomoo`09Ool00`00Oomoo`01Ool003eoo`800022
OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7ELLFceG75/m
FcaK?E/LHeaOG6=LHe]WO6=KIgaWNV^KJgY_VVmiMkUcV7>IMiMg^7NFNkIkU7^eNi=k/g^DOkAkTW^b
Ni5k/W^BNk9gTW^dMk=keGNcNkAZOol00`00Oomoo`08Ool00`00Oomoo`01Ool003moo`06001ooe;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7E<L00=G7@04DaaG7E/lFcd3
Fc`01U/mFcaK?6MKIgaWF`A[N`=_VP9cV@0:MiMg^7NGNkIk]7^eNi=k/g^DNk<3Ni8017^bNi9kTW^B
0W^c0W^b00=k]7ooOol0JWoo00<007ooOol01goo00<007ooOol00Goo0010Ool0P000OomC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aG7E;lDaeBo5LMD_aC7E<LEaeC75LMDaaG?E/lFceK75/mFcaOG5/lGeeK
?6]kIgY[Vf]jKiY_NG>JLiQcVG>HMkQgUg^fMiEk]G^DNkAkU7^eNi=k/g^ANk9kTW^bNi5k/gNcNk9g
TW^dMk=]Ool00`00Oomoo`07Ool10001Ool1Ool0045oo`06001oogooD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;m
DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@03EaaG7ELM00IO?0=SG004Gea_VVnJKiX3LiT0
1WNhMiMk]W^fNkEkU09k]P06NkEkTg^BNi9k/W^C0W^B00Ak/W^BNi9k/P9k/fioo`03001oogoo00Mo
o`40005oo`5oo`00@Woo0P0007]oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E<L
EceG75LMEaaK?ELLGeaK?5mMGeaSG5lkHeaOG6MlHe]WO7>HLiUcV7NiMiMg^7NENkIgUgNhMiEk]G^D
NkAkTW^bNi=k/g^ANk9kTW^bNi5k/gNcNk@0Kgoo00<007ooOol01Woo0@000Goo0Goo0014Ool01@00
OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0U<M00iG7E<MDaeC7ELMEaaG?ELLFceG75Lm
EaaK?EmL0f=L00AOG6MkIe]WO0A[N`06MiMg]g>ILiUgUgNg0W^f00QkU7^eNi=k/g^CNk=kTW^b0g^B
00=k/g^BNk@0LGoo00<007ooOol01Goo0@000Goo0Goo0015Ool0N@00Oom>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
D_aC7E;lDaeBo5LMD_aG7E<LEaeG75/mEaaK?ELLFceK?5/mGc]SG6=KIgaSFfMlJgY[NfMjJi]_NVnJ
LiQg^G>HMkQgUg^fNiAk]G^COk=kU7^dNi9o/g^BNk=kTG^bNi9k]7Nc075oo`03001oogoo00Eoo`40
005oo`5oo`00AWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMDa`00eLM
00AC75/lFcaK?@=K?005FceWFfMkIe]WO004Jg/3KiX2LiT02gNgMiMk]W^FNkEkU7^cNiAk/g^CNk<0
0g^B00Ak/W^BNk9k/g=oo`03001oogoo00Aoo`40005oo`5oo`00Agoo0P0007Aooe<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5LMD_aC7E;lEaeC75LMDaaG7ELLEaeC75/mFcaK?E/LGeeK?5mLFcaOGF]jJg]WNV^KKgY_VVmiMkUc
V7NhMiMg^7NFNkEkU7ndMiIk]G^COk=kTW^bNi9o/W^BNk=g/g^bM7oo00<007ooOol00goo0@000Goo
0Goo0019Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@03EaaG7Ell
00EO?004GeaSG6]kJg/3KiX2LiT02gNgMiMg^7^FNkIkU7^eNiIk]G^CNk<00W^B00AkTg^cNi9kTP9k
/WIoo`03001oogoo00=oo`40005oo`00BWoo078007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7E;lEaeC
75LmEaaK?ELLFceK?5mLFcaSG5mLHeaO>f=LKgY_VVmiLiYcV7>IMiMg^7NGNkIgUgNhMiIk]W^DOkAk
TW^cNi=o/g^BNk9gTWnbNi9fOol00`00Oomoo`03Ool10001Ool004]oo`04001ooe<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00AC7E;m
DaeBo@AC7@0;EaeC7E<MDaeK?ELLEceG75/mEaaG?@02He`025mLHeaSG6=LIe]WNfMKIg`2LiT03WNG
MkQgUg>IMiMg^7NGNkIkU7^eNi=kTW^DNk<3Ni800g^bNi9oo`1gOol00`00Oomoo`02Ool10001Ool0
04aoo`80001]Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E<LFceG75/mEaaK?E/LFceOG6=LGc]WO6=KIgaS
FfMlJgY[NfmiLiY_NW>ILiQg^7NGNkIgUG^eNi=k/g^DOkAkTW^bNi5o/g^BNk80NGoo00D007ooOomo
o`00005oo`00CWoo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00YC7DkmDaeBoE<MD_eC7E;mDaeBo@=C7@05D_eG7ELMEaeC7003Ead3Fc`02E/mFcaK?5/l
IgaWFfMkIe]WO002Jg/3KiX2LiT02WNhMiMg]g^fNkEkU7^cNiAk]G^C0W^B00=k/g^BNi80Ngoo00@0
07ooOol0005oo`00Cgoo06/007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aG7E;lDaeBo5LMDaaG7E<LEceG75LMFaaK?E/lFceK?5mMFcaW
O6=KJi][NV]kIgYcVVmjKiYcV7NiMiMg^7NENkIkU7^dMiEk]G^CNkAkTWndNi9k/W^A07]oo`04001o
ogoo0001Ool0051oo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;m
Dad00e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05D_eG7ELMEaeG7003Ead7Gc`4Jg/3KiX2LiT0
37NGMkMk]W^fNiAk]G^fNkEkU7^cNi9k/P=kTWeoo`03001oo`00005oo`00DGoo0P0006I>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG
7E;lEceG75LMDaaK?ELLFceK?5mMFcaOG5lkHeaOG6=LGc]cVVmjKiYcV7NiLiQg^7NGNkIgUWNhMiMk
]W^DNkAkTgncNi=k/g^ANk9nOol10001Ool1000005=oo`06001>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@0=DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mEad00e<M00YG7E<MDaeG75/m
EaaG?ELLFceG70=SG006GeaSG6=LIgaWFfMk0g>I011g]gNGLiUcVGNgMiMk]W^DNkEkTg^cNiAk/g^B
Nk9kTWmoo`800000E7oo06@007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMDaaG7ELLFceG75/mFcaK?E/LHeaOG6=LHe]WO6=KIgaW
NV^KJgY_VVmiMkUcV7>IMiMg^7NFNkEkTgndNiAk]7^BOk9kTX1oo`800000EGoo00H007ooD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MDa`0
0eLM00AC75LMEaeK?@=K?007FceK?6MkIe]WO6MKIg/00f]k0VnJ0g>I00YgUgNhNiIk]G^DNk=kU7^e
Ni=k/`9kTX1oo`800000EWoo068007ooOom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDaeBo5LMD_aC7E<LEaeC75LMDaaG?ELLFceK75/mFcaOG5/lIgaSFfMlIgY[Vf]j
KiY_NFnJLiQcVGNGMkQgUg^fNiAk]WNFNkEkTgncNi9k]7^BO7oo10000Woo001GOol2000017ooD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`0
0eLM00=G75LMEad01ell0f]k0fnJ0W>I00YgUgNhMiMk]W^DMkQkUW^eNiAk/`=kTWUoo`@000Ioo`00
FGoo05h007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG
7E;lEaeC75LmEaaG7ELLFceG75mLFcaOGE/lHeaO>f=LGea_VVmiKiYcV7>ILiQg^7NGMkQgUGNhMiIk
]W^DNkEkTg^cNi=o/gEoo`@000Yoo`00FWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eB
oE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00iG7E<MDaeC7ELMDaeG?ELLFceG75LmEaaK?EmL0f=L00AO
G6MkIe]WO0=[N`0=MkQgUgNgLiUg^7NGNkIkU7^eNi=kTW^DNk<0LWoo10003Woo001KOol0F`00Oom>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E<LFceG
75/mEaaK?E/lFceO>f=LHe]WO6=KIga[NV]kIgY_VVmjKiYcV7NiMiMk]WNENkEkU7^dNiAo]7^B06io
o`@0019oo`00G7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M
00EBoE<MEaeG7E<L00=G7@04DaaK?5/lFcd3Fc`01E/mIe]WNfMKIg`00f]k00=_VVmjKiX00W>I00Yg
UgNgNkIk]G^DNk=k]W^eNi=kTV]oo`<001Ioo`00GWoo05L007ooDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MC_aG7E;lDaeBo5LMDaaG7E<LEaeG75LMDaaK?E/lFceK75mMFcaOG5/lGee[NV]kIgY_
VVmjKiYcV7NiMiMg^7NENkIkU7^eMiIk]G^CNk<0J7oo10006Goo001OOol01000OomC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@03EaaG7Ell00EO?006
GeaSG6=LKiY_NVnJ0g>I00Yg]gNGNkIgUgNgMiMk]W^DNk=kTVAoo`@001eoo`00H7oo05D007ooDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG7E<LEceG75/mEaaK?E/lGeaK
?6=LGeaSG5lkIgaSFfMlLiQg^G>HMkQgUgNiMiMg^7NGNkIkU7^dNi9k]@1POol4000QOol0065oo`80
0006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00]G7E<MDaeC7E/mEaaG?ELL
FceG75Lm009SG006GeaSG6=LIgaWFfMk0f]k0VnJ0W>I00Mg]gNGMkQkUW^eNi=k]@1MOol4000UOol0
06=oo`1A001C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75/mEaaK?ELL
FceK75/mGeaSG5lkIgaSFfMlIgY[Vf]jKiY_NFnJLiQg^7NGMkQgUW^eNi=k]W^D05Yoo`<002Uoo`00
I7oo00<005<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;mDaeBo@=C7@05D_eG7ELMEaeC7003Ead3Fc`0
1e/mFcaK?5/lIgaWFfMk00A[N`9_VP9cV@07MiMg^7NGNkIkU7^fNi@0Egoo1000;7oo001UOol0CP00
Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG7E<LEaeC75LmEaaG7E/LFceK?5/mFcaOGE/l
GeaWNV^KJgY[NfmiKiYcV7>IMiMg^7NGNkIkU7NhMiIk]E=oo`@0031oo`00IWoo0P0000E>oE;mD_eC
7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:
DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMEa`00eLM1Ull0V=L00EOG6=LKiY_VVmj009c
V@08MkQgUgNgNkIg^7^FNkEkU4moo`@003Aoo`00J7oo04X007ooDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG
7E;lEaeBo5LMEaaG7E<LFceG75/mFcaOGE/lHeaO>f=LGeaSG6=KIgaSFg>ILiQg^7NGMkQcV7NhMiMk
]W^DC7oo1000>7oo001YOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mD_eBoE<MD_d6Dad02ULMDaeC7ELLFceG75LmEaaK
?ELL0f=L00EOG6MkIe]WO6MK009[N`03KiY_NVnJ009cV@04MiMk]W^DNkE8Ool4000lOol006Yoo`17
001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMDaaG7ELLFceG75/mFcaK?E/LFceSFfMlHe]WO6=K
Jg]WNVnJKgY_VW>HMkUgUgNhMiIk]@16Ool30010Ool006]oo`80009Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE<MD_eC7E;mDaeBoE<MD_d3Dad0
1E;mEaeG7ELMDa`00ULM00AK?E/lFcaK?0=O?003Ie]WO6MK00=[N`09KgY_VW>ILiUgUgNgNkIk]G^D
049oo`@004=oo`00KGoo04<007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEceG75LMDaaG?ELLEaeK?5mMFcaO
G5/lGeeK?6]kIgY[VfmjKiYcV7NiLiQg^7NGNkIgU`0oOol40017Ool006ioo`05001ooe;mDae>o@02
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<M
D_eC7E;m0U<M00=G7E<MEad00ULM00AG75LmEaaK?@AO?006GeaSG6=LHea_NVnJ0g>I00Eg]gNGLiUg
UgNg03]oo`@004]oo`00Kgoo040007ooOomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E;lEaeG75/mEaaK?ELLFceO>f=L
GeaSG5lkHeaSFfMlIgY[Vf]jKiY_NGNiLiQg^3Qoo`@004moo`00L7oo0P0000=ooe<MC_d00U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@02D_d2Dad015;mDaeC7ELM
0e<M00IG7E<LEaeG75/mEa`2Fc`01E/mGeaSG6=LIg`00VMK0f]k0VnJ0W>I00=g]gNGOol0=7oo0`00
Dgoo001bOol0?000C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeK?5/mFaaK?E/lFceK76MlHe]WO6MjJi][NVnJ
KgU_VW>HLiUgUc9oo`@005Ioo`00Lgoo00@005;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7Dkm
D_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7E<L00=G7@04EaaG7E/lFcd2Fc`4Gc`3
Jg/3KiX2LiT00gNGMkQoo`0]Ool4001JOol007Aoo`0i001>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E<LEceG75LMDaaG?ELLGeaK
?5mMFcaSG5lkHeaOG6nJKgU_VW>HLiUcV7Nh02]oo`@005ioo`00MGoo0P0000IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@0=DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mEad00e<M00=G7ELLEad0
0ULM00EG75LmEaaK?EmL00=SG004GeaWFfMKIg`3Jg/00fnJOomoo`0VOol4001ROol007Moo`0e001C
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG
7E;lEaeG75/mEaaK?ELLFceK?5/mGc]SG6=KIgaSFfMlJgY[NfMjKiY_NP0TOol4001VOol007Qoo`03
001C7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7DkmD_eBoE<MC_eC7E;mDaeBo@=C7@05D_eC7E<M
EaeC7003Ead015<LEaeK?5/m0e/l00EK?FMKIe]WFfMl00=[N`03KiY_NWoo025oo`<006Yoo`00NGoo
034005<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;l
EaeC75LMDaaG7E<LEceK?5/mFaaOGE/lGeaK?5mMJgY[NfMjKiY_NP0OOol4001]Ool007Yoo`03001o
odkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG
7003Ead00eLLEaeO?005Gc`01UmLHeaSG6nJKgY_VQ]oo`@0075oo`00Ngoo0P0002a>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E<LEceG75/mEaaK?E/l
GeaK?6=LGeaSG5lkIgaSFfMl67oo1000MGoo001mOol01P00C_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC
7@03D_d01U<MD_eC7E;mDaeBo@9C7@0AEaeC7E<MDaeG7ELLEceG75/mEaaG?ELLHeaOG6=LIe]WO002
Ie/EOol4001iOol007ioo`0X001>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
D_aC7E;lEaeC75LMDaaG7ELLFceG75/mFaaK?E/lFceSFfMlHe/COol4001mOol007moo`06001ooe;m
D_eC7Dkm0U;m00YC7DkmD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7003Ead3Fc`00e/mFcaO
?003Gc`AOol30021Ool0081oo`80000RDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
DaeBo5LMD_aG7E<LEceG75LMDaaG?E/lGeaK?5mMFc`>Ool40024Ool0089oo`05001BoE;mDae>o@02
D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0U<M00IG7E<MDaeC7ELMEa`2Ead00e/mEaaG?@02Gc`<Ool4
0028Ool008=oo`0N001C7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LM
EaaK?ELLFceG75/m2Goo1000S7oo0024Ool01@00OomBoE<MC_d00U;m00IC7E;mD_eBoE<MD_d3Dad0
1E;mDaeC7ELMDa`00eLM00=G75LmEa`01goo1000T7oo0025Ool200005TklDae>o5<MC_aC7DklDae>
o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75LM1Woo0`00U7oo0027Ool00`00D_eC7@03D_d01U<MD_eC
7E;mDaeBo@=C7@03D_eC7E<M00Ioo`@009Moo`00R7oo00d004klDae>o5<MC_aC7DklDaeBo5<MC_aC
7@06Ool4002KOol008Uoo`03001ooe<M00=Bo@04DaeBoE<MD_d4Ool4002OOol008Yoo`800005Dae>
o5<MC_aC7@02Ool4002SOol008aoo`800003Ool0000000800:Moo`00SGoo0P00Zgoo003oOolkOol0
0?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.649 .764 .933 r
.38973 .79891 .39806 .80563 .41197 .80185 .40368 .79513 Mtetra
.651 .766 .933 r
.40368 .79513 .41197 .80185 .42594 .79792 .4177 .79124 Mtetra
.656 .769 .932 r
.4177 .79124 .42594 .79792 .44 .79375 .4318 .78716 Mtetra
.665 .775 .931 r
.4318 .78716 .44 .79375 .45413 .78912 .44597 .78275 Mtetra
.681 .785 .929 r
.44597 .78275 .45413 .78912 .46834 .78368 .46023 .77772 Mtetra
.709 .803 .923 r
.46023 .77772 .46834 .78368 .48263 .77672 .47457 .77158 Mtetra
.755 .831 .91 r
.47457 .77158 .48263 .77672 .49699 .76712 .48898 .76342 Mtetra
.821 .869 .882 r
.48898 .76342 .49699 .76712 .51139 .7531 .50345 .75179 Mtetra
.895 .906 .826 r
.50345 .75179 .51139 .7531 .52578 .73252 .51795 .73466 Mtetra
.951 .926 .743 r
.51795 .73466 .52578 .73252 .54009 .70396 .5324 .71001 Mtetra
.975 .925 .654 r
.5324 .71001 .54009 .70396 .55421 .66884 .54671 .6776 Mtetra
.973 .918 .595 r
.54671 .6776 .55421 .66884 .56813 .63227 .56082 .6408 Mtetra
.966 .923 .593 r
.56082 .6408 .56813 .63227 .58193 .60029 .57475 .60574 Mtetra
.961 .944 .661 r
.57475 .60574 .58193 .60029 .59573 .576 .58862 .57734 Mtetra
.934 .95 .77 r
.58862 .57734 .59573 .576 .60962 .559 .60254 .55679 Mtetra
.87 .914 .857 r
.60254 .55679 .60962 .559 .62363 .54726 .61657 .54262 Mtetra
.795 .857 .896 r
.61657 .54262 .62363 .54726 .63776 .53881 .63073 .53267 Mtetra
.74 .81 .907 r
.63073 .53267 .63776 .53881 .65199 .53225 .645 .52525 Mtetra
.705 .779 .909 r
.645 .52525 .65199 .53225 .66633 .52673 .65937 .51923 Mtetra
.686 .762 .909 r
.65937 .51923 .66633 .52673 .68075 .52175 .67384 .51396 Mtetra
.675 .752 .909 r
.67384 .51396 .68075 .52175 .69526 .51705 .68839 .5091 Mtetra
.67 .747 .908 r
.68839 .5091 .69526 .51705 .70985 .5125 .70303 .50443 Mtetra
.667 .744 .908 r
.70303 .50443 .70985 .5125 .72452 .508 .71775 .49985 Mtetra
.665 .743 .908 r
.71775 .49985 .72452 .508 .73927 .50353 .73255 .49532 Mtetra
.664 .742 .908 r
.73255 .49532 .73927 .50353 .75409 .49905 .74743 .49079 Mtetra
.74743 .49079 .75409 .49905 .76899 .49457 .76239 .48626 Mtetra
.76239 .48626 .76899 .49457 .78397 .49007 .77742 .48171 Mtetra
.664 .741 .908 r
.77742 .48171 .78397 .49007 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47256 Mtetra
.80773 .47256 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84469 .47185 .83836 .46331 Mtetra
.83836 .46331 .84469 .47185 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.648 .764 .933 r
.38132 .79212 .38973 .79891 .40368 .79513 .39531 .78833 Mtetra
.65 .765 .933 r
.39531 .78833 .40368 .79513 .4177 .79124 .40938 .78445 Mtetra
.653 .767 .933 r
.40938 .78445 .4177 .79124 .4318 .78716 .42352 .78043 Mtetra
.66 .771 .932 r
.42352 .78043 .4318 .78716 .44597 .78275 .43774 .77616 Mtetra
.672 .779 .93 r
.43774 .77616 .44597 .78275 .46023 .77772 .45204 .77144 Mtetra
.693 .793 .926 r
.45204 .77144 .46023 .77772 .47457 .77158 .46643 .76589 Mtetra
.73 .816 .918 r
.46643 .76589 .47457 .77158 .48898 .76342 .48089 .75882 Mtetra
.786 .849 .899 r
.48089 .75882 .48898 .76342 .50345 .75179 .49542 .74908 Mtetra
.858 .889 .858 r
.49542 .74908 .50345 .75179 .51795 .73466 .51001 .73489 Mtetra
.927 .919 .787 r
.51001 .73489 .51795 .73466 .5324 .71001 .52458 .71409 Mtetra
.967 .927 .697 r
.52458 .71409 .5324 .71001 .54671 .6776 .53907 .68526 Mtetra
.976 .921 .619 r
.53907 .68526 .54671 .6776 .56082 .6408 .55337 .64983 Mtetra
.969 .918 .585 r
.55337 .64983 .56082 .6408 .57475 .60574 .56746 .61294 Mtetra
.964 .933 .619 r
.56746 .61294 .57475 .60574 .58862 .57734 .58144 .58068 Mtetra
.952 .951 .715 r
.58144 .58068 .58862 .57734 .60254 .55679 .59541 .55616 Mtetra
.906 .937 .82 r
.59541 .55616 .60254 .55679 .61657 .54262 .60947 .53898 Mtetra
.831 .885 .881 r
.60947 .53898 .61657 .54262 .63073 .53267 .62364 .52709 Mtetra
.765 .831 .903 r
.62364 .52709 .63073 .53267 .645 .52525 .63794 .51852 Mtetra
.72 .792 .909 r
.63794 .51852 .645 .52525 .65937 .51923 .65235 .51184 Mtetra
.694 .769 .909 r
.65235 .51184 .65937 .51923 .67384 .51396 .66686 .5062 Mtetra
.68 .756 .909 r
.66686 .5062 .67384 .51396 .68839 .5091 .68146 .50112 Mtetra
.672 .749 .909 r
.68146 .50112 .68839 .5091 .70303 .50443 .69615 .49631 Mtetra
.668 .746 .908 r
.69615 .49631 .70303 .50443 .71775 .49985 .71092 .49164 Mtetra
.666 .744 .908 r
.71092 .49164 .71775 .49985 .73255 .49532 .72577 .48704 Mtetra
.665 .742 .908 r
.72577 .48704 .73255 .49532 .74743 .49079 .7407 .48245 Mtetra
.664 .742 .908 r
.7407 .48245 .74743 .49079 .76239 .48626 .75571 .47787 Mtetra
.75571 .47787 .76239 .48626 .77742 .48171 .7708 .47327 Mtetra
.664 .741 .908 r
.7708 .47327 .77742 .48171 .79253 .47714 .78597 .46866 Mtetra
.78597 .46866 .79253 .47714 .80773 .47256 .80122 .46403 Mtetra
.80122 .46403 .80773 .47256 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.647 .763 .934 r
.37283 .78525 .38132 .79212 .39531 .78833 .38687 .78144 Mtetra
.649 .764 .933 r
.38687 .78144 .39531 .78833 .40938 .78445 .40098 .77757 Mtetra
.651 .766 .933 r
.40098 .77757 .40938 .78445 .42352 .78043 .41517 .77358 Mtetra
.656 .769 .932 r
.41517 .77358 .42352 .78043 .43774 .77616 .42943 .76941 Mtetra
.665 .775 .931 r
.42943 .76941 .43774 .77616 .45204 .77144 .44378 .7649 Mtetra
.681 .785 .929 r
.44378 .7649 .45204 .77144 .46643 .76589 .45821 .75977 Mtetra
.709 .803 .923 r
.45821 .75977 .46643 .76589 .48089 .75882 .47272 .75351 Mtetra
.755 .831 .91 r
.47272 .75351 .48089 .75882 .49542 .74908 .48731 .74522 Mtetra
.821 .869 .882 r
.48731 .74522 .49542 .74908 .51001 .73489 .50196 .73344 Mtetra
.895 .906 .826 r
.50196 .73344 .51001 .73489 .52458 .71409 .51664 .71611 Mtetra
.951 .926 .742 r
.51664 .71611 .52458 .71409 .53907 .68526 .53128 .69122 Mtetra
.975 .925 .654 r
.53128 .69122 .53907 .68526 .55337 .64983 .54577 .65852 Mtetra
.973 .918 .594 r
.54577 .65852 .55337 .64983 .56746 .61294 .56006 .62139 Mtetra
.966 .923 .593 r
.56006 .62139 .56746 .61294 .58144 .58068 .57416 .58602 Mtetra
.961 .944 .661 r
.57416 .58602 .58144 .58068 .59541 .55616 .58821 .55737 Mtetra
.934 .95 .771 r
.58821 .55737 .59541 .55616 .60947 .53898 .6023 .53662 Mtetra
.87 .914 .857 r
.6023 .53662 .60947 .53898 .62364 .52709 .6165 .52228 Mtetra
.795 .857 .896 r
.6165 .52228 .62364 .52709 .63794 .51852 .63083 .51219 Mtetra
.74 .809 .907 r
.63083 .51219 .63794 .51852 .65235 .51184 .64527 .50464 Mtetra
.705 .779 .909 r
.64527 .50464 .65235 .51184 .66686 .5062 .65982 .49851 Mtetra
.686 .762 .909 r
.65982 .49851 .66686 .5062 .68146 .50112 .67447 .49313 Mtetra
.675 .752 .909 r
.67447 .49313 .68146 .50112 .69615 .49631 .6892 .48815 Mtetra
.67 .747 .908 r
.6892 .48815 .69615 .49631 .71092 .49164 .70402 .48337 Mtetra
.667 .744 .908 r
.70402 .48337 .71092 .49164 .72577 .48704 .71893 .47869 Mtetra
.665 .743 .908 r
.71893 .47869 .72577 .48704 .7407 .48245 .73391 .47404 Mtetra
.664 .742 .908 r
.73391 .47404 .7407 .48245 .75571 .47787 .74898 .4694 Mtetra
.74898 .4694 .75571 .47787 .7708 .47327 .76412 .46476 Mtetra
.76412 .46476 .7708 .47327 .78597 .46866 .77935 .4601 Mtetra
.664 .741 .908 r
.77935 .4601 .78597 .46866 .80122 .46403 .79466 .45542 Mtetra
.79466 .45542 .80122 .46403 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.647 .763 .934 r
.36425 .77831 .37283 .78525 .38687 .78144 .37834 .77448 Mtetra
.648 .764 .933 r
.37834 .77448 .38687 .78144 .40098 .77757 .39249 .77059 Mtetra
.65 .765 .933 r
.39249 .77059 .40098 .77757 .41517 .77358 .40673 .76662 Mtetra
.653 .767 .933 r
.40673 .76662 .41517 .77358 .42943 .76941 .42104 .76251 Mtetra
.66 .771 .932 r
.42104 .76251 .42943 .76941 .44378 .7649 .43543 .75814 Mtetra
.672 .779 .93 r
.43543 .75814 .44378 .7649 .45821 .75977 .44991 .75332 Mtetra
.693 .793 .926 r
.44991 .75332 .45821 .75977 .47272 .75351 .46446 .74765 Mtetra
.73 .816 .918 r
.46446 .74765 .47272 .75351 .48731 .74522 .47911 .74046 Mtetra
.786 .849 .899 r
.47911 .74046 .48731 .74522 .50196 .73344 .49382 .73058 Mtetra
.858 .889 .858 r
.49382 .73058 .50196 .73344 .51664 .71611 .50859 .71622 Mtetra
.927 .919 .787 r
.50859 .71622 .51664 .71611 .53128 .69122 .52335 .69519 Mtetra
.967 .927 .696 r
.52335 .69519 .53128 .69122 .54577 .65852 .53802 .66609 Mtetra
.976 .921 .618 r
.53802 .66609 .54577 .65852 .56006 .62139 .55251 .63034 Mtetra
.969 .918 .585 r
.55251 .63034 .56006 .62139 .57416 .58602 .56678 .59313 Mtetra
.964 .933 .619 r
.56678 .59313 .57416 .58602 .58821 .55737 .58093 .56058 Mtetra
.952 .951 .715 r
.58093 .56058 .58821 .55737 .6023 .53662 .59508 .53584 Mtetra
.906 .937 .82 r
.59508 .53584 .6023 .53662 .6165 .52228 .60931 .51847 Mtetra
.831 .885 .881 r
.60931 .51847 .6165 .52228 .63083 .51219 .62366 .50643 Mtetra
.765 .831 .903 r
.62366 .50643 .63083 .51219 .64527 .50464 .63813 .49773 Mtetra
.72 .792 .909 r
.63813 .49773 .64527 .50464 .65982 .49851 .65272 .49093 Mtetra
.694 .769 .909 r
.65272 .49093 .65982 .49851 .67447 .49313 .66741 .48517 Mtetra
.68 .756 .909 r
.66741 .48517 .67447 .49313 .6892 .48815 .68219 .47997 Mtetra
.672 .749 .909 r
.68219 .47997 .6892 .48815 .70402 .48337 .69706 .47505 Mtetra
.668 .746 .908 r
.69706 .47505 .70402 .48337 .71893 .47869 .71201 .47027 Mtetra
.666 .744 .908 r
.71201 .47027 .71893 .47869 .73391 .47404 .72705 .46556 Mtetra
.665 .742 .908 r
.72705 .46556 .73391 .47404 .74898 .4694 .74217 .46086 Mtetra
.664 .742 .908 r
.74217 .46086 .74898 .4694 .76412 .46476 .75737 .45616 Mtetra
.75737 .45616 .76412 .46476 .77935 .4601 .77266 .45145 Mtetra
.664 .741 .908 r
.77266 .45145 .77935 .4601 .79466 .45542 .78802 .44672 Mtetra
.78802 .44672 .79466 .45542 .81005 .45071 .80347 .44197 Mtetra
.80347 .44197 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.647 .763 .934 r
.3556 .7713 .36425 .77831 .37834 .77448 .36972 .76744 Mtetra
.36972 .76744 .37834 .77448 .39249 .77059 .38393 .76353 Mtetra
.649 .764 .933 r
.38393 .76353 .39249 .77059 .40673 .76662 .39821 .75956 Mtetra
.651 .766 .933 r
.39821 .75956 .40673 .76662 .42104 .76251 .41257 .75548 Mtetra
.656 .769 .932 r
.41257 .75548 .42104 .76251 .43543 .75814 .427 .75121 Mtetra
.665 .775 .931 r
.427 .75121 .43543 .75814 .44991 .75332 .44153 .7466 Mtetra
.681 .785 .929 r
.44153 .7466 .44991 .75332 .46446 .74765 .45613 .74136 Mtetra
.709 .803 .923 r
.45613 .74136 .46446 .74765 .47911 .74046 .47082 .73498 Mtetra
.755 .831 .91 r
.47082 .73498 .47911 .74046 .49382 .73058 .48559 .72657 Mtetra
.821 .869 .882 r
.48559 .72657 .49382 .73058 .50859 .71622 .50043 .71462 Mtetra
.895 .906 .826 r
.50043 .71462 .50859 .71622 .52335 .69519 .5153 .6971 Mtetra
.951 .926 .742 r
.5153 .6971 .52335 .69519 .53802 .66609 .53013 .67196 Mtetra
.975 .925 .654 r
.53013 .67196 .53802 .66609 .55251 .63034 .54481 .63895 Mtetra
.973 .918 .594 r
.54481 .63895 .55251 .63034 .56678 .59313 .55928 .60149 Mtetra
.966 .923 .593 r
.55928 .60149 .56678 .59313 .58093 .56058 .57356 .56582 Mtetra
.961 .944 .662 r
.57356 .56582 .58093 .56058 .59508 .53584 .58778 .5369 Mtetra
.934 .95 .771 r
.58778 .5369 .59508 .53584 .60931 .51847 .60205 .51595 Mtetra
.87 .913 .857 r
.60205 .51595 .60931 .51847 .62366 .50643 .61643 .50144 Mtetra
.795 .856 .896 r
.61643 .50144 .62366 .50643 .63813 .49773 .63093 .49121 Mtetra
.74 .809 .907 r
.63093 .49121 .63813 .49773 .65272 .49093 .64555 .48353 Mtetra
.705 .779 .909 r
.64555 .48353 .65272 .49093 .66741 .48517 .66028 .47728 Mtetra
.686 .762 .909 r
.66028 .47728 .66741 .48517 .68219 .47997 .67511 .47178 Mtetra
.675 .752 .909 r
.67511 .47178 .68219 .47997 .69706 .47505 .69003 .46669 Mtetra
.67 .747 .908 r
.69003 .46669 .69706 .47505 .71201 .47027 .70504 .4618 Mtetra
.667 .744 .908 r
.70504 .4618 .71201 .47027 .72705 .46556 .72013 .457 Mtetra
.665 .743 .908 r
.72013 .457 .72705 .46556 .74217 .46086 .7353 .45223 Mtetra
.664 .742 .908 r
.7353 .45223 .74217 .46086 .75737 .45616 .75056 .44748 Mtetra
.75056 .44748 .75737 .45616 .77266 .45145 .7659 .44272 Mtetra
.7659 .44272 .77266 .45145 .78802 .44672 .78133 .43794 Mtetra
.664 .741 .908 r
.78133 .43794 .78802 .44672 .80347 .44197 .79683 .43314 Mtetra
.79683 .43314 .80347 .44197 .819 .43719 .81242 .42831 Mtetra
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42347 Mtetra
.8281 .42347 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.646 .763 .934 r
.34685 .76422 .3556 .7713 .36972 .76744 .36103 .76033 Mtetra
.647 .763 .934 r
.36103 .76033 .36972 .76744 .38393 .76353 .37528 .7564 Mtetra
.648 .764 .933 r
.37528 .7564 .38393 .76353 .39821 .75956 .3896 .75241 Mtetra
.65 .765 .933 r
.3896 .75241 .39821 .75956 .41257 .75548 .40401 .74834 Mtetra
.653 .767 .933 r
.40401 .74834 .41257 .75548 .427 .75121 .41849 .74413 Mtetra
.66 .771 .932 r
.41849 .74413 .427 .75121 .44153 .7466 .43306 .73966 Mtetra
.672 .779 .93 r
.43306 .73966 .44153 .7466 .45613 .74136 .44771 .73473 Mtetra
.693 .793 .926 r
.44771 .73473 .45613 .74136 .47082 .73498 .46245 .72895 Mtetra
.73 .816 .918 r
.46245 .72895 .47082 .73498 .48559 .72657 .47728 .72164 Mtetra
.786 .85 .899 r
.47728 .72164 .48559 .72657 .50043 .71462 .49218 .71161 Mtetra
.858 .889 .858 r
.49218 .71161 .50043 .71462 .5153 .6971 .50714 .69707 Mtetra
.927 .919 .787 r
.50714 .69707 .5153 .6971 .53013 .67196 .52209 .67582 Mtetra
.967 .927 .696 r
.52209 .67582 .53013 .67196 .54481 .63895 .53695 .64643 Mtetra
.976 .921 .618 r
.53695 .64643 .54481 .63895 .55928 .60149 .55163 .61036 Mtetra
.969 .918 .585 r
.55163 .61036 .55928 .60149 .57356 .56582 .56609 .57283 Mtetra
.964 .933 .619 r
.56609 .57283 .57356 .56582 .58778 .5369 .58041 .53999 Mtetra
.952 .951 .715 r
.58041 .53999 .58778 .5369 .60205 .51595 .59474 .51501 Mtetra
.906 .936 .82 r
.59474 .51501 .60205 .51595 .61643 .50144 .60914 .49746 Mtetra
.831 .885 .881 r
.60914 .49746 .61643 .50144 .63093 .49121 .62367 .48526 Mtetra
.765 .831 .903 r
.62367 .48526 .63093 .49121 .64555 .48353 .63832 .47642 Mtetra
.72 .792 .909 r
.63832 .47642 .64555 .48353 .66028 .47728 .65309 .46949 Mtetra
.694 .769 .909 r
.65309 .46949 .66028 .47728 .67511 .47178 .66796 .46362 Mtetra
.68 .756 .909 r
.66796 .46362 .67511 .47178 .69003 .46669 .68293 .4583 Mtetra
.672 .749 .909 r
.68293 .4583 .69003 .46669 .70504 .4618 .69799 .45327 Mtetra
.668 .746 .908 r
.69799 .45327 .70504 .4618 .72013 .457 .71314 .44837 Mtetra
.666 .744 .908 r
.71314 .44837 .72013 .457 .7353 .45223 .72837 .44353 Mtetra
.665 .742 .908 r
.72837 .44353 .7353 .45223 .75056 .44748 .74368 .43872 Mtetra
.664 .742 .908 r
.74368 .43872 .75056 .44748 .7659 .44272 .75908 .4339 Mtetra
.75908 .4339 .7659 .44272 .78133 .43794 .77456 .42907 Mtetra
.664 .741 .908 r
.77456 .42907 .78133 .43794 .79683 .43314 .79013 .42422 Mtetra
.79013 .42422 .79683 .43314 .81242 .42831 .80578 .41935 Mtetra
.80578 .41935 .81242 .42831 .8281 .42347 .82151 .41445 Mtetra
.82151 .41445 .8281 .42347 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.646 .763 .934 r
.33802 .75706 .34685 .76422 .36103 .76033 .35224 .75314 Mtetra
.647 .763 .934 r
.35224 .75314 .36103 .76033 .37528 .7564 .36654 .74918 Mtetra
.36654 .74918 .37528 .7564 .3896 .75241 .38091 .74518 Mtetra
.649 .764 .933 r
.38091 .74518 .3896 .75241 .40401 .74834 .39537 .7411 Mtetra
.651 .766 .933 r
.39537 .7411 .40401 .74834 .41849 .74413 .4099 .73692 Mtetra
.656 .769 .932 r
.4099 .73692 .41849 .74413 .43306 .73966 .42452 .73255 Mtetra
.665 .775 .931 r
.42452 .73255 .43306 .73966 .44771 .73473 .43922 .72783 Mtetra
.681 .785 .929 r
.43922 .72783 .44771 .73473 .46245 .72895 .454 .72248 Mtetra
.709 .803 .923 r
.454 .72248 .46245 .72895 .47728 .72164 .46888 .71598 Mtetra
.755 .831 .91 r
.46888 .71598 .47728 .72164 .49218 .71161 .48384 .70743 Mtetra
.821 .87 .882 r
.48384 .70743 .49218 .71161 .50714 .69707 .49886 .69533 Mtetra
.895 .907 .826 r
.49886 .69533 .50714 .69707 .52209 .67582 .51393 .6776 Mtetra
.951 .926 .742 r
.51393 .6776 .52209 .67582 .53695 .64643 .52894 .6522 Mtetra
.975 .925 .653 r
.52894 .6522 .53695 .64643 .55163 .61036 .54382 .61888 Mtetra
.973 .918 .594 r
.54382 .61888 .55163 .61036 .56609 .57283 .55848 .5811 Mtetra
.966 .923 .593 r
.55848 .5811 .56609 .57283 .58041 .53999 .57295 .54511 Mtetra
.961 .944 .662 r
.57295 .54511 .58041 .53999 .59474 .51501 .58735 .51593 Mtetra
.934 .95 .771 r
.58735 .51593 .59474 .51501 .60914 .49746 .6018 .49476 Mtetra
.87 .913 .857 r
.6018 .49476 .60914 .49746 .62367 .48526 .61635 .48008 Mtetra
.795 .856 .895 r
.61635 .48008 .62367 .48526 .63832 .47642 .63103 .46971 Mtetra
.74 .809 .907 r
.63103 .46971 .63832 .47642 .65309 .46949 .64584 .4619 Mtetra
.705 .779 .909 r
.64584 .4619 .65309 .46949 .66796 .46362 .66075 .45552 Mtetra
.686 .762 .909 r
.66075 .45552 .66796 .46362 .68293 .4583 .67577 .4499 Mtetra
.675 .752 .909 r
.67577 .4499 .68293 .4583 .69799 .45327 .69088 .44469 Mtetra
.67 .747 .908 r
.69088 .44469 .69799 .45327 .71314 .44837 .70608 .43968 Mtetra
.667 .744 .908 r
.70608 .43968 .71314 .44837 .72837 .44353 .72136 .43476 Mtetra
.665 .743 .908 r
.72136 .43476 .72837 .44353 .74368 .43872 .73673 .42987 Mtetra
.664 .742 .908 r
.73673 .42987 .74368 .43872 .75908 .4339 .75219 .425 Mtetra
.75219 .425 .75908 .4339 .77456 .42907 .76773 .42012 Mtetra
.76773 .42012 .77456 .42907 .79013 .42422 .78335 .41521 Mtetra
.664 .741 .908 r
.78335 .41521 .79013 .42422 .80578 .41935 .79906 .41029 Mtetra
.79906 .41029 .80578 .41935 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.646 .763 .934 r
.32911 .74983 .33802 .75706 .35224 .75314 .34337 .74587 Mtetra
.34337 .74587 .35224 .75314 .36654 .74918 .35772 .74188 Mtetra
.647 .763 .934 r
.35772 .74188 .36654 .74918 .38091 .74518 .37214 .73785 Mtetra
.648 .764 .933 r
.37214 .73785 .38091 .74518 .39537 .7411 .38664 .73377 Mtetra
.65 .765 .933 r
.38664 .73377 .39537 .7411 .4099 .73692 .40122 .7296 Mtetra
.653 .767 .933 r
.40122 .7296 .4099 .73692 .42452 .73255 .41588 .72528 Mtetra
.66 .771 .932 r
.41588 .72528 .42452 .73255 .43922 .72783 .43063 .72071 Mtetra
.672 .779 .93 r
.43063 .72071 .43922 .72783 .454 .72248 .44547 .71566 Mtetra
.693 .793 .926 r
.44547 .71566 .454 .72248 .46888 .71598 .46039 .70977 Mtetra
.73 .816 .918 r
.46039 .70977 .46888 .71598 .48384 .70743 .4754 .70232 Mtetra
.786 .85 .899 r
.4754 .70232 .48384 .70743 .49886 .69533 .4905 .69215 Mtetra
.858 .889 .858 r
.4905 .69215 .49886 .69533 .51393 .6776 .50564 .67742 Mtetra
.927 .92 .787 r
.50564 .67742 .51393 .6776 .52894 .6522 .5208 .65594 Mtetra
.967 .928 .696 r
.5208 .65594 .52894 .6522 .54382 .61888 .53585 .62627 Mtetra
.976 .921 .618 r
.53585 .62627 .54382 .61888 .55848 .5811 .55072 .58987 Mtetra
.969 .918 .585 r
.55072 .58987 .55848 .5811 .57295 .54511 .56537 .55201 Mtetra
.964 .933 .62 r
.56537 .55201 .57295 .54511 .58735 .51593 .57988 .51888 Mtetra
.952 .951 .715 r
.57988 .51888 .58735 .51593 .6018 .49476 .59439 .49366 Mtetra
.906 .936 .82 r
.59439 .49366 .6018 .49476 .61635 .48008 .60897 .47591 Mtetra
.831 .885 .881 r
.60897 .47591 .61635 .48008 .63103 .46971 .62368 .46356 Mtetra
.765 .831 .903 r
.62368 .46356 .63103 .46971 .64584 .4619 .63852 .45458 Mtetra
.72 .792 .909 r
.63852 .45458 .64584 .4619 .66075 .45552 .65347 .44752 Mtetra
.694 .769 .909 r
.65347 .44752 .66075 .45552 .67577 .4499 .66854 .44152 Mtetra
.68 .756 .909 r
.66854 .44152 .67577 .4499 .69088 .44469 .68369 .43608 Mtetra
.672 .749 .909 r
.68369 .43608 .69088 .44469 .70608 .43968 .69895 .43093 Mtetra
.668 .746 .908 r
.69895 .43093 .70608 .43968 .72136 .43476 .71429 .42591 Mtetra
.666 .744 .908 r
.71429 .42591 .72136 .43476 .73673 .42987 .72971 .42095 Mtetra
.665 .742 .908 r
.72971 .42095 .73673 .42987 .75219 .425 .74523 .41601 Mtetra
.664 .742 .908 r
.74523 .41601 .75219 .425 .76773 .42012 .76082 .41107 Mtetra
.76082 .41107 .76773 .42012 .78335 .41521 .77651 .40612 Mtetra
.664 .741 .908 r
.77651 .40612 .78335 .41521 .79906 .41029 .79228 .40114 Mtetra
.79228 .40114 .79906 .41029 .81486 .40534 .80814 .39614 Mtetra
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38607 Mtetra
.84012 .38607 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .763 .934 r
.3201 .74253 .32911 .74983 .34337 .74587 .33441 .73853 Mtetra
.33441 .73853 .34337 .74587 .35772 .74188 .3488 .73451 Mtetra
.647 .763 .934 r
.3488 .73451 .35772 .74188 .37214 .73785 .36327 .73045 Mtetra
.36327 .73045 .37214 .73785 .38664 .73377 .37782 .72635 Mtetra
.649 .764 .933 r
.37782 .72635 .38664 .73377 .40122 .7296 .39245 .72217 Mtetra
.651 .766 .933 r
.39245 .72217 .40122 .7296 .41588 .72528 .40717 .71788 Mtetra
.656 .769 .932 r
.40717 .71788 .41588 .72528 .43063 .72071 .42196 .7134 Mtetra
.665 .775 .931 r
.42196 .7134 .43063 .72071 .44547 .71566 .43685 .70857 Mtetra
.681 .785 .929 r
.43685 .70857 .44547 .71566 .46039 .70977 .45182 .70311 Mtetra
.709 .803 .923 r
.45182 .70311 .46039 .70977 .4754 .70232 .46688 .69649 Mtetra
.755 .831 .911 r
.46688 .69649 .4754 .70232 .4905 .69215 .48203 .68779 Mtetra
.821 .87 .882 r
.48203 .68779 .4905 .69215 .50564 .67742 .49726 .67552 Mtetra
.895 .907 .826 r
.49726 .67552 .50564 .67742 .5208 .65594 .51251 .65759 Mtetra
.951 .927 .742 r
.51251 .65759 .5208 .65594 .53585 .62627 .52773 .63193 Mtetra
.975 .925 .653 r
.52773 .63193 .53585 .62627 .55072 .58987 .5428 .5983 Mtetra
.973 .918 .594 r
.5428 .5983 .55072 .58987 .56537 .55201 .55766 .56018 Mtetra
.966 .923 .593 r
.55766 .56018 .56537 .55201 .57988 .51888 .57232 .52387 Mtetra
.961 .944 .662 r
.57232 .52387 .57988 .51888 .59439 .49366 .58691 .49443 Mtetra
.934 .949 .771 r
.58691 .49443 .59439 .49366 .60897 .47591 .60153 .47304 Mtetra
.87 .913 .857 r
.60153 .47304 .60897 .47591 .62368 .46356 .61627 .45819 Mtetra
.795 .856 .895 r
.61627 .45819 .62368 .46356 .63852 .45458 .63114 .44766 Mtetra
.74 .809 .907 r
.63114 .44766 .63852 .45458 .65347 .44752 .64613 .43971 Mtetra
.705 .779 .909 r
.64613 .43971 .65347 .44752 .66854 .44152 .66124 .4332 Mtetra
.686 .762 .909 r
.66124 .4332 .66854 .44152 .68369 .43608 .67644 .42746 Mtetra
.675 .752 .909 r
.67644 .42746 .68369 .43608 .69895 .43093 .69175 .42213 Mtetra
.67 .747 .908 r
.69175 .42213 .69895 .43093 .71429 .42591 .70714 .41699 Mtetra
.667 .744 .908 r
.70714 .41699 .71429 .42591 .72971 .42095 .72262 .41195 Mtetra
.665 .743 .908 r
.72262 .41195 .72971 .42095 .74523 .41601 .7382 .40694 Mtetra
.664 .742 .908 r
.7382 .40694 .74523 .41601 .76082 .41107 .75385 .40194 Mtetra
.75385 .40194 .76082 .41107 .77651 .40612 .7696 .39693 Mtetra
.7696 .39693 .77651 .40612 .79228 .40114 .78543 .3919 Mtetra
.664 .741 .908 r
.78543 .3919 .79228 .40114 .80814 .39614 .80135 .38685 Mtetra
.80135 .38685 .80814 .39614 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38607 .83346 .37667 Mtetra
.83346 .37667 .84012 .38607 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .762 .934 r
.31101 .73515 .3201 .74253 .33441 .73853 .32537 .73112 Mtetra
.646 .763 .934 r
.32537 .73112 .33441 .73853 .3488 .73451 .3398 .72706 Mtetra
.3398 .72706 .3488 .73451 .36327 .73045 .35432 .72297 Mtetra
.647 .763 .934 r
.35432 .72297 .36327 .73045 .37782 .72635 .36892 .71884 Mtetra
.648 .764 .933 r
.36892 .71884 .37782 .72635 .39245 .72217 .3836 .71465 Mtetra
.65 .765 .933 r
.3836 .71465 .39245 .72217 .40717 .71788 .39836 .71037 Mtetra
.653 .767 .933 r
.39836 .71037 .40717 .71788 .42196 .7134 .41321 .70594 Mtetra
.66 .771 .932 r
.41321 .70594 .42196 .7134 .43685 .70857 .42814 .70126 Mtetra
.672 .779 .93 r
.42814 .70126 .43685 .70857 .45182 .70311 .44316 .6961 Mtetra
.693 .793 .927 r
.44316 .6961 .45182 .70311 .46688 .69649 .45827 .69009 Mtetra
.73 .816 .918 r
.45827 .69009 .46688 .69649 .48203 .68779 .47348 .68251 Mtetra
.786 .85 .899 r
.47348 .68251 .48203 .68779 .49726 .67552 .48877 .67218 Mtetra
.858 .89 .858 r
.48877 .67218 .49726 .67552 .51251 .65759 .50411 .65726 Mtetra
.927 .92 .787 r
.50411 .65726 .51251 .65759 .52773 .63193 .51947 .63555 Mtetra
.967 .928 .696 r
.51947 .63555 .52773 .63193 .5428 .5983 .53473 .60558 Mtetra
.976 .921 .618 r
.53473 .60558 .5428 .5983 .55766 .56018 .54979 .56885 Mtetra
.969 .918 .585 r
.54979 .56885 .55766 .56018 .57232 .52387 .56464 .53066 Mtetra
.964 .933 .62 r
.56464 .53066 .57232 .52387 .58691 .49443 .57934 .49723 Mtetra
.952 .951 .716 r
.57934 .49723 .58691 .49443 .60153 .47304 .59403 .47177 Mtetra
.906 .936 .82 r
.59403 .47177 .60153 .47304 .61627 .45819 .6088 .45383 Mtetra
.831 .884 .881 r
.6088 .45383 .61627 .45819 .63114 .44766 .6237 .44131 Mtetra
.765 .831 .903 r
.6237 .44131 .63114 .44766 .64613 .43971 .63872 .43218 Mtetra
.72 .792 .909 r
.63872 .43218 .64613 .43971 .66124 .4332 .65387 .42499 Mtetra
.694 .769 .909 r
.65387 .42499 .66124 .4332 .67644 .42746 .66912 .41886 Mtetra
.68 .756 .909 r
.66912 .41886 .67644 .42746 .69175 .42213 .68448 .4133 Mtetra
.672 .749 .909 r
.68448 .4133 .69175 .42213 .70714 .41699 .69992 .40801 Mtetra
.668 .746 .908 r
.69992 .40801 .70714 .41699 .72262 .41195 .71546 .40287 Mtetra
.666 .744 .908 r
.71546 .40287 .72262 .41195 .7382 .40694 .73109 .39779 Mtetra
.665 .742 .908 r
.73109 .39779 .7382 .40694 .75385 .40194 .74681 .39272 Mtetra
.664 .742 .908 r
.74681 .39272 .75385 .40194 .7696 .39693 .76262 .38765 Mtetra
.76262 .38765 .7696 .39693 .78543 .3919 .77851 .38257 Mtetra
.664 .741 .908 r
.77851 .38257 .78543 .3919 .80135 .38685 .79449 .37746 Mtetra
.79449 .37746 .80135 .38685 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Mtetra
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85933 .35678 Mtetra
.85933 .35678 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .762 .934 r
.30182 .7277 .31101 .73515 .32537 .73112 .31623 .72363 Mtetra
.646 .763 .934 r
.31623 .72363 .32537 .73112 .3398 .72706 .33071 .71953 Mtetra
.33071 .71953 .3398 .72706 .35432 .72297 .34528 .7154 Mtetra
.647 .763 .934 r
.34528 .7154 .35432 .72297 .36892 .71884 .35993 .71124 Mtetra
.35993 .71124 .36892 .71884 .3836 .71465 .37465 .70703 Mtetra
.649 .764 .933 r
.37465 .70703 .3836 .71465 .39836 .71037 .38947 .70275 Mtetra
.651 .766 .933 r
.38947 .70275 .39836 .71037 .41321 .70594 .40436 .69835 Mtetra
.656 .769 .932 r
.40436 .69835 .41321 .70594 .42814 .70126 .41934 .69376 Mtetra
.665 .775 .931 r
.41934 .69376 .42814 .70126 .44316 .6961 .43442 .68882 Mtetra
.681 .785 .929 r
.43442 .68882 .44316 .6961 .45827 .69009 .44958 .68323 Mtetra
.709 .803 .923 r
.44958 .68323 .45827 .69009 .47348 .68251 .46483 .67648 Mtetra
.755 .832 .911 r
.46483 .67648 .47348 .68251 .48877 .67218 .48018 .66764 Mtetra
.821 .87 .882 r
.48018 .66764 .48877 .67218 .50411 .65726 .4956 .6552 Mtetra
.895 .907 .826 r
.4956 .6552 .50411 .65726 .51947 .63555 .51107 .63705 Mtetra
.952 .927 .742 r
.51107 .63705 .51947 .63555 .53473 .60558 .52649 .61113 Mtetra
.975 .925 .653 r
.52649 .61113 .53473 .60558 .54979 .56885 .54176 .57718 Mtetra
.973 .918 .594 r
.54176 .57718 .54979 .56885 .56464 .53066 .55682 .53872 Mtetra
.967 .923 .594 r
.55682 .53872 .56464 .53066 .57934 .49723 .57167 .50209 Mtetra
.961 .944 .663 r
.57167 .50209 .57934 .49723 .59403 .47177 .58645 .47237 Mtetra
.934 .949 .771 r
.58645 .47237 .59403 .47177 .6088 .45383 .60127 .45077 Mtetra
.87 .913 .857 r
.60127 .45077 .6088 .45383 .6237 .44131 .61619 .43573 Mtetra
.795 .856 .895 r
.61619 .43573 .6237 .44131 .63872 .43218 .63125 .42505 Mtetra
.74 .809 .907 r
.63125 .42505 .63872 .43218 .65387 .42499 .64643 .41696 Mtetra
.705 .779 .909 r
.64643 .41696 .65387 .42499 .66912 .41886 .66173 .41032 Mtetra
.686 .762 .909 r
.66173 .41032 .66912 .41886 .68448 .4133 .67714 .40445 Mtetra
.675 .752 .909 r
.67714 .40445 .68448 .4133 .69992 .40801 .69264 .39898 Mtetra
.67 .747 .908 r
.69264 .39898 .69992 .40801 .71546 .40287 .70823 .39372 Mtetra
.667 .744 .908 r
.70823 .39372 .71546 .40287 .73109 .39779 .72392 .38855 Mtetra
.665 .743 .908 r
.72392 .38855 .73109 .39779 .74681 .39272 .7397 .38341 Mtetra
.664 .742 .908 r
.7397 .38341 .74681 .39272 .76262 .38765 .75556 .37828 Mtetra
.75556 .37828 .76262 .38765 .77851 .38257 .77152 .37314 Mtetra
.77152 .37314 .77851 .38257 .79449 .37746 .78757 .36798 Mtetra
.664 .741 .908 r
.78757 .36798 .79449 .37746 .81057 .37233 .8037 .36279 Mtetra
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Mtetra
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85933 .35678 .85266 .34707 Mtetra
.85266 .34707 .85933 .35678 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .762 .934 r
.29254 .72017 .30182 .7277 .31623 .72363 .30699 .71606 Mtetra
.30699 .71606 .31623 .72363 .33071 .71953 .32153 .71192 Mtetra
.646 .763 .934 r
.32153 .71192 .33071 .71953 .34528 .7154 .33614 .70776 Mtetra
.33614 .70776 .34528 .7154 .35993 .71124 .35084 .70356 Mtetra
.647 .763 .934 r
.35084 .70356 .35993 .71124 .37465 .70703 .36562 .69932 Mtetra
.648 .764 .933 r
.36562 .69932 .37465 .70703 .38947 .70275 .38048 .69502 Mtetra
.65 .765 .933 r
.38048 .69502 .38947 .70275 .40436 .69835 .39543 .69064 Mtetra
.653 .767 .933 r
.39543 .69064 .40436 .69835 .41934 .69376 .41046 .6861 Mtetra
.66 .771 .932 r
.41046 .6861 .41934 .69376 .43442 .68882 .42558 .6813 Mtetra
.672 .779 .93 r
.42558 .6813 .43442 .68882 .44958 .68323 .44079 .67603 Mtetra
.693 .793 .927 r
.44079 .67603 .44958 .68323 .46483 .67648 .4561 .66988 Mtetra
.73 .816 .918 r
.4561 .66988 .46483 .67648 .48018 .66764 .4715 .66217 Mtetra
.786 .85 .899 r
.4715 .66217 .48018 .66764 .4956 .6552 .48699 .65168 Mtetra
.858 .89 .858 r
.48699 .65168 .4956 .6552 .51107 .63705 .50254 .63657 Mtetra
.927 .92 .787 r
.50254 .63657 .51107 .63705 .52649 .61113 .5181 .61461 Mtetra
.967 .928 .696 r
.5181 .61461 .52649 .61113 .54176 .57718 .53357 .58435 Mtetra
.976 .921 .618 r
.53357 .58435 .54176 .57718 .55682 .53872 .54884 .54729 Mtetra
.969 .918 .585 r
.54884 .54729 .55682 .53872 .57167 .50209 .56389 .50875 Mtetra
.965 .933 .62 r
.56389 .50875 .57167 .50209 .58645 .47237 .57878 .47503 Mtetra
.952 .951 .716 r
.57878 .47503 .58645 .47237 .60127 .45077 .59366 .44932 Mtetra
.906 .936 .82 r
.59366 .44932 .60127 .45077 .61619 .43573 .60862 .43117 Mtetra
.831 .884 .881 r
.60862 .43117 .61619 .43573 .63125 .42505 .62371 .41849 Mtetra
.765 .83 .903 r
.62371 .41849 .63125 .42505 .64643 .41696 .63893 .40921 Mtetra
.72 .792 .909 r
.63893 .40921 .64643 .41696 .66173 .41032 .65427 .40188 Mtetra
.694 .769 .909 r
.65427 .40188 .66173 .41032 .67714 .40445 .66972 .39562 Mtetra
.68 .756 .909 r
.66972 .39562 .67714 .40445 .69264 .39898 .68528 .38992 Mtetra
.672 .749 .909 r
.68528 .38992 .69264 .39898 .70823 .39372 .70093 .38451 Mtetra
.668 .746 .908 r
.70093 .38451 .70823 .39372 .72392 .38855 .71667 .37923 Mtetra
.666 .744 .908 r
.71667 .37923 .72392 .38855 .7397 .38341 .73251 .37402 Mtetra
.665 .742 .908 r
.73251 .37402 .7397 .38341 .75556 .37828 .74844 .36882 Mtetra
.664 .742 .908 r
.74844 .36882 .75556 .37828 .77152 .37314 .76446 .36362 Mtetra
.76446 .36362 .77152 .37314 .78757 .36798 .78057 .3584 Mtetra
.664 .741 .908 r
.78057 .3584 .78757 .36798 .8037 .36279 .79677 .35316 Mtetra
.79677 .35316 .8037 .36279 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Mtetra
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72017 .30699 .71606 .29767 .70842 Mtetra
.29767 .70842 .30699 .71606 .32153 .71192 .31225 .70424 Mtetra
.646 .763 .934 r
.31225 .70424 .32153 .71192 .33614 .70776 .32691 .70003 Mtetra
.32691 .70003 .33614 .70776 .35084 .70356 .34166 .6958 Mtetra
.647 .763 .934 r
.34166 .6958 .35084 .70356 .36562 .69932 .35649 .69153 Mtetra
.35649 .69153 .36562 .69932 .38048 .69502 .3714 .68721 Mtetra
.649 .764 .933 r
.3714 .68721 .38048 .69502 .39543 .69064 .3864 .68281 Mtetra
.651 .766 .933 r
.3864 .68281 .39543 .69064 .41046 .6861 .40148 .6783 Mtetra
.656 .769 .932 r
.40148 .6783 .41046 .6861 .42558 .6813 .41666 .6736 Mtetra
.665 .775 .931 r
.41666 .6736 .42558 .6813 .44079 .67603 .43192 .66853 Mtetra
.681 .785 .929 r
.43192 .66853 .44079 .67603 .4561 .66988 .44728 .66283 Mtetra
.709 .803 .923 r
.44728 .66283 .4561 .66988 .4715 .66217 .46273 .65594 Mtetra
.755 .832 .911 r
.46273 .65594 .4715 .66217 .48699 .65168 .47828 .64695 Mtetra
.821 .87 .882 r
.47828 .64695 .48699 .65168 .50254 .63657 .49391 .63434 Mtetra
.895 .907 .826 r
.49391 .63434 .50254 .63657 .5181 .61461 .50958 .61597 Mtetra
.952 .927 .742 r
.50958 .61597 .5181 .61461 .53357 .58435 .52521 .58977 Mtetra
.974 .925 .653 r
.52521 .58977 .53357 .58435 .54884 .54729 .5407 .5555 Mtetra
.973 .918 .594 r
.5407 .5555 .54884 .54729 .56389 .50875 .55596 .51669 Mtetra
.967 .923 .594 r
.55596 .51669 .56389 .50875 .57878 .47503 .57101 .47974 Mtetra
.961 .944 .663 r
.57101 .47974 .57878 .47503 .59366 .44932 .58598 .44975 Mtetra
.934 .949 .771 r
.58598 .44975 .59366 .44932 .60862 .43117 .60099 .42792 Mtetra
.869 .912 .857 r
.60099 .42792 .60862 .43117 .62371 .41849 .61611 .4127 Mtetra
.795 .856 .895 r
.61611 .4127 .62371 .41849 .63893 .40921 .63136 .40186 Mtetra
.74 .809 .907 r
.63136 .40186 .63893 .40921 .65427 .40188 .64674 .39362 Mtetra
.705 .779 .909 r
.64674 .39362 .65427 .40188 .66972 .39562 .66224 .38684 Mtetra
.686 .762 .909 r
.66224 .38684 .66972 .39562 .68528 .38992 .67785 .38084 Mtetra
.675 .752 .909 r
.67785 .38084 .68528 .38992 .70093 .38451 .69355 .37524 Mtetra
.67 .747 .908 r
.69355 .37524 .70093 .38451 .71667 .37923 .70936 .36984 Mtetra
.667 .744 .908 r
.70936 .36984 .71667 .37923 .73251 .37402 .72525 .36453 Mtetra
.665 .743 .908 r
.72525 .36453 .73251 .37402 .74844 .36882 .74124 .35926 Mtetra
.664 .742 .908 r
.74124 .35926 .74844 .36882 .76446 .36362 .75732 .354 Mtetra
.75732 .354 .76446 .36362 .78057 .3584 .77349 .34872 Mtetra
.77349 .34872 .78057 .3584 .79677 .35316 .78976 .34342 Mtetra
.664 .741 .908 r
.78976 .34342 .79677 .35316 .81306 .34789 .80611 .3381 Mtetra
.80611 .3381 .81306 .34789 .82944 .34259 .82256 .33274 Mtetra
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Mtetra
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70842 .28825 .70069 Mtetra
.28825 .70069 .29767 .70842 .31225 .70424 .30288 .69647 Mtetra
.30288 .69647 .31225 .70424 .32691 .70003 .31759 .69223 Mtetra
.646 .763 .934 r
.31759 .69223 .32691 .70003 .34166 .6958 .33239 .68795 Mtetra
.33239 .68795 .34166 .6958 .35649 .69153 .34727 .68364 Mtetra
.647 .763 .934 r
.34727 .68364 .35649 .69153 .3714 .68721 .36223 .67929 Mtetra
.648 .764 .933 r
.36223 .67929 .3714 .68721 .3864 .68281 .37728 .67488 Mtetra
.65 .765 .933 r
.37728 .67488 .3864 .68281 .40148 .6783 .39241 .67038 Mtetra
.653 .767 .933 r
.39241 .67038 .40148 .6783 .41666 .6736 .40764 .66573 Mtetra
.66 .771 .932 r
.40764 .66573 .41666 .6736 .43192 .66853 .42295 .66081 Mtetra
.672 .779 .93 r
.42295 .66081 .43192 .66853 .44728 .66283 .43836 .65541 Mtetra
.693 .793 .927 r
.43836 .65541 .44728 .66283 .46273 .65594 .45387 .64914 Mtetra
.73 .816 .918 r
.45387 .64914 .46273 .65594 .47828 .64695 .46947 .64128 Mtetra
.786 .85 .899 r
.46947 .64128 .47828 .64695 .49391 .63434 .48517 .63062 Mtetra
.858 .89 .858 r
.48517 .63062 .49391 .63434 .50958 .61597 .50093 .61532 Mtetra
.927 .92 .787 r
.50093 .61532 .50958 .61597 .52521 .58977 .5167 .59312 Mtetra
.967 .928 .695 r
.5167 .59312 .52521 .58977 .5407 .5555 .53238 .56255 Mtetra
.976 .921 .617 r
.53238 .56255 .5407 .5555 .55596 .51669 .54786 .52515 Mtetra
.97 .918 .585 r
.54786 .52515 .55596 .51669 .57101 .47974 .56311 .48627 Mtetra
.965 .933 .62 r
.56311 .48627 .57101 .47974 .58598 .44975 .57821 .45224 Mtetra
.952 .951 .716 r
.57821 .45224 .58598 .44975 .60099 .42792 .59329 .42628 Mtetra
.906 .935 .82 r
.59329 .42628 .60099 .42792 .61611 .4127 .60844 .40793 Mtetra
.831 .884 .881 r
.60844 .40793 .61611 .4127 .63136 .40186 .62373 .39507 Mtetra
.765 .83 .903 r
.62373 .39507 .63136 .40186 .64674 .39362 .63914 .38564 Mtetra
.72 .792 .909 r
.63914 .38564 .64674 .39362 .66224 .38684 .65469 .37816 Mtetra
.694 .769 .909 r
.65469 .37816 .66224 .38684 .67785 .38084 .67034 .37176 Mtetra
.68 .756 .909 r
.67034 .37176 .67785 .38084 .69355 .37524 .6861 .36593 Mtetra
.672 .749 .909 r
.6861 .36593 .69355 .37524 .70936 .36984 .70196 .36038 Mtetra
.668 .746 .908 r
.70196 .36038 .70936 .36984 .72525 .36453 .71792 .35497 Mtetra
.666 .744 .908 r
.71792 .35497 .72525 .36453 .74124 .35926 .73397 .34962 Mtetra
.665 .742 .908 r
.73397 .34962 .74124 .35926 .75732 .354 .75011 .34428 Mtetra
.664 .742 .908 r
.75011 .34428 .75732 .354 .77349 .34872 .76635 .33894 Mtetra
.76635 .33894 .77349 .34872 .78976 .34342 .78267 .33358 Mtetra
.664 .741 .908 r
.78267 .33358 .78976 .34342 .80611 .3381 .7991 .3282 Mtetra
.7991 .3282 .80611 .3381 .82256 .33274 .81561 .32279 Mtetra
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Mtetra
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Mtetra
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Mtetra
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .70069 .27873 .69289 Mtetra
.27873 .69289 .28825 .70069 .30288 .69647 .29341 .68863 Mtetra
.29341 .68863 .30288 .69647 .31759 .69223 .30817 .68434 Mtetra
.646 .763 .934 r
.30817 .68434 .31759 .69223 .33239 .68795 .32302 .68002 Mtetra
.32302 .68002 .33239 .68795 .34727 .68364 .33795 .67568 Mtetra
.647 .763 .934 r
.33795 .67568 .34727 .68364 .36223 .67929 .35296 .67129 Mtetra
.35296 .67129 .36223 .67929 .37728 .67488 .36806 .66685 Mtetra
.649 .764 .933 r
.36806 .66685 .37728 .67488 .39241 .67038 .38325 .66234 Mtetra
.651 .766 .933 r
.38325 .66234 .39241 .67038 .40764 .66573 .39853 .65772 Mtetra
.656 .769 .932 r
.39853 .65772 .40764 .66573 .42295 .66081 .41389 .65289 Mtetra
.665 .775 .931 r
.41389 .65289 .42295 .66081 .43836 .65541 .42936 .64771 Mtetra
.681 .785 .929 r
.42936 .64771 .43836 .65541 .45387 .64914 .44492 .64187 Mtetra
.709 .803 .923 r
.44492 .64187 .45387 .64914 .46947 .64128 .46057 .63485 Mtetra
.755 .832 .911 r
.46057 .63485 .46947 .64128 .48517 .63062 .47633 .62571 Mtetra
.821 .87 .882 r
.47633 .62571 .48517 .63062 .50093 .61532 .49217 .61291 Mtetra
.895 .908 .826 r
.49217 .61291 .50093 .61532 .5167 .59312 .50805 .59432 Mtetra
.952 .927 .742 r
.50805 .59432 .5167 .59312 .53238 .56255 .5239 .56784 Mtetra
.974 .925 .652 r
.5239 .56784 .53238 .56255 .54786 .52515 .5396 .53324 Mtetra
.973 .918 .594 r
.5396 .53324 .54786 .52515 .56311 .48627 .55507 .49409 Mtetra
.967 .923 .594 r
.55507 .49409 .56311 .48627 .57821 .45224 .57033 .4568 Mtetra
.961 .943 .663 r
.57033 .4568 .57821 .45224 .59329 .42628 .5855 .42653 Mtetra
.934 .949 .772 r
.5855 .42653 .59329 .42628 .60844 .40793 .60071 .40447 Mtetra
.869 .912 .857 r
.60071 .40447 .60844 .40793 .62373 .39507 .61603 .38906 Mtetra
.795 .856 .895 r
.61603 .38906 .62373 .39507 .63914 .38564 .63148 .37805 Mtetra
.74 .809 .907 r
.63148 .37805 .63914 .38564 .65469 .37816 .64706 .36967 Mtetra
.705 .779 .909 r
.64706 .36967 .65469 .37816 .67034 .37176 .66276 .36274 Mtetra
.686 .762 .909 r
.66276 .36274 .67034 .37176 .6861 .36593 .67858 .3566 Mtetra
.675 .752 .909 r
.67858 .3566 .6861 .36593 .70196 .36038 .69449 .35086 Mtetra
.67 .747 .908 r
.69449 .35086 .70196 .36038 .71792 .35497 .71051 .34532 Mtetra
.667 .744 .908 r
.71051 .34532 .71792 .35497 .73397 .34962 .72662 .33988 Mtetra
.665 .743 .908 r
.72662 .33988 .73397 .34962 .75011 .34428 .74282 .33447 Mtetra
.664 .742 .908 r
.74282 .33447 .75011 .34428 .76635 .33894 .75912 .32906 Mtetra
.75912 .32906 .76635 .33894 .78267 .33358 .77552 .32364 Mtetra
.77552 .32364 .78267 .33358 .7991 .3282 .79201 .3182 Mtetra
.664 .741 .908 r
.79201 .3182 .7991 .3282 .81561 .32279 .80859 .31273 Mtetra
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30724 Mtetra
.82527 .30724 .83222 .31735 .84893 .31188 .84205 .30171 Mtetra
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Mtetra
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .68501 Mtetra
.26911 .68501 .27873 .69289 .29341 .68863 .28384 .6807 Mtetra
.28384 .6807 .29341 .68863 .30817 .68434 .29865 .67637 Mtetra
.29865 .67637 .30817 .68434 .32302 .68002 .31355 .67201 Mtetra
.646 .763 .934 r
.31355 .67201 .32302 .68002 .33795 .67568 .32853 .66762 Mtetra
.32853 .66762 .33795 .67568 .35296 .67129 .3436 .6632 Mtetra
.647 .763 .934 r
.3436 .6632 .35296 .67129 .36806 .66685 .35875 .65873 Mtetra
.648 .764 .933 r
.35875 .65873 .36806 .66685 .38325 .66234 .37399 .6542 Mtetra
.65 .765 .933 r
.37399 .6542 .38325 .66234 .39853 .65772 .38932 .64958 Mtetra
.653 .767 .933 r
.38932 .64958 .39853 .65772 .41389 .65289 .40474 .64481 Mtetra
.66 .771 .932 r
.40474 .64481 .41389 .65289 .42936 .64771 .42026 .63976 Mtetra
.672 .779 .93 r
.42026 .63976 .42936 .64771 .44492 .64187 .43587 .63424 Mtetra
.693 .793 .927 r
.43587 .63424 .44492 .64187 .46057 .63485 .45158 .62783 Mtetra
.73 .816 .918 r
.45158 .62783 .46057 .63485 .47633 .62571 .46739 .61982 Mtetra
.786 .85 .899 r
.46739 .61982 .47633 .62571 .49217 .61291 .4833 .609 Mtetra
.858 .89 .858 r
.4833 .609 .49217 .61291 .50805 .59432 .49927 .59349 Mtetra
.927 .921 .786 r
.49927 .59349 .50805 .59432 .5239 .56784 .51526 .57104 Mtetra
.967 .928 .695 r
.51526 .57104 .5239 .56784 .5396 .53324 .53116 .54017 Mtetra
.975 .921 .617 r
.53116 .54017 .5396 .53324 .55507 .49409 .54686 .50241 Mtetra
.97 .918 .585 r
.54686 .50241 .55507 .49409 .57033 .4568 .56232 .46319 Mtetra
.965 .933 .621 r
.56232 .46319 .57033 .4568 .5855 .42653 .57762 .42885 Mtetra
.952 .95 .717 r
.57762 .42885 .5855 .42653 .60071 .40447 .5929 .40263 Mtetra
.905 .935 .82 r
.5929 .40263 .60071 .40447 .61603 .38906 .60826 .38407 Mtetra
.831 .884 .881 r
.60826 .38407 .61603 .38906 .63148 .37805 .62374 .37104 Mtetra
.765 .83 .903 r
.62374 .37104 .63148 .37805 .64706 .36967 .63936 .36144 Mtetra
.72 .792 .909 r
.63936 .36144 .64706 .36967 .66276 .36274 .65511 .35382 Mtetra
.694 .769 .909 r
.65511 .35382 .66276 .36274 .67858 .3566 .67097 .34728 Mtetra
.68 .756 .909 r
.67097 .34728 .67858 .3566 .69449 .35086 .68695 .3413 Mtetra
.672 .749 .909 r
.68695 .3413 .69449 .35086 .71051 .34532 .70302 .33561 Mtetra
.668 .746 .908 r
.70302 .33561 .71051 .34532 .72662 .33988 .71919 .33006 Mtetra
.666 .744 .908 r
.71919 .33006 .72662 .33988 .74282 .33447 .73546 .32456 Mtetra
.665 .742 .908 r
.73546 .32456 .74282 .33447 .75912 .32906 .75182 .31908 Mtetra
.664 .742 .908 r
.75182 .31908 .75912 .32906 .77552 .32364 .76828 .3136 Mtetra
.76828 .3136 .77552 .32364 .79201 .3182 .78484 .3081 Mtetra
.664 .741 .908 r
.78484 .3081 .79201 .3182 .80859 .31273 .80149 .30257 Mtetra
.80149 .30257 .80859 .31273 .82527 .30724 .81824 .29701 Mtetra
.81824 .29701 .82527 .30724 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .68501 .25939 .67704 Mtetra
.25939 .67704 .26911 .68501 .28384 .6807 .27417 .67269 Mtetra
.27417 .67269 .28384 .6807 .29865 .67637 .28904 .66831 Mtetra
.28904 .66831 .29865 .67637 .31355 .67201 .30398 .66391 Mtetra
.646 .763 .934 r
.30398 .66391 .31355 .67201 .32853 .66762 .31901 .65948 Mtetra
.31901 .65948 .32853 .66762 .3436 .6632 .33413 .65501 Mtetra
.647 .763 .934 r
.33413 .65501 .3436 .6632 .35875 .65873 .34934 .65051 Mtetra
.34934 .65051 .35875 .65873 .37399 .6542 .36463 .64595 Mtetra
.649 .764 .933 r
.36463 .64595 .37399 .6542 .38932 .64958 .38001 .64132 Mtetra
.651 .766 .933 r
.38001 .64132 .38932 .64958 .40474 .64481 .39549 .63658 Mtetra
.656 .769 .932 r
.39549 .63658 .40474 .64481 .42026 .63976 .41106 .63162 Mtetra
.665 .775 .931 r
.41106 .63162 .42026 .63976 .43587 .63424 .42672 .62631 Mtetra
.681 .785 .929 r
.42672 .62631 .43587 .63424 .45158 .62783 .44249 .62034 Mtetra
.709 .803 .923 r
.44249 .62034 .45158 .62783 .46739 .61982 .45836 .61318 Mtetra
.755 .832 .911 r
.45836 .61318 .46739 .61982 .4833 .609 .47432 .60387 Mtetra
.821 .87 .882 r
.47432 .60387 .4833 .609 .49927 .59349 .49038 .59089 Mtetra
.895 .908 .826 r
.49038 .59089 .49927 .59349 .51526 .57104 .50648 .57207 Mtetra
.952 .927 .741 r
.50648 .57207 .51526 .57104 .53116 .54017 .52255 .54531 Mtetra
.974 .925 .652 r
.52255 .54531 .53116 .54017 .54686 .50241 .53848 .51038 Mtetra
.973 .918 .594 r
.53848 .51038 .54686 .50241 .56232 .46319 .55416 .47087 Mtetra
.967 .923 .594 r
.55416 .47087 .56232 .46319 .57762 .42885 .56963 .43325 Mtetra
.961 .943 .664 r
.56963 .43325 .57762 .42885 .5929 .40263 .58501 .40269 Mtetra
.934 .948 .772 r
.58501 .40269 .5929 .40263 .60826 .38407 .60042 .3804 Mtetra
.869 .912 .857 r
.60042 .3804 .60826 .38407 .62374 .37104 .61594 .36479 Mtetra
.795 .856 .895 r
.61594 .36479 .62374 .37104 .63936 .36144 .6316 .35362 Mtetra
.74 .809 .907 r
.6316 .35362 .63936 .36144 .65511 .35382 .64739 .34508 Mtetra
.705 .779 .909 r
.64739 .34508 .65511 .35382 .67097 .34728 .6633 .338 Mtetra
.686 .762 .909 r
.6633 .338 .67097 .34728 .68695 .3413 .67932 .33171 Mtetra
.675 .752 .909 r
.67932 .33171 .68695 .3413 .70302 .33561 .69546 .32583 Mtetra
.67 .747 .908 r
.69546 .32583 .70302 .33561 .71919 .33006 .71169 .32015 Mtetra
.667 .744 .908 r
.71169 .32015 .71919 .33006 .73546 .32456 .72802 .31456 Mtetra
.665 .743 .908 r
.72802 .31456 .73546 .32456 .75182 .31908 .74445 .30901 Mtetra
.664 .742 .908 r
.74445 .30901 .75182 .31908 .76828 .3136 .76097 .30345 Mtetra
.76097 .30345 .76828 .3136 .78484 .3081 .7776 .29788 Mtetra
.7776 .29788 .78484 .3081 .80149 .30257 .79432 .29229 Mtetra
.664 .741 .908 r
.79432 .29229 .80149 .30257 .81824 .29701 .81113 .28668 Mtetra
.81113 .28668 .81824 .29701 .83509 .29142 .82805 .28103 Mtetra
.82805 .28103 .83509 .29142 .85203 .2858 .84507 .27535 Mtetra
.84507 .27535 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .66459 Mtetra
.2644 .66459 .27417 .67269 .28904 .66831 .27932 .66017 Mtetra
.27932 .66017 .28904 .66831 .30398 .66391 .29431 .65572 Mtetra
.29431 .65572 .30398 .66391 .31901 .65948 .3094 .65125 Mtetra
.646 .763 .934 r
.3094 .65125 .31901 .65948 .33413 .65501 .32457 .64674 Mtetra
.32457 .64674 .33413 .65501 .34934 .65051 .33983 .6422 Mtetra
.647 .763 .934 r
.33983 .6422 .34934 .65051 .36463 .64595 .35517 .63761 Mtetra
.648 .764 .933 r
.35517 .63761 .36463 .64595 .38001 .64132 .37061 .63296 Mtetra
.65 .765 .933 r
.37061 .63296 .38001 .64132 .39549 .63658 .38614 .62821 Mtetra
.653 .767 .933 r
.38614 .62821 .39549 .63658 .41106 .63162 .40176 .62331 Mtetra
.66 .771 .932 r
.40176 .62331 .41106 .63162 .42672 .62631 .41748 .61814 Mtetra
.672 .779 .93 r
.41748 .61814 .42672 .62631 .44249 .62034 .4333 .61248 Mtetra
.693 .793 .927 r
.4333 .61248 .44249 .62034 .45836 .61318 .44922 .60593 Mtetra
.73 .816 .918 r
.44922 .60593 .45836 .61318 .47432 .60387 .46525 .59777 Mtetra
.786 .85 .899 r
.46525 .59777 .47432 .60387 .49038 .59089 .48137 .58678 Mtetra
.859 .891 .858 r
.48137 .58678 .49038 .59089 .50648 .57207 .49757 .57106 Mtetra
.927 .921 .786 r
.49757 .57106 .50648 .57207 .52255 .54531 .51378 .54835 Mtetra
.967 .928 .695 r
.51378 .54835 .52255 .54531 .53848 .51038 .52991 .51717 Mtetra
.975 .921 .617 r
.52991 .51717 .53848 .51038 .55416 .47087 .54583 .47906 Mtetra
.97 .918 .586 r
.54583 .47906 .55416 .47087 .56963 .43325 .56151 .43948 Mtetra
.965 .933 .621 r
.56151 .43948 .56963 .43325 .58501 .40269 .57702 .40483 Mtetra
.952 .95 .717 r
.57702 .40483 .58501 .40269 .60042 .3804 .5925 .37835 Mtetra
.905 .935 .82 r
.5925 .37835 .60042 .3804 .61594 .36479 .60807 .35958 Mtetra
.831 .884 .881 r
.60807 .35958 .61594 .36479 .6316 .35362 .62376 .34636 Mtetra
.765 .83 .903 r
.62376 .34636 .6316 .35362 .64739 .34508 .63959 .3366 Mtetra
.72 .792 .909 r
.63959 .3366 .64739 .34508 .6633 .338 .65555 .32883 Mtetra
.694 .769 .909 r
.65555 .32883 .6633 .338 .67932 .33171 .67163 .32213 Mtetra
.68 .756 .909 r
.67163 .32213 .67932 .33171 .69546 .32583 .68781 .31601 Mtetra
.672 .749 .909 r
.68781 .31601 .69546 .32583 .71169 .32015 .70411 .31017 Mtetra
.668 .746 .908 r
.70411 .31017 .71169 .32015 .72802 .31456 .7205 .30447 Mtetra
.666 .744 .908 r
.7205 .30447 .72802 .31456 .74445 .30901 .737 .29883 Mtetra
.665 .742 .908 r
.737 .29883 .74445 .30901 .76097 .30345 .75359 .2932 Mtetra
.664 .742 .908 r
.75359 .2932 .76097 .30345 .7776 .29788 .77028 .28756 Mtetra
.77028 .28756 .7776 .29788 .79432 .29229 .78707 .28191 Mtetra
.664 .741 .908 r
.78707 .28191 .79432 .29229 .81113 .28668 .80395 .27623 Mtetra
.80395 .27623 .81113 .28668 .82805 .28103 .82094 .27052 Mtetra
.82094 .27052 .82805 .28103 .84507 .27535 .83803 .26478 Mtetra
.83803 .26478 .84507 .27535 .86218 .26963 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .66459 .25453 .65641 Mtetra
.25453 .65641 .2644 .66459 .27932 .66017 .2695 .65195 Mtetra
.2695 .65195 .27932 .66017 .29431 .65572 .28454 .64745 Mtetra
.28454 .64745 .29431 .65572 .3094 .65125 .29968 .64293 Mtetra
.646 .763 .934 r
.29968 .64293 .3094 .65125 .32457 .64674 .3149 .63838 Mtetra
.3149 .63838 .32457 .64674 .33983 .6422 .33022 .63379 Mtetra
.647 .763 .934 r
.33022 .63379 .33983 .6422 .35517 .63761 .34562 .62916 Mtetra
.34562 .62916 .35517 .63761 .37061 .63296 .36111 .62448 Mtetra
.649 .764 .933 r
.36111 .62448 .37061 .63296 .38614 .62821 .37669 .61973 Mtetra
.651 .766 .933 r
.37669 .61973 .38614 .62821 .40176 .62331 .39237 .61485 Mtetra
.656 .769 .932 r
.39237 .61485 .40176 .62331 .41748 .61814 .40814 .60977 Mtetra
.665 .775 .931 r
.40814 .60977 .41748 .61814 .4333 .61248 .42402 .60433 Mtetra
.681 .785 .929 r
.42402 .60433 .4333 .61248 .44922 .60593 .43999 .59822 Mtetra
.709 .803 .923 r
.43999 .59822 .44922 .60593 .46525 .59777 .45608 .59091 Mtetra
.755 .832 .911 r
.45608 .59091 .46525 .59777 .48137 .58678 .47226 .58144 Mtetra
.821 .871 .882 r
.47226 .58144 .48137 .58678 .49757 .57106 .48854 .56826 Mtetra
.895 .908 .826 r
.48854 .56826 .49757 .57106 .51378 .54835 .50487 .5492 Mtetra
.952 .928 .741 r
.50487 .5492 .51378 .54835 .52991 .51717 .52117 .52216 Mtetra
.974 .925 .652 r
.52117 .52216 .52991 .51717 .54583 .47906 .53732 .48689 Mtetra
.973 .918 .594 r
.53732 .48689 .54583 .47906 .56151 .43948 .55323 .44702 Mtetra
.967 .923 .594 r
.55323 .44702 .56151 .43948 .57702 .40483 .56891 .40906 Mtetra
.961 .943 .664 r
.56891 .40906 .57702 .40483 .5925 .37835 .5845 .37821 Mtetra
.934 .948 .772 r
.5845 .37821 .5925 .37835 .60807 .35958 .60012 .35568 Mtetra
.869 .912 .857 r
.60012 .35568 .60807 .35958 .62376 .34636 .61585 .33987 Mtetra
.795 .855 .895 r
.61585 .33987 .62376 .34636 .63959 .3366 .63172 .32852 Mtetra
.74 .809 .907 r
.63172 .32852 .63959 .3366 .65555 .32883 .64772 .31982 Mtetra
.705 .779 .909 r
.64772 .31982 .65555 .32883 .67163 .32213 .66385 .31259 Mtetra
.686 .762 .909 r
.66385 .31259 .67163 .32213 .68781 .31601 .68009 .30615 Mtetra
.675 .752 .909 r
.68009 .30615 .68781 .31601 .70411 .31017 .69645 .30012 Mtetra
.67 .747 .908 r
.69645 .30012 .70411 .31017 .7205 .30447 .7129 .29429 Mtetra
.667 .744 .908 r
.7129 .29429 .7205 .30447 .737 .29883 .72946 .28855 Mtetra
.665 .743 .908 r
.72946 .28855 .737 .29883 .75359 .2932 .74612 .28284 Mtetra
.664 .742 .908 r
.74612 .28284 .75359 .2932 .77028 .28756 .76288 .27714 Mtetra
.76288 .27714 .77028 .28756 .78707 .28191 .77973 .27142 Mtetra
.77973 .27142 .78707 .28191 .80395 .27623 .79669 .26567 Mtetra
.664 .741 .908 r
.79669 .26567 .80395 .27623 .82094 .27052 .81375 .25989 Mtetra
.81375 .25989 .82094 .27052 .83803 .26478 .83091 .25409 Mtetra
.83091 .25409 .83803 .26478 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65641 .24456 .64815 Mtetra
.24456 .64815 .25453 .65641 .2695 .65195 .25957 .64363 Mtetra
.25957 .64363 .2695 .65195 .28454 .64745 .27467 .63909 Mtetra
.27467 .63909 .28454 .64745 .29968 .64293 .28986 .63452 Mtetra
.28986 .63452 .29968 .64293 .3149 .63838 .30513 .62992 Mtetra
.646 .763 .934 r
.30513 .62992 .3149 .63838 .33022 .63379 .3205 .62529 Mtetra
.3205 .62529 .33022 .63379 .34562 .62916 .33596 .62062 Mtetra
.647 .763 .934 r
.33596 .62062 .34562 .62916 .36111 .62448 .3515 .61591 Mtetra
.648 .764 .933 r
.3515 .61591 .36111 .62448 .37669 .61973 .36714 .61113 Mtetra
.65 .765 .933 r
.36714 .61113 .37669 .61973 .39237 .61485 .38288 .60626 Mtetra
.653 .767 .933 r
.38288 .60626 .39237 .61485 .40814 .60977 .39871 .60123 Mtetra
.66 .771 .932 r
.39871 .60123 .40814 .60977 .42402 .60433 .41463 .59592 Mtetra
.672 .779 .93 r
.41463 .59592 .42402 .60433 .43999 .59822 .43067 .59012 Mtetra
.693 .793 .927 r
.43067 .59012 .43999 .59822 .45608 .59091 .4468 .58343 Mtetra
.73 .816 .918 r
.4468 .58343 .45608 .59091 .47226 .58144 .46305 .57511 Mtetra
.786 .851 .899 r
.46305 .57511 .47226 .58144 .48854 .56826 .4794 .56393 Mtetra
.859 .891 .858 r
.4794 .56393 .48854 .56826 .50487 .5492 .49582 .548 Mtetra
.927 .921 .786 r
.49582 .548 .50487 .5492 .52117 .52216 .51226 .52503 Mtetra
.967 .928 .695 r
.51226 .52503 .52117 .52216 .53732 .48689 .52862 .49353 Mtetra
.975 .921 .617 r
.52862 .49353 .53732 .48689 .55323 .44702 .54477 .45506 Mtetra
.97 .918 .586 r
.54477 .45506 .55323 .44702 .56891 .40906 .56067 .41513 Mtetra
.965 .933 .621 r
.56067 .41513 .56891 .40906 .5845 .37821 .5764 .38016 Mtetra
.952 .95 .717 r
.5764 .38016 .5845 .37821 .60012 .35568 .59209 .35341 Mtetra
.905 .935 .82 r
.59209 .35341 .60012 .35568 .61585 .33987 .60787 .33442 Mtetra
.831 .884 .881 r
.60787 .33442 .61585 .33987 .63172 .32852 .62377 .32101 Mtetra
.765 .83 .903 r
.62377 .32101 .63172 .32852 .64772 .31982 .63982 .31108 Mtetra
.72 .792 .908 r
.63982 .31108 .64772 .31982 .66385 .31259 .656 .30315 Mtetra
.694 .769 .909 r
.656 .30315 .66385 .31259 .68009 .30615 .67229 .2963 Mtetra
.68 .756 .909 r
.67229 .2963 .68009 .30615 .69645 .30012 .68871 .29002 Mtetra
.672 .749 .909 r
.68871 .29002 .69645 .30012 .7129 .29429 .70522 .28403 Mtetra
.668 .746 .908 r
.70522 .28403 .7129 .29429 .72946 .28855 .72185 .27818 Mtetra
.666 .744 .908 r
.72185 .27818 .72946 .28855 .74612 .28284 .73857 .27238 Mtetra
.665 .742 .908 r
.73857 .27238 .74612 .28284 .76288 .27714 .7554 .2666 Mtetra
.664 .742 .908 r
.7554 .2666 .76288 .27714 .77973 .27142 .77232 .26081 Mtetra
.77232 .26081 .77973 .27142 .79669 .26567 .78935 .255 Mtetra
.664 .741 .908 r
.78935 .255 .79669 .26567 .81375 .25989 .80648 .24916 Mtetra
.80648 .24916 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63909 .26469 .63064 Mtetra
.26469 .63064 .27467 .63909 .28986 .63452 .27993 .62602 Mtetra
.27993 .62602 .28986 .63452 .30513 .62992 .29526 .62137 Mtetra
.646 .763 .934 r
.29526 .62137 .30513 .62992 .3205 .62529 .31068 .61669 Mtetra
.31068 .61669 .3205 .62529 .33596 .62062 .32619 .61198 Mtetra
.647 .763 .934 r
.32619 .61198 .33596 .62062 .3515 .61591 .34179 .60723 Mtetra
.34179 .60723 .3515 .61591 .36714 .61113 .35749 .60242 Mtetra
.649 .764 .933 r
.35749 .60242 .36714 .61113 .38288 .60626 .37328 .59753 Mtetra
.651 .766 .933 r
.37328 .59753 .38288 .60626 .39871 .60123 .38916 .59252 Mtetra
.656 .769 .932 r
.38916 .59252 .39871 .60123 .41463 .59592 .40515 .58731 Mtetra
.665 .775 .931 r
.40515 .58731 .41463 .59592 .43067 .59012 .42124 .58172 Mtetra
.681 .785 .929 r
.42124 .58172 .43067 .59012 .4468 .58343 .43743 .57547 Mtetra
.709 .803 .923 r
.43743 .57547 .4468 .58343 .46305 .57511 .45373 .568 Mtetra
.755 .832 .911 r
.45373 .568 .46305 .57511 .4794 .56393 .47014 .55836 Mtetra
.821 .871 .883 r
.47014 .55836 .4794 .56393 .49582 .548 .48665 .54499 Mtetra
.895 .908 .826 r
.48665 .54499 .49582 .548 .51226 .52503 .50321 .5257 Mtetra
.952 .928 .741 r
.50321 .5257 .51226 .52503 .52862 .49353 .51974 .49836 Mtetra
.974 .925 .652 r
.51974 .49836 .52862 .49353 .54477 .45506 .53613 .46274 Mtetra
.973 .918 .594 r
.53613 .46274 .54477 .45506 .56067 .41513 .55227 .4225 Mtetra
.967 .923 .595 r
.55227 .4225 .56067 .41513 .5764 .38016 .56818 .3842 Mtetra
.962 .943 .664 r
.56818 .3842 .5764 .38016 .59209 .35341 .58398 .35306 Mtetra
.934 .948 .772 r
.58398 .35306 .59209 .35341 .60787 .33442 .59981 .33029 Mtetra
.869 .911 .857 r
.59981 .33029 .60787 .33442 .62377 .32101 .61576 .31428 Mtetra
.795 .855 .895 r
.61576 .31428 .62377 .32101 .63982 .31108 .63184 .30275 Mtetra
.74 .809 .907 r
.63184 .30275 .63982 .31108 .656 .30315 .64806 .29388 Mtetra
.705 .779 .909 r
.64806 .29388 .656 .30315 .67229 .2963 .66441 .28649 Mtetra
.686 .762 .909 r
.66441 .28649 .67229 .2963 .68871 .29002 .68088 .27989 Mtetra
.675 .752 .909 r
.68088 .27989 .68871 .29002 .70522 .28403 .69746 .2737 Mtetra
.67 .747 .908 r
.69746 .2737 .70522 .28403 .72185 .27818 .71415 .26772 Mtetra
.667 .744 .908 r
.71415 .26772 .72185 .27818 .73857 .27238 .73094 .26182 Mtetra
.665 .743 .908 r
.73094 .26182 .73857 .27238 .7554 .2666 .74784 .25595 Mtetra
.664 .742 .908 r
.74784 .25595 .7554 .2666 .77232 .26081 .76483 .25009 Mtetra
.76483 .25009 .77232 .26081 .78935 .255 .78193 .24421 Mtetra
.78193 .24421 .78935 .255 .80648 .24916 .79913 .2383 Mtetra
.664 .741 .908 r
.79913 .2383 .80648 .24916 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62673 Mtetra
.2394 .62673 .24954 .63523 .26469 .63064 .2546 .6221 Mtetra
.2546 .6221 .26469 .63064 .27993 .62602 .2699 .61743 Mtetra
.2699 .61743 .27993 .62602 .29526 .62137 .28528 .61273 Mtetra
.28528 .61273 .29526 .62137 .31068 .61669 .30075 .608 Mtetra
.646 .763 .934 r
.30075 .608 .31068 .61669 .32619 .61198 .31632 .60324 Mtetra
.31632 .60324 .32619 .61198 .34179 .60723 .33198 .59845 Mtetra
.647 .763 .934 r
.33198 .59845 .34179 .60723 .35749 .60242 .34773 .5936 Mtetra
.648 .764 .933 r
.34773 .5936 .35749 .60242 .37328 .59753 .36357 .58869 Mtetra
.65 .765 .933 r
.36357 .58869 .37328 .59753 .38916 .59252 .37952 .58368 Mtetra
.653 .767 .933 r
.37952 .58368 .38916 .59252 .40515 .58731 .39556 .57852 Mtetra
.66 .771 .932 r
.39556 .57852 .40515 .58731 .42124 .58172 .4117 .57307 Mtetra
.672 .779 .93 r
.4117 .57307 .42124 .58172 .43743 .57547 .42795 .56713 Mtetra
.693 .793 .927 r
.42795 .56713 .43743 .57547 .45373 .568 .44431 .56028 Mtetra
.73 .816 .919 r
.44431 .56028 .45373 .568 .47014 .55836 .46079 .5518 Mtetra
.786 .851 .9 r
.46079 .5518 .47014 .55836 .48665 .54499 .47736 .54044 Mtetra
.859 .891 .858 r
.47736 .54044 .48665 .54499 .50321 .5257 .49402 .52429 Mtetra
.927 .921 .786 r
.49402 .52429 .50321 .5257 .51974 .49836 .5107 .50104 Mtetra
.967 .929 .694 r
.5107 .50104 .51974 .49836 .53613 .46274 .5273 .46922 Mtetra
.975 .921 .617 r
.5273 .46922 .53613 .46274 .55227 .4225 .54368 .43039 Mtetra
.97 .918 .586 r
.54368 .43039 .55227 .4225 .56818 .3842 .55981 .3901 Mtetra
.965 .933 .622 r
.55981 .3901 .56818 .3842 .58398 .35306 .57576 .3548 Mtetra
.953 .95 .717 r
.57576 .3548 .58398 .35306 .59981 .33029 .59168 .32779 Mtetra
.905 .934 .82 r
.59168 .32779 .59981 .33029 .61576 .31428 .60767 .30857 Mtetra
.831 .883 .881 r
.60767 .30857 .61576 .31428 .63184 .30275 .62379 .29497 Mtetra
.765 .83 .903 r
.62379 .29497 .63184 .30275 .64806 .29388 .64006 .28487 Mtetra
.72 .792 .908 r
.64006 .28487 .64806 .29388 .66441 .28649 .65646 .27677 Mtetra
.694 .769 .909 r
.65646 .27677 .66441 .28649 .68088 .27989 .67298 .26976 Mtetra
.68 .756 .909 r
.67298 .26976 .68088 .27989 .69746 .2737 .68962 .26332 Mtetra
.672 .749 .909 r
.68962 .26332 .69746 .2737 .71415 .26772 .70637 .25717 Mtetra
.668 .745 .908 r
.70637 .25717 .71415 .26772 .73094 .26182 .72323 .25116 Mtetra
.666 .744 .908 r
.72323 .25116 .73094 .26182 .74784 .25595 .74019 .2452 Mtetra
.665 .742 .908 r
.74019 .2452 .74784 .25595 .76483 .25009 .75726 .23926 Mtetra
.664 .742 .908 r
.75726 .23926 .76483 .25009 .78193 .24421 .77443 .2333 Mtetra
.77443 .2333 .78193 .24421 .79913 .2383 .7917 .22732 Mtetra
.664 .741 .908 r
.7917 .22732 .79913 .2383 .81644 .23236 .80908 .22132 Mtetra
.80908 .22132 .81644 .23236 .83385 .22639 .82657 .21528 Mtetra
.646 .762 .934 r
.18391 .63206 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62673 .22915 .61815 Mtetra
.22915 .61815 .2394 .62673 .2546 .6221 .24441 .61346 Mtetra
.24441 .61346 .2546 .6221 .2699 .61743 .25975 .60874 Mtetra
.25975 .60874 .2699 .61743 .28528 .61273 .27519 .60399 Mtetra
.27519 .60399 .28528 .61273 .30075 .608 .29072 .59922 Mtetra
.646 .763 .934 r
.29072 .59922 .30075 .608 .31632 .60324 .30634 .59441 Mtetra
.30634 .59441 .31632 .60324 .33198 .59845 .32205 .58956 Mtetra
.647 .763 .934 r
.32205 .58956 .33198 .59845 .34773 .5936 .33786 .58468 Mtetra
.33786 .58468 .34773 .5936 .36357 .58869 .35376 .57973 Mtetra
.649 .764 .933 r
.35376 .57973 .36357 .58869 .37952 .58368 .36977 .57471 Mtetra
.651 .766 .933 r
.36977 .57471 .37952 .58368 .39556 .57852 .38587 .56957 Mtetra
.656 .769 .932 r
.38587 .56957 .39556 .57852 .4117 .57307 .40207 .56421 Mtetra
.665 .775 .931 r
.40207 .56421 .4117 .57307 .42795 .56713 .41838 .55848 Mtetra
.681 .785 .929 r
.41838 .55848 .42795 .56713 .44431 .56028 .43479 .55208 Mtetra
.709 .803 .923 r
.43479 .55208 .44431 .56028 .46079 .5518 .45132 .54445 Mtetra
.755 .832 .911 r
.45132 .54445 .46079 .5518 .47736 .54044 .46796 .53463 Mtetra
.821 .871 .883 r
.46796 .53463 .47736 .54044 .49402 .52429 .4847 .52105 Mtetra
.895 .909 .826 r
.4847 .52105 .49402 .52429 .5107 .50104 .50151 .50151 Mtetra
.952 .928 .741 r
.50151 .50151 .5107 .50104 .5273 .46922 .51828 .47388 Mtetra
.974 .925 .651 r
.51828 .47388 .5273 .46922 .54368 .43039 .53491 .43791 Mtetra
.973 .918 .594 r
.53491 .43791 .54368 .43039 .55981 .3901 .55128 .3973 Mtetra
.967 .923 .595 r
.55128 .3973 .55981 .3901 .57576 .3548 .56742 .35865 Mtetra
.962 .943 .665 r
.56742 .35865 .57576 .3548 .59168 .32779 .58345 .32721 Mtetra
.934 .948 .772 r
.58345 .32721 .59168 .32779 .60767 .30857 .5995 .30419 Mtetra
.869 .911 .856 r
.5995 .30419 .60767 .30857 .62379 .29497 .61566 .28797 Mtetra
.795 .855 .895 r
.61566 .28797 .62379 .29497 .64006 .28487 .63197 .27625 Mtetra
.74 .809 .907 r
.63197 .27625 .64006 .28487 .65646 .27677 .64842 .26721 Mtetra
.705 .779 .909 r
.64842 .26721 .65646 .27677 .67298 .26976 .665 .25966 Mtetra
.686 .762 .909 r
.665 .25966 .67298 .26976 .68962 .26332 .6817 .2529 Mtetra
.675 .752 .909 r
.6817 .2529 .68962 .26332 .70637 .25717 .69851 .24655 Mtetra
.67 .747 .908 r
.69851 .24655 .70637 .25717 .72323 .25116 .71543 .2404 Mtetra
.667 .744 .908 r
.71543 .2404 .72323 .25116 .74019 .2452 .73247 .23434 Mtetra
.665 .743 .908 r
.73247 .23434 .74019 .2452 .75726 .23926 .7496 .22831 Mtetra
.664 .742 .908 r
.7496 .22831 .75726 .23926 .77443 .2333 .76684 .22228 Mtetra
.76684 .22228 .77443 .2333 .7917 .22732 .78419 .21623 Mtetra
.78419 .21623 .7917 .22732 .80908 .22132 .80164 .21015 Mtetra
.664 .741 .908 r
.80164 .21015 .80908 .22132 .82657 .21528 .8192 .20404 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63206 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .60399 .26499 .59516 Mtetra
.26499 .59516 .27519 .60399 .29072 .59922 .28057 .59033 Mtetra
.28057 .59033 .29072 .59922 .30634 .59441 .29625 .58547 Mtetra
.646 .763 .934 r
.29625 .58547 .30634 .59441 .32205 .58956 .31202 .58058 Mtetra
.31202 .58058 .32205 .58956 .33786 .58468 .32788 .57565 Mtetra
.647 .763 .934 r
.32788 .57565 .33786 .58468 .35376 .57973 .34385 .57066 Mtetra
.648 .764 .933 r
.34385 .57066 .35376 .57973 .36977 .57471 .35991 .56562 Mtetra
.65 .765 .933 r
.35991 .56562 .36977 .57471 .38587 .56957 .37606 .56047 Mtetra
.653 .767 .933 r
.37606 .56047 .38587 .56957 .40207 .56421 .39233 .55516 Mtetra
.66 .771 .932 r
.39233 .55516 .40207 .56421 .41838 .55848 .40869 .54957 Mtetra
.672 .779 .93 r
.40869 .54957 .41838 .55848 .43479 .55208 .42517 .54348 Mtetra
.693 .793 .927 r
.42517 .54348 .43479 .55208 .45132 .54445 .44175 .53647 Mtetra
.73 .816 .919 r
.44175 .53647 .45132 .54445 .46796 .53463 .45846 .52782 Mtetra
.786 .851 .9 r
.45846 .52782 .46796 .53463 .4847 .52105 .47527 .51627 Mtetra
.859 .891 .858 r
.47527 .51627 .4847 .52105 .50151 .50151 .49217 .49989 Mtetra
.928 .922 .786 r
.49217 .49989 .50151 .50151 .51828 .47388 .50909 .47637 Mtetra
.967 .929 .694 r
.50909 .47637 .51828 .47388 .53491 .43791 .52593 .44422 Mtetra
.975 .921 .616 r
.52593 .44422 .53491 .43791 .55128 .3973 .54256 .40503 Mtetra
.97 .918 .586 r
.54256 .40503 .55128 .3973 .56742 .35865 .55893 .36436 Mtetra
.965 .933 .622 r
.55893 .36436 .56742 .35865 .58345 .32721 .57511 .32874 Mtetra
.953 .95 .718 r
.57511 .32874 .58345 .32721 .5995 .30419 .59125 .30145 Mtetra
.905 .934 .82 r
.59125 .30145 .5995 .30419 .61566 .28797 .60746 .282 Mtetra
.831 .883 .88 r
.60746 .282 .61566 .28797 .63197 .27625 .62381 .2682 Mtetra
.765 .83 .903 r
.62381 .2682 .63197 .27625 .64842 .26721 .6403 .25792 Mtetra
.72 .792 .908 r
.6403 .25792 .64842 .26721 .665 .25966 .65693 .24965 Mtetra
.694 .769 .909 r
.65693 .24965 .665 .25966 .6817 .2529 .67369 .24247 Mtetra
.68 .756 .909 r
.67369 .24247 .6817 .2529 .69851 .24655 .69056 .23586 Mtetra
.672 .749 .909 r
.69056 .23586 .69851 .24655 .71543 .2404 .70755 .22955 Mtetra
.668 .745 .908 r
.70755 .22955 .71543 .2404 .73247 .23434 .72465 .22337 Mtetra
.666 .744 .908 r
.72465 .22337 .73247 .23434 .7496 .22831 .74186 .21725 Mtetra
.665 .742 .908 r
.74186 .21725 .7496 .22831 .76684 .22228 .75917 .21113 Mtetra
.664 .742 .908 r
.75917 .21113 .76684 .22228 .78419 .21623 .77659 .20501 Mtetra
.77659 .20501 .78419 .21623 .80164 .21015 .79412 .19886 Mtetra
.664 .741 .908 r
.79412 .19886 .80164 .21015 .8192 .20404 .81176 .19268 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .5959 Mtetra
.22368 .5959 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59516 .25468 .58623 Mtetra
.25468 .58623 .26499 .59516 .28057 .59033 .27032 .58135 Mtetra
.27032 .58135 .28057 .59033 .29625 .58547 .28605 .57644 Mtetra
.646 .763 .934 r
.28605 .57644 .29625 .58547 .31202 .58058 .30187 .57149 Mtetra
.30187 .57149 .31202 .58058 .32788 .57565 .3178 .56651 Mtetra
.647 .763 .934 r
.3178 .56651 .32788 .57565 .34385 .57066 .33382 .56149 Mtetra
.33382 .56149 .34385 .57066 .35991 .56562 .34994 .5564 Mtetra
.649 .764 .933 r
.34994 .5564 .35991 .56562 .37606 .56047 .36615 .55124 Mtetra
.651 .766 .933 r
.36615 .55124 .37606 .56047 .39233 .55516 .38247 .54595 Mtetra
.656 .769 .932 r
.38247 .54595 .39233 .55516 .40869 .54957 .3989 .54044 Mtetra
.665 .775 .931 r
.3989 .54044 .40869 .54957 .42517 .54348 .41543 .53456 Mtetra
.681 .785 .929 r
.41543 .53456 .42517 .54348 .44175 .53647 .43208 .52801 Mtetra
.709 .803 .924 r
.43208 .52801 .44175 .53647 .45846 .52782 .44884 .52021 Mtetra
.755 .832 .911 r
.44884 .52021 .45846 .52782 .47527 .51627 .46572 .51021 Mtetra
.821 .871 .883 r
.46572 .51021 .47527 .51627 .49217 .49989 .4827 .49642 Mtetra
.895 .909 .826 r
.4827 .49642 .49217 .49989 .50909 .47637 .49975 .47663 Mtetra
.952 .928 .741 r
.49975 .47663 .50909 .47637 .52593 .44422 .51677 .44869 Mtetra
.974 .925 .651 r
.51677 .44869 .52593 .44422 .54256 .40503 .53365 .41237 Mtetra
.973 .918 .593 r
.53365 .41237 .54256 .40503 .55893 .36436 .55027 .37138 Mtetra
.967 .924 .595 r
.55027 .37138 .55893 .36436 .57511 .32874 .56664 .33238 Mtetra
.962 .943 .665 r
.56664 .33238 .57511 .32874 .59125 .30145 .5829 .30064 Mtetra
.934 .948 .772 r
.5829 .30064 .59125 .30145 .60746 .282 .59918 .27736 Mtetra
.869 .911 .856 r
.59918 .27736 .60746 .282 .62381 .2682 .61557 .26093 Mtetra
.795 .855 .895 r
.61557 .26093 .62381 .2682 .6403 .25792 .6321 .24902 Mtetra
.74 .809 .907 r
.6321 .24902 .6403 .25792 .65693 .24965 .64878 .2398 Mtetra
.705 .779 .909 r
.64878 .2398 .65693 .24965 .67369 .24247 .66559 .23207 Mtetra
.686 .762 .909 r
.66559 .23207 .67369 .24247 .69056 .23586 .68253 .22514 Mtetra
.675 .752 .909 r
.68253 .22514 .69056 .23586 .70755 .22955 .69959 .21862 Mtetra
.67 .747 .908 r
.69959 .21862 .70755 .22955 .72465 .22337 .71675 .2123 Mtetra
.667 .744 .908 r
.71675 .2123 .72465 .22337 .74186 .21725 .73403 .20607 Mtetra
.665 .743 .908 r
.73403 .20607 .74186 .21725 .75917 .21113 .75142 .19987 Mtetra
.664 .742 .908 r
.75142 .19987 .75917 .21113 .77659 .20501 .76891 .19367 Mtetra
.76891 .19367 .77659 .20501 .79412 .19886 .78652 .18744 Mtetra
.78652 .18744 .79412 .19886 .81176 .19268 .80423 .18119 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .5959 .21314 .58698 Mtetra
.21314 .58698 .22368 .5959 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58623 .24425 .5772 Mtetra
.24425 .5772 .25468 .58623 .27032 .58135 .25994 .57227 Mtetra
.25994 .57227 .27032 .58135 .28605 .57644 .27573 .5673 Mtetra
.27573 .5673 .28605 .57644 .30187 .57149 .29162 .56231 Mtetra
.646 .763 .934 r
.29162 .56231 .30187 .57149 .3178 .56651 .3076 .55727 Mtetra
.3076 .55727 .3178 .56651 .33382 .56149 .32368 .5522 Mtetra
.647 .763 .934 r
.32368 .5522 .33382 .56149 .34994 .5564 .33985 .54707 Mtetra
.648 .764 .933 r
.33985 .54707 .34994 .5564 .36615 .55124 .35613 .54188 Mtetra
.65 .765 .933 r
.35613 .54188 .36615 .55124 .38247 .54595 .37251 .53659 Mtetra
.653 .767 .933 r
.37251 .53659 .38247 .54595 .3989 .54044 .389 .53113 Mtetra
.66 .771 .932 r
.389 .53113 .3989 .54044 .41543 .53456 .40559 .52539 Mtetra
.672 .779 .93 r
.40559 .52539 .41543 .53456 .43208 .52801 .4223 .51914 Mtetra
.693 .793 .927 r
.4223 .51914 .43208 .52801 .44884 .52021 .43912 .51197 Mtetra
.73 .816 .919 r
.43912 .51197 .44884 .52021 .46572 .51021 .45606 .50314 Mtetra
.786 .851 .9 r
.45606 .50314 .46572 .51021 .4827 .49642 .47312 .49139 Mtetra
.859 .891 .859 r
.47312 .49139 .4827 .49642 .49975 .47663 .49026 .47478 Mtetra
.928 .922 .786 r
.49026 .47478 .49975 .47663 .51677 .44869 .50744 .45098 Mtetra
.967 .929 .694 r
.50744 .45098 .51677 .44869 .53365 .41237 .52453 .41849 Mtetra
.975 .921 .616 r
.52453 .41849 .53365 .41237 .55027 .37138 .54141 .37893 Mtetra
.97 .918 .586 r
.54141 .37893 .55027 .37138 .56664 .33238 .55802 .33789 Mtetra
.965 .933 .622 r
.55802 .33789 .56664 .33238 .5829 .30064 .57443 .30194 Mtetra
.953 .95 .718 r
.57443 .30194 .5829 .30064 .59918 .27736 .5908 .27437 Mtetra
.905 .934 .82 r
.5908 .27437 .59918 .27736 .61557 .26093 .60725 .25469 Mtetra
.831 .883 .88 r
.60725 .25469 .61557 .26093 .6321 .24902 .62383 .24068 Mtetra
.765 .83 .903 r
.62383 .24068 .6321 .24902 .64878 .2398 .64055 .23021 Mtetra
.72 .792 .908 r
.64055 .23021 .64878 .2398 .66559 .23207 .65742 .22176 Mtetra
.694 .769 .909 r
.65742 .22176 .66559 .23207 .68253 .22514 .67441 .2144 Mtetra
.68 .756 .909 r
.67441 .2144 .68253 .22514 .69959 .21862 .69153 .20763 Mtetra
.672 .749 .909 r
.69153 .20763 .69959 .21862 .71675 .2123 .70877 .20114 Mtetra
.668 .745 .908 r
.70877 .20114 .71675 .2123 .73403 .20607 .72612 .19479 Mtetra
.666 .744 .908 r
.72612 .19479 .73403 .20607 .75142 .19987 .74358 .18849 Mtetra
.665 .742 .908 r
.74358 .18849 .75142 .19987 .76891 .19367 .76114 .1822 Mtetra
.664 .742 .908 r
.76114 .1822 .76891 .19367 .78652 .18744 .77882 .1759 Mtetra
.77882 .1759 .78652 .18744 .80423 .18119 .79661 .16957 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .5772 .23371 .56807 Mtetra
.23371 .56807 .24425 .5772 .25994 .57227 .24946 .56309 Mtetra
.24946 .56309 .25994 .57227 .27573 .5673 .2653 .55806 Mtetra
.2653 .55806 .27573 .5673 .29162 .56231 .28124 .55301 Mtetra
.646 .763 .934 r
.28124 .55301 .29162 .56231 .3076 .55727 .29728 .54792 Mtetra
.29728 .54792 .3076 .55727 .32368 .5522 .31342 .5428 Mtetra
.647 .763 .934 r
.31342 .5428 .32368 .5522 .33985 .54707 .32966 .53763 Mtetra
.32966 .53763 .33985 .54707 .35613 .54188 .346 .5324 Mtetra
.649 .764 .933 r
.346 .5324 .35613 .54188 .37251 .53659 .36244 .52708 Mtetra
.651 .766 .933 r
.36244 .52708 .37251 .53659 .389 .53113 .37898 .52164 Mtetra
.656 .769 .932 r
.37898 .52164 .389 .53113 .40559 .52539 .39564 .51599 Mtetra
.665 .775 .931 r
.39564 .51599 .40559 .52539 .4223 .51914 .4124 .50995 Mtetra
.681 .785 .929 r
.4124 .50995 .4223 .51914 .43912 .51197 .42929 .50323 Mtetra
.709 .803 .924 r
.42929 .50323 .43912 .51197 .45606 .50314 .44629 .49526 Mtetra
.755 .832 .911 r
.44629 .49526 .45606 .50314 .47312 .49139 .46341 .48507 Mtetra
.821 .871 .883 r
.46341 .48507 .47312 .49139 .49026 .47478 .48064 .47107 Mtetra
.896 .909 .826 r
.48064 .47107 .49026 .47478 .50744 .45098 .49794 .45102 Mtetra
.952 .928 .741 r
.49794 .45102 .50744 .45098 .52453 .41849 .51522 .42276 Mtetra
.974 .925 .651 r
.51522 .42276 .52453 .41849 .54141 .37893 .53235 .38608 Mtetra
.973 .918 .593 r
.53235 .38608 .54141 .37893 .55802 .33789 .54922 .34472 Mtetra
.967 .924 .595 r
.54922 .34472 .55802 .33789 .57443 .30194 .56584 .30536 Mtetra
.962 .943 .665 r
.56584 .30536 .57443 .30194 .5908 .27437 .58233 .2733 Mtetra
.934 .947 .773 r
.58233 .2733 .5908 .27437 .60725 .25469 .59884 .24977 Mtetra
.869 .911 .856 r
.59884 .24977 .60725 .25469 .62383 .24068 .61547 .23312 Mtetra
.795 .855 .895 r
.61547 .23312 .62383 .24068 .64055 .23021 .63224 .22101 Mtetra
.74 .809 .907 r
.63224 .22101 .64055 .23021 .65742 .22176 .64915 .2116 Mtetra
.705 .779 .909 r
.64915 .2116 .65742 .22176 .67441 .2144 .66621 .2037 Mtetra
.686 .762 .909 r
.66621 .2037 .67441 .2144 .69153 .20763 .68339 .19659 Mtetra
.675 .752 .909 r
.68339 .19659 .69153 .20763 .70877 .20114 .70069 .18989 Mtetra
.67 .747 .908 r
.70069 .18989 .70877 .20114 .72612 .19479 .71811 .1834 Mtetra
.667 .744 .908 r
.71811 .1834 .72612 .19479 .74358 .18849 .73564 .17699 Mtetra
.665 .743 .908 r
.73564 .17699 .74358 .18849 .76114 .1822 .75329 .17061 Mtetra
.664 .742 .908 r
.75329 .17061 .76114 .1822 .77882 .1759 .77104 .16422 Mtetra
.77104 .16422 .77882 .1759 .79661 .16957 .78891 .15782 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56807 .22305 .55884 Mtetra
.22305 .55884 .23371 .56807 .24946 .56309 .23885 .5538 Mtetra
.23885 .5538 .24946 .56309 .2653 .55806 .25476 .54872 Mtetra
.25476 .54872 .2653 .55806 .28124 .55301 .27075 .54361 Mtetra
.27075 .54361 .28124 .55301 .29728 .54792 .28685 .53847 Mtetra
.646 .763 .934 r
.28685 .53847 .29728 .54792 .31342 .5428 .30305 .53329 Mtetra
.30305 .53329 .31342 .5428 .32966 .53763 .31935 .52807 Mtetra
.647 .763 .934 r
.31935 .52807 .32966 .53763 .346 .5324 .33575 .52279 Mtetra
.648 .764 .933 r
.33575 .52279 .346 .5324 .36244 .52708 .35225 .51745 Mtetra
.65 .765 .933 r
.35225 .51745 .36244 .52708 .37898 .52164 .36886 .512 Mtetra
.653 .767 .933 r
.36886 .512 .37898 .52164 .39564 .51599 .38557 .50639 Mtetra
.66 .771 .932 r
.38557 .50639 .39564 .51599 .4124 .50995 .4024 .50049 Mtetra
.672 .779 .93 r
.4024 .50049 .4124 .50995 .42929 .50323 .41934 .49408 Mtetra
.693 .793 .927 r
.41934 .49408 .42929 .50323 .44629 .49526 .43641 .48674 Mtetra
.73 .816 .919 r
.43641 .48674 .44629 .49526 .46341 .48507 .45359 .47773 Mtetra
.786 .851 .9 r
.45359 .47773 .46341 .48507 .48064 .47107 .4709 .46577 Mtetra
.859 .892 .859 r
.4709 .46577 .48064 .47107 .49794 .45102 .4883 .44893 Mtetra
.928 .922 .786 r
.4883 .44893 .49794 .45102 .51522 .42276 .50574 .42484 Mtetra
.967 .929 .694 r
.50574 .42484 .51522 .42276 .53235 .38608 .52309 .39201 Mtetra
.975 .921 .616 r
.52309 .39201 .53235 .38608 .54922 .34472 .54023 .35206 Mtetra
.97 .918 .586 r
.54023 .35206 .54922 .34472 .56584 .30536 .55708 .31065 Mtetra
.965 .933 .623 r
.55708 .31065 .56584 .30536 .58233 .2733 .57374 .27436 Mtetra
.953 .95 .718 r
.57374 .27436 .58233 .2733 .59884 .24977 .59035 .24651 Mtetra
.905 .934 .82 r
.59035 .24651 .59884 .24977 .61547 .23312 .60703 .22659 Mtetra
.831 .883 .88 r
.60703 .22659 .61547 .23312 .63224 .22101 .62384 .21237 Mtetra
.765 .83 .903 r
.62384 .21237 .63224 .22101 .64915 .2116 .64081 .2017 Mtetra
.72 .792 .908 r
.64081 .2017 .64915 .2116 .66621 .2037 .65792 .19307 Mtetra
.694 .769 .909 r
.65792 .19307 .66621 .2037 .68339 .19659 .67516 .18553 Mtetra
.68 .756 .909 r
.67516 .18553 .68339 .19659 .70069 .18989 .69253 .17858 Mtetra
.672 .749 .909 r
.69253 .17858 .70069 .18989 .71811 .1834 .71002 .17191 Mtetra
.668 .745 .908 r
.71002 .17191 .71811 .1834 .73564 .17699 .72762 .16537 Mtetra
.666 .744 .908 r
.72762 .16537 .73564 .17699 .75329 .17061 .74534 .15889 Mtetra
.665 .742 .908 r
.74534 .15889 .75329 .17061 .77104 .16422 .76317 .15242 Mtetra
.664 .742 .908 r
.76317 .15242 .77104 .16422 .78891 .15782 .78112 .14593 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .5538 .22813 .5444 Mtetra
.22813 .5444 .23885 .5538 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27075 .54361 .26015 .53411 Mtetra
.26015 .53411 .27075 .54361 .28685 .53847 .2763 .52891 Mtetra
.646 .763 .934 r
.2763 .52891 .28685 .53847 .30305 .53329 .29256 .52367 Mtetra
.29256 .52367 .30305 .53329 .31935 .52807 .30892 .51839 Mtetra
.647 .763 .934 r
.30892 .51839 .31935 .52807 .33575 .52279 .32538 .51307 Mtetra
.32538 .51307 .33575 .52279 .35225 .51745 .34194 .50769 Mtetra
.649 .764 .933 r
.34194 .50769 .35225 .51745 .36886 .512 .35861 .50222 Mtetra
.651 .766 .933 r
.35861 .50222 .36886 .512 .38557 .50639 .37539 .49662 Mtetra
.656 .769 .933 r
.37539 .49662 .38557 .50639 .4024 .50049 .39228 .49081 Mtetra
.665 .775 .931 r
.39228 .49081 .4024 .50049 .41934 .49408 .40929 .48461 Mtetra
.681 .785 .929 r
.40929 .48461 .41934 .49408 .43641 .48674 .42641 .47771 Mtetra
.709 .803 .924 r
.42641 .47771 .43641 .48674 .45359 .47773 .44366 .46957 Mtetra
.755 .832 .911 r
.44366 .46957 .45359 .47773 .4709 .46577 .46103 .45918 Mtetra
.821 .871 .883 r
.46103 .45918 .4709 .46577 .4883 .44893 .47852 .44495 Mtetra
.896 .909 .826 r
.47852 .44495 .4883 .44893 .50574 .42484 .49608 .42464 Mtetra
.952 .929 .74 r
.49608 .42464 .50574 .42484 .52309 .39201 .51363 .39607 Mtetra
.974 .926 .651 r
.51363 .39607 .52309 .39201 .54023 .35206 .53102 .35902 Mtetra
.973 .918 .593 r
.53102 .35902 .54023 .35206 .55708 .31065 .54815 .31727 Mtetra
.967 .924 .596 r
.54815 .31727 .55708 .31065 .57374 .27436 .56501 .27755 Mtetra
.962 .943 .666 r
.56501 .27755 .57374 .27436 .59035 .24651 .58175 .24518 Mtetra
.934 .947 .773 r
.58175 .24518 .59035 .24651 .60703 .22659 .5985 .22139 Mtetra
.869 .911 .856 r
.5985 .22139 .60703 .22659 .62384 .21237 .61537 .2045 Mtetra
.795 .855 .895 r
.61537 .2045 .62384 .21237 .64081 .2017 .63238 .19219 Mtetra
.74 .809 .906 r
.63238 .19219 .64081 .2017 .65792 .19307 .64954 .18259 Mtetra
.705 .779 .909 r
.64954 .18259 .65792 .19307 .67516 .18553 .66684 .1745 Mtetra
.686 .762 .909 r
.66684 .1745 .67516 .18553 .69253 .17858 .68428 .16721 Mtetra
.675 .752 .909 r
.68428 .16721 .69253 .17858 .71002 .17191 .70183 .16033 Mtetra
.67 .747 .908 r
.70183 .16033 .71002 .17191 .72762 .16537 .71951 .15365 Mtetra
.667 .744 .908 r
.71951 .15365 .72762 .16537 .74534 .15889 .7373 .14705 Mtetra
.665 .743 .908 r
.7373 .14705 .74534 .15889 .76317 .15242 .75521 .14049 Mtetra
.664 .742 .908 r
.75521 .14049 .76317 .15242 .78112 .14593 .77323 .13391 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54006 Mtetra
.20137 .54006 .21227 .54951 .22813 .5444 .21728 .53491 Mtetra
.21728 .53491 .22813 .5444 .24409 .53927 .2333 .52971 Mtetra
.2333 .52971 .24409 .53927 .26015 .53411 .24942 .52449 Mtetra
.24942 .52449 .26015 .53411 .2763 .52891 .26563 .51923 Mtetra
.26563 .51923 .2763 .52891 .29256 .52367 .28195 .51394 Mtetra
.646 .763 .934 r
.28195 .51394 .29256 .52367 .30892 .51839 .29837 .5086 Mtetra
.29837 .5086 .30892 .51839 .32538 .51307 .31489 .50323 Mtetra
.647 .763 .934 r
.31489 .50323 .32538 .51307 .34194 .50769 .33152 .4978 Mtetra
.648 .764 .933 r
.33152 .4978 .34194 .50769 .35861 .50222 .34825 .4923 Mtetra
.65 .765 .933 r
.34825 .4923 .35861 .50222 .37539 .49662 .36509 .48669 Mtetra
.653 .767 .933 r
.36509 .48669 .37539 .49662 .39228 .49081 .38204 .48092 Mtetra
.66 .771 .932 r
.38204 .48092 .39228 .49081 .40929 .48461 .39911 .47486 Mtetra
.672 .779 .93 r
.39911 .47486 .40929 .48461 .42641 .47771 .4163 .46827 Mtetra
.693 .793 .927 r
.4163 .46827 .42641 .47771 .44366 .46957 .43361 .46076 Mtetra
.73 .817 .919 r
.43361 .46076 .44366 .46957 .46103 .45918 .45105 .45155 Mtetra
.786 .851 .9 r
.45105 .45155 .46103 .45918 .47852 .44495 .46861 .43938 Mtetra
.859 .892 .859 r
.46861 .43938 .47852 .44495 .49608 .42464 .48628 .42229 Mtetra
.928 .922 .786 r
.48628 .42229 .49608 .42464 .51363 .39607 .50398 .39791 Mtetra
.967 .929 .693 r
.50398 .39791 .51363 .39607 .53102 .35902 .5216 .36473 Mtetra
.975 .921 .616 r
.5216 .36473 .53102 .35902 .54815 .31727 .53901 .3244 Mtetra
.97 .918 .586 r
.53901 .3244 .54815 .31727 .56501 .27755 .55612 .28261 Mtetra
.965 .933 .623 r
.55612 .28261 .56501 .27755 .58175 .24518 .57303 .24598 Mtetra
.953 .949 .718 r
.57303 .24598 .58175 .24518 .5985 .22139 .58988 .21784 Mtetra
.905 .933 .82 r
.58988 .21784 .5985 .22139 .61537 .2045 .6068 .19767 Mtetra
.831 .883 .88 r
.6068 .19767 .61537 .2045 .63238 .19219 .62386 .18324 Mtetra
.765 .83 .902 r
.62386 .18324 .63238 .19219 .64954 .18259 .64107 .17237 Mtetra
.72 .792 .908 r
.64107 .17237 .64954 .18259 .66684 .1745 .65843 .16354 Mtetra
.694 .769 .909 r
.65843 .16354 .66684 .1745 .68428 .16721 .67593 .15582 Mtetra
.68 .756 .909 r
.67593 .15582 .68428 .16721 .70183 .16033 .69356 .14867 Mtetra
.672 .749 .909 r
.69356 .14867 .70183 .16033 .71951 .15365 .7113 .14181 Mtetra
.668 .745 .908 r
.7113 .14181 .71951 .15365 .7373 .14705 .72917 .13509 Mtetra
.666 .744 .908 r
.72917 .13509 .7373 .14705 .75521 .14049 .74716 .12842 Mtetra
.665 .742 .908 r
.74716 .12842 .75521 .14049 .77323 .13391 .76526 .12176 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54006 .19034 .53052 Mtetra
.19034 .53052 .20137 .54006 .21728 .53491 .20631 .5253 Mtetra
.20631 .5253 .21728 .53491 .2333 .52971 .22239 .52005 Mtetra
.22239 .52005 .2333 .52971 .24942 .52449 .23856 .51476 Mtetra
.23856 .51476 .24942 .52449 .26563 .51923 .25484 .50944 Mtetra
.25484 .50944 .26563 .51923 .28195 .51394 .27121 .50409 Mtetra
.646 .763 .934 r
.27121 .50409 .28195 .51394 .29837 .5086 .28769 .4987 Mtetra
.28769 .4987 .29837 .5086 .31489 .50323 .30428 .49327 Mtetra
.647 .763 .934 r
.30428 .49327 .31489 .50323 .33152 .4978 .32097 .48779 Mtetra
.32097 .48779 .33152 .4978 .34825 .4923 .33777 .48224 Mtetra
.649 .764 .933 r
.33777 .48224 .34825 .4923 .36509 .48669 .35467 .47661 Mtetra
.651 .766 .933 r
.35467 .47661 .36509 .48669 .38204 .48092 .37169 .47085 Mtetra
.656 .769 .933 r
.37169 .47085 .38204 .48092 .39911 .47486 .38882 .46487 Mtetra
.665 .775 .931 r
.38882 .46487 .39911 .47486 .4163 .46827 .40607 .4585 Mtetra
.681 .785 .929 r
.40607 .4585 .4163 .46827 .43361 .46076 .42345 .45143 Mtetra
.709 .804 .924 r
.42345 .45143 .43361 .46076 .45105 .45155 .44095 .4431 Mtetra
.755 .833 .911 r
.44095 .4431 .45105 .45155 .46861 .43938 .45858 .43251 Mtetra
.821 .872 .883 r
.45858 .43251 .46861 .43938 .48628 .42229 .47634 .41805 Mtetra
.896 .91 .826 r
.47634 .41805 .48628 .42229 .50398 .39791 .49417 .39746 Mtetra
.952 .929 .74 r
.49417 .39746 .50398 .39791 .5216 .36473 .51198 .36856 Mtetra
.974 .926 .65 r
.51198 .36856 .5216 .36473 .53901 .3244 .52965 .33114 Mtetra
.973 .918 .593 r
.52965 .33114 .53901 .3244 .55612 .28261 .54704 .289 Mtetra
.967 .924 .596 r
.54704 .289 .55612 .28261 .57303 .24598 .56416 .24892 Mtetra
.962 .943 .666 r
.56416 .24892 .57303 .24598 .58988 .21784 .58115 .21623 Mtetra
.934 .947 .773 r
.58115 .21623 .58988 .21784 .6068 .19767 .59815 .19217 Mtetra
.869 .91 .856 r
.59815 .19217 .6068 .19767 .62386 .18324 .61526 .17505 Mtetra
.795 .855 .895 r
.61526 .17505 .62386 .18324 .64107 .17237 .63252 .16253 Mtetra
.74 .808 .906 r
.63252 .16253 .64107 .17237 .65843 .16354 .64994 .15273 Mtetra
.705 .779 .909 r
.64994 .15273 .65843 .16354 .67593 .15582 .66749 .14444 Mtetra
.686 .762 .909 r
.66749 .14444 .67593 .15582 .69356 .14867 .68519 .13696 Mtetra
.675 .752 .909 r
.68519 .13696 .69356 .14867 .7113 .14181 .70301 .12989 Mtetra
.67 .747 .908 r
.70301 .12989 .7113 .14181 .72917 .13509 .72095 .12301 Mtetra
.667 .744 .908 r
.72095 .12301 .72917 .13509 .74716 .12842 .73901 .11623 Mtetra
.665 .743 .908 r
.73901 .11623 .74716 .12842 .76526 .12176 .75719 .10946 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52005 .21135 .51027 Mtetra
.21135 .51027 .22239 .52005 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50944 .24392 .49954 Mtetra
.24392 .49954 .25484 .50944 .27121 .50409 .26036 .49413 Mtetra
.26036 .49413 .27121 .50409 .28769 .4987 .2769 .48868 Mtetra
.646 .763 .934 r
.2769 .48868 .28769 .4987 .30428 .49327 .29354 .48318 Mtetra
.29354 .48318 .30428 .49327 .32097 .48779 .3103 .47765 Mtetra
.647 .763 .934 r
.3103 .47765 .32097 .48779 .33777 .48224 .32716 .47206 Mtetra
.648 .764 .933 r
.32716 .47206 .33777 .48224 .35467 .47661 .34413 .46639 Mtetra
.65 .765 .933 r
.34413 .46639 .35467 .47661 .37169 .47085 .36121 .46062 Mtetra
.653 .767 .933 r
.36121 .46062 .37169 .47085 .38882 .46487 .37841 .45468 Mtetra
.66 .771 .932 r
.37841 .45468 .38882 .46487 .40607 .4585 .39573 .44844 Mtetra
.672 .779 .93 r
.39573 .44844 .40607 .4585 .42345 .45143 .41316 .44168 Mtetra
.693 .793 .927 r
.41316 .44168 .42345 .45143 .44095 .4431 .43073 .43398 Mtetra
.73 .817 .919 r
.43073 .43398 .44095 .4431 .45858 .43251 .44843 .42458 Mtetra
.786 .851 .9 r
.44843 .42458 .45858 .43251 .47634 .41805 .46626 .41219 Mtetra
.859 .892 .859 r
.46626 .41219 .47634 .41805 .49417 .39746 .4842 .39484 Mtetra
.928 .922 .786 r
.4842 .39484 .49417 .39746 .51198 .36856 .50217 .37016 Mtetra
.967 .929 .693 r
.50217 .37016 .51198 .36856 .52965 .33114 .52007 .33663 Mtetra
.975 .921 .616 r
.52007 .33663 .52965 .33114 .54704 .289 .53775 .29591 Mtetra
.97 .918 .586 r
.53775 .29591 .54704 .289 .56416 .24892 .55513 .25374 Mtetra
.966 .933 .623 r
.55513 .25374 .56416 .24892 .58115 .21623 .57229 .21676 Mtetra
.953 .949 .719 r
.57229 .21676 .58115 .21623 .59815 .19217 .5894 .18832 Mtetra
.905 .933 .82 r
.5894 .18832 .59815 .19217 .61526 .17505 .60657 .1679 Mtetra
.831 .882 .88 r
.60657 .1679 .61526 .17505 .63252 .16253 .62388 .15324 Mtetra
.765 .829 .902 r
.62388 .15324 .63252 .16253 .64994 .15273 .64135 .14217 Mtetra
.72 .792 .908 r
.64135 .14217 .64994 .15273 .66749 .14444 .65896 .13314 Mtetra
.694 .769 .909 r
.65896 .13314 .66749 .14444 .68519 .13696 .67672 .12522 Mtetra
.68 .756 .909 r
.67672 .12522 .68519 .13696 .70301 .12989 .69461 .11788 Mtetra
.672 .749 .909 r
.69461 .11788 .70301 .12989 .72095 .12301 .71263 .11082 Mtetra
.668 .745 .908 r
.71263 .11082 .72095 .12301 .73901 .11623 .73077 .1039 Mtetra
.666 .744 .908 r
.73077 .1039 .73901 .11623 .75719 .10946 .74903 .09703 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50038 Mtetra
.20018 .50038 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49954 .23287 .48953 Mtetra
.23287 .48953 .24392 .49954 .26036 .49413 .24937 .48405 Mtetra
.24937 .48405 .26036 .49413 .2769 .48868 .26597 .47853 Mtetra
.646 .763 .934 r
.26597 .47853 .2769 .48868 .29354 .48318 .28268 .47298 Mtetra
.28268 .47298 .29354 .48318 .3103 .47765 .2995 .46739 Mtetra
.647 .763 .934 r
.2995 .46739 .3103 .47765 .32716 .47206 .31643 .46174 Mtetra
.31643 .46174 .32716 .47206 .34413 .46639 .33346 .45603 Mtetra
.649 .764 .933 r
.33346 .45603 .34413 .46639 .36121 .46062 .35061 .45023 Mtetra
.651 .766 .933 r
.35061 .45023 .36121 .46062 .37841 .45468 .36788 .4443 Mtetra
.656 .769 .933 r
.36788 .4443 .37841 .45468 .39573 .44844 .38526 .43814 Mtetra
.665 .775 .931 r
.38526 .43814 .39573 .44844 .41316 .44168 .40276 .43159 Mtetra
.681 .785 .929 r
.40276 .43159 .41316 .44168 .43073 .43398 .42039 .42434 Mtetra
.709 .804 .924 r
.42039 .42434 .43073 .43398 .44843 .42458 .43816 .41581 Mtetra
.755 .833 .911 r
.43816 .41581 .44843 .42458 .46626 .41219 .45606 .40501 Mtetra
.821 .872 .883 r
.45606 .40501 .46626 .41219 .4842 .39484 .47408 .39031 Mtetra
.896 .91 .826 r
.47408 .39031 .4842 .39484 .50217 .37016 .49219 .36944 Mtetra
.952 .929 .74 r
.49219 .36944 .50217 .37016 .52007 .33663 .51029 .34022 Mtetra
.974 .926 .65 r
.51029 .34022 .52007 .33663 .53775 .29591 .52823 .30242 Mtetra
.973 .918 .593 r
.52823 .30242 .53775 .29591 .55513 .25374 .5459 .25988 Mtetra
.967 .924 .596 r
.5459 .25988 .55513 .25374 .57229 .21676 .56329 .21943 Mtetra
.962 .943 .666 r
.56329 .21943 .57229 .21676 .5894 .18832 .58053 .18642 Mtetra
.934 .947 .773 r
.58053 .18642 .5894 .18832 .60657 .1679 .59779 .16209 Mtetra
.869 .91 .856 r
.59779 .16209 .60657 .1679 .62388 .15324 .61515 .14473 Mtetra
.795 .854 .894 r
.61515 .14473 .62388 .15324 .64135 .14217 .63267 .13199 Mtetra
.74 .808 .906 r
.63267 .13199 .64135 .14217 .65896 .13314 .65034 .12198 Mtetra
.705 .779 .909 r
.65034 .12198 .65896 .13314 .67672 .12522 .66816 .11349 Mtetra
.686 .762 .909 r
.66816 .11349 .67672 .12522 .69461 .11788 .68612 .1058 Mtetra
.675 .752 .909 r
.68612 .1058 .69461 .11788 .71263 .11082 .70421 .09853 Mtetra
.67 .747 .908 r
.70421 .09853 .71263 .11082 .73077 .1039 .72243 .09146 Mtetra
.667 .744 .908 r
.72243 .09146 .73077 .1039 .74903 .09703 .74077 .08447 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50038 .18889 .49037 Mtetra
.18889 .49037 .20018 .50038 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48953 .2217 .47939 Mtetra
.2217 .47939 .23287 .48953 .24937 .48405 .23826 .47385 Mtetra
.23826 .47385 .24937 .48405 .26597 .47853 .25492 .46827 Mtetra
.25492 .46827 .26597 .47853 .28268 .47298 .2717 .46266 Mtetra
.646 .763 .934 r
.2717 .46266 .28268 .47298 .2995 .46739 .28858 .457 Mtetra
.28858 .457 .2995 .46739 .31643 .46174 .30557 .45129 Mtetra
.647 .763 .934 r
.30557 .45129 .31643 .46174 .33346 .45603 .32267 .44553 Mtetra
.648 .764 .933 r
.32267 .44553 .33346 .45603 .35061 .45023 .33989 .43969 Mtetra
.65 .765 .933 r
.33989 .43969 .35061 .45023 .36788 .4443 .35722 .43375 Mtetra
.653 .767 .933 r
.35722 .43375 .36788 .4443 .38526 .43814 .37467 .42763 Mtetra
.66 .771 .932 r
.37467 .42763 .38526 .43814 .40276 .43159 .39224 .42121 Mtetra
.672 .779 .93 r
.39224 .42121 .40276 .43159 .42039 .42434 .40993 .41427 Mtetra
.693 .793 .927 r
.40993 .41427 .42039 .42434 .43816 .41581 .42776 .40638 Mtetra
.73 .817 .919 r
.42776 .40638 .43816 .41581 .45606 .40501 .44573 .39677 Mtetra
.786 .851 .9 r
.44573 .39677 .45606 .40501 .47408 .39031 .46383 .38415 Mtetra
.859 .892 .859 r
.46383 .38415 .47408 .39031 .49219 .36944 .48205 .36654 Mtetra
.928 .923 .786 r
.48205 .36654 .49219 .36944 .51029 .34022 .50031 .34155 Mtetra
.967 .929 .693 r
.50031 .34155 .51029 .34022 .52823 .30242 .51849 .30766 Mtetra
.975 .921 .615 r
.51849 .30766 .52823 .30242 .5459 .25988 .53645 .26655 Mtetra
.97 .918 .586 r
.53645 .26655 .5459 .25988 .56329 .21943 .55411 .22399 Mtetra
.966 .933 .624 r
.55411 .22399 .56329 .21943 .58053 .18642 .57154 .18666 Mtetra
.953 .949 .719 r
.57154 .18666 .58053 .18642 .59779 .16209 .5889 .15792 Mtetra
.905 .933 .82 r
.5889 .15792 .59779 .16209 .61515 .14473 .60633 .13724 Mtetra
.831 .882 .88 r
.60633 .13724 .61515 .14473 .63267 .13199 .6239 .12235 Mtetra
.765 .829 .902 r
.6239 .12235 .63267 .13199 .65034 .12198 .64163 .11106 Mtetra
.72 .792 .908 r
.64163 .11106 .65034 .12198 .66816 .11349 .65951 .10182 Mtetra
.694 .769 .909 r
.65951 .10182 .66816 .11349 .68612 .1058 .67754 .0937 Mtetra
.68 .756 .909 r
.67754 .0937 .68612 .1058 .70421 .09853 .6957 .08615 Mtetra
.672 .749 .909 r
.6957 .08615 .70421 .09853 .72243 .09146 .71399 .07889 Mtetra
.668 .745 .908 r
.71399 .07889 .72243 .09146 .74077 .08447 .73241 .07177 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47385 .22701 .46353 Mtetra
.22701 .46353 .23826 .47385 .25492 .46827 .24374 .45789 Mtetra
.24374 .45789 .25492 .46827 .2717 .46266 .26058 .45221 Mtetra
.646 .763 .934 r
.26058 .45221 .2717 .46266 .28858 .457 .27752 .44648 Mtetra
.27752 .44648 .28858 .457 .30557 .45129 .29458 .44072 Mtetra
.647 .763 .934 r
.29458 .44072 .30557 .45129 .32267 .44553 .31175 .4349 Mtetra
.31175 .4349 .32267 .44553 .33989 .43969 .32903 .42901 Mtetra
.649 .764 .933 r
.32903 .42901 .33989 .43969 .35722 .43375 .34643 .42304 Mtetra
.651 .766 .933 r
.34643 .42304 .35722 .43375 .37467 .42763 .36395 .41692 Mtetra
.656 .769 .933 r
.36395 .41692 .37467 .42763 .39224 .42121 .38158 .41059 Mtetra
.665 .775 .931 r
.38158 .41059 .39224 .42121 .40993 .41427 .39935 .40385 Mtetra
.681 .785 .929 r
.39935 .40385 .40993 .41427 .42776 .40638 .41724 .3964 Mtetra
.709 .804 .924 r
.41724 .3964 .42776 .40638 .44573 .39677 .43528 .38767 Mtetra
.755 .833 .911 r
.43528 .38767 .44573 .39677 .46383 .38415 .45345 .37665 Mtetra
.821 .872 .883 r
.45345 .37665 .46383 .38415 .48205 .36654 .47176 .3617 Mtetra
.896 .91 .826 r
.47176 .3617 .48205 .36654 .50031 .34155 .49015 .34055 Mtetra
.952 .929 .74 r
.49015 .34055 .50031 .34155 .51849 .30766 .50854 .31099 Mtetra
.974 .926 .65 r
.50854 .31099 .51849 .30766 .53645 .26655 .52677 .27281 Mtetra
.973 .918 .593 r
.52677 .27281 .53645 .26655 .55411 .22399 .54473 .22987 Mtetra
.967 .924 .596 r
.54473 .22987 .55411 .22399 .57154 .18666 .56239 .18904 Mtetra
.962 .943 .667 r
.56239 .18904 .57154 .18666 .5889 .15792 .5799 .15571 Mtetra
.934 .947 .773 r
.5799 .15571 .5889 .15792 .60633 .13724 .59741 .13109 Mtetra
.869 .91 .856 r
.59741 .13109 .60633 .13724 .6239 .12235 .61504 .11349 Mtetra
.795 .854 .894 r
.61504 .11349 .6239 .12235 .64163 .11106 .63282 .10052 Mtetra
.74 .808 .906 r
.63282 .10052 .64163 .11106 .65951 .10182 .65076 .0903 Mtetra
.705 .779 .909 r
.65076 .0903 .65951 .10182 .67754 .0937 .66886 .08159 Mtetra
.686 .762 .909 r
.66886 .08159 .67754 .0937 .6957 .08615 .68709 .0737 Mtetra
.675 .752 .909 r
.68709 .0737 .6957 .08615 .71399 .07889 .70546 .06622 Mtetra
.67 .747 .908 r
.70546 .06622 .71399 .07889 .73241 .07177 .72396 .05893 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45789 .23242 .44738 Mtetra
.23242 .44738 .24374 .45789 .26058 .45221 .24932 .44163 Mtetra
.24932 .44163 .26058 .45221 .27752 .44648 .26634 .43584 Mtetra
.646 .763 .934 r
.26634 .43584 .27752 .44648 .29458 .44072 .28346 .43001 Mtetra
.28346 .43001 .29458 .44072 .31175 .4349 .30069 .42413 Mtetra
.647 .763 .934 r
.30069 .42413 .31175 .4349 .32903 .42901 .31804 .41819 Mtetra
.648 .764 .933 r
.31804 .41819 .32903 .42901 .34643 .42304 .33551 .41217 Mtetra
.65 .765 .933 r
.33551 .41217 .34643 .42304 .36395 .41692 .3531 .40604 Mtetra
.653 .767 .933 r
.3531 .40604 .36395 .41692 .38158 .41059 .3708 .39974 Mtetra
.66 .771 .932 r
.3708 .39974 .38158 .41059 .39935 .40385 .38864 .39313 Mtetra
.672 .779 .93 r
.38864 .39313 .39935 .40385 .41724 .3964 .4066 .386 Mtetra
.693 .793 .927 r
.4066 .386 .41724 .3964 .43528 .38767 .4247 .3779 Mtetra
.729 .817 .919 r
.4247 .3779 .43528 .38767 .45345 .37665 .44294 .36808 Mtetra
.786 .852 .9 r
.44294 .36808 .45345 .37665 .47176 .3617 .46133 .35522 Mtetra
.859 .893 .859 r
.46133 .35522 .47176 .3617 .49015 .34055 .47983 .33735 Mtetra
.928 .923 .786 r
.47983 .33735 .49015 .34055 .50854 .31099 .49839 .31204 Mtetra
.967 .929 .693 r
.49839 .31204 .50854 .31099 .52677 .27281 .51687 .27779 Mtetra
.975 .921 .615 r
.51687 .27779 .52677 .27281 .54473 .22987 .53512 .23628 Mtetra
.97 .918 .586 r
.53512 .23628 .54473 .22987 .56239 .18904 .55306 .19332 Mtetra
.966 .933 .624 r
.55306 .19332 .56239 .18904 .5799 .15571 .57076 .15564 Mtetra
.953 .949 .719 r
.57076 .15564 .5799 .15571 .59741 .13109 .58839 .1266 Mtetra
.905 .933 .82 r
.58839 .1266 .59741 .13109 .61504 .11349 .60608 .10565 Mtetra
.831 .882 .88 r
.60608 .10565 .61504 .11349 .63282 .10052 .62392 .09053 Mtetra
.765 .829 .902 r
.62392 .09053 .63282 .10052 .65076 .0903 .64192 .07901 Mtetra
.72 .792 .908 r
.64192 .07901 .65076 .0903 .66886 .08159 .66007 .06955 Mtetra
.694 .769 .909 r
.66007 .06955 .66886 .08159 .68709 .0737 .67838 .06121 Mtetra
.68 .756 .909 r
.67838 .06121 .68709 .0737 .70546 .06622 .69682 .05345 Mtetra
.672 .749 .909 r
.69682 .05345 .70546 .06622 .72396 .05893 .7154 .04598 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45397 Mtetra
.17073 .45397 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44738 .22097 .43674 Mtetra
.22097 .43674 .23242 .44738 .24932 .44163 .23793 .43093 Mtetra
.23793 .43093 .24932 .44163 .26634 .43584 .25501 .42507 Mtetra
.646 .763 .934 r
.25501 .42507 .26634 .43584 .28346 .43001 .2722 .41917 Mtetra
.2722 .41917 .28346 .43001 .30069 .42413 .28951 .41322 Mtetra
.647 .763 .934 r
.28951 .41322 .30069 .42413 .31804 .41819 .30692 .40722 Mtetra
.30692 .40722 .31804 .41819 .33551 .41217 .32446 .40115 Mtetra
.649 .764 .933 r
.32446 .40115 .33551 .41217 .3531 .40604 .34211 .39499 Mtetra
.651 .766 .933 r
.34211 .39499 .3531 .40604 .3708 .39974 .35989 .38869 Mtetra
.656 .769 .933 r
.35989 .38869 .3708 .39974 .38864 .39313 .37779 .38216 Mtetra
.665 .775 .931 r
.37779 .38216 .38864 .39313 .4066 .386 .39583 .37523 Mtetra
.681 .785 .929 r
.39583 .37523 .4066 .386 .4247 .3779 .41399 .36758 Mtetra
.709 .804 .924 r
.41399 .36758 .4247 .3779 .44294 .36808 .43231 .35864 Mtetra
.755 .833 .911 r
.43231 .35864 .44294 .36808 .46133 .35522 .45076 .34739 Mtetra
.821 .872 .883 r
.45076 .34739 .46133 .35522 .47983 .33735 .46936 .33219 Mtetra
.896 .91 .826 r
.46936 .33219 .47983 .33735 .49839 .31204 .48805 .31074 Mtetra
.952 .929 .74 r
.48805 .31074 .49839 .31204 .51687 .27779 .50674 .28083 Mtetra
.974 .926 .649 r
.50674 .28083 .51687 .27779 .53512 .23628 .52527 .24226 Mtetra
.973 .918 .593 r
.52527 .24226 .53512 .23628 .55306 .19332 .54351 .19893 Mtetra
.967 .924 .596 r
.54351 .19893 .55306 .19332 .57076 .15564 .56146 .15772 Mtetra
.962 .943 .667 r
.56146 .15772 .57076 .15564 .58839 .1266 .57924 .12406 Mtetra
.934 .946 .773 r
.57924 .12406 .58839 .1266 .60608 .10565 .59703 .09915 Mtetra
.869 .91 .856 r
.59703 .09915 .60608 .10565 .62392 .09053 .61493 .08129 Mtetra
.795 .854 .894 r
.61493 .08129 .62392 .09053 .64192 .07901 .63298 .06809 Mtetra
.74 .808 .906 r
.63298 .06809 .64192 .07901 .66007 .06955 .6512 .05764 Mtetra
.705 .779 .909 r
.6512 .05764 .66007 .06955 .67838 .06121 .66957 .04872 Mtetra
.686 .762 .909 r
.66957 .04872 .67838 .06121 .69682 .05345 .68809 .04061 Mtetra
.675 .752 .909 r
.68809 .04061 .69682 .05345 .7154 .04598 .70674 .03291 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45397 .15895 .44341 Mtetra
.15895 .44341 .17073 .45397 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43183 Mtetra
.19246 .43183 .20411 .44252 .22097 .43674 .20938 .42598 Mtetra
.20938 .42598 .22097 .43674 .23793 .43093 .22641 .42009 Mtetra
.22641 .42009 .23793 .43093 .25501 .42507 .24355 .41416 Mtetra
.24355 .41416 .25501 .42507 .2722 .41917 .26081 .40819 Mtetra
.646 .763 .934 r
.26081 .40819 .2722 .41917 .28951 .41322 .27818 .40218 Mtetra
.27818 .40218 .28951 .41322 .30692 .40722 .29567 .39611 Mtetra
.647 .763 .934 r
.29567 .39611 .30692 .40722 .32446 .40115 .31327 .38999 Mtetra
.648 .764 .933 r
.31327 .38999 .32446 .40115 .34211 .39499 .331 .38378 Mtetra
.65 .765 .933 r
.331 .38378 .34211 .39499 .35989 .38869 .34885 .37746 Mtetra
.653 .767 .933 r
.34885 .37746 .35989 .38869 .37779 .38216 .36682 .37097 Mtetra
.66 .771 .932 r
.36682 .37097 .37779 .38216 .39583 .37523 .38492 .36416 Mtetra
.672 .779 .93 r
.38492 .36416 .39583 .37523 .41399 .36758 .40316 .35682 Mtetra
.693 .793 .927 r
.40316 .35682 .41399 .36758 .43231 .35864 .42154 .34852 Mtetra
.729 .817 .919 r
.42154 .34852 .43231 .35864 .45076 .34739 .44007 .33847 Mtetra
.786 .852 .9 r
.44007 .33847 .45076 .34739 .46936 .33219 .45874 .32537 Mtetra
.859 .893 .859 r
.45874 .32537 .46936 .33219 .48805 .31074 .47754 .30722 Mtetra
.928 .923 .786 r
.47754 .30722 .48805 .31074 .50674 .28083 .4964 .28159 Mtetra
.967 .93 .692 r
.4964 .28159 .50674 .28083 .52527 .24226 .51519 .24696 Mtetra
.975 .921 .615 r
.51519 .24696 .52527 .24226 .54351 .19893 .53374 .20505 Mtetra
.97 .918 .586 r
.53374 .20505 .54351 .19893 .56146 .15772 .55197 .1617 Mtetra
.966 .933 .624 r
.55197 .1617 .56146 .15772 .57924 .12406 .56996 .12366 Mtetra
.953 .949 .719 r
.56996 .12366 .57924 .12406 .59703 .09915 .58786 .09431 Mtetra
.905 .932 .821 r
.58786 .09431 .59703 .09915 .61493 .08129 .60583 .07309 Mtetra
.831 .882 .88 r
.60583 .07309 .61493 .08129 .63298 .06809 .62394 .05772 Mtetra
.765 .829 .902 r
.62394 .05772 .63298 .06809 .6512 .05764 .64222 .04596 Mtetra
.72 .792 .908 r
.64222 .04596 .6512 .05764 .66957 .04872 .66066 .03628 Mtetra
.694 .769 .909 r
.66066 .03628 .66957 .04872 .68809 .04061 .67925 .02772 Mtetra
.68 .756 .909 r
.67925 .02772 .68809 .04061 .70674 .03291 .69798 .01973 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43183 .18066 .421 Mtetra
.18066 .421 .19246 .43183 .20938 .42598 .19765 .41508 Mtetra
.19765 .41508 .20938 .42598 .22641 .42009 .21474 .40912 Mtetra
.21474 .40912 .22641 .42009 .24355 .41416 .23195 .40312 Mtetra
.23195 .40312 .24355 .41416 .26081 .40819 .24927 .39708 Mtetra
.646 .763 .934 r
.24927 .39708 .26081 .40819 .27818 .40218 .26671 .391 Mtetra
.26671 .391 .27818 .40218 .29567 .39611 .28427 .38486 Mtetra
.647 .763 .934 r
.28427 .38486 .29567 .39611 .31327 .38999 .30195 .37867 Mtetra
.30195 .37867 .31327 .38999 .331 .38378 .31974 .37241 Mtetra
.649 .764 .933 r
.31974 .37241 .331 .38378 .34885 .37746 .33766 .36606 Mtetra
.651 .766 .933 r
.33766 .36606 .34885 .37746 .36682 .37097 .35571 .35956 Mtetra
.656 .769 .933 r
.35571 .35956 .36682 .37097 .38492 .36416 .37388 .35283 Mtetra
.665 .775 .931 r
.37388 .35283 .38492 .36416 .40316 .35682 .39219 .3457 Mtetra
.681 .785 .929 r
.39219 .3457 .40316 .35682 .42154 .34852 .41064 .33784 Mtetra
.709 .804 .924 r
.41064 .33784 .42154 .34852 .44007 .33847 .42924 .32868 Mtetra
.755 .833 .912 r
.42924 .32868 .44007 .33847 .45874 .32537 .44799 .31719 Mtetra
.821 .872 .883 r
.44799 .31719 .45874 .32537 .47754 .30722 .46688 .30172 Mtetra
.896 .911 .826 r
.46688 .30172 .47754 .30722 .4964 .28159 .48588 .27997 Mtetra
.952 .93 .74 r
.48588 .27997 .4964 .28159 .51519 .24696 .50488 .24971 Mtetra
.974 .926 .649 r
.50488 .24971 .51519 .24696 .53374 .20505 .52372 .21075 Mtetra
.973 .918 .593 r
.52372 .21075 .53374 .20505 .55197 .1617 .54226 .167 Mtetra
.968 .924 .597 r
.54226 .167 .55197 .1617 .56996 .12366 .5605 .12541 Mtetra
.962 .943 .667 r
.5605 .12541 .56996 .12366 .58786 .09431 .57857 .09141 Mtetra
.934 .946 .773 r
.57857 .09141 .58786 .09431 .60583 .07309 .59663 .06622 Mtetra
.869 .909 .856 r
.59663 .06622 .60583 .07309 .62394 .05772 .61481 .0481 Mtetra
.795 .854 .894 r
.61481 .0481 .62394 .05772 .64222 .04596 .63314 .03465 Mtetra
.74 .808 .906 r
.63314 .03465 .64222 .04596 .66066 .03628 .65164 .02397 Mtetra
.705 .779 .909 r
.65164 .02397 .66066 .03628 .67925 .02772 .6703 .01482 Mtetra
.686 .762 .909 r
.6703 .01482 .67925 .02772 .69798 .01973 .68911 .00648 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001ooeLLD_`0
07oo0000Egoo003EOol30003Ool02ELLE_aFo5KlEa`005KlOol0001FOol00=9oo`<000Aoo`0;E_aK
75LLEaaBo5LLE_`005;lOol0001FOol00=1oo`8000Eoo`07FaaG75/LEaaK75KlEa`00UKl00D005LL
E_aoo`0005Eoo`00cGoo0`001Goo015G75/LE_aK75LLFaaFo5/LE_aG75;l001Bo5KlD_aoo`0005Ao
o`00bgoo0P001goo00UK?5llEaaK75LLFaaG75/LEa`00eKl00H005KlE_aFo7oo001DOol00<Qoo`<0
0003Ool007oo00Aoo`0EGcaK75llFa]O?5LLFaaFo5/LE_aG75KlEaaBo5Kl001G75;lE_aoo`0005=o
o`00Igoo0P000Woo0P00FGoo0P0017oo00@007ooOomoo`9O?00<FcaO?5llGcaK?5llE_aG75KlEaaF
o5LL0eKl00L005KlE_aBo5KlOol0001BOol006Qoo`04001oogoo001GOol30009Ool06F=KIgaK75ll
Fa]O?5/LGcaK75/lE_aG75KlFaaFo5LLD_aG7000E_aBo5KlD_aoo`00059oo`00JGoo0P00EWoo0P00
2goo00ASFfMLHe]SG09O?003FcaK75/L009K700@EaaFo5LLE_aG75KlEaaBo000D_aFo5;lE_aBo7oo
001AOol006Uoo`8005=oo`<000]oo`0=IgaSFfMlHe]WO6=KIgaK75/lFaaK?5/LFc`00U/L00aFo5LL
E_aG75KlEa`005KlD_aFo5;lE_`2Ool00`00Oomoo`1>Ool006Qoo`04001oogoo001@Ool2000=Ool0
2F=LHe]WG6=KHeaSFf=LGcaOG006Fa`3E_`03ELLE_aFo5Kl001Bo5KlD_aFo5;lE_aoo`00051oo`00
Igoo0P000Woo0P00C7oo0`003Woo00e_Vf^JIgaSFfMlGc]SG5lkHeaO>e/lFaaK?002Fa`04ULLFaaB
o5LLE_aG75;lEa`005KlD]aFo5;lE_aBg5KlOol004moo`00]Woo0`000Woo00<007ooOol02goo0VnJ
015_VfnJGeaO?6=LGcaOG5llHeaO?5/LEaaK75LLFaaG75/L00=Fo003EaaFo000009Fo005D_aFo5;l
E_aBo002001?Ool00;Aoo`80019oo`0TKi][VVnKJiY[NfMkHeaO>f=LGc]SG5lkGcaK6e/LEaaK75Kl
FaaG75/LD_aG75;lE_`005LLD_aFo5;LE_aBo5KlD]aoo`00CWoo002aOol3000COol2KiX02VnKKiY[
NfMkJg]WNemLGcaSG5/l0ell00QK?5/LEaaK75LLFaaFo5LL0eKl00`005KlE_aBo5KlD_aFo5;lE_aB
o7oo001=Ool00:moo`8001Eoo`0CKi][VVnKJiY[NfMkJiaWNf]kIg]O?5/LGcaK6ellFaaO?5KlFa`0
0ULL019Fo5/LE_aFo5;lEa`005KlD_aG75;lE_aBg5KlD_aFo7oo000AOol5000gOol00:aoo`<001Io
o`9g^00:Ki]_VV]kIg][NfMkJg]WNfMLHe/3Gc`02U/lGcaO?5llE_aG75KlEaaFo5LL0eKl00L005Kl
E_aBo5KlD_aFo003D_`00eKlOol0000@Ool01@00Oomoogoo0000=goo002ZOol2000HOol0:gOHLkMg
f7NgJg]WNf^LIg][NfMkIgaSFfMlHe]O?5/LGcaK6ellFaaK?5KlFaaFo5LLE_aK75;lE_`005KlD_aF
o5;lE_aBo5KlD]aFo5;LE_aoo`00011oo`03001oogoo03Qoo`00Ygoo0`000Woo00<007ooOol057oo
0gNh00eg]g>iLkU[NfMkJg]SFfMLHe]SG6=KIeaK?002Gc`4Fa`01ELLE_aG75KlEa`00UKl00IBo000
D_aFo5;lE_`3D_`01UKlD_aBo5;lE_`000Moo`H000Aoo`03001oogoo03Moo`00YGoo0P0077oo02ec
]gOHMkMc^VnILkYcVG>jHe]WO6=KIgaSFfMlHe]WO5/LFcaK75/lFaaK?5/LEaaBo5LLE_aG75;lEa`0
05KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg7oo00004Goo00<007ooOol0=Woo002ROol3000MOol2MkP0
0gNgMkQc^@03LkT02VnJKi]SFf=LHe]WG6=KGeaO?6=L1U/L0ULL0eKl00UG75Kl001Bo5KlD_aFo5;l
E_`00e;l00IFo5;lD_aBo7oo000AOol00`00Oomoo`0eOol007Eoo`@002Moo`8001moo`0JLkMgf7Ng
MmQ_VG>jLiUc^V^JKi][VVMlHe]WO5lkHeaO>f=LGc]K?5/LFcaG75/LE_aK709G700DD_aG75KlEa`0
05KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]`000eoo`05001oogooOol0000gOol007Aoo`03001o
ogoo009oo`03001oogoo025oo`<0021oo`9g^003MkMg^7>i00=c^@03KiY_VfnJ009_VP0AHeaO?5mL
GcaSG5llGeaO?5/LEaaK75LLFaaG75/LE_aG7003E_`01`00E_aFo5;lE_aBo5Kl00QBo003Ool007oo
00aoo`<003Qoo`00M7oo00<007ooOol00Woo00<007ooOol07Woo0`008goo01EkeGNdNkE_VG>jLiUc
^V^JKi][VVnKJiY[W6MkHeaO>f=LGc]SG5lkGc`00U/L01aFo5/LEaaK75KlFaaBo5KlD_aG75;l001B
g5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlOol004Moo`00M7oo00<007ooOol00Woo00<007ooOol0
77oo0P000Woo00<007ooOol087oo0g^d00Ig]W^fMkIg]VnJKi/3KiX01f]kIg][NfMkHeaO?5mL009O
?006FcaO?5llFaaG75/L0ULL00=Fo5LLE_`00eKl00<005KlD_`00U;l00=Fo5;lD_`01e;l00=oo`00
Ool0AWoo001dOol00`00Oomoo`02Ool00`00Oomoo`0IOol3000WOol0=GNdNkEg]7_FMkIkeW>gMmQ[
VVnKIg][W6MkJg]WNf^LIg]O?5/KGcaK75llFa]O?5/LEaaFo5/LE_aG75KlEaaBo5KlD_`005;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg7oo0000AWoo001dOol00`00Oomoo`02Ool00`00Oomoo`0G
Ool2000YOol3Nk@04W^fMkIg]WNfMkQg]gNhIg][NfMkJg]WNf]kIg]SG6=KGcaK?0=O?0=K7005EaaF
o5LLE_aG7002E_`01U;lE_`005KlD_aFo0=Bo003E_aBo5;l00IBo09oo`03001oogoo04=oo`00M7oo
00<007ooOol00Woo00<007ooOol057oo0`00:goo03Mk]GNdNmEg]W_FMkIgf7NgMmQ_VG>jIg][NfMk
JiaSFfMlHe]WO5/LGcaK6e/lFaaK?5/LFcaFo5LLE_aK75KlEaaBo5KlD_`005;lE_aBo5KlD]aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlOol00015Ool007Eoo`@001Eoo`8002eoo`=k]0=g]P03MkQg]gNh00Ec
^@07IeaSFf=LHe]WG6=KHe`025/L00=Fo5LLE_`00UKl00UG75KlE_`005KlD_aFo5;lE_`00e;l00=F
o5;lD_`01U;l00=oo`00Ool0@goo002;Ool3000_Ool0>WNdNmEg]W_FMkIgf7NgMmQc]g>jLiUc^FnI
Ki][VVMlHe]WO6=KIgaO>f=LFaaK?5/LFcaK75/lE_aK75KlEaaBo5LLE_aG75;l001Bo5KlD]aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aoo`00@goo0029Ool20002Ool00`00Oomoo`0/Ool3Nk@2
MkH017^fMkMg^7Nh17>i00]_VfnJKiYSFfMLHe]OG5llHeaO?5mL00AK7003EaaK75LL009Fo00=EaaF
o5KlE_aG7000E_aBo5KlD_aFo5;lE_`02e;l00=oo`00Ool0@Woo0026Ool3000cOol0?7_EMkAkeWNf
NmIg]gOHLkMc^W>ILkU_VFnKJiY_Vf^JKi]O>f=LGc]SG5lkHeaO>f=LEaaK75KlFaaG75/LE_aG75Kl
EaaBo5LLD_`005;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LOol0049oo`00Q7oo
0P00=Goo00=k/W^BNk800g^c0W^d17>i01E_VfnJKiY_VVnKIg][NellHeaO?5mLGcaSG5/lGcaG75/L
EaaK75LLFa`01UKl00H005KlD_aFo5;lE_`<D_`01E;LD_aBo7oo0000@Goo0021Ool3000gOol0?W^B
Nk9gTW^cNi=k]GNdNmIg]W_FMkI_Vf^JKi][VVnKIg][NfMkJiaO>f=LGc]O?5/LGcaK6e/LEaaK75Kl
FaaFo5LLD_aG75;lE_aBo000D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo7oo
0011Ool007ioo`<003Uoo`03Ni9k/W^B00=k/`9k]0=g]P0;MkQg]fnJKiY[NfMkJg]WNf]kIg][N`02
Gc`035/lGcaO?5llFcaG75KlEaaFo5LLE_aG70AFo004001Fo5;lE_`3D_`00eKlD_aBo006D_`025;L
D_aBo5;lD]aBo7oo0010Ool007aoo`8003aoo`0MNk9gTW^cNi=k/gNdNmEg]W_FMkIkeWNgMmQc]f^L
Ig][NfMkJiaWNf]kHe]WO5/LGcaK6ellFaaK?002Fa`08UKlEaaFo5/LE_aG75;lE_aBo000D_aFo5;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aoo`00?goo001iOol30002Ool2000i
Ool00g^bNi9k/P03Nk<2Nk@2MkH017^fMkMg^7Nh0W>i00Q[NfMkJg]WNf=LHe]WG6=K0ell1E/L00=G
75KlEa`00eKl00UG75;lE_`005KlD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00MBg5;lD_aBo5;LOol0
000oOol007Moo`80041oo`0VMi9k/W^CNk=gTW_EMkAkeWNfNmIg]gOHLkMc^W>ILkU_VG>jHe]WO6=K
IgaSFfMlHe]K?5/LFcaK75/lFaaK?5/LEaaFo5LLD_aG709Fo00KD_`005;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0003ioo`00M7oo0`00@Woo00=k/W^BNk<00W^c
00Ek]7NfMkIk]WNg00=g^0Ac^@9_VP07He]WG6=KHeaSFf=LGc`01e/L00AG75KlE_aG70AFo008001F
o5;lE_aBo5KlD_aFo0=Bo003E_aBo5;l00IBo004D]aBo5;lD_`2Ool00`00Oomoo`0kOol0079oo`80
04Aoo`15Nk9kTW^cMi9k/gNdNkEg]W_FMkIgf7>gMmQcVG>iKiUc^V^JKi][VVMlHe]WO5lkHeaO>f=L
Gc]K?5/LFcaFo5/LEaaK75;lEaaFo5LLD_aG75;l001Bg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aoo`0003eoo`00Kgoo0`00AWoo00=kTW^bNk<00W^c00Ak]7NfNkIg
]P=g^0Ac^@=_VP0AKi]_VUmLGcaSG5llGeaO?6=LGcaK75LLFaaG75/LEaaK7007E_`01@00D_aFo5;l
E_`035;l00EBg5;lD_aBo5;L009Bo09oo`03001oogoo03Yoo`00KGoo0P0000=oo`00Ool0AGoo04Ek
TW^bMi9k/g^CNk9gTW^cNi=k/gNdNmEcVG>iKiUc^V^JKi][VVnKJiY[NfMkHeaO>f=LGc]SG5/LGcaK
6e/LEaaK75KlFaaFo5LLD_aG75;lE_aBo5LL001Fo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]`00Woo00<007ooOol0>Goo001ZOol3001:Ool00g^bNi9k/P03Ni83Nk<2
Nk@3MkH02g^fKiY_VVnJKi]_VV]kIg][NfMkJg/00Ull00IK?5llGcaO?5LLFa`2Ea`015KlEaaFo5LL
1EKl00<005;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000kOol0
06Moo`<004aoo`0WNk9gTWnbNi5k/WNBNk9kTg^cMi9keGNdNmIg]W_FMkMgf6^JKi]WNf]kIg][W6Mk
Jg]SFfMlFaaO?5/KGcaK75llE_aK75KlEaaFo5/L009Fo00QD_aG75;lE_`005KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aoo`0003Yoo`00IGoo0P00Cgoo00=k
TW^bNi800W^B00Ak/W^cNk=k/`9k]09g]P03NkIg]WNh009g^009Ig][NfMkJg]WNf]kHeaWG6=K00=O
?00:FcaK75/LFaaFo5LLE_aG75KlEa`2E_`015;lE_aBo0000e;l00EFo5;lD_aBo5Kl00QBo005D]aB
o5;lD_aBg003D_`015;LD_aBo000>Woo001ROol3001AOol0:GnbNi9k/W^ANk9kTW^cMi9k/gNdNkEg
]W_FMkIgf7>gMmQcVG>iIg][W6MkIgaSFfMlHe]WO6=KFcaK75/lFaaK?5/LFcaFo5/LE_aG75;lEa`0
0UKl021Bo5Kl001Fo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg000>Goo001POol2001COol01W^bNi9kTW^BNk9kTP=k/`9k]003MkIk]WNf00=g^003MkMc
^G>i009c^@9SG003IeaSFf=L009SG003GcaK75/L00EK70=Fo009EaaFo5KlD_aFo5;l001Bo5Kl00=B
o003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`015;LD_aoo`00>7oo001MOol300000goo001oo`1B
Ool08W^BNk9kTG^bNi9k/WNBNk=kTg^eMkIkeWNfMmQc]gOHMkMc^FnILkYcVFnKJiYWO6=KIgaO>f=L
Gc]SG5lkFcaK75/l0U/L02UG75/LD_aG75KlEaaBo5LLD_aFo000E_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo00003Qoo`00Fgoo0P00Egoo0g^B00=k
/W^BNk800g^c0W^d00=k]WNfMkH00WNh00=g]g>iLkT00W>i0VnJ00m_VfnJGeaO?6=LGcaOG5llHeaO
?5/LEaaK75LLFa`00ULL1UKl00IBo000D_aFo5;lE_`@D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo0000
=goo000^Ool4000VOol3001IOol0D7^bNi5k/W^ANk9gTW^cNi=k/gNdNmIg]W_FLkMgf7NgMmQ_VG>j
LiU_Vf^JKi][VV^KIg]SG5lkHeaO>f=LGc]O?5/KFaaG75/LE_aK75LLE_aBo5LLD_aFo5;lE_`005Kl
D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo
000ROol3000AOol002eoo`03001oogoo009oo`03001oogoo025oo`8005aoo`03Ni9k/W^B009kTP=k
/`03Ni9k/W^c009k/`=k]0=c^@9_VP0:Ki]_VV]kIg][NfMkGeaO?6=LFc`3Gc`01ULLFaaG75/LE_aG
70MFo003001Bo5Kl00=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00=oo`00Ool08goo00<007ooOol03goo000bOol00`00Oomoo`0MOol4001MOol0DW^AOk9kTG^bMi9k
/W^ANk9kTG^bNi=k/gNBNmEg]7^eMkIkeWNfKi][VVnKJiY[VfMkJiaWNf^KIg]O?5/lGcaK6ellFcaO
?5KlFaaFo5LLE_aK75;lE_aBo5LLD_aFo000E_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`008goo00<007ooOol03goo000UOol60007Ool0
0`00Oomoo`0LOol3001OOol01G^bNi9kTW^BNk800g^B00=k/W^BNk<00W^c0g^d00=k]WNfMkP00WNh
00Ug]f]kIg][NfMkJg]WNfMLHe/00ell011K?5llFaaK75KlEaaFo5LLE_aG75;lE_aBo5KlD_`000=B
o003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=oo`00Ool087oo00<0
07oo000047oo000^Ool4000LOol3001QOol08GnbNi9k/W^AOk9kTW^bNi5k/W^BNk9gTW^cMkAk]GNd
NmIg]W_FLkMgf7NgLkU_VF^LIg][Vf=KIgaSFfMlFa]O?002Fc`0<E/LFcaK75LLE_aK75KlEaaBo5LL
D_aFo5;lE_`005KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aoo`00025oo`03001oo`00011oo`00;Woo00<007ooOol06Woo0`00I7oo0W^B
00=kTg^cNi800W^B00=k/W^BNk800g^c0g^d0WNf0WNh00=g]g>iLkT00W>i0V=L00EWG6=KHeaSG6ML
00MK7005EaaFo5KlE_aG7002E_`01U;lE_aBo000D_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00U;l0P007goo00D007ooOomoo`0000moo`00;Woo00<007ooOol067oo
0P00IWoo02QkTW^bNi=o/g^BNk9kTG^bNi5k/WNBNk=kTg^eMkAkeGNfNmIc]gOHMkMgf6nILkYcVFnK
JiYWO6=KIgaSFfMlGcaSG5/LFcaK75/lE_aK709G700]D_aG75KlEaaBo5LLD_aFo000E_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]ao
o`0001ioo`05001oogooOol0000?Ool002ioo`D001=oo`<006Qoo`9k]005Nk=kTW^BNi9k/P03Ni83
Nk<2Nk@2MkH2MkP00gNgMkQc^@02LkT2KiX00fnKHe]SG002He`02UllGeaO?6=LGcaK75LLFaaG75/L
0ULL1UKl00IBo000D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aB
o7oo000MOol3000017oo000000003Woo0014Ool2001ZOol08g^dNi=o]7^BNk9kTGnbNi5k/WNBNk9k
Tg^cMkAkeGNdNmIg]WOHMkMgf6nILkYcVFnKJiY_^f^JKi]O>f=LGcaSG5lkHe`00Ull0U/L039G75/L
E_aK75LLE_aBo5LLD_aFo5;lE_`005KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`002Goo100097oo0011Ool300000goo001o
o`1YOol2Nk@017^BNi=kTW^b0g^B00Ak/W^BNk=k/`9k]09g]P03MkQg]gNh00=c^@9_VP0:Ki]_VVnJ
Ig][NellGeaO?6=LFc`3Gc`01ULLFaaG75/LE_aG70MFo003D_`005Kl00aBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00QBg5;lD_aBo5;LD_aoo`001goo00<007ooOol00Woo00<007ooOol0
8Goo000oOol2001^Ool0Fg^COkAkTg^cNi9o/W^BNk9kTG^bNi9k/gNBNk9kTW^bMi9keGNdNkEg]G_F
MkI_Vf^JKk][VVnKIg][W6MkJi]WNellFcaO?5/LGcaK?5llE_aK75KlEaaFo5/LD_aFo5;lEaaBo5Kl
D_`005;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aoo`0000Moo`03001oogoo009oo`03001oogoo025oo`00?7oo0`00L7oo00Ek
]7^DNi=kTg^b00=kTP07Nk9kTW^bNi9k/W^BNk800W^c0g^d00Ek]WNfMkQg^6nK009_VP07Ig][NfMk
Jg]WNfMLHe/00ell015K?5llFaaK75KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo000009Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aoo`00
00Ioo`03001oogoo009oo`03001oogoo025oo`00>Woo0P00LWoo02Eo]7^CNkAkTWncNi9k/W^ANk9k
TW^bNi5k/W^BNk9gTW^cMkAk]GNdNmIg]W_FLkMgf7NgMmQWNf^LIg][Vf=KIgaSFfMlFaaO?002Fc`0
=5/LFcaK75LLE_aK75KlEaaBo5LLD_aFo5;lE_aBo000D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l0Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol08Goo000gOol3001dOol017^DNkAkTg^c0g^B00Qk/W^BNi9kTW^b
Ni9k/W^B0W^c0g^d0WNf0WNh00=g]gNhLkT00W>i0V=L00EWG6=KHeaSG6ML00MK7005EaaFo5KlE_aG
7002E_`01U;lE_aBo5Kl001Fo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool007oo00Aoo`03001oogoo009oo`03001oogoo025oo`00
=Goo0P0000=oo`00Ool0Lgoo02akTg^dNi=o/g^BNk9kTGncNi9k/g^AOk9kTG^bMi9k/W^CNkEg]7_E
MkIkeW>gMmQg]gOHKiUc^W>iKi][VVMlHe]WO6=KIgaO?6=LFaaK?5/LFcaFo5/L0ULL02mBo5LLE_aG
75;lE_aBo5KlD]`005;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo025oo`00<Woo0`00N7oo0W^d00Uk/g^BNi9kTW^dNi9kTg^BNk800g^B00=k/W^cNk<00W^d0WNf
0WNh00=g]gNhLkT00W>i0VnJ00=_Vf=KHe`00V=L00YO?5mLGcaSG5llFaaG75/LEaaK709G70IFo006
D_aFo000E_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0U;l0`0017oo100097oo000_Ool3001jOol09g^dNi=o]7^BNk=kTgndNi9k/g^BOk9kTW^bMi9k/W^B
Nk=g]7_EMkAkeWNeMmQg]gOHKiUc^W>iKi][VVnkJiY_VelkHeaO?6=LGc]SG002Gc`2Fa`0=eLLFaaF
o5/LEaaFo5;lEaaBo5KlD_aFo5;l001Bg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002aoo`00;Goo0P00OGoo
0W^d0g^e00Ek]7^DNi=kTg^b00=kTP04Nk9kTW^cNk<2Nk@2MkH00gNhMkMg^003LkT2KiX02VnKKiY_
VVMkJg]O?5mLGcaSG5/l0ell00IG75/LEaaK75KlEa`7E_`200000eKlD_aBo00:D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aoogoo0000:goo000ZOol3
001nOol0=GNFNkMgUW^eMiEo]7^CNk=kTWncNi9k/W^ANk9kTW^bMi9k/W^BNk9gTW^cMkAk]GNeNmIg
]VnKJiY_^f^JKi]WNf^LIg][VfMkGcaK?5llFaaO?5/lGcaFo5/LE_aG75KlFaaBo5KlD_`00`0002YB
o5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`2Ool00`00Oomoo`0XOol002Qoo`800003Ool007oo07eoo`03
MkMk]gNf00=k]@04NiAk]7^CNk<3Ni801g^bNi9k/W^BNk9kTW^b009k/`=k]005NmIg]WNhMkQ_V`02
KiX01fMkJg]WNf]kIg]WG6=K00=O?009FcaO?5/LFaaFo5LLE_aG75Kl00<00008D_aFo5;lE_aBo000
D_aFo0QBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aB
o5;lD_aBg5;lOol002Yoo`009Woo0P00PWoo02Uk]gNFNkMgUG^fNi=k]7^COk=kTW^bNi5k/W^BNk9k
TG^bNi9k/WNBNk=kTg^eMkAkeWNfNmIc]gOHMkMgf6MkJiaWNf^KHe]WO6=KIgaK75ll009K?006FaaK
?5/LEaaFo5/L0P00035Bo5LLD_aFo5;lE_aBo5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00
Oomoo`0WOol002Ioo`80085oo`03NkMg]WNg00=k]@9k]005Nk=kTW^CNi9k/P03Ni8017^bNi9k/W^B
0W^c0g^d0WNf0WNh00=g]gNhLkT00W>i0V=L00EWG6=KHeaSG6ML00IK70<0009Fo00=EaaFo5KlD_aF
o5;lE_aBo5KlD_`005;lE_`025;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L009oo`03001oogoo02Ioo`009Woo0`00P7oo02agUW^gMiIk]W^E
NkAkTgndNi9k/g^AOk9kTG^cNi5o/W^ANk9gTW^bNi=k/gNdNmEg]W_FMkEgf7NgMmQ_VG>jLkU_Vf^J
IgaSFfMlHe]SG5llHeaK75/l0`0003YK75LLEaaBo5LLE_aG75;lE_aBo5KlD]aFo5;lE_aBg000D]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LOol002Qoo`009Woo00@007ooOol007ioo`03MkIg]gNg00=k]@9k]008Ni9k
Tg^CNk9kTW^CNi9k/P=kTP03Nk9k/g^c009k]0=g]P03MkQg]gNh00=c^@9_VP07Ki]_VUmLGcaSG5ll
Ge`00`0000MK75LLFaaG75/LE_aG7006E_`015;lE_aBo5Kl0U;l00<005;lD_`02E;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lD_aBo09oo`03001oogoo
02Eoo`009Goo00<007ooOol00Woo00<007ooOol0Ngoo02Mk]gNFNkMkUG^eNi=o]7^CNk=kTWnbNi=k
/g^BOk9kTW^bNi5k/W^BNk=gTW_EMkAkeWNeNmIg]gOHKiUc^W>iKi][VVnkJiY[VfMkHe`00`00045S
G5/lGcaFo5/LEaaK75KlFaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBo5Kl001Fo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aoo`0002Moo`009Goo00<007ooOol00goo00<007ooOol0NGoo0WNg00Ik]g^eNkEk]G^dNi@2
Ni<01G^cNiAkTg^CNk800g^B00Ak/W^BNk=k/`9k]09g]P03NmIg]gNh00=c^@9_VP03Ki]_VV]k00<0
0004GeaO?5llFc`3Gc`01ULLFaaG75LLE_aG70IFo0=Bo003E_aBo5;l009Bo005001Bo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00=oo`00Ool09Goo000UOol00`00Oomoo`04Ool00`00Oomoo`1hOol08WNFNkMgUW^eMiEo
]7^CNkAgUG^fNiEk]7^BOk=kTW^bNi5k/W^BNk9gTW^cNi9k/WNBNk=g]7^eMkEkeWNfKi][VVnk0`00
04I[W6MkJi]WNellFcaO?5/LGcaK?5llE_aK75KlEaaFo5/LD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5Kl
D]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg09oo`03001oogoo02=oo`009Goo0P001Woo0P00Mgoo00=g]g^g
MkH00g^e00QgUWNgMkMk]G^ENkAkTg^c0g^B00=k/W^BNk800W^c00=kTW^bNk<00W^c0W^d00AkeWNf
MkQg^0800008Jg]WNf]kIg][NfMkIeaSF`=O?00@FcaK75/LFaaFo5LLE_aG75KlEaaBo5KlD_aFo5;l
E_`3D_`01EKlD_aBo5;l000015;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000UOol002Eoo`03001oogoo00Moo`03
001oogoo07=oo`0OKiUc^VnIMkQcV7NiMiIk]gNFNkIkUG^eNi=o/g^BNk9kTG^bNi5k/WNBNk9kTG^b
Mi9k/g^CNkEg]7_FMkH00`0004mg]g>iKiU[W6MkJi]SFfMlHe]WO6=KFcaK75/lFaaK?5/LEaaFo5/L
E_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000T
Ool002Eoo`03001oogoo00Qoo`03001oogoo075oo`07LiUcVVnILiUgV7NhLiP00WNg00=k]g^ENkD0
0W^d00AkTW^CNi9k/P=kTP04Nk9kTW^BNi83Nk<017^d000000000WNh00=g]g>iLkT00W>i0V=L00=W
G6=KHe`00V=L00=O?5/LFa`015/L00EG75KlE_aFo5LL009Fo006D_aFo5;lE_aBo5Kl0e;l00EFo5;l
D_aBo00000ABo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aoogoo00008goo000UOol00`00Oomoo`09Ool00`00Oomoo`1`Ool0
6W>jKiUcVW>HMkUcV7^gMiIk]g^ENkEgUGndNi9k/g^AOk9kTG^bNi9o/W^ANk9gTW^bNi<3000067Nf
NmIg]GOHMkMgf6nILkYc^FnKJiYWO6=KIgaO>f=LGcaSG5/LFcaK75/lE_aK709G700lD_aG75KlEaaB
o5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`008goo000TOol2
000<Ool00`00Oomoo`1^Ool02W>JKiUcVG>IMkQcV7NhMkMk]gNF0W^e00Ik]7^DNi=kTg^bNi82Ni<0
17^bNi9kTW^B0`0000=k/g^dMkH00WNf00=g^7NgMkP00g>i0VnJ011_VfnJGeaO?6=LGcaOG5llHeaG
75/LEaaK75LLFaaG70MFo004D_aFo5;lE_`8D_`00`00D_aBo003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol0029oo`00
97oo00<007ooOol037oo00<007ooOol0K7oo01Ic^VnILiY_VGNiLiQg^7NFNkMgUW^eMiEk]W^CNk=k
TWnbNi9k]7^BOk=kTP<0000PNi9k/gNBNmEg]7_FMkEkeWNgMmQ_VG>jLkU_Vf^JKk][VV^KIg]SG5ll
HeaO>ellFcaO?5KlFaaG75/LE_aK709Fo00iD_aG75;lE_aBg5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;L009oo`03001oogoo01moo`0097oo00<007ooOol03Goo00<007oo
Ool0JWoo00]cVVnILiUcVGNhLiQg^7NHNkMgUWNg009k]@07NiAk]7^CNk=kU7^dNi<00`0000=kTW^b
Ni800g^c00Ik]7NfMkIkeWNgMkP3LkT2KiX01fnKKiY[NfMkJg]WNf]k009O?00:FcaO?5llGcaK?5LL
E_aG75KlEa`6E_`3D_`00eKlD_aBo008D_`00`00D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00008Goo000TOol0
0`00Oomoo`0>Ool00`00Oomoo`1XOol04f]lIg]cVVnILkYcV7NhLiQk]gNFNkMgUG^fNiEk]7^BOk=k
UG^d0080000PNi9k/W^ANk9kTW^bMi9k/g^BNk9gTW^cMkAk]GNdNmIg]VnKJiY_^f^JJi]WNf^LIg][
Vf=KIgaK?5llFaaO?09K?09K7011E_aG75KlFaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg000D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000POol002Aoo`03001oogoo00moo`03001oogoo
06Eoo`IWN`05LiQg^7NHMkQgUP02MkL01G^eNiEk]7^dNkD00`0000Mk/g^BNi=kTW^bNi9k/P02Nk<0
0g^BNk9k/`02Nk<2Nk@00g_FMkIg^002MkP02GNgJg]WNf]kIg][Nf=LIeaSF`03Gc`4Fa`015KlEaaF
o5LL0UKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;L001Bo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03
001oogoo01eoo`0097oo0P004Goo00<007ooOol0Hgoo011WFf]lIg][O6MKJga[NVnKJgY_VgNFNkMg
UW^fNiEk]@<0001[NkEkTgndNi9k/g^AOk9kTG^bMi9k/W^ANk9gTW^cNi=k]GNdNmEg]W_FLkMgf7Ng
LkU_VF^LIg]WO6=KIgaSFfMlHe]K?5/LFcaK75/lFaaK?5;lEaaFo5LLD_aG75;lE_aBo5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000OOol002=oo`03001o
ogoo019oo`03001oogoo061oo`MWN`05JgY[VV]jKi]_V@02LiT01gNh00000000NkMkUG^e009k]004
NiAkTg^CNk83Ni8017^bNi9kTW^B0g^c0W^d0WNf0WNh00=g]g>iLkT00W>i0V=L00=WG6=KHe`00V=L
00=O?5/LFa`00e/L00=G75/LE_`00UKl00UG75KlE_aBo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l
00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`0MOol001Yoo`@000Eoo`03001oogoo01=oo`03001o
ogoo05ioo`0=GeaO?6]lIg][O6MKKi][NVnKJgY_VfnILiX00`0002mg^7>HNkMkUG^eMiEo]7^CNk=k
TWnbNi9k/W^BOk9kTG^bMi9k/W^CNk=g]7_EMkAkeW>gMmQg]g>iKiUc^W>iKi][VVMlHe]WO5lkHeaO
?6=LGc]K75LLFaaFo5/L009G700oD_aG75KlE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03001oogoo01]oo`006Goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol057oo00<007ooOol0G7oo0emL00QO?6MkIg]_Vf]jJiY[NVnK0`00
00Ig^7>HMkQgV7^gMiH2NkD01G^dNiAk]7^CNk<00W^B00=kTg^bNi800W^B00Ak/W^BNk=k/`9k]09g
]P03MkQg]g>i00=c^@9_VP07Ki]_VUmLGcaSG5llGe`00Ull00MK?5/LEaaK75LLFaaG7007E_`00e;l
E_aBo00;D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lOol0000MOol001Uoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo01Eoo`03001oogoo05Uoo`0:GcaOG5llHeeO?5mLGca_Vf]jKi/3
0000=g>JKiUcVW>HMkQcV7^gMiIk]GNENkIkTg^dNi9o/g^BNk9kTWncNi9k/W^ANk9kTW^cMi9keGNd
NkEg]GOHMkMc^FnILkYc^FnKJiY_^f^JJi]WNf=LGcaSG5/LGcaK?5llE_aK75LLFaaFo5/L009Fo011
D_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LOol0000LOol001Uoo`03001oogoo009oo`03001oogoo009oo`8001Moo`8005Qoo`05GcaO
G5mLGeaO?002Ge`2He`200002fnKKiUcVG>ILiYcV7NhMiQk]gNFMkL00W^e00EkU7^dNkAk/g^B009k
]007Nk=kTW^BNi9k/W^BNk800W^c0W^d00Mk/g^dNkAk]7NfNmIg]P02KiX01fnKIg][NfMkJg]WNf]k
009O?00:FcaO?5llGcaFo5LLE_aG75KlEa`4E_`00e;lE_aBo002D_`00eKlD_aBo006D_`01E;LD_aB
o5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0JOol001Uoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo01Qoo`03001oogoo05=oo`08FceG75/mGcaSGEllGeaO?0<00020He]W
O6nILiY_VG>JLiQg^7>HMkUgUW^gMiEk]W^ENkAkTgncNi9k]G^COk=kTW^bNi5k/W^BNk9gTW^cNi9k
/WNBNk=g]7^eMkEkeWNfMmQc]gOHIg][VfMkJiaWNf^KHe]WO5/lGcaK75/lFaaK?5KlFaaFo5LLE_aK
75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]`001]oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol06Goo00<0
07ooOol0Cgoo00QK?E/lFceG75/mFcaK?Ell0`0016=L16Mk00EcV7NhMiQg^7NF009g]`03NkEkUG^d
009k]00@NiEk]G^dNkAkTW^CNi9k/W^BNk9kTW^bNi9k/W^BNk<3Nk@00g_FMkIg]P02MkP2LkT00fMk
Jg]WN`02He`00fMLHe]SG007Fa`2E_`02ELLE_aFo5;lE_aBo5KlD_aFo003D_`00eKlD_aBo006D_`0
1E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000JOol001Uoo`03001oogoo009o
o`05001oogooOol0000MOol00`00Oomoo`1<Ool01e<LEaeC75/mEaaK?ELL00<0000^He]WO6=KHgaS
FfMlIg][O6MKJga[NVnKJgY_VgNFNkMgUW^fNiEk]GNFNkMgUW^eMiEo]7^BNk=kTGnbNi5k/WNBOk9k
TG^bMi9k/W^CNkEg]7_FMkIkeW>gMmP2LkT0F6nILkYSFfMlHe]WO6=KIgaO>f=LFaaK?5/LFcaG75/L
E_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aoo`001goo1@003Goo000JOol40004Ool2000MOol00`00Oomoo`19
Ool00eLMEaaG7@02Ead01ELL00000000Ea`00U/l00AK?F=LHeaSG0EWN`05JgY[VV]jKi]_V@02LiT0
1WNhLiQg^7NgNkMgUP9k]@05NkAkU7^CNi=k/P03Ni801W^bNi9kTW^BNk9k/`=k]09g]P9g^004MkMc
^G>iLkT2KiX03V=LIeaSFemLGcaSG5llGeaG75/LEaaK75LLFa`6E_`01U;lE_aBo5KlD_aFo0aBo005
D]aBo5;lD_aBg002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00001goo00D007ooOomoo`0000eoo`00
8Woo00<007ooOol07Goo00<007ooOol0AWoo00EC75LMDaaG7E<L00<0002?DaaOGE/lGceK?5mMFcaO
?E/lJgaWNf]lIe][O6]jKi][NVnKKiUcVVnILiYcV7NhLiQk]gNFNkMgUG^fNi=k/g^BOk9kTW^bNi9o
/W^BNk9gTW^bNi9k/gNdNmEg]W_FLkMgf7NgLkU_VG>jJiY_Vf^JKk]O?6=LGc]SG5llHeaK75llEaaK
75KlFaaG75/LD_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol00007Ool00`00Oomoo`0>Ool0029oo`03001oogoo
01ioo`03001oogoo04=oo`=C7@05Ea`00000001G7002Ead01ELmEaaK?5/lFcd00e/l00=OG5llIg/0
0VMk00E[NV^JJgY_Vf]j009cV@07LiYcV7NhMiQk]gNFMkL00W^e00AkU7^dNi=k/`9kTP03Ni=k/W^B
009kTP03Nk9kTW^c00=k]09g]P03MkQg]g>i009c^@=_VP05Ki]WNf]kGcaSG004Gc`015/lFaaG75/L
0ULL00=Fo5LLE_`01EKl00=Bo5KlD_`02e;l00EBg5;lD_aBo5;L00=Bo005D]aBo000D_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l0Woo00<007ooOol01Goo00<007ooOol03Goo000ROol00`00Oomoo`0OOol00`00Oomoo`0oOol0
1ELMD_aG7E;lEad00P0004QC75LMDaaG?ELLFceG75LmEaaOGE/lGceO?6=MGcaOG5llHee[NVnKJgY_
Vf]jLiY_VG>JKiUg^7>HMkUgUW^gMiIk]W^ENkAkTWncNi9k/W^COk=kTW^bNi5k/W^BNk9gTW_EMkAk
eWNeMmQg]g>iKiUc^V^JKi][VVnkIg][VfMkJiaWNellFaaO?5/lGc`2Fa`015KlEaaFo5/L0UKl04IB
o5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_`0
05;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lOol000Qoo`03001oogoo00aoo`008Woo00<007ooOol087oo00<007ooOol0
?7oo00ABoE<MD_eC7@<000=C7@05EaaG7ELMEceG7002Ead00eLmEaaOG002Ge`015llGeaOG5mL0V=L
00=[NVnKJgX00W>I00IcVVnIMkQgV7NhMiH2MkL01W^eNiEk]7^dNk=kTP9k]00;Nk=kTW^BNi9k/W^B
Nk9k/g^bNi9k/P02Nk<03G^dMkIg]W_FMkMg^6nJKi]WNf]kIg][NfMk009SG003GcaK?5ll00=K7005
EaaFo5LLE_aG7002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]`0
05;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00U;l0Woo00<007ooOol01Woo00<007ooOol02goo000QOol2000SOol00`00Oomo
o`0hOol015;lDae>o5<M0`0005EG7E;lEaeBo5LMDaaG7ELLFceG75LmEaaK?ELLFceG76=MGcaOG5ll
HeeSFf=lHe]WO6=KLiY_VG>JKiUg^7>HMkUgUW^gMiIk]g^ENkEkTgncNi9k]G^COkAkTW^bNi5k/W^B
Nk9gTW^bNi9k/WNBNk=g]7^dMkEkeWNfMmQc]gOHIg][VfMkJiaSFfMlHe]WO6=KFcaK75/lFaaK?5/L
EaaFo5LLD_aG7002E_`0@e;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`05001oogooOol00003Ool00`00Oomoo`0;
Ool0025oo`03001oogoo02=oo`03001oogoo039oo`06D_eC7E;mDaeBoE<M0`0000aC7E;mDaeBoELM
DaeG7E<MEaeC7ELMDad2Ead01ULmEaaK?E/lFceG709OG0ISG09WN`06LiY_VG>IMiQg^7>H0WNg00=k
]g^ENkD00W^d00mkUG^eNkAk]7^BNi=kTW^bNi9k/W^BNk9kTW^bNi800W^c00Ak]7NfNmIg]P=g^0=c
^@08IgaSFf=LHeaWO6=KGeaO?0=K7003EaaK75LL009Fo003EaaFo5Kl009Fo004D_aFo5;lE_`3D_`0
0eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg5;lD_`00P00
17oo0`003Woo000QOol00`00Oomoo`0TOol00`00Oomoo`0_Ool01E<MC_aC7DklDad00`0004EC7E;l
Dae>o5<MD_aC7E;lEaeC75LMD_aG7E<LEaeBo5/mEaaK?ELLFceG75/mEaaWO6=KHgaSFfMlHe][O6MK
JgaWNf]lLiQg^G>HNkMgUW^gMiIk]GNENkMkUG^eMiEo]7^CNk=kTGnbNi5k/WNBOk9kTG^bMi9k/g^C
NkAg]7_FMkIgf7>gMmP00W>i05e_VFnkJiYWO6=KIgaO?6=LGc]SG5llFaaFo5/LEaaK75KlEaaFo5LL
D_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000057oo000QOol00`00Oomoo`0UOol00`00Oomoo`0[Ool2
D_d00e<MD_eBo@03000015<MD_eC7E;m0e<M00UBoE<MDaeC7E;mEaeC7ELMDad00eLM00UG75/mFcaK
?ELLFceK?5/mFc`00f=L1VMk00=[NVnKJgX00W>I00IcVVnIMkQgV7^gMiH2NkD01G^dNiAk]7^CNk80
0g^B00Ek/W^BNi9kTW^b009k/`03NkAkeWNf00=g^0=c^@09Ki]_VVnJKiYSG5llGeaO?6=L00=O?006
FaaG75/LEaaK75LL1EKl00IBo5KlD_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo000
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo7oo00004goo000QOol00`00Oomoo`0VOol00`00Oomoo`0XOol014kmDae>
o5<M0`0004UC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75LMDaaK?ELL
FceK?5mMFcaO?E/lGeeWNf]lIe][O6MkJga[NVnKJgYcVVnILiY_VGNhLiQg^GNFNkEgUG^fNi=k]7^B
Ok9kTW^bNi9o/W^BNk9gTW^bNi=k/gNdNmEg]W_FLkMgf002LkT0H6nIKk][VVnKJiY[W6MkHeaO>f=L
FcaO?5/LGcaG75/LE_aK75KlEaaFo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol001=oo`008Goo
0P00:7oo0P009Goo00=BoE<MC_d00U;m0P000U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@03D_eC
7E<M009C7@=G7@05EaaG7ELMEaeG7002Fc`01e/mFcaK?5/lFceO?5mL00AWN`0<JgY_Vf]jJiYcVG>J
KiUcVGNHMkQgUWNg0W^e00AkU7^dNkAk/`9kTP03Ni=k/W^B009kTP05Nk9kTW^cNk=k]002MkH2MkP3
LkT02VnKKiY_VVnJJg]WNf]kIg][Ne/l0ell00QK?5llE_aG75KlEaaFo5LL15Kl00ABo5KlD_aFo0=B
o003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aBo5;lD_aB
g5;lOol0019oo`008Goo00<007ooOol0:Goo00<007ooOol087oo00AC7DklDae>o@<0001LC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeBo5LMDaaG7E<LEaeG75LmEaaOGE/l
GceK?5mMGcaOG5llHeeWNf]lJgY_Vf]jKi]_VG>JKiUcVW>HMkUgUW^gMiEk]W^ENkAkTgncNi9k/W^C
Ok=kTW^bNi5k/W^BNk=gTW_ENi9k/gNBNmEg]W_FMkEgf7NgKi][VV^LIg][VfMkJiaSFfMlFaaO?09K
?01CFaaK?5KlEaaFo5/LE_aG75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`0000BOol0021oo`03
001oogoo02]oo`03001oogoo01aoo`04Dae>oE;mD_d300000e;mDae>o@02D_d01E<MC_eBoE;mDad0
0e;m00IC7E;mDaeBoE<MD_d8Dad2Ead01ULmEaaG7ELMEceG709K?003GeaO?5mL009OG00=GcaOG6]j
Ki][NV^JLiUcVVnILiUgV7NhMiH00WNg00=k]G^ENk@00W^d00AkTW^dNiAk/`=kTP03Nk9kTW^b009k
/`03Ni9k/g^c009k]09g]P0:NmIg]gNhMkQ[NfMkJg]WNfMlHe/2He`00fMlFaaK7004Fa`00eKlEaaF
o002E_`01ELLD_aFo5;lE_`00e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g002D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00004Goo000POol00`00Oomoo`0/Ool00`00Oomoo`0F
Ool01U<MC_eC7DklDae>o@<0001HC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDae>o5<MD_aG7E;lEaeC75LMD_aK?ELLEceG75/mEaaG?ELLHeeO?5mLGcaSGEllGeaSFfMlHe]S
G6nILiY_VG>JLiQg^G>HNkMgUW^fNiEk]G^COkAkTW^eNi=o]7^BNk9kTG^bNi5k/W^ANk9kTG^bMi9k
/gNdNmIg]G_FMkMgf7>gLkX2LkT02V=KIgaSFfMlHe]WO5llHeaK75/l0U/L05=Fo5/LE_aG75;lEaaF
o5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00011oo`0087oo00<007oo0000;Goo00<007oo
Ool04goo00=BoE<MC_d00U;m0`0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;m
DaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad01ULMDaeG7E<MEaeC7@9G7@06EceG75LMFcaK?ELL0emL00=O
?6=LHe`00f=L0VMk00E_VG>ILiUg^7>H009g]`03NkMkUG^e009k]00>NiAk]G^DNkAkTW^CNi9k/W^B
Nk9kTW^bNi9k/P9k/`9k]003MkIkeWNg009g^0=c^@03KiY_Vf=K00=SG009GcaOG5llHeaG75/LEaaK
75LL009Fo003EaaFo5Kl009Fo004D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l0P0047oo000POol2000_Ool00`00Oomoo`0?Ool01DkmDae>
o5<MC_d00`0005a>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMD_aG7ELLFceG75/mEaaK?ELLFceSFf=LHe]WO6=KHeaW
Ff]lIg][O6MKMkUcV7^gMiIk]g^ENkEgUG^gMiIk]GNEOkAkTg^cNi9o/W^ANk9kTW^bNi5k/WNBNk=k
TW^dMkEkeWNgMmQc]gOH0W>i069[VVnkJiY_VelkHeaO?6=LGc]SG5/lGcaFo5/LEaaK75KlEaaBo5Kl
D_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`003goo0005Ool50005Ool20005Ool40006
Ool00`00Oomoo`0_Ool00`00Oomoo`0<Ool015<MC_eBoE;m0`0000=BoE<MC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@0@D_eC7E<MEaeC
7ELMDaeG7ELLEaeK?5/mEaaK?E/lFcd2Fc`3He`6Ig/03VnKJgYcVG>ILiYcV7NhMiQk]gNFMkMk]G^d
Ni@2Ni<01G^bNi9kTW^CNk800g^B0W^c0W^d00=keWNfMkP00WNh0W>i00Q_VVnKKiY_VVMkJg]O?5mL
0Ull00QK?5llGcaK75LLFaaFo5LL25Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0Woo00<007ooOol037oo0004Ool2
00001Goo000007oo000017oo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0<7oo
00<007ooOol027oo00EC7DklDae>oE<M0080001PC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<L
EaeC75/mEaaK?E/lGeeK?5lmFcaOGE/lJgaWFf]lIg][O6MKKi][NW>JKiUcVVnIMkQcV7NiMiIk]gNE
NkIkTg^dNi9o/g^BNk=kTWnbNi9k/W^ANk9kTW^cMkAkeWNfMmQc]gOH0W>i06E[VVnkJiY[VfMkJiaW
Nf^KIg]O?5/lGcaK75llFcaG75KlFaaFo5LLE_aK75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aoo`0000ioo`0017oo0P000Woo00<007oo00003goo00<007ooOol00goo00<007ooOol0<Goo
00<007ooOol01Goo00A>oE;mD_eC7@<00006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@0>DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@EC7@9G7@05EaaG7ELM
EaeG7002Fc`01U/mFcaK?5/lFceK?09OG0=WN`0;JgY_Vf]jJiYcVG>JKiUg^7NHMkQgUP02MkL02G^e
NiAk]7^CNk=kTW^dNi=k/`03Ni801G^bNk=k/g^dNk800W^c0W^d0WNf0WNh00Ug]f]kIg][NfMkJg]W
NfMlHe/00ell0e/L00EG75KlEaaFo5LL009Fo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`02E;LD_aBo5;lD]aBo000D_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=o
o`00Ool037oo0004Ool20002Ool00`00Ool0000?Ool00`00Oomoo`02Ool2000dOol02000Oomoogoo
C_aC7DkmDad30000cU<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E;lEaeC75LMDaaG7ELLEceG
75mMFcaO?E/lGeeO?5mLGcaSGFMkJga[NVnKJgY_VfnILiY_VGNhLiQg^G>HNkMgUW^fNiEk]7^COk=k
TW^bNi9o/g^BNk9kTG^bNi9k/gNBNk9kTW^cMkAkeGNdNmIg]GOHMkMc^FnIJiaWNf^KHe]WO6=KIgaS
Fe/lFaaK?5/LFcaK75LLD_aG75KlEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g7oo000<Ool000Aoo`80009oo`03001oo`0000]oo`@000Eoo`03001oogoo039oo`03D_eC7Dkm009B
o@06Dad00000001C7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@MC7@03EaeG?ELL009G7@06
EceG75/lFcaK?Ell0emL00eO?5mLJgY_Vf]jJiYcVG>JKiUg^7NHMkQcV002MkL02G^gNiEk]7^DNk=k
TW^CNiAk/`03Ni801W^bNi9kTW^BNk9kTP9k/`9k]09g]P03MkQg]gNh00=c^@9SG006IgaSFf=LGcaS
G5ll0e/L00AG75/LEaaG70=Fo009EaaFo5KlD_aFo5;lE_aBo5Kl00aBo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol000aoo`000goo0`0000Eo
o`00001oo`0000]oo`03001oogoo00Ioo`03001oogoo031oo`05Dae>o5<MC_eC7@030000eE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeBo5LMEaaG?ELLFceG75LmEaaS
GEllGeaO?6=MGcaOG6=KIgaSFf=LKiUcVVnILiYcV7NiLiQk]gNFNkMkUG^eNi=o]7^ENkEgUGncNi9k
/g^BNk9kTG^bNi5k/W^BNk=gTW_EMkAkeWNeMmQg]gOHKiUc^W>iKi][VVnkGcaSG5lkHeaO?6=LGc]K
75LLFaaFo5/LEaaFo5;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol0
000;Ool000Eoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo02eoo`05
Dae>oE;mD_eC7@0300001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m019C7E;mDaeBoE<MD_eC7E;mDaeB
oE<MD_eG7E<MEaeC7ELMDad2Ead01ULmEaaG7E/lFceG70=OG003GcaSG6=L00=SG0AWN`0;MiQg^7>H
MkQg]g^gMiIk]G^DNkAgUP02NkD01G^dNi9kTg^BNk800g^B00=k/W^BNk800W^c00Ik]7NfMkIg^7Ng
MkP3LkT2KiX01fnKIg][NellHeaO?5mL009O?006FcaK75LLFaaFo5LL1eKl0U;l00=Fo5;lD_`01U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;L
0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00ABg5;l000000Yoo`001Woo100037oo1@0017oo00<007ooOol0:goo00A>o5<MC_eC
7@<00021Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LM
D_aG7E<LEaeBo5LMEaaK?ELLFceG75/mEaaK?F=KHeaSFfMlHe]SG6MKJgaWNf]lJgY_Vf]jKi]gUW^g
MiIk]GNENkMgUW^eMiEk]W^CNk=kTWnbNi9k/g^BNk9kTG^bMi9k/gNdNkAg]G_FMkMgf7>gLkYc^FnK
JiY_^fMkJi]WNf^LIg]O?5/LGcaK?5ll009K701IE_aG75KlFaaBo5KlD_aG75;lE_aBo5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000:Ool001moo`03001oogoo02Qoo`05C_eBoE;mDae>
o@0200001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m
0e<M011BoE<MDaeG7E<MEaeC7ELMEaaG7E/lFceG75/mFcaK?@9K?0=SG0EWN`0<JgY_Vf]jJiYcVG>J
KiUg^7NHMkQgUWNg0W^e00AkU7^CNi=k/P=kTP04Nk9kTW^BNi82Nk<017^dMkIkeWNg0WNh0W>i0VnJ
00I_VfMkJg]WNf]kIg/2He`00ellFcaO?003Fa`02eLLE_aG75KlEaaBo5KlD_aFo5;lE_`00e;l00=F
o5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`00e;L00000009Ool001ioo`8002Eoo`07C_eC7DklDae>oE<MC_`00`00
0>9>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;l
DaeBo5<MD_aG7E<LEaeC75LMDaaG7ELLFceG75mMFcaO?E/lGeeK?6]lIe][O6MkJga[NVnKJgY_VfnI
LiY_VG>JLiQg^GNFNkMgUG^fNiEk]7^BOk=kTW^bNi9o/W^ANk9gTW^bNi9k]7NBNk=kTW^dMkAkeWNf
MmQc]gOHIg][VfMkJiaSFfMlHe]WO6=KFcaK75/lFaaK?5KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol000Uoo`007Woo00<007ooOol08Woo00IC7Dkm
D_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>DaeBoE;m
D_eC7E;mDaeBoE<MD_eC7E;mDaeBo@IC7@03EaeG75LM009G7@04EaaG7E/lFcd3Fc`015/mFcaOG5mL
0fMk00][NVnKJgY[VV]jLiY_VG>IMiQg^7>H009g]`05NkEkUG^dNi=k/`02Ni800g^DNk9kTP02Ni80
17^bNk=k/g^B0W^c0g^d0WNf0WNh0g>i00QWO6=KHeaSG6MlHe]OG5ll1E/L0eKl00UG75KlE_aBo5Kl
D_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00`00Oomoo`07Ool001ioo`03001oogoo021o
o`05C_aC7DkmDae>o0030000OTklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMD_aG7E<LEaeC75LmEaaK?E/lGceK
?5mMGcaOG5llHeeO?5mLJgY_Vf]jKi][NW>JKiUcVW>HMkUcV7^gMiIk]W^ENkEkTgncNi9k]7^COk=k
TW^bNi5k/W^BNk9kTG^bNi9k/gNdNmEg]W_FLkMgf09c^@0BKiU_^f^JIgaSFfMlGcaSG5lkHeaO?5/L
E_aK75LLFaaBo5LL0UKl04mBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg004Ool0
0`00Oomoo`07Ool001ioo`03001oogoo01ioo`9Bo@03Dae>o@0000800005C_eBoE;mDae>o@02D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC
7E;mDaeBo@QC7@06EceG75LMEaeG?ELL0ULM00=OG5llGe`00UmL01QO?5mLHeaSG6]jJiY[NW>JKiUc
VGNHMkQcV7NhMkMk]g^ENkEkU7^cNi9k]G^DNk@3Ni801G^bNi9kTW^BNk800W^c0W^d0WNf0WNh00Ag
]g>iLkU_V`=_VP05HeaO?5mLGcaSG003Gc`01E/LEaaK75LLFa`01UKl00=Bo5KlD_`00U;l00=Fo5;l
D_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo0Moo`03001oogoo00Ioo`007Woo00<007ooOol06goo00AC7DkmDae>o0<0003TC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMDaaG?ELLFceG75LmEaaK?ELLGeaO?6=MGcaO
G6=KIgaSFf=LHe]cVVnILiY_VGNiLiQg^7NFNkMkUG^eMiEo]7^ENkEkTgndNi9k/W^BNk9kTW^bNi5k
/W^BNk=gTW_EMkIkeWNeMmQg]g>iKiUc^V^JKi][VV^LIg]SG5lkHeaK?5llFaaO?5LLFaaFo5/LE_aG
75;lEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l2Woo00<007ooOol01Woo000MOol2000HOol0
1U<MC_eBoE;mDae>o@<00005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0<DaeBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M
011G7E<MEaeC7ELMDaeG?ELLEaeK?5/mEaaK?E/lGeaO?0ISG0AWN`06MkQcV7NhMiQk]gNF0W^e00Uk
]gNFNkEk]G^dNiAkTg^BNk800g^B00Ak/W^BNk9k/`9k]09g]P03MkQg]g>i009c^@9_VP07Ig][NfMk
Jg]WNellFc`00ell011K?5llE_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD_aFo0QBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`>Ool00`00Oomoo`06Ool001io
o`03001oogoo01Aoo`06C_aC7DkmDae>o5<M0P0009I>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7DklDaeBo5<MD_aG7E<LEaeBo5LMDaaK?ELLFceG75/mEaaK?ELLHeaSFfMlHe]SG6=KJgaWFf]l
Ie]_Vf]jKi][NW^gMiIg^7>HNkMgUW^eMiEo]7^CNk=kTWnbNi5k/W^BNk9kTG^bMi9k/gNdNk=gTW_E
MkAkeWNeNmI[VVnKIg][W6MkJi]WNfMlHe]O?5/LGc`2Fc`0BE/LFcaFo5LLE_aG75KlEaaBo5KlD_aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;L01=oo`03001oogoo00Ioo`007Goo00<007ooOol04goo0U;m00=C7DkmD_d00`000U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad015LMDaeG7ELL0ULM
00EK?ELLFceK?5/m00=K?0=SG0EWN`0;Ki][NV^JJgYcVVnIMkQgV7NhMiIg]`02NkD027^DNkAkTg^b
Ni9kTg^BNk83Ni800g^cNi9k/P02Nk<2Nk@017NfNmIg]gNh0W>i00EWNf]kHeaWO6=K009SG003IgaK
75/L00AK7003E_aG75Kl00=Fo008D_aFo5;lE_aBo5KlD_aFo0QBo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l
00IBg5;lD_aBo5;LD_`EOol00`00Oomoo`06Ool001eoo`03001oogoo015oo`04C_eC7DklDad30000
TE<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC
75LMDaaG7E<LEaeK?5mMFcaO?E/lGeeK?5lmIe][O6MKJgaWFfnKJgY_Vf]jLiY_VGNhLiQg^GNFNkMg
UG^fNi=k]7^BOk9kTW^dNi9o/W^BNk9gTW^cNi5k/WNBNk=g]7^dMkEkeWNfMmQc]g>j009c^@0:He]W
O6=KIgaSFf=LGcaSG5/LFc`2Fa`01UKlFaaFo5LLD_aG709Fo00kD]aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg00GOol00`00Oomoo`06Ool001eoo`80
00moo`04D_eC7DkmD_d30002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eB
oE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@04EaaG7ELMEcd3Fc`01E/mFcaK?5llGe`0
0fMk00Y_Vf]jJiY[NW>JKiUcVGNHMkQcV09g]`09NkEkUG^dNiAk/g^DNkAkTg^b00=kTP04Nk9kTG^b
Ni82Nk<2Nk@017_FMkIg^7Nh0g>i011_VVnKKiYOG5llHeaO?5mLGcaSG5LLFaaG75/LEaaK70IFo004
D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L01aoo`03001oogoo00Ioo`007Goo00<007ooOol02Goo
00I>o5<MC_eC7DklDad30000UE<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E;lEaeC75LMDaaG?ELLFceG75LmFcaOGE/lGeaO?6=MGcaO
G5llKi][NVnKJgYcVVnILiYcV7NiLiQk]gNFNkIkUG^dNi=o/g^ENkAkTgncNi9k/W^ANk9kTW^bMi9k
/g^BNkAg]7_FMkIgf7>gLkX00W>i00i[VVnkJiY[VfMkHeaO?6=LGc]O?5/lGcaFo5/L0ULL03YFo5/L
D_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol001moo`03001o
ogoo00Eoo`007Goo00<007ooOol01goo0U;m00=C7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1e<M00EG
75LMEaeG?ELL009G7@08EceO?5mLGcaOG5llGeaO?0ASG006LiY_VG>IMiQg^7>H0WNg00Uk]g^ENkEk
U7^dNiEk]7^DNk<00g^B00Ek/W^BNi9kTW^b009k/`9k]09g]P9g^09c^@07KiY_VfnJJg]WNf]kIg/0
0ell00QK?5llGcaO?5KlEaaFo5LL15Kl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOomo
o`02Ool00`00Oomoo`0LOol00`00Oomoo`05Ool001eoo`03001oogoo00Eoo`04C_eC7DklDad30000
VE<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDae>o5<MDaaG7E;lEaeC75LMEaaK?ELLEceG75/mEaaK?EllHeeO?5mLHe]WO6=KHeaS
Ff]lIe][O7>HMkUcV7NhMiIk]g^ENkEgUW^gNiEk]G^COkAkTW^bNi9k/W^BNk9kTG^bNi9k/gNdNmEg
]W_FLkMgf002LkT056^JKk][VV^KIg][W6MkIgaSFellFcaO?5/LFcaK75/lE_aK75KlEa`2E_`0;e;l
E_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`027oo00<007ooOol06goo00<007ooOol01Goo
000MOol01000Oomoodkm0U;m00AC7DkmD_eBo@80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m019C7DkmD_eBoE<MC_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<M
D_d2Dad03ULMDaeG7E<MEaeC7E/mFcaK?ELLFceK?5/mEa`6He`3Ig/04V]jKi][NV^JMkMk]gNFMkQg
V7^gMiIk]G^DNkAkTW^CNi9k/P=kTP06Nk9kTW^cNk=k]7^B0W^c00=k]7NfMkH00WNh00Eg]f]kIg][
Nf=K009SG003IgaSFf=L00IK70=Fo009EaaFo5KlD_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l00IBo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo0aoo`03001oogoo01]o
o`03001oogoo00Eoo`0077oo00P007ooDae>oE<MC_aC7Dkm0`000:i>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7E;lDaeBo5<MDaaG7E;lEaeC75LMDaaK?ELLFceG75/mEaaO?E/lIgaSFf=LIe][O6MKJga[NVnKJgY_
VfnILiY_VGNhLiQk]gNFNkEgUGndNi=k/g^BOk9kTW^cNi9k/W^BNk9gTW^bNi9k/gNBNmEg]7_FMkEg
f7NgLkU_VG>jHe]WO6=KIgaSFf=LGc]SG5/LFc`2Fa`0;ELLFaaBo5LLE_aG75;lE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg00AOol00`00Oomoo`0JOol00`00Oomoo`05Ool001aoo`03001C7Dkm009Bo@<00003D_eC7Dkm
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7Dkm
D_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMEa`00eLM00AG75/mFcaK
?@=K?003FceK?5/l00AWN`0<JgY_Vf]jJiYcVG>JKiUcVGNHMkQgUWNg0W^e00ikU7^CNi=k/W^DNi=k
TW^bNi5k/W^cNk9kTW^b0W^c00Ek]7NfMkIg^7Ng00=c^@=_VP0=HeaO?5mLGcaSG5llGeaG75/LEaaK
75LLFa`01UKl00ABo5KlD_aFo0iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`05goo00<007oo
Ool06Goo00<007ooOol01Goo000BOol50005Ool00`00C_d000020000/4kmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MD_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E<LEaeC75LMDaaO?E/lGceK?5lmFcaO?EllHeeW
Ff]lJgY_Vf]jKi][NW>JKiUcVW>HMkUgUW^gMiEk]W^CNkAkTWncNi=k/g^BOk9kTG^bMi9k/W^BNk9g
TW^cMkAk]7NeMmQg]gOHKiUc^V^JKi][VV^LIg]SG5lkHe`2Gc`0:U/LGcaG75/LE_aK75KlEaaBo5LL
D_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo1Yoo`03001oogoo01Qoo`03001oogoo00Eoo`0057oo00<007ooOol01Goo0P0000=BoE<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d7Dad2Ead01ELLEaeG7ELm
Ea`00U/l019K?E/lGeaO?5mLGcaOG6]jKi][NV^JJgYcVVnILiUgV7NhLiP2MkL02W^eNiEk]7^CNk=k
UG^dNi=k/g^A0W^B00Ak/W^ANk9kTP9k/`05NkAg]W_FMkMg^002LkT3KiX01V]kIg][NfMkGcaK?0=O
?006FcaO?5KlEaaFo5LL15Kl00=Bo5KlD_`00U;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg002D_`LOol00`00Oomoo`0IOol00`00Oomoo`04Ool001Aoo`03001oogoo00Ioo`2f
001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E;lEaeG75Lm
EaaK?ELLEceG75/mGcaOG5llHeeO?5mLHe]WO6]jKi][NW>JKiUcVW>HMkUcV7^gMiIk]W^ENkAkTg^f
NiEk]7^BOk=kTW^bNi5o/W^ANk9gTW^cNi9k]7NdNmIg]gOHKiUc^V^JKi][VV^LIg][VfMkIgaSFell
FaaO?09K?006FaaK?5KlEaaFo5/L0UKl01YBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5Kl8Goo00<007ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07
Ool200000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@AC
7@06EaeC7ELMEaeG?ELL0ULM00IK?ELLFceO?5mLGc`6He`04G>JKiUcVG>IMkQcV7NhMkMk]g^ENkEg
]g^gNiEk]G^DNk<00g^B00Ek/g^BNi9kTW^b009k/`07NkAk/g^cNkAg]W_FMkL00WNh00I[NfMkJg]S
G6MlHe/2He`7Fa`00eKlEaaFo003E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L
02Ioo`03001oogoo01Moo`03001oogoo00Aoo`0057oo00<007ooOol02Goo0:T007ooDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMDaaG7E;lEaeC75/mEaaK?ELLFceG75/mEaaS
G6=KIgaSFf=LHe][O6MKJgaWFgNiLiQg^7NFNkMcV7NhMiIk]g^ENkEkTgndNi9k/W^BOk=kTW^bNi5k
/W^BNk=gTW^bMi9k]7NdNmIg]WOHLkMc^P02LkT02V=KIgaSFfMlGc]SG5llFcaK75/l0U/L00IFo5/L
E_aG75;lEa`2E_`04U;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo2Qoo`03001oogoo
01Moo`03001oogoo00Aoo`0057oo00<007ooOol02Woo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eB
oE;mDaeBoE<MD_eC7E;m0e<M00UBoE<MDaeG7E<MEaeC7ELMEa`00ULM00IK?ELLFceK?5/mEa`2Fc`3
He`5Ig/01VnKJgY[VW>ILiYcV09gV009NkMgUW^eNkEk]7^BNi=kU7^c00=kTP05Nk9kTW^cNi9k/P02
Nk<00g^dNmIg]P02MkP3LkT046nJKi]_VUmLGcaSG5llGeaO?6=LEaaK75LLFaaG75/L1UKl00ABo5Kl
D_aFo0YBo2aoo`03001oogoo01Ioo`03001oogoo00Aoo`004Woo0`003Goo0:D007ooDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeC75/mEaaK?E/lGceK?5lmFca[
O6MKJgaWFf]lIe]_Vf]jKi]_VG>JLiQg^7>HNkMgUW^eMiEo]7^CNk=kTWncNi9k/W^BNk9kTW^bNi5k
/W^BNk=g]7_EMkIgf7>gMmP00W>i00i[VVnkJiY[VfMkHeaO?6=LGc]O?5/lGcaFo5/L0ULL015Fo5/L
D_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;L035oo`03001oogoo01Eoo`03001oogoo00Aoo`00
57oo00<007ooOol037oo0P0000IoodkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@05
D_eC7E<MDaeG7003Ead015LLEaeG7E/m0e/l00AK?E/lGeaO?0=WN`07JgY_Vf]jJiY[NW>JKiT00WNH
00=g^7NFMkL00W^e00QkU7^CNi=k]7^BNi=kTW^b0g^B00Ek/W^BNk=k/g^d009g]P0;MkQgf7>iLkU_
VVnKKiY[NfMkJg]WN`03Gc`025/lGcaO?5llE_aG75KlEa`4E_`015;lE_aBo5Kl0e;l00=Fo7ooOol0
=7oo00<007ooOol057oo00<007ooOol017oo000UOol0X000Oom>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7Dkl
EaeBo5LMD_aG7E;lEaeC75LMDaaG7ELLFceG75lmFcaO?EllGeaO?6=MGcaOG6]jKi][NVnKJgYcVVnI
MkQcV7NiMiIk]gNENkIkTg^dMiEk]W^CNk=kTWnbNi5k/W^ANk9kTW^bMi9keGNdNmIc]gOH0W>i01A[
VVnkJiY[VfMkJiaWNfMlHe]O?5/lGcaK75/lFaaK?5KlFaaFo5LL0UKl00EBo5KlD_aFo5;l03Yoo`03
001oogoo01Eoo`03001oogoo00=oo`009Woo00<007ooOol00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC
7E;mDaeBo@MC7@05EaaG7ELMEceG7002Ead01eLmGcaOG5llGeaO?5mL009SG005JgY[VV]jLiY_V@02
MiP01gNhMiIg]gNgNkEkUG^d009k]@0:NiAkTg^CNk9kTW^CNi9k/W^ANk82Nk<017^dNk=k/g^d0WNf
00Mg^7OHMkM[NfMkJg]SF`02He`00fMlHe]K7006Fa`3E_`01ELLE_aFo5;lE_`0?Goo00<007ooOol0
57oo00<007ooOol00goo000WOol0[P00Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5LMD_aG7E<L
EaeG75/mEaaG?ELLFceG75/mGcaSGEllHeaSFfMlHe]SG6=KLiY_VGNhLiQg^G>HNkMgUW^fNiEk]gNF
NkIkUG^dNi9o/W^BNk9kTWnbNi5k/WNBNk=kTW^bMi9keGNdNmIg]GOHMkMc^FnILkYSFfMlHe]WO5ll
HeaO>e/lFaaK?09K7007EaaK75;lEaaFo5LLD_`0@7oo00<007ooOol04goo00<007ooOol00goo000X
Ool200001GooD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d05U<MC_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eG7E<MEaeC7ELMDaeG7ELL0ULM
00EK?ELLFceK?5/m00MSG09WN`04JiY[NVnKJgX2MkL02G^gLiQg]gNgNkEkUG^dNi=k/`02Ni800g^C
Nk9kT@02Ni800g^cNi5k/P02Nk<01G^dMkIg]WOHMkL00g>i0fnJ00eSG5llGeaO?6=LGcaK75LLFaaG
75/LEaaK7015Ool00`00Oomoo`0BOol00`00Oomoo`03Ool002Yoo`2Y001ooe<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
D_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK?ELLFceK?5lmHe]WO6=KHeaWFf]lIe]_Vf]jKi][NW>J
KiUcVW>HMkQgUW^gNiEk]G^COk=kTW^bNi=o/g^BNk9gTW^bNi5k/WNANk=g]7^dMkEgf7NgMmQ_VG>j
JiY_Vf^JJiaWNf=LGc]SG5/lGc`00U/L00=G75/LE_`0Agoo00<007ooOol04Woo00<007ooOol00goo
000[Ool01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>
oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7ELL00=G7@04EaaK?E/l
Fcd3Fc`00e/mFcaWN`04Ig/00f]jKi][NP02LiT03G>JLiQgV7NgNkMkUG^eNiAk]7^BNkAkU7^c00=k
TP04Nk9kTW^BNi82Nk<01G^dMkIkeWNgMkP00W>i0fnJ00I[NfMkJg]WNellFc`3Gc`00e/lOomoo`19
Ool00`00Oomoo`0AOol00`00Oomoo`03Ool002aoo`2W001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeC
75LMDaaG7E<LEaeK?5lmFcaO?E/lGceK?5mLGca[O6MKJga[NVnKJgYcVVnILiY_VGNhLiQk]gNFNkEg
UGndNi9k]G^COkAkTW^bNi5k/W^BNk9kTG^bMi9k]7NdNmIg]gOHKiUc^V^JKi][VV^LIg][VfMkIgaS
FellFaaO?01>Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eBoE<MD_eC7E;mDaeBoE<M
D_d7Dad2Ead015LLEaeG7ELm0e/l00YK?EllGeaO?5mLGcaOG6]jKi][NP9cV@06LiY_VGNHMiQk]gNF
0W^e00Ek]7^DNkEkU7^d00=kTP05Nk9kTW^BNi9k/P02Nk<01g^dNk=k/g^dMkIkeWNg009g^006Jg]W
Nf]kHeaWO6=K0V=LDGoo00<007ooOol047oo00<007ooOol00Woo000_Ool0VP00Dae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;l
EaeBo5LMD_aG7ELLEceG75/mEaaG?ELLHeeO?5mLGcaSGEllGeaSFfMlHe]cVVnILiY_VGNhLiQk]gNF
NkMgUG^fMiIk]GNEOkAkTg^cNi9k/W^BNk9kTG^bNi9k/gNANk9gTW^dMkAkeWNfMmQc]g>j0W>i00AS
FfMlHe]WO5=oo`03001oogoo011oo`03001oogoo009oo`00<7oo00D007ooD_eC7Dkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<M
D_d4Dad03ULMDaeG7ELMEceG75LMFcaK?ELLGeaO?5mLGc`4He`4Ig/2MiP02WNhMiIg]gNHMkQgUWNg
NkEk]7^D0W^C00Uk/W^CNi9kTW^bNi9k/g^BNk800W^c00=k]7_FMkH00WNh0g>i00=_VVnKKiX0EWoo
00<007ooOol03goo00<007ooOol00Woo000aOol0UP00Oomooe<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeC75LMD_aG7E<LFceG
75/mEaaK?ELLFceSFf=LHe]WO6=KJgaWFf]lIe]_Vf]jKi]_VG>JLiQg^G>HNkMgUG^fNi=k]7^BOk9k
U7^cNi9k/W^ANk9kTG^bNi9k/gNdNmEg]WOHLkMgf09c^@03JiY_^f^J05Qoo`03001oogoo00ioo`03
001oogoo009oo`00<Woo00D007ooOomC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad02E;mDaeC7ELMDaeG7E<MEaeG7002Ead01E/mEaaK
?E/lFcd00U/l0f=L16Mk00A[VV]jKi]_V@9cV@0:MkQcV7NgMkMk]G^ENkAkTg^cNi@2Ni<01W^bNi5k
TW^BNk9kTP9k/`05NkAg]WNfMkQgf002LkT00fnJKi]oo`1IOol00`00Oomoo`0>Ool00`00Oomoo`02
Ool003=oo`80002@OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeG75/mEaaO?E/lGceK?5lmFca[O6MKJgaWFfnK
JgY_VfnILiY_VGNiLiQg^7NFNkIkUG^dNi=o/g^ENkAkTWnbNi5k/WNANk9kTG^bMi9keGNdNmIc]gOH
0W>i00=[VVnkOol0Fgoo00<007ooOol03Goo00<007ooOol00Woo000eOol01000OomC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<M
DaeC7ELL00=G7@04EaaG7E/lFcd3Fc`015/mFcaOG5ll0VMk00A[VV]jKi][NP9cV@0=MkQcV7NHMkMk
]g^ENkEkU7^eNiEk]7^DNk<00g^B00=k/W^ANk800W^c00Ak]7^cNk=k]09g]P03MkQgf7oo05eoo`03
001oogoo00aoo`03001oogoo009oo`00=Woo094007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aG7E;lEaeBo5LMDaaG7E<LEceG75/mFcaO?E/lGceO
?5mLGcaSGEllKi][NVnKJgYcVVnIMkUcV7NhMiIk]g^ENkEkTg^gNiEk]G^COk=kTW^bNi5o/g^BNk9g
TG^cNi9k/WNBNmEg]7_FMkEgf01POol00`00Oomoo`0;Ool00`00Oomoo`02Ool003Moo`04001ooe<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m
1e<M00EG75LMEaeG?ELL009G7@06GeaO?5mLGcaOG5ll16=L0W>I00IcVW>HMiQgV7^gMiH2NkD02G^g
NiEk]G^DNkAkTg^BNi=k/`03Ni800g^cNi5k/P02Nk<01G^dMkIg]WOHMkL0H7oo00<007ooOol037oo
00<007ooOol00Goo000hOol20000S5<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aC7E<LEaeBo5LMDaaG7ELLFceG75LmEaaK?ELLGeaO?6=MHe]SG6=KIgaSFf]k
Ie][O7>HMkQcV7^gMiIg^7>HNkMgUW^eMiEo]7^BNk=kTgncNi9k/W^ANk9kTG^bMi5k/gNdNkAg]GOH
MkMROol00`00Oomoo`0;Ool00`00Oomoo`01Ool003Yoo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d04U<MC_eBoE;mDae>oE<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@9C7@0=EaeC7ELMDaeG7ELLFceK
?5/mEaaK?E/lFcd01F=L0fMk00E[NV^JJgYcVVnI009gV00:MkQgUW^eNkEk]7^DNi=kTW^cNi<2Ni80
17^bNi9kTW^B0W^c00Ak]7NfNmIg]fAoo`03001oogoo00Yoo`03001oogoo005oo`00>goo08T007oo
OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeBo5LM
DaaG7ELLFceG75/mEaaO?E/lGceSFfMlIe][NfMKJga[NVnKJgYcVVnILiYcV7NiMiIk]gNENkIkU7^d
Ni9o]7^BNk=kTW^bNi9k/WNANk9gTW^dMkAkeWNd06Ioo`03001oogoo00Uoo`03001oogoo005oo`00
?7oo00<007ooOol00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeB
o@=C7@05D_eC7ELMEaeG7003Ead015LLFcaK?5/m0e/l00=K?FMkIg/00VMk00Y[NV^JJgYcVVnILiUg
V7NhMiIg]`9k]@09NiAk]7^CNkEkU7^CNi9k/W^A009kTP04Nk9k/g^cNk@2Nk<00g^dOomoo`1TOol0
0`00Oomoo`09Ool00`00Oomoo`01Ool003eoo`800024OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7E<LEaeC75LMEaaG?ELLGceK?5lmFcaSGEllGeaO?6=MJgY_
Vf]jLiY_VG>JLiQg^GNFNkMgUW^fNiEk]7^CNkIkU7^cNi9o/W^ANk=kTW^bNi9k/gNANk9gTW^dJ7oo
00<007ooOol027oo00<007ooOol00Goo000oOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@08DaeBoE<MD_eC7E;mDaeBo@MC7@03EaeG?ELL009G7@09EceG75LMGcaOG5llGeaO?5mL00=SG006
LiY_VG>ILiUg^7>H0WNg015k]G^EMkMg]g^eNiEk]7^CNk9kTW^CNi9k/W^BNk=kTW^b009k/`03NkAo
ogoo06Moo`03001oogoo00Moo`03001oogoo005oo`00@7oo088007ooDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG75LmEaaK?ELLEceG75/mGcaOG5llIgaSFf=L
He][O6MKJg]WFgNiLiQk]gNFNkMcV7NhMiIk]g^ENkAkTWncNi9k]7^BOk9kTG^bNi5k/W^BNk=g]6]o
o`03001oogoo00Moo`40005oo`5oo`00@Goo00H007ooOomBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0@Dae>oE;mD_eC7E;mDaeB
oE<MD_eC7E;mDaeBoE<MD_d2Dad015LMDaeG7E<M0ULM00MG?ELLFceK?5/mEaaK?@05He`4Ig/05VnK
JgYcVG>ILiYcV7NHMkMk]g^ENkEkU7^cNi9k]7^CNk9kTG^bNi9k/W^B0W^c00=k]7ooOol0JGoo00<0
07ooOol01goo0@000Goo0Goo0012Ool20000OGooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;l
DaeBo5<MD_aG7E<LEaeBo5LMEaaK?ELLFceG75/mFcaO?F=KHeaSFf]lIe][NfMKKi][NVnKKiUcVW>H
MkQcV7^gMiIk]W^COkAkTW^dNi=o/g^BNk9kTW^bNi9k/WNBNmD0KGoo00<007ooOol01Woo0@000Goo
0Goo0014Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL
00=G7@05EaaG7E/lFceG7002Fc`015/mFcaK?5/l16Mk00I_Vf]jJgYcVG>JKiT2MiP03g^gMiIk]G^e
NkAkTg^eNiAk/g^CNi9kTg^bNi5k/P02Nk<00g^BOomoo`1/Ool00`00Oomoo`05Ool10001Ool1Ool0
04Eoo`1k001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E<LEaeC75LMDaaG7E<L
GceK?5lmFcaO?E/lHeeO?6]kIe]_Vf]jKi]_VG>JKiUg^7>HMkUgUW^fMiEo]7^DNkIkTgndNi9k/W^A
Ok9kTW^bMi5k/g^B06moo`03001oogoo00Eoo`40005oo`5oo`00AWoo00D007ooD_eC7Dkm009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC
7E;mD_eBoE<MD_eC7E;mDaeBo@MC7@05EaaG7ELMEaeG7002Ead02E/mFcaK?5llGeaO?5mLGca_V`03
JgX01g>JKiUgV7NHMkQgUWNg009k]@04MiIg]g^eNk@2Ni<00g^BNk=kTP02Ni800g^cNi5k/P1`Ool0
0`00Oomoo`04Ool10001Ool1Ool004Moo`80001gOomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;l
EaeBo5LMEaaK?ELLEceG75/mEaaOG5llHeeO?5mLGcaWO6=KHeaSFg>JKiUg^7>HMkUcV7^gLiQg^GNF
NkMgUGndNiAk/g^BOkAkTW^bNi5k/W^ANk9gT@1aOol00`00Oomoo`03Ool10001Ool1Ool004Uoo`04
001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@0BDaeBoE<MD_eC7E;mDaeBoE<MD_eC7E;mEaeC7ELMDaeG7ELL0ULM00MG?ELLFceK
?5mLGcaOG005He`2Ig/2JgX01VnKJgYcVGNHMkQcV09g]`06NkEkU7^CNi=k]7^C0W^B00Ak/W^BNi9k
TW=oo`03001oogoo00=oo`40005oo`00BWoo07D007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeB
o5LMDaaG7E;lFceG75/mEaaK?ELLFceSFfMlHe]SG6MKJgaWFfnKJgY_Vf]jLiY_VGNiLiQk]gNFNkIk
U7^dNi9k]W^DNk=kTW^bNi9k/WNANk80Lgoo00<007ooOol00goo0@000Goo001;Ool01000OomC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=B
o@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7E<M00=G7@05EaaK?E/lFceG7002Fc`00e/mFcaWN`04
Ig/00f]jKi][NP02LiT03WNhLiQgV7NgNkMkUG^dNi=k]G^DNi=kTW^bNi<2Ni800g^bNi9oo`1cOol0
0`00Oomoo`02Ool10001Ool004aoo`80001`Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG
7E<LGceK?5lmFcaO?E/lGeaO?6]lIe][Nf]jKi][NW>JKiUg^G>HMkQgUW^gNiEk]7^CNkIkUG^dNi9o
/W^ANk9kTG^bNi9fOol01@00Oomoogoo00000Goo001>Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d5
Dad2Ead01ELLEaeG7ELmEa`00U/l00YK?EllGeaO?5mLGcaOG6]jKi][NP9cV@0CLiYcV7NHMkMk]gNF
NkEg]g^gNiEk]7^DNk=kTW^CNi9k/W^BNk80Mgoo00@007ooOol0005oo`00Cgoo06l007ooC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
Dae>o5LMD_aG7E;lEaeBo5LmEaaK?ELLEceG75/mGcaOG5llHeeO?5mLHe]WO6=KLiY_VG>JLiQg^7>H
NkMgUWNhMiIk]g^ENkIkTgncNi9k]7^BOk9kTG^bNi80Mgoo00@007ooOol0005oo`00D7oo00<007oo
C_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m01IC7DkmD_eBoE<M
D_eC7E;mDaeBoE<MD_eC7E;mEaeC7ELMDaeG7E<MEceG709G7@06FceG75/mGcaOG5ll16=L0fMk0f]j
011cVVnIMiQgV7^gMiIk]G^DNkAkTg^dNi=k/W^ANk9kTWUoo`03001oo`00005oo`00DGoo0P0006Y>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MD_aC7E;lEaeC75LMD_aG7E<LFceG75/mEaaK?ELLFceSFf=LHe]WO6MKJg]WFf]lJgY_Vf]jLiY_
VGNhLiQk]gNFNkIgUGndNi9k]W^COk=kTW^bNi9o/WYoo`40005oo`400000Dgoo00H004kmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m
0e<M00EBoELMDaeG7ELL009G7@05FceG75/mFcaK?@03Fc`00e/mIg]WN`02Ig/3JgX03G>JKiUcVGNH
MkQgUWNgNkEk]7^DNkEkU7^c009kTP03Ni=k/W^B07]oo`800000E7oo06P007ooDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<L
EaeC75LMDaaG7E/lGceK?5lmFcaO?EllGeaWFf]lJgY_Vf]jKi]_VG>JLiQg^GNFNkMgUG^fNiAk]WNE
OkAkTW^bNi9o/W^BO7oo0P00001EOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01E<MD_eBoE;mDad00e;m00AC7E;mDaeBo@IC7@=G7@04EaaG7ELMEcd3Fc`01EmLGcaOG5ll
Ge`00f]j00I_VfnILiUgV7NhLiP2MkL02G^eMiIg]g^eNkAkU7^CNiAk/`02Ni9lOol2000005Ioo`1U
001oogooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
DaeBo5LMD_aG7E;lEaeG75LmEaaK?ELLEceO?6=MGcaOG5llHeeSFf=LHe]WO6nILiYcV7NiLiQk]gNF
MkUgUW^gMiEk]W^DNk=kTWncNi9k/P1iOol40002Ool005Moo`800004OomBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_d2Dad015LMDaeG7E<M0ULM
00QG?ELLFceK?5/mGcaOG5ll1F=L0VMk00=[NVnKJgX00W>I00Yg^7>HMkMg]g^eNiEk]7^CNkAkT`9k
TWEoo`@000Ioo`00FGoo068007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lEaeG75/mEaaK?ELLFceG76MlHe]SG6=KJgaWFf]kJgY_
Vf]jLiY_VG>JLiQk]gNFNkIkUG^dNi9k]W^BNk=kTWnbLGoo10002Woo001JOol01@00OomBoE<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad02eLM
DaeG7ELLEaeK?5/mEaaK?E/lFcd00U/l1FMk015_Vf]jJgYcVG>JLiQgV7NgNkMkUG^eNiAk]G^DNi=k
TW^b06ioo`@000ioo`00Fgoo05l007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeC75lmFcaO?E/lGceO?6=MIe][NfMKKi][NVnK
KiUcVW>HMkQgUW^gNiEk]W^CNkMkUG^dNi9o/W^B06Yoo`@0019oo`00G7oo0P0000=ooe<MC_d00U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d7Dad01ELLEaeG7ELMEa`00ULM00UK
?E/lGeaO?5mLGcaOG5llKi/00V]j00=cVG>JKiT00WNH00]k]gNFNkEk]G^gNiEk]7^CNk9kTW^d06Mo
o`<001Ioo`00GWoo05/007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aG7E;lEaeBo5LMEaaK?ELLEceG75/mEaaOG5llHeeO?5mLGcaWO6=KHea_VG>JKiUg^7>HNkMgUWNh
LiQk]gNFNkIkTgncNiAk]01TOol4000IOol005moo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;m
D_eC7@03D_d03U<MD_eC7E;mDaeBoE<MD_eG7E<MEaeC7ELMEa`2Ead01eLmEaaK?E/lGeaO?5mL00AS
G0=WN`9[NP0<LiY_VGNHMiQg^7NFNkEkU7^cNiEk]7^DH7oo10007Goo001POol0F000OomC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeBo5/mEaaK?ELLFceG
75/mHe]WO6=KJg]WFf]lIe]_Vf]jLiY_VG>JLiQg^GNFNkMgUGndNiEk]7^CGGoo10008Goo001QOol2
00001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeG7003Ead0
1ELLFceK?5/mEa`00U/l00=K?E/lIg/00VMk0f]j00e_VfnILiUgV7NhMiIg]g^eNkAgUW^eNiAk]01I
Ool4000UOol006=oo`1E001C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeB
o5LMDaaG7E<LEaeC75lmFcaO?E/lGceK?5mLGcaSGF]jKi][NVnKKiUcVW>HMkUgUW^gMiIk]WNFNkIk
TgndNi@0EWoo0`00:Goo001TOol00`00Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<M
D_d7Dad01ELLEaeG7ELmEa`00U/l00EK?EllGeaO?5mL00ASG005KiUcVG>IMkQcV002MkL01WNhMiIg
]g^eNkAkU5=oo`@002aoo`00IGoo058007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeB
o5LMD_aG7E<LEaeG75/mEaaG?ELLFceO?5mLGcaWO6=KHeaSFfMlIe][NfMKMkUcV7>JKgUg^G>HNkMg
UGndNiAk]4moo`@0031oo`00IWoo0P0000E>oE;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeB
o@9C7@0<EaeC7ELMDaeG7ELLFceK?5/mEaaK?E/l1F=L0fMk00I_Vf]jLiUcVG>JLiP2MkL00g^eNiAk
]01<Ool4000dOol006Qoo`1>001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeBo5LM
DaaG7ELLFceG75/mFcaO?E/lHeaSFf]lIe][NfMKKi][NW>JKgUcVW>HMkQgUW^fNiAk]7^CB7oo1000
>7oo001YOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeG7003Ead015LL
FcaK?5/m0e/l16Mk00Y_Vf]jJgYcVG>JLiQgV7NgNkMkU@9g]dEoo`@003aoo`00JWoo04/007ooDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MD_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMDaaG7E<LEaeG75LmEaaO?E/lGceO?6=LGcaOG5llKi][
NVnKKgUcVVnIMkQcV7^gNiEk]gNFNkL0@Woo0`00@7oo001[Ool20002D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeB
oE<MD_d6Dad035LmEaaG7ELMEceG75mLGcaOG5llGeaO?0=SG003LiUcVVnI009gV005NkMgUWNHMkMk
]`0oOol40013Ool006eoo`17001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMDaaG7E;lEaeC75LmEaaK?ELL
FceG76=LGcaOG6=KIgaSFf=LIe][O6MKKi][NW>JKiUg^7NFNkMgUP0kOol40017Ool006ioo`05001o
oe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MC_eC
7E;mDaeBoE<MD_eC7E;m0e<M00iBoELMDaeG7E<MEaeC7E/mEaaK?E/lFceG75/m0f=L16Mk0V]j00Ic
VVnILiUgV7^gMiLhOol4001;Ool006moo`13001oogooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC
75/mEaaK?ELLGceK?5lmFca[NfMKJga[NVnKJgY_VfnILiYcV7^gMiH0=Goo1000Cgoo001`Ool20000
0gooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=B
o@06DaeBoE<MD_eC7E;m0e<M00EBoELMEaeG7ELL009G7@09FceK?5/lFcaK?E/lGeaO?5mL00=[NP07
Ki]_VG>IMiQg^7NGMkL0<Woo0`00Dgoo001bOol0?`00C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG75LmEaaK
?ELLGceK?5lmGcaOG5llHeaSFf=LHe]WO6nILiY_NGNiMiIk]`0_Ool4001FOol007=oo`04001BoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@04DaeB
oE<MD_d4Dad01ULMDaeG7ELMEceG709G7@04EceO?5mLGc`5He`3Ig/00fnKKiUcV@0/Ool4001JOol0
07Aoo`0l001>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<M
C_aC7E;lDae>o5<MD_aC7E;lEaeC75LMD_aG7E<LFceG75/mEaaK?ELLIgaSFf=LHe][O6MKJg]WFfnK
KiUcVVmi:7oo1000GWoo001eOol200001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC
7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m15<M00AG7E<MEaeG709G7@05FceG75/mFcaK?@02Fc`5
Ig/016nKJgYcVG>I9Goo1000HWoo001gOol0=`00Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MDaaG7E<LEaeC75LMDaaO?E/lGceK?5lm
GcaSG6MKJg]WFfnKJgYcVVmi029oo`@006Ioo`00N7oo00<005<MC_d00U;m00IC7DkmD_eBoE<MC_d2
D_d01E<MC_eBoE;mDad00e;m00QC7E;mD_eBoE<MD_eC7E;m1E<M00EG75LMEaeG7ELL009G7@0:FceK
?5mLGcaOG5llGeaO?6nKJgX2LiT00g>JOomoo`0MOol3001ZOol007Uoo`0d001C7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeBo5/mEaaG
?ELLFceG75mLGcaSG5llGeaSFfMlHe][NfMKJg`LOol4001]Ool007Yoo`03001oodkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@9C7@04EaeC7ELMDad2
Ead01ULmEaaK?E/lFceG70ASG0=WNaUoo`@0075oo`00Ngoo0P0002i>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aK?ELLFceG75/mFcaO
?E/lIgaSFf]kIe][O1Ioo`@007Eoo`00OGoo00H004kmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m
00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05EaaG7ELMEaeG7002Ead01U/mFcaK?5/lFceK?0=WNa=o
o`@007Uoo`00OWoo02/004klDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aG7E;lEaeBo5LMDaaG7E<LEaeG75/mEaaO?E/lGceO?5mLGcaSG00@Ool4001mOol007moo`06001o
oe;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@EC7@05EaaG7ELMEceG
7002Ead015mLGcaOG5ll3goo0`00PGoo0020Ool200008e<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMDaaG7ELLFceG75LmEaaK?ELLFcd03Goo1000Q7oo0022Ool0
1@00D_eBoE<MC_d00U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00YG7E<MEaeC7ELM
DaeK?E/lFceG70]oo`@008Qoo`00Pgoo01h005<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEad9Ool4002<Ool008Aoo`05001ooe;mDae>o@02D_d035<M
D_eBoE;mDaeBoE<MD_eC7E;mDaeBo@EC7@03EaaG7ELM00Moo`@0091oo`00QGoo0P0001I>oE<MC_aC
7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7@Ioo`<009Aoo`00Qgoo00@005;mDae>
o@9Bo@0<DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;m1Woo1000Ugoo0028Ool03@00C_aC7DklDae>o5<M
C_aC7DklDae>o5<M00Ioo`@009]oo`00RGoo00<007ooDad00e;m00AC7E;mDaeBo@Aoo`@009moo`00
RWoo0P0000EC7DklDae>o5<M009oo`@00:=oo`00S7oo0P0000=oo`0000000P00Ygoo002=Ool2002[
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00
ogoo>goo0000\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.648 .763 .934 r
.38973 .79896 .39806 .80569 .41196 .80196 .40368 .79521 Mtetra
.649 .764 .933 r
.40368 .79521 .41196 .80196 .42594 .79813 .4177 .79139 Mtetra
.652 .766 .933 r
.4177 .79139 .42594 .79813 .43999 .79415 .43179 .78745 Mtetra
.658 .77 .932 r
.43179 .78745 .43999 .79415 .45411 .78988 .44596 .7833 Mtetra
.668 .776 .931 r
.44596 .7833 .45411 .78988 .46832 .7851 .46021 .77876 Mtetra
.686 .788 .928 r
.46021 .77876 .46832 .7851 .4826 .77936 .47454 .77353 Mtetra
.718 .808 .921 r
.47454 .77353 .4826 .77936 .49695 .77192 .48894 .76701 Mtetra
.768 .84 .906 r
.48894 .76701 .49695 .77192 .51136 .76148 .50341 .7582 Mtetra
.838 .879 .872 r
.50341 .7582 .51136 .76148 .52579 .74615 .51793 .7455 Mtetra
.91 .914 .809 r
.51793 .7455 .52579 .74615 .54017 .72379 .53244 .7268 Mtetra
.96 .928 .72 r
.53244 .7268 .54017 .72379 .55441 .69346 .54685 .70029 Mtetra
.975 .923 .634 r
.54685 .70029 .55441 .69346 .56844 .65742 .56108 .66641 Mtetra
.97 .917 .584 r
.56108 .66641 .56844 .65742 .58228 .62136 .57509 .62938 Mtetra
.963 .927 .597 r
.57509 .62938 .58228 .62136 .59604 .59093 .58896 .59545 Mtetra
.957 .949 .681 r
.58896 .59545 .59604 .59093 .60986 .56836 .60282 .5688 Mtetra
.923 .947 .793 r
.60282 .5688 .60986 .56836 .62379 .5527 .61677 .54983 Mtetra
.853 .903 .87 r
.61677 .54983 .62379 .5527 .63786 .54183 .63086 .53676 Mtetra
.781 .845 .9 r
.63086 .53676 .63786 .54183 .65206 .53389 .64508 .52748 Mtetra
.73 .802 .908 r
.64508 .52748 .65206 .53389 .66637 .5276 .65942 .52043 Mtetra
.7 .775 .91 r
.65942 .52043 .66637 .5276 .68078 .52221 .67387 .5146 Mtetra
.683 .759 .909 r
.67387 .5146 .68078 .52221 .69528 .5173 .68841 .50943 Mtetra
.674 .751 .909 r
.68841 .50943 .69528 .5173 .70986 .51262 .70304 .50461 Mtetra
.669 .746 .908 r
.70304 .50461 .70986 .51262 .72453 .50807 .71776 .49995 Mtetra
.666 .744 .908 r
.71776 .49995 .72453 .50807 .73927 .50356 .73255 .49537 Mtetra
.665 .743 .908 r
.73255 .49537 .73927 .50356 .75409 .49907 .74743 .49082 Mtetra
.664 .742 .908 r
.74743 .49082 .75409 .49907 .76899 .49458 .76239 .48627 Mtetra
.76239 .48627 .76899 .49458 .78397 .49007 .77742 .48172 Mtetra
.77742 .48172 .78397 .49007 .79903 .48555 .79254 .47715 Mtetra
.664 .741 .908 r
.79254 .47715 .79903 .48555 .81417 .481 .80773 .47256 Mtetra
.80773 .47256 .81417 .481 .82939 .47644 .823 .46795 Mtetra
.823 .46795 .82939 .47644 .84469 .47185 .83836 .46331 Mtetra
.83836 .46331 .84469 .47185 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.647 .763 .934 r
.38132 .79215 .38973 .79896 .40368 .79521 .39531 .78838 Mtetra
.648 .764 .933 r
.39531 .78838 .40368 .79521 .4177 .79139 .40938 .78456 Mtetra
.65 .765 .933 r
.40938 .78456 .4177 .79139 .43179 .78745 .42352 .78064 Mtetra
.654 .768 .933 r
.42352 .78064 .43179 .78745 .44596 .7833 .43773 .77657 Mtetra
.662 .773 .932 r
.43773 .77657 .44596 .7833 .46021 .77876 .45203 .7722 Mtetra
.676 .782 .93 r
.45203 .7722 .46021 .77876 .47454 .77353 .4664 .76732 Mtetra
.7 .797 .925 r
.4664 .76732 .47454 .77353 .48894 .76701 .48086 .76148 Mtetra
.74 .823 .915 r
.48086 .76148 .48894 .76701 .50341 .7582 .49538 .75391 Mtetra
.801 .859 .892 r
.49538 .75391 .50341 .7582 .51793 .7455 .50997 .74333 Mtetra
.875 .898 .845 r
.50997 .74333 .51793 .7455 .53244 .7268 .52458 .72781 Mtetra
.939 .924 .767 r
.52458 .72781 .53244 .7268 .54685 .70029 .53915 .70523 Mtetra
.971 .927 .674 r
.53915 .70523 .54685 .70029 .56108 .66641 .55357 .67461 Mtetra
.974 .919 .602 r
.55357 .67461 .56108 .66641 .57509 .62938 .56778 .63825 Mtetra
.966 .92 .581 r
.56778 .63825 .57509 .62938 .58896 .59545 .58179 .60188 Mtetra
.962 .938 .632 r
.58179 .60188 .58896 .59545 .60282 .5688 .59572 .57118 Mtetra
.945 .953 .738 r
.59572 .57118 .60282 .5688 .61677 .54983 .6097 .5484 Mtetra
.891 .929 .838 r
.6097 .5484 .61677 .54983 .63086 .53676 .6238 .53257 Mtetra
.815 .873 .889 r
.6238 .53257 .63086 .53676 .64508 .52748 .63804 .52156 Mtetra
.753 .821 .906 r
.63804 .52156 .64508 .52748 .65942 .52043 .65241 .51349 Mtetra
.713 .786 .909 r
.65241 .51349 .65942 .52043 .67387 .5146 .6669 .50708 Mtetra
.69 .766 .91 r
.6669 .50708 .67387 .5146 .68841 .50943 .68148 .50158 Mtetra
.678 .754 .909 r
.68148 .50158 .68841 .50943 .70304 .50461 .69616 .49656 Mtetra
.671 .748 .909 r
.69616 .49656 .70304 .50461 .71776 .49995 .71093 .49177 Mtetra
.667 .745 .908 r
.71093 .49177 .71776 .49995 .73255 .49537 .72578 .48711 Mtetra
.666 .743 .908 r
.72578 .48711 .73255 .49537 .74743 .49082 .7407 .48249 Mtetra
.665 .742 .908 r
.7407 .48249 .74743 .49082 .76239 .48627 .75571 .47789 Mtetra
.664 .742 .908 r
.75571 .47789 .76239 .48627 .77742 .48172 .7708 .47328 Mtetra
.7708 .47328 .77742 .48172 .79254 .47715 .78597 .46867 Mtetra
.664 .741 .908 r
.78597 .46867 .79254 .47715 .80773 .47256 .80122 .46403 Mtetra
.80122 .46403 .80773 .47256 .823 .46795 .81656 .45937 Mtetra
.81656 .45937 .823 .46795 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.647 .763 .934 r
.37283 .78527 .38132 .79215 .39531 .78838 .38686 .78148 Mtetra
.648 .763 .934 r
.38686 .78148 .39531 .78838 .40938 .78456 .40097 .77765 Mtetra
.649 .764 .933 r
.40097 .77765 .40938 .78456 .42352 .78064 .41516 .77373 Mtetra
.652 .766 .933 r
.41516 .77373 .42352 .78064 .43773 .77657 .42942 .7697 Mtetra
.658 .77 .932 r
.42942 .7697 .43773 .77657 .45203 .7722 .44377 .76545 Mtetra
.668 .776 .931 r
.44377 .76545 .45203 .7722 .4664 .76732 .45819 .76082 Mtetra
.686 .788 .928 r
.45819 .76082 .4664 .76732 .48086 .76148 .47269 .75547 Mtetra
.718 .808 .921 r
.47269 .75547 .48086 .76148 .49538 .75391 .48727 .74884 Mtetra
.768 .84 .906 r
.48727 .74884 .49538 .75391 .50997 .74333 .50192 .73989 Mtetra
.838 .879 .872 r
.50192 .73989 .50997 .74333 .52458 .72781 .51662 .72703 Mtetra
.91 .914 .809 r
.51662 .72703 .52458 .72781 .53915 .70523 .53131 .70813 Mtetra
.96 .929 .72 r
.53131 .70813 .53915 .70523 .55357 .67461 .54591 .68135 Mtetra
.975 .924 .633 r
.54591 .68135 .55357 .67461 .56778 .63825 .56032 .64717 Mtetra
.97 .917 .584 r
.56032 .64717 .56778 .63825 .58179 .60188 .57451 .60982 Mtetra
.964 .927 .598 r
.57451 .60982 .58179 .60188 .59572 .57118 .58855 .5756 Mtetra
.957 .949 .681 r
.58855 .5756 .59572 .57118 .6097 .5484 .60258 .5487 Mtetra
.923 .947 .793 r
.60258 .5487 .6097 .5484 .6238 .53257 .6167 .52954 Mtetra
.853 .902 .869 r
.6167 .52954 .6238 .53257 .63804 .52156 .63096 .5163 Mtetra
.781 .845 .9 r
.63096 .5163 .63804 .52156 .65241 .51349 .64535 .50689 Mtetra
.73 .802 .908 r
.64535 .50689 .65241 .51349 .6669 .50708 .65987 .49971 Mtetra
.7 .775 .91 r
.65987 .49971 .6669 .50708 .68148 .50158 .6745 .49377 Mtetra
.683 .759 .909 r
.6745 .49377 .68148 .50158 .69616 .49656 .68922 .48849 Mtetra
.674 .751 .909 r
.68922 .48849 .69616 .49656 .71093 .49177 .70403 .48355 Mtetra
.669 .746 .908 r
.70403 .48355 .71093 .49177 .72578 .48711 .71893 .47878 Mtetra
.666 .744 .908 r
.71893 .47878 .72578 .48711 .7407 .48249 .73391 .47409 Mtetra
.665 .743 .908 r
.73391 .47409 .7407 .48249 .75571 .47789 .74898 .46943 Mtetra
.664 .742 .908 r
.74898 .46943 .75571 .47789 .7708 .47328 .76412 .46477 Mtetra
.76412 .46477 .7708 .47328 .78597 .46867 .77935 .4601 Mtetra
.664 .741 .908 r
.77935 .4601 .78597 .46867 .80122 .46403 .79466 .45542 Mtetra
.79466 .45542 .80122 .46403 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44599 Mtetra
.82552 .44599 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43646 Mtetra
.85671 .43646 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.647 .763 .934 r
.36425 .77833 .37283 .78527 .38686 .78148 .37833 .77451 Mtetra
.37833 .77451 .38686 .78148 .40097 .77765 .39249 .77065 Mtetra
.648 .764 .933 r
.39249 .77065 .40097 .77765 .41516 .77373 .40672 .76673 Mtetra
.65 .765 .933 r
.40672 .76673 .41516 .77373 .42942 .7697 .42103 .76272 Mtetra
.654 .768 .933 r
.42103 .76272 .42942 .7697 .44377 .76545 .43542 .75854 Mtetra
.662 .773 .932 r
.43542 .75854 .44377 .76545 .45819 .76082 .44989 .75408 Mtetra
.676 .782 .93 r
.44989 .75408 .45819 .76082 .47269 .75547 .46444 .74909 Mtetra
.7 .797 .925 r
.46444 .74909 .47269 .75547 .48727 .74884 .47907 .74314 Mtetra
.74 .823 .915 r
.47907 .74314 .48727 .74884 .50192 .73989 .49378 .73545 Mtetra
.801 .859 .892 r
.49378 .73545 .50192 .73989 .51662 .72703 .50855 .72471 Mtetra
.875 .899 .845 r
.50855 .72471 .51662 .72703 .53131 .70813 .52335 .70902 Mtetra
.939 .925 .767 r
.52335 .70902 .53131 .70813 .54591 .68135 .5381 .6862 Mtetra
.971 .928 .674 r
.5381 .6862 .54591 .68135 .56032 .64717 .55271 .65529 Mtetra
.974 .919 .602 r
.55271 .65529 .56032 .64717 .57451 .60982 .5671 .61861 Mtetra
.966 .92 .582 r
.5671 .61861 .57451 .60982 .58855 .5756 .58129 .58192 Mtetra
.962 .938 .632 r
.58129 .58192 .58855 .5756 .60258 .5487 .59539 .55095 Mtetra
.945 .953 .739 r
.59539 .55095 .60258 .5487 .6167 .52954 .60954 .52795 Mtetra
.891 .929 .838 r
.60954 .52795 .6167 .52954 .63096 .5163 .62382 .51194 Mtetra
.815 .873 .889 r
.62382 .51194 .63096 .5163 .64535 .50689 .63823 .50078 Mtetra
.753 .821 .906 r
.63823 .50078 .64535 .50689 .65987 .49971 .65278 .49258 Mtetra
.713 .786 .909 r
.65278 .49258 .65987 .49971 .6745 .49377 .66744 .48606 Mtetra
.69 .766 .909 r
.66744 .48606 .6745 .49377 .68922 .48849 .68221 .48044 Mtetra
.678 .754 .909 r
.68221 .48044 .68922 .48849 .70403 .48355 .69707 .4753 Mtetra
.671 .748 .909 r
.69707 .4753 .70403 .48355 .71893 .47878 .71202 .4704 Mtetra
.667 .745 .908 r
.71202 .4704 .71893 .47878 .73391 .47409 .72706 .46562 Mtetra
.666 .743 .908 r
.72706 .46562 .73391 .47409 .74898 .46943 .74218 .46089 Mtetra
.665 .742 .908 r
.74218 .46089 .74898 .46943 .76412 .46477 .75738 .45618 Mtetra
.664 .742 .908 r
.75738 .45618 .76412 .46477 .77935 .4601 .77266 .45146 Mtetra
.77266 .45146 .77935 .4601 .79466 .45542 .78802 .44672 Mtetra
.664 .741 .908 r
.78802 .44672 .79466 .45542 .81005 .45071 .80347 .44197 Mtetra
.80347 .44197 .81005 .45071 .82552 .44599 .819 .43719 Mtetra
.819 .43719 .82552 .44599 .84107 .44123 .83462 .43239 Mtetra
.83462 .43239 .84107 .44123 .85671 .43646 .85032 .42757 Mtetra
.85032 .42757 .85671 .43646 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.646 .763 .934 r
.35559 .77131 .36425 .77833 .37833 .77451 .36972 .76746 Mtetra
.647 .763 .934 r
.36972 .76746 .37833 .77451 .39249 .77065 .38392 .76358 Mtetra
.648 .763 .934 r
.38392 .76358 .39249 .77065 .40672 .76673 .3982 .75964 Mtetra
.649 .764 .933 r
.3982 .75964 .40672 .76673 .42103 .76272 .41256 .75564 Mtetra
.652 .766 .933 r
.41256 .75564 .42103 .76272 .43542 .75854 .427 .7515 Mtetra
.658 .77 .932 r
.427 .7515 .43542 .75854 .44989 .75408 .44151 .74715 Mtetra
.668 .776 .931 r
.44151 .74715 .44989 .75408 .46444 .74909 .45611 .74241 Mtetra
.686 .788 .928 r
.45611 .74241 .46444 .74909 .47907 .74314 .47079 .73696 Mtetra
.718 .809 .921 r
.47079 .73696 .47907 .74314 .49378 .73545 .48555 .7302 Mtetra
.768 .84 .906 r
.48555 .7302 .49378 .73545 .50855 .72471 .50039 .72112 Mtetra
.838 .879 .873 r
.50039 .72112 .50855 .72471 .52335 .70902 .51527 .7081 Mtetra
.91 .914 .809 r
.51527 .7081 .52335 .70902 .5381 .6862 .53015 .68898 Mtetra
.96 .929 .72 r
.53015 .68898 .5381 .6862 .55271 .65529 .54494 .66194 Mtetra
.975 .924 .633 r
.54494 .66194 .55271 .65529 .5671 .61861 .55954 .62744 Mtetra
.97 .917 .584 r
.55954 .62744 .5671 .61861 .58129 .58192 .57391 .58977 Mtetra
.964 .927 .598 r
.57391 .58977 .58129 .58192 .59539 .55095 .58813 .55525 Mtetra
.957 .949 .682 r
.58813 .55525 .59539 .55095 .60954 .52795 .60233 .5281 Mtetra
.923 .947 .793 r
.60233 .5281 .60954 .52795 .62382 .51194 .61663 .50874 Mtetra
.853 .902 .869 r
.61663 .50874 .62382 .51194 .63823 .50078 .63106 .49535 Mtetra
.781 .845 .9 r
.63106 .49535 .63823 .50078 .65278 .49258 .64563 .48579 Mtetra
.73 .802 .908 r
.64563 .48579 .65278 .49258 .66744 .48606 .66033 .47849 Mtetra
.7 .775 .91 r
.66033 .47849 .66744 .48606 .68221 .48044 .67514 .47243 Mtetra
.683 .759 .909 r
.67514 .47243 .68221 .48044 .69707 .4753 .69005 .46703 Mtetra
.674 .751 .909 r
.69005 .46703 .69707 .4753 .71202 .4704 .70505 .46198 Mtetra
.669 .746 .908 r
.70505 .46198 .71202 .4704 .72706 .46562 .72013 .45709 Mtetra
.666 .744 .908 r
.72013 .45709 .72706 .46562 .74218 .46089 .73531 .45228 Mtetra
.665 .743 .908 r
.73531 .45228 .74218 .46089 .75738 .45618 .75056 .44751 Mtetra
.664 .742 .908 r
.75056 .44751 .75738 .45618 .77266 .45146 .7659 .44273 Mtetra
.7659 .44273 .77266 .45146 .78802 .44672 .78133 .43795 Mtetra
.664 .741 .908 r
.78133 .43795 .78802 .44672 .80347 .44197 .79683 .43314 Mtetra
.79683 .43314 .80347 .44197 .819 .43719 .81242 .42832 Mtetra
.81242 .42832 .819 .43719 .83462 .43239 .8281 .42347 Mtetra
.8281 .42347 .83462 .43239 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.646 .763 .934 r
.34685 .76422 .35559 .77131 .36972 .76746 .36103 .76034 Mtetra
.647 .763 .934 r
.36103 .76034 .36972 .76746 .38392 .76358 .37527 .75643 Mtetra
.37527 .75643 .38392 .76358 .3982 .75964 .3896 .75247 Mtetra
.648 .764 .933 r
.3896 .75247 .3982 .75964 .41256 .75564 .404 .74846 Mtetra
.65 .765 .933 r
.404 .74846 .41256 .75564 .427 .7515 .41849 .74434 Mtetra
.654 .768 .933 r
.41849 .74434 .427 .7515 .44151 .74715 .43305 .74007 Mtetra
.662 .773 .932 r
.43305 .74007 .44151 .74715 .45611 .74241 .4477 .7355 Mtetra
.676 .782 .93 r
.4477 .7355 .45611 .74241 .47079 .73696 .46243 .7304 Mtetra
.7 .797 .925 r
.46243 .7304 .47079 .73696 .48555 .7302 .47724 .72433 Mtetra
.74 .823 .915 r
.47724 .72433 .48555 .7302 .50039 .72112 .49213 .71651 Mtetra
.801 .859 .892 r
.49213 .71651 .50039 .72112 .51527 .7081 .50709 .70563 Mtetra
.875 .899 .845 r
.50709 .70563 .51527 .7081 .53015 .68898 .52208 .68974 Mtetra
.939 .925 .766 r
.52208 .68974 .53015 .68898 .54494 .66194 .53702 .66668 Mtetra
.971 .928 .674 r
.53702 .66668 .54494 .66194 .55954 .62744 .55182 .63548 Mtetra
.974 .919 .602 r
.55182 .63548 .55954 .62744 .57391 .58977 .5664 .59848 Mtetra
.966 .92 .582 r
.5664 .59848 .57391 .58977 .58813 .55525 .58077 .56147 Mtetra
.962 .938 .633 r
.58077 .56147 .58813 .55525 .60233 .5281 .59505 .53022 Mtetra
.945 .953 .739 r
.59505 .53022 .60233 .5281 .61663 .50874 .60938 .50699 Mtetra
.89 .928 .838 r
.60938 .50699 .61663 .50874 .63106 .49535 .62383 .4908 Mtetra
.815 .873 .889 r
.62383 .4908 .63106 .49535 .64563 .48579 .63843 .47949 Mtetra
.753 .821 .906 r
.63843 .47949 .64563 .48579 .66033 .47849 .65316 .47116 Mtetra
.713 .786 .909 r
.65316 .47116 .66033 .47849 .67514 .47243 .668 .46451 Mtetra
.69 .766 .909 r
.668 .46451 .67514 .47243 .69005 .46703 .68295 .45877 Mtetra
.678 .754 .909 r
.68295 .45877 .69005 .46703 .70505 .46198 .698 .45351 Mtetra
.671 .748 .909 r
.698 .45351 .70505 .46198 .72013 .45709 .71314 .4485 Mtetra
.667 .745 .908 r
.71314 .4485 .72013 .45709 .73531 .45228 .72837 .4436 Mtetra
.666 .743 .908 r
.72837 .4436 .73531 .45228 .75056 .44751 .74368 .43875 Mtetra
.665 .742 .908 r
.74368 .43875 .75056 .44751 .7659 .44273 .75908 .43392 Mtetra
.664 .742 .908 r
.75908 .43392 .7659 .44273 .78133 .43795 .77456 .42908 Mtetra
.77456 .42908 .78133 .43795 .79683 .43314 .79013 .42423 Mtetra
.664 .741 .908 r
.79013 .42423 .79683 .43314 .81242 .42832 .80578 .41935 Mtetra
.80578 .41935 .81242 .42832 .8281 .42347 .82151 .41445 Mtetra
.82151 .41445 .8281 .42347 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.646 .763 .934 r
.33802 .75707 .34685 .76422 .36103 .76034 .35224 .75315 Mtetra
.35224 .75315 .36103 .76034 .37527 .75643 .36654 .7492 Mtetra
.647 .763 .934 r
.36654 .7492 .37527 .75643 .3896 .75247 .38091 .74522 Mtetra
.648 .763 .934 r
.38091 .74522 .3896 .75247 .404 .74846 .39536 .74119 Mtetra
.649 .764 .933 r
.39536 .74119 .404 .74846 .41849 .74434 .4099 .73708 Mtetra
.652 .766 .933 r
.4099 .73708 .41849 .74434 .43305 .74007 .42451 .73284 Mtetra
.658 .77 .932 r
.42451 .73284 .43305 .74007 .4477 .7355 .4392 .72839 Mtetra
.668 .776 .931 r
.4392 .72839 .4477 .7355 .46243 .7304 .45398 .72354 Mtetra
.686 .788 .928 r
.45398 .72354 .46243 .7304 .47724 .72433 .46884 .71798 Mtetra
.718 .809 .921 r
.46884 .71798 .47724 .72433 .49213 .71651 .48379 .71109 Mtetra
.768 .84 .906 r
.48379 .71109 .49213 .71651 .50709 .70563 .49882 .70187 Mtetra
.838 .88 .873 r
.49882 .70187 .50709 .70563 .52208 .68974 .51389 .68868 Mtetra
.91 .915 .809 r
.51389 .68868 .52208 .68974 .53702 .66668 .52896 .66934 Mtetra
.96 .929 .72 r
.52896 .66934 .53702 .66668 .55182 .63548 .54395 .64204 Mtetra
.975 .924 .633 r
.54395 .64204 .55182 .63548 .5664 .59848 .55874 .60722 Mtetra
.97 .917 .583 r
.55874 .60722 .5664 .59848 .58077 .56147 .57329 .56921 Mtetra
.964 .927 .598 r
.57329 .56921 .58077 .56147 .59505 .53022 .5877 .53439 Mtetra
.957 .949 .682 r
.5877 .53439 .59505 .53022 .60938 .50699 .60208 .50699 Mtetra
.923 .947 .793 r
.60208 .50699 .60938 .50699 .62383 .4908 .61655 .48743 Mtetra
.853 .902 .869 r
.61655 .48743 .62383 .4908 .63843 .47949 .63117 .47387 Mtetra
.781 .845 .9 r
.63117 .47387 .63843 .47949 .65316 .47116 .64592 .46417 Mtetra
.73 .801 .908 r
.64592 .46417 .65316 .47116 .668 .46451 .6608 .45674 Mtetra
.7 .775 .91 r
.6608 .45674 .668 .46451 .68295 .45877 .6758 .45055 Mtetra
.683 .759 .909 r
.6758 .45055 .68295 .45877 .698 .45351 .69089 .44503 Mtetra
.674 .751 .909 r
.69089 .44503 .698 .45351 .71314 .4485 .70609 .43986 Mtetra
.669 .746 .908 r
.70609 .43986 .71314 .4485 .72837 .4436 .72137 .43485 Mtetra
.666 .744 .908 r
.72137 .43485 .72837 .4436 .74368 .43875 .73673 .42992 Mtetra
.665 .743 .908 r
.73673 .42992 .74368 .43875 .75908 .43392 .75219 .42503 Mtetra
.664 .742 .908 r
.75219 .42503 .75908 .43392 .77456 .42908 .76773 .42013 Mtetra
.76773 .42013 .77456 .42908 .79013 .42423 .78335 .41522 Mtetra
.664 .741 .908 r
.78335 .41522 .79013 .42423 .80578 .41935 .79906 .41029 Mtetra
.79906 .41029 .80578 .41935 .82151 .41445 .81486 .40534 Mtetra
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.646 .763 .934 r
.32911 .74983 .33802 .75707 .35224 .75315 .34337 .74588 Mtetra
.34337 .74588 .35224 .75315 .36654 .7492 .35772 .7419 Mtetra
.647 .763 .934 r
.35772 .7419 .36654 .7492 .38091 .74522 .37214 .73789 Mtetra
.37214 .73789 .38091 .74522 .39536 .74119 .38664 .73383 Mtetra
.648 .764 .933 r
.38664 .73383 .39536 .74119 .4099 .73708 .40122 .72971 Mtetra
.65 .765 .933 r
.40122 .72971 .4099 .73708 .42451 .73284 .41588 .7255 Mtetra
.654 .768 .933 r
.41588 .7255 .42451 .73284 .4392 .72839 .43062 .72112 Mtetra
.662 .773 .932 r
.43062 .72112 .4392 .72839 .45398 .72354 .44545 .71644 Mtetra
.676 .782 .93 r
.44545 .71644 .45398 .72354 .46884 .71798 .46036 .71123 Mtetra
.7 .797 .925 r
.46036 .71123 .46884 .71798 .48379 .71109 .47536 .70504 Mtetra
.74 .823 .915 r
.47536 .70504 .48379 .71109 .49882 .70187 .49045 .69709 Mtetra
.801 .859 .893 r
.49045 .69709 .49882 .70187 .51389 .68868 .5056 .68605 Mtetra
.875 .899 .845 r
.5056 .68605 .51389 .68868 .52896 .66934 .52078 .66997 Mtetra
.939 .925 .766 r
.52078 .66997 .52896 .66934 .54395 .64204 .53592 .64667 Mtetra
.971 .928 .674 r
.53592 .64667 .54395 .64204 .55874 .60722 .55091 .61516 Mtetra
.974 .919 .601 r
.55091 .61516 .55874 .60722 .57329 .56921 .56568 .57783 Mtetra
.966 .92 .582 r
.56568 .57783 .57329 .56921 .5877 .53439 .58024 .54049 Mtetra
.962 .938 .633 r
.58024 .54049 .5877 .53439 .60208 .50699 .59471 .50896 Mtetra
.945 .953 .739 r
.59471 .50896 .60208 .50699 .61655 .48743 .60922 .48551 Mtetra
.89 .928 .838 r
.60922 .48551 .61655 .48743 .63117 .47387 .62385 .46914 Mtetra
.815 .873 .889 r
.62385 .46914 .63117 .47387 .64592 .46417 .63863 .45767 Mtetra
.753 .821 .906 r
.63863 .45767 .64592 .46417 .6608 .45674 .65354 .4492 Mtetra
.713 .786 .909 r
.65354 .4492 .6608 .45674 .6758 .45055 .66857 .44242 Mtetra
.69 .766 .909 r
.66857 .44242 .6758 .45055 .69089 .44503 .68372 .43656 Mtetra
.678 .754 .909 r
.68372 .43656 .69089 .44503 .70609 .43986 .69896 .43118 Mtetra
.671 .748 .909 r
.69896 .43118 .70609 .43986 .72137 .43485 .71429 .42604 Mtetra
.667 .745 .908 r
.71429 .42604 .72137 .43485 .73673 .42992 .72972 .42102 Mtetra
.666 .743 .908 r
.72972 .42102 .73673 .42992 .75219 .42503 .74523 .41605 Mtetra
.665 .742 .908 r
.74523 .41605 .75219 .42503 .76773 .42013 .76083 .41109 Mtetra
.664 .742 .908 r
.76083 .41109 .76773 .42013 .78335 .41522 .77651 .40613 Mtetra
.77651 .40613 .78335 .41522 .79906 .41029 .79228 .40115 Mtetra
.664 .741 .908 r
.79228 .40115 .79906 .41029 .81486 .40534 .80814 .39615 Mtetra
.80814 .39615 .81486 .40534 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38607 Mtetra
.84012 .38607 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .762 .934 r
.3201 .74253 .32911 .74983 .34337 .74588 .33441 .73854 Mtetra
.646 .763 .934 r
.33441 .73854 .34337 .74588 .35772 .7419 .3488 .73452 Mtetra
.3488 .73452 .35772 .7419 .37214 .73789 .36327 .73047 Mtetra
.647 .763 .934 r
.36327 .73047 .37214 .73789 .38664 .73383 .37782 .72639 Mtetra
.648 .763 .934 r
.37782 .72639 .38664 .73383 .40122 .72971 .39245 .72225 Mtetra
.649 .764 .933 r
.39245 .72225 .40122 .72971 .41588 .7255 .40716 .71804 Mtetra
.652 .766 .933 r
.40716 .71804 .41588 .7255 .43062 .72112 .42195 .7137 Mtetra
.658 .77 .932 r
.42195 .7137 .43062 .72112 .44545 .71644 .43683 .70914 Mtetra
.668 .776 .931 r
.43683 .70914 .44545 .71644 .46036 .71123 .4518 .70418 Mtetra
.686 .788 .928 r
.4518 .70418 .46036 .71123 .47536 .70504 .46685 .6985 Mtetra
.718 .809 .921 r
.46685 .6985 .47536 .70504 .49045 .69709 .48199 .69149 Mtetra
.768 .84 .906 r
.48199 .69149 .49045 .69709 .5056 .68605 .4972 .68212 Mtetra
.838 .88 .873 r
.4972 .68212 .5056 .68605 .52078 .66997 .51247 .66875 Mtetra
.91 .915 .809 r
.51247 .66875 .52078 .66997 .53592 .64667 .52775 .64919 Mtetra
.96 .929 .72 r
.52775 .64919 .53592 .64667 .55091 .61516 .54293 .62161 Mtetra
.975 .924 .633 r
.54293 .62161 .55091 .61516 .56568 .57783 .55791 .58648 Mtetra
.97 .917 .583 r
.55791 .58648 .56568 .57783 .58024 .54049 .57266 .54813 Mtetra
.964 .927 .598 r
.57266 .54813 .58024 .54049 .59471 .50896 .58725 .513 Mtetra
.957 .948 .682 r
.58725 .513 .59471 .50896 .60922 .48551 .60182 .48534 Mtetra
.923 .946 .794 r
.60182 .48534 .60922 .48551 .62385 .46914 .61648 .46557 Mtetra
.853 .902 .869 r
.61648 .46557 .62385 .46914 .63863 .45767 .63128 .45184 Mtetra
.781 .845 .9 r
.63128 .45184 .63863 .45767 .65354 .4492 .64622 .442 Mtetra
.73 .801 .908 r
.64622 .442 .65354 .4492 .66857 .44242 .66129 .43443 Mtetra
.7 .774 .91 r
.66129 .43443 .66857 .44242 .68372 .43656 .67647 .42812 Mtetra
.683 .759 .909 r
.67647 .42812 .68372 .43656 .69896 .43118 .69176 .42247 Mtetra
.674 .751 .909 r
.69176 .42247 .69896 .43118 .71429 .42604 .70715 .41717 Mtetra
.669 .746 .908 r
.70715 .41717 .71429 .42604 .72972 .42102 .72263 .41204 Mtetra
.666 .744 .908 r
.72263 .41204 .72972 .42102 .74523 .41605 .7382 .40699 Mtetra
.665 .743 .908 r
.7382 .40699 .74523 .41605 .76083 .41109 .75386 .40197 Mtetra
.664 .742 .908 r
.75386 .40197 .76083 .41109 .77651 .40613 .7696 .39694 Mtetra
.7696 .39694 .77651 .40613 .79228 .40115 .78543 .39191 Mtetra
.664 .741 .908 r
.78543 .39191 .79228 .40115 .80814 .39615 .80135 .38685 Mtetra
.80135 .38685 .80814 .39615 .82409 .39112 .81736 .38177 Mtetra
.81736 .38177 .82409 .39112 .84012 .38607 .83346 .37667 Mtetra
.83346 .37667 .84012 .38607 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .762 .934 r
.31101 .73515 .3201 .74253 .33441 .73854 .32537 .73112 Mtetra
.646 .763 .934 r
.32537 .73112 .33441 .73854 .3488 .73452 .3398 .72707 Mtetra
.3398 .72707 .3488 .73452 .36327 .73047 .35432 .72298 Mtetra
.647 .763 .934 r
.35432 .72298 .36327 .73047 .37782 .72639 .36892 .71887 Mtetra
.36892 .71887 .37782 .72639 .39245 .72225 .3836 .71471 Mtetra
.648 .764 .933 r
.3836 .71471 .39245 .72225 .40716 .71804 .39836 .71048 Mtetra
.65 .765 .933 r
.39836 .71048 .40716 .71804 .42195 .7137 .4132 .70616 Mtetra
.654 .768 .933 r
.4132 .70616 .42195 .7137 .43683 .70914 .42813 .70167 Mtetra
.662 .773 .932 r
.42813 .70167 .43683 .70914 .4518 .70418 .44314 .69689 Mtetra
.676 .782 .93 r
.44314 .69689 .4518 .70418 .46685 .6985 .45825 .69156 Mtetra
.7 .797 .925 r
.45825 .69156 .46685 .6985 .48199 .69149 .47344 .68525 Mtetra
.74 .823 .915 r
.47344 .68525 .48199 .69149 .4972 .68212 .48871 .67715 Mtetra
.801 .859 .893 r
.48871 .67715 .4972 .68212 .51247 .66875 .50406 .66595 Mtetra
.875 .899 .845 r
.50406 .66595 .51247 .66875 .52775 .64919 .51944 .64967 Mtetra
.94 .925 .766 r
.51944 .64967 .52775 .64919 .54293 .62161 .53478 .62612 Mtetra
.971 .928 .673 r
.53478 .62612 .54293 .62161 .55791 .58648 .54998 .59432 Mtetra
.974 .919 .601 r
.54998 .59432 .55791 .58648 .57266 .54813 .56495 .55664 Mtetra
.966 .92 .582 r
.56495 .55664 .57266 .54813 .58725 .513 .5797 .51898 Mtetra
.962 .938 .633 r
.5797 .51898 .58725 .513 .60182 .48534 .59435 .48716 Mtetra
.945 .953 .739 r
.59435 .48716 .60182 .48534 .61648 .46557 .60905 .46348 Mtetra
.89 .928 .838 r
.60905 .46348 .61648 .46557 .63128 .45184 .62387 .44692 Mtetra
.815 .872 .889 r
.62387 .44692 .63128 .45184 .64622 .442 .63883 .43529 Mtetra
.753 .821 .906 r
.63883 .43529 .64622 .442 .66129 .43443 .65393 .42668 Mtetra
.713 .786 .909 r
.65393 .42668 .66129 .43443 .67647 .42812 .66916 .41976 Mtetra
.69 .766 .909 r
.66916 .41976 .67647 .42812 .69176 .42247 .6845 .41377 Mtetra
.678 .754 .909 r
.6845 .41377 .69176 .42247 .70715 .41717 .69994 .40827 Mtetra
.671 .748 .909 r
.69994 .40827 .70715 .41717 .72263 .41204 .71547 .403 Mtetra
.667 .745 .908 r
.71547 .403 .72263 .41204 .7382 .40699 .7311 .39786 Mtetra
.666 .743 .908 r
.7311 .39786 .7382 .40699 .75386 .40197 .74681 .39276 Mtetra
.665 .742 .908 r
.74681 .39276 .75386 .40197 .7696 .39694 .76262 .38767 Mtetra
.664 .742 .908 r
.76262 .38767 .7696 .39694 .78543 .39191 .77851 .38258 Mtetra
.77851 .38258 .78543 .39191 .80135 .38685 .79449 .37747 Mtetra
.664 .741 .908 r
.79449 .37747 .80135 .38685 .81736 .38177 .81057 .37233 Mtetra
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36718 Mtetra
.82673 .36718 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85933 .35678 Mtetra
.85933 .35678 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .762 .934 r
.30182 .7277 .31101 .73515 .32537 .73112 .31623 .72363 Mtetra
.31623 .72363 .32537 .73112 .3398 .72707 .33071 .71954 Mtetra
.646 .763 .934 r
.33071 .71954 .3398 .72707 .35432 .72298 .34528 .71542 Mtetra
.34528 .71542 .35432 .72298 .36892 .71887 .35992 .71126 Mtetra
.647 .763 .934 r
.35992 .71126 .36892 .71887 .3836 .71471 .37465 .70707 Mtetra
.648 .763 .934 r
.37465 .70707 .3836 .71471 .39836 .71048 .38946 .70283 Mtetra
.649 .764 .933 r
.38946 .70283 .39836 .71048 .4132 .70616 .40436 .69851 Mtetra
.652 .766 .933 r
.40436 .69851 .4132 .70616 .42813 .70167 .41933 .69406 Mtetra
.658 .77 .932 r
.41933 .69406 .42813 .70167 .44314 .69689 .4344 .68939 Mtetra
.668 .777 .931 r
.4344 .68939 .44314 .69689 .45825 .69156 .44955 .68431 Mtetra
.686 .788 .928 r
.44955 .68431 .45825 .69156 .47344 .68525 .4648 .67851 Mtetra
.718 .809 .921 r
.4648 .67851 .47344 .68525 .48871 .67715 .48013 .67136 Mtetra
.768 .84 .906 r
.48013 .67136 .48871 .67715 .50406 .66595 .49555 .66185 Mtetra
.838 .88 .873 r
.49555 .66185 .50406 .66595 .51944 .64967 .51102 .64829 Mtetra
.911 .915 .809 r
.51102 .64829 .51944 .64967 .53478 .62612 .5265 .62852 Mtetra
.96 .929 .719 r
.5265 .62852 .53478 .62612 .54998 .59432 .54188 .60065 Mtetra
.975 .924 .632 r
.54188 .60065 .54998 .59432 .56495 .55664 .55707 .56519 Mtetra
.97 .917 .583 r
.55707 .56519 .56495 .55664 .5797 .51898 .57202 .5265 Mtetra
.964 .927 .599 r
.57202 .5265 .5797 .51898 .59435 .48716 .5868 .49106 Mtetra
.957 .948 .683 r
.5868 .49106 .59435 .48716 .60905 .46348 .60155 .46314 Mtetra
.923 .946 .794 r
.60155 .46314 .60905 .46348 .62387 .44692 .6164 .44316 Mtetra
.853 .901 .869 r
.6164 .44316 .62387 .44692 .63883 .43529 .63139 .42926 Mtetra
.781 .845 .9 r
.63139 .42926 .63883 .43529 .65393 .42668 .64652 .41926 Mtetra
.73 .801 .908 r
.64652 .41926 .65393 .42668 .66916 .41976 .66178 .41155 Mtetra
.7 .774 .909 r
.66178 .41155 .66916 .41976 .6845 .41377 .67717 .40511 Mtetra
.683 .759 .909 r
.67717 .40511 .6845 .41377 .69994 .40827 .69266 .39933 Mtetra
.674 .751 .909 r
.69266 .39933 .69994 .40827 .71547 .403 .70824 .3939 Mtetra
.669 .746 .908 r
.70824 .3939 .71547 .403 .7311 .39786 .72393 .38864 Mtetra
.666 .744 .908 r
.72393 .38864 .7311 .39786 .74681 .39276 .7397 .38346 Mtetra
.665 .743 .908 r
.7397 .38346 .74681 .39276 .76262 .38767 .75557 .37831 Mtetra
.664 .742 .908 r
.75557 .37831 .76262 .38767 .77851 .38258 .77152 .37315 Mtetra
.77152 .37315 .77851 .38258 .79449 .37747 .78757 .36799 Mtetra
.664 .741 .908 r
.78757 .36799 .79449 .37747 .81057 .37233 .8037 .3628 Mtetra
.8037 .3628 .81057 .37233 .82673 .36718 .81993 .35758 Mtetra
.81993 .35758 .82673 .36718 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85933 .35678 .85266 .34707 Mtetra
.85266 .34707 .85933 .35678 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .762 .934 r
.29254 .72018 .30182 .7277 .31623 .72363 .30699 .71606 Mtetra
.30699 .71606 .31623 .72363 .33071 .71954 .32153 .71193 Mtetra
.646 .763 .934 r
.32153 .71193 .33071 .71954 .34528 .71542 .33614 .70777 Mtetra
.33614 .70777 .34528 .71542 .35992 .71126 .35084 .70358 Mtetra
.647 .763 .934 r
.35084 .70358 .35992 .71126 .37465 .70707 .36562 .69935 Mtetra
.36562 .69935 .37465 .70707 .38946 .70283 .38048 .69508 Mtetra
.648 .764 .933 r
.38048 .69508 .38946 .70283 .40436 .69851 .39542 .69075 Mtetra
.65 .765 .933 r
.39542 .69075 .40436 .69851 .41933 .69406 .41045 .68632 Mtetra
.654 .768 .933 r
.41045 .68632 .41933 .69406 .4344 .68939 .42557 .68172 Mtetra
.662 .773 .932 r
.42557 .68172 .4344 .68939 .44955 .68431 .44077 .67681 Mtetra
.675 .782 .93 r
.44077 .67681 .44955 .68431 .4648 .67851 .45607 .67137 Mtetra
.7 .797 .925 r
.45607 .67137 .4648 .67851 .48013 .67136 .47146 .66493 Mtetra
.74 .823 .916 r
.47146 .66493 .48013 .67136 .49555 .66185 .48694 .65669 Mtetra
.801 .86 .893 r
.48694 .65669 .49555 .66185 .51102 .64829 .50249 .64532 Mtetra
.875 .9 .845 r
.50249 .64532 .51102 .64829 .5265 .62852 .51807 .62884 Mtetra
.94 .925 .766 r
.51807 .62884 .5265 .62852 .54188 .60065 .53362 .60504 Mtetra
.971 .928 .673 r
.53362 .60504 .54188 .60065 .55707 .56519 .54902 .57292 Mtetra
.974 .919 .601 r
.54902 .57292 .55707 .56519 .57202 .5265 .56419 .5349 Mtetra
.966 .92 .582 r
.56419 .5349 .57202 .5265 .5868 .49106 .57914 .49691 Mtetra
.962 .938 .634 r
.57914 .49691 .5868 .49106 .60155 .46314 .59399 .4648 Mtetra
.945 .953 .739 r
.59399 .4648 .60155 .46314 .6164 .44316 .60887 .44088 Mtetra
.89 .928 .838 r
.60887 .44088 .6164 .44316 .63139 .42926 .62388 .42413 Mtetra
.815 .872 .889 r
.62388 .42413 .63139 .42926 .64652 .41926 .63904 .41234 Mtetra
.753 .821 .905 r
.63904 .41234 .64652 .41926 .66178 .41155 .65434 .40357 Mtetra
.713 .786 .909 r
.65434 .40357 .66178 .41155 .67717 .40511 .66976 .39652 Mtetra
.69 .766 .909 r
.66976 .39652 .67717 .40511 .69266 .39933 .6853 .3904 Mtetra
.678 .754 .909 r
.6853 .3904 .69266 .39933 .70824 .3939 .70094 .38476 Mtetra
.671 .748 .909 r
.70094 .38476 .70824 .3939 .72393 .38864 .71668 .37936 Mtetra
.667 .745 .908 r
.71668 .37936 .72393 .38864 .7397 .38346 .73252 .37409 Mtetra
.666 .743 .908 r
.73252 .37409 .7397 .38346 .75557 .37831 .74844 .36885 Mtetra
.665 .742 .908 r
.74844 .36885 .75557 .37831 .77152 .37315 .76446 .36364 Mtetra
.664 .742 .908 r
.76446 .36364 .77152 .37315 .78757 .36799 .78057 .35841 Mtetra
.78057 .35841 .78757 .36799 .8037 .3628 .79677 .35316 Mtetra
.664 .741 .908 r
.79677 .35316 .8037 .3628 .81993 .35758 .81306 .34789 Mtetra
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .3426 Mtetra
.82944 .3426 .83625 .35234 .85266 .34707 .84592 .33727 Mtetra
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72018 .30699 .71606 .29767 .70842 Mtetra
.29767 .70842 .30699 .71606 .32153 .71193 .31225 .70424 Mtetra
.31225 .70424 .32153 .71193 .33614 .70777 .32691 .70004 Mtetra
.646 .763 .934 r
.32691 .70004 .33614 .70777 .35084 .70358 .34166 .69581 Mtetra
.34166 .69581 .35084 .70358 .36562 .69935 .35649 .69155 Mtetra
.647 .763 .934 r
.35649 .69155 .36562 .69935 .38048 .69508 .3714 .68725 Mtetra
.648 .763 .934 r
.3714 .68725 .38048 .69508 .39542 .69075 .38639 .6829 Mtetra
.649 .764 .933 r
.38639 .6829 .39542 .69075 .41045 .68632 .40148 .67846 Mtetra
.652 .766 .933 r
.40148 .67846 .41045 .68632 .42557 .68172 .41665 .6739 Mtetra
.658 .77 .932 r
.41665 .6739 .42557 .68172 .44077 .67681 .4319 .66911 Mtetra
.668 .777 .931 r
.4319 .66911 .44077 .67681 .45607 .67137 .44725 .66391 Mtetra
.686 .788 .928 r
.44725 .66391 .45607 .67137 .47146 .66493 .4627 .65798 Mtetra
.718 .809 .922 r
.4627 .65798 .47146 .66493 .48694 .65669 .47823 .6507 Mtetra
.768 .84 .906 r
.47823 .6507 .48694 .65669 .50249 .64532 .49385 .64103 Mtetra
.838 .88 .873 r
.49385 .64103 .50249 .64532 .51807 .62884 .50953 .62729 Mtetra
.911 .915 .809 r
.50953 .62729 .51807 .62884 .53362 .60504 .52521 .60728 Mtetra
.96 .929 .719 r
.52521 .60728 .53362 .60504 .54902 .57292 .54081 .57914 Mtetra
.975 .924 .632 r
.54081 .57914 .54902 .57292 .56419 .5349 .5562 .54334 Mtetra
.97 .917 .583 r
.5562 .54334 .56419 .5349 .57914 .49691 .57135 .50431 Mtetra
.964 .927 .599 r
.57135 .50431 .57914 .49691 .59399 .4648 .58633 .46855 Mtetra
.958 .948 .683 r
.58633 .46855 .59399 .4648 .60887 .44088 .60128 .44037 Mtetra
.923 .946 .794 r
.60128 .44037 .60887 .44088 .62388 .42413 .61632 .42017 Mtetra
.853 .901 .869 r
.61632 .42017 .62388 .42413 .63904 .41234 .6315 .40609 Mtetra
.781 .845 .9 r
.6315 .40609 .63904 .41234 .65434 .40357 .64683 .39594 Mtetra
.73 .801 .908 r
.64683 .39594 .65434 .40357 .66976 .39652 .66229 .38808 Mtetra
.7 .774 .909 r
.66229 .38808 .66976 .39652 .6853 .3904 .67788 .3815 Mtetra
.683 .759 .909 r
.67788 .3815 .6853 .3904 .70094 .38476 .69357 .37559 Mtetra
.674 .751 .909 r
.69357 .37559 .70094 .38476 .71668 .37936 .70937 .37002 Mtetra
.669 .746 .908 r
.70937 .37002 .71668 .37936 .73252 .37409 .72526 .36463 Mtetra
.666 .744 .908 r
.72526 .36463 .73252 .37409 .74844 .36885 .74124 .35931 Mtetra
.665 .743 .908 r
.74124 .35931 .74844 .36885 .76446 .36364 .75732 .35402 Mtetra
.664 .742 .908 r
.75732 .35402 .76446 .36364 .78057 .35841 .77349 .34873 Mtetra
.77349 .34873 .78057 .35841 .79677 .35316 .78976 .34343 Mtetra
.664 .741 .908 r
.78976 .34343 .79677 .35316 .81306 .34789 .80611 .3381 Mtetra
.80611 .3381 .81306 .34789 .82944 .3426 .82256 .33275 Mtetra
.82256 .33275 .82944 .3426 .84592 .33727 .83911 .32737 Mtetra
.83911 .32737 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70842 .28825 .7007 Mtetra
.28825 .7007 .29767 .70842 .31225 .70424 .30288 .69648 Mtetra
.30288 .69648 .31225 .70424 .32691 .70004 .31759 .69223 Mtetra
.646 .763 .934 r
.31759 .69223 .32691 .70004 .34166 .69581 .33239 .68796 Mtetra
.33239 .68796 .34166 .69581 .35649 .69155 .34726 .68366 Mtetra
.647 .763 .934 r
.34726 .68366 .35649 .69155 .3714 .68725 .36223 .67932 Mtetra
.36223 .67932 .3714 .68725 .38639 .6829 .37727 .67494 Mtetra
.648 .764 .933 r
.37727 .67494 .38639 .6829 .40148 .67846 .39241 .6705 Mtetra
.65 .765 .933 r
.39241 .6705 .40148 .67846 .41665 .6739 .40763 .66595 Mtetra
.654 .768 .933 r
.40763 .66595 .41665 .6739 .4319 .66911 .42294 .66123 Mtetra
.662 .773 .932 r
.42294 .66123 .4319 .66911 .44725 .66391 .43834 .65621 Mtetra
.675 .782 .93 r
.43834 .65621 .44725 .66391 .4627 .65798 .45384 .65063 Mtetra
.7 .797 .925 r
.45384 .65063 .4627 .65798 .47823 .6507 .46943 .64406 Mtetra
.74 .823 .916 r
.46943 .64406 .47823 .6507 .49385 .64103 .48511 .63568 Mtetra
.801 .86 .893 r
.48511 .63568 .49385 .64103 .50953 .62729 .50087 .62413 Mtetra
.876 .9 .845 r
.50087 .62413 .50953 .62729 .52521 .60728 .51667 .60745 Mtetra
.94 .926 .766 r
.51667 .60745 .52521 .60728 .54081 .57914 .53243 .58338 Mtetra
.971 .928 .673 r
.53243 .58338 .54081 .57914 .5562 .54334 .54804 .55096 Mtetra
.974 .919 .601 r
.54804 .55096 .5562 .54334 .57135 .50431 .56342 .51259 Mtetra
.966 .92 .582 r
.56342 .51259 .57135 .50431 .58633 .46855 .57857 .47426 Mtetra
.962 .938 .634 r
.57857 .47426 .58633 .46855 .60128 .44037 .59361 .44185 Mtetra
.945 .952 .74 r
.59361 .44185 .60128 .44037 .61632 .42017 .6087 .41769 Mtetra
.89 .927 .838 r
.6087 .41769 .61632 .42017 .6315 .40609 .6239 .40074 Mtetra
.815 .872 .889 r
.6239 .40074 .6315 .40609 .64683 .39594 .63926 .38878 Mtetra
.753 .821 .905 r
.63926 .38878 .64683 .39594 .66229 .38808 .65475 .37987 Mtetra
.713 .786 .909 r
.65475 .37987 .66229 .38808 .67788 .3815 .67038 .37267 Mtetra
.69 .766 .909 r
.67038 .37267 .67788 .3815 .69357 .37559 .68613 .36641 Mtetra
.678 .754 .909 r
.68613 .36641 .69357 .37559 .70937 .37002 .70198 .36063 Mtetra
.671 .748 .909 r
.70198 .36063 .70937 .37002 .72526 .36463 .71792 .3551 Mtetra
.667 .745 .908 r
.71792 .3551 .72526 .36463 .74124 .35931 .73397 .34969 Mtetra
.666 .743 .908 r
.73397 .34969 .74124 .35931 .75732 .35402 .75011 .34432 Mtetra
.665 .742 .908 r
.75011 .34432 .75732 .35402 .77349 .34873 .76635 .33896 Mtetra
.664 .742 .908 r
.76635 .33896 .77349 .34873 .78976 .34343 .78267 .33359 Mtetra
.78267 .33359 .78976 .34343 .80611 .3381 .7991 .32821 Mtetra
.664 .741 .908 r
.7991 .32821 .80611 .3381 .82256 .33275 .81561 .32279 Mtetra
.81561 .32279 .82256 .33275 .83911 .32737 .83223 .31735 Mtetra
.83223 .31735 .83911 .32737 .85575 .32195 .84893 .31189 Mtetra
.84893 .31189 .85575 .32195 .87248 .31651 .86574 .30639 Mtetra
.86574 .30639 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .7007 .27873 .69289 Mtetra
.27873 .69289 .28825 .7007 .30288 .69648 .29341 .68863 Mtetra
.29341 .68863 .30288 .69648 .31759 .69223 .30817 .68434 Mtetra
.30817 .68434 .31759 .69223 .33239 .68796 .32302 .68003 Mtetra
.646 .763 .934 r
.32302 .68003 .33239 .68796 .34726 .68366 .33795 .67569 Mtetra
.33795 .67569 .34726 .68366 .36223 .67932 .35296 .67131 Mtetra
.647 .763 .934 r
.35296 .67131 .36223 .67932 .37727 .67494 .36806 .6669 Mtetra
.648 .763 .934 r
.36806 .6669 .37727 .67494 .39241 .6705 .38325 .66243 Mtetra
.649 .764 .933 r
.38325 .66243 .39241 .6705 .40763 .66595 .39852 .65788 Mtetra
.652 .766 .933 r
.39852 .65788 .40763 .66595 .42294 .66123 .41388 .6532 Mtetra
.658 .77 .932 r
.41388 .6532 .42294 .66123 .43834 .65621 .42934 .64829 Mtetra
.668 .777 .931 r
.42934 .64829 .43834 .65621 .45384 .65063 .44489 .64297 Mtetra
.686 .788 .928 r
.44489 .64297 .45384 .65063 .46943 .64406 .46054 .6369 Mtetra
.718 .809 .922 r
.46054 .6369 .46943 .64406 .48511 .63568 .47628 .62948 Mtetra
.768 .84 .907 r
.47628 .62948 .48511 .63568 .50087 .62413 .4921 .61965 Mtetra
.838 .88 .873 r
.4921 .61965 .50087 .62413 .51667 .60745 .508 .60572 Mtetra
.911 .916 .809 r
.508 .60572 .51667 .60745 .53243 .58338 .52389 .58548 Mtetra
.96 .93 .719 r
.52389 .58548 .53243 .58338 .54804 .55096 .53971 .55704 Mtetra
.975 .924 .632 r
.53971 .55704 .54804 .55096 .56342 .51259 .55531 .52091 Mtetra
.97 .917 .583 r
.55531 .52091 .56342 .51259 .57857 .47426 .57067 .48152 Mtetra
.964 .927 .599 r
.57067 .48152 .57857 .47426 .59361 .44185 .58585 .44544 Mtetra
.958 .948 .683 r
.58585 .44544 .59361 .44185 .6087 .41769 .601 .41699 Mtetra
.923 .946 .794 r
.601 .41699 .6087 .41769 .6239 .40074 .61624 .39658 Mtetra
.852 .901 .869 r
.61624 .39658 .6239 .40074 .63926 .38878 .63162 .38231 Mtetra
.781 .844 .9 r
.63162 .38231 .63926 .38878 .65475 .37987 .64715 .37199 Mtetra
.73 .801 .908 r
.64715 .37199 .65475 .37987 .67038 .37267 .66282 .36399 Mtetra
.7 .774 .909 r
.66282 .36399 .67038 .37267 .68613 .36641 .67861 .35726 Mtetra
.683 .759 .909 r
.67861 .35726 .68613 .36641 .70198 .36063 .69451 .35121 Mtetra
.674 .751 .909 r
.69451 .35121 .70198 .36063 .71792 .3551 .71052 .34551 Mtetra
.669 .746 .908 r
.71052 .34551 .71792 .3551 .73397 .34969 .72662 .33998 Mtetra
.666 .744 .908 r
.72662 .33998 .73397 .34969 .75011 .34432 .74283 .33452 Mtetra
.665 .743 .908 r
.74283 .33452 .75011 .34432 .76635 .33896 .75913 .32909 Mtetra
.664 .742 .908 r
.75913 .32909 .76635 .33896 .78267 .33359 .77552 .32366 Mtetra
.77552 .32366 .78267 .33359 .7991 .32821 .79201 .31821 Mtetra
.664 .741 .908 r
.79201 .31821 .7991 .32821 .81561 .32279 .80859 .31274 Mtetra
.80859 .31274 .81561 .32279 .83223 .31735 .82527 .30724 Mtetra
.82527 .30724 .83223 .31735 .84893 .31189 .84205 .30171 Mtetra
.84205 .30171 .84893 .31189 .86574 .30639 .85892 .29615 Mtetra
.85892 .29615 .86574 .30639 .88264 .30085 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .68501 Mtetra
.26911 .68501 .27873 .69289 .29341 .68863 .28384 .6807 Mtetra
.28384 .6807 .29341 .68863 .30817 .68434 .29865 .67637 Mtetra
.29865 .67637 .30817 .68434 .32302 .68003 .31355 .67201 Mtetra
.646 .763 .934 r
.31355 .67201 .32302 .68003 .33795 .67569 .32853 .66763 Mtetra
.32853 .66763 .33795 .67569 .35296 .67131 .34359 .66321 Mtetra
.647 .763 .934 r
.34359 .66321 .35296 .67131 .36806 .6669 .35875 .65876 Mtetra
.35875 .65876 .36806 .6669 .38325 .66243 .37399 .65426 Mtetra
.648 .764 .933 r
.37399 .65426 .38325 .66243 .39852 .65788 .38931 .6497 Mtetra
.65 .765 .933 r
.38931 .6497 .39852 .65788 .41388 .6532 .40473 .64503 Mtetra
.654 .768 .933 r
.40473 .64503 .41388 .6532 .42934 .64829 .42024 .64019 Mtetra
.662 .773 .932 r
.42024 .64019 .42934 .64829 .44489 .64297 .43585 .63504 Mtetra
.675 .782 .93 r
.43585 .63504 .44489 .64297 .46054 .6369 .45155 .62934 Mtetra
.7 .797 .926 r
.45155 .62934 .46054 .6369 .47628 .62948 .46734 .62262 Mtetra
.74 .823 .916 r
.46734 .62262 .47628 .62948 .4921 .61965 .48324 .61409 Mtetra
.801 .86 .893 r
.48324 .61409 .4921 .61965 .508 .60572 .49921 .60237 Mtetra
.876 .9 .845 r
.49921 .60237 .508 .60572 .52389 .58548 .51522 .58547 Mtetra
.94 .926 .766 r
.51522 .58547 .52389 .58548 .53971 .55704 .5312 .56114 Mtetra
.971 .928 .673 r
.5312 .56114 .53971 .55704 .55531 .52091 .54703 .52839 Mtetra
.973 .919 .601 r
.54703 .52839 .55531 .52091 .57067 .48152 .56262 .48968 Mtetra
.966 .92 .582 r
.56262 .48968 .57067 .48152 .58585 .44544 .57798 .451 Mtetra
.962 .938 .634 r
.57798 .451 .58585 .44544 .601 .41699 .59323 .4183 Mtetra
.945 .952 .74 r
.59323 .4183 .601 .41699 .61624 .39658 .60851 .39389 Mtetra
.89 .927 .838 r
.60851 .39389 .61624 .39658 .63162 .38231 .62392 .37674 Mtetra
.815 .872 .889 r
.62392 .37674 .63162 .38231 .64715 .37199 .63948 .36461 Mtetra
.753 .821 .905 r
.63948 .36461 .64715 .37199 .66282 .36399 .65518 .35553 Mtetra
.713 .786 .909 r
.65518 .35553 .66282 .36399 .67861 .35726 .67102 .34819 Mtetra
.69 .766 .909 r
.67102 .34819 .67861 .35726 .69451 .35121 .68697 .34178 Mtetra
.678 .754 .909 r
.68697 .34178 .69451 .35121 .71052 .34551 .70303 .33586 Mtetra
.671 .748 .909 r
.70303 .33586 .71052 .34551 .72662 .33998 .7192 .33019 Mtetra
.667 .745 .908 r
.7192 .33019 .72662 .33998 .74283 .33452 .73547 .32463 Mtetra
.666 .743 .908 r
.73547 .32463 .74283 .33452 .75913 .32909 .75183 .31912 Mtetra
.665 .742 .908 r
.75183 .31912 .75913 .32909 .77552 .32366 .76829 .31362 Mtetra
.664 .742 .908 r
.76829 .31362 .77552 .32366 .79201 .31821 .78484 .30811 Mtetra
.78484 .30811 .79201 .31821 .80859 .31274 .80149 .30257 Mtetra
.664 .741 .908 r
.80149 .30257 .80859 .31274 .82527 .30724 .81824 .29701 Mtetra
.81824 .29701 .82527 .30724 .84205 .30171 .83509 .29142 Mtetra
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .68501 .25939 .67704 Mtetra
.25939 .67704 .26911 .68501 .28384 .6807 .27417 .67269 Mtetra
.27417 .67269 .28384 .6807 .29865 .67637 .28903 .66831 Mtetra
.28903 .66831 .29865 .67637 .31355 .67201 .30398 .66391 Mtetra
.30398 .66391 .31355 .67201 .32853 .66763 .31901 .65948 Mtetra
.646 .763 .934 r
.31901 .65948 .32853 .66763 .34359 .66321 .33413 .65503 Mtetra
.33413 .65503 .34359 .66321 .35875 .65876 .34934 .65053 Mtetra
.647 .763 .934 r
.34934 .65053 .35875 .65876 .37399 .65426 .36463 .646 Mtetra
.648 .763 .934 r
.36463 .646 .37399 .65426 .38931 .6497 .38001 .64141 Mtetra
.649 .764 .933 r
.38001 .64141 .38931 .6497 .40473 .64503 .39548 .63674 Mtetra
.652 .766 .933 r
.39548 .63674 .40473 .64503 .42024 .64019 .41105 .63193 Mtetra
.658 .77 .932 r
.41105 .63193 .42024 .64019 .43585 .63504 .42671 .6269 Mtetra
.668 .777 .931 r
.42671 .6269 .43585 .63504 .45155 .62934 .44246 .62145 Mtetra
.686 .788 .928 r
.44246 .62145 .45155 .62934 .46734 .62262 .45832 .61524 Mtetra
.718 .809 .922 r
.45832 .61524 .46734 .62262 .48324 .61409 .47427 .60768 Mtetra
.768 .84 .907 r
.47427 .60768 .48324 .61409 .49921 .60237 .49031 .59768 Mtetra
.838 .881 .873 r
.49031 .59768 .49921 .60237 .51522 .58547 .50642 .58355 Mtetra
.911 .916 .809 r
.50642 .58355 .51522 .58547 .5312 .56114 .52254 .56307 Mtetra
.96 .93 .719 r
.52254 .56307 .5312 .56114 .54703 .52839 .53857 .53434 Mtetra
.975 .924 .632 r
.53857 .53434 .54703 .52839 .56262 .48968 .5544 .49786 Mtetra
.97 .917 .583 r
.5544 .49786 .56262 .48968 .57798 .451 .56997 .45812 Mtetra
.964 .927 .6 r
.56997 .45812 .57798 .451 .59323 .4183 .58536 .42171 Mtetra
.958 .948 .684 r
.58536 .42171 .59323 .4183 .60851 .39389 .60071 .39299 Mtetra
.923 .945 .794 r
.60071 .39299 .60851 .39389 .62392 .37674 .61615 .37235 Mtetra
.852 .901 .869 r
.61615 .37235 .62392 .37674 .63948 .36461 .63174 .3579 Mtetra
.781 .844 .9 r
.63174 .3579 .63948 .36461 .65518 .35553 .64748 .34742 Mtetra
.73 .801 .908 r
.64748 .34742 .65518 .35553 .67102 .34819 .66335 .33926 Mtetra
.7 .774 .909 r
.66335 .33926 .67102 .34819 .68697 .34178 .67936 .33238 Mtetra
.683 .759 .909 r
.67936 .33238 .68697 .34178 .70303 .33586 .69548 .32618 Mtetra
.674 .751 .909 r
.69548 .32618 .70303 .33586 .7192 .33019 .7117 .32034 Mtetra
.669 .746 .908 r
.7117 .32034 .7192 .33019 .73547 .32463 .72803 .31466 Mtetra
.666 .744 .908 r
.72803 .31466 .73547 .32463 .75183 .31912 .74445 .30906 Mtetra
.665 .743 .908 r
.74445 .30906 .75183 .31912 .76829 .31362 .76098 .30348 Mtetra
.664 .742 .908 r
.76098 .30348 .76829 .31362 .78484 .30811 .7776 .2979 Mtetra
.7776 .2979 .78484 .30811 .80149 .30257 .79432 .2923 Mtetra
.664 .741 .908 r
.79432 .2923 .80149 .30257 .81824 .29701 .81113 .28668 Mtetra
.81113 .28668 .81824 .29701 .83509 .29142 .82805 .28103 Mtetra
.82805 .28103 .83509 .29142 .85203 .2858 .84507 .27535 Mtetra
.84507 .27535 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .6646 Mtetra
.2644 .6646 .27417 .67269 .28903 .66831 .27932 .66017 Mtetra
.27932 .66017 .28903 .66831 .30398 .66391 .29431 .65573 Mtetra
.29431 .65573 .30398 .66391 .31901 .65948 .3094 .65125 Mtetra
.646 .763 .934 r
.3094 .65125 .31901 .65948 .33413 .65503 .32457 .64675 Mtetra
.32457 .64675 .33413 .65503 .34934 .65053 .33983 .64221 Mtetra
.647 .763 .934 r
.33983 .64221 .34934 .65053 .36463 .646 .35517 .63764 Mtetra
.35517 .63764 .36463 .646 .38001 .64141 .37061 .63302 Mtetra
.648 .764 .933 r
.37061 .63302 .38001 .64141 .39548 .63674 .38614 .62833 Mtetra
.65 .765 .933 r
.38614 .62833 .39548 .63674 .41105 .63193 .40176 .62354 Mtetra
.654 .768 .933 r
.40176 .62354 .41105 .63193 .42671 .6269 .41747 .61857 Mtetra
.662 .773 .932 r
.41747 .61857 .42671 .6269 .44246 .62145 .43328 .61329 Mtetra
.675 .782 .93 r
.43328 .61329 .44246 .62145 .45832 .61524 .44919 .60745 Mtetra
.7 .797 .926 r
.44919 .60745 .45832 .61524 .47427 .60768 .4652 .6006 Mtetra
.74 .823 .916 r
.4652 .6006 .47427 .60768 .49031 .59768 .48131 .5919 Mtetra
.801 .86 .893 r
.48131 .5919 .49031 .59768 .50642 .58355 .4975 .58 Mtetra
.876 .9 .845 r
.4975 .58 .50642 .58355 .52254 .56307 .51374 .56288 Mtetra
.94 .926 .766 r
.51374 .56288 .52254 .56307 .53857 .53434 .52994 .53828 Mtetra
.971 .928 .672 r
.52994 .53828 .53857 .53434 .5544 .49786 .546 .50521 Mtetra
.973 .919 .601 r
.546 .50521 .5544 .49786 .56997 .45812 .56181 .46614 Mtetra
.966 .92 .582 r
.56181 .46614 .56997 .45812 .58536 .42171 .57738 .42711 Mtetra
.962 .938 .635 r
.57738 .42711 .58536 .42171 .60071 .39299 .59283 .39411 Mtetra
.945 .952 .74 r
.59283 .39411 .60071 .39299 .61615 .37235 .60832 .36945 Mtetra
.89 .927 .838 r
.60832 .36945 .61615 .37235 .63174 .3579 .62394 .35209 Mtetra
.815 .872 .889 r
.62394 .35209 .63174 .3579 .64748 .34742 .6397 .33978 Mtetra
.753 .821 .905 r
.6397 .33978 .64748 .34742 .66335 .33926 .65562 .33055 Mtetra
.713 .786 .909 r
.65562 .33055 .66335 .33926 .67936 .33238 .67167 .32305 Mtetra
.69 .766 .909 r
.67167 .32305 .67936 .33238 .69548 .32618 .68784 .31649 Mtetra
.678 .754 .909 r
.68784 .31649 .69548 .32618 .7117 .32034 .70412 .31043 Mtetra
.671 .748 .909 r
.70412 .31043 .7117 .32034 .72803 .31466 .72051 .30461 Mtetra
.667 .745 .908 r
.72051 .30461 .72803 .31466 .74445 .30906 .737 .2989 Mtetra
.666 .743 .908 r
.737 .2989 .74445 .30906 .76098 .30348 .75359 .29324 Mtetra
.665 .742 .908 r
.75359 .29324 .76098 .30348 .7776 .2979 .77028 .28758 Mtetra
.664 .742 .908 r
.77028 .28758 .7776 .2979 .79432 .2923 .78707 .28192 Mtetra
.78707 .28192 .79432 .2923 .81113 .28668 .80395 .27623 Mtetra
.664 .741 .908 r
.80395 .27623 .81113 .28668 .82805 .28103 .82094 .27052 Mtetra
.82094 .27052 .82805 .28103 .84507 .27535 .83803 .26478 Mtetra
.83803 .26478 .84507 .27535 .86218 .26963 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .6646 .25453 .65642 Mtetra
.25453 .65642 .2644 .6646 .27932 .66017 .2695 .65195 Mtetra
.2695 .65195 .27932 .66017 .29431 .65573 .28454 .64745 Mtetra
.28454 .64745 .29431 .65573 .3094 .65125 .29968 .64293 Mtetra
.29968 .64293 .3094 .65125 .32457 .64675 .3149 .63838 Mtetra
.646 .763 .934 r
.3149 .63838 .32457 .64675 .33983 .64221 .33021 .6338 Mtetra
.33021 .6338 .33983 .64221 .35517 .63764 .34562 .62919 Mtetra
.647 .763 .934 r
.34562 .62919 .35517 .63764 .37061 .63302 .36111 .62453 Mtetra
.648 .763 .934 r
.36111 .62453 .37061 .63302 .38614 .62833 .37669 .61981 Mtetra
.649 .764 .933 r
.37669 .61981 .38614 .62833 .40176 .62354 .39236 .61502 Mtetra
.652 .766 .933 r
.39236 .61502 .40176 .62354 .41747 .61857 .40813 .61008 Mtetra
.658 .77 .932 r
.40813 .61008 .41747 .61857 .43328 .61329 .424 .60491 Mtetra
.668 .777 .931 r
.424 .60491 .43328 .61329 .44919 .60745 .43997 .59933 Mtetra
.686 .789 .928 r
.43997 .59933 .44919 .60745 .4652 .6006 .45603 .59299 Mtetra
.718 .809 .922 r
.45603 .59299 .4652 .6006 .48131 .5919 .4722 .58527 Mtetra
.768 .841 .907 r
.4722 .58527 .48131 .5919 .4975 .58 .48847 .5751 Mtetra
.838 .881 .873 r
.48847 .5751 .4975 .58 .51374 .56288 .5048 .56077 Mtetra
.911 .916 .809 r
.5048 .56077 .51374 .56288 .52994 .53828 .52115 .54004 Mtetra
.96 .93 .719 r
.52115 .54004 .52994 .53828 .546 .50521 .53741 .51101 Mtetra
.975 .924 .631 r
.53741 .51101 .546 .50521 .56181 .46614 .55346 .47418 Mtetra
.97 .917 .583 r
.55346 .47418 .56181 .46614 .57738 .42711 .56926 .43408 Mtetra
.964 .927 .6 r
.56926 .43408 .57738 .42711 .59283 .39411 .58486 .39735 Mtetra
.958 .948 .684 r
.58486 .39735 .59283 .39411 .60832 .36945 .60042 .36834 Mtetra
.923 .945 .794 r
.60042 .36834 .60832 .36945 .62394 .35209 .61607 .34748 Mtetra
.852 .901 .869 r
.61607 .34748 .62394 .35209 .6397 .33978 .63186 .33283 Mtetra
.781 .844 .9 r
.63186 .33283 .6397 .33978 .65562 .33055 .64781 .32217 Mtetra
.73 .801 .908 r
.64781 .32217 .65562 .33055 .67167 .32305 .6639 .31386 Mtetra
.7 .774 .909 r
.6639 .31386 .67167 .32305 .68784 .31649 .68013 .30682 Mtetra
.683 .759 .909 r
.68013 .30682 .68784 .31649 .70412 .31043 .69647 .30048 Mtetra
.674 .751 .909 r
.69647 .30048 .70412 .31043 .72051 .30461 .71291 .29448 Mtetra
.669 .746 .908 r
.71291 .29448 .72051 .30461 .737 .2989 .72947 .28865 Mtetra
.666 .744 .908 r
.72947 .28865 .737 .2989 .75359 .29324 .74612 .2829 Mtetra
.665 .743 .908 r
.74612 .2829 .75359 .29324 .77028 .28758 .76288 .27716 Mtetra
.664 .742 .908 r
.76288 .27716 .77028 .28758 .78707 .28192 .77974 .27143 Mtetra
.77974 .27143 .78707 .28192 .80395 .27623 .79669 .26568 Mtetra
.664 .741 .908 r
.79669 .26568 .80395 .27623 .82094 .27052 .81375 .2599 Mtetra
.81375 .2599 .82094 .27052 .83803 .26478 .83091 .25409 Mtetra
.83091 .25409 .83803 .26478 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65642 .24456 .64815 Mtetra
.24456 .64815 .25453 .65642 .2695 .65195 .25957 .64363 Mtetra
.25957 .64363 .2695 .65195 .28454 .64745 .27467 .63909 Mtetra
.27467 .63909 .28454 .64745 .29968 .64293 .28986 .63452 Mtetra
.28986 .63452 .29968 .64293 .3149 .63838 .30513 .62992 Mtetra
.646 .763 .934 r
.30513 .62992 .3149 .63838 .33021 .6338 .3205 .6253 Mtetra
.3205 .6253 .33021 .6338 .34562 .62919 .33595 .62064 Mtetra
.647 .763 .934 r
.33595 .62064 .34562 .62919 .36111 .62453 .3515 .61594 Mtetra
.3515 .61594 .36111 .62453 .37669 .61981 .36714 .61119 Mtetra
.648 .764 .933 r
.36714 .61119 .37669 .61981 .39236 .61502 .38287 .60637 Mtetra
.65 .765 .933 r
.38287 .60637 .39236 .61502 .40813 .61008 .3987 .60145 Mtetra
.654 .768 .933 r
.3987 .60145 .40813 .61008 .424 .60491 .41462 .59635 Mtetra
.662 .773 .932 r
.41462 .59635 .424 .60491 .43997 .59933 .43064 .59094 Mtetra
.675 .782 .93 r
.43064 .59094 .43997 .59933 .45603 .59299 .44677 .58496 Mtetra
.7 .797 .926 r
.44677 .58496 .45603 .59299 .4722 .58527 .463 .57795 Mtetra
.74 .823 .916 r
.463 .57795 .4722 .58527 .48847 .5751 .47933 .56909 Mtetra
.801 .86 .893 r
.47933 .56909 .48847 .5751 .5048 .56077 .49574 .55701 Mtetra
.876 .9 .845 r
.49574 .55701 .5048 .56077 .52115 .54004 .51221 .53966 Mtetra
.94 .926 .766 r
.51221 .53966 .52115 .54004 .53741 .51101 .52864 .51479 Mtetra
.971 .928 .672 r
.52864 .51479 .53741 .51101 .55346 .47418 .54493 .48139 Mtetra
.973 .919 .6 r
.54493 .48139 .55346 .47418 .56926 .43408 .56097 .44195 Mtetra
.967 .92 .583 r
.56097 .44195 .56926 .43408 .58486 .39735 .57676 .40257 Mtetra
.963 .938 .635 r
.57676 .40257 .58486 .39735 .60042 .36834 .59243 .36926 Mtetra
.945 .952 .74 r
.59243 .36926 .60042 .36834 .61607 .34748 .60813 .34435 Mtetra
.89 .927 .838 r
.60813 .34435 .61607 .34748 .63186 .33283 .62396 .32678 Mtetra
.815 .872 .888 r
.62396 .32678 .63186 .33283 .64781 .32217 .63994 .31428 Mtetra
.753 .82 .905 r
.63994 .31428 .64781 .32217 .6639 .31386 .65607 .30488 Mtetra
.713 .786 .909 r
.65607 .30488 .6639 .31386 .68013 .30682 .67234 .29723 Mtetra
.69 .766 .909 r
.67234 .29723 .68013 .30682 .69647 .30048 .68873 .29051 Mtetra
.678 .754 .909 r
.68873 .29051 .69647 .30048 .71291 .29448 .70524 .28429 Mtetra
.671 .748 .909 r
.70524 .28429 .71291 .29448 .72947 .28865 .72186 .27832 Mtetra
.667 .745 .908 r
.72186 .27832 .72947 .28865 .74612 .2829 .73858 .27246 Mtetra
.666 .743 .908 r
.73858 .27246 .74612 .2829 .76288 .27716 .7554 .26664 Mtetra
.665 .742 .908 r
.7554 .26664 .76288 .27716 .77974 .27143 .77233 .26083 Mtetra
.664 .742 .908 r
.77233 .26083 .77974 .27143 .79669 .26568 .78935 .25501 Mtetra
.78935 .25501 .79669 .26568 .81375 .2599 .80648 .24916 Mtetra
.664 .741 .908 r
.80648 .24916 .81375 .2599 .83091 .25409 .82371 .24329 Mtetra
.82371 .24329 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63909 .26469 .63064 Mtetra
.26469 .63064 .27467 .63909 .28986 .63452 .27993 .62602 Mtetra
.27993 .62602 .28986 .63452 .30513 .62992 .29526 .62138 Mtetra
.29526 .62138 .30513 .62992 .3205 .6253 .31068 .6167 Mtetra
.646 .763 .934 r
.31068 .6167 .3205 .6253 .33595 .62064 .32619 .61199 Mtetra
.32619 .61199 .33595 .62064 .3515 .61594 .34179 .60725 Mtetra
.647 .763 .934 r
.34179 .60725 .3515 .61594 .36714 .61119 .35749 .60246 Mtetra
.648 .763 .934 r
.35749 .60246 .36714 .61119 .38287 .60637 .37327 .59762 Mtetra
.649 .764 .933 r
.37327 .59762 .38287 .60637 .3987 .60145 .38916 .59269 Mtetra
.652 .766 .933 r
.38916 .59269 .3987 .60145 .41462 .59635 .40514 .58762 Mtetra
.657 .77 .932 r
.40514 .58762 .41462 .59635 .43064 .59094 .42122 .58232 Mtetra
.668 .777 .931 r
.42122 .58232 .43064 .59094 .44677 .58496 .4374 .57659 Mtetra
.686 .789 .928 r
.4374 .57659 .44677 .58496 .463 .57795 .45369 .5701 Mtetra
.718 .809 .922 r
.45369 .5701 .463 .57795 .47933 .56909 .47008 .56222 Mtetra
.768 .841 .907 r
.47008 .56222 .47933 .56909 .49574 .55701 .48657 .55188 Mtetra
.838 .881 .873 r
.48657 .55188 .49574 .55701 .51221 .53966 .50314 .53734 Mtetra
.911 .916 .809 r
.50314 .53734 .51221 .53966 .52864 .51479 .51972 .51636 Mtetra
.96 .93 .718 r
.51972 .51636 .52864 .51479 .54493 .48139 .53621 .48702 Mtetra
.975 .924 .631 r
.53621 .48702 .54493 .48139 .56097 .44195 .5525 .44984 Mtetra
.97 .917 .583 r
.5525 .44984 .56097 .44195 .57676 .40257 .56852 .40938 Mtetra
.964 .927 .6 r
.56852 .40938 .57676 .40257 .59243 .36926 .58434 .37231 Mtetra
.958 .948 .684 r
.58434 .37231 .59243 .36926 .60813 .34435 .60012 .34302 Mtetra
.923 .945 .794 r
.60012 .34302 .60813 .34435 .62396 .32678 .61598 .32192 Mtetra
.852 .9 .869 r
.61598 .32192 .62396 .32678 .63994 .31428 .63199 .30707 Mtetra
.781 .844 .899 r
.63199 .30707 .63994 .31428 .65607 .30488 .64816 .29624 Mtetra
.73 .801 .908 r
.64816 .29624 .65607 .30488 .67234 .29723 .66447 .28776 Mtetra
.7 .774 .909 r
.66447 .28776 .67234 .29723 .68873 .29051 .68092 .28057 Mtetra
.683 .759 .909 r
.68092 .28057 .68873 .29051 .70524 .28429 .69748 .27406 Mtetra
.674 .751 .909 r
.69748 .27406 .70524 .28429 .72186 .27832 .71416 .26791 Mtetra
.669 .746 .908 r
.71416 .26791 .72186 .27832 .73858 .27246 .73095 .26192 Mtetra
.666 .744 .908 r
.73095 .26192 .73858 .27246 .7554 .26664 .74784 .25601 Mtetra
.665 .743 .908 r
.74784 .25601 .7554 .26664 .77233 .26083 .76484 .25012 Mtetra
.664 .742 .908 r
.76484 .25012 .77233 .26083 .78935 .25501 .78193 .24422 Mtetra
.78193 .24422 .78935 .25501 .80648 .24916 .79913 .23831 Mtetra
.664 .741 .908 r
.79913 .23831 .80648 .24916 .82371 .24329 .81644 .23237 Mtetra
.81644 .23237 .82371 .24329 .84105 .23738 .83385 .22639 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62674 Mtetra
.2394 .62674 .24954 .63523 .26469 .63064 .2546 .6221 Mtetra
.2546 .6221 .26469 .63064 .27993 .62602 .2699 .61743 Mtetra
.2699 .61743 .27993 .62602 .29526 .62138 .28528 .61273 Mtetra
.28528 .61273 .29526 .62138 .31068 .6167 .30075 .60801 Mtetra
.646 .763 .934 r
.30075 .60801 .31068 .6167 .32619 .61199 .31632 .60325 Mtetra
.31632 .60325 .32619 .61199 .34179 .60725 .33198 .59846 Mtetra
.647 .763 .934 r
.33198 .59846 .34179 .60725 .35749 .60246 .34773 .59363 Mtetra
.34773 .59363 .35749 .60246 .37327 .59762 .36357 .58875 Mtetra
.648 .764 .933 r
.36357 .58875 .37327 .59762 .38916 .59269 .37951 .5838 Mtetra
.65 .765 .933 r
.37951 .5838 .38916 .59269 .40514 .58762 .39555 .57874 Mtetra
.654 .768 .933 r
.39555 .57874 .40514 .58762 .42122 .58232 .41169 .5735 Mtetra
.662 .773 .932 r
.41169 .5735 .42122 .58232 .4374 .57659 .42793 .56795 Mtetra
.675 .782 .93 r
.42793 .56795 .4374 .57659 .45369 .5701 .44428 .56182 Mtetra
.7 .798 .926 r
.44428 .56182 .45369 .5701 .47008 .56222 .46073 .55466 Mtetra
.74 .823 .916 r
.46073 .55466 .47008 .56222 .48657 .55188 .47729 .54564 Mtetra
.801 .86 .893 r
.47729 .54564 .48657 .55188 .50314 .53734 .49394 .53336 Mtetra
.876 .901 .845 r
.49394 .53336 .50314 .53734 .51972 .51636 .51064 .51578 Mtetra
.94 .927 .766 r
.51064 .51578 .51972 .51636 .53621 .48702 .52731 .49062 Mtetra
.971 .928 .672 r
.52731 .49062 .53621 .48702 .5525 .44984 .54384 .45689 Mtetra
.973 .919 .6 r
.54384 .45689 .5525 .44984 .56852 .40938 .56011 .41708 Mtetra
.967 .92 .583 r
.56011 .41708 .56852 .40938 .58434 .37231 .57612 .37735 Mtetra
.963 .938 .635 r
.57612 .37735 .58434 .37231 .60012 .34302 .59201 .34373 Mtetra
.946 .952 .741 r
.59201 .34373 .60012 .34302 .61598 .32192 .60793 .31856 Mtetra
.89 .926 .838 r
.60793 .31856 .61598 .32192 .63199 .30707 .62397 .30077 Mtetra
.815 .871 .888 r
.62397 .30077 .63199 .30707 .64816 .29624 .64018 .28808 Mtetra
.753 .82 .905 r
.64018 .28808 .64816 .29624 .66447 .28776 .65653 .27851 Mtetra
.713 .786 .909 r
.65653 .27851 .66447 .28776 .68092 .28057 .67303 .27069 Mtetra
.69 .766 .909 r
.67303 .27069 .68092 .28057 .69748 .27406 .68965 .26381 Mtetra
.678 .754 .909 r
.68965 .26381 .69748 .27406 .71416 .26791 .70639 .25743 Mtetra
.671 .748 .909 r
.70639 .25743 .71416 .26791 .73095 .26192 .72324 .25129 Mtetra
.667 .745 .908 r
.72324 .25129 .73095 .26192 .74784 .25601 .7402 .24527 Mtetra
.666 .743 .908 r
.7402 .24527 .74784 .25601 .76484 .25012 .75726 .23929 Mtetra
.665 .742 .908 r
.75726 .23929 .76484 .25012 .78193 .24422 .77443 .23332 Mtetra
.664 .742 .908 r
.77443 .23332 .78193 .24422 .79913 .23831 .7917 .22733 Mtetra
.7917 .22733 .79913 .23831 .81644 .23237 .80908 .22132 Mtetra
.664 .741 .908 r
.80908 .22132 .81644 .23237 .83385 .22639 .82657 .21528 Mtetra
.646 .762 .934 r
.18391 .63206 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62674 .22915 .61815 Mtetra
.22915 .61815 .2394 .62674 .2546 .6221 .24441 .61346 Mtetra
.24441 .61346 .2546 .6221 .2699 .61743 .25975 .60874 Mtetra
.25975 .60874 .2699 .61743 .28528 .61273 .27519 .604 Mtetra
.27519 .604 .28528 .61273 .30075 .60801 .29072 .59922 Mtetra
.29072 .59922 .30075 .60801 .31632 .60325 .30634 .59442 Mtetra
.646 .763 .934 r
.30634 .59442 .31632 .60325 .33198 .59846 .32205 .58958 Mtetra
.32205 .58958 .33198 .59846 .34773 .59363 .33786 .5847 Mtetra
.647 .763 .934 r
.33786 .5847 .34773 .59363 .36357 .58875 .35376 .57978 Mtetra
.648 .763 .934 r
.35376 .57978 .36357 .58875 .37951 .5838 .36976 .5748 Mtetra
.649 .764 .933 r
.36976 .5748 .37951 .5838 .39555 .57874 .38586 .56973 Mtetra
.652 .766 .933 r
.38586 .56973 .39555 .57874 .41169 .5735 .40206 .56452 Mtetra
.657 .77 .932 r
.40206 .56452 .41169 .5735 .42793 .56795 .41836 .55908 Mtetra
.668 .777 .931 r
.41836 .55908 .42793 .56795 .44428 .56182 .43476 .5532 Mtetra
.686 .789 .928 r
.43476 .5532 .44428 .56182 .46073 .55466 .45128 .54656 Mtetra
.718 .809 .922 r
.45128 .54656 .46073 .55466 .47729 .54564 .4679 .53852 Mtetra
.768 .841 .907 r
.4679 .53852 .47729 .54564 .49394 .53336 .48462 .52799 Mtetra
.838 .881 .873 r
.48462 .52799 .49394 .53336 .51064 .51578 .50142 .51324 Mtetra
.911 .917 .809 r
.50142 .51324 .51064 .51578 .52731 .49062 .51824 .492 Mtetra
.96 .93 .718 r
.51824 .492 .52731 .49062 .54384 .45689 .53498 .46235 Mtetra
.975 .924 .631 r
.53498 .46235 .54384 .45689 .56011 .41708 .55151 .42481 Mtetra
.97 .917 .583 r
.55151 .42481 .56011 .41708 .57612 .37735 .56776 .38398 Mtetra
.965 .927 .6 r
.56776 .38398 .57612 .37735 .59201 .34373 .58381 .34657 Mtetra
.958 .948 .685 r
.58381 .34657 .59201 .34373 .60793 .31856 .5998 .317 Mtetra
.923 .945 .794 r
.5998 .317 .60793 .31856 .62397 .30077 .61589 .29566 Mtetra
.852 .9 .869 r
.61589 .29566 .62397 .30077 .64018 .28808 .63212 .2806 Mtetra
.781 .844 .899 r
.63212 .2806 .64018 .28808 .65653 .27851 .64851 .26959 Mtetra
.73 .801 .908 r
.64851 .26959 .65653 .27851 .67303 .27069 .66505 .26093 Mtetra
.7 .774 .909 r
.66505 .26093 .67303 .27069 .68965 .26381 .68173 .25358 Mtetra
.683 .759 .909 r
.68173 .25358 .68965 .26381 .70639 .25743 .69853 .24691 Mtetra
.674 .751 .909 r
.69853 .24691 .70639 .25743 .72324 .25129 .71545 .24059 Mtetra
.669 .746 .908 r
.71545 .24059 .72324 .25129 .7402 .24527 .73247 .23444 Mtetra
.666 .744 .908 r
.73247 .23444 .7402 .24527 .75726 .23929 .74961 .22836 Mtetra
.665 .743 .908 r
.74961 .22836 .75726 .23929 .77443 .23332 .76685 .2223 Mtetra
.664 .742 .908 r
.76685 .2223 .77443 .23332 .7917 .22733 .78419 .21624 Mtetra
.78419 .21624 .7917 .22733 .80908 .22132 .80165 .21016 Mtetra
.664 .741 .908 r
.80165 .21016 .80908 .22132 .82657 .21528 .8192 .20405 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63206 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .604 .26499 .59516 Mtetra
.26499 .59516 .27519 .604 .29072 .59922 .28057 .59034 Mtetra
.28057 .59034 .29072 .59922 .30634 .59442 .29625 .58548 Mtetra
.646 .763 .934 r
.29625 .58548 .30634 .59442 .32205 .58958 .31202 .58059 Mtetra
.31202 .58059 .32205 .58958 .33786 .5847 .32788 .57566 Mtetra
.647 .763 .934 r
.32788 .57566 .33786 .5847 .35376 .57978 .34384 .5707 Mtetra
.34384 .5707 .35376 .57978 .36976 .5748 .3599 .56568 Mtetra
.648 .764 .933 r
.3599 .56568 .36976 .5748 .38586 .56973 .37606 .56059 Mtetra
.65 .765 .933 r
.37606 .56059 .38586 .56973 .40206 .56452 .39232 .55539 Mtetra
.654 .768 .933 r
.39232 .55539 .40206 .56452 .41836 .55908 .40868 .55001 Mtetra
.662 .773 .932 r
.40868 .55001 .41836 .55908 .43476 .5532 .42514 .5443 Mtetra
.675 .782 .93 r
.42514 .5443 .43476 .5532 .45128 .54656 .44172 .53803 Mtetra
.7 .798 .926 r
.44172 .53803 .45128 .54656 .4679 .53852 .4584 .5307 Mtetra
.74 .824 .916 r
.4584 .5307 .4679 .53852 .48462 .52799 .47519 .5215 Mtetra
.801 .861 .893 r
.47519 .5215 .48462 .52799 .50142 .51324 .49208 .50902 Mtetra
.876 .901 .845 r
.49208 .50902 .50142 .51324 .51824 .492 .50902 .49121 Mtetra
.94 .927 .765 r
.50902 .49121 .51824 .492 .53498 .46235 .52594 .46577 Mtetra
.971 .929 .671 r
.52594 .46577 .53498 .46235 .55151 .42481 .54271 .43169 Mtetra
.973 .919 .6 r
.54271 .43169 .55151 .42481 .56776 .38398 .55922 .39151 Mtetra
.967 .92 .583 r
.55922 .39151 .56776 .38398 .58381 .34657 .57547 .35142 Mtetra
.963 .938 .636 r
.57547 .35142 .58381 .34657 .5998 .317 .59159 .31748 Mtetra
.946 .952 .741 r
.59159 .31748 .5998 .317 .61589 .29566 .60773 .29204 Mtetra
.89 .926 .838 r
.60773 .29204 .61589 .29566 .63212 .2806 .62399 .27403 Mtetra
.815 .871 .888 r
.62399 .27403 .63212 .2806 .64851 .26959 .64042 .26115 Mtetra
.753 .82 .905 r
.64042 .26115 .64851 .26959 .66505 .26093 .657 .2514 Mtetra
.713 .786 .909 r
.657 .2514 .66505 .26093 .68173 .25358 .67373 .2434 Mtetra
.69 .766 .909 r
.67373 .2434 .68173 .25358 .69853 .24691 .69059 .23636 Mtetra
.678 .754 .909 r
.69059 .23636 .69853 .24691 .71545 .24059 .70757 .22981 Mtetra
.671 .748 .909 r
.70757 .22981 .71545 .24059 .73247 .23444 .72466 .22351 Mtetra
.667 .745 .908 r
.72466 .22351 .73247 .23444 .74961 .22836 .74187 .21732 Mtetra
.666 .743 .908 r
.74187 .21732 .74961 .22836 .76685 .2223 .75918 .21117 Mtetra
.665 .742 .908 r
.75918 .21117 .76685 .2223 .78419 .21624 .7766 .20503 Mtetra
.664 .742 .908 r
.7766 .20503 .78419 .21624 .80165 .21016 .79412 .19887 Mtetra
.79412 .19887 .80165 .21016 .8192 .20405 .81176 .19269 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .59591 Mtetra
.22368 .59591 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59516 .25468 .58623 Mtetra
.25468 .58623 .26499 .59516 .28057 .59034 .27032 .58135 Mtetra
.27032 .58135 .28057 .59034 .29625 .58548 .28605 .57644 Mtetra
.28605 .57644 .29625 .58548 .31202 .58059 .30187 .5715 Mtetra
.646 .763 .934 r
.30187 .5715 .31202 .58059 .32788 .57566 .3178 .56652 Mtetra
.3178 .56652 .32788 .57566 .34384 .5707 .33382 .56151 Mtetra
.647 .763 .934 r
.33382 .56151 .34384 .5707 .3599 .56568 .34993 .55645 Mtetra
.648 .763 .934 r
.34993 .55645 .3599 .56568 .37606 .56059 .36615 .55133 Mtetra
.649 .764 .933 r
.36615 .55133 .37606 .56059 .39232 .55539 .38247 .54611 Mtetra
.652 .766 .933 r
.38247 .54611 .39232 .55539 .40868 .55001 .39889 .54076 Mtetra
.657 .77 .932 r
.39889 .54076 .40868 .55001 .42514 .5443 .41541 .53517 Mtetra
.668 .777 .931 r
.41541 .53517 .42514 .5443 .44172 .53803 .43205 .52914 Mtetra
.686 .789 .928 r
.43205 .52914 .44172 .53803 .4584 .5307 .44879 .52234 Mtetra
.718 .809 .922 r
.44879 .52234 .4584 .5307 .47519 .5215 .46565 .51413 Mtetra
.768 .841 .907 r
.46565 .51413 .47519 .5215 .49208 .50902 .48261 .50341 Mtetra
.838 .881 .873 r
.48261 .50341 .49208 .50902 .50902 .49121 .49966 .48844 Mtetra
.911 .917 .809 r
.49966 .48844 .50902 .49121 .52594 .46577 .51673 .46694 Mtetra
.96 .93 .718 r
.51673 .46694 .52594 .46577 .54271 .43169 .53371 .43697 Mtetra
.975 .924 .631 r
.53371 .43697 .54271 .43169 .55922 .39151 .55049 .39907 Mtetra
.97 .917 .583 r
.55049 .39907 .55922 .39151 .57547 .35142 .56698 .35786 Mtetra
.965 .927 .601 r
.56698 .35786 .57547 .35142 .59159 .31748 .58326 .3201 Mtetra
.958 .948 .685 r
.58326 .3201 .59159 .31748 .60773 .29204 .59948 .29024 Mtetra
.923 .944 .794 r
.59948 .29024 .60773 .29204 .62399 .27403 .61579 .26865 Mtetra
.852 .9 .869 r
.61579 .26865 .62399 .27403 .64042 .26115 .63226 .25339 Mtetra
.781 .844 .899 r
.63226 .25339 .64042 .26115 .657 .2514 .64888 .24219 Mtetra
.73 .801 .908 r
.64888 .24219 .657 .2514 .67373 .2434 .66565 .23335 Mtetra
.7 .774 .909 r
.66565 .23335 .67373 .2434 .69059 .23636 .68257 .22582 Mtetra
.683 .759 .909 r
.68257 .22582 .69059 .23636 .70757 .22981 .69961 .21898 Mtetra
.674 .751 .909 r
.69961 .21898 .70757 .22981 .72466 .22351 .71677 .21249 Mtetra
.669 .746 .908 r
.71677 .21249 .72466 .22351 .74187 .21732 .73404 .20617 Mtetra
.666 .744 .908 r
.73404 .20617 .74187 .21732 .75918 .21117 .75142 .19992 Mtetra
.665 .743 .908 r
.75142 .19992 .75918 .21117 .7766 .20503 .76892 .19369 Mtetra
.664 .742 .908 r
.76892 .19369 .7766 .20503 .79412 .19887 .78652 .18746 Mtetra
.78652 .18746 .79412 .19887 .81176 .19269 .80423 .1812 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .59591 .21314 .58698 Mtetra
.21314 .58698 .22368 .59591 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58623 .24425 .5772 Mtetra
.24425 .5772 .25468 .58623 .27032 .58135 .25994 .57227 Mtetra
.25994 .57227 .27032 .58135 .28605 .57644 .27573 .56731 Mtetra
.27573 .56731 .28605 .57644 .30187 .5715 .29162 .56231 Mtetra
.646 .763 .934 r
.29162 .56231 .30187 .5715 .3178 .56652 .3076 .55728 Mtetra
.3076 .55728 .3178 .56652 .33382 .56151 .32368 .55221 Mtetra
.647 .763 .934 r
.32368 .55221 .33382 .56151 .34993 .55645 .33985 .54711 Mtetra
.33985 .54711 .34993 .55645 .36615 .55133 .35613 .54194 Mtetra
.648 .764 .933 r
.35613 .54194 .36615 .55133 .38247 .54611 .37251 .53671 Mtetra
.65 .765 .933 r
.37251 .53671 .38247 .54611 .39889 .54076 .38899 .53136 Mtetra
.654 .768 .933 r
.38899 .53136 .39889 .54076 .41541 .53517 .40558 .52583 Mtetra
.662 .773 .932 r
.40558 .52583 .41541 .53517 .43205 .52914 .42227 .51997 Mtetra
.675 .782 .93 r
.42227 .51997 .43205 .52914 .44879 .52234 .43908 .51353 Mtetra
.7 .798 .926 r
.43908 .51353 .44879 .52234 .46565 .51413 .456 .50605 Mtetra
.74 .824 .916 r
.456 .50605 .46565 .51413 .48261 .50341 .47303 .49666 Mtetra
.801 .861 .893 r
.47303 .49666 .48261 .50341 .49966 .48844 .49017 .48398 Mtetra
.876 .901 .845 r
.49017 .48398 .49966 .48844 .51673 .46694 .50736 .46592 Mtetra
.94 .927 .765 r
.50736 .46592 .51673 .46694 .53371 .43697 .52453 .44018 Mtetra
.971 .929 .671 r
.52453 .44018 .53371 .43697 .55049 .39907 .54155 .40576 Mtetra
.973 .919 .6 r
.54155 .40576 .55049 .39907 .56698 .35786 .55831 .3652 Mtetra
.967 .92 .583 r
.55831 .3652 .56698 .35786 .58326 .3201 .5748 .32474 Mtetra
.963 .938 .636 r
.5748 .32474 .58326 .3201 .59948 .29024 .59115 .29048 Mtetra
.946 .951 .741 r
.59115 .29048 .59948 .29024 .61579 .26865 .60752 .26478 Mtetra
.89 .926 .838 r
.60752 .26478 .61579 .26865 .63226 .25339 .62401 .24654 Mtetra
.815 .871 .888 r
.62401 .24654 .63226 .25339 .64888 .24219 .64067 .23346 Mtetra
.753 .82 .905 r
.64067 .23346 .64888 .24219 .66565 .23335 .65749 .22352 Mtetra
.713 .786 .909 r
.65749 .22352 .66565 .23335 .68257 .22582 .67446 .21534 Mtetra
.69 .766 .909 r
.67446 .21534 .68257 .22582 .69961 .21898 .69156 .20813 Mtetra
.678 .754 .909 r
.69156 .20813 .69961 .21898 .71677 .21249 .70878 .2014 Mtetra
.671 .748 .908 r
.70878 .2014 .71677 .21249 .73404 .20617 .72613 .19493 Mtetra
.667 .745 .908 r
.72613 .19493 .73404 .20617 .75142 .19992 .74358 .18856 Mtetra
.666 .743 .908 r
.74358 .18856 .75142 .19992 .76892 .19369 .76115 .18224 Mtetra
.665 .742 .908 r
.76115 .18224 .76892 .19369 .78652 .18746 .77882 .17592 Mtetra
.664 .742 .908 r
.77882 .17592 .78652 .18746 .80423 .1812 .79661 .16958 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .5772 .23371 .56807 Mtetra
.23371 .56807 .24425 .5772 .25994 .57227 .24946 .56309 Mtetra
.24946 .56309 .25994 .57227 .27573 .56731 .2653 .55807 Mtetra
.2653 .55807 .27573 .56731 .29162 .56231 .28124 .55302 Mtetra
.28124 .55302 .29162 .56231 .3076 .55728 .29728 .54793 Mtetra
.646 .763 .934 r
.29728 .54793 .3076 .55728 .32368 .55221 .31342 .54281 Mtetra
.31342 .54281 .32368 .55221 .33985 .54711 .32966 .53765 Mtetra
.647 .763 .934 r
.32966 .53765 .33985 .54711 .35613 .54194 .34599 .53244 Mtetra
.648 .763 .934 r
.34599 .53244 .35613 .54194 .37251 .53671 .36243 .52717 Mtetra
.649 .764 .933 r
.36243 .52717 .37251 .53671 .38899 .53136 .37898 .52181 Mtetra
.652 .766 .933 r
.37898 .52181 .38899 .53136 .40558 .52583 .39563 .51631 Mtetra
.657 .77 .932 r
.39563 .51631 .40558 .52583 .42227 .51997 .41238 .51056 Mtetra
.668 .777 .931 r
.41238 .51056 .42227 .51997 .43908 .51353 .42925 .50437 Mtetra
.686 .789 .928 r
.42925 .50437 .43908 .51353 .456 .50605 .44624 .4974 Mtetra
.718 .809 .922 r
.44624 .4974 .456 .50605 .47303 .49666 .46334 .48902 Mtetra
.768 .841 .907 r
.46334 .48902 .47303 .49666 .49017 .48398 .48055 .4781 Mtetra
.838 .882 .873 r
.48055 .4781 .49017 .48398 .50736 .46592 .49785 .46291 Mtetra
.911 .917 .809 r
.49785 .46291 .50736 .46592 .52453 .44018 .51517 .44114 Mtetra
.96 .931 .718 r
.51517 .44114 .52453 .44018 .54155 .40576 .53241 .41084 Mtetra
.975 .924 .63 r
.53241 .41084 .54155 .40576 .55831 .3652 .54944 .37257 Mtetra
.97 .917 .583 r
.54944 .37257 .55831 .3652 .5748 .32474 .56617 .33098 Mtetra
.965 .927 .601 r
.56617 .33098 .5748 .32474 .59115 .29048 .58269 .29288 Mtetra
.958 .948 .685 r
.58269 .29288 .59115 .29048 .60752 .26478 .59915 .26271 Mtetra
.923 .944 .795 r
.59915 .26271 .60752 .26478 .62401 .24654 .6157 .24088 Mtetra
.852 .9 .869 r
.6157 .24088 .62401 .24654 .64067 .23346 .63239 .2254 Mtetra
.781 .844 .899 r
.63239 .2254 .64067 .23346 .65749 .22352 .64925 .214 Mtetra
.73 .801 .908 r
.64925 .214 .65749 .22352 .67446 .21534 .66627 .20498 Mtetra
.7 .774 .909 r
.66627 .20498 .67446 .21534 .69156 .20813 .68343 .19727 Mtetra
.683 .759 .909 r
.68343 .19727 .69156 .20813 .70878 .2014 .70071 .19026 Mtetra
.674 .751 .909 r
.70071 .19026 .70878 .2014 .72613 .19493 .71812 .18359 Mtetra
.669 .746 .908 r
.71812 .18359 .72613 .19493 .74358 .18856 .73565 .17709 Mtetra
.666 .744 .908 r
.73565 .17709 .74358 .18856 .76115 .18224 .75329 .17066 Mtetra
.665 .743 .908 r
.75329 .17066 .76115 .18224 .77882 .17592 .77104 .16425 Mtetra
.664 .742 .908 r
.77104 .16425 .77882 .17592 .79661 .16958 .78891 .15783 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56807 .22305 .55884 Mtetra
.22305 .55884 .23371 .56807 .24946 .56309 .23885 .5538 Mtetra
.23885 .5538 .24946 .56309 .2653 .55807 .25476 .54872 Mtetra
.25476 .54872 .2653 .55807 .28124 .55302 .27075 .54361 Mtetra
.27075 .54361 .28124 .55302 .29728 .54793 .28685 .53847 Mtetra
.646 .763 .934 r
.28685 .53847 .29728 .54793 .31342 .54281 .30305 .5333 Mtetra
.30305 .5333 .31342 .54281 .32966 .53765 .31935 .52808 Mtetra
.647 .763 .934 r
.31935 .52808 .32966 .53765 .34599 .53244 .33574 .52283 Mtetra
.33574 .52283 .34599 .53244 .36243 .52717 .35225 .51751 Mtetra
.648 .764 .933 r
.35225 .51751 .36243 .52717 .37898 .52181 .36885 .51213 Mtetra
.65 .765 .933 r
.36885 .51213 .37898 .52181 .39563 .51631 .38556 .50662 Mtetra
.654 .768 .933 r
.38556 .50662 .39563 .51631 .41238 .51056 .40238 .50093 Mtetra
.662 .773 .932 r
.40238 .50093 .41238 .51056 .42925 .50437 .41932 .49492 Mtetra
.675 .782 .93 r
.41932 .49492 .42925 .50437 .44624 .4974 .43636 .48832 Mtetra
.7 .798 .926 r
.43636 .48832 .44624 .4974 .46334 .48902 .45353 .48065 Mtetra
.74 .824 .916 r
.45353 .48065 .46334 .48902 .48055 .4781 .47081 .47108 Mtetra
.801 .861 .893 r
.47081 .47108 .48055 .4781 .49785 .46291 .4882 .45819 Mtetra
.876 .901 .845 r
.4882 .45819 .49785 .46291 .51517 .44114 .50565 .43988 Mtetra
.94 .927 .765 r
.50565 .43988 .51517 .44114 .53241 .41084 .52308 .41384 Mtetra
.971 .929 .671 r
.52308 .41384 .53241 .41084 .54944 .37257 .54036 .37906 Mtetra
.973 .919 .6 r
.54036 .37906 .54944 .37257 .56617 .33098 .55737 .33812 Mtetra
.967 .92 .583 r
.55737 .33812 .56617 .33098 .58269 .29288 .5741 .29729 Mtetra
.963 .938 .636 r
.5741 .29729 .58269 .29288 .59915 .26271 .59069 .26271 Mtetra
.946 .951 .741 r
.59069 .26271 .59915 .26271 .6157 .24088 .6073 .23673 Mtetra
.89 .926 .838 r
.6073 .23673 .6157 .24088 .63239 .2254 .62404 .21826 Mtetra
.815 .871 .888 r
.62404 .21826 .63239 .2254 .64925 .214 .64093 .20497 Mtetra
.753 .82 .905 r
.64093 .20497 .64925 .214 .66627 .20498 .658 .19483 Mtetra
.713 .786 .909 r
.658 .19483 .66627 .20498 .68343 .19727 .67521 .18647 Mtetra
.69 .766 .909 r
.67521 .18647 .68343 .19727 .70071 .19026 .69256 .17907 Mtetra
.678 .754 .909 r
.69256 .17907 .70071 .19026 .71812 .18359 .71003 .17217 Mtetra
.671 .748 .908 r
.71003 .17217 .71812 .18359 .73565 .17709 .72763 .16551 Mtetra
.667 .745 .908 r
.72763 .16551 .73565 .17709 .75329 .17066 .74535 .15897 Mtetra
.666 .743 .908 r
.74535 .15897 .75329 .17066 .77104 .16425 .76317 .15246 Mtetra
.665 .742 .908 r
.76317 .15246 .77104 .16425 .78891 .15783 .78112 .14595 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .5538 .22813 .54441 Mtetra
.22813 .54441 .23885 .5538 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27075 .54361 .26015 .53411 Mtetra
.26015 .53411 .27075 .54361 .28685 .53847 .2763 .52891 Mtetra
.2763 .52891 .28685 .53847 .30305 .5333 .29256 .52368 Mtetra
.646 .763 .934 r
.29256 .52368 .30305 .5333 .31935 .52808 .30892 .51841 Mtetra
.30892 .51841 .31935 .52808 .33574 .52283 .32538 .51309 Mtetra
.647 .763 .934 r
.32538 .51309 .33574 .52283 .35225 .51751 .34194 .50773 Mtetra
.648 .763 .934 r
.34194 .50773 .35225 .51751 .36885 .51213 .35861 .50231 Mtetra
.649 .764 .933 r
.35861 .50231 .36885 .51213 .38556 .50662 .37538 .49679 Mtetra
.652 .766 .933 r
.37538 .49679 .38556 .50662 .40238 .50093 .39227 .49113 Mtetra
.657 .77 .932 r
.39227 .49113 .40238 .50093 .41932 .49492 .40926 .48522 Mtetra
.668 .777 .931 r
.40926 .48522 .41932 .49492 .43636 .48832 .42638 .47887 Mtetra
.686 .789 .928 r
.42638 .47887 .43636 .48832 .45353 .48065 .44361 .47173 Mtetra
.718 .809 .922 r
.44361 .47173 .45353 .48065 .47081 .47108 .46096 .46315 Mtetra
.768 .841 .907 r
.46096 .46315 .47081 .47108 .4882 .45819 .47842 .45204 Mtetra
.838 .882 .873 r
.47842 .45204 .4882 .45819 .50565 .43988 .49598 .43661 Mtetra
.911 .917 .809 r
.49598 .43661 .50565 .43988 .52308 .41384 .51356 .41456 Mtetra
.96 .931 .718 r
.51356 .41456 .52308 .41384 .54036 .37906 .53107 .38393 Mtetra
.975 .924 .63 r
.53107 .38393 .54036 .37906 .55737 .33812 .54835 .34529 Mtetra
.97 .917 .583 r
.54835 .34529 .55737 .33812 .5741 .29729 .56535 .30332 Mtetra
.965 .927 .601 r
.56535 .30332 .5741 .29729 .59069 .26271 .58211 .26486 Mtetra
.958 .948 .686 r
.58211 .26486 .59069 .26271 .6073 .23673 .59882 .23439 Mtetra
.923 .944 .795 r
.59882 .23439 .6073 .23673 .62404 .21826 .6156 .21231 Mtetra
.852 .9 .869 r
.6156 .21231 .62404 .21826 .64093 .20497 .63254 .1966 Mtetra
.781 .844 .899 r
.63254 .1966 .64093 .20497 .658 .19483 .64964 .185 Mtetra
.73 .801 .908 r
.64964 .185 .658 .19483 .67521 .18647 .6669 .17579 Mtetra
.7 .774 .909 r
.6669 .17579 .67521 .18647 .69256 .17907 .68431 .16789 Mtetra
.683 .759 .909 r
.68431 .16789 .69256 .17907 .71003 .17217 .70185 .16069 Mtetra
.674 .751 .909 r
.70185 .16069 .71003 .17217 .72763 .16551 .71952 .15384 Mtetra
.669 .746 .908 r
.71952 .15384 .72763 .16551 .74535 .15897 .73731 .14715 Mtetra
.666 .744 .908 r
.73731 .14715 .74535 .15897 .76317 .15246 .75521 .14054 Mtetra
.665 .743 .908 r
.75521 .14054 .76317 .15246 .78112 .14595 .77324 .13394 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54007 Mtetra
.20137 .54007 .21227 .54951 .22813 .54441 .21728 .53491 Mtetra
.21728 .53491 .22813 .54441 .24409 .53927 .2333 .52971 Mtetra
.2333 .52971 .24409 .53927 .26015 .53411 .24942 .52449 Mtetra
.24942 .52449 .26015 .53411 .2763 .52891 .26563 .51923 Mtetra
.26563 .51923 .2763 .52891 .29256 .52368 .28195 .51394 Mtetra
.646 .763 .934 r
.28195 .51394 .29256 .52368 .30892 .51841 .29837 .50861 Mtetra
.29837 .50861 .30892 .51841 .32538 .51309 .31489 .50325 Mtetra
.647 .763 .934 r
.31489 .50325 .32538 .51309 .34194 .50773 .33151 .49783 Mtetra
.33151 .49783 .34194 .50773 .35861 .50231 .34825 .49236 Mtetra
.648 .764 .933 r
.34825 .49236 .35861 .50231 .37538 .49679 .36509 .48682 Mtetra
.65 .765 .933 r
.36509 .48682 .37538 .49679 .39227 .49113 .38203 .48115 Mtetra
.654 .768 .933 r
.38203 .48115 .39227 .49113 .40926 .48522 .3991 .4753 Mtetra
.662 .773 .932 r
.3991 .4753 .40926 .48522 .42638 .47887 .41627 .46912 Mtetra
.675 .782 .93 r
.41627 .46912 .42638 .47887 .44361 .47173 .43357 .46234 Mtetra
.7 .798 .926 r
.43357 .46234 .44361 .47173 .46096 .46315 .45098 .4545 Mtetra
.74 .824 .916 r
.45098 .4545 .46096 .46315 .47842 .45204 .46852 .44473 Mtetra
.801 .861 .893 r
.46852 .44473 .47842 .45204 .49598 .43661 .48617 .43161 Mtetra
.876 .902 .845 r
.48617 .43161 .49598 .43661 .51356 .41456 .50388 .41305 Mtetra
.94 .928 .765 r
.50388 .41305 .51356 .41456 .53107 .38393 .52158 .3867 Mtetra
.971 .929 .671 r
.52158 .3867 .53107 .38393 .54835 .34529 .53913 .35157 Mtetra
.973 .919 .6 r
.53913 .35157 .54835 .34529 .56535 .30332 .5564 .31024 Mtetra
.967 .92 .583 r
.5564 .31024 .56535 .30332 .58211 .26486 .57339 .26904 Mtetra
.963 .938 .637 r
.57339 .26904 .58211 .26486 .59882 .23439 .59023 .23412 Mtetra
.946 .951 .742 r
.59023 .23412 .59882 .23439 .6156 .21231 .60708 .20786 Mtetra
.89 .926 .838 r
.60708 .20786 .6156 .21231 .63254 .1966 .62406 .18915 Mtetra
.815 .871 .888 r
.62406 .18915 .63254 .1966 .64964 .185 .6412 .17565 Mtetra
.753 .82 .905 r
.6412 .17565 .64964 .185 .6669 .17579 .65851 .16531 Mtetra
.713 .786 .909 r
.65851 .16531 .6669 .17579 .68431 .16789 .67598 .15676 Mtetra
.69 .765 .909 r
.67598 .15676 .68431 .16789 .70185 .16069 .69358 .14917 Mtetra
.678 .754 .909 r
.69358 .14917 .70185 .16069 .71952 .15384 .71132 .14208 Mtetra
.671 .748 .908 r
.71132 .14208 .71952 .15384 .73731 .14715 .72918 .13523 Mtetra
.667 .745 .908 r
.72918 .13523 .73731 .14715 .75521 .14054 .74716 .12849 Mtetra
.666 .743 .908 r
.74716 .12849 .75521 .14054 .77324 .13394 .76526 .12179 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54007 .19034 .53052 Mtetra
.19034 .53052 .20137 .54007 .21728 .53491 .20631 .5253 Mtetra
.20631 .5253 .21728 .53491 .2333 .52971 .22239 .52005 Mtetra
.22239 .52005 .2333 .52971 .24942 .52449 .23856 .51476 Mtetra
.23856 .51476 .24942 .52449 .26563 .51923 .25484 .50945 Mtetra
.25484 .50945 .26563 .51923 .28195 .51394 .27121 .50409 Mtetra
.27121 .50409 .28195 .51394 .29837 .50861 .28769 .49871 Mtetra
.646 .763 .934 r
.28769 .49871 .29837 .50861 .31489 .50325 .30428 .49328 Mtetra
.30428 .49328 .31489 .50325 .33151 .49783 .32097 .48781 Mtetra
.647 .763 .934 r
.32097 .48781 .33151 .49783 .34825 .49236 .33776 .48229 Mtetra
.648 .763 .934 r
.33776 .48229 .34825 .49236 .36509 .48682 .35467 .4767 Mtetra
.649 .765 .933 r
.35467 .4767 .36509 .48682 .38203 .48115 .37168 .47102 Mtetra
.652 .766 .933 r
.37168 .47102 .38203 .48115 .3991 .4753 .38881 .46519 Mtetra
.657 .77 .932 r
.38881 .46519 .3991 .4753 .41627 .46912 .40605 .45911 Mtetra
.668 .777 .931 r
.40605 .45911 .41627 .46912 .43357 .46234 .42341 .45259 Mtetra
.686 .789 .928 r
.42341 .45259 .43357 .46234 .45098 .4545 .44089 .44527 Mtetra
.718 .809 .922 r
.44089 .44527 .45098 .4545 .46852 .44473 .4585 .4365 Mtetra
.768 .841 .907 r
.4585 .4365 .46852 .44473 .48617 .43161 .47623 .42518 Mtetra
.838 .882 .873 r
.47623 .42518 .48617 .43161 .50388 .41305 .49405 .40951 Mtetra
.911 .918 .809 r
.49405 .40951 .50388 .41305 .52158 .3867 .51191 .38718 Mtetra
.96 .931 .717 r
.51191 .38718 .52158 .3867 .53913 .35157 .52969 .35621 Mtetra
.975 .924 .63 r
.52969 .35621 .53913 .35157 .5564 .31024 .54724 .31719 Mtetra
.97 .917 .583 r
.54724 .31719 .5564 .31024 .57339 .26904 .5645 .27483 Mtetra
.965 .927 .601 r
.5645 .27483 .57339 .26904 .59023 .23412 .58152 .23601 Mtetra
.958 .947 .686 r
.58152 .23601 .59023 .23412 .60708 .20786 .59847 .20524 Mtetra
.922 .944 .795 r
.59847 .20524 .60708 .20786 .62406 .18915 .6155 .18289 Mtetra
.852 .899 .869 r
.6155 .18289 .62406 .18915 .6412 .17565 .63268 .16696 Mtetra
.781 .843 .899 r
.63268 .16696 .6412 .17565 .65851 .16531 .65004 .15515 Mtetra
.73 .801 .908 r
.65004 .15515 .65851 .16531 .67598 .15676 .66756 .14574 Mtetra
.7 .774 .909 r
.66756 .14574 .67598 .15676 .69358 .14917 .68522 .13765 Mtetra
.683 .759 .909 r
.68522 .13765 .69358 .14917 .71132 .14208 .70303 .13025 Mtetra
.674 .751 .909 r
.70303 .13025 .71132 .14208 .72918 .13523 .72096 .12321 Mtetra
.669 .746 .908 r
.72096 .12321 .72918 .13523 .74716 .12849 .73902 .11633 Mtetra
.666 .744 .908 r
.73902 .11633 .74716 .12849 .76526 .12179 .7572 .10952 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52005 .21135 .51027 Mtetra
.21135 .51027 .22239 .52005 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50945 .24392 .49954 Mtetra
.24392 .49954 .25484 .50945 .27121 .50409 .26036 .49413 Mtetra
.26036 .49413 .27121 .50409 .28769 .49871 .2769 .48868 Mtetra
.646 .763 .934 r
.2769 .48868 .28769 .49871 .30428 .49328 .29354 .48319 Mtetra
.29354 .48319 .30428 .49328 .32097 .48781 .3103 .47767 Mtetra
.647 .763 .934 r
.3103 .47767 .32097 .48781 .33776 .48229 .32716 .47209 Mtetra
.32716 .47209 .33776 .48229 .35467 .4767 .34413 .46646 Mtetra
.648 .764 .933 r
.34413 .46646 .35467 .4767 .37168 .47102 .36121 .46074 Mtetra
.65 .765 .933 r
.36121 .46074 .37168 .47102 .38881 .46519 .3784 .45491 Mtetra
.654 .768 .933 r
.3784 .45491 .38881 .46519 .40605 .45911 .39571 .44889 Mtetra
.662 .773 .932 r
.39571 .44889 .40605 .45911 .42341 .45259 .41314 .44253 Mtetra
.675 .782 .93 r
.41314 .44253 .42341 .45259 .44089 .44527 .43069 .43558 Mtetra
.7 .798 .926 r
.43069 .43558 .44089 .44527 .4585 .4365 .44836 .42754 Mtetra
.74 .824 .916 r
.44836 .42754 .4585 .4365 .47623 .42518 .46616 .41757 Mtetra
.801 .861 .894 r
.46616 .41757 .47623 .42518 .49405 .40951 .48408 .40423 Mtetra
.876 .902 .845 r
.48408 .40423 .49405 .40951 .51191 .38718 .50207 .3854 Mtetra
.94 .928 .765 r
.50207 .3854 .51191 .38718 .52969 .35621 .52004 .35874 Mtetra
.971 .929 .67 r
.52004 .35874 .52969 .35621 .54724 .31719 .53786 .32324 Mtetra
.973 .919 .599 r
.53786 .32324 .54724 .31719 .5645 .27483 .5554 .28152 Mtetra
.967 .92 .583 r
.5554 .28152 .5645 .27483 .58152 .23601 .57266 .23994 Mtetra
.963 .938 .637 r
.57266 .23994 .58152 .23601 .59847 .20524 .58975 .20469 Mtetra
.946 .951 .742 r
.58975 .20469 .59847 .20524 .6155 .18289 .60685 .17815 Mtetra
.89 .925 .838 r
.60685 .17815 .6155 .18289 .63268 .16696 .62408 .15919 Mtetra
.815 .871 .888 r
.62408 .15919 .63268 .16696 .65004 .15515 .64148 .14546 Mtetra
.753 .82 .905 r
.64148 .14546 .65004 .15515 .66756 .14574 .65905 .13492 Mtetra
.713 .786 .909 r
.65905 .13492 .66756 .14574 .68522 .13765 .67677 .12617 Mtetra
.69 .765 .909 r
.67677 .12617 .68522 .13765 .70303 .13025 .69464 .11838 Mtetra
.678 .754 .909 r
.69464 .11838 .70303 .13025 .72096 .12321 .71265 .11109 Mtetra
.671 .748 .908 r
.71265 .11109 .72096 .12321 .73902 .11633 .73078 .10404 Mtetra
.667 .745 .908 r
.73078 .10404 .73902 .11633 .7572 .10952 .74904 .09711 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50038 Mtetra
.20018 .50038 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49954 .23287 .48953 Mtetra
.23287 .48953 .24392 .49954 .26036 .49413 .24937 .48405 Mtetra
.24937 .48405 .26036 .49413 .2769 .48868 .26597 .47854 Mtetra
.26597 .47854 .2769 .48868 .29354 .48319 .28268 .47299 Mtetra
.646 .763 .934 r
.28268 .47299 .29354 .48319 .3103 .47767 .2995 .4674 Mtetra
.2995 .4674 .3103 .47767 .32716 .47209 .31643 .46176 Mtetra
.647 .763 .934 r
.31643 .46176 .32716 .47209 .34413 .46646 .33346 .45608 Mtetra
.648 .764 .934 r
.33346 .45608 .34413 .46646 .36121 .46074 .35061 .45032 Mtetra
.649 .765 .933 r
.35061 .45032 .36121 .46074 .3784 .45491 .36787 .44447 Mtetra
.652 .766 .933 r
.36787 .44447 .3784 .45491 .39571 .44889 .38524 .43847 Mtetra
.657 .77 .932 r
.38524 .43847 .39571 .44889 .41314 .44253 .40274 .43221 Mtetra
.668 .777 .931 r
.40274 .43221 .41314 .44253 .43069 .43558 .42036 .42551 Mtetra
.686 .789 .928 r
.42036 .42551 .43069 .43558 .44836 .42754 .4381 .418 Mtetra
.718 .809 .922 r
.4381 .418 .44836 .42754 .46616 .41757 .45597 .40903 Mtetra
.768 .841 .907 r
.45597 .40903 .46616 .41757 .48408 .40423 .47397 .39749 Mtetra
.838 .882 .873 r
.47397 .39749 .48408 .40423 .50207 .3854 .49207 .38158 Mtetra
.911 .918 .809 r
.49207 .38158 .50207 .3854 .52004 .35874 .5102 .35895 Mtetra
.96 .931 .717 r
.5102 .35895 .52004 .35874 .53786 .32324 .52826 .32764 Mtetra
.975 .924 .63 r
.52826 .32764 .53786 .32324 .5554 .28152 .54609 .28823 Mtetra
.97 .917 .583 r
.54609 .28823 .5554 .28152 .57266 .23994 .56362 .24548 Mtetra
.965 .927 .602 r
.56362 .24548 .57266 .23994 .58975 .20469 .5809 .2063 Mtetra
.958 .947 .686 r
.5809 .2063 .58975 .20469 .60685 .17815 .59811 .17522 Mtetra
.922 .944 .795 r
.59811 .17522 .60685 .17815 .62408 .15919 .61539 .1526 Mtetra
.852 .899 .869 r
.61539 .1526 .62408 .15919 .64148 .14546 .63283 .13644 Mtetra
.781 .843 .899 r
.63283 .13644 .64148 .14546 .65905 .13492 .65045 .12441 Mtetra
.73 .801 .908 r
.65045 .12441 .65905 .13492 .67677 .12617 .66823 .11479 Mtetra
.7 .774 .909 r
.66823 .11479 .67677 .12617 .69464 .11838 .68616 .1065 Mtetra
.683 .759 .909 r
.68616 .1065 .69464 .11838 .71265 .11109 .70424 .0989 Mtetra
.674 .751 .909 r
.70424 .0989 .71265 .11109 .73078 .10404 .72244 .09165 Mtetra
.669 .746 .908 r
.72244 .09165 .73078 .10404 .74904 .09711 .74078 .08457 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50038 .18889 .49037 Mtetra
.18889 .49037 .20018 .50038 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48953 .2217 .47939 Mtetra
.2217 .47939 .23287 .48953 .24937 .48405 .23826 .47385 Mtetra
.23826 .47385 .24937 .48405 .26597 .47854 .25492 .46828 Mtetra
.25492 .46828 .26597 .47854 .28268 .47299 .2717 .46266 Mtetra
.646 .763 .934 r
.2717 .46266 .28268 .47299 .2995 .4674 .28858 .45701 Mtetra
.28858 .45701 .2995 .4674 .31643 .46176 .30557 .45131 Mtetra
.647 .763 .934 r
.30557 .45131 .31643 .46176 .33346 .45608 .32267 .44557 Mtetra
.32267 .44557 .33346 .45608 .35061 .45032 .33988 .43976 Mtetra
.648 .764 .933 r
.33988 .43976 .35061 .45032 .36787 .44447 .35721 .43387 Mtetra
.65 .765 .933 r
.35721 .43387 .36787 .44447 .38524 .43847 .37465 .42787 Mtetra
.654 .768 .933 r
.37465 .42787 .38524 .43847 .40274 .43221 .39222 .42166 Mtetra
.662 .773 .932 r
.39222 .42166 .40274 .43221 .42036 .42551 .4099 .41512 Mtetra
.675 .782 .93 r
.4099 .41512 .42036 .42551 .4381 .418 .42771 .40798 Mtetra
.7 .798 .926 r
.42771 .40798 .4381 .418 .45597 .40903 .44566 .39975 Mtetra
.74 .824 .916 r
.44566 .39975 .45597 .40903 .47397 .39749 .46373 .38957 Mtetra
.801 .861 .894 r
.46373 .38957 .47397 .39749 .49207 .38158 .48192 .37599 Mtetra
.876 .902 .845 r
.48192 .37599 .49207 .38158 .5102 .35895 .50019 .35689 Mtetra
.94 .928 .765 r
.50019 .35689 .5102 .35895 .52826 .32764 .51845 .32991 Mtetra
.971 .929 .67 r
.51845 .32991 .52826 .32764 .54609 .28823 .53656 .29404 Mtetra
.973 .919 .599 r
.53656 .29404 .54609 .28823 .56362 .24548 .55438 .25192 Mtetra
.967 .92 .584 r
.55438 .25192 .56362 .24548 .5809 .2063 .5719 .20995 Mtetra
.963 .938 .637 r
.5719 .20995 .5809 .2063 .59811 .17522 .58925 .17436 Mtetra
.946 .951 .742 r
.58925 .17436 .59811 .17522 .61539 .1526 .60661 .14753 Mtetra
.89 .925 .838 r
.60661 .14753 .61539 .1526 .63283 .13644 .6241 .12832 Mtetra
.815 .87 .888 r
.6241 .12832 .63283 .13644 .65045 .12441 .64176 .11437 Mtetra
.753 .82 .905 r
.64176 .11437 .65045 .12441 .66823 .11479 .65959 .10361 Mtetra
.713 .786 .909 r
.65959 .10361 .66823 .11479 .68616 .1065 .67759 .09465 Mtetra
.69 .765 .909 r
.67759 .09465 .68616 .1065 .70424 .0989 .69573 .08666 Mtetra
.678 .754 .909 r
.69573 .08666 .70424 .0989 .72244 .09165 .71401 .07916 Mtetra
.671 .748 .908 r
.71401 .07916 .72244 .09165 .74078 .08457 .73242 .07191 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47385 .22701 .46353 Mtetra
.22701 .46353 .23826 .47385 .25492 .46828 .24374 .45789 Mtetra
.24374 .45789 .25492 .46828 .2717 .46266 .26058 .45221 Mtetra
.26058 .45221 .2717 .46266 .28858 .45701 .27752 .44649 Mtetra
.646 .763 .934 r
.27752 .44649 .28858 .45701 .30557 .45131 .29458 .44073 Mtetra
.29458 .44073 .30557 .45131 .32267 .44557 .31175 .43492 Mtetra
.647 .763 .934 r
.31175 .43492 .32267 .44557 .33988 .43976 .32903 .42906 Mtetra
.648 .764 .934 r
.32903 .42906 .33988 .43976 .35721 .43387 .34642 .42313 Mtetra
.649 .765 .933 r
.34642 .42313 .35721 .43387 .37465 .42787 .36394 .4171 Mtetra
.652 .766 .933 r
.36394 .4171 .37465 .42787 .39222 .42166 .38157 .41091 Mtetra
.657 .77 .932 r
.38157 .41091 .39222 .42166 .4099 .41512 .39932 .40447 Mtetra
.668 .777 .931 r
.39932 .40447 .4099 .41512 .42771 .40798 .4172 .39758 Mtetra
.686 .789 .928 r
.4172 .39758 .42771 .40798 .44566 .39975 .43522 .38987 Mtetra
.717 .809 .922 r
.43522 .38987 .44566 .39975 .46373 .38957 .45336 .3807 Mtetra
.768 .841 .907 r
.45336 .3807 .46373 .38957 .48192 .37599 .47164 .36893 Mtetra
.838 .882 .874 r
.47164 .36893 .48192 .37599 .50019 .35689 .49002 .35277 Mtetra
.912 .918 .809 r
.49002 .35277 .50019 .35689 .51845 .32991 .50844 .32984 Mtetra
.96 .931 .717 r
.50844 .32984 .51845 .32991 .53656 .29404 .52679 .29818 Mtetra
.974 .924 .629 r
.52679 .29818 .53656 .29404 .55438 .25192 .54491 .25838 Mtetra
.97 .917 .583 r
.54491 .25838 .55438 .25192 .5719 .20995 .56271 .21523 Mtetra
.965 .927 .602 r
.56271 .21523 .5719 .20995 .58925 .17436 .58027 .17568 Mtetra
.958 .947 .687 r
.58027 .17568 .58925 .17436 .60661 .14753 .59774 .14429 Mtetra
.922 .943 .795 r
.59774 .14429 .60661 .14753 .6241 .12832 .61528 .1214 Mtetra
.852 .899 .869 r
.61528 .1214 .6241 .12832 .64176 .11437 .63299 .10499 Mtetra
.781 .843 .899 r
.63299 .10499 .64176 .11437 .65959 .10361 .65087 .09274 Mtetra
.73 .801 .908 r
.65087 .09274 .65959 .10361 .67759 .09465 .66892 .08291 Mtetra
.7 .774 .909 r
.66892 .08291 .67759 .09465 .69573 .08666 .68713 .0744 Mtetra
.683 .759 .909 r
.68713 .0744 .69573 .08666 .71401 .07916 .70548 .06659 Mtetra
.674 .751 .909 r
.70548 .06659 .71401 .07916 .73242 .07191 .72397 .05913 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45789 .23242 .44738 Mtetra
.23242 .44738 .24374 .45789 .26058 .45221 .24932 .44163 Mtetra
.24932 .44163 .26058 .45221 .27752 .44649 .26633 .43585 Mtetra
.646 .763 .934 r
.26633 .43585 .27752 .44649 .29458 .44073 .28346 .43002 Mtetra
.28346 .43002 .29458 .44073 .31175 .43492 .30069 .42414 Mtetra
.647 .763 .934 r
.30069 .42414 .31175 .43492 .32903 .42906 .31804 .41822 Mtetra
.31804 .41822 .32903 .42906 .34642 .42313 .33551 .41224 Mtetra
.648 .764 .933 r
.33551 .41224 .34642 .42313 .36394 .4171 .35309 .40617 Mtetra
.65 .765 .933 r
.35309 .40617 .36394 .4171 .38157 .41091 .37079 .39998 Mtetra
.654 .768 .933 r
.37079 .39998 .38157 .41091 .39932 .40447 .38862 .39359 Mtetra
.662 .773 .932 r
.38862 .39359 .39932 .40447 .4172 .39758 .40657 .38686 Mtetra
.675 .782 .93 r
.40657 .38686 .4172 .39758 .43522 .38987 .42465 .37952 Mtetra
.7 .798 .926 r
.42465 .37952 .43522 .38987 .45336 .3807 .44287 .37108 Mtetra
.74 .824 .916 r
.44287 .37108 .45336 .3807 .47164 .36893 .46122 .36068 Mtetra
.801 .862 .894 r
.46122 .36068 .47164 .36893 .49002 .35277 .4797 .34686 Mtetra
.876 .902 .845 r
.4797 .34686 .49002 .35277 .50844 .32984 .49826 .32748 Mtetra
.94 .928 .765 r
.49826 .32748 .50844 .32984 .52679 .29818 .51681 .30017 Mtetra
.971 .929 .67 r
.51681 .30017 .52679 .29818 .54491 .25838 .53521 .26392 Mtetra
.973 .919 .599 r
.53521 .26392 .54491 .25838 .56271 .21523 .55332 .2214 Mtetra
.967 .92 .584 r
.55332 .2214 .56271 .21523 .58027 .17568 .57112 .17905 Mtetra
.963 .938 .638 r
.57112 .17905 .58027 .17568 .59774 .14429 .58874 .14312 Mtetra
.946 .951 .742 r
.58874 .14312 .59774 .14429 .61528 .1214 .60637 .11599 Mtetra
.89 .925 .838 r
.60637 .11599 .61528 .1214 .63299 .10499 .62413 .09652 Mtetra
.815 .87 .888 r
.62413 .09652 .63299 .10499 .65087 .09274 .64205 .08233 Mtetra
.753 .82 .905 r
.64205 .08233 .65087 .09274 .66892 .08291 .66016 .07135 Mtetra
.713 .786 .909 r
.66016 .07135 .66892 .08291 .68713 .0744 .67843 .06217 Mtetra
.69 .765 .909 r
.67843 .06217 .68713 .0744 .70548 .06659 .69685 .05396 Mtetra
.678 .754 .909 r
.69685 .05396 .70548 .06659 .72397 .05913 .71542 .04625 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45397 Mtetra
.17073 .45397 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44738 .22097 .43674 Mtetra
.22097 .43674 .23242 .44738 .24932 .44163 .23793 .43093 Mtetra
.23793 .43093 .24932 .44163 .26633 .43585 .25501 .42507 Mtetra
.25501 .42507 .26633 .43585 .28346 .43002 .2722 .41917 Mtetra
.646 .763 .934 r
.2722 .41917 .28346 .43002 .30069 .42414 .2895 .41323 Mtetra
.2895 .41323 .30069 .42414 .31804 .41822 .30692 .40725 Mtetra
.647 .763 .934 r
.30692 .40725 .31804 .41822 .33551 .41224 .32446 .4012 Mtetra
.648 .764 .934 r
.32446 .4012 .33551 .41224 .35309 .40617 .34211 .39508 Mtetra
.649 .765 .933 r
.34211 .39508 .35309 .40617 .37079 .39998 .35988 .38887 Mtetra
.652 .766 .933 r
.35988 .38887 .37079 .39998 .38862 .39359 .37778 .38249 Mtetra
.657 .77 .932 r
.37778 .38249 .38862 .39359 .40657 .38686 .3958 .37586 Mtetra
.668 .777 .931 r
.3958 .37586 .40657 .38686 .42465 .37952 .41395 .36877 Mtetra
.686 .789 .928 r
.41395 .36877 .42465 .37952 .44287 .37108 .43224 .36086 Mtetra
.717 .809 .922 r
.43224 .36086 .44287 .37108 .46122 .36068 .45067 .35147 Mtetra
.768 .842 .907 r
.45067 .35147 .46122 .36068 .4797 .34686 .46923 .33947 Mtetra
.838 .883 .874 r
.46923 .33947 .4797 .34686 .49826 .32748 .4879 .32303 Mtetra
.912 .918 .809 r
.4879 .32303 .49826 .32748 .51681 .30017 .50663 .2998 Mtetra
.96 .931 .717 r
.50663 .2998 .51681 .30017 .53521 .26392 .52527 .26778 Mtetra
.974 .924 .629 r
.52527 .26778 .53521 .26392 .55332 .2214 .54369 .22759 Mtetra
.97 .917 .583 r
.54369 .22759 .55332 .2214 .57112 .17905 .56178 .18403 Mtetra
.965 .927 .602 r
.56178 .18403 .57112 .17905 .58874 .14312 .57961 .14412 Mtetra
.958 .947 .687 r
.57961 .14412 .58874 .14312 .60637 .11599 .59735 .11241 Mtetra
.922 .943 .795 r
.59735 .11241 .60637 .11599 .62413 .09652 .61517 .08924 Mtetra
.852 .899 .869 r
.61517 .08924 .62413 .09652 .64205 .08233 .63315 .07258 Mtetra
.781 .843 .899 r
.63315 .07258 .64205 .08233 .66016 .07135 .6513 .0601 Mtetra
.73 .801 .908 r
.6513 .0601 .66016 .07135 .67843 .06217 .66963 .05004 Mtetra
.7 .774 .909 r
.66963 .05004 .67843 .06217 .69685 .05396 .68813 .04131 Mtetra
.683 .759 .909 r
.68813 .04131 .69685 .05396 .71542 .04625 .70677 .03328 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45397 .15895 .44341 Mtetra
.15895 .44341 .17073 .45397 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43183 Mtetra
.19246 .43183 .20411 .44252 .22097 .43674 .20938 .42598 Mtetra
.20938 .42598 .22097 .43674 .23793 .43093 .22641 .42009 Mtetra
.22641 .42009 .23793 .43093 .25501 .42507 .24355 .41417 Mtetra
.24355 .41417 .25501 .42507 .2722 .41917 .26081 .4082 Mtetra
.646 .763 .934 r
.26081 .4082 .2722 .41917 .2895 .41323 .27818 .40219 Mtetra
.27818 .40219 .2895 .41323 .30692 .40725 .29567 .39613 Mtetra
.647 .763 .934 r
.29567 .39613 .30692 .40725 .32446 .4012 .31327 .39002 Mtetra
.31327 .39002 .32446 .4012 .34211 .39508 .33099 .38385 Mtetra
.648 .764 .933 r
.33099 .38385 .34211 .39508 .35988 .38887 .34884 .37759 Mtetra
.65 .765 .933 r
.34884 .37759 .35988 .38887 .37778 .38249 .36681 .37121 Mtetra
.654 .768 .933 r
.36681 .37121 .37778 .38249 .3958 .37586 .3849 .36462 Mtetra
.662 .773 .932 r
.3849 .36462 .3958 .37586 .41395 .36877 .40313 .35769 Mtetra
.675 .782 .93 r
.40313 .35769 .41395 .36877 .43224 .36086 .42149 .35015 Mtetra
.7 .798 .926 r
.42149 .35015 .43224 .36086 .45067 .35147 .43999 .3415 Mtetra
.74 .824 .916 r
.43999 .3415 .45067 .35147 .46923 .33947 .45863 .33086 Mtetra
.801 .862 .894 r
.45863 .33086 .46923 .33947 .4879 .32303 .4774 .31679 Mtetra
.876 .903 .846 r
.4774 .31679 .4879 .32303 .50663 .2998 .49626 .29712 Mtetra
.94 .928 .765 r
.49626 .29712 .50663 .2998 .52527 .26778 .51512 .26948 Mtetra
.971 .929 .67 r
.51512 .26948 .52527 .26778 .54369 .22759 .53382 .23284 Mtetra
.973 .919 .599 r
.53382 .23284 .54369 .22759 .56178 .18403 .55223 .18992 Mtetra
.967 .92 .584 r
.55223 .18992 .56178 .18403 .57961 .14412 .57031 .14718 Mtetra
.964 .938 .638 r
.57031 .14718 .57961 .14412 .59735 .11241 .58822 .1109 Mtetra
.946 .95 .742 r
.58822 .1109 .59735 .11241 .61517 .08924 .60612 .08347 Mtetra
.89 .925 .838 r
.60612 .08347 .61517 .08924 .63315 .07258 .62415 .06373 Mtetra
.814 .87 .888 r
.62415 .06373 .63315 .07258 .6513 .0601 .64235 .0493 Mtetra
.753 .82 .905 r
.64235 .0493 .6513 .0601 .66963 .05004 .66074 .03809 Mtetra
.713 .786 .909 r
.66074 .03809 .66963 .05004 .68813 .04131 .6793 .02868 Mtetra
.69 .765 .909 r
.6793 .02868 .68813 .04131 .70677 .03328 .69801 .02024 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43183 .18066 .421 Mtetra
.18066 .421 .19246 .43183 .20938 .42598 .19765 .41508 Mtetra
.19765 .41508 .20938 .42598 .22641 .42009 .21474 .40912 Mtetra
.21474 .40912 .22641 .42009 .24355 .41417 .23195 .40313 Mtetra
.23195 .40313 .24355 .41417 .26081 .4082 .24927 .39709 Mtetra
.24927 .39709 .26081 .4082 .27818 .40219 .26671 .391 Mtetra
.646 .763 .934 r
.26671 .391 .27818 .40219 .29567 .39613 .28427 .38487 Mtetra
.28427 .38487 .29567 .39613 .31327 .39002 .30194 .3787 Mtetra
.647 .763 .934 r
.30194 .3787 .31327 .39002 .33099 .38385 .31974 .37246 Mtetra
.648 .764 .934 r
.31974 .37246 .33099 .38385 .34884 .37759 .33766 .36615 Mtetra
.649 .765 .933 r
.33766 .36615 .34884 .37759 .36681 .37121 .3557 .35974 Mtetra
.652 .766 .933 r
.3557 .35974 .36681 .37121 .3849 .36462 .37387 .35316 Mtetra
.657 .77 .932 r
.37387 .35316 .3849 .36462 .40313 .35769 .39216 .34633 Mtetra
.668 .777 .931 r
.39216 .34633 .40313 .35769 .42149 .35015 .4106 .33903 Mtetra
.686 .789 .928 r
.4106 .33903 .42149 .35015 .43999 .3415 .42917 .33091 Mtetra
.717 .81 .922 r
.42917 .33091 .43999 .3415 .45863 .33086 .44789 .32129 Mtetra
.768 .842 .907 r
.44789 .32129 .45863 .33086 .4774 .31679 .46675 .30904 Mtetra
.838 .883 .874 r
.46675 .30904 .4774 .31679 .49626 .29712 .48572 .29234 Mtetra
.912 .919 .809 r
.48572 .29234 .49626 .29712 .51512 .26948 .50475 .26879 Mtetra
.96 .932 .716 r
.50475 .26879 .51512 .26948 .53382 .23284 .52371 .23641 Mtetra
.974 .924 .629 r
.52371 .23641 .53382 .23284 .55223 .18992 .54243 .19581 Mtetra
.97 .917 .583 r
.54243 .19581 .55223 .18992 .57031 .14718 .56082 .15185 Mtetra
.965 .927 .602 r
.56082 .15185 .57031 .14718 .58822 .1109 .57894 .11157 Mtetra
.958 .947 .687 r
.57894 .11157 .58822 .1109 .60612 .08347 .59696 .07953 Mtetra
.922 .943 .795 r
.59696 .07953 .60612 .08347 .62415 .06373 .61506 .05608 Mtetra
.852 .899 .869 r
.61506 .05608 .62415 .06373 .64235 .0493 .63331 .03916 Mtetra
.781 .843 .899 r
.63331 .03916 .64235 .0493 .66074 .03809 .65175 .02643 Mtetra
.73 .801 .908 r
.65175 .02643 .66074 .03809 .6793 .02868 .67037 .01614 Mtetra
.7 .774 .909 r
.67037 .01614 .6793 .02868 .69801 .02024 .68915 .00718 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001oogooE_`0
07oo0000Egoo003EOol30005Ool2Ea`01E/L001G77oo0000EWoo003BOol30006Ool02EKlFaaFo5/L
E_`005KlOol0001FOol00=1oo`8000Moo`05FcaK75/lEaaK7002Ea`01@00FaaG77oo0000EGoo003=
Ool30007Ool015/LGcaK75ll0U/L00UFo5/LE_`005KlEaaFo7oo0000E7oo003;Ool20008Ool3Fc`0
1E/LFcaK?5/lFa`00UKl00MG7000E_aFo5LLOol0001DOol00<Qoo`<00003Ool007oo00Ioo`07HeaO
>ellFaaO?5/LGc`00U/L0ULL00QFo5LL001G75KlEaaoo`00Dgoo001WOol20002Ool2001IOol20004
Ool00`00Oomoo`03Ool5He`3Fc`5Fa`2E_`01000E_aFo5Kl0Woo00<007ooOol0D7oo001XOol01000
Oomoo`00Egoo0`002Woo01QSG6=KHeaO>f=LHe]SG5lkFcaG75/LEaaK?5LLFaaFo5LL001G75;lEaaB
o7oo001BOol006Uoo`8005Ioo`8000aoo`9[V`ISG09O?0MK7003E_`005Kl00AFo003Ool007oo051o
o`00JGoo0P00Dgoo0`003Goo00U_Vf]jKi][NV=LHe]SG5lkGe`00Ull015G75/lEaaK75LLFaaFo5/L
001G75;lEaaBo5LLD_aoo`00051oo`00J7oo00@007ooOol0051oo`8000moo`I[V`MO?0=G7005FaaG
75LLEa`00004E_`015;lE_aFo000D7oo001WOol20002Ool2001<Ool3000@Ool02FnKJgY_Vf]jKi][
NVMlIe]OG002Gc`055lkGeaK75llE_aK75KlFaaFo5/L001Fo5;lEaaBo5KlD_aG77oo001?Ool00;Io
o`<0009oo`03001oogoo00eoo`E[V`=WN`06IgaO?5llGcaK?5/L0e/l0eLL00=K75LL00000UKl00MB
o5KlE_aFo5;lE_`0001?Ool00;Aoo`8001Aoo`0AMmUc^6nKJgY_VfMKIgaWFfMlIe]WO5/LGcaK75ll
FaaO?002Fa`01UKlFaaFo5LL001G709Fo007D_aG75;lE_aBo7oo0000CWoo002aOol3000FOol017>h
MkQc^6Ml0fMk00=WO6MkIg/00V=L00EK75/lFcaK?5/L009K?005EaaFo5KlE_`00004E_`01e;lE_aB
o5KlD_aoo`0004eoo`00[goo0P0067oo01Ac^7NiLkQc^VnIIgaWFfMlIe]WO5lkHeaSFf=LFaaO?5/L
GcaG75/l0ULL00iFo5LL001G75KlEaaBo5KlD_aFo5;lE_aoo`004Goo1@00=goo002/Ool3000IOol0
2G>hMkQc^7>jKiY_^VnJIgaWN`07He`6Fa`015KlEaaFo00015Kl00QBo5KlD_aFo5;lE_aoo`0047oo
00D007ooOomoo`0003Moo`00ZWoo0P006goo011c^7NiLkQgfFnILkY_VG>jKiUSG5lkHeaSFf=LGc]S
G09O?00CEaaK?5LLFaaG75/lD_aG7000EaaBo5LLD_aFo5;lE_aBo5KlD_`00Woo00<007ooOol03Woo
00<007ooOol0>7oo002WOol30002Ool00`00Oomoo`0HOol027NhLkQg^FnJKkY_VW>jKiX2Ji/4He`4
Gc`5Fa`2Ea`00eKl001Fo005E_`00e;lE_aBo002D_`00goo001oo`06Ool60004Ool00`00Oomoo`0g
Ool00:Eoo`8001moo`0?MkUc^7OIKiUc^VnILkY_VFnKJgY_Vf]jKi]O>emL009O?00IGc]OG5llFaaG
75/LE_aK75KlFa`005LLD_aG75;lEaaBg5KlD_aFo5;LE_aBo7oo00004Goo00<007ooOol0=Woo002R
Ool3000POol3NkD016nJKkY_VW>j1V^K00=WNfMlGc`01Ell00=G75/LEa`00ULL00=K75LL00001UKl
0e;l00IFo5;lD_aBo7oo000AOol00`00Oomoo`0eOol007Eoo`@002Moo`8002=oo`0BMkAkeGNfNmMg
]W_GJgY_Vf]jKi][NVnKIe]WO6MKGcaO>emL0Ull01QK75llE_aK75KlFaaFo5/L001G75;lE_aBo5LL
D_aFo5;LE_aBo5KlD]aFo5;L000=Ool01@00Oomoogoo0000=goo001dOol00`00Oomoo`02Ool00`00
Oomoo`0QOol3000TOol2NkD01WNeMkMg]gOGLkQg^0=[V`9WN`06IgaWNfMkIg]K?5/L0e/l00AK75/l
EaaK709G7003E_`005Kl00=Fo004D_aFo5KlE_`3D_`01EKlD_aBo7oo00003Goo0`00>7oo001dOol0
0`00Oomoo`02Ool00`00Oomoo`0NOol3000WOol0;g_EMkEkegNfNmMg]WNiLkQ_Vf]jIgaWFfMlIe]W
O6MKHeaSFellFaaO?5/LGcaK75llE_aG75KlEaaFo000D_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aF
o7oo0000Agoo001dOol00`00Oomoo`02Ool00`00Oomoo`0LOol20002Ool00`00Oomoo`0TOol02W^e
MkEk]GNgMmMg]WNhLkQg^G>h0VMk00AWO6MkIg]WN`ASG003FcaK75/l009K?09K700>E_aG75KlE_`0
05LLD_aFo5;lE_aBo5KlD_aFo0=Bo004E_aBo7oo0017Ool007Aoo`03001oogoo009oo`03001oogoo
01Uoo`<002]oo`0JMkEkeGNfNmMg]WNiLkQgfG>hLkY_VFMlIe]WO5lkHeaSFf=LGc]SG5/LGcaK75/l
EaaK709G700EE_aG75Kl001Bo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aoo`0004Ioo`00M7oo
00<007ooOol00Woo00<007ooOol05goo0P00;Goo00ig]G^eMkMgegNfMkQc^7NiLkQ_^VnJLkY_VVnj
26=L1e/L0eKl00X005KlE_aFo5;lE_aBo5KlD_aFo0IBo09oo`03001oogoo04=oo`00M7oo00<007oo
Ool00Woo00<007ooOol057oo0`00;goo03=keGNdNmMg]W_GLkQgfG>hLkY_VG>jKiUc^V]jKi]SFf=L
Gc]SG6=KHeaO>emLEaaK75LLFcaG75/LE_aG75;l001Bo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo7oo0000AGoo001eOol4000EOol2000aOol2NkD02gOGMkIg]g>hMkUc^6njKiYc^VnJKkX016^K
0f=L15ll0e/L0eLL00AK75LLE_`000EFo0=Bo003E_aBo5;l00IBo003Ool007oo04=oo`00Rgoo0`00
<Woo01=k/gNBNk=g/g^dMkAkeGNeLkY_VG>jKiUc^V]jKi][NVnKJgY_V`02Gc`08UlkGeaO?5llGc]K
75KlFaaFo5/LE_aK75;l001Bo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aoo`00@goo
0029Ool20002Ool00`00Oomoo`0`Ool2Nk83Nk<01g^eMkEg]gNgLkY_VVnj00I[V`9WN`AO?09K?004
FaaG75LLFa`3Ea`00e/L001Fo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01E;l00=oo`00Ool0@Woo
0026Ool3000fOol0>GNBNk=kTW^dMk=keGNeNmEg]W_GMkIkef]jKi][NVnKJgYWO6MKIgaWFfMlFaaO
?5/LGcaK75llE_aK75KlFaaFo5LLE_`005;lEaaBo5KlD_aG75;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LOol00012Ool008Aoo`8003Uoo`0=Nk9kTW^cNk=k]7NeNkEg]gOGMkIg]g>hMkT00f^K00EWO6Mk
Ig]WNfMl009SG09K?004FaaK?5/lFc`3E_`01ULLE_aFo000E_aBo0=Fo004D_aFo5;lE_`3D_`00eKl
D_aBo005D_`00goo001oo`10Ool0085oo`<003Yoo`0UNk=kTW^cMk=k]7NeNmEg]7_GMkIkeg>hMmUc
^7NiIe]WO6MKIgaWFfMlHe]SG5lkGcaK75llFaaK?5LLFaaFo5LLE_aG75Kl00000UKl01ABo5KlD_aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aoo`00@Goo001nOol3000mOol01G^BNk9k/g^dNk<0
0W^e00UgegNfMkMg]gNiLkQg^6nJLkX00fMk1V=L1e/L0eKl00=G7000E_`00UKl00ABo5KlD_aFo0=B
o003E_aBo5;l00QBo003Ool007oo03moo`00O7oo0P00?goo03ikTW^cMi9k]7NcNmEg]7_GMkIkegNf
MmUc^7NiKiUc^VnILkY_VF=LHe]SG5lkHeaSFellGc]K?5LLFaaG75/lEaaK75;lEaaBo000D_aG75;l
E_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aoo`00?goo001iOol30002Ool2000m
Ool2Nk800g^dNk=k/`02NkD02gNfMkMg]gNiLkQg^6nJLkY_VVnjKiX00V^K0f=L1Ell1E/L00EG75/L
E_aFo00000=Fo003D_aFo5;l009Bo003E_aBo5;l00]Bo003Ool007oo03ioo`00Mgoo0P00@goo01Mk
/gNBNk=g/g^dMkAkeGNfNmMg]WOILkQg^FnILkY_VG>jKiU_Vf]jKi][NUmL009O?00WGc]OG5llGcaG
75/lEaaK75KlFaaFo5LLD_`005;lEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aoo`0003ioo`00M7oo0`00AGoo0W^b00EkTG^BNi9k/W^B009k/`08NkEg]G^eKiYc^VnJKkY_
VPA[V`03IgaWNell00IO?0=G7006FaaG75LLEaaFo0000eKl0e;l00EFo5;lD_aBo5Kl00aBo09oo`03
001oogoo03]oo`00LWoo0P00Agoo01YkTG^bNi5k/WNANk=kTW^dMk=k]7NeNmEg]7_GKiUc^VnIKi][
NVnKJgYWO6MKIgaWFemL0Ull02IO>ellFaaO?5KlFaaFo5/LE_aK75;l001Bo5LLD_aFo5;lE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aoo`00?Goo001_Ool30019Ool02W^BNi5kTW^B
Nk9kTW^bNk=k]7Ne0W^e00AgegNfMkMg]`=[V`03Ig]WO6Mk009WN`03IgaWNe/l009K?004FaaK?5/l
Fa`4Ea`3E_`00`00D_aFo002E_`3D_`00eKlD_aBo00:D_`00e;LD_aBo002Ool00`00Oomoo`0jOol0
06eoo`800003Ool007oo04Qoo`12Nk9kTG^bMi5k/W^BNk=g/g^dMk=keGNdNmEg]W_GMkIgfG>hMkUW
FfMlIe]WO6MKIgaWFf=LGc]O?5/LGcaK75llFaaG75KlEaaFo5LLE_aG7000E_aBo5LLD_aFo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L0Woo00<007ooOol0>Goo001ZOol3001=Ool0
1G^ANi9kTW^bNi400W^b00=k]7^cNkD00W^e00Qg]WNgMkMg^G>hMkQ_VW>j0fMk00=WO6MkHe`00V=L
00AK75/lFcaK?0=K700=EaaFo5KlE_aG75Kl001Bo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`02U;l00EB
g5;lD_aoo`0003]oo`00Igoo0`00Cgoo02AkTG^bNi5k/W^ANk=gTW^dMk=k]7NdNmEg]G_GMkIkeg>h
MkUc^7>jKiUc^VMKIgaSFf=LGc]SG6=KHeaG75/lEaaK75LLFc`2Ea`08EKlEaaFo5LL001G75;lE_aB
o5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LOol0000jOol006Eoo`80
059oo`=kTP04Ni5kTW^bNk82Nk<2NkD037NeMkMg]gOGLkQg^7>hLkY_VVnjKiYc^PISG09O?0MK70AF
o005001Fo5KlD_aFo003D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00U;l00<007ooOol0>7oo001R
Ool3001DOol07W^ANk9kTG^bMi9k/gNcNkAg/g_EMkEkeGNfNmMc^7NiLkQc^VnILkY_VG>jJgY_Velk
HeaSFellGc]OG09O?00XEaaK?5LLFaaFo5/LE_aG75;lEa`005LLD_aFo5;lE_aBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L000iOol0061oo`8005Ioo`9kTP05Ni5kTW^B
Nk9kTP02Nk<03G^eMkEk]GNgMmMc^7NhLkQg^FnJKkY_VW>j00A[V`QO?0=G7003FaaG75LL00=Fo003
001Fo5Kl00=Bo003E_aBo5;l00iBo008D]aBo5;lD_aBg5;lOol003Qoo`00GGoo0`0000=oo`00Ool0
EGoo01ek/W^ANk9gTG^cNi9k/WNANk9kTW^cMi9k]7NeNmEg]7_EKiUc^VnIKi][NVnKJgY_VfMKIgaO
>emL009O?00[Gc]OG5/LGcaFo5/LE_aK75KlFaaBo5Kl001G75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl0000>7oo001KOol2001KOol01G^ANi9kTW^b
Ni400W^B00Ik/W^BNk9k/W^dNk<3NkD00gNfMkMg]`05Ji/3Ig/01VMlGcaO?5llFcaK709K?003FaaG
75LL009G7005E_aG75Kl001Bo003E_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo
0000=goo000^Ool4000VOol3001LOol0CG^ANk9gTG^bNi9k/WNANk9kTG^cMi9k/gNcNmEg]7_EMkEk
egNfMmUc^6nKJgYWO6MKIgaWFfMlIe]WO5/LGcaK75llFaaO?5/LEaaFo5LLE_aG75KlEa`005KlD_aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg7oo0000
8Woo0`004Goo000]Ool00`00Oomoo`02Ool00`00Oomoo`0QOol2001OOol2Ni801W^bNi9kTW^BNk9k
T@=k/P9k/`9k]@08MkEg]gNgMmMc^7NhLkQWO0=WN`03IgaWNfMk009SG004FaaK?5/lFc`3Fa`03ELL
E_aG75KlEaaFo000D_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01U;L
D_aBo5;lOol002Aoo`03001oogoo00moo`00<Woo00<007ooOol07Goo1000H7oo04mk/W^AOkAkTW^b
Ni5k/W^ANk9gTW^cNi9k]7NdNmEg]G_GMkIkeg>hMkUc^7>jKiUWO6MKIgaWFf=LGe]SG6=KGcaK75ll
EaaK75LLFcaFo5LLE_aG75;lEa`005KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000SOol00`00Oomoo`0?Ool002Eoo`H000Moo`03001o
ogoo01aoo`<0069oo`03Ni=k/g^B00=kTP05Ni5kTW^bNk9kTP02Nk<02W^eMkEg]gNgMmMc^7NhLkQc
^VnJ0Vnj00=c^V=LHe`01F=L1e/L1EKl00L005KlE_aBo5KlD_aFo00>D_`01E;LD_aBo5;lD]`00e;l
00IBg5;lD_aBo7oo000QOol00`00Ool0000@Ool002ioo`@001aoo`<006Eoo`1@OkAkTg^bNi9k/W^A
Nk9gTG^cNi9k/gNcNmEg]G_EMkIkeg>hMkUc^7OIKiUc^VnILkY[NVnKGe]SG6=KHeaO>emLGcaK75LL
FcaG75/LE_aK75;lEaaBo5LL001G75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0025oo`03001oo`00011oo`00;Woo00<007ooOol06Woo
0`00Igoo00Ik/g^CNi9kTW^bNi42Ni803W^bNi9k/W^cNkAg]G^eMkMgegNfMkQc^7NiKiX2KkX00g>j
Ji][V`02Ji/7Gc`01E/LEaaG75LLFa`00ULL0eKl00<005KlE_`00e;l00=Fo5;lD_`03U;l00EBg5;l
D_aBo5;L00=Bo003D]aBo5;l008001moo`05001oogooOol0000?Ool002ioo`03001oogoo01Qoo`80
06Yoo`0PNi=k/g^BOk=kTG^bMi5k/W^BNk=gTW^dNi9k/gNBNkAg/gNiLkQgfFnILkY_VG>jJgY_Vf]j
Ki]WFfMlGc]OG09O?00aGc]O?5/LFaaFo5/LE_aK75KlFaaBo5Kl001G75;lE_aBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo00007Woo00D0
07ooOomoo`0000moo`00;Woo1@004goo0`00Jgoo00AkTg^cNi=k/P=kTP03Nk9kTW^b009k/P05Ni5k
/W^bNkAk/`03NkD017NfMkM_^W>j16^K0fMk00=WO5llGc`00U/l00AK75/lFcaK70AG7005E_aG75Kl
001Bo003E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aB
o7oo000MOol3000017oo000000003Woo0014Ool2001^Ool0EG^cNi=o/g^BNk9kTG^bNi5k/W^ANk9k
TG^cMi9k/gNcNkAg]7_EMkEkegNfNmM[NVnKJgYWO6MKIgaWFfMlIe]WO5/LGcaK75llFaaO?5/LEaaF
o5LLE_aG75KlEa`005KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`0000Uoo`@002Aoo`00@Goo0`0000=oo`00Ool0K7oo00=k
/g^CNk<00g^B00=k/W^ANi800W^B00AkTG^BNk9k/P9k/`9k]@08MkEg]gNgMmMc^7NhLkQWO0=WN`03
IgaWNfMk009SG004FaaK?5/lFc`3Fa`01ELLE_aG75KlEa`00UKl00H005KlD_aFo5;lE_`3D_`00eKl
D_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo0007Ool00`00Oomo
o`02Ool00`00Oomoo`0QOol003moo`80079oo`1GNi=o]7^BNk9kTW^bNi9k/W^ANk9kTG^bMi9k/g^B
NkAg/g_EMkEkeGNfNmMc^7NiLkQc^VnIIgaWFfMlIe]SG5mKHeaSFellFaaO?5LLFaaG75/lE_aG75Kl
EaaBo5LLD_`005;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0000Moo`03001oogoo009oo`03001oogoo025oo`00?7oo0`00
Lgoo00=kTg^cNi<00g^B00EkTg^BNi9kTW^A009kTP0>Nk9kTW^cNk=k]GNeNkEg]gOGMkIg^7>hMkU_
VP9_^P03LkYSG6=L00ESG0MK70IFo006001Fo5;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`00e;LOol00006Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003Yoo`8007Ioo`1G
OkAkTg^bNi9o/g^CNk9kTW^bNi5k/WNANk=kTW^cMk=keGNeNmEg]W_GMkIg^G>hMmU_VG>jKiUc^V]j
Ki]OFf=LHe]SG5mKGeaO?5/LEaaK?5LLFaaFo5/LD_aG75;lEaaBo000D_aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo025oo`00=goo0`00Mgoo00Yk/g^CNk=k]7^eNi=k
/g^BNk9kT@9kTP06Nk9kTW^bNk=k]7Ne0W^e00IgegNfMkQc^7NiKiX2KkX017>jJi][Vf^K0f=L15ll
0e/L0ULL00=K75LLE_`015Kl00<005KlD_`00U;l00=Fo5;lD_`03U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`00goo001oo`04Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003Eoo`800003
Ool007oo07Moo`0TMiIk]W^DNkEkU7^cNi9o/g^BNk9kTG^bNi9k/gNBNkAg]G_EMkAkegNfMkUc^7OI
LkQc^VnILkY[NVnKJgY_Vf]jGcaO>emL0Ull03=O>emLE_aK75KlFaaFo5/LE_aG75;lE_aBo000D_aF
o5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]`00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol08Goo000bOol3001k
Ool027NfNkIk]W^eNiAk/g^CNk84Ni801G^ANk9k/W^bNi400g^b00Ek/g^eNkEk]GNe009_^P03LkY[
Vf^K00=[V`9WN`AO?005FcaK75/lEaaK7002Ea`00eKlEaaFo003E_`01000E_aFo5Kl0e;l00=Fo5;l
D_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0`0017oo
100097oo000_Ool3001nOol0GW^fMiEk]G^DNkEkTgndNi9k/W^ANk9kTG^cMi9k/W^ANk9gTW^cMk=k
]7NdNmEg]G_GMkIkef]jKi][NVnKIe]WO6MKIgaWFfMlFaaO?5/LGcaK75llFaaG75KlEaaFo5LLE_aG
75;l001Bo5LLD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`00;7oo000]Ool20020Ool3NkH017^DNkAkTg^c17^B00Ik
TG^BNi9kTW^ANi82Nk8037^BNk=k]G^eMkEk]GNgMmMc^7NhLkQWO0=WN`03IgaWNfMk009SG004FaaK
?5/lFc`3Fa`01ULLE_aG75KlEaaFo0800005E_aBo5KlD_aFo003D_`00eKlD_aBo006D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg5;l0Woo00<007ooOol0:Goo000ZOol3
0022Ool0<GNENkIkU7^eNiAo]7^CNk9kTW^bNi5k/W^BNk9kTG^bMi9k/g^BNkAg/g_EMkEkeGNfNmMc
^7NiLkQc^VnIIgaWFfMlIe]SG5mKHeaSFellFaaO?5LLFaaG75/lE_aG75Kl00<0000ZD_aFo000E_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5Kl0Woo00<007ooOol0:7oo000XOol200000goo001oo`21Ool2NkH01GNfNkAk
]7^cNi<00W^B00=k/W^ANi800W^B015kTG^BNi9k/W^BNk9k/g^eMkEk]GNgMmMg]WNhLkQg^FnJ009_
^P03LkYSG6=L00ESG0IK70<000AFo006D_`005;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo000ZOol002Ioo`8008Eoo`0^MiEk]WNFNkEkU7^eNi=k
/g^BOk=kTG^bNi=o/g^ANk9gTG^cNi9k/WNcNkAg]G_EMkIkegNfMkUc^7OIKiUc^VnILkY[NVnKGe]S
G6=KHeaO>emLGcaK75LLFc`20000<EKlFaaBo5LLD_aG75;lEaaBg000D_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
009oo`03001oogoo02Moo`009Woo0P00QGoo00ik]WNfNkIk]7^eNi=k/g^BNk9kTW^cNi=k/W^A0W^B
00Ik/W^BNk9k/W^dMkD2NkD01WOGMkIg^7>hMkU_VP9_^P03LkY[Vf^K009[V`IO?0<0009G7003FaaG
75Kl00IFo004D_`005;lE_`@D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg002Ool00`00Oomoo`0VOol002Ioo`<008=oo`0YNkIgUW^fNiAk]G^DNk=kTg^eNiAk]G^COkAk
TW^bNi5k/W^BNk9gTW^dMk=keGNdNmMg]WNiLkQgfG>hLkY_VG>jJgY_Vf]jKi]WFfMlGc]OG0030000
>UllFaaK75KlFaaFo5/LE_aG75;lE_aBo5LLD_aFo5;L001Bo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00:7oo
000VOol01000Oomoo`00PWoo00Eg]W^fNkIk]G^D00=k]P04NiAk]7^CNk<4Ni801G^ANk9k/W^bNk<0
0g^b0W^c0W^e00Ag]FnjKkYc^PA[V`9WN`<00007GcaK?5/lFaaK?5LLFa`00ULL00=Fo5LLE_`00eKl
00EBo5KlE_aFo000009Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo004D]aBo5;lD_`2Ool00`00Oomoo`0UOol002Eoo`03001oogoo009oo`03
001oogoo07ioo`0TMiIk]WNEMkQgUg^fMiEk]W^DNkEkU7ndNi=k/W^ANk9kTG^bMi9k/g^ANk9gTW^c
Mk=k]7NdNmEg]G_GMkIkef]jKi][NVMl0`00045WO6MKGcaK75llFaaO?5/LGcaFo5LLE_aG75KlEaaB
o5LLD_aFo5;lE_aBo5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0002Moo`009Goo00<007ooOol00goo
00<007ooOol0O7oo0g>I00=g^7NGMkL00W^f00Ig]W^dNkAk/g^CNk<2Ni801W^ANi9kTW^BNi5kTP9k
/P0:Ni9k/g^cNkEg]G^eMkMgeg>hMkP30002Ig/01VMlIg]SG6=LFcaK709K?0=K700?E_aG75KlEaaF
o5LLD_aFo5;lE_aBo5KlD_aFo000009Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aoo`009Woo000UOol00`00Oomoo`04Ool0
0`00Oomoo`1jOol087>ILkUcV7NiMiMg^7NENkIgUW^eNiAk]G^CNk=kTW^bNi5k/W^BNk9kTG^bMi5k
/g^BNkAg/g_EMkEkeGNfNmL30000AW>jKiUWO6MKIgaSFf=LGe]SG6=KHeaG75/lEaaK75LLFcaFo5LL
E_aG75;lEaaBo5KlD_aFo5;lE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00<007ooOol08goo000U
Ool20006Ool2001jOol2LiT03W>iMiMg]gNgNkIg]W^fNkAk]G^CNk=kTg^bNi43Ni801W^ANi9kTW^b
Ni9k/P9k/`03MkEk]GNg00800004MkQc^7>jKiX2KkX00g>jHeaSG004He`2Gc`6Fa`6E_`015;lE_aB
o5Kl0e;l00<005;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aoo`0002Eoo`009Goo00<007ooOol01goo00<007ooOol0MWoo01ac^G>HMkUc
VGNhMiMk]WNFNkIkU7^eNiAk/g^COk=kTG^bNi=o/g^ANk9gTG^bNi9k/WNcNkAg]@<0001?MkIg^G>h
MmU_VG>jKiUc^V]jKi]OFf=LHe]O?5lkGeaO?5/LEaaK?5LLFaaFo5/LD_aG75;lEaaBo5LLD]aFo5;l
E_aBg5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000097oo000UOol00`00Oomoo`08Ool00`00Oomo
o`1dOol2LiT01W>iLiUg]gNgMkQg]P9k]P09NkEkU7^cNi=k/g^BNk=kTg^b00=kTP04Nk9kTG^bNk83
00001g^eMmMg]WNhLkQg^FnJ009_^P03LkY[Vf^K009[V`MO?006FaaG75LLEaaK75LL1eKl0e;l00EF
o5;lD_aBo00000aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo7ooOol0000SOol002Eoo`03001oogoo00Uoo`03001oogoo079oo`0HLkUcV7NiLiUg^7NG
MkQgUW^fMiEk]G^DNkEkTgndNi9k]G^COkAkTW^bNi5k/W^A0`0001Ag/g_EMkAkegNfMkUc^7OIKiUc
^VnIKi][NVnKJgY_VfMKIgaO>emL0Ull041K75llFaaK75KlFaaFo5/LE_aG75;lE_aBo5LLD_aFo5;L
E_aBo5KlD]aFo5;L001Bg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol002=oo`0097oo0P0037oo00<007ooOol0L7oo
0V]k00Ic^G>ILiUg]gNhMiL3NkH027^DNkAkTg^cNi=k]7^CNk<3Ni830002Nk82Nk<2Nk82Nk<2NkD0
0gNfMkMg]`05Ji/3Ig/00fMlFaaK?002Fc`015/LFcaG75/L0ULL00=Fo5LLE_`00eKl00ABo5KlE_aF
o0=Bo004E_aBo5;l0005D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol0029oo`0097oo00<007ooOol037oo00<007ooOol0
KWoo01A[VfMjJi]WNf^KMiMg^7NGNkIgUG^fNiAk]G^DNkIgUW^eNiAo]7^C0`0005]kTG^bMi9k/g^A
Nk9gTG^cMk=k]7NdNmEg]G_GMkIgfG>hKi][NVMlIe]WO6MKIgaSFf=LFaaO?5/LGcaK75llE_aG75Kl
EaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00
Oomoo`0OOol002Aoo`03001oogoo00eoo`03001oogoo06aoo`E[N`=_VP9cV@08LkUcVGNgMkMk]WNf
NkIk]0<0009kTP05Ni5kTW^BNi9kT@02Ni801W^bNi9k/g^cNkEg]@9g]`05MmMc^7NhLkQWO003Ig/0
0fMlHeaSG002He`00e/LFcaK?003Fa`03UKlEaaFo5LLE_aG75;lE_aBo5KlD_aFo5;lE_`6D_`00`00
D_aBo003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00=Bg7oo00008Goo000TOol00`00Oomoo`0>Ool00`00Oomoo`1ZOol01V^KIgY[
VfMkJi]_NP=_VP08LiQg^G>IMkQgUgNhMiIk]P80001UNi=k/g^BOk=kTG^bMi5o/g^ANk9gTG^bNi9k
]7NcNmEg]G_EMkIkeg>hMkUc^7>jKiUWO6MKIgaSFf=LGe]SG6=KHeaG75/lEaaK75LLFcaBo5LLD_aG
75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000POol0
02Aoo`03001oogoo00moo`03001oogoo06Qoo`E[N`A_VP06LiUc^G>ILiUg]gNh0`0000Ek]G^CNk=k
Tg^b00=kTP07Nk9kTG^BNi9k/W^BNk800W^c00Ug]G^eMkMgeg>hMkQc^7>jKiX00Vnj00=c^V=LHe`0
16=L0Ull15/L0ULL1UKl00ABo5KlD_aFo0UBo003001Bo5;l00ABo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`0MOol0
02Aoo`80015oo`03001oogoo06Ioo`06HeaO?6^KIg][Vfmj0fnJ00AcV7NiLiUc^@<0000WNkIgUG^e
NiAk/g^COk=kTW^bNi=o/g^BNk9gTG^bNi5k/WNcNkAg]G_EMkIkegNfMkUc^7OIKiUc^VnILkY[NVnK
Ge]SG6=KGcaO>emL009O?012E_aK75KlFaaFo5/LD_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;L
E_aBg5KlD]`005;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`007goo000SOol00`00Oomoo`0BOol00`00Oomoo`1S
Ool01UmLHeaOG6=LGeaSG0A_VP03LiUc^@0000800009MkQgUg^fNkIk]G^DNk=kTg^c009kTP03Ni=k
/W^B009kTP04Nk9kTG^bNk82Nk<2NkD01WOGMkIg^7>hMkU_VP9_^P03LkY[Vf^K009[V`IO?09K?0=G
7003FaaG75LL009Fo004D_aFo5KlE_`3D_`00eKlD_aBo007D_`01000D_aBo5;L0e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003Ool0
07oo01eoo`006Woo10001Goo00<007ooOol04goo00<007ooOol0HGoo00QOG6=LGcaSG5mLHeaSFfMl
0VnJ0`0002]c^GNGMkQgUg^fMiEk]W^DNkEkTgndNi9k/W^DOkAkTW^bNi5k/W^ANk9gTW^dMk=keGNd
NkAg/g_EMkAkeFnILkY_VFnKJgY_Vf]jKi]WNfMlGc]OG002Gc`0@e/LGcaK75/LE_aK75KlEaaFo5LL
D_aFo5;lEaaBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03
001oogoo01]oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol057oo00<007ooOol0
GWoo00USG5mLHeaOG6=LGeaWO6MKIg`00`0000Ic^G>ILiUcVGNhMiL3NkH01G^DNkAkTg^cNi<00W^d
00=k/g^BNi800W^B00IkTG^BNk9k/W^cNi82Nk82Nk<2NkD00gNfMkMg]`04Ji/01VMlIg]WNfMkIgaK
70=K?008FaaK?5/lEaaFo5LLE_aG70AFo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01@00D_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L009Bo003Ool007oo01aoo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
5Goo00<007ooOol0Fgoo00QG75/mFcaSG5llHeaOG6Ml0`0003MWO6=KJi]WNf^KIgYg^7NGMkQgUG^f
MiIk]G^DNkIgUW^fNiAk]G^CNk9kTW^bNi5k/WNANk=kTG^bMi9k/gNcNkAg]7_EMkEkegNfMmUc^7Ni
Ie]WO6MkIgaWFfMlHe]SG5/LGcaK75llEaaK?002Ea`015KlEaaFo5LL0UKl03]Bo5KlD_aFo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0001aoo`006Goo00<007oo
Ool00Woo00<007ooOol00Woo0P005goo0P00F7oo00UK?5/mFcaK?E/lFceK?5/mHe/00P0000AWO6=K
IgaWF`A[N`=_VP9k]P0=MkIg]gNgNkIg]W^fNkAk]G^CNk=kTW^bNi400g^B00EkTG^BNi9k/W^B009k
/`09NkEg]GNgMkMgeg>hMkQ_^W>j00=WN`ESG0IK7004E_aG75KlEa`4E_`015;lE_aBo5Kl3U;l00D0
05;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg002D_`00goo001oo`0JOol001Uoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo01Qoo`03001oogoo05Aoo`07EaaG7ELLFceK?5/mEa`00`00081SFfMlHe]WO6MjJi]WNf^K
IgY_VVmjKiYcV7NiLiUg^7NGMkQgUW^fMiEk]G^DNk=kTWncNi5k/WNAOk=kTG^bMi5k/g^BNkAg/g_E
MkEkegNfNmMc^7NiKiUc^VnILkY_VF=LHe]SG5mKHeaO?5mLEaaK?5LLFaaG75/lD_aG75;lEaaBo5LL
D_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000
6goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`1AOol00eLM
EaaG7@02Ead01E/l00000000Fc`00ell00=SFfMlJg/016]k16nJ00Ic^G>ILiUg]gNhMkH2NkH01G^e
NiAk]7^CNk800g^B00Mk/W^ANi9kTW^bNi9k/P02Nk<02GNeMkMg]gOGLkQg^7>hLkY_VP02KkX2Ji/2
He`5Gc`4Fa`2Ea`6E_`3D_`00eKlD_aBo00=D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol001Yoo`00
6Goo00<007ooOol00Woo00D007ooOomoo`0001eoo`03001oogoo04ioo`05DaaG?ELLEaeC70030000
R5/lGeeK?5mMFcaOGE/lGeeWNV^KIg][VfMjKiY_NVnJKgYg^G>ILkUgUgNhMiMk]WNENkIkU7^eNi=o
/g^BNk9kTgncNi9k/W^ANk9kTW^bMk=k]7NeNmEg]W_GMkIg^G>hLkY_VG>jKiU_Vf]jKi][NUmLGcaO
G5lkGeaO?5mLE_aK75KlFaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`001goo1@003Goo000JOol40004Ool2000MOol0
0`00Oomoo`1;Ool2Dad00eLMEa`0000200001ELLEaeG7E/mFc`00ell00AK?5llGeaSG0=[N`A_VP06
LkUcVG>ILiUg^7NG0g^f00AkU7^dNkAk/`9kTP03Ni=k/W^B009kTP04Nk9kTG^bNk82Nk<02G^eMkMg
egNfMkQc^7>jKiY_^P05Ji/00fMlIg]O?003Gc`3Fc`4Ea`01EKlEaaFo5KlD_`00eKl0e;l00=Fo5;l
D_`01U;l00EBg5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOol00007Ool01@00Oomoogoo
00003Goo000ROol00`00Oomoo`0MOol00`00Oomoo`16Ool01E;lEaeBo5LMD_`00`0008mC75LmEaaK
?ELLFceG75/mFcaOGE/lHeaO?6=LGeaSG5llKiY_NVnJKgYg^G>ILkUcV7NhMiMg^7NENkIgUW^eNiAo
]7^BNk9kU7ndNi9k/W^ANk9kTG^bMi9k]7NcNk9gTW^dMk=keGNdNmMg]WOGJgY_Vf]jKi]WFfMlIg]W
O6MKGcaK75llFaaO?5/LGcaFo5LLE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0000Moo`03001oogoo00ioo`008Woo
00<007ooOol07Woo00<007ooOol0@goo15<M0`000e<M019G7ELLEceG7E/mEaaG?ELMFceOG6=LGeaS
G5mLHeaOG6MlHe/3KiX3LiT00gNhMiMg]`02NkH01GNfNkAk]7^eNi<00W^d00=k/g^CNi800W^B00Mk
TG^BNk9k/W^ANi9k/P03Nk<2NkD01GNfMkMc^7NiLkP00VMk00AWO6MkIg]WN`9SG0=K?0AK700<E_aG
75KlEaaFo5LLD_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo09oo`03001oogoo00Eoo`03001oogoo00eoo`008Woo00<007ooOol07goo00<007ooOol0?goo
00EC7E;lDaeBo5<M0080001>D_aG7E;lEaeBo5LMDaaG7ELLFceG75/mEaaK?E/lFceO?6=LGeaSG5ll
IgaSFfMlHe]WO7>ILkUcV7NiMiMg^7NGNkIgUW^fNiAk]G^CNkIkU7^eNi=k/W^BNk9kTG^bMi9k/g^A
Nk9gTW^cMk=k]7NdNmEg]WOGMkIgfG>hLkY_VFMlIg]WO5mKHeaSFf=LGe]K?5LLFaaG75/l0ULL04IF
o5LLE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_`0
05;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lOol000Qoo`03001oogoo00aoo`008Woo00<007ooOol087oo00<007ooOol0
?7oo00ABoE<MD_eC7@<000AC7@0GEaeC7ELMDaeG7E<MEaeG75LmEaeK?E/lFceK?5/mGeaSG6MKIgaS
FfMlIe]WO004Jg/04GNGMkMg]g^fMkIk]W^dNkEkU7^fNkAk]G^CNk=kTW^bNi400g^B00AkTG^BNi9k
/P=k/`06NkEg]WNgMkMg^G>h0Vnj00=c^VnJKkX01F=L0Ull1U/L1eKl00=Bo5KlD_`03e;l00IBg5;l
D_aBo5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00=Bg5;lD_`00Woo00<007ooOol01Woo00<007ooOol02goo000QOol2000S
Ool00`00Oomoo`0hOol014klDae>o5<M0`0009YC7E;lDaeBo5LMD_aC7E<LEaeC75LMDaaG7E<LEaeG
75/mFcaK?ELLFceK?5/mHe]WO6=KIgaSFfMlIg][NfMjJi]_NVnJKgYg^G>ILkUgUgNhMiMk]WNENkEk
U7^cNi=o/g^ANk9gTGncNi5k/WNANk=kTW^dMk=keGNfMmMg]WOILkQg^FnILkY_VG>jJgY_Vf=KHeaO
>emLGcaOG5lkFcaG75/LE_aK75KlEaaBo5LLD_aG75;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg09oo`05001oogooOol00003Ool00`00
Oomoo`0;Ool0025oo`03001oogoo02=oo`03001oogoo039oo`=Bo@03DaeBoE;m00<00004DaeBoE<M
D_d3Dad02E;mDaeC7E<MD_eG7E<MEaeC7@03Ead01U/lFceK?5/mFcaK?@9O?003He]WO6MK00E[N`A_
VP=cV@09MkQgUgNgNkIk]G^DNk=kTg^b00=kTP0:Nk9kTG^BNi9k/W^BNk9k/g^eMkD2MkL01gOGLkQg
^6njLkY_VVnj00A[V`MO?09G7006FaaG75LLEaaFo5;l0eKl0e;l00=Fo5;lD_`03U;l00IBg5;lD_aB
o5;L0002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00=Bg5;lD_`00P0017oo0`003Woo000QOol00`00Oomoo`0TOol00`00Oomoo`0_
Ool01E<MC_eC7DklDad00`0005MC7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lDaeBo5LmEaaG7E<L
EceG75LMEaaK?E/lGeeK?5mMFcaOGE/lJi]WNf]kIgY[VfmjKiY_NVnJLiUc^G>HMkQgUgNhMiEk]W^D
NkEkTgndNi9k/W^AOkAkTW^bNi5k/W^BNk9g/g^dMkEgegNfNmMc^7NiKiUc^VnIKi][NVnKJgY_VfMK
IgaO?5mLGc]OG5/LGc`00U/L00AFo5/LE_aG709Fo015D_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0001Aoo`008Goo
00<007ooOol09Goo00<007ooOol0:goo0U;m00=C7DkmD_d00`000U;m00YC7E;mD_eBoE<MD_eC7E;m
DaeBo@=C7@05D_eC7E<MEaeC7@03Ead01ELLEaeG7ELMFc`00ell00EK?5llGcaSG5mL00=[N`A_VP=c
V@03LkUgUgNg009k]P08NiAk]7^CNk=kTg^BNi=k/`AkTP06Ni5k/W^bNk=kTW^b0W^c00Eg]G^eMkMg
egNf00A[V`9WN`03IgaWNfMk009K?00:FaaK?5/lFcaK75LLE_aG75KlEa`2E_`015;lE_aFo5Kl0e;l
00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`00
01=oo`008Goo00<007ooOol09Woo00<007ooOol0:7oo00A>oE<MC_aC7@<0001ODae>oE<MC_aC7Dkl
Dae>o5<MD_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMD_aG7E;lEceG75LMDaaK?ELLFceK?5mMFcaOGE/l
HeaOG6=LGcaSG6mjKiY_NVnJLiUc^G>HMkUgUgNhMiEk]WNFNkEkU7ndNi=k/W^DOkAkTg^bNi5k/W^A
Nk9gTW^dNi5k/WNcNkAg/g_EMkAkegNfMkUc^7OIIg]WO6MKIgaWNfMlGe]SG5/LGcaK75llEaaK7002
Ea`0BUKlEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo000COol0025oo`8002Qoo`8002Eoo`03D_eC7Dkm
009Bo@80009Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eBoE;mDaeBo@=C7@04D_eC7E<MEad3Dad04eLM
DaeG?ELMFceG75LmEaeK?E/lGcaOG6=LGeaSG5mLHeaSFfMl00=_VP9cV@06LkUgUgNgMkMk]WNf0W^d
00Ik/g^CNk=k]7^cNi<3Ni801G^ANi9k/W^bNi400W^b0W^c0W^e00YgegNfMkMc^7NiKiY_^VMkIgaW
N`ESG0IK7003E_aG75Kl00=Fo006D_aFo5;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00ABg5;lOol0019oo`008Goo00<007ooOol0:Goo00<007ooOol087oo00AC7Dkl
Dae>o@<0002aC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG
7E;lEaeC75LMDaaK?ELLFceG75/mEaaK?EllHeaOG6=LGcaSG6=KIgaSFfMlHe]c^G>HMkUcVGNhMiMk
]WNFNkIkU7^eMiIk]WNENkEkTg^cNi9k/W^ANk9kTG^bNi5k/WNBNkAg/g^dMkAkeGNfMmMc^7OIKiUc
^VnILkY_VF=LGe]SG6=KHeaO>emLEaaK75LLFcaG75/LD_aG75;lEaaBo5KlD_aFo5;lE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o000019oo`0087oo00<007ooOol0:goo00<007ooOol077oo00AC7DkmD_eBo@<00003D_eC7Dkm009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mD_eBoE<MD_d3Dad07E;mDaeC7E<MD_eG7E<MEaeC7ELMDaeG
7E<MEceG7E/mEaaK?E/lFceOG6=LGeaWO6=KIgaWFfMlHe/016]k0WNg00Ik]WNfNkIg]gNhMkH2NkH0
1W^eNi=k/g^CNk9kT@=kTP04Ni5kTW^BNk82Nk<2NkD01GNfMkMc^7NiLkP00Vnj00Ac^VnJJi][V`9S
G0AO?0AK709G7003FaaFo5Kl00=Fo09Bo003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo003D]aoo`00015oo`0087oo00<007ooOol0;7oo00<007ooOol05Woo00IC7Dkm
Dae>o5<MC_d30000^DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeC75/mFcaK?ELLFceK?5/mEaaWO6=KIgaSFfMlHe][
NfMjJi]WNfnJKgYg^G>ILkUgUgNhMiMk]WNENkIkU7^cNi=o/g^ANk9gTG^bNi5k/WNANk=gTW^dMkAk
eGNeMmMg]WOILkQc^VnILkY_VFnKJgY_Vf]jGeaO>emLGcaOG5lkFaaFo5/LE_aK75KlFaaBo5LLD_aF
o5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg7oo000047oo000POol00`00Ool0000]Ool00`00Oomoo`0COol00e;m
Dae>o@02D_d300000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<M
D_eC7E;mDaeBo@=C7@09D_eC7E<MDaeBoELMDaeG7E<M00=G7@0<EaaK?E/lFceK?5/mFcaO?5/lIgaW
FfMl1F]k0fnJ0g>I00=g^7NGNkH00W^f00AkU7^cNi=k/`=kTP06Nk9kTG^BNi9k/W^B0W^c00Ik]GNe
MkMg]gNiLkP2KkX00g>jJi][V`03Ji/2Ig/3Gc`2Fc`015/LEaaG75/L0ULL00=Fo5LLD_`00eKl0e;l
00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo080011oo`0087oo0P00;goo00<007ooOol03goo00E>oE<MC_aC7Dkm00<0001dC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeB
o5LMD_aC7E;lEceG75LMDaaG?ELLEaeC75/mFcaK?E/lGeeK?5mMFcaOGFMkJg]WNV^KIg]_VVmjKiYc
VG>iLiQg^7NGMkQgUG^fMiIk]G^COkAkTW^bNi5o]7^BNk9kTG^bMi9k/WNcNk=gTW^bMk=keGNeMmMg
]W_GJgY_Vf]jKi]WNfMlIe]WO6MkGcaK75llFaaO?5/LEaaFo5LLE_aG709Fo01:D_aG75;lE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lOol000moo`001Goo1@001Goo0P001Goo10001Woo00<007ooOol0;goo00<007oo
Ool037oo00AC7DkmD_eBo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01E<MD_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMDad00eLM00EG75LM
EaeG7ELL00=O?006FcaO?5llGcaOG6=L0f]k0fnJ0g>I00=c^GNGMkL00W^f00Qg]W^dNi=k/g^CNi9k
Tg^c0g^B00Mk/W^ANk9k/g^bNi9k/P02Nk<027NeNkEg]gOGLkQg^7>hIg`3Ig/01fMlIg]SG6=LFcaK
75/l00=K7005EaaFo5LLE_aG7002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo09oo`03001oogoo00aoo`0017oo
0P0000Eoo`00001oo`0000Aoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo031o
o`03001oogoo00Qoo`05Dae>o5<MC_eC7@020000MTkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeB
o5LMD_aG?ELLEaeC75LmEaaK?ELLGeeK?5mMFcaOGEmLHeaO?6=LGea_VVmjKiYcVG>iLiQg^GNGMkQg
Ug^fMiIk]W^DOkAkTg^bNiAo]7^CNk9kTG^bNi5k/WNBNk9gTW^bMi9k]7NeNmEg]W_GMkIgfG>hLkY_
VFMlIe]WO6=KHeaOFf=LHe]K75LLFcaG75/L0ULL04mFo5LLD_aG75;lE_aBo5KlD_aFo5;lE_aBg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LOol0000>Ool000Aoo`80009oo`03001oo`0000moo`03001oogoo00=oo`03001oogoo035o
o`03001oogoo00Eoo`04C_eBoE;mDad300001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@9C7@0>
EaeC7E<MDaeG7E<MEceG7E/mEaaG?ELMFceG709O?008HeaOG6=LGeaSG5mLIgaWF`9_VP9cV@0>LkUg
UgNgMkMk]WNfNkIk]7^cNi=k/g^dNk=kT`=kTP05Ni5kTW^bNi9kT@02Nk82Nk<2NkD01WOGMkIg^7>h
LkY_VP9_^P03LkYSG6=L00=SG09O?0IK70MFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0<Ool000Aoo`80009oo`03
001oo`0000moo`03001oogoo009oo`8003Aoo`08001oogooOom>o5<MC_eC7@<0003>Dae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMDaaG7E<LFceG75/mEaaK?ELLFceG76=LGeaS
G5llHeaSFfMlHe]WO6=KLkUcV7NiLiUg^7NGMkQgUW^fMiEk]GNFNkIgUG^eNi=k/g^BNk9kTG^bMi5k
/W^ANk9gTW^cMk=keGNdNmMg]WOILkQgfFnILkY_VG>jJgY_VemKHeaO?5mLGc]OG5llFaaFo5/LE_aK
75KlEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol000aoo`0017oo0P000Woo00<0
07oo00002goo10001Goo00<007ooOol0<Woo00=BoE<MC_d00U;m00IC7@00000005<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad06E;mDaeC7ELMDaeG7E<MEaeC7ELmEaeK?ELLEceK
?5/mFcaSG5mLHeaSFfMlIe]WO6=K00A[N`9g]`06MkQg]W^fNkIg^7Nf0W^f00Ik]G^DNk=kTW^bNi42
Ni800g^bNi5kTP02Nk802G^cNkEk]G^eMkIg]g>hMkU_VP02KkX00g>jJi][V`02Ji/5Gc`2Fc`01U/L
EaaG75LLFaaG70=Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000<Ool000=oo`<00005Ool00000
Ool0000;Ool00`00Oomoo`06Ool00`00Oomoo`0`Ool01E<MC_aC7DkmDad00`000=EC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7E<LFceK?5/m
EaaK?E/lFceG76MlHe]WO6=KIgaSFf]kIgY[VfMkKiY_NVnJLiUc^G>HMkQgUg^fMiEk]W^DNk=kTgnc
Ni9k/W^BOk=kTG^bMi5k/gNBNkAg]7_EMkIgeg>hMmU_VG>jKiU_Vf]jKi][NVnKIg]WO5lkGeaK75ll
FaaO?5KlFaaFo5/LE_aG75KlEaaBo5KlD_aG75;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo00002goo
0005Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0]Ool01E<MC_eB
oE;mDad00`0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;m
DaeBo@=C7@05D_eC7E<MEaeC7@03Ead035LLFceK?5/mFcaK?E/lGcaK?6MlIe]WO0E[N`=_VPAcV@08
MiMk]W^fNkIkU7^dNi=k/P9kTP03Ni=k/W^B009kTP03Nk9kTW^c009k/P05Ni9k/g^cNkEg]P02MkL4
Ji/01VMlIg]WNfMkIgaK70=K?008FaaK?5KlEaaFo5LLE_aG709Fo006D_aFo5;lE_aBo5Kl0e;l00=F
o5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`015;LD_`000002Woo0006Ool4000<Ool50004Ool00`00Oomoo`0[Ool014klDae>oE<M0`0008=C
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aC
7E;lEaeG75LMDaaG?ELLEaeC75/mFcaK?E/lGeeK?5mMFcaOGFMkJg]WNV^KIg]_VVmjKiY_NW>iLiQg
^GNGMkQgUG^fMiIk]G^COkAkTW^bNi=o/g^BNk9gTG^bMi9k/WNANk=gTW^dMk=keGNdMmMg]WOILkQg
fFMKIgaWNfMlIe]SG6=KHeaK75ll009K701GEaaK?5KlEaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aoo`0000Yoo`007goo00<007ooOol0:7oo00E>oE;mD_eC7Dkm00800006
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>DaeBoE;mD_eC7E;mDaeBoE<M
D_eC7E;mDaeBo@9C7@03EaeC7E<M009G7@05EaaG7ELMEaeG7003Gc`01U/lGcaO?5llGeaSG0=[N`A_
VP=cV@05MiMg]g^fNkIg]P02Nk@01G^cNi9kTW^dNk<00g^B00Mk/W^ANk9kTG^bNi9k/P02Nk<02WNe
MkMg]gOGLkQg^6njLkY_VVnj1V=L1U/L1UKl00ABo5KlD_aFo11Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;L00000009Ool001ioo`8002Eoo`07C_eC
7DklDae>oE<MC_`00`000>9>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aG7ELLEaeC75LmEaaK?ELLGeeK?5mMFcaS
G5mLHeaO?6=LGea_VVmjKiY_NW>iLiQg^GNGMkQgUg^fMiIk]W^DNkEkTg^eNiAo]7^CNk9kTG^bNi5k
/W^ANk9gTW^bMk=k]7NdNmEg]W_GLkQgfFnILkY_VG>jJgY_Vf=KHeaOFemLGcaOG5LLFcaG75/LE_aK
75;lEaaBo5LLD_aG75;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol000Uoo`007Woo00<0
07ooOol08Woo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@9C7@05EaeC7E<MDaeG
7@02Dad04eLMFceG75LmEaeK?ELLEceOG6=LGeaSG5mLHeaOG6MlIe]WO6=K00AcV@9g]`0:NkIg]W^f
NkAk]G^CNkIk]7^eNi<3Ni801G^ANi9kTW^bNi400W^b0W^c00Uk]GNgMmMc^7NhLkQc^VnJKkX016^K
1Ull0eLL00=K75LLEa`00UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l00002Goo000NOol00`00
Oomoo`0POol01DklDae>oE<MC_`00`000>=>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E<L
EaeG75/mEaaK?ELLFceG75/mGeaSG5llHeaOG6MlHe]WO6=KJg]WNV^KIg]g^7NGMkQgUW^fMiEk]G^D
NkIkU7^eNi=k/g^BNk9kTG^bNi9k/W^ANk9gTW^dMk=keGNdNmMg]WOILkQc^VnIKi][NVnKJgY_VfMK
IgaO?5mLGc]O?5/LGcaFo5/LE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
00Aoo`03001oogoo00Moo`007Woo00<007ooOol07Woo0U;m00=C7Dkm00000P0000E>oE;mD_eC7Dkm
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7E;mDaeBoE<MD_d3Dad02E;mDaeC7ELMDaeG7E<MEaeC7@02Ead03U/mEaaK?E/lFceK?5/m
GeaSG6=KIgaWFfMlHe/4Jg/3KiX01GNfNkIk]WNhMiL00W^f00Ik]G^DNk=kTW^bNi43Ni8017^ANi9k
/W^b0W^c00Mk]GOGMkIg^7>hLkY_VP04Ji/2Ig/00fMlIg]WN`02Fc`02U/LFcaK?5/lE_aG75KlEaaF
o5LL0UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`7Ool00`00Oomoo`06Ool001ioo`03001oogoo01]oo`04Dae>
oE<MC_`30000i4klDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMDaaG7E<L
EaeK?5/mEaaK?E/lFceG75/mHe]WO6=KIgaSFf]kIgY[VfMkKiY_NVnJLiUc^G>HMkQgUgNhMiEk]G^D
Nk=kTgncNi5k/g^BOk=kTG^bMi9k/gNcNkAgTW^dMk=k]7NdNmMg]WOILkQgfFMkIgaWFfMlIg]WO5mK
HeaK75llFaaK?5LLFaaFo5LLE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo0Yoo`03001oogoo00Io
o`007Goo0P0067oo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;mDaeBoE<M
D_eC7E;mDaeBoE<MD_d3Dad05E;mDaeC7ELMDaeG7E<MEaeG75LMFcaK?E/lFceK?5/mFcaO?6MKIgaS
F`05Jg/2KiX4LiT057NGMkMk]W^fNiAk]7^CNk=kTW^cNi9k/W^ANi9kTG^bNi9k/g^ANk82Nk<2NkD0
2GNfMkMc^7NiKiY_^VMkIgaWN`05He`6Fa`6E_`015;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00U;l3Woo00<007ooOol01Woo000NOol00`00Oomoo`0DOol01TklDae>oE<M
C_aC7@80003QC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG
7E;lEaeC75LmEaaG7E<LEceK?5/mEaaOGE/lGeeK?5mMFca[NfMjJi]WNf]kKgY_VVmjLkUcV7NiMiMg
^7NGNkIkU7^eNi=o]7^BNkEkTgncNi9k/WNANk9gTW^bMi5k/gNcNkAg/g_EMkIgeg>hMmU_VG>jKiUc
^VnIHeaOFf=LHe]OG5lkGeaG75/LEaaK75KlFaaBo5LLD_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L01=oo`03001oogoo00Ioo`007Goo
00<007ooOol04goo0U;m00=C7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03
D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m1U<M00=G7ELLEad00ULM00EG75LMGcaO?5/l00=O?003FcaS
G5mL00=[N`=_VP=cV@05MiMg]gNgNkIg]P02Nk@01G^cNi=k]G^CNk<00g^B00Ik/W^BNi9kTG^bNi82
Nk<01W^eMkEg]g>hMkUc^09_^P03LkY_VV^K009[V`IO?003EaaK75LL009G70EFo004D_aFo5;lE_`@
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_`005;l
D]`00e;l00IBg5;lD_aBo5;LD_`EOol00`00Oomoo`06Ool001eoo`03001oogoo015oo`04C_eC7Dkl
Dad30000WE<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC
7E;lEaeBo5LMD_aG7E;lEaeC75LmEaaK?ELLFceK?5mMFcaOGEmLHeaO?6=LGeaSG6mjKiY_NW>iLiQg
^GNGMkQgUg^fMiIk]G^DOkAkTg^fNiAo]7^BNk9kTG^bNi5k/WNANk9gTW^dMk=k]7NdMmMg]WOILkQc
^VnILkY_VFnKJgY_VfMkIgaO>emL009O?006FaaO?5KlFaaFo5/L0UKl03]Bo5LLD_aFo5;lE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;L01Moo`03001oogoo00Ioo`00
7Goo0P003goo00ABoE<MC_eBo@<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05
Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@IC7@0FEaeC7E<MDaeK?ELLEceG7E/mEaaG?ELMHeaO
G6=LGeaSG5mLHeaWFfMlHe/4LiT2MkL02WNhMkIk]W^dNkEg]W^fNkAk/g^C0g^B00IkTG^BNi9k/W^A
Nk82Nk<01GNeNkEg]gNiLkP00Vnj00=c^V^KJi/00V^K0fMk00=WO5/LFc`00U/l00IK75/lE_aG75Kl
Ea`2E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg00LOol00`00Oomoo`06
Ool001eoo`03001oogoo00Uoo`06C_aC7DkmDae>o5<M0`000:EC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LM
DaaK?ELLFceG75/mEaaK?E/lHeaO?6=LGeaWO6=KIgaSFf]kIgY[VfMkMkQgUgNhMiIk]WNGMkQgUW^f
MiEk]G^CNk9kTW^bNi5k/W^ANk9kTG^bMk=k]7NcNmEg/g^dMkAgegNfNmM[NVnKJgYWO6MkIgaWFfMl
He]SG5/LGc`00U/L00IG75/lE_aG75KlEa`2E_`0<U;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo7oo000OOol00`00Oomoo`05Ool001eoo`03001oogoo00Moo`9Bo@03Dae>oE;m00<0009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7DkmD_eB
oE<MD_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@0DEaeC7ELMDaeG7E<MFceG75LmFcaK?E/lFceK?5/m
He]WO6MKIgaSF`A[N`=_VP9cV@03MkMg^7NG009k]P03NkEkTg^c009kTP07Ni5k/g^BNi9kTG^BNk80
0W^c0W^b00Uk/gNeNkEg]gOGLkQg^7>hIg`00fMk1F=L1E/L00=G75KlEa`015Kl00ABo5KlD_aFo0aB
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g004Ool00`00Oomoo`0LOol00`00Oomoo`05Ool001eoo`03001oogoo00Eoo`04C_eC7DklDad30000
[e<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<MDaaG7E<LEaeC75LMDaaK?ELLFceK?5/mEaaK?E/lGeeS
FfMlHe][NfMjJi]WNfnJKgY_VW>ILkUcV7NhMiMk]WNENkIkU7^cNi=o/g^CNk=kTWncNi5k/WNBNk9k
TG^bMi9k]7NcNmEg]W_GLkQgfG>hLkY_VG>jGe]SG6=KHeaOFf=LGcaOG5LLFcaG75/L009G700_D_aG
75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg008Ool00`00Oomoo`0KOol00`00Oomoo`05Ool0
01eoo`04001oogooC_d2D_d015<MC_eBoE;m0P000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<M
D_d3Dad00e;mDaeC7@02Dad015LMDaeG7ELL0ULM00IK?E/lFceK?5llFc`3Gc`00e/lJg][N`02Jg/4
KiX2LiT00gNhMiMg]`02NkH03W^DNk=kTg^bNiAk/g^CNk9kTG^BNi5kTW^ANi82Nk802W^cNkEg]GOG
MkIg^7>hLkY_VVnj0V^K0f=L1Ell0eLL00=K75LLE_`015Kl00=Bo5KlD_`00U;l00=Fo5;lD_`02U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l37oo00<007ooOol06goo00<0
07ooOol01Goo000LOol02000OomC7DkmDae>o5<MC_d30000gDkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7DklEaeBo5<MD_aG7E;lDaeC75LmEaaG7E<LEceG75LMFcaOGE/lGeeK?5mMFcaSG5llJi]WNfnJKgY_
VVmjLkUcV7NiMiMg^7NENkIgUW^eNi=o]7^DNk=kTgncNi9k/WNANk9kTG^bMi5k/gNcNkAg]7_GMkIg
fG>hLkY_VG>jJgY_Vf]jKi][NUmLGcaOG5lkGeaK75llE_aK75KlFaaFo5LLD_aFo5;lEaaBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`0
4Goo00<007ooOol06Woo00<007ooOol01Goo000LOol00`00Dae>o@02D_d300000e;mDae>o@02D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00IG7E<MDaeC7ELMEa`3Ead01ELL
EceG7E/mFc`00ell00EOG6=LGeaSG5mL00A_VP=cV@0<MiMg]g^fNkIg]W^eNi=k/gNfNkEkTg^c0g^B
00mk/W^ANi9kTG^bNi9k/gNeNkEg]WNhLkQc^VnJKkX01F^K00IWO6MkGcaO?5/lFa`2Fc`01E/LEaaG
75KlEa`015Kl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`05goo00<007ooOol06Goo00<007ooOol01Goo000BOol50005Ool00`00C_d000020000_TkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG
75/mEaaK?ELLHeaOG6=LGcaSG5mLIgaSFfMlHe]c^G>HMkUcVGNhMiMk]WNFNkIkU7^fMiIk]G^DOkAk
TW^bNi5k/W^ANk9gTG^bMi9k]7NcNmEg/g^dMkAkegNfMmM[NVnKJgY_VfMKIgaWNfMlIe]O?5/LGcaK
75llFaaG75KlEaaFo5LL0UKl01aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo1Yoo`03001oogoo01Qoo`03001oogoo00Eoo`0057oo00<007ooOol01Goo
0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@03DaeB
oE<M009C7@04D_eC7E<MEad3Dad04ULMDaeG?ELMFceG75LmEaeK?E/lHeaOG6=LGeaWO6MKIgaSF`A[
N`9g]`0:NkIg]W^fMkMg^7NfNkIk]7^cNi<5Ni803g^ANk9kTW^bNk=k/W^BNk=g]G^eMkIg]g>hMkUc
^002Ig/00fMlIg]WN`04He`5Fa`00eLLE_aG7004E_`015;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L009B
o1aoo`03001oogoo01Uoo`03001oogoo00Aoo`0057oo00<007ooOol01Woo0;h007ooC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7E<LFceG
75/mEaaK?E/lFceO?6=LHe]WO6=KIgaSFf]kIgY[VfMkKiY_NWNiLiUc^GNGMkQgUW^fNiAk]G^CNk9k
TW^bNi=k/W^ANk9kTG^bMk=k/WNBNkAg/g_EMkIgegNfMmUc^7>jKiUc^V=KHeaOFf=LHe]SG5lkGeaG
75/LEaaK?09G700JD_aG75;lEaaBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
D]aFo25oo`03001oogoo01Qoo`03001oogoo00Aoo`0057oo00<007ooOol01goo0P0000=BoE<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7DkmDaeBoE<MD_eC7E;mDaeBo@=C7@0ED_eC7E<M
EaeC7ELMDaeG7E<MFceK?5/mFcaK?E/lFceSFfMlIe]WO6=K00A[N`9_VPAcV@0:MkQgUg^fNkIk]G^C
Nk=kTW^bNi<2Ni800g^bNi5k/P02Nk801G^BNk9k/g^eMkD00WNg00Eg^G>hKkY_^W>j009[V`=SG0EO
?003EaaK75LL009G70EFo0=Bo003E_aBo5;l00]Bo2Ioo`03001oogoo01Moo`03001oogoo00Aoo`00
57oo00<007ooOol02Goo0;d007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5LMD_aC7E;lEaeC75LMDaaG7ELLEaeC75/mFcaK?ELLGeeK?5mMHe]WO6=KJg]WNV^KIg]_VVmjKiYc
VG>iLiQg^7NGNkIgUG^eNiAk/g^BOk=kU7^cNi9k/W^ANk9gTW^bNi5k/WNcNkAg]7OGMkIgfG>hMmU_
VG>jJgY_Vf]jKi]O?5mLGc]OG5llGeaK75llE_aK75KlFa`00UKl019Bo5LLD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_`XOol00`00Oomoo`0GOol00`00Oomoo`04Ool001Aoo`03001oogoo00Yo
o`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d3
Dad01E;mDaeG7ELMEa`00eLM00EG75LMGcaO?5/l00=O?003Fca[Nf]k009[N`=_VP=cV@03MkQgUgNh
009k]P09NiAk]G^CNkEkU7^cNi9k/W^A00=kTP0<Ni5k/W^bNk=g]G^eMkMgeg>hMkQ_^W>j16^K0VMk
0ell0e/l00IK75LLEaaK75KlEa`2E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`015;l;7oo00<007ooOol0
5Woo00<007ooOol017oo000BOol3000=Ool0_@00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;l
Dae>o5<MD_aC7E;lEaeBo5LMD_aG7ELLEaeC75LmEaaK?ELLFceK?5mMFcaOGE/lHeaO?6=LGea_VVmj
KiYcVG>iLiQg^7NGMkQgUG^fNiAk]G^CNkIkU7^eNi=o/g^ANk9kTW^bNi5k/WNBNkAg/g_EMkIkeg>h
MmU_VG>jJgY_Vf]jIgaWNfMlIe]WO6MkGcaK75llFaaO?5/LEaaFo5LLE_aG7002E_`02E;lE_aBo5Kl
D]aFo5;LE_aBg00aOol00`00Oomoo`0EOol00`00Oomoo`04Ool001Aoo`03001oogoo00aoo`800006
Oom>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0=DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mEad00e<M00YG7E<M
DaeC7E/mEaaG?ELMFceG70=O?008GeaSG5mLHeaOG6MlIe]WO0AcV@0<MiMg^7NgNkIg]W^eNkAk]W^D
NkEkTg^b17^B00EkTG^BNi5k/W^c009k/P09Nk=g]G^eMkMgeg>hMkQc^6Ml00=WN`03IgaSG6=L009S
G0EK7003EaaFo5LL00AFo004D_aFo5;lE_`fOol00`00Oomoo`0DOol00`00Oomoo`04Ool002Eoo`2f
001oodklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMDaaG7E<LFceG75/m
EaaK?ELLHeaOG6=LGcaSG5mLIgaSFfMlIg][NfMjJi]gUgNhMiMk]WNFMkQgUg^fMiIk]G^DOkAkTW^b
Ni=o/g^ANk9gTG^cMk=k/WNBNkAg/g_EMkAkegNfMmUc^7>jKiUc^UmKHeaSFf=LGe]SG5llGeaG75/l
EaaK709G7005D_aG75;lEaaBo00jOol00`00Oomoo`0EOol00`00Oomoo`03Ool002Ioo`03001oogoo
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00=C7E;mDad00U<M00=BoE<MDad00U<M00AG7E<MEaeC
7@9G7@0=FceG75LmFcaK?E/lHeaOG6=LHe]WO6MKIg`016]k0fnJ0W>I00Mg^7NgMkQg]W^eNkAk/`03
Ni801G^bNi9kTW^ANk800W^B0W^b00Yk/g^eMkEgegNfMkQc^7>jKiYc^P9[V`=SG0EO?0=G7003FaaG
75Kl009Fo3eoo`03001oogoo01Aoo`03001oogoo00=oo`009goo0;L007ooOomC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7E;lEaeBo5<MDaaG7E<LEaeC75LMFcaK?ELLFceK?5/mEaaK?F=KIgaSFfMlHe][
NfMjJi]_NVnJKgYg^G>ILkUgUgNhMiIk]W^DNkEkTg^bNi9o]7^BNk9kTG^bMi9k/WNANk=g/g^dMkAk
egNfMmUc^7OIKiUc^V]jKi][NVnKGc]OG5llGeaO>ellFaaO?5KlFaaFo5/LE_`0@7oo00<007ooOol0
4goo00<007ooOol00goo000XOol200001GooD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3
Dad00e;mDaeC7@02Dad045LMDaeG7ELLEaeK?5/mFcaK?E/lGcaK?5llIe]WO6=K0f]k16nJ0W>I00Mg
]gNhMiMk]W^dNkEkT`02Ni804g^eNi=kTW^BNk9kTG^BNi5k/W^BNk=g]G^eMkIg]g>hMkU_VW>j00A[
V`03Ig]WO6Mk00=K?004FaaK?5/lFca5Ool00`00Oomoo`0BOol00`00Oomoo`03Ool002Yoo`2^001o
oe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lDaeC75LmEaaG7E<LEceG75mMFcaOGE/lGeeK
?5mMFca[NfMjJi]_NVnJKgY_VW>ILkUcV7NhMiMk]WNFNkEkU7^cNiAk]G^CNk9kTG^bNi5k/W^ANk9g
TW^dMk=keGNfMmMc^7OIKiUc^V]jKi][NVMlIe]WO6MkHeaOFellFaaO?5/LAgoo00<007ooOol04Woo
00<007ooOol00goo000[Ool01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EB
oE<MDaeG7ELL00=G7@05EaaG?ELMGcaK?003Gc`015/lHeaOG6=L16nJ0g>I00Ig^7NGNkIk]W^eNi@2
NkH00g^eNiAk/`02Ni804G^ANi9kTW^BNi5k/W^cNk9kTW^cMkEk]GNfMkMc^7NiLkP00VMk00=WO6=L
He`00f=LBgoo00<007ooOol04Goo00<007ooOol00goo000/Ool0Y`00OomC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
Dae>o5LMD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaOGE/lGeeOG6=LGcaSG6=KIgaSFfMlLiUc^G>H
MkUgUgNhMiIk]WNGMkQgUW^eNiAk/g^BOk=kTG^bNi9k/W^ANk9g/g^bMi9k]7NcNmEg]7OGLkQgfG>h
LkY_VG>jHe]SG5mKHe`0CWoo00<007ooOol047oo00<007ooOol00goo000]Ool20002D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7E;mD_eBoE<MD_d3Dad065;mDaeC7ELMDaeG7E<MEaeG75LmEaeK?ELLEceG7F=LGeaSG5mLHeaS
FfMlIe]WO0A[N`06MiMg^7>ILiUgUgNh0W^f00IkU7^eNi=k/W^ANk<2Ni802G^ANi9k/W^bNi9k/W^c
NkEg]@02MkL01GNiLkQc^VnjLkX00f^KDGoo00<007ooOol047oo00<007ooOol00Woo000_Ool0X@00
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7ELLFceG75/mEaaK?E/lHeaO?6=LHe]WO6=K
IgaWNf]kIgY[VfmjKiYcV7NiLiUg^7NGNkIkU7^eNi=o]7^BNk=kTWncNi5k/WNBNk9kTG^bMk=k]7Nd
MmMg]WOILkQc^VnILkY[VVnKJgX0DWoo00<007ooOol047oo00<007ooOol00Woo000`Ool01@00OomB
oE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
2U<MC_eC7E;mDaeBoE<MD_eC7E;m0e<M01=BoE<MDaeG7E<MEaeC7ELMFcaK?E/lFceK?5/mFcaK?F=K
IgaWF`05Jg/2KiX3LiT047NhMkMk]WNfNkEk]7^cNi9k]G^CNk9kTG^BNi5kTW^A0W^b00Uk/gNeNkEg
]gNiLkQc^VnjLkX00f^KE7oo00<007ooOol03goo00<007ooOol00Woo000aOol0W@00Oomooe<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lEaeBo5<MD_aG7E<LEaeC75LmEaaG7ELLFceK?5/mEaaOGE/lGeeK?6^KIg][NfMjJi]_NVnJKgYg
^G>IMkQgUgNhMiIk]G^DOkAkTg^eNi=o/g^BNk9kTGncNi5k/WNBNkAg/g_EMk=k]7NdMmMg]W_GJiY_
Vf]j05Ioo`03001oogoo00ioo`03001oogoo009oo`00<Woo00D007ooOomC7Dkm009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC
7E;m0e<M00EBoELMEaeG7ELL00=G7@05EaaO?5llGcaK?002Gc`00f=LGea[N`02Jg/3KiX2LiT02gNh
MkMg^7NfNkIk]7^eNi=k]G^dNk<00g^B00Ik/W^ANi9kTG^bNk<2Nk8027^cMkEk]GNfMmMc^7NhLkQG
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool003=oo`80002GOomC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEceG75LM
DaaG?ELLFceG75mMFcaOGEllHeaOG6=LGcaSG6mjKiY_NWNiLiUc^GNGMkQgUg^fNiAk]GNFNkIkU7nd
Ni=k/W^ANk9kTW^bMi5k/gNcNk9gTW^dMk=keGNfNmMc^7OILkP0FGoo00<007ooOol03Goo00<007oo
Ool00Woo000eOol01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC
7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m1U<M01AG7E<MDaeG7E/mEaaG?ELMFceG75LmGeaSG5mL
HeaOG6=LHe]WO6MK0g>I00=g]gNhMiL00W^f00Ig^7NGNkIk]7^eNi<3Ni8017^CNi9kTW^b0W^B0W^b
00Mk/g^eMkEgegNfMkQc^01KOol00`00Oomoo`0<Ool00`00Oomoo`02Ool003Ioo`2D001ooe<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC
7E;lEaeBo5LMDaaG7ELLFceG75/mEaaK?ELLFceOG6=LGcaWO6=KIgaSFf^KIg][NfmjKiY_NVnJLiQg
^7NGNkIgUW^eNiAk/g^BOkAkTg^bNi5k/WNBNk9gTG^cMk=k/gNdNmMg]WOILkQMOol00`00Oomoo`0;
Ool00`00Oomoo`02Ool003Moo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M00=BoE<MDad00U<M00AG7E<MEaeC7@9G7@0<FceG
75/mFcaK?E/lFceWFfMlHe]WO6MK0f]k16nJ0W>I00YgUgNhNkIk]G^DNk=kTW^eNi=k/`9kTP0;Ni5k
TW^ANk9kTW^cMkEk]GNfMkQc^01NOol00`00Oomoo`0<Ool00`00Oomoo`01Ool003Qoo`80002>Dae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeB
o5<MDaaG7E<LEaeC75LMFcaK?ELLFceK?5/mFcaOGF=KIgaSFf^KIg][NfmjKiY_NVnJLiQg^GNGMkQg
UW^fNiAk]G^CNkEkTg^cNi9k/W^ANk9kTG^bMi9k/gNcNmEg/g^cMkAPOol00`00Oomoo`0;Ool00`00
Oomoo`01Ool003Yoo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:
DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM00EG75LMFcaK?E/l00=O?003FcaO
?5ll00=[N`A_VP9cV@0=MiMg^7NgNkIkU7^eNi=k]W^DNk=kTg^bNi400g^B00QkTG^bNk=k/W^BNk=g
]G^eHGoo00<007ooOol02Woo00<007ooOol00Goo000kOol0S000Oomooe<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5LMDaaG?ELLEaeC75LmEaaO
GE/lGeeK?5mMFcaSG5mLHea_NVnJKgY_VW>HMkUgUgNhMiMk]WNFNkEkU7^fNiAk/g^COk=kTW^bNi9k
/W^ANk9g/g^bMi9k/gNcNmESOol00`00Oomoo`09Ool00`00Oomoo`01Ool003aoo`03001oogoo009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d2Dad0
1ULMDaeC7E<MEaeG70=G7@0>EaaG?ELMGcaK?5llGeaSG5mLHeaWFfMlHe]WO0=cV@0;MkQg]gNhMkIg
^7NgNkIgUW^eNi=k/`02Ni8017^CNk9kTG^B0W^b00AkTW^bNk=k]FAoo`03001oogoo00Uoo`03001o
ogoo005oo`00?Goo0P0008Mooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDaeBo5<MD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaSG5llHeaOG6=LHe]WO6=KIgaWNV^KIg]g
^7NGMkQcVGNhMiMg^7NFNkEkU7ndNi9k/W^COk=kTG^bMi9k/W^ANk9g/g^dMk@0IGoo00<007ooOol0
27oo00<007ooOol00Goo000oOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eB
oE;mDad00e;m00=C7E;mDad00U<M01IBoE<MDaeG7E<MEaeC7ELMEaaG?ELMFceK?5/mFcaSG5mLHeaW
FfMlHe]WO0=[N`=_VP9cV@0:MkMg^7NFNkIk]7^cNi=kTW^dNk<2Ni800g^ANi9kT@02Nk800g^cMkEo
o`1VOol00`00Oomoo`07Ool00`00Oomoo`01Ool0041oo`25001ooe<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC75LMDaaK?E/lFceG75/mFcaK?F=K
IgaSFf]kIgY[VfMkKiY_NVnJLiUc^GNGMkQgUg^fMiIk]G^CNkEkU7ndNi9k/W^AOk=kTG^bMi9k]7Nc
Nk80J7oo00<007ooOol01goo0@000Goo0Goo0011Ool01P00Oomooe;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M
00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMDad00eLM00EG75/mFcaK?E/l00=O
?003Fca[Nf]k00=[N`=_VP9cV@0:MkQgUg^fNkIk]G^CNkIk]7^eNi<2Ni801g^bNi5kTW^ANk9k/g^b
06Uoo`03001oogoo00Moo`40005oo`5oo`00@Woo0P00081oodkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7ELLEaeC75LmEaaG7E<LGeeK?5mMFcaOGE/lHeaO?6^KIg][
NfmjKiY_NW>iLiQg^7NGNkIgUW^fNiAk]W^DNkEkTg^dNi9k/W^BNk9gTG^cMk=k/WNBJWoo00<007oo
Ool01Woo0@000Goo0Goo0014Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00QC7E;mD_eB
oE<MD_eC7E;m15<M00=G7E<MDad00ULM00EG75LMEaeK?ELL00=O?006GeaSG5mLHeaOG6=L0fnJ0g>I
00YgUgNhNkIk]W^DMkQk]W^eNiAk/`9kTP04Ni=kTW^BNk82Ni82Nk9[Ool00`00Oomoo`05Ool10001
Ool1Ool004Eoo`1n001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LM
D_aG7E;lFceG75/mEaaK?ELLFceOG6=LGcaSG5mLHeaSFfMlHe]c^G>HMkUgUgNhMiIk]WNFMkQgUW^e
NiAk]7^COk=kTg^cNi5k/WNBNk9gTG^bK7oo00<007ooOol01Goo0@000Goo0Goo0016Ool01@00OomB
oE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01E<MC_eBoE;mDad00e;m00=C7E;mD_d00U<M00=BoE<MDad015<M019G7E<MEaeC7E/m
EaaG?ELMFceK?5/mGeaSG5mLIgaWFfMlHe/3Jg/2KiX3LiT02GNhMiMk]W^DNkEkTg^bNiAk/`02Ni80
1G^ANi9kTG^bNi80KGoo00<007ooOol017oo0@000Goo0Goo0017Ool20000NWooDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7E<LFceG75/mFcaK?ELLFceSFfMlHe]WO6=K
Jg]WNV^KKgY_VVmjMkUcVGNhMiMk]WNFNkEkTgndNiAk]7^BNk9kTG^cNi5k/WNBNk9^Ool00`00Oomo
o`03Ool10001Ool1Ool004Uoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeB
o@AC7@04EaeC7ELMEa`2Ead02U/mFcaK?E/lFceK?5llIe]WO6=K0f]k0fnJ0g>I00]gUgNhMiIk]G^d
Nk=kU7^eNi=k/W^A009kTP03Nk9kTW^b071oo`03001oogoo00=oo`40005oo`00BWoo07P007ooDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aC7E;lEceG75LMDaaG?ELLFceG75mMFcaOGE/lGeeK
?6]kIgY[VfmjKiY_NWNiLiUc^GNGMkQgUW^fNiAk]WNFNkEkTgndNi9k]7^BNk9kTG^bMi9`Ool00`00
Oomoo`03Ool10001Ool004]oo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;m
DaeC7ELMDad00eLM00EG75LMEaeO?5/l00=O?004GeaSG5mLHe`4KiX2LiT02WNGMkQgUg^fNkAg^7NF
NkEk]7^c0g^B00Ek/W^ANk9k/W^B075oo`03001oogoo009oo`40005oo`00C7oo0P0007=C7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/mEaaK?EllHeaOG6=LGcaSG6=KIgaS
FfMlLiUc^GNGMkQgUg^fMiIg^7NFNkIkU7^eNi=k/g^COk=kTG^bNi5k/P1cOol01@00Oomoogoo0000
0Goo001>Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE;mD_eC7E;m0e<M00ABoE<MDaeG7@=C7@0AEaeC7ELmEaeK
?ELLEceK?5/mGeaSG5mLIgaSFfMlIe]WO002Jg/3KiX2LiT02GNhMiMk]W^dNkEkTg^BNkAk/`04Ni80
0g^AOomoo`1bOol01000Oomoo`000Goo001?Ool0L@00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC
75LMDaaG7E<LFceG75/mEaaK?E/lFceG76MlHe]WO6=KIgaWNf]kJgY_VVmjLkUcV7NiMiMk]WNFNkEk
U7^dNiAo]7^BNk9gTG^bNi40MGoo00@007ooOol0005oo`00D7oo00<007ooC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;m
DaeBo@=C7@0CD_eC7E<MEaeC7ELMDaeG7E<MFceK?5/mFcaK?E/lGcaK?6MlIe/016]k0fnJ0W>I00Ug
UgNhNkIk]G^DNk=k]W^eNi<00W^B00=k/W^ANi80MWoo00<007oo00000Goo001AOol20000KDklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MD_aG7E;lDaeBo5LMD_aG7E<LEceG75LMDaaK?E/lFceK?5mMFcaOGE/lJi]WNf]kIgY_VVmjKiYc
V7NiMiMg^7NFNkIkU7^eMiIk]G^CNk=kTWndNi9k/W^A07Moo`40005oo`400000Dgoo00H004kmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;m
DaeBoE<MD_eC7E;m1U<M00=G7ELLEad00ULM00EG75llGcaO?5/l009O?004HeaOG6=LGe`3KiX3LiT0
1GNhMiMk]WNGMkP00W^f00=kU7^cNi8017^BNGoo0P00001DOol0J`00OomC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aG7E;l
EaeBo5LMEaaK?ELLFceG75mMFcaOGElkHeaOG6=LGc]WO6=KIgacV7NiLiUg^7NGLkUgUgNhMiMk]W^D
NkEkTgncNi=k/g^ANk80NGoo0P00001EOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE;mD_eC7E;m0e<M01IBoE<MDaeG7E<MEaeC7ELM
EaaG?ELLFceG75LmGeaSG5mLHeaWFfMlHe]WO0=[N`9_VP9cV@08MkQgUg^fMiIk]G^CNk9kU0=kTWYo
o`800000EWoo06P007ooOom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaK?ELLFceG75/mEaaK?E/lIgaSFfMlHe]W
O6MjJi]WNfnJJgY_VW>IMkQgUgNhMiIk]G^DOkAkU7^dNi9o/g^AMWoo10000Woo001GOol2000017oo
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7DkmDaeBoE<MD_eC7E;m
DaeBo@=C7@0=D_eC7E<MEaeC7ELMDaeK?E/lFceK?5/mFc`00Ull00=WO6=KIg`00f]k0fnJ0W>I00ag
UgNhMiIk]W^dNk=gUW^eNi=k/W^BNk=bOol40006Ool005Uoo`1T001oodkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aG7E;lDaeBo5LMEaaG7E<LEceG
75/mEaaK?E/lGeeK?5mMFcaOGFMjJi]WNfnJJgY_VW>ILkUgUgNhMiIk]W^DNkEgUW^eNi=o/g^BNk9_
Ool4000:Ool005Yoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;m
D_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0U<M00=G7E<MDad00ULM00EG75LMEaeG7E/l00=O?005FcaS
G5mLHeaOG004KiX2LiT02GNhMiMk]W^fMkQgUW^fNkAk/`02Ni800g^COomoo`1YOol4000>Ool005]o
o`1R001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/mEaaSG5mLHeaO>f=LGeaWO6=KIgaSFg>iLiQg^7NGLkUc
V7NhMiMk]W^DOkAkTW^cNiAo]6Moo`@0019oo`00G7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@02D_d2Dad00e;mDaeC7@04Dad04ULMDaeG7E<MFceG75Lm
FcaK?E/lHeaOG6=LHe]WG6MKIgaSF`9[N`9_VP=cV@08MiMk]W^fNkEkTg^eNkAk/fEoo`<001Ioo`00
GWoo05h007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeB
o5<MDaaG7E<LEaeC75LMDaaK?ELLFceK?5/mEaaK?F=KIgaSFfMlIg][NfMjKiY_NW>iLiQc^GNGMkQg
UW^eNi=k]W^DNkEkTf5oo`@001Uoo`00Ggoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m15<M00AG7E<MEaeG709G7@06FceK?5/lFcaO?5/l0Ull
1F]k0VnJ0W>I00UgUgNhNkIk]W^DNkIk]7^eNi<0GWoo10007Goo001POol0F`00OomC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lDaeBo5LmEaaG7E<LEceG75LM
FcaOGE/lGeeK?6=LGea[NfMjJi]_NVnJLiQc^GNGMkQgUg^fNiAg^7NFNkEkU7^d05Yoo`@0025oo`00
HGoo0P0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;m
DaeC7ELMDad00eLM00aG75LmEaaK?E/lGcaOG6=LGeaSG5mLHe`2KiX3LiT02WNhMiMk]WNFMkQk]W^e
NiAk/g^CEWoo10009Goo001SOol0E`00Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;l
Dae>o5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/mEaaK?ElkHeaOG6=LGc]SG6=KIgaWNV^KIg]_VV]j
LkUcVGNhMiMk]W^DNkEkT`1DOol3000YOol006Aoo`03001C7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eB
oE<M00=Bo@03DaeBoE<M009C7@04D_eC7E<MEad2Dad2Ead01E<MEceG75/mEa`00U/l00MK?EmLHeaO
G6MlHe]WG003Jg/2KiX3LiT01WNGNkIkU7^eNi=k/e1oo`@002aoo`00IGoo04`007ooC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeK?5/mEaaK?E/lFceS
FfMlHe]WO6MjJi]WNfnJJgY_VP9cV@07MiMg^7NFNkEkU7ndMiH0C7oo1000<7oo001VOol200001Dkm
D_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7E<M00=G7@05EaaG7E/l
FceK?003Gc`00e/lGca[N`02Jg/3KiX2LiT01gNGMkQgUW^eNkAk]WNF04Uoo`@003Aoo`00J7oo04L0
07ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMDaaG?ELLEaeC75LmFcaO
GE/lGeeK?5mMGc]SG5mLKiY[NVnJ009cV@08LiQg^7NGNkIgUg^fMiIk]TEoo`@003Qoo`00JGoo00H0
07ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d2Dad01ULMDaeC7E<MEaeG709G7@03FceG
75Lm009O?008FcaSG5mLHeaOG6MLIe]WO0=cV@07MkQgUg>IMiMg^7NFNkH0@Woo1000?7oo001ZOol0
CP00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeG75/mEaaK?ELLFceO
G6=LGc]SG6=KIgaSFfMlIg][NfMjKiY_NW>ILiQg^7NFNkIgUSmoo`<0041oo`00Jgoo0P000U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MD_eBoE;mDaeBo@=C7@05D_eC7E<MEaeC7@03Ead015LLEceG75/m0e/l00EK?F=KIeaW
FfMl00=[N`9_VP9cV@04MkQgUg^fNkHlOol40013Ool006eoo`1:001oodkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MD_aC7E;lEaeBo5LMDaaG7E<LEaeG75/mFcaK?ELLFceK?5mMHe]WO6MkJg]WNV^KKgY_VW>HLkUg
Ug^fMiIk]SQoo`@004Moo`00KWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC
7ELMEa`00eLM0e/l00=O?5/lGc`00Ull16]k0VnJ0W>I00AgUgNhNkIk]SEoo`@004]oo`00Kgoo04H0
07ooOomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LGeeK?5mMFcaSG5mLHeaO
>f=LKgY_VW>HLkUcVGNhLiQc^C9oo`@004moo`00L7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeB
o@9C7@0CEaeC7E<MDaeK?ELLEceG75/mEaaG?EmLHeaOG6=LGeaSG6=KIe`00f]k00A_VW>ILiUcVBmo
o`<005=oo`00LWoo048004kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75/mEaaK?ELLFceG75/m
GeaSG5lkIgaSFfMlIgY[VfMkKiY[NW>iLiT/Ool4001FOol007=oo`04001BoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;mDaeBo@=C
7@05D_eG7ELMEaeC7@03Ead3Fc`01e/mFcaK?6MKIgaSFfML00=[N`9_VP9cVBUoo`@005Yoo`00M7oo
03h004kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MD_aG7E;lDaeBo5LMDaaG7E<LEceG75LMEaaK?E/lGeeK?5mMFcaOGFMjJi]WNfnJ
JgYc^G>I9Woo1000GWoo001eOol200001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7ELL00=G7@09FcaO
?5llGcaK?6=LGeaSG5mL00=_VP9cVB9oo`@0069oo`00Mgoo03P005<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5LMD_aG7ELL
EaeC75/mEaaK?ELLHeaOG6=LGc]SG5mLIgaSFfMl0W>I7goo1000IWoo001hOol00`00Dae>o@02D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@03DaeBoE<M00EC
7@0AEaeC7E<MEaaK?ELLEceK?5/mFcaSG5mLHeaSFfMLIe]WO002Jg/MOol3001ZOol007Uoo`0f001C
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7E;lDaeBo5LMDaaG7E<LEaeC75/mEaaK?E/LFceG75/mHe]WO6=KJi]WNf]k6Woo1000KGoo001jOol0
0`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC
7E;mDaeBo@=C7@05D_eG7ELMEaeG7002Ead01U/mFcaK?5/lGcaK?09O?0=[NaMoo`@0075oo`00Ngoo
0P00031>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7E;lEaeBo5<MD_aG?ELLEaeC75LmEaaG7E/lGeeK?5mMFcaSG5mLHe`DOol4001eOol007eoo`06001>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00AC7E;mDaeBo@AC7@03
EaeC7ELM009G7@0:EaaG?ELLFceK?5llGeaSG5mLHe`AOol4001iOol007ioo`0/001>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG7ELL
FceG75/mEaaK?ElkHeaOG0moo`@007eoo`00Ogoo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@0:Dae>oE;mD_eC7E;mDaeBoE<MD_d4Dad3Ead01E<MEaeG75/mEa`00U/l00=K?E/lOol037oo
0`00PGoo0020Ool200009E<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5LMD_aC7E<LEaeC75LMDaaG7E/LFceG75/m00]oo`@008Aoo`00PWoo00D005;mD_eC7Dkm009B
o@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoELMEaeG7ELL009G7@Uo
o`@008Qoo`00Pgoo020005<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
DaeBo5LMD_aG7E;lEceG75LM1goo1000S7oo0024Ool01@00OomBoE<MC_d00U;m00EC7DkmD_eBoE<M
00=Bo@06DaeBoE<MD_eC7E;m1U<M00=G7E<MOol017oo1000T7oo0025Ool200005TkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<M1Woo0`00U7oo0027Ool01000D_eC7Dkm0U;m
00aC7DkmD_eBoE<MC_eC7E;mDaeBoE<MD_d6Ool4002GOol008Qoo`0?001>oE<MC_aC7DkmDae>o5<M
C_aC7DklDae>o5<M00Aoo`@009]oo`00RGoo00@007ooDae>o@9Bo@06DaeBoE;mD_eC7E;m0Woo1000
Wgoo002:Ool200001E<MC_aC7DkmDad00Woo1000Xgoo002<Ool200000goo00000002002WOol008eo
o`800:]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo
>goo003oOolkOol00001\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.647 .763 .934 r
.38973 .79898 .39806 .80572 .41196 .80202 .40368 .79526 Mtetra
.648 .764 .933 r
.40368 .79526 .41196 .80202 .42593 .79826 .41769 .79148 Mtetra
.65 .765 .933 r
.41769 .79148 .42593 .79826 .43998 .79439 .43179 .78763 Mtetra
.653 .767 .933 r
.43179 .78763 .43998 .79439 .4541 .79034 .44596 .78363 Mtetra
.659 .771 .932 r
.44596 .78363 .4541 .79034 .4683 .78597 .4602 .7794 Mtetra
.671 .779 .93 r
.4602 .7794 .4683 .78597 .48258 .781 .47452 .77473 Mtetra
.692 .792 .927 r
.47452 .77473 .48258 .781 .49692 .77495 .48892 .76925 Mtetra
.727 .815 .919 r
.48892 .76925 .49692 .77495 .51134 .76695 .50339 .7623 Mtetra
.783 .849 .901 r
.50339 .7623 .51134 .76695 .52579 .75557 .51792 .75276 Mtetra
.855 .889 .861 r
.51792 .75276 .52579 .75557 .54024 .73881 .53246 .73888 Mtetra
.925 .921 .79 r
.53246 .73888 .54024 .73881 .55459 .71462 .54697 .71851 Mtetra
.966 .93 .697 r
.54697 .71851 .55459 .71462 .56876 .68262 .56133 .69014 Mtetra
.974 .922 .614 r
.56133 .69014 .56876 .68262 .58269 .64596 .57546 .655 Mtetra
.966 .917 .575 r
.57546 .655 .58269 .64596 .59646 .6107 .58938 .61809 Mtetra
.961 .931 .606 r
.58938 .61809 .59646 .6107 .6102 .58194 .6032 .58552 Mtetra
.952 .953 .704 r
.6032 .58552 .6102 .58194 .62403 .56105 .61707 .56063 Mtetra
.91 .942 .814 r
.61707 .56063 .62403 .56105 .63802 .54662 .63106 .54314 Mtetra
.836 .891 .88 r
.63106 .54314 .63802 .54662 .65216 .53653 .64521 .53106 Mtetra
.767 .835 .904 r
.64521 .53106 .65216 .53653 .66643 .52903 .6595 .52237 Mtetra
.722 .795 .909 r
.6595 .52237 .66643 .52903 .68081 .52297 .67391 .51565 Mtetra
.695 .77 .91 r
.67391 .51565 .68081 .52297 .6953 .5177 .68844 .50999 Mtetra
.68 .757 .909 r
.68844 .50999 .6953 .5177 .70987 .51284 .70306 .5049 Mtetra
.672 .75 .909 r
.70306 .5049 .70987 .51284 .72453 .50818 .71777 .5001 Mtetra
.668 .746 .908 r
.71777 .5001 .72453 .50818 .73927 .50362 .73256 .49545 Mtetra
.666 .744 .908 r
.73256 .49545 .73927 .50362 .7541 .4991 .74743 .49086 Mtetra
.665 .743 .908 r
.74743 .49086 .7541 .4991 .769 .49459 .76239 .48629 Mtetra
.664 .742 .908 r
.76239 .48629 .769 .49459 .78397 .49008 .77742 .48173 Mtetra
.77742 .48173 .78397 .49008 .79903 .48555 .79254 .47715 Mtetra
.664 .741 .908 r
.79254 .47715 .79903 .48555 .81417 .48101 .80773 .47256 Mtetra
.80773 .47256 .81417 .48101 .82939 .47644 .823 .46795 Mtetra
.823 .46795 .82939 .47644 .84469 .47185 .83836 .46331 Mtetra
.83836 .46331 .84469 .47185 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.647 .763 .934 r
.38132 .79217 .38973 .79898 .40368 .79526 .39531 .78842 Mtetra
.39531 .78842 .40368 .79526 .41769 .79148 .40937 .78463 Mtetra
.649 .764 .933 r
.40937 .78463 .41769 .79148 .43179 .78763 .42351 .78077 Mtetra
.651 .766 .933 r
.42351 .78077 .43179 .78763 .44596 .78363 .43773 .77681 Mtetra
.656 .769 .933 r
.43773 .77681 .44596 .78363 .4602 .7794 .45202 .77267 Mtetra
.664 .774 .931 r
.45202 .77267 .4602 .7794 .47452 .77473 .46639 .76819 Mtetra
.68 .784 .929 r
.46639 .76819 .47452 .77473 .48892 .76925 .48084 .76313 Mtetra
.707 .802 .924 r
.48084 .76313 .48892 .76925 .50339 .7623 .49536 .75696 Mtetra
.752 .83 .912 r
.49536 .75696 .50339 .7623 .51792 .75276 .50995 .74883 Mtetra
.817 .869 .885 r
.50995 .74883 .51792 .75276 .53246 .73888 .52458 .7373 Mtetra
.892 .907 .83 r
.52458 .7373 .53246 .73888 .54697 .71851 .53921 .72035 Mtetra
.95 .929 .745 r
.53921 .72035 .54697 .71851 .56133 .69014 .55375 .69593 Mtetra
.974 .927 .652 r
.55375 .69593 .56133 .69014 .57546 .655 .56809 .66363 Mtetra
.971 .918 .587 r
.56809 .66363 .57546 .655 .58938 .61809 .5822 .62664 Mtetra
.963 .922 .581 r
.5822 .62664 .58938 .61809 .6032 .58552 .59614 .59108 Mtetra
.959 .944 .649 r
.59614 .59108 .6032 .58552 .61707 .56063 .61005 .56206 Mtetra
.937 .954 .762 r
.61005 .56206 .61707 .56063 .63106 .54314 .62405 .54097 Mtetra
.874 .919 .854 r
.62405 .54097 .63106 .54314 .64521 .53106 .63821 .52638 Mtetra
.799 .861 .895 r
.63821 .52638 .64521 .53106 .6595 .52237 .65252 .51614 Mtetra
.742 .812 .908 r
.65252 .51614 .6595 .52237 .67391 .51565 .66696 .50851 Mtetra
.706 .781 .91 r
.66696 .50851 .67391 .51565 .68844 .50999 .68152 .50234 Mtetra
.686 .763 .909 r
.68152 .50234 .68844 .50999 .70306 .5049 .69618 .49696 Mtetra
.676 .753 .909 r
.69618 .49696 .70306 .5049 .71777 .5001 .71094 .49199 Mtetra
.67 .747 .909 r
.71094 .49199 .71777 .5001 .73256 .49545 .72578 .48722 Mtetra
.667 .744 .908 r
.72578 .48722 .73256 .49545 .74743 .49086 .74071 .48255 Mtetra
.665 .743 .908 r
.74071 .48255 .74743 .49086 .76239 .48629 .75572 .47792 Mtetra
.664 .742 .908 r
.75572 .47792 .76239 .48629 .77742 .48173 .77081 .4733 Mtetra
.77081 .4733 .77742 .48173 .79254 .47715 .78597 .46867 Mtetra
.78597 .46867 .79254 .47715 .80773 .47256 .80123 .46403 Mtetra
.664 .741 .908 r
.80123 .46403 .80773 .47256 .823 .46795 .81656 .45937 Mtetra
.81656 .45937 .823 .46795 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.646 .763 .934 r
.37283 .78529 .38132 .79217 .39531 .78842 .38686 .78151 Mtetra
.647 .763 .934 r
.38686 .78151 .39531 .78842 .40937 .78463 .40097 .7777 Mtetra
.648 .764 .933 r
.40097 .7777 .40937 .78463 .42351 .78077 .41516 .77383 Mtetra
.65 .765 .933 r
.41516 .77383 .42351 .78077 .43773 .77681 .42942 .76988 Mtetra
.653 .767 .933 r
.42942 .76988 .43773 .77681 .45202 .77267 .44376 .76579 Mtetra
.659 .771 .932 r
.44376 .76579 .45202 .77267 .46639 .76819 .45817 .76146 Mtetra
.671 .779 .93 r
.45817 .76146 .46639 .76819 .48084 .76313 .47267 .75668 Mtetra
.692 .792 .927 r
.47267 .75668 .48084 .76313 .49536 .75696 .48725 .75109 Mtetra
.727 .815 .919 r
.48725 .75109 .49536 .75696 .50995 .74883 .50189 .74403 Mtetra
.783 .849 .901 r
.50189 .74403 .50995 .74883 .52458 .7373 .5166 .73434 Mtetra
.855 .889 .861 r
.5166 .73434 .52458 .7373 .53921 .72035 .53133 .7203 Mtetra
.925 .921 .79 r
.53133 .7203 .53921 .72035 .55375 .69593 .54602 .6997 Mtetra
.966 .93 .697 r
.54602 .6997 .55375 .69593 .56809 .66363 .56056 .67106 Mtetra
.974 .922 .614 r
.56056 .67106 .56809 .66363 .5822 .62664 .57488 .63561 Mtetra
.966 .917 .575 r
.57488 .63561 .5822 .62664 .59614 .59108 .58898 .59837 Mtetra
.961 .931 .606 r
.58898 .59837 .59614 .59108 .61005 .56206 .60297 .56552 Mtetra
.952 .953 .704 r
.60297 .56552 .61005 .56206 .62405 .54097 .617 .5404 Mtetra
.91 .942 .814 r
.617 .5404 .62405 .54097 .63821 .52638 .63116 .52272 Mtetra
.836 .89 .88 r
.63116 .52272 .63821 .52638 .65252 .51614 .64548 .51049 Mtetra
.767 .834 .903 r
.64548 .51049 .65252 .51614 .66696 .50851 .65995 .50167 Mtetra
.722 .794 .909 r
.65995 .50167 .66696 .50851 .68152 .50234 .67454 .49482 Mtetra
.695 .77 .91 r
.67454 .49482 .68152 .50234 .69618 .49696 .68925 .48905 Mtetra
.68 .757 .909 r
.68925 .48905 .69618 .49696 .71094 .49199 .70405 .48385 Mtetra
.672 .75 .909 r
.70405 .48385 .71094 .49199 .72578 .48722 .71894 .47894 Mtetra
.668 .746 .908 r
.71894 .47894 .72578 .48722 .74071 .48255 .73392 .47417 Mtetra
.666 .744 .908 r
.73392 .47417 .74071 .48255 .75572 .47792 .74898 .46947 Mtetra
.665 .743 .908 r
.74898 .46947 .75572 .47792 .77081 .4733 .76412 .46479 Mtetra
.664 .742 .908 r
.76412 .46479 .77081 .4733 .78597 .46867 .77935 .46012 Mtetra
.77935 .46012 .78597 .46867 .80123 .46403 .79466 .45543 Mtetra
.664 .741 .908 r
.79466 .45543 .80123 .46403 .81656 .45937 .81005 .45072 Mtetra
.81005 .45072 .81656 .45937 .83197 .45469 .82552 .44599 Mtetra
.82552 .44599 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43646 Mtetra
.85671 .43646 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.646 .763 .934 r
.36425 .77834 .37283 .78529 .38686 .78151 .37833 .77453 Mtetra
.647 .763 .934 r
.37833 .77453 .38686 .78151 .40097 .7777 .39249 .77069 Mtetra
.39249 .77069 .40097 .7777 .41516 .77383 .40672 .7668 Mtetra
.649 .764 .933 r
.40672 .7668 .41516 .77383 .42942 .76988 .42103 .76285 Mtetra
.651 .766 .933 r
.42103 .76285 .42942 .76988 .44376 .76579 .43542 .75879 Mtetra
.656 .769 .933 r
.43542 .75879 .44376 .76579 .45817 .76146 .44988 .75455 Mtetra
.664 .774 .931 r
.44988 .75455 .45817 .76146 .47267 .75668 .46442 .74998 Mtetra
.68 .784 .929 r
.46442 .74998 .47267 .75668 .48725 .75109 .47905 .7448 Mtetra
.707 .802 .924 r
.47905 .7448 .48725 .75109 .50189 .74403 .49375 .73852 Mtetra
.752 .83 .912 r
.49375 .73852 .50189 .74403 .5166 .73434 .50852 .73026 Mtetra
.817 .869 .885 r
.50852 .73026 .5166 .73434 .53133 .7203 .52334 .71858 Mtetra
.892 .908 .83 r
.52334 .71858 .53133 .7203 .54602 .6997 .53816 .70143 Mtetra
.95 .929 .745 r
.53816 .70143 .54602 .6997 .56056 .67106 .55288 .67676 Mtetra
.974 .927 .652 r
.55288 .67676 .56056 .67106 .57488 .63561 .56741 .64416 Mtetra
.971 .918 .587 r
.56741 .64416 .57488 .63561 .58898 .59837 .5817 .60685 Mtetra
.963 .922 .582 r
.5817 .60685 .58898 .59837 .60297 .56552 .59581 .57098 Mtetra
.959 .944 .649 r
.59581 .57098 .60297 .56552 .617 .5404 .60989 .5417 Mtetra
.937 .953 .763 r
.60989 .5417 .617 .5404 .63116 .52272 .62407 .52039 Mtetra
.874 .919 .854 r
.62407 .52039 .63116 .52272 .64548 .51049 .6384 .50563 Mtetra
.799 .861 .895 r
.6384 .50563 .64548 .51049 .65995 .50167 .65288 .49525 Mtetra
.742 .812 .907 r
.65288 .49525 .65995 .50167 .67454 .49482 .66751 .4875 Mtetra
.706 .781 .91 r
.66751 .4875 .67454 .49482 .68925 .48905 .68225 .48121 Mtetra
.686 .763 .909 r
.68225 .48121 .68925 .48905 .70405 .48385 .69709 .47571 Mtetra
.676 .753 .909 r
.69709 .47571 .70405 .48385 .71894 .47894 .71203 .47062 Mtetra
.67 .747 .909 r
.71203 .47062 .71894 .47894 .73392 .47417 .72706 .46574 Mtetra
.667 .744 .908 r
.72706 .46574 .73392 .47417 .74898 .46947 .74218 .46095 Mtetra
.665 .743 .908 r
.74218 .46095 .74898 .46947 .76412 .46479 .75738 .45621 Mtetra
.664 .742 .908 r
.75738 .45621 .76412 .46479 .77935 .46012 .77266 .45148 Mtetra
.77266 .45148 .77935 .46012 .79466 .45543 .78802 .44673 Mtetra
.78802 .44673 .79466 .45543 .81005 .45072 .80347 .44198 Mtetra
.664 .741 .908 r
.80347 .44198 .81005 .45072 .82552 .44599 .819 .4372 Mtetra
.819 .4372 .82552 .44599 .84107 .44123 .83462 .4324 Mtetra
.83462 .4324 .84107 .44123 .85671 .43646 .85032 .42757 Mtetra
.85032 .42757 .85671 .43646 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.646 .763 .934 r
.35559 .77132 .36425 .77834 .37833 .77453 .36972 .76748 Mtetra
.36972 .76748 .37833 .77453 .39249 .77069 .38392 .7636 Mtetra
.647 .763 .934 r
.38392 .7636 .39249 .77069 .40672 .7668 .3982 .75969 Mtetra
.648 .764 .933 r
.3982 .75969 .40672 .7668 .42103 .76285 .41256 .75573 Mtetra
.65 .765 .933 r
.41256 .75573 .42103 .76285 .43542 .75879 .42699 .75168 Mtetra
.653 .767 .933 r
.42699 .75168 .43542 .75879 .44988 .75455 .4415 .74749 Mtetra
.659 .771 .932 r
.4415 .74749 .44988 .75455 .46442 .74998 .4561 .74306 Mtetra
.671 .779 .93 r
.4561 .74306 .46442 .74998 .47905 .7448 .47077 .73818 Mtetra
.692 .792 .927 r
.47077 .73818 .47905 .7448 .49375 .73852 .48553 .73248 Mtetra
.727 .815 .919 r
.48553 .73248 .49375 .73852 .50852 .73026 .50036 .72529 Mtetra
.783 .849 .901 r
.50036 .72529 .50852 .73026 .52334 .71858 .51525 .71546 Mtetra
.855 .89 .861 r
.51525 .71546 .52334 .71858 .53816 .70143 .53017 .70124 Mtetra
.925 .921 .79 r
.53017 .70124 .53816 .70143 .55288 .67676 .54505 .68042 Mtetra
.966 .93 .697 r
.54505 .68042 .55288 .67676 .56741 .64416 .55978 .6515 Mtetra
.974 .922 .614 r
.55978 .6515 .56741 .64416 .5817 .60685 .57428 .61573 Mtetra
.966 .917 .576 r
.57428 .61573 .5817 .60685 .59581 .57098 .58856 .57817 Mtetra
.961 .932 .607 r
.58856 .57817 .59581 .57098 .60989 .5417 .60272 .54503 Mtetra
.953 .953 .704 r
.60272 .54503 .60989 .5417 .62407 .52039 .61693 .51967 Mtetra
.91 .941 .815 r
.61693 .51967 .62407 .52039 .6384 .50563 .63127 .50181 Mtetra
.836 .89 .88 r
.63127 .50181 .6384 .50563 .65288 .49525 .64576 .48942 Mtetra
.767 .834 .903 r
.64576 .48942 .65288 .49525 .66751 .4875 .66041 .48046 Mtetra
.722 .794 .909 r
.66041 .48046 .66751 .4875 .68225 .48121 .67519 .47349 Mtetra
.695 .77 .91 r
.67519 .47349 .68225 .48121 .69709 .47571 .69007 .46759 Mtetra
.68 .757 .909 r
.69007 .46759 .69709 .47571 .71203 .47062 .70506 .46227 Mtetra
.672 .75 .909 r
.70506 .46227 .71203 .47062 .72706 .46574 .72014 .45725 Mtetra
.668 .746 .908 r
.72014 .45725 .72706 .46574 .74218 .46095 .73531 .45237 Mtetra
.666 .744 .908 r
.73531 .45237 .74218 .46095 .75738 .45621 .75057 .44755 Mtetra
.665 .743 .908 r
.75057 .44755 .75738 .45621 .77266 .45148 .7659 .44275 Mtetra
.664 .742 .908 r
.7659 .44275 .77266 .45148 .78802 .44673 .78133 .43796 Mtetra
.78133 .43796 .78802 .44673 .80347 .44198 .79683 .43315 Mtetra
.664 .741 .908 r
.79683 .43315 .80347 .44198 .819 .4372 .81242 .42832 Mtetra
.81242 .42832 .819 .4372 .83462 .4324 .8281 .42347 Mtetra
.8281 .42347 .83462 .4324 .85032 .42757 .84386 .41859 Mtetra
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.646 .763 .934 r
.34685 .76423 .35559 .77132 .36972 .76748 .36102 .76035 Mtetra
.36102 .76035 .36972 .76748 .38392 .7636 .37527 .75645 Mtetra
.647 .763 .934 r
.37527 .75645 .38392 .7636 .3982 .75969 .3896 .75251 Mtetra
.3896 .75251 .3982 .75969 .41256 .75573 .404 .74852 Mtetra
.649 .764 .933 r
.404 .74852 .41256 .75573 .42699 .75168 .41848 .74447 Mtetra
.651 .766 .933 r
.41848 .74447 .42699 .75168 .4415 .74749 .43305 .74032 Mtetra
.656 .769 .933 r
.43305 .74032 .4415 .74749 .4561 .74306 .44769 .73597 Mtetra
.664 .774 .931 r
.44769 .73597 .4561 .74306 .47077 .73818 .46241 .73129 Mtetra
.68 .784 .929 r
.46241 .73129 .47077 .73818 .48553 .73248 .47722 .72601 Mtetra
.707 .802 .924 r
.47722 .72601 .48553 .73248 .50036 .72529 .49211 .71961 Mtetra
.752 .831 .912 r
.49211 .71961 .50036 .72529 .51525 .71546 .50706 .71122 Mtetra
.817 .869 .885 r
.50706 .71122 .51525 .71546 .53017 .70124 .52207 .69937 Mtetra
.892 .908 .83 r
.52207 .69937 .53017 .70124 .54505 .68042 .53708 .68202 Mtetra
.95 .929 .745 r
.53708 .68202 .54505 .68042 .55978 .6515 .55199 .6571 Mtetra
.973 .927 .651 r
.55199 .6571 .55978 .6515 .57428 .61573 .56671 .62419 Mtetra
.971 .918 .587 r
.56671 .62419 .57428 .61573 .58856 .57817 .58118 .58655 Mtetra
.963 .922 .582 r
.58118 .58655 .58856 .57817 .60272 .54503 .59548 .55037 Mtetra
.959 .944 .65 r
.59548 .55037 .60272 .54503 .61693 .51967 .60973 .52082 Mtetra
.937 .953 .763 r
.60973 .52082 .61693 .51967 .63127 .50181 .62409 .4993 Mtetra
.874 .919 .854 r
.62409 .4993 .63127 .50181 .64576 .48942 .6386 .48437 Mtetra
.799 .861 .895 r
.6386 .48437 .64576 .48942 .66041 .48046 .65326 .47385 Mtetra
.742 .812 .907 r
.65326 .47385 .66041 .48046 .67519 .47349 .66806 .46596 Mtetra
.706 .781 .91 r
.66806 .46596 .67519 .47349 .69007 .46759 .68299 .45954 Mtetra
.686 .763 .909 r
.68299 .45954 .69007 .46759 .70506 .46227 .69803 .45392 Mtetra
.676 .753 .909 r
.69803 .45392 .70506 .46227 .72014 .45725 .71316 .44872 Mtetra
.67 .747 .909 r
.71316 .44872 .72014 .45725 .73531 .45237 .72838 .44372 Mtetra
.667 .744 .908 r
.72838 .44372 .73531 .45237 .75057 .44755 .74369 .43881 Mtetra
.665 .743 .908 r
.74369 .43881 .75057 .44755 .7659 .44275 .75908 .43395 Mtetra
.664 .742 .908 r
.75908 .43395 .7659 .44275 .78133 .43796 .77456 .4291 Mtetra
.77456 .4291 .78133 .43796 .79683 .43315 .79013 .42423 Mtetra
.79013 .42423 .79683 .43315 .81242 .42832 .80578 .41935 Mtetra
.664 .741 .908 r
.80578 .41935 .81242 .42832 .8281 .42347 .82151 .41445 Mtetra
.82151 .41445 .8281 .42347 .84386 .41859 .83733 .40953 Mtetra
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.646 .762 .934 r
.33802 .75707 .34685 .76423 .36102 .76035 .35224 .75315 Mtetra
.646 .763 .934 r
.35224 .75315 .36102 .76035 .37527 .75645 .36654 .74921 Mtetra
.36654 .74921 .37527 .75645 .3896 .75251 .38091 .74524 Mtetra
.647 .763 .934 r
.38091 .74524 .3896 .75251 .404 .74852 .39536 .74123 Mtetra
.648 .764 .933 r
.39536 .74123 .404 .74852 .41848 .74447 .40989 .73717 Mtetra
.65 .765 .933 r
.40989 .73717 .41848 .74447 .43305 .74032 .4245 .73302 Mtetra
.653 .767 .933 r
.4245 .73302 .43305 .74032 .44769 .73597 .43919 .72873 Mtetra
.659 .771 .932 r
.43919 .72873 .44769 .73597 .46241 .73129 .45397 .72419 Mtetra
.671 .779 .93 r
.45397 .72419 .46241 .73129 .47722 .72601 .46883 .7192 Mtetra
.692 .792 .927 r
.46883 .7192 .47722 .72601 .49211 .71961 .48377 .71338 Mtetra
.727 .815 .919 r
.48377 .71338 .49211 .71961 .50706 .71122 .49879 .70607 Mtetra
.783 .849 .901 r
.49879 .70607 .50706 .71122 .52207 .69937 .51387 .69609 Mtetra
.855 .89 .862 r
.51387 .69609 .52207 .69937 .53708 .68202 .52898 .68169 Mtetra
.925 .922 .79 r
.52898 .68169 .53708 .68202 .55199 .6571 .54405 .66065 Mtetra
.966 .93 .697 r
.54405 .66065 .55199 .6571 .56671 .62419 .55897 .63144 Mtetra
.974 .922 .613 r
.55897 .63144 .56671 .62419 .58118 .58655 .57367 .59535 Mtetra
.966 .917 .576 r
.57367 .59535 .58118 .58655 .59548 .55037 .58813 .55746 Mtetra
.961 .932 .607 r
.58813 .55746 .59548 .55037 .60973 .52082 .60247 .52402 Mtetra
.953 .953 .705 r
.60247 .52402 .60973 .52082 .62409 .4993 .61686 .49842 Mtetra
.91 .941 .815 r
.61686 .49842 .62409 .4993 .6386 .48437 .63138 .48036 Mtetra
.836 .89 .88 r
.63138 .48036 .6386 .48437 .65326 .47385 .64605 .46781 Mtetra
.767 .834 .903 r
.64605 .46781 .65326 .47385 .66806 .46596 .66088 .45872 Mtetra
.722 .794 .909 r
.66088 .45872 .66806 .46596 .68299 .45954 .67585 .45161 Mtetra
.695 .77 .91 r
.67585 .45161 .68299 .45954 .69803 .45392 .69092 .4456 Mtetra
.68 .757 .909 r
.69092 .4456 .69803 .45392 .71316 .44872 .7061 .44016 Mtetra
.672 .75 .909 r
.7061 .44016 .71316 .44872 .72838 .44372 .72138 .43501 Mtetra
.668 .746 .908 r
.72138 .43501 .72838 .44372 .74369 .43881 .73674 .43001 Mtetra
.666 .744 .908 r
.73674 .43001 .74369 .43881 .75908 .43395 .75219 .42507 Mtetra
.665 .743 .908 r
.75219 .42507 .75908 .43395 .77456 .4291 .76773 .42015 Mtetra
.664 .742 .908 r
.76773 .42015 .77456 .4291 .79013 .42423 .78335 .41523 Mtetra
.78335 .41523 .79013 .42423 .80578 .41935 .79906 .4103 Mtetra
.664 .741 .908 r
.79906 .4103 .80578 .41935 .82151 .41445 .81486 .40535 Mtetra
.81486 .40535 .82151 .41445 .83733 .40953 .83074 .40037 Mtetra
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.646 .762 .934 r
.32911 .74984 .33802 .75707 .35224 .75315 .34337 .74589 Mtetra
.646 .763 .934 r
.34337 .74589 .35224 .75315 .36654 .74921 .35772 .74191 Mtetra
.35772 .74191 .36654 .74921 .38091 .74524 .37214 .7379 Mtetra
.647 .763 .934 r
.37214 .7379 .38091 .74524 .39536 .74123 .38664 .73387 Mtetra
.38664 .73387 .39536 .74123 .40989 .73717 .40121 .72978 Mtetra
.649 .764 .933 r
.40121 .72978 .40989 .73717 .4245 .73302 .41587 .72563 Mtetra
.651 .766 .933 r
.41587 .72563 .4245 .73302 .43919 .72873 .43061 .72137 Mtetra
.656 .769 .933 r
.43061 .72137 .43919 .72873 .45397 .72419 .44544 .71692 Mtetra
.664 .774 .931 r
.44544 .71692 .45397 .72419 .46883 .7192 .46035 .71213 Mtetra
.68 .784 .929 r
.46035 .71213 .46883 .7192 .48377 .71338 .47534 .70673 Mtetra
.707 .802 .924 r
.47534 .70673 .48377 .71338 .49879 .70607 .49042 .70021 Mtetra
.752 .831 .912 r
.49042 .70021 .49879 .70607 .51387 .69609 .50557 .69168 Mtetra
.817 .869 .885 r
.50557 .69168 .51387 .69609 .52898 .68169 .52077 .67967 Mtetra
.892 .908 .83 r
.52077 .67967 .52898 .68169 .54405 .66065 .53597 .66211 Mtetra
.95 .929 .744 r
.53597 .66211 .54405 .66065 .55897 .63144 .55108 .63693 Mtetra
.973 .927 .651 r
.55108 .63693 .55897 .63144 .57367 .59535 .56599 .60371 Mtetra
.971 .918 .587 r
.56599 .60371 .57367 .59535 .58813 .55746 .58066 .56574 Mtetra
.963 .922 .582 r
.58066 .56574 .58813 .55746 .60247 .52402 .59513 .52924 Mtetra
.959 .943 .65 r
.59513 .52924 .60247 .52402 .61686 .49842 .60957 .49943 Mtetra
.937 .953 .763 r
.60957 .49943 .61686 .49842 .63138 .48036 .62411 .47769 Mtetra
.874 .918 .854 r
.62411 .47769 .63138 .48036 .64605 .46781 .6388 .46258 Mtetra
.799 .861 .895 r
.6388 .46258 .64605 .46781 .66088 .45872 .65365 .4519 Mtetra
.742 .812 .907 r
.65365 .4519 .66088 .45872 .67585 .45161 .66864 .44388 Mtetra
.706 .781 .91 r
.66864 .44388 .67585 .45161 .69092 .4456 .68375 .43733 Mtetra
.687 .763 .909 r
.68375 .43733 .69092 .4456 .7061 .44016 .69898 .43159 Mtetra
.676 .753 .909 r
.69898 .43159 .7061 .44016 .72138 .43501 .71431 .42626 Mtetra
.67 .747 .908 r
.71431 .42626 .72138 .43501 .73674 .43001 .72972 .42113 Mtetra
.667 .744 .908 r
.72972 .42113 .73674 .43001 .75219 .42507 .74523 .41611 Mtetra
.665 .743 .908 r
.74523 .41611 .75219 .42507 .76773 .42015 .76083 .41112 Mtetra
.664 .742 .908 r
.76083 .41112 .76773 .42015 .78335 .41523 .77651 .40614 Mtetra
.77651 .40614 .78335 .41523 .79906 .4103 .79228 .40116 Mtetra
.79228 .40116 .79906 .4103 .81486 .40535 .80814 .39615 Mtetra
.664 .741 .908 r
.80814 .39615 .81486 .40535 .83074 .40037 .82409 .39112 Mtetra
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38607 Mtetra
.84012 .38607 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .762 .934 r
.3201 .74253 .32911 .74984 .34337 .74589 .33441 .73854 Mtetra
.33441 .73854 .34337 .74589 .35772 .74191 .3488 .73453 Mtetra
.646 .763 .934 r
.3488 .73453 .35772 .74191 .37214 .7379 .36327 .73049 Mtetra
.36327 .73049 .37214 .7379 .38664 .73387 .37782 .72642 Mtetra
.647 .763 .934 r
.37782 .72642 .38664 .73387 .40121 .72978 .39245 .7223 Mtetra
.648 .764 .933 r
.39245 .7223 .40121 .72978 .41587 .72563 .40716 .71814 Mtetra
.65 .765 .933 r
.40716 .71814 .41587 .72563 .43061 .72137 .42195 .71388 Mtetra
.653 .767 .933 r
.42195 .71388 .43061 .72137 .44544 .71692 .43682 .70949 Mtetra
.659 .771 .932 r
.43682 .70949 .44544 .71692 .46035 .71213 .45178 .70484 Mtetra
.671 .779 .93 r
.45178 .70484 .46035 .71213 .47534 .70673 .46683 .69973 Mtetra
.692 .792 .927 r
.46683 .69973 .47534 .70673 .49042 .70021 .48196 .6938 Mtetra
.727 .815 .919 r
.48196 .6938 .49042 .70021 .50557 .69168 .49717 .68634 Mtetra
.783 .849 .901 r
.49717 .68634 .50557 .69168 .52077 .67967 .51245 .67622 Mtetra
.855 .89 .862 r
.51245 .67622 .52077 .67967 .53597 .66211 .52776 .66163 Mtetra
.925 .922 .79 r
.52776 .66163 .53597 .66211 .55108 .63693 .54303 .64036 Mtetra
.966 .93 .696 r
.54303 .64036 .55108 .63693 .56599 .60371 .55815 .61087 Mtetra
.974 .922 .613 r
.55815 .61087 .56599 .60371 .58066 .56574 .57304 .57444 Mtetra
.966 .917 .576 r
.57304 .57444 .58066 .56574 .59513 .52924 .58769 .53622 Mtetra
.962 .932 .607 r
.58769 .53622 .59513 .52924 .60957 .49943 .60222 .50248 Mtetra
.953 .953 .705 r
.60222 .50248 .60957 .49943 .62411 .47769 .61679 .47663 Mtetra
.91 .941 .815 r
.61679 .47663 .62411 .47769 .6388 .46258 .63149 .45838 Mtetra
.836 .89 .88 r
.63149 .45838 .6388 .46258 .65365 .4519 .64635 .44567 Mtetra
.767 .834 .903 r
.64635 .44567 .65365 .4519 .66864 .44388 .66137 .43643 Mtetra
.722 .794 .909 r
.66137 .43643 .66864 .44388 .68375 .43733 .67652 .42919 Mtetra
.695 .77 .91 r
.67652 .42919 .68375 .43733 .69898 .43159 .69179 .42304 Mtetra
.68 .757 .909 r
.69179 .42304 .69898 .43159 .71431 .42626 .70717 .41747 Mtetra
.672 .75 .909 r
.70717 .41747 .71431 .42626 .72972 .42113 .72264 .4122 Mtetra
.668 .746 .908 r
.72264 .4122 .72972 .42113 .74523 .41611 .7382 .40707 Mtetra
.666 .744 .908 r
.7382 .40707 .74523 .41611 .76083 .41112 .75386 .40201 Mtetra
.665 .743 .908 r
.75386 .40201 .76083 .41112 .77651 .40614 .7696 .39697 Mtetra
.664 .742 .908 r
.7696 .39697 .77651 .40614 .79228 .40116 .78543 .39192 Mtetra
.78543 .39192 .79228 .40116 .80814 .39615 .80135 .38686 Mtetra
.664 .741 .908 r
.80135 .38686 .80814 .39615 .82409 .39112 .81736 .38178 Mtetra
.81736 .38178 .82409 .39112 .84012 .38607 .83346 .37667 Mtetra
.83346 .37667 .84012 .38607 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .762 .934 r
.31101 .73516 .3201 .74253 .33441 .73854 .32537 .73113 Mtetra
.32537 .73113 .33441 .73854 .3488 .73453 .3398 .72707 Mtetra
.646 .763 .934 r
.3398 .72707 .3488 .73453 .36327 .73049 .35432 .72299 Mtetra
.35432 .72299 .36327 .73049 .37782 .72642 .36892 .71889 Mtetra
.647 .763 .934 r
.36892 .71889 .37782 .72642 .39245 .7223 .3836 .71474 Mtetra
.3836 .71474 .39245 .7223 .40716 .71814 .39835 .71055 Mtetra
.649 .764 .933 r
.39835 .71055 .40716 .71814 .42195 .71388 .4132 .70629 Mtetra
.651 .766 .933 r
.4132 .70629 .42195 .71388 .43682 .70949 .42812 .70192 Mtetra
.656 .769 .933 r
.42812 .70192 .43682 .70949 .45178 .70484 .44313 .69736 Mtetra
.664 .774 .931 r
.44313 .69736 .45178 .70484 .46683 .69973 .45823 .69246 Mtetra
.68 .785 .929 r
.45823 .69246 .46683 .69973 .48196 .6938 .47341 .68695 Mtetra
.707 .802 .924 r
.47341 .68695 .48196 .6938 .49717 .68634 .48868 .6803 Mtetra
.752 .831 .912 r
.48868 .6803 .49717 .68634 .51245 .67622 .50403 .67162 Mtetra
.817 .87 .885 r
.50403 .67162 .51245 .67622 .52776 .66163 .51943 .65944 Mtetra
.892 .908 .83 r
.51943 .65944 .52776 .66163 .54303 .64036 .53483 .64168 Mtetra
.95 .929 .744 r
.53483 .64168 .54303 .64036 .55815 .61087 .55014 .61623 Mtetra
.973 .927 .651 r
.55014 .61623 .55815 .61087 .57304 .57444 .56526 .58271 Mtetra
.971 .918 .587 r
.56526 .58271 .57304 .57444 .58769 .53622 .58011 .54439 Mtetra
.963 .922 .582 r
.58011 .54439 .58769 .53622 .60222 .50248 .59478 .50757 Mtetra
.959 .943 .65 r
.59478 .50757 .60222 .50248 .61679 .47663 .60941 .47748 Mtetra
.937 .953 .763 r
.60941 .47748 .61679 .47663 .63149 .45838 .62413 .45552 Mtetra
.874 .918 .854 r
.62413 .45552 .63149 .45838 .64635 .44567 .639 .44023 Mtetra
.799 .86 .895 r
.639 .44023 .64635 .44567 .66137 .43643 .65404 .4294 Mtetra
.742 .812 .907 r
.65404 .4294 .66137 .43643 .67652 .42919 .66923 .42123 Mtetra
.706 .781 .91 r
.66923 .42123 .67652 .42919 .69179 .42304 .68454 .41455 Mtetra
.687 .763 .909 r
.68454 .41455 .69179 .42304 .70717 .41747 .69996 .40868 Mtetra
.676 .753 .909 r
.69996 .40868 .70717 .41747 .72264 .4122 .71549 .40322 Mtetra
.67 .747 .908 r
.71549 .40322 .72264 .4122 .7382 .40707 .73111 .39797 Mtetra
.667 .744 .908 r
.73111 .39797 .7382 .40707 .75386 .40201 .74682 .39282 Mtetra
.665 .743 .908 r
.74682 .39282 .75386 .40201 .7696 .39697 .76262 .3877 Mtetra
.664 .742 .908 r
.76262 .3877 .7696 .39697 .78543 .39192 .77851 .38259 Mtetra
.77851 .38259 .78543 .39192 .80135 .38686 .7945 .37748 Mtetra
.7945 .37748 .80135 .38686 .81736 .38178 .81057 .37234 Mtetra
.664 .741 .908 r
.81057 .37234 .81736 .38178 .83346 .37667 .82673 .36718 Mtetra
.82673 .36718 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85933 .35678 Mtetra
.85933 .35678 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .762 .934 r
.30182 .7277 .31101 .73516 .32537 .73113 .31623 .72363 Mtetra
.31623 .72363 .32537 .73113 .3398 .72707 .33071 .71954 Mtetra
.33071 .71954 .3398 .72707 .35432 .72299 .34528 .71542 Mtetra
.646 .763 .934 r
.34528 .71542 .35432 .72299 .36892 .71889 .35992 .71128 Mtetra
.35992 .71128 .36892 .71889 .3836 .71474 .37465 .7071 Mtetra
.647 .763 .934 r
.37465 .7071 .3836 .71474 .39835 .71055 .38946 .70288 Mtetra
.648 .764 .933 r
.38946 .70288 .39835 .71055 .4132 .70629 .40435 .69861 Mtetra
.65 .765 .933 r
.40435 .69861 .4132 .70629 .42812 .70192 .41933 .69424 Mtetra
.653 .767 .933 r
.41933 .69424 .42812 .70192 .44313 .69736 .43439 .68974 Mtetra
.659 .771 .932 r
.43439 .68974 .44313 .69736 .45823 .69246 .44954 .68497 Mtetra
.671 .779 .931 r
.44954 .68497 .45823 .69246 .47341 .68695 .46478 .67975 Mtetra
.692 .792 .927 r
.46478 .67975 .47341 .68695 .48868 .6803 .4801 .67369 Mtetra
.727 .815 .919 r
.4801 .67369 .48868 .6803 .50403 .67162 .49551 .6661 Mtetra
.783 .849 .901 r
.49551 .6661 .50403 .67162 .51943 .65944 .51099 .65582 Mtetra
.855 .89 .862 r
.51099 .65582 .51943 .65944 .53483 .64168 .5265 .64104 Mtetra
.925 .922 .79 r
.5265 .64104 .53483 .64168 .55014 .61623 .54198 .61953 Mtetra
.966 .93 .696 r
.54198 .61953 .55014 .61623 .56526 .58271 .5573 .58974 Mtetra
.974 .922 .613 r
.5573 .58974 .56526 .58271 .58011 .54439 .57239 .55299 Mtetra
.966 .917 .576 r
.57239 .55299 .58011 .54439 .59478 .50757 .58723 .51442 Mtetra
.962 .932 .608 r
.58723 .51442 .59478 .50757 .60941 .47748 .60196 .48038 Mtetra
.953 .952 .705 r
.60196 .48038 .60941 .47748 .62413 .45552 .61671 .45429 Mtetra
.91 .941 .815 r
.61671 .45429 .62413 .45552 .639 .44023 .6316 .43583 Mtetra
.835 .89 .88 r
.6316 .43583 .639 .44023 .65404 .4294 .64666 .42295 Mtetra
.767 .834 .903 r
.64666 .42295 .65404 .4294 .66923 .42123 .66187 .41356 Mtetra
.722 .794 .909 r
.66187 .41356 .66923 .42123 .68454 .41455 .67722 .40618 Mtetra
.695 .77 .91 r
.67722 .40618 .68454 .41455 .69996 .40868 .69269 .3999 Mtetra
.68 .757 .909 r
.69269 .3999 .69996 .40868 .71549 .40322 .70826 .3942 Mtetra
.672 .75 .909 r
.70826 .3942 .71549 .40322 .73111 .39797 .72394 .3888 Mtetra
.668 .746 .908 r
.72394 .3888 .73111 .39797 .74682 .39282 .73971 .38355 Mtetra
.666 .744 .908 r
.73971 .38355 .74682 .39282 .76262 .3877 .75557 .37835 Mtetra
.665 .743 .908 r
.75557 .37835 .76262 .3877 .77851 .38259 .77152 .37318 Mtetra
.664 .742 .908 r
.77152 .37318 .77851 .38259 .7945 .37748 .78757 .368 Mtetra
.78757 .368 .7945 .37748 .81057 .37234 .8037 .3628 Mtetra
.664 .741 .908 r
.8037 .3628 .81057 .37234 .82673 .36718 .81993 .35759 Mtetra
.81993 .35759 .82673 .36718 .84298 .36199 .83625 .35234 Mtetra
.83625 .35234 .84298 .36199 .85933 .35678 .85266 .34708 Mtetra
.85266 .34708 .85933 .35678 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .762 .934 r
.29254 .72018 .30182 .7277 .31623 .72363 .30699 .71607 Mtetra
.30699 .71607 .31623 .72363 .33071 .71954 .32153 .71193 Mtetra
.32153 .71193 .33071 .71954 .34528 .71542 .33614 .70777 Mtetra
.646 .763 .934 r
.33614 .70777 .34528 .71542 .35992 .71128 .35084 .70359 Mtetra
.35084 .70359 .35992 .71128 .37465 .7071 .36562 .69937 Mtetra
.647 .763 .934 r
.36562 .69937 .37465 .7071 .38946 .70288 .38048 .69512 Mtetra
.38048 .69512 .38946 .70288 .40435 .69861 .39542 .69082 Mtetra
.649 .764 .933 r
.39542 .69082 .40435 .69861 .41933 .69424 .41045 .68645 Mtetra
.651 .766 .933 r
.41045 .68645 .41933 .69424 .43439 .68974 .42556 .68197 Mtetra
.656 .769 .933 r
.42556 .68197 .43439 .68974 .44954 .68497 .44076 .6773 Mtetra
.664 .774 .931 r
.44076 .6773 .44954 .68497 .46478 .67975 .45605 .67228 Mtetra
.68 .785 .929 r
.45605 .67228 .46478 .67975 .4801 .67369 .47143 .66664 Mtetra
.707 .802 .924 r
.47143 .66664 .4801 .67369 .49551 .6661 .4869 .65986 Mtetra
.752 .831 .912 r
.4869 .65986 .49551 .6661 .51099 .65582 .50245 .65103 Mtetra
.817 .87 .885 r
.50245 .65103 .51099 .65582 .5265 .64104 .51805 .63868 Mtetra
.892 .909 .83 r
.51805 .63868 .5265 .64104 .54198 .61953 .53366 .6207 Mtetra
.95 .93 .744 r
.53366 .6207 .54198 .61953 .5573 .58974 .54918 .59499 Mtetra
.973 .927 .651 r
.54918 .59499 .5573 .58974 .57239 .55299 .5645 .56114 Mtetra
.971 .918 .587 r
.5645 .56114 .57239 .55299 .58723 .51442 .57956 .52248 Mtetra
.963 .922 .582 r
.57956 .52248 .58723 .51442 .60196 .48038 .59442 .48533 Mtetra
.96 .943 .651 r
.59442 .48533 .60196 .48038 .61671 .45429 .60924 .45496 Mtetra
.937 .953 .763 r
.60924 .45496 .61671 .45429 .6316 .43583 .62415 .43278 Mtetra
.874 .918 .854 r
.62415 .43278 .6316 .43583 .64666 .42295 .63922 .4173 Mtetra
.799 .86 .895 r
.63922 .4173 .64666 .42295 .66187 .41356 .65445 .40631 Mtetra
.742 .812 .907 r
.65445 .40631 .66187 .41356 .67722 .40618 .66983 .398 Mtetra
.706 .781 .91 r
.66983 .398 .67722 .40618 .69269 .3999 .68534 .39118 Mtetra
.687 .763 .909 r
.68534 .39118 .69269 .3999 .70826 .3942 .70097 .38517 Mtetra
.676 .753 .909 r
.70097 .38517 .70826 .3942 .72394 .3888 .7167 .37958 Mtetra
.67 .747 .908 r
.7167 .37958 .72394 .3888 .73971 .38355 .73252 .3742 Mtetra
.667 .744 .908 r
.73252 .3742 .73971 .38355 .75557 .37835 .74845 .36892 Mtetra
.665 .743 .908 r
.74845 .36892 .75557 .37835 .77152 .37318 .76446 .36367 Mtetra
.664 .742 .908 r
.76446 .36367 .77152 .37318 .78757 .368 .78057 .35842 Mtetra
.78057 .35842 .78757 .368 .8037 .3628 .79677 .35317 Mtetra
.79677 .35317 .8037 .3628 .81993 .35759 .81306 .3479 Mtetra
.664 .741 .908 r
.81306 .3479 .81993 .35759 .83625 .35234 .82944 .3426 Mtetra
.82944 .3426 .83625 .35234 .85266 .34708 .84592 .33727 Mtetra
.84592 .33727 .85266 .34708 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72018 .30699 .71607 .29767 .70842 Mtetra
.29767 .70842 .30699 .71607 .32153 .71193 .31225 .70424 Mtetra
.31225 .70424 .32153 .71193 .33614 .70777 .32691 .70004 Mtetra
.32691 .70004 .33614 .70777 .35084 .70359 .34166 .69582 Mtetra
.646 .763 .934 r
.34166 .69582 .35084 .70359 .36562 .69937 .35649 .69156 Mtetra
.35649 .69156 .36562 .69937 .38048 .69512 .3714 .68728 Mtetra
.647 .763 .934 r
.3714 .68728 .38048 .69512 .39542 .69082 .38639 .68295 Mtetra
.648 .764 .933 r
.38639 .68295 .39542 .69082 .41045 .68645 .40147 .67856 Mtetra
.65 .765 .933 r
.40147 .67856 .41045 .68645 .42556 .68197 .41664 .67408 Mtetra
.653 .767 .933 r
.41664 .67408 .42556 .68197 .44076 .6773 .43189 .66946 Mtetra
.659 .771 .932 r
.43189 .66946 .44076 .6773 .45605 .67228 .44724 .66458 Mtetra
.671 .779 .931 r
.44724 .66458 .45605 .67228 .47143 .66664 .46267 .65924 Mtetra
.692 .792 .927 r
.46267 .65924 .47143 .66664 .4869 .65986 .4782 .65304 Mtetra
.727 .815 .919 r
.4782 .65304 .4869 .65986 .50245 .65103 .49381 .64532 Mtetra
.783 .849 .901 r
.49381 .64532 .50245 .65103 .51805 .63868 .50949 .63487 Mtetra
.855 .89 .862 r
.50949 .63487 .51805 .63868 .53366 .6207 .52521 .6199 Mtetra
.925 .922 .79 r
.52521 .6199 .53366 .6207 .54918 .59499 .5409 .59814 Mtetra
.966 .931 .696 r
.5409 .59814 .54918 .59499 .5645 .56114 .55643 .56806 Mtetra
.974 .922 .613 r
.55643 .56806 .5645 .56114 .57956 .52248 .57173 .53096 Mtetra
.966 .917 .576 r
.57173 .53096 .57956 .52248 .59442 .48533 .58677 .49206 Mtetra
.962 .932 .608 r
.58677 .49206 .59442 .48533 .60924 .45496 .60169 .45771 Mtetra
.953 .952 .706 r
.60169 .45771 .60924 .45496 .62415 .43278 .61664 .43136 Mtetra
.909 .94 .815 r
.61664 .43136 .62415 .43278 .63922 .4173 .63172 .4127 Mtetra
.835 .889 .88 r
.63172 .4127 .63922 .4173 .65445 .40631 .64697 .39964 Mtetra
.767 .834 .903 r
.64697 .39964 .65445 .40631 .66983 .398 .66238 .3901 Mtetra
.722 .794 .909 r
.66238 .3901 .66983 .398 .68534 .39118 .67793 .38258 Mtetra
.695 .77 .91 r
.67793 .38258 .68534 .39118 .70097 .38517 .6936 .37616 Mtetra
.68 .757 .909 r
.6936 .37616 .70097 .38517 .7167 .37958 .70938 .37033 Mtetra
.672 .75 .909 r
.70938 .37033 .7167 .37958 .73252 .3742 .72527 .36479 Mtetra
.668 .746 .908 r
.72527 .36479 .73252 .3742 .74845 .36892 .74125 .3594 Mtetra
.666 .744 .908 r
.74125 .3594 .74845 .36892 .76446 .36367 .75733 .35407 Mtetra
.665 .743 .908 r
.75733 .35407 .76446 .36367 .78057 .35842 .7735 .34876 Mtetra
.664 .742 .908 r
.7735 .34876 .78057 .35842 .79677 .35317 .78976 .34344 Mtetra
.78976 .34344 .79677 .35317 .81306 .3479 .80611 .33811 Mtetra
.664 .741 .908 r
.80611 .33811 .81306 .3479 .82944 .3426 .82256 .33275 Mtetra
.82256 .33275 .82944 .3426 .84592 .33727 .83911 .32737 Mtetra
.83911 .32737 .84592 .33727 .86249 .33192 .85575 .32195 Mtetra
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70842 .28825 .7007 Mtetra
.28825 .7007 .29767 .70842 .31225 .70424 .30288 .69648 Mtetra
.30288 .69648 .31225 .70424 .32691 .70004 .31759 .69224 Mtetra
.31759 .69224 .32691 .70004 .34166 .69582 .33239 .68797 Mtetra
.646 .763 .934 r
.33239 .68797 .34166 .69582 .35649 .69156 .34726 .68367 Mtetra
.34726 .68367 .35649 .69156 .3714 .68728 .36223 .67934 Mtetra
.647 .763 .934 r
.36223 .67934 .3714 .68728 .38639 .68295 .37727 .67498 Mtetra
.37727 .67498 .38639 .68295 .40147 .67856 .39241 .67057 Mtetra
.649 .764 .933 r
.39241 .67057 .40147 .67856 .41664 .67408 .40763 .66608 Mtetra
.651 .766 .933 r
.40763 .66608 .41664 .67408 .43189 .66946 .42293 .66148 Mtetra
.656 .769 .933 r
.42293 .66148 .43189 .66946 .44724 .66458 .43833 .65669 Mtetra
.664 .774 .931 r
.43833 .65669 .44724 .66458 .46267 .65924 .45382 .65155 Mtetra
.68 .785 .929 r
.45382 .65155 .46267 .65924 .4782 .65304 .4694 .64578 Mtetra
.707 .802 .924 r
.4694 .64578 .4782 .65304 .49381 .64532 .48507 .63887 Mtetra
.752 .831 .912 r
.48507 .63887 .49381 .64532 .50949 .63487 .50083 .62989 Mtetra
.818 .87 .885 r
.50083 .62989 .50949 .63487 .52521 .6199 .51664 .61736 Mtetra
.892 .909 .83 r
.51664 .61736 .52521 .6199 .5409 .59814 .53246 .59916 Mtetra
.95 .93 .744 r
.53246 .59916 .5409 .59814 .55643 .56806 .54819 .57318 Mtetra
.973 .927 .65 r
.54819 .57318 .55643 .56806 .57173 .53096 .56372 .539 Mtetra
.971 .918 .587 r
.56372 .539 .57173 .53096 .58677 .49206 .57899 .49999 Mtetra
.963 .922 .583 r
.57899 .49999 .58677 .49206 .60169 .45771 .59405 .46251 Mtetra
.96 .943 .651 r
.59405 .46251 .60169 .45771 .61664 .43136 .60906 .43186 Mtetra
.937 .952 .764 r
.60906 .43186 .61664 .43136 .63172 .4127 .62417 .40944 Mtetra
.874 .918 .854 r
.62417 .40944 .63172 .4127 .64697 .39964 .63943 .39377 Mtetra
.799 .86 .895 r
.63943 .39377 .64697 .39964 .66238 .3901 .65487 .38262 Mtetra
.742 .812 .907 r
.65487 .38262 .66238 .3901 .67793 .38258 .67045 .37416 Mtetra
.706 .781 .91 r
.67045 .37416 .67793 .38258 .6936 .37616 .68617 .3672 Mtetra
.687 .763 .909 r
.68617 .3672 .6936 .37616 .70938 .37033 .702 .36105 Mtetra
.676 .753 .909 r
.702 .36105 .70938 .37033 .72527 .36479 .71794 .35532 Mtetra
.67 .747 .908 r
.71794 .35532 .72527 .36479 .74125 .3594 .73398 .3498 Mtetra
.667 .744 .908 r
.73398 .3498 .74125 .3594 .75733 .35407 .75012 .34438 Mtetra
.665 .743 .908 r
.75012 .34438 .75733 .35407 .7735 .34876 .76635 .33899 Mtetra
.664 .742 .908 r
.76635 .33899 .7735 .34876 .78976 .34344 .78268 .33361 Mtetra
.78268 .33361 .78976 .34344 .80611 .33811 .7991 .32821 Mtetra
.7991 .32821 .80611 .33811 .82256 .33275 .81561 .3228 Mtetra
.664 .741 .908 r
.81561 .3228 .82256 .33275 .83911 .32737 .83223 .31736 Mtetra
.83223 .31736 .83911 .32737 .85575 .32195 .84893 .31189 Mtetra
.84893 .31189 .85575 .32195 .87248 .31651 .86574 .30639 Mtetra
.86574 .30639 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .7007 .27873 .69289 Mtetra
.27873 .69289 .28825 .7007 .30288 .69648 .29341 .68863 Mtetra
.29341 .68863 .30288 .69648 .31759 .69224 .30817 .68434 Mtetra
.30817 .68434 .31759 .69224 .33239 .68797 .32302 .68003 Mtetra
.32302 .68003 .33239 .68797 .34726 .68367 .33794 .67569 Mtetra
.646 .763 .934 r
.33794 .67569 .34726 .68367 .36223 .67934 .35296 .67133 Mtetra
.35296 .67133 .36223 .67934 .37727 .67498 .36806 .66693 Mtetra
.647 .763 .934 r
.36806 .66693 .37727 .67498 .39241 .67057 .38324 .66248 Mtetra
.648 .764 .933 r
.38324 .66248 .39241 .67057 .40763 .66608 .39852 .65798 Mtetra
.65 .765 .933 r
.39852 .65798 .40763 .66608 .42293 .66148 .41388 .65338 Mtetra
.653 .767 .933 r
.41388 .65338 .42293 .66148 .43833 .65669 .42933 .64864 Mtetra
.659 .771 .932 r
.42933 .64864 .43833 .65669 .45382 .65155 .44487 .64364 Mtetra
.671 .779 .931 r
.44487 .64364 .45382 .65155 .4694 .64578 .46051 .63817 Mtetra
.692 .792 .927 r
.46051 .63817 .4694 .64578 .48507 .63887 .47624 .63184 Mtetra
.727 .815 .92 r
.47624 .63184 .48507 .63887 .50083 .62989 .49206 .62397 Mtetra
.783 .85 .901 r
.49206 .62397 .50083 .62989 .51664 .61736 .50796 .61336 Mtetra
.855 .891 .862 r
.50796 .61336 .51664 .61736 .53246 .59916 .52389 .59818 Mtetra
.925 .923 .79 r
.52389 .59818 .53246 .59916 .54819 .57318 .53979 .57618 Mtetra
.966 .931 .696 r
.53979 .57618 .54819 .57318 .56372 .539 .55554 .54579 Mtetra
.974 .922 .612 r
.55554 .54579 .56372 .539 .57899 .49999 .57104 .50835 Mtetra
.966 .917 .576 r
.57104 .50835 .57899 .49999 .59405 .46251 .58629 .4691 Mtetra
.962 .932 .608 r
.58629 .4691 .59405 .46251 .60906 .43186 .60141 .43444 Mtetra
.953 .952 .706 r
.60141 .43444 .60906 .43186 .62417 .40944 .61656 .40783 Mtetra
.909 .94 .815 r
.61656 .40783 .62417 .40944 .63943 .39377 .63184 .38896 Mtetra
.835 .889 .88 r
.63184 .38896 .63943 .39377 .65487 .38262 .64729 .37572 Mtetra
.767 .834 .903 r
.64729 .37572 .65487 .38262 .67045 .37416 .6629 .36602 Mtetra
.722 .794 .909 r
.6629 .36602 .67045 .37416 .68617 .3672 .67866 .35835 Mtetra
.695 .77 .91 r
.67866 .35835 .68617 .3672 .702 .36105 .69454 .35179 Mtetra
.68 .757 .909 r
.69454 .35179 .702 .36105 .71794 .35532 .71054 .34581 Mtetra
.672 .75 .909 r
.71054 .34581 .71794 .35532 .73398 .3498 .72663 .34014 Mtetra
.668 .746 .908 r
.72663 .34014 .73398 .3498 .75012 .34438 .74283 .33461 Mtetra
.666 .744 .908 r
.74283 .33461 .75012 .34438 .76635 .33899 .75913 .32913 Mtetra
.665 .743 .908 r
.75913 .32913 .76635 .33899 .78268 .33361 .77552 .32368 Mtetra
.664 .742 .908 r
.77552 .32368 .78268 .33361 .7991 .32821 .79201 .31822 Mtetra
.79201 .31822 .7991 .32821 .81561 .3228 .80859 .31274 Mtetra
.664 .741 .908 r
.80859 .31274 .81561 .3228 .83223 .31736 .82527 .30724 Mtetra
.82527 .30724 .83223 .31736 .84893 .31189 .84205 .30171 Mtetra
.84205 .30171 .84893 .31189 .86574 .30639 .85892 .29615 Mtetra
.85892 .29615 .86574 .30639 .88264 .30085 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .68501 Mtetra
.26911 .68501 .27873 .69289 .29341 .68863 .28384 .6807 Mtetra
.28384 .6807 .29341 .68863 .30817 .68434 .29865 .67637 Mtetra
.29865 .67637 .30817 .68434 .32302 .68003 .31355 .67202 Mtetra
.31355 .67202 .32302 .68003 .33794 .67569 .32853 .66763 Mtetra
.646 .763 .934 r
.32853 .66763 .33794 .67569 .35296 .67133 .34359 .66322 Mtetra
.34359 .66322 .35296 .67133 .36806 .66693 .35875 .65878 Mtetra
.647 .763 .934 r
.35875 .65878 .36806 .66693 .38324 .66248 .37398 .6543 Mtetra
.37398 .6543 .38324 .66248 .39852 .65798 .38931 .64977 Mtetra
.649 .764 .933 r
.38931 .64977 .39852 .65798 .41388 .65338 .40473 .64516 Mtetra
.651 .766 .933 r
.40473 .64516 .41388 .65338 .42933 .64864 .42023 .64044 Mtetra
.656 .769 .933 r
.42023 .64044 .42933 .64864 .44487 .64364 .43583 .63553 Mtetra
.664 .774 .931 r
.43583 .63553 .44487 .64364 .46051 .63817 .45153 .63026 Mtetra
.68 .785 .929 r
.45153 .63026 .46051 .63817 .47624 .63184 .46731 .62436 Mtetra
.707 .802 .924 r
.46731 .62436 .47624 .63184 .49206 .62397 .4832 .6173 Mtetra
.752 .831 .912 r
.4832 .6173 .49206 .62397 .50796 .61336 .49916 .60817 Mtetra
.818 .87 .885 r
.49916 .60817 .50796 .61336 .52389 .59818 .51519 .59545 Mtetra
.892 .909 .83 r
.51519 .59545 .52389 .59818 .53979 .57618 .53123 .57703 Mtetra
.95 .93 .744 r
.53123 .57703 .53979 .57618 .55554 .54579 .54718 .55077 Mtetra
.973 .927 .65 r
.54718 .55077 .55554 .54579 .57104 .50835 .56293 .51626 Mtetra
.971 .918 .586 r
.56293 .51626 .57104 .50835 .58629 .4691 .5784 .4769 Mtetra
.963 .922 .583 r
.5784 .4769 .58629 .4691 .60141 .43444 .59367 .43908 Mtetra
.96 .943 .651 r
.59367 .43908 .60141 .43444 .61656 .40783 .60888 .40814 Mtetra
.937 .952 .764 r
.60888 .40814 .61656 .40783 .63184 .38896 .62419 .38549 Mtetra
.874 .917 .854 r
.62419 .38549 .63184 .38896 .64729 .37572 .63966 .36962 Mtetra
.799 .86 .895 r
.63966 .36962 .64729 .37572 .6629 .36602 .65529 .3583 Mtetra
.742 .812 .907 r
.65529 .3583 .6629 .36602 .67866 .35835 .67109 .34968 Mtetra
.706 .781 .909 r
.67109 .34968 .67866 .35835 .69454 .35179 .68701 .34258 Mtetra
.687 .763 .909 r
.68701 .34258 .69454 .35179 .71054 .34581 .70306 .33629 Mtetra
.676 .753 .909 r
.70306 .33629 .71054 .34581 .72663 .34014 .71921 .33041 Mtetra
.67 .747 .908 r
.71921 .33041 .72663 .34014 .74283 .33461 .73547 .32475 Mtetra
.667 .744 .908 r
.73547 .32475 .74283 .33461 .75913 .32913 .75183 .31918 Mtetra
.665 .743 .908 r
.75183 .31918 .75913 .32913 .77552 .32368 .76829 .31365 Mtetra
.664 .742 .908 r
.76829 .31365 .77552 .32368 .79201 .31822 .78484 .30812 Mtetra
.78484 .30812 .79201 .31822 .80859 .31274 .80149 .30258 Mtetra
.80149 .30258 .80859 .31274 .82527 .30724 .81824 .29702 Mtetra
.664 .741 .908 r
.81824 .29702 .82527 .30724 .84205 .30171 .83509 .29143 Mtetra
.83509 .29143 .84205 .30171 .85892 .29615 .85203 .28581 Mtetra
.85203 .28581 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .68501 .25939 .67704 Mtetra
.25939 .67704 .26911 .68501 .28384 .6807 .27417 .67269 Mtetra
.27417 .67269 .28384 .6807 .29865 .67637 .28903 .66832 Mtetra
.28903 .66832 .29865 .67637 .31355 .67202 .30398 .66391 Mtetra
.30398 .66391 .31355 .67202 .32853 .66763 .31901 .65949 Mtetra
.31901 .65949 .32853 .66763 .34359 .66322 .33413 .65503 Mtetra
.646 .763 .934 r
.33413 .65503 .34359 .66322 .35875 .65878 .34934 .65055 Mtetra
.34934 .65055 .35875 .65878 .37398 .6543 .36463 .64603 Mtetra
.647 .763 .934 r
.36463 .64603 .37398 .6543 .38931 .64977 .38001 .64146 Mtetra
.648 .764 .933 r
.38001 .64146 .38931 .64977 .40473 .64516 .39548 .63684 Mtetra
.65 .765 .933 r
.39548 .63684 .40473 .64516 .42023 .64044 .41104 .63212 Mtetra
.653 .767 .933 r
.41104 .63212 .42023 .64044 .43583 .63553 .4267 .62725 Mtetra
.659 .771 .932 r
.4267 .62725 .43583 .63553 .45153 .63026 .44245 .62212 Mtetra
.671 .779 .931 r
.44245 .62212 .45153 .63026 .46731 .62436 .45829 .61652 Mtetra
.692 .792 .927 r
.45829 .61652 .46731 .62436 .4832 .6173 .47423 .61005 Mtetra
.727 .815 .92 r
.47423 .61005 .4832 .6173 .49916 .60817 .49027 .60203 Mtetra
.783 .85 .902 r
.49027 .60203 .49916 .60817 .51519 .59545 .50638 .59125 Mtetra
.855 .891 .862 r
.50638 .59125 .51519 .59545 .53123 .57703 .52253 .57587 Mtetra
.925 .923 .79 r
.52253 .57587 .53123 .57703 .54718 .55077 .53865 .55361 Mtetra
.966 .931 .695 r
.53865 .55361 .54718 .55077 .56293 .51626 .55462 .52292 Mtetra
.974 .922 .612 r
.55462 .52292 .56293 .51626 .5784 .4769 .57034 .48512 Mtetra
.966 .917 .576 r
.57034 .48512 .5784 .4769 .59367 .43908 .58581 .44551 Mtetra
.962 .932 .609 r
.58581 .44551 .59367 .43908 .60888 .40814 .60113 .41054 Mtetra
.953 .952 .706 r
.60113 .41054 .60888 .40814 .62419 .38549 .61648 .38367 Mtetra
.909 .94 .815 r
.61648 .38367 .62419 .38549 .63966 .36962 .63196 .36458 Mtetra
.835 .889 .879 r
.63196 .36458 .63966 .36962 .65529 .3583 .64762 .35116 Mtetra
.767 .834 .903 r
.64762 .35116 .65529 .3583 .67109 .34968 .66344 .3413 Mtetra
.722 .794 .909 r
.66344 .3413 .67109 .34968 .68701 .34258 .67941 .33347 Mtetra
.695 .77 .91 r
.67941 .33347 .68701 .34258 .70306 .33629 .69551 .32676 Mtetra
.68 .757 .909 r
.69551 .32676 .70306 .33629 .71921 .33041 .71172 .32064 Mtetra
.672 .75 .909 r
.71172 .32064 .71921 .33041 .73547 .32475 .72804 .31482 Mtetra
.668 .746 .908 r
.72804 .31482 .73547 .32475 .75183 .31918 .74446 .30914 Mtetra
.666 .744 .908 r
.74446 .30914 .75183 .31918 .76829 .31365 .76098 .30352 Mtetra
.665 .743 .908 r
.76098 .30352 .76829 .31365 .78484 .30812 .7776 .29792 Mtetra
.664 .742 .908 r
.7776 .29792 .78484 .30812 .80149 .30258 .79432 .29231 Mtetra
.79432 .29231 .80149 .30258 .81824 .29702 .81114 .28669 Mtetra
.664 .741 .908 r
.81114 .28669 .81824 .29702 .83509 .29143 .82805 .28103 Mtetra
.82805 .28103 .83509 .29143 .85203 .28581 .84507 .27535 Mtetra
.84507 .27535 .85203 .28581 .86907 .28015 .86218 .26963 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .6646 Mtetra
.2644 .6646 .27417 .67269 .28903 .66832 .27932 .66017 Mtetra
.27932 .66017 .28903 .66832 .30398 .66391 .29431 .65573 Mtetra
.29431 .65573 .30398 .66391 .31901 .65949 .3094 .65125 Mtetra
.3094 .65125 .31901 .65949 .33413 .65503 .32457 .64675 Mtetra
.646 .763 .934 r
.32457 .64675 .33413 .65503 .34934 .65055 .33983 .64222 Mtetra
.33983 .64222 .34934 .65055 .36463 .64603 .35517 .63766 Mtetra
.647 .763 .934 r
.35517 .63766 .36463 .64603 .38001 .64146 .37061 .63306 Mtetra
.37061 .63306 .38001 .64146 .39548 .63684 .38613 .6284 Mtetra
.649 .764 .933 r
.38613 .6284 .39548 .63684 .41104 .63212 .40175 .62367 Mtetra
.651 .766 .933 r
.40175 .62367 .41104 .63212 .4267 .62725 .41746 .61883 Mtetra
.656 .769 .933 r
.41746 .61883 .4267 .62725 .44245 .62212 .43327 .61378 Mtetra
.664 .774 .931 r
.43327 .61378 .44245 .62212 .45829 .61652 .44917 .60838 Mtetra
.68 .785 .929 r
.44917 .60838 .45829 .61652 .47423 .61005 .46517 .60234 Mtetra
.707 .802 .924 r
.46517 .60234 .47423 .61005 .49027 .60203 .48127 .59514 Mtetra
.752 .831 .912 r
.48127 .59514 .49027 .60203 .50638 .59125 .49745 .58584 Mtetra
.818 .87 .885 r
.49745 .58584 .50638 .59125 .52253 .57587 .5137 .57294 Mtetra
.892 .909 .83 r
.5137 .57294 .52253 .57587 .53865 .55361 .52996 .55429 Mtetra
.95 .93 .744 r
.52996 .55429 .53865 .55361 .55462 .52292 .54614 .52774 Mtetra
.973 .927 .65 r
.54614 .52774 .55462 .52292 .57034 .48512 .56211 .4929 Mtetra
.97 .918 .586 r
.56211 .4929 .57034 .48512 .58581 .44551 .5778 .45317 Mtetra
.964 .922 .583 r
.5778 .45317 .58581 .44551 .60113 .41054 .59328 .41502 Mtetra
.96 .943 .652 r
.59328 .41502 .60113 .41054 .61648 .38367 .6087 .38378 Mtetra
.937 .952 .764 r
.6087 .38378 .61648 .38367 .63196 .36458 .62421 .36089 Mtetra
.874 .917 .854 r
.62421 .36089 .63196 .36458 .64762 .35116 .63989 .34483 Mtetra
.799 .86 .895 r
.63989 .34483 .64762 .35116 .66344 .3413 .65573 .33333 Mtetra
.742 .812 .907 r
.65573 .33333 .66344 .3413 .67941 .33347 .67174 .32455 Mtetra
.706 .781 .909 r
.67174 .32455 .67941 .33347 .69551 .32676 .68788 .31729 Mtetra
.687 .763 .909 r
.68788 .31729 .69551 .32676 .71172 .32064 .70415 .31085 Mtetra
.676 .753 .909 r
.70415 .31085 .71172 .32064 .72804 .31482 .72052 .30483 Mtetra
.67 .747 .908 r
.72052 .30483 .72804 .31482 .74446 .30914 .73701 .29902 Mtetra
.667 .744 .908 r
.73701 .29902 .74446 .30914 .76098 .30352 .75359 .2933 Mtetra
.665 .743 .908 r
.75359 .2933 .76098 .30352 .7776 .29792 .77028 .28762 Mtetra
.664 .742 .908 r
.77028 .28762 .7776 .29792 .79432 .29231 .78707 .28194 Mtetra
.78707 .28194 .79432 .29231 .81114 .28669 .80395 .27624 Mtetra
.80395 .27624 .81114 .28669 .82805 .28103 .82094 .27053 Mtetra
.664 .741 .908 r
.82094 .27053 .82805 .28103 .84507 .27535 .83803 .26478 Mtetra
.83803 .26478 .84507 .27535 .86218 .26963 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .6646 .25453 .65642 Mtetra
.25453 .65642 .2644 .6646 .27932 .66017 .2695 .65195 Mtetra
.2695 .65195 .27932 .66017 .29431 .65573 .28454 .64745 Mtetra
.28454 .64745 .29431 .65573 .3094 .65125 .29968 .64293 Mtetra
.29968 .64293 .3094 .65125 .32457 .64675 .3149 .63839 Mtetra
.3149 .63839 .32457 .64675 .33983 .64222 .33021 .63381 Mtetra
.646 .763 .934 r
.33021 .63381 .33983 .64222 .35517 .63766 .34561 .6292 Mtetra
.34561 .6292 .35517 .63766 .37061 .63306 .3611 .62456 Mtetra
.647 .763 .934 r
.3611 .62456 .37061 .63306 .38613 .6284 .37669 .61987 Mtetra
.648 .764 .933 r
.37669 .61987 .38613 .6284 .40175 .62367 .39236 .61511 Mtetra
.65 .765 .933 r
.39236 .61511 .40175 .62367 .41746 .61883 .40813 .61027 Mtetra
.653 .767 .933 r
.40813 .61027 .41746 .61883 .43327 .61378 .42399 .60527 Mtetra
.659 .771 .932 r
.42399 .60527 .43327 .61378 .44917 .60838 .43995 .60001 Mtetra
.671 .779 .931 r
.43995 .60001 .44917 .60838 .46517 .60234 .45601 .59427 Mtetra
.692 .792 .927 r
.45601 .59427 .46517 .60234 .48127 .59514 .47217 .58766 Mtetra
.727 .815 .92 r
.47217 .58766 .48127 .59514 .49745 .58584 .48842 .57948 Mtetra
.783 .85 .902 r
.48842 .57948 .49745 .58584 .5137 .57294 .50476 .56852 Mtetra
.855 .891 .862 r
.50476 .56852 .5137 .57294 .52996 .55429 .52113 .55293 Mtetra
.925 .923 .79 r
.52113 .55293 .52996 .55429 .54614 .52774 .53748 .53041 Mtetra
.966 .931 .695 r
.53748 .53041 .54614 .52774 .56211 .4929 .55368 .4994 Mtetra
.974 .922 .612 r
.55368 .4994 .56211 .4929 .5778 .45317 .56963 .46126 Mtetra
.966 .917 .576 r
.56963 .46126 .5778 .45317 .59328 .41502 .5853 .42129 Mtetra
.962 .932 .609 r
.5853 .42129 .59328 .41502 .6087 .38378 .60084 .386 Mtetra
.953 .952 .707 r
.60084 .386 .6087 .38378 .62421 .36089 .6164 .35886 Mtetra
.909 .94 .815 r
.6164 .35886 .62421 .36089 .63989 .34483 .63209 .33955 Mtetra
.835 .889 .879 r
.63209 .33955 .63989 .34483 .65573 .33333 .64796 .32594 Mtetra
.767 .834 .903 r
.64796 .32594 .65573 .33333 .67174 .32455 .664 .31591 Mtetra
.722 .794 .909 r
.664 .31591 .67174 .32455 .68788 .31729 .68018 .30792 Mtetra
.695 .77 .91 r
.68018 .30792 .68788 .31729 .70415 .31085 .6965 .30106 Mtetra
.68 .757 .909 r
.6965 .30106 .70415 .31085 .72052 .30483 .71293 .29479 Mtetra
.672 .75 .909 r
.71293 .29479 .72052 .30483 .73701 .29902 .72948 .28881 Mtetra
.668 .746 .908 r
.72948 .28881 .73701 .29902 .75359 .2933 .74613 .28298 Mtetra
.666 .744 .908 r
.74613 .28298 .75359 .2933 .77028 .28762 .76288 .27721 Mtetra
.665 .743 .908 r
.76288 .27721 .77028 .28762 .78707 .28194 .77974 .27145 Mtetra
.664 .742 .908 r
.77974 .27145 .78707 .28194 .80395 .27624 .79669 .26569 Mtetra
.79669 .26569 .80395 .27624 .82094 .27053 .81375 .25991 Mtetra
.664 .741 .908 r
.81375 .25991 .82094 .27053 .83803 .26478 .83091 .25409 Mtetra
.83091 .25409 .83803 .26478 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65642 .24456 .64815 Mtetra
.24456 .64815 .25453 .65642 .2695 .65195 .25957 .64363 Mtetra
.25957 .64363 .2695 .65195 .28454 .64745 .27467 .63909 Mtetra
.27467 .63909 .28454 .64745 .29968 .64293 .28986 .63452 Mtetra
.28986 .63452 .29968 .64293 .3149 .63839 .30513 .62993 Mtetra
.30513 .62993 .3149 .63839 .33021 .63381 .3205 .6253 Mtetra
.646 .763 .934 r
.3205 .6253 .33021 .63381 .34561 .6292 .33595 .62065 Mtetra
.33595 .62065 .34561 .6292 .3611 .62456 .3515 .61596 Mtetra
.647 .763 .934 r
.3515 .61596 .3611 .62456 .37669 .61987 .36714 .61123 Mtetra
.36714 .61123 .37669 .61987 .39236 .61511 .38287 .60645 Mtetra
.649 .764 .933 r
.38287 .60645 .39236 .61511 .40813 .61027 .39869 .60159 Mtetra
.651 .766 .933 r
.39869 .60159 .40813 .61027 .42399 .60527 .41461 .59661 Mtetra
.656 .769 .933 r
.41461 .59661 .42399 .60527 .43995 .60001 .43063 .59143 Mtetra
.664 .774 .932 r
.43063 .59143 .43995 .60001 .45601 .59427 .44675 .58589 Mtetra
.68 .785 .929 r
.44675 .58589 .45601 .59427 .47217 .58766 .46296 .57971 Mtetra
.707 .803 .924 r
.46296 .57971 .47217 .58766 .48842 .57948 .47928 .57235 Mtetra
.752 .831 .913 r
.47928 .57235 .48842 .57948 .50476 .56852 .49569 .56289 Mtetra
.818 .87 .885 r
.49569 .56289 .50476 .56852 .52113 .55293 .51217 .54979 Mtetra
.893 .91 .83 r
.51217 .54979 .52113 .55293 .53748 .53041 .52866 .5309 Mtetra
.951 .93 .743 r
.52866 .5309 .53748 .53041 .55368 .4994 .54507 .50406 Mtetra
.973 .927 .65 r
.54507 .50406 .55368 .4994 .56963 .46126 .56127 .46888 Mtetra
.97 .918 .586 r
.56127 .46888 .56963 .46126 .5853 .42129 .57718 .42879 Mtetra
.964 .922 .583 r
.57718 .42879 .5853 .42129 .60084 .386 .59287 .39029 Mtetra
.96 .943 .652 r
.59287 .39029 .60084 .386 .6164 .35886 .60851 .35876 Mtetra
.937 .952 .764 r
.60851 .35876 .6164 .35886 .63209 .33955 .62423 .33563 Mtetra
.874 .917 .854 r
.62423 .33563 .63209 .33955 .64796 .32594 .64012 .31936 Mtetra
.799 .86 .895 r
.64012 .31936 .64796 .32594 .664 .31591 .65619 .30768 Mtetra
.742 .812 .907 r
.65619 .30768 .664 .31591 .68018 .30792 .67241 .29873 Mtetra
.707 .78 .909 r
.67241 .29873 .68018 .30792 .6965 .30106 .68877 .29131 Mtetra
.687 .763 .909 r
.68877 .29131 .6965 .30106 .71293 .29479 .70526 .28472 Mtetra
.676 .753 .909 r
.70526 .28472 .71293 .29479 .72948 .28881 .72187 .27854 Mtetra
.67 .747 .908 r
.72187 .27854 .72948 .28881 .74613 .28298 .73859 .27257 Mtetra
.667 .744 .908 r
.73859 .27257 .74613 .28298 .76288 .27721 .75541 .2667 Mtetra
.665 .743 .908 r
.75541 .2667 .76288 .27721 .77974 .27145 .77233 .26086 Mtetra
.664 .742 .908 r
.77233 .26086 .77974 .27145 .79669 .26569 .78935 .25502 Mtetra
.78935 .25502 .79669 .26569 .81375 .25991 .80648 .24917 Mtetra
.80648 .24917 .81375 .25991 .83091 .25409 .82371 .24329 Mtetra
.664 .741 .908 r
.82371 .24329 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63909 .26469 .63064 Mtetra
.26469 .63064 .27467 .63909 .28986 .63452 .27993 .62602 Mtetra
.27993 .62602 .28986 .63452 .30513 .62993 .29526 .62138 Mtetra
.29526 .62138 .30513 .62993 .3205 .6253 .31068 .6167 Mtetra
.31068 .6167 .3205 .6253 .33595 .62065 .32619 .612 Mtetra
.646 .763 .934 r
.32619 .612 .33595 .62065 .3515 .61596 .34179 .60726 Mtetra
.34179 .60726 .3515 .61596 .36714 .61123 .35748 .60249 Mtetra
.647 .763 .934 r
.35748 .60249 .36714 .61123 .38287 .60645 .37327 .59767 Mtetra
.648 .764 .933 r
.37327 .59767 .38287 .60645 .39869 .60159 .38915 .59279 Mtetra
.65 .765 .933 r
.38915 .59279 .39869 .60159 .41461 .59661 .40513 .58781 Mtetra
.653 .767 .933 r
.40513 .58781 .41461 .59661 .43063 .59143 .42121 .58268 Mtetra
.659 .771 .932 r
.42121 .58268 .43063 .59143 .44675 .58589 .43738 .57728 Mtetra
.671 .779 .931 r
.43738 .57728 .44675 .58589 .46296 .57971 .45366 .57139 Mtetra
.692 .792 .927 r
.45366 .57139 .46296 .57971 .47928 .57235 .47004 .56463 Mtetra
.727 .815 .92 r
.47004 .56463 .47928 .57235 .49569 .56289 .48652 .55629 Mtetra
.783 .85 .902 r
.48652 .55629 .49569 .56289 .51217 .54979 .50309 .54515 Mtetra
.855 .891 .862 r
.50309 .54515 .51217 .54979 .52866 .5309 .5197 .52934 Mtetra
.925 .923 .79 r
.5197 .52934 .52866 .5309 .54507 .50406 .53628 .50656 Mtetra
.966 .931 .695 r
.53628 .50656 .54507 .50406 .56127 .46888 .55271 .47523 Mtetra
.974 .922 .612 r
.55271 .47523 .56127 .46888 .57718 .42879 .56889 .43672 Mtetra
.966 .917 .576 r
.56889 .43672 .57718 .42879 .59287 .39029 .58479 .39639 Mtetra
.962 .932 .609 r
.58479 .39639 .59287 .39029 .60851 .35876 .60054 .36077 Mtetra
.953 .952 .707 r
.60054 .36077 .60851 .35876 .62423 .33563 .61631 .33337 Mtetra
.909 .939 .815 r
.61631 .33337 .62423 .33563 .64012 .31936 .63222 .31383 Mtetra
.835 .889 .879 r
.63222 .31383 .64012 .31936 .65619 .30768 .64831 .30003 Mtetra
.767 .833 .903 r
.64831 .30003 .65619 .30768 .67241 .29873 .66456 .28982 Mtetra
.722 .794 .909 r
.66456 .28982 .67241 .29873 .68877 .29131 .68097 .28167 Mtetra
.695 .77 .909 r
.68097 .28167 .68877 .29131 .70526 .28472 .69752 .27465 Mtetra
.68 .757 .909 r
.69752 .27465 .70526 .28472 .72187 .27854 .71418 .26821 Mtetra
.672 .75 .909 r
.71418 .26821 .72187 .27854 .73859 .27257 .73096 .26208 Mtetra
.668 .746 .908 r
.73096 .26208 .73859 .27257 .75541 .2667 .74785 .25609 Mtetra
.666 .744 .908 r
.74785 .25609 .75541 .2667 .77233 .26086 .76484 .25016 Mtetra
.665 .743 .908 r
.76484 .25016 .77233 .26086 .78935 .25502 .78194 .24425 Mtetra
.664 .742 .908 r
.78194 .24425 .78935 .25502 .80648 .24917 .79914 .23832 Mtetra
.79914 .23832 .80648 .24917 .82371 .24329 .81644 .23237 Mtetra
.664 .741 .908 r
.81644 .23237 .82371 .24329 .84105 .23738 .83385 .2264 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62674 Mtetra
.2394 .62674 .24954 .63523 .26469 .63064 .2546 .6221 Mtetra
.2546 .6221 .26469 .63064 .27993 .62602 .2699 .61743 Mtetra
.2699 .61743 .27993 .62602 .29526 .62138 .28528 .61273 Mtetra
.28528 .61273 .29526 .62138 .31068 .6167 .30075 .60801 Mtetra
.30075 .60801 .31068 .6167 .32619 .612 .31632 .60326 Mtetra
.646 .763 .934 r
.31632 .60326 .32619 .612 .34179 .60726 .33197 .59847 Mtetra
.33197 .59847 .34179 .60726 .35748 .60249 .34772 .59365 Mtetra
.647 .763 .934 r
.34772 .59365 .35748 .60249 .37327 .59767 .36357 .58879 Mtetra
.36357 .58879 .37327 .59767 .38915 .59279 .37951 .58388 Mtetra
.649 .764 .933 r
.37951 .58388 .38915 .59279 .40513 .58781 .39555 .57888 Mtetra
.651 .766 .933 r
.39555 .57888 .40513 .58781 .42121 .58268 .41168 .57377 Mtetra
.656 .769 .933 r
.41168 .57377 .42121 .58268 .43738 .57728 .42792 .56845 Mtetra
.664 .774 .932 r
.42792 .56845 .43738 .57728 .45366 .57139 .44426 .56277 Mtetra
.68 .785 .929 r
.44426 .56277 .45366 .57139 .47004 .56463 .4607 .55644 Mtetra
.707 .803 .924 r
.4607 .55644 .47004 .56463 .48652 .55629 .47724 .54892 Mtetra
.752 .831 .913 r
.47724 .54892 .48652 .55629 .50309 .54515 .49388 .53928 Mtetra
.818 .871 .885 r
.49388 .53928 .50309 .54515 .5197 .52934 .5106 .52598 Mtetra
.893 .91 .83 r
.5106 .52598 .5197 .52934 .53628 .50656 .52732 .50685 Mtetra
.951 .931 .743 r
.52732 .50685 .53628 .50656 .55271 .47523 .54397 .47972 Mtetra
.973 .927 .649 r
.54397 .47972 .55271 .47523 .56889 .43672 .5604 .44419 Mtetra
.97 .918 .586 r
.5604 .44419 .56889 .43672 .58479 .39639 .57655 .40373 Mtetra
.964 .922 .583 r
.57655 .40373 .58479 .39639 .60054 .36077 .59246 .36488 Mtetra
.96 .943 .653 r
.59246 .36488 .60054 .36077 .61631 .33337 .60831 .33305 Mtetra
.937 .952 .764 r
.60831 .33305 .61631 .33337 .63222 .31383 .62426 .30966 Mtetra
.874 .917 .854 r
.62426 .30966 .63222 .31383 .64831 .30003 .64036 .29318 Mtetra
.799 .86 .895 r
.64036 .29318 .64831 .30003 .66456 .28982 .65665 .28132 Mtetra
.742 .812 .907 r
.65665 .28132 .66456 .28982 .68097 .28167 .6731 .2722 Mtetra
.707 .78 .909 r
.6731 .2722 .68097 .28167 .69752 .27465 .68969 .26462 Mtetra
.687 .763 .909 r
.68969 .26462 .69752 .27465 .71418 .26821 .70641 .25786 Mtetra
.676 .753 .909 r
.70641 .25786 .71418 .26821 .73096 .26208 .72325 .25152 Mtetra
.67 .747 .908 r
.72325 .25152 .73096 .26208 .74785 .25609 .74021 .24539 Mtetra
.667 .744 .908 r
.74021 .24539 .74785 .25609 .76484 .25016 .75727 .23936 Mtetra
.665 .743 .908 r
.75727 .23936 .76484 .25016 .78194 .24425 .77443 .23335 Mtetra
.664 .742 .908 r
.77443 .23335 .78194 .24425 .79914 .23832 .79171 .22735 Mtetra
.79171 .22735 .79914 .23832 .81644 .23237 .80908 .22133 Mtetra
.80908 .22133 .81644 .23237 .83385 .2264 .82657 .21529 Mtetra
.646 .762 .934 r
.18391 .63206 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62674 .22915 .61815 Mtetra
.22915 .61815 .2394 .62674 .2546 .6221 .24441 .61346 Mtetra
.24441 .61346 .2546 .6221 .2699 .61743 .25975 .60874 Mtetra
.25975 .60874 .2699 .61743 .28528 .61273 .27519 .604 Mtetra
.27519 .604 .28528 .61273 .30075 .60801 .29072 .59922 Mtetra
.29072 .59922 .30075 .60801 .31632 .60326 .30634 .59442 Mtetra
.30634 .59442 .31632 .60326 .33197 .59847 .32205 .58958 Mtetra
.646 .763 .934 r
.32205 .58958 .33197 .59847 .34772 .59365 .33786 .58471 Mtetra
.33786 .58471 .34772 .59365 .36357 .58879 .35376 .57981 Mtetra
.647 .763 .934 r
.35376 .57981 .36357 .58879 .37951 .58388 .36976 .57485 Mtetra
.648 .764 .934 r
.36976 .57485 .37951 .58388 .39555 .57888 .38586 .56983 Mtetra
.65 .765 .933 r
.38586 .56983 .39555 .57888 .41168 .57377 .40205 .56471 Mtetra
.653 .767 .933 r
.40205 .56471 .41168 .57377 .42792 .56845 .41835 .55944 Mtetra
.659 .771 .932 r
.41835 .55944 .42792 .56845 .44426 .56277 .43474 .55389 Mtetra
.671 .779 .931 r
.43474 .55389 .44426 .56277 .4607 .55644 .45125 .54786 Mtetra
.692 .792 .927 r
.45125 .54786 .4607 .55644 .47724 .54892 .46786 .54095 Mtetra
.727 .816 .92 r
.46786 .54095 .47724 .54892 .49388 .53928 .48457 .53243 Mtetra
.783 .85 .902 r
.48457 .53243 .49388 .53928 .5106 .52598 .50137 .5211 Mtetra
.855 .892 .862 r
.50137 .5211 .5106 .52598 .52732 .50685 .51822 .50507 Mtetra
.926 .924 .79 r
.51822 .50507 .52732 .50685 .54397 .47972 .53504 .48202 Mtetra
.966 .931 .695 r
.53504 .48202 .54397 .47972 .5604 .44419 .55172 .45037 Mtetra
.974 .922 .612 r
.55172 .45037 .5604 .44419 .57655 .40373 .56813 .41149 Mtetra
.967 .917 .576 r
.56813 .41149 .57655 .40373 .59246 .36488 .58426 .3708 Mtetra
.962 .932 .61 r
.58426 .3708 .59246 .36488 .60831 .33305 .60023 .33485 Mtetra
.953 .952 .707 r
.60023 .33485 .60831 .33305 .62426 .30966 .61622 .30716 Mtetra
.909 .939 .815 r
.61622 .30716 .62426 .30966 .64036 .29318 .63236 .2874 Mtetra
.835 .888 .879 r
.63236 .2874 .64036 .29318 .65665 .28132 .64867 .2734 Mtetra
.767 .833 .903 r
.64867 .2734 .65665 .28132 .6731 .2722 .66515 .26301 Mtetra
.722 .794 .909 r
.66515 .26301 .6731 .2722 .68969 .26462 .68179 .25468 Mtetra
.695 .77 .909 r
.68179 .25468 .68969 .26462 .70641 .25786 .69856 .24749 Mtetra
.68 .757 .909 r
.69856 .24749 .70641 .25786 .72325 .25152 .71547 .2409 Mtetra
.672 .75 .909 r
.71547 .2409 .72325 .25152 .74021 .24539 .73248 .2346 Mtetra
.668 .746 .908 r
.73248 .2346 .74021 .24539 .75727 .23936 .74961 .22845 Mtetra
.666 .744 .908 r
.74961 .22845 .75727 .23936 .77443 .23335 .76685 .22235 Mtetra
.665 .743 .908 r
.76685 .22235 .77443 .23335 .79171 .22735 .78419 .21627 Mtetra
.664 .742 .908 r
.78419 .21627 .79171 .22735 .80908 .22133 .80165 .21017 Mtetra
.80165 .21017 .80908 .22133 .82657 .21529 .8192 .20405 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63206 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .604 .26499 .59516 Mtetra
.26499 .59516 .27519 .604 .29072 .59922 .28057 .59034 Mtetra
.28057 .59034 .29072 .59922 .30634 .59442 .29625 .58548 Mtetra
.29625 .58548 .30634 .59442 .32205 .58958 .31202 .58059 Mtetra
.646 .763 .934 r
.31202 .58059 .32205 .58958 .33786 .58471 .32788 .57567 Mtetra
.32788 .57567 .33786 .58471 .35376 .57981 .34384 .57072 Mtetra
.647 .763 .934 r
.34384 .57072 .35376 .57981 .36976 .57485 .3599 .56572 Mtetra
.3599 .56572 .36976 .57485 .38586 .56983 .37606 .56066 Mtetra
.649 .764 .933 r
.37606 .56066 .38586 .56983 .40205 .56471 .39231 .55553 Mtetra
.651 .766 .933 r
.39231 .55553 .40205 .56471 .41835 .55944 .40867 .55027 Mtetra
.656 .769 .933 r
.40867 .55027 .41835 .55944 .43474 .55389 .42513 .54481 Mtetra
.664 .774 .932 r
.42513 .54481 .43474 .55389 .45125 .54786 .44169 .53898 Mtetra
.68 .785 .929 r
.44169 .53898 .45125 .54786 .46786 .54095 .45836 .53249 Mtetra
.707 .803 .924 r
.45836 .53249 .46786 .54095 .48457 .53243 .47514 .52481 Mtetra
.752 .831 .913 r
.47514 .52481 .48457 .53243 .50137 .5211 .49202 .51499 Mtetra
.818 .871 .886 r
.49202 .51499 .50137 .5211 .51822 .50507 .50897 .50148 Mtetra
.893 .91 .83 r
.50897 .50148 .51822 .50507 .53504 .48202 .52595 .4821 Mtetra
.951 .931 .743 r
.52595 .4821 .53504 .48202 .55172 .45037 .54284 .45467 Mtetra
.973 .927 .649 r
.54284 .45467 .55172 .45037 .56813 .41149 .55951 .41879 Mtetra
.97 .918 .586 r
.55951 .41879 .56813 .41149 .58426 .3708 .57589 .37795 Mtetra
.964 .922 .584 r
.57589 .37795 .58426 .3708 .60023 .33485 .59204 .33875 Mtetra
.96 .943 .653 r
.59204 .33875 .60023 .33485 .61622 .30716 .60812 .30661 Mtetra
.937 .951 .764 r
.60812 .30661 .61622 .30716 .63236 .2874 .62428 .28297 Mtetra
.874 .917 .854 r
.62428 .28297 .63236 .2874 .64867 .2734 .64061 .26628 Mtetra
.799 .859 .894 r
.64061 .26628 .64867 .2734 .66515 .26301 .65713 .25422 Mtetra
.742 .811 .907 r
.65713 .25422 .66515 .26301 .68179 .25468 .67381 .24492 Mtetra
.707 .78 .909 r
.67381 .24492 .68179 .25468 .69856 .24749 .69063 .23717 Mtetra
.687 .762 .909 r
.69063 .23717 .69856 .24749 .71547 .2409 .7076 .23024 Mtetra
.676 .753 .909 r
.7076 .23024 .71547 .2409 .73248 .2346 .72468 .22373 Mtetra
.67 .747 .908 r
.72468 .22373 .73248 .2346 .74961 .22845 .74187 .21744 Mtetra
.667 .744 .908 r
.74187 .21744 .74961 .22845 .76685 .22235 .75918 .21123 Mtetra
.665 .743 .908 r
.75918 .21123 .76685 .22235 .78419 .21627 .7766 .20506 Mtetra
.664 .742 .908 r
.7766 .20506 .78419 .21627 .80165 .21017 .79413 .19889 Mtetra
.79413 .19889 .80165 .21017 .8192 .20405 .81176 .19269 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .59591 Mtetra
.22368 .59591 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59516 .25468 .58623 Mtetra
.25468 .58623 .26499 .59516 .28057 .59034 .27032 .58135 Mtetra
.27032 .58135 .28057 .59034 .29625 .58548 .28605 .57645 Mtetra
.28605 .57645 .29625 .58548 .31202 .58059 .30187 .57151 Mtetra
.30187 .57151 .31202 .58059 .32788 .57567 .3178 .56653 Mtetra
.646 .763 .934 r
.3178 .56653 .32788 .57567 .34384 .57072 .33382 .56152 Mtetra
.33382 .56152 .34384 .57072 .3599 .56572 .34993 .55648 Mtetra
.647 .763 .934 r
.34993 .55648 .3599 .56572 .37606 .56066 .36615 .55138 Mtetra
.648 .764 .934 r
.36615 .55138 .37606 .56066 .39231 .55553 .38246 .54622 Mtetra
.65 .765 .933 r
.38246 .54622 .39231 .55553 .40867 .55027 .39888 .54095 Mtetra
.653 .767 .933 r
.39888 .54095 .40867 .55027 .42513 .54481 .4154 .53553 Mtetra
.659 .771 .932 r
.4154 .53553 .42513 .54481 .44169 .53898 .43203 .52984 Mtetra
.671 .779 .931 r
.43203 .52984 .44169 .53898 .45836 .53249 .44876 .52365 Mtetra
.692 .792 .927 r
.44876 .52365 .45836 .53249 .47514 .52481 .46561 .51657 Mtetra
.727 .816 .92 r
.46561 .51657 .47514 .52481 .49202 .51499 .48256 .50788 Mtetra
.783 .85 .902 r
.48256 .50788 .49202 .51499 .50897 .50148 .4996 .49636 Mtetra
.855 .892 .862 r
.4996 .49636 .50897 .50148 .52595 .4821 .5167 .4801 Mtetra
.926 .924 .79 r
.5167 .4801 .52595 .4821 .54284 .45467 .53377 .45677 Mtetra
.966 .931 .694 r
.53377 .45677 .54284 .45467 .55951 .41879 .55069 .42478 Mtetra
.974 .922 .611 r
.55069 .42478 .55951 .41879 .57589 .37795 .56734 .38554 Mtetra
.967 .917 .576 r
.56734 .38554 .57589 .37795 .59204 .33875 .58371 .34447 Mtetra
.962 .932 .61 r
.58371 .34447 .59204 .33875 .60812 .30661 .59991 .30819 Mtetra
.953 .952 .707 r
.59991 .30819 .60812 .30661 .62428 .28297 .61614 .28022 Mtetra
.909 .939 .815 r
.61614 .28022 .62428 .28297 .64061 .26628 .63249 .26022 Mtetra
.835 .888 .879 r
.63249 .26022 .64061 .26628 .65713 .25422 .64903 .24602 Mtetra
.767 .833 .903 r
.64903 .24602 .65713 .25422 .67381 .24492 .66575 .23544 Mtetra
.722 .794 .909 r
.66575 .23544 .67381 .24492 .69063 .23717 .68262 .22694 Mtetra
.695 .77 .909 r
.68262 .22694 .69063 .23717 .7076 .23024 .69964 .21957 Mtetra
.68 .757 .909 r
.69964 .21957 .7076 .23024 .72468 .22373 .71679 .21281 Mtetra
.672 .75 .909 r
.71679 .21281 .72468 .22373 .74187 .21744 .73405 .20634 Mtetra
.668 .746 .908 r
.73405 .20634 .74187 .21744 .75918 .21123 .75143 .20001 Mtetra
.666 .744 .908 r
.75143 .20001 .75918 .21123 .7766 .20506 .76892 .19374 Mtetra
.665 .743 .908 r
.76892 .19374 .7766 .20506 .79413 .19889 .78652 .18748 Mtetra
.664 .742 .908 r
.78652 .18748 .79413 .19889 .81176 .19269 .80423 .18121 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .59591 .21314 .58698 Mtetra
.21314 .58698 .22368 .59591 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58623 .24425 .5772 Mtetra
.24425 .5772 .25468 .58623 .27032 .58135 .25994 .57227 Mtetra
.25994 .57227 .27032 .58135 .28605 .57645 .27573 .56731 Mtetra
.27573 .56731 .28605 .57645 .30187 .57151 .29162 .56231 Mtetra
.29162 .56231 .30187 .57151 .3178 .56653 .3076 .55729 Mtetra
.646 .763 .934 r
.3076 .55729 .3178 .56653 .33382 .56152 .32367 .55222 Mtetra
.32367 .55222 .33382 .56152 .34993 .55648 .33985 .54713 Mtetra
.647 .763 .934 r
.33985 .54713 .34993 .55648 .36615 .55138 .35613 .54198 Mtetra
.35613 .54198 .36615 .55138 .38246 .54622 .3725 .53678 Mtetra
.649 .764 .933 r
.3725 .53678 .38246 .54622 .39888 .54095 .38898 .5315 Mtetra
.651 .766 .933 r
.38898 .5315 .39888 .54095 .4154 .53553 .40557 .52609 Mtetra
.656 .769 .933 r
.40557 .52609 .4154 .53553 .43203 .52984 .42226 .52048 Mtetra
.664 .774 .932 r
.42226 .52048 .43203 .52984 .44876 .52365 .43905 .51449 Mtetra
.68 .785 .929 r
.43905 .51449 .44876 .52365 .46561 .51657 .45596 .50784 Mtetra
.707 .803 .924 r
.45596 .50784 .46561 .51657 .48256 .50788 .47298 .49999 Mtetra
.752 .832 .913 r
.47298 .49999 .48256 .50788 .4996 .49636 .4901 .48998 Mtetra
.818 .871 .886 r
.4901 .48998 .4996 .49636 .5167 .4801 .50731 .47626 Mtetra
.893 .91 .83 r
.50731 .47626 .5167 .4801 .53377 .45677 .52453 .45663 Mtetra
.951 .931 .743 r
.52453 .45663 .53377 .45677 .55069 .42478 .54167 .42889 Mtetra
.973 .928 .649 r
.54167 .42889 .55069 .42478 .56734 .38554 .55859 .39265 Mtetra
.97 .918 .586 r
.55859 .39265 .56734 .38554 .58371 .34447 .57522 .35143 Mtetra
.964 .922 .584 r
.57522 .35143 .58371 .34447 .59991 .30819 .5916 .31187 Mtetra
.96 .943 .653 r
.5916 .31187 .59991 .30819 .61614 .28022 .60791 .27943 Mtetra
.937 .951 .765 r
.60791 .27943 .61614 .28022 .63249 .26022 .62431 .25553 Mtetra
.874 .916 .854 r
.62431 .25553 .63249 .26022 .64903 .24602 .64087 .23861 Mtetra
.799 .859 .894 r
.64087 .23861 .64903 .24602 .66575 .23544 .65762 .22635 Mtetra
.742 .811 .907 r
.65762 .22635 .66575 .23544 .68262 .22694 .67454 .21687 Mtetra
.707 .78 .909 r
.67454 .21687 .68262 .22694 .69964 .21957 .6916 .20894 Mtetra
.687 .762 .909 r
.6916 .20894 .69964 .21957 .71679 .21281 .70881 .20183 Mtetra
.676 .753 .909 r
.70881 .20183 .71679 .21281 .73405 .20634 .72614 .19515 Mtetra
.67 .747 .908 r
.72614 .19515 .73405 .20634 .75143 .20001 .74359 .18868 Mtetra
.667 .744 .908 r
.74359 .18868 .75143 .20001 .76892 .19374 .76115 .1823 Mtetra
.665 .743 .908 r
.76115 .1823 .76892 .19374 .78652 .18748 .77883 .17595 Mtetra
.664 .742 .908 r
.77883 .17595 .78652 .18748 .80423 .18121 .79661 .1696 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .5772 .23371 .56808 Mtetra
.23371 .56808 .24425 .5772 .25994 .57227 .24946 .56309 Mtetra
.24946 .56309 .25994 .57227 .27573 .56731 .2653 .55807 Mtetra
.2653 .55807 .27573 .56731 .29162 .56231 .28124 .55302 Mtetra
.28124 .55302 .29162 .56231 .3076 .55729 .29728 .54793 Mtetra
.29728 .54793 .3076 .55729 .32367 .55222 .31342 .54282 Mtetra
.646 .763 .934 r
.31342 .54282 .32367 .55222 .33985 .54713 .32966 .53767 Mtetra
.32966 .53767 .33985 .54713 .35613 .54198 .34599 .53247 Mtetra
.647 .763 .934 r
.34599 .53247 .35613 .54198 .3725 .53678 .36243 .52723 Mtetra
.648 .764 .934 r
.36243 .52723 .3725 .53678 .38898 .5315 .37897 .52191 Mtetra
.65 .765 .933 r
.37897 .52191 .38898 .5315 .40557 .52609 .39562 .5165 Mtetra
.653 .767 .933 r
.39562 .5165 .40557 .52609 .42226 .52048 .41237 .51093 Mtetra
.659 .771 .932 r
.41237 .51093 .42226 .52048 .43905 .51449 .42923 .50507 Mtetra
.671 .779 .931 r
.42923 .50507 .43905 .51449 .45596 .50784 .44621 .49872 Mtetra
.691 .793 .927 r
.44621 .49872 .45596 .50784 .47298 .49999 .46329 .49148 Mtetra
.727 .816 .92 r
.46329 .49148 .47298 .49999 .4901 .48998 .48049 .48261 Mtetra
.783 .85 .902 r
.48049 .48261 .4901 .48998 .50731 .47626 .49778 .47088 Mtetra
.855 .892 .862 r
.49778 .47088 .50731 .47626 .52453 .45663 .51513 .45438 Mtetra
.926 .924 .79 r
.51513 .45438 .52453 .45663 .54167 .42889 .53246 .43077 Mtetra
.966 .932 .694 r
.53246 .43077 .54167 .42889 .55859 .39265 .54963 .39845 Mtetra
.973 .922 .611 r
.54963 .39845 .55859 .39265 .57522 .35143 .56654 .35883 Mtetra
.967 .917 .576 r
.56654 .35883 .57522 .35143 .5916 .31187 .58315 .31738 Mtetra
.963 .932 .61 r
.58315 .31738 .5916 .31187 .60791 .27943 .59959 .28076 Mtetra
.953 .951 .708 r
.59959 .28076 .60791 .27943 .62431 .25553 .61604 .25251 Mtetra
.909 .939 .815 r
.61604 .25251 .62431 .25553 .64087 .23861 .63264 .23227 Mtetra
.835 .888 .879 r
.63264 .23227 .64087 .23861 .65762 .22635 .64941 .21785 Mtetra
.767 .833 .903 r
.64941 .21785 .65762 .22635 .67454 .21687 .66637 .20708 Mtetra
.722 .794 .909 r
.66637 .20708 .67454 .21687 .6916 .20894 .68349 .19839 Mtetra
.695 .77 .909 r
.68349 .19839 .6916 .20894 .70881 .20183 .70075 .19085 Mtetra
.68 .757 .909 r
.70075 .19085 .70881 .20183 .72614 .19515 .71814 .1839 Mtetra
.672 .75 .909 r
.71814 .1839 .72614 .19515 .74359 .18868 .73566 .17726 Mtetra
.668 .746 .908 r
.73566 .17726 .74359 .18868 .76115 .1823 .7533 .17075 Mtetra
.666 .744 .908 r
.7533 .17075 .76115 .1823 .77883 .17595 .77105 .1643 Mtetra
.665 .743 .908 r
.77105 .1643 .77883 .17595 .79661 .1696 .78891 .15786 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56808 .22305 .55884 Mtetra
.22305 .55884 .23371 .56808 .24946 .56309 .23885 .5538 Mtetra
.23885 .5538 .24946 .56309 .2653 .55807 .25476 .54872 Mtetra
.25476 .54872 .2653 .55807 .28124 .55302 .27075 .54362 Mtetra
.27075 .54362 .28124 .55302 .29728 .54793 .28685 .53848 Mtetra
.28685 .53848 .29728 .54793 .31342 .54282 .30305 .5333 Mtetra
.646 .763 .934 r
.30305 .5333 .31342 .54282 .32966 .53767 .31934 .5281 Mtetra
.31934 .5281 .32966 .53767 .34599 .53247 .33574 .52285 Mtetra
.647 .763 .934 r
.33574 .52285 .34599 .53247 .36243 .52723 .35224 .51755 Mtetra
.35224 .51755 .36243 .52723 .37897 .52191 .36885 .5122 Mtetra
.649 .764 .933 r
.36885 .5122 .37897 .52191 .39562 .5165 .38556 .50677 Mtetra
.651 .766 .933 r
.38556 .50677 .39562 .5165 .41237 .51093 .40237 .5012 Mtetra
.656 .769 .933 r
.40237 .5012 .41237 .51093 .42923 .50507 .4193 .49543 Mtetra
.664 .774 .932 r
.4193 .49543 .42923 .50507 .44621 .49872 .43634 .48928 Mtetra
.68 .785 .929 r
.43634 .48928 .44621 .49872 .46329 .49148 .45349 .48247 Mtetra
.707 .803 .924 r
.45349 .48247 .46329 .49148 .48049 .48261 .47076 .47444 Mtetra
.752 .832 .913 r
.47076 .47444 .48049 .48261 .49778 .47088 .48813 .46423 Mtetra
.818 .871 .886 r
.48813 .46423 .49778 .47088 .51513 .45438 .50559 .45029 Mtetra
.893 .911 .83 r
.50559 .45029 .51513 .45438 .53246 .43077 .52307 .4304 Mtetra
.951 .931 .743 r
.52307 .4304 .53246 .43077 .54963 .39845 .54047 .40234 Mtetra
.973 .928 .648 r
.54047 .40234 .54963 .39845 .56654 .35883 .55765 .36574 Mtetra
.97 .918 .586 r
.55765 .36574 .56654 .35883 .58315 .31738 .57453 .32414 Mtetra
.964 .922 .584 r
.57453 .32414 .58315 .31738 .59959 .28076 .59115 .28422 Mtetra
.96 .943 .654 r
.59115 .28422 .59959 .28076 .61604 .25251 .6077 .25146 Mtetra
.937 .951 .765 r
.6077 .25146 .61604 .25251 .63264 .23227 .62433 .22729 Mtetra
.874 .916 .854 r
.62433 .22729 .63264 .23227 .64941 .21785 .64113 .21015 Mtetra
.799 .859 .894 r
.64113 .21015 .64941 .21785 .66637 .20708 .65812 .19768 Mtetra
.742 .811 .907 r
.65812 .19768 .66637 .20708 .68349 .19839 .67528 .18801 Mtetra
.707 .78 .909 r
.67528 .18801 .68349 .19839 .70075 .19085 .6926 .17989 Mtetra
.687 .762 .909 r
.6926 .17989 .70075 .19085 .71814 .1839 .71006 .1726 Mtetra
.676 .753 .909 r
.71006 .1726 .71814 .1839 .73566 .17726 .72765 .16574 Mtetra
.67 .747 .908 r
.72765 .16574 .73566 .17726 .7533 .17075 .74535 .15909 Mtetra
.667 .744 .908 r
.74535 .15909 .7533 .17075 .77105 .1643 .76318 .15252 Mtetra
.665 .743 .908 r
.76318 .15252 .77105 .1643 .78891 .15786 .78112 .14599 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .5538 .22813 .54441 Mtetra
.22813 .54441 .23885 .5538 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27075 .54362 .26015 .53411 Mtetra
.26015 .53411 .27075 .54362 .28685 .53848 .2763 .52891 Mtetra
.2763 .52891 .28685 .53848 .30305 .5333 .29256 .52368 Mtetra
.29256 .52368 .30305 .5333 .31934 .5281 .30892 .51841 Mtetra
.646 .763 .934 r
.30892 .51841 .31934 .5281 .33574 .52285 .32537 .51311 Mtetra
.32537 .51311 .33574 .52285 .35224 .51755 .34194 .50776 Mtetra
.647 .763 .934 r
.34194 .50776 .35224 .51755 .36885 .5122 .35861 .50236 Mtetra
.648 .764 .934 r
.35861 .50236 .36885 .5122 .38556 .50677 .37538 .49689 Mtetra
.65 .765 .933 r
.37538 .49689 .38556 .50677 .40237 .5012 .39226 .49132 Mtetra
.653 .767 .933 r
.39226 .49132 .40237 .5012 .4193 .49543 .40925 .48559 Mtetra
.659 .771 .932 r
.40925 .48559 .4193 .49543 .43634 .48928 .42635 .47957 Mtetra
.671 .779 .931 r
.42635 .47957 .43634 .48928 .45349 .48247 .44357 .47306 Mtetra
.691 .793 .927 r
.44357 .47306 .45349 .48247 .47076 .47444 .46091 .46563 Mtetra
.727 .816 .92 r
.46091 .46563 .47076 .47444 .48813 .46423 .47836 .45658 Mtetra
.783 .851 .902 r
.47836 .45658 .48813 .46423 .50559 .45029 .49591 .44464 Mtetra
.856 .892 .862 r
.49591 .44464 .50559 .45029 .52307 .4304 .51352 .4279 Mtetra
.926 .924 .79 r
.51352 .4279 .52307 .4304 .54047 .40234 .53111 .404 Mtetra
.966 .932 .694 r
.53111 .404 .54047 .40234 .55765 .36574 .54855 .37133 Mtetra
.973 .922 .611 r
.54855 .37133 .55765 .36574 .57453 .32414 .56571 .33133 Mtetra
.967 .917 .576 r
.56571 .33133 .57453 .32414 .59115 .28422 .58257 .2895 Mtetra
.963 .932 .611 r
.58257 .2895 .59115 .28422 .6077 .25146 .59925 .25254 Mtetra
.953 .951 .708 r
.59925 .25254 .6077 .25146 .62433 .22729 .61595 .224 Mtetra
.909 .939 .815 r
.61595 .224 .62433 .22729 .64113 .21015 .63278 .2035 Mtetra
.835 .888 .879 r
.63278 .2035 .64113 .21015 .65812 .19768 .6498 .18887 Mtetra
.767 .833 .903 r
.6498 .18887 .65812 .19768 .67528 .18801 .667 .1779 Mtetra
.722 .794 .909 r
.667 .1779 .67528 .18801 .6926 .17989 .68437 .16902 Mtetra
.695 .77 .909 r
.68437 .16902 .6926 .17989 .71006 .1726 .70189 .16129 Mtetra
.68 .757 .909 r
.70189 .16129 .71006 .1726 .72765 .16574 .71954 .15415 Mtetra
.672 .75 .909 r
.71954 .15415 .72765 .16574 .74535 .15909 .73732 .14732 Mtetra
.668 .746 .908 r
.73732 .14732 .74535 .15909 .76318 .15252 .75522 .14063 Mtetra
.666 .744 .908 r
.75522 .14063 .76318 .15252 .78112 .14599 .77324 .13399 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54007 Mtetra
.20137 .54007 .21227 .54951 .22813 .54441 .21728 .53491 Mtetra
.21728 .53491 .22813 .54441 .24409 .53927 .2333 .52971 Mtetra
.2333 .52971 .24409 .53927 .26015 .53411 .24942 .52449 Mtetra
.24942 .52449 .26015 .53411 .2763 .52891 .26563 .51923 Mtetra
.26563 .51923 .2763 .52891 .29256 .52368 .28195 .51394 Mtetra
.28195 .51394 .29256 .52368 .30892 .51841 .29837 .50862 Mtetra
.646 .763 .934 r
.29837 .50862 .30892 .51841 .32537 .51311 .31489 .50326 Mtetra
.31489 .50326 .32537 .51311 .34194 .50776 .33151 .49785 Mtetra
.647 .763 .934 r
.33151 .49785 .34194 .50776 .35861 .50236 .34824 .4924 Mtetra
.34824 .4924 .35861 .50236 .37538 .49689 .36508 .48689 Mtetra
.649 .764 .933 r
.36508 .48689 .37538 .49689 .39226 .49132 .38203 .4813 Mtetra
.651 .766 .933 r
.38203 .4813 .39226 .49132 .40925 .48559 .39909 .47557 Mtetra
.656 .769 .933 r
.39909 .47557 .40925 .48559 .42635 .47957 .41625 .46963 Mtetra
.664 .774 .932 r
.41625 .46963 .42635 .47957 .44357 .47306 .43354 .46332 Mtetra
.68 .785 .929 r
.43354 .46332 .44357 .47306 .46091 .46563 .45094 .45632 Mtetra
.707 .803 .924 r
.45094 .45632 .46091 .46563 .47836 .45658 .46846 .44811 Mtetra
.752 .832 .913 r
.46846 .44811 .47836 .45658 .49591 .44464 .4861 .43771 Mtetra
.818 .871 .886 r
.4861 .43771 .49591 .44464 .51352 .4279 .50382 .42353 Mtetra
.893 .911 .83 r
.50382 .42353 .51352 .4279 .53111 .404 .52156 .40337 Mtetra
.951 .931 .743 r
.52156 .40337 .53111 .404 .54855 .37133 .53923 .37499 Mtetra
.973 .928 .648 r
.53923 .37499 .54855 .37133 .56571 .33133 .55668 .33802 Mtetra
.97 .918 .586 r
.55668 .33802 .56571 .33133 .58257 .2895 .57381 .29604 Mtetra
.964 .922 .584 r
.57381 .29604 .58257 .2895 .59925 .25254 .59069 .25574 Mtetra
.961 .943 .654 r
.59069 .25574 .59925 .25254 .61595 .224 .60748 .22266 Mtetra
.937 .951 .765 r
.60748 .22266 .61595 .224 .63278 .2035 .62436 .19823 Mtetra
.874 .916 .854 r
.62436 .19823 .63278 .2035 .6498 .18887 .6414 .18085 Mtetra
.799 .859 .894 r
.6414 .18085 .6498 .18887 .667 .1779 .65864 .16818 Mtetra
.742 .811 .907 r
.65864 .16818 .667 .1779 .68437 .16902 .67606 .15831 Mtetra
.707 .78 .909 r
.67606 .15831 .68437 .16902 .70189 .16129 .69363 .14999 Mtetra
.687 .762 .909 r
.69363 .14999 .70189 .16129 .71954 .15415 .71135 .14251 Mtetra
.676 .753 .909 r
.71135 .14251 .71954 .15415 .73732 .14732 .7292 .13546 Mtetra
.67 .747 .908 r
.7292 .13546 .73732 .14732 .75522 .14063 .74717 .12861 Mtetra
.667 .744 .908 r
.74717 .12861 .75522 .14063 .77324 .13399 .76527 .12186 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54007 .19034 .53052 Mtetra
.19034 .53052 .20137 .54007 .21728 .53491 .20631 .5253 Mtetra
.20631 .5253 .21728 .53491 .2333 .52971 .22239 .52005 Mtetra
.22239 .52005 .2333 .52971 .24942 .52449 .23856 .51476 Mtetra
.23856 .51476 .24942 .52449 .26563 .51923 .25484 .50945 Mtetra
.25484 .50945 .26563 .51923 .28195 .51394 .27121 .5041 Mtetra
.27121 .5041 .28195 .51394 .29837 .50862 .28769 .49871 Mtetra
.28769 .49871 .29837 .50862 .31489 .50326 .30428 .49329 Mtetra
.646 .763 .934 r
.30428 .49329 .31489 .50326 .33151 .49785 .32097 .48782 Mtetra
.32097 .48782 .33151 .49785 .34824 .4924 .33776 .48232 Mtetra
.647 .763 .934 r
.33776 .48232 .34824 .4924 .36508 .48689 .35467 .47676 Mtetra
.648 .764 .934 r
.35467 .47676 .36508 .48689 .38203 .4813 .37168 .47113 Mtetra
.65 .765 .933 r
.37168 .47113 .38203 .4813 .39909 .47557 .3888 .46539 Mtetra
.653 .767 .933 r
.3888 .46539 .39909 .47557 .41625 .46963 .40604 .45949 Mtetra
.659 .771 .932 r
.40604 .45949 .41625 .46963 .43354 .46332 .42339 .4533 Mtetra
.671 .779 .931 r
.42339 .4533 .43354 .46332 .45094 .45632 .44086 .44661 Mtetra
.691 .793 .927 r
.44086 .44661 .45094 .45632 .46846 .44811 .45845 .439 Mtetra
.727 .816 .92 r
.45845 .439 .46846 .44811 .4861 .43771 .47616 .42975 Mtetra
.783 .851 .902 r
.47616 .42975 .4861 .43771 .50382 .42353 .49397 .41759 Mtetra
.856 .892 .862 r
.49397 .41759 .50382 .42353 .52156 .40337 .51185 .4006 Mtetra
.926 .925 .789 r
.51185 .4006 .52156 .40337 .53923 .37499 .52972 .37641 Mtetra
.966 .932 .694 r
.52972 .37641 .53923 .37499 .55668 .33802 .54743 .34339 Mtetra
.973 .922 .611 r
.54743 .34339 .55668 .33802 .57381 .29604 .56486 .303 Mtetra
.967 .917 .576 r
.56486 .303 .57381 .29604 .59069 .25574 .58197 .26079 Mtetra
.963 .932 .611 r
.58197 .26079 .59069 .25574 .60748 .22266 .59891 .22348 Mtetra
.953 .951 .708 r
.59891 .22348 .60748 .22266 .62436 .19823 .61585 .19464 Mtetra
.909 .938 .815 r
.61585 .19464 .62436 .19823 .6414 .18085 .63293 .1739 Mtetra
.835 .888 .879 r
.63293 .1739 .6414 .18085 .65864 .16818 .6502 .15904 Mtetra
.767 .833 .903 r
.6502 .15904 .65864 .16818 .67606 .15831 .66766 .14785 Mtetra
.722 .794 .909 r
.66766 .14785 .67606 .15831 .69363 .14999 .68528 .13878 Mtetra
.695 .77 .909 r
.68528 .13878 .69363 .14999 .71135 .14251 .70306 .13085 Mtetra
.68 .757 .909 r
.70306 .13085 .71135 .14251 .7292 .13546 .72098 .12352 Mtetra
.672 .75 .909 r
.72098 .12352 .7292 .13546 .74717 .12861 .73903 .11649 Mtetra
.668 .746 .908 r
.73903 .11649 .74717 .12861 .76527 .12186 .7572 .1096 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52005 .21135 .51027 Mtetra
.21135 .51027 .22239 .52005 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50945 .24392 .49955 Mtetra
.24392 .49955 .25484 .50945 .27121 .5041 .26036 .49413 Mtetra
.26036 .49413 .27121 .5041 .28769 .49871 .2769 .48868 Mtetra
.2769 .48868 .28769 .49871 .30428 .49329 .29354 .4832 Mtetra
.646 .763 .934 r
.29354 .4832 .30428 .49329 .32097 .48782 .3103 .47768 Mtetra
.3103 .47768 .32097 .48782 .33776 .48232 .32716 .47211 Mtetra
.647 .763 .934 r
.32716 .47211 .33776 .48232 .35467 .47676 .34413 .4665 Mtetra
.34413 .4665 .35467 .47676 .37168 .47113 .3612 .46082 Mtetra
.649 .764 .933 r
.3612 .46082 .37168 .47113 .3888 .46539 .37839 .45506 Mtetra
.651 .766 .933 r
.37839 .45506 .3888 .46539 .40604 .45949 .3957 .44916 Mtetra
.656 .769 .933 r
.3957 .44916 .40604 .45949 .42339 .4533 .41312 .44305 Mtetra
.664 .774 .932 r
.41312 .44305 .42339 .4533 .44086 .44661 .43066 .43656 Mtetra
.68 .785 .929 r
.43066 .43656 .44086 .44661 .45845 .439 .44832 .42938 Mtetra
.707 .803 .925 r
.44832 .42938 .45845 .439 .47616 .42975 .4661 .42097 Mtetra
.752 .832 .913 r
.4661 .42097 .47616 .42975 .49397 .41759 .484 .41036 Mtetra
.818 .872 .886 r
.484 .41036 .49397 .41759 .51185 .4006 .50199 .39595 Mtetra
.893 .911 .83 r
.50199 .39595 .51185 .4006 .52972 .37641 .52001 .37551 Mtetra
.951 .932 .742 r
.52001 .37551 .52972 .37641 .54743 .34339 .53796 .34681 Mtetra
.973 .928 .648 r
.53796 .34681 .54743 .34339 .56486 .303 .55568 .30946 Mtetra
.97 .918 .586 r
.55568 .30946 .56486 .303 .58197 .26079 .57308 .26708 Mtetra
.964 .922 .584 r
.57308 .26708 .58197 .26079 .59891 .22348 .59021 .22642 Mtetra
.961 .943 .654 r
.59021 .22642 .59891 .22348 .61585 .19464 .60726 .19302 Mtetra
.937 .951 .765 r
.60726 .19302 .61585 .19464 .63293 .1739 .62438 .16831 Mtetra
.874 .916 .854 r
.62438 .16831 .63293 .1739 .6502 .15904 .64168 .15069 Mtetra
.799 .859 .894 r
.64168 .15069 .6502 .15904 .66766 .14785 .65918 .1378 Mtetra
.742 .811 .907 r
.65918 .1378 .66766 .14785 .68528 .13878 .67685 .12772 Mtetra
.707 .78 .909 r
.67685 .12772 .68528 .13878 .70306 .13085 .69469 .11921 Mtetra
.687 .762 .909 r
.69469 .11921 .70306 .13085 .72098 .12352 .71267 .11153 Mtetra
.676 .753 .909 r
.71267 .11153 .72098 .12352 .73903 .11649 .73079 .10427 Mtetra
.67 .747 .908 r
.73079 .10427 .73903 .11649 .7572 .1096 .74904 .09723 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50038 Mtetra
.20018 .50038 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49955 .23287 .48953 Mtetra
.23287 .48953 .24392 .49955 .26036 .49413 .24937 .48405 Mtetra
.24937 .48405 .26036 .49413 .2769 .48868 .26597 .47854 Mtetra
.26597 .47854 .2769 .48868 .29354 .4832 .28268 .47299 Mtetra
.28268 .47299 .29354 .4832 .3103 .47768 .2995 .46741 Mtetra
.646 .763 .934 r
.2995 .46741 .3103 .47768 .32716 .47211 .31643 .46178 Mtetra
.31643 .46178 .32716 .47211 .34413 .4665 .33346 .45611 Mtetra
.647 .763 .934 r
.33346 .45611 .34413 .4665 .3612 .46082 .35061 .45038 Mtetra
.648 .764 .934 r
.35061 .45038 .3612 .46082 .37839 .45506 .36786 .44457 Mtetra
.65 .765 .933 r
.36786 .44457 .37839 .45506 .3957 .44916 .38524 .43867 Mtetra
.653 .767 .933 r
.38524 .43867 .3957 .44916 .41312 .44305 .40272 .43259 Mtetra
.659 .771 .932 r
.40272 .43259 .41312 .44305 .43066 .43656 .42033 .42622 Mtetra
.671 .779 .931 r
.42033 .42622 .43066 .43656 .44832 .42938 .43806 .41935 Mtetra
.691 .793 .927 r
.43806 .41935 .44832 .42938 .4661 .42097 .45592 .41155 Mtetra
.727 .816 .92 r
.45592 .41155 .4661 .42097 .484 .41036 .4739 .40209 Mtetra
.783 .851 .902 r
.4739 .40209 .484 .41036 .50199 .39595 .49198 .38971 Mtetra
.856 .893 .862 r
.49198 .38971 .50199 .39595 .52001 .37551 .51014 .37247 Mtetra
.926 .925 .789 r
.51014 .37247 .52001 .37551 .53796 .34681 .52828 .34796 Mtetra
.966 .932 .693 r
.52828 .34796 .53796 .34681 .55568 .30946 .54627 .31459 Mtetra
.973 .922 .61 r
.54627 .31459 .55568 .30946 .57308 .26708 .56398 .27381 Mtetra
.967 .917 .576 r
.56398 .27381 .57308 .26708 .59021 .22642 .58136 .23121 Mtetra
.963 .932 .611 r
.58136 .23121 .59021 .22642 .60726 .19302 .59855 .19355 Mtetra
.953 .951 .709 r
.59855 .19355 .60726 .19302 .62438 .16831 .61575 .16441 Mtetra
.909 .938 .815 r
.61575 .16441 .62438 .16831 .64168 .15069 .63309 .1434 Mtetra
.835 .887 .879 r
.63309 .1434 .64168 .15069 .65918 .1378 .65061 .12831 Mtetra
.767 .833 .902 r
.65061 .12831 .65918 .1378 .67685 .12772 .66833 .11691 Mtetra
.722 .794 .909 r
.66833 .11691 .67685 .12772 .69469 .11921 .68622 .10763 Mtetra
.695 .77 .909 r
.68622 .10763 .69469 .11921 .71267 .11153 .70427 .0995 Mtetra
.68 .757 .909 r
.70427 .0995 .71267 .11153 .73079 .10427 .72247 .09197 Mtetra
.672 .75 .909 r
.72247 .09197 .73079 .10427 .74904 .09723 .74079 .08474 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50038 .18889 .49037 Mtetra
.18889 .49037 .20018 .50038 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48953 .2217 .47939 Mtetra
.2217 .47939 .23287 .48953 .24937 .48405 .23826 .47385 Mtetra
.23826 .47385 .24937 .48405 .26597 .47854 .25492 .46828 Mtetra
.25492 .46828 .26597 .47854 .28268 .47299 .2717 .46266 Mtetra
.2717 .46266 .28268 .47299 .2995 .46741 .28858 .45701 Mtetra
.646 .763 .934 r
.28858 .45701 .2995 .46741 .31643 .46178 .30557 .45132 Mtetra
.30557 .45132 .31643 .46178 .33346 .45611 .32267 .44559 Mtetra
.647 .763 .934 r
.32267 .44559 .33346 .45611 .35061 .45038 .33988 .4398 Mtetra
.33988 .4398 .35061 .45038 .36786 .44457 .35721 .43395 Mtetra
.649 .764 .933 r
.35721 .43395 .36786 .44457 .38524 .43867 .37465 .42801 Mtetra
.651 .766 .933 r
.37465 .42801 .38524 .43867 .40272 .43259 .39221 .42194 Mtetra
.656 .769 .933 r
.39221 .42194 .40272 .43259 .42033 .42622 .40988 .41564 Mtetra
.664 .774 .932 r
.40988 .41564 .42033 .42622 .43806 .41935 .42768 .40897 Mtetra
.68 .785 .929 r
.42768 .40897 .43806 .41935 .45592 .41155 .44561 .4016 Mtetra
.707 .803 .925 r
.44561 .4016 .45592 .41155 .4739 .40209 .46366 .39299 Mtetra
.752 .832 .913 r
.46366 .39299 .4739 .40209 .49198 .38971 .48184 .38216 Mtetra
.818 .872 .886 r
.48184 .38216 .49198 .38971 .51014 .37247 .50011 .36751 Mtetra
.893 .911 .83 r
.50011 .36751 .51014 .37247 .52828 .34796 .51841 .34679 Mtetra
.951 .932 .742 r
.51841 .34679 .52828 .34796 .54627 .31459 .53664 .31775 Mtetra
.973 .928 .648 r
.53664 .31775 .54627 .31459 .56398 .27381 .55465 .28003 Mtetra
.97 .918 .585 r
.55465 .28003 .56398 .27381 .58136 .23121 .57232 .23725 Mtetra
.964 .922 .585 r
.57232 .23725 .58136 .23121 .59855 .19355 .58972 .19621 Mtetra
.961 .943 .655 r
.58972 .19621 .59855 .19355 .61575 .16441 .60703 .16248 Mtetra
.937 .95 .765 r
.60703 .16248 .61575 .16441 .63309 .1434 .62441 .13749 Mtetra
.873 .915 .853 r
.62441 .13749 .63309 .1434 .65061 .12831 .64197 .11962 Mtetra
.799 .859 .894 r
.64197 .11962 .65061 .12831 .66833 .11691 .65973 .1065 Mtetra
.742 .811 .907 r
.65973 .1065 .66833 .11691 .68622 .10763 .67767 .09621 Mtetra
.707 .78 .909 r
.67767 .09621 .68622 .10763 .70427 .0995 .69578 .08749 Mtetra
.687 .762 .909 r
.69578 .08749 .70427 .0995 .72247 .09197 .71404 .0796 Mtetra
.676 .753 .909 r
.71404 .0796 .72247 .09197 .74079 .08474 .73244 .07214 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47385 .22701 .46353 Mtetra
.22701 .46353 .23826 .47385 .25492 .46828 .24374 .45789 Mtetra
.24374 .45789 .25492 .46828 .2717 .46266 .26058 .45221 Mtetra
.26058 .45221 .2717 .46266 .28858 .45701 .27752 .44649 Mtetra
.27752 .44649 .28858 .45701 .30557 .45132 .29458 .44074 Mtetra
.646 .763 .934 r
.29458 .44074 .30557 .45132 .32267 .44559 .31175 .43494 Mtetra
.31175 .43494 .32267 .44559 .33988 .4398 .32903 .42909 Mtetra
.647 .763 .934 r
.32903 .42909 .33988 .4398 .35721 .43395 .34642 .42318 Mtetra
.648 .764 .934 r
.34642 .42318 .35721 .43395 .37465 .42801 .36393 .4172 Mtetra
.65 .765 .933 r
.36393 .4172 .37465 .42801 .39221 .42194 .38156 .41111 Mtetra
.653 .767 .933 r
.38156 .41111 .39221 .42194 .40988 .41564 .39931 .40485 Mtetra
.659 .771 .932 r
.39931 .40485 .40988 .41564 .42768 .40897 .41718 .3983 Mtetra
.671 .779 .931 r
.41718 .3983 .42768 .40897 .44561 .4016 .43518 .39123 Mtetra
.691 .793 .928 r
.43518 .39123 .44561 .4016 .46366 .39299 .45331 .38324 Mtetra
.727 .816 .92 r
.45331 .38324 .46366 .39299 .48184 .38216 .47156 .37357 Mtetra
.783 .851 .902 r
.47156 .37357 .48184 .38216 .50011 .36751 .48993 .36095 Mtetra
.856 .893 .862 r
.48993 .36095 .50011 .36751 .51841 .34679 .50837 .34344 Mtetra
.926 .925 .789 r
.50837 .34344 .51841 .34679 .53664 .31775 .5268 .31863 Mtetra
.966 .932 .693 r
.5268 .31863 .53664 .31775 .55465 .28003 .54508 .28489 Mtetra
.973 .922 .61 r
.54508 .28489 .55465 .28003 .57232 .23725 .56307 .24371 Mtetra
.967 .917 .576 r
.56307 .24371 .57232 .23725 .58972 .19621 .58073 .20072 Mtetra
.963 .932 .612 r
.58073 .20072 .58972 .19621 .60703 .16248 .59819 .1627 Mtetra
.953 .951 .709 r
.59819 .1627 .60703 .16248 .62441 .13749 .61565 .13326 Mtetra
.909 .938 .815 r
.61565 .13326 .62441 .13749 .64197 .11962 .63325 .11199 Mtetra
.835 .887 .879 r
.63325 .11199 .64197 .11962 .65973 .1065 .65104 .09666 Mtetra
.767 .833 .902 r
.65104 .09666 .65973 .1065 .67767 .09621 .66903 .08504 Mtetra
.722 .794 .908 r
.66903 .08504 .67767 .09621 .69578 .08749 .68719 .07554 Mtetra
.695 .77 .909 r
.68719 .07554 .69578 .08749 .71404 .0796 .70552 .06719 Mtetra
.68 .757 .909 r
.70552 .06719 .71404 .0796 .73244 .07214 .72399 .05945 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45789 .23242 .44738 Mtetra
.23242 .44738 .24374 .45789 .26058 .45221 .24932 .44163 Mtetra
.24932 .44163 .26058 .45221 .27752 .44649 .26633 .43585 Mtetra
.26633 .43585 .27752 .44649 .29458 .44074 .28346 .43002 Mtetra
.646 .763 .934 r
.28346 .43002 .29458 .44074 .31175 .43494 .30069 .42416 Mtetra
.30069 .42416 .31175 .43494 .32903 .42909 .31804 .41824 Mtetra
.647 .763 .934 r
.31804 .41824 .32903 .42909 .34642 .42318 .3355 .41228 Mtetra
.3355 .41228 .34642 .42318 .36393 .4172 .35309 .40624 Mtetra
.649 .764 .933 r
.35309 .40624 .36393 .4172 .38156 .41111 .37078 .40012 Mtetra
.651 .766 .933 r
.37078 .40012 .38156 .41111 .39931 .40485 .3886 .39386 Mtetra
.656 .769 .933 r
.3886 .39386 .39931 .40485 .41718 .3983 .40655 .38738 Mtetra
.664 .774 .932 r
.40655 .38738 .41718 .3983 .43518 .39123 .42462 .38051 Mtetra
.68 .785 .929 r
.42462 .38051 .43518 .39123 .45331 .38324 .44282 .37295 Mtetra
.707 .803 .925 r
.44282 .37295 .45331 .38324 .47156 .37357 .46115 .36413 Mtetra
.752 .832 .913 r
.46115 .36413 .47156 .37357 .48993 .36095 .47961 .35307 Mtetra
.818 .872 .886 r
.47961 .35307 .48993 .36095 .50837 .34344 .49817 .33817 Mtetra
.893 .912 .83 r
.49817 .33817 .50837 .34344 .5268 .31863 .51676 .31716 Mtetra
.951 .932 .742 r
.51676 .31716 .5268 .31863 .54508 .28489 .53529 .28778 Mtetra
.973 .928 .647 r
.53529 .28778 .54508 .28489 .56307 .24371 .55358 .24966 Mtetra
.97 .918 .585 r
.55358 .24966 .56307 .24371 .58073 .20072 .57154 .20648 Mtetra
.964 .922 .585 r
.57154 .20648 .58073 .20072 .59819 .1627 .58922 .16507 Mtetra
.961 .943 .655 r
.58922 .16507 .59819 .1627 .61565 .13326 .60679 .131 Mtetra
.937 .95 .765 r
.60679 .131 .61565 .13326 .63325 .11199 .62444 .10572 Mtetra
.873 .915 .853 r
.62444 .10572 .63325 .11199 .65104 .09666 .64227 .0876 Mtetra
.799 .859 .894 r
.64227 .0876 .65104 .09666 .66903 .08504 .66029 .07425 Mtetra
.742 .811 .907 r
.66029 .07425 .66903 .08504 .68719 .07554 .67851 .06373 Mtetra
.707 .78 .909 r
.67851 .06373 .68719 .07554 .70552 .06719 .6969 .05479 Mtetra
.687 .762 .909 r
.6969 .05479 .70552 .06719 .72399 .05945 .71545 .04669 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45397 Mtetra
.17073 .45397 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44738 .22097 .43674 Mtetra
.22097 .43674 .23242 .44738 .24932 .44163 .23793 .43093 Mtetra
.23793 .43093 .24932 .44163 .26633 .43585 .25501 .42507 Mtetra
.25501 .42507 .26633 .43585 .28346 .43002 .2722 .41918 Mtetra
.2722 .41918 .28346 .43002 .30069 .42416 .2895 .41324 Mtetra
.646 .763 .934 r
.2895 .41324 .30069 .42416 .31804 .41824 .30692 .40726 Mtetra
.30692 .40726 .31804 .41824 .3355 .41228 .32445 .40123 Mtetra
.647 .763 .934 r
.32445 .40123 .3355 .41228 .35309 .40624 .34211 .39514 Mtetra
.648 .764 .934 r
.34211 .39514 .35309 .40624 .37078 .40012 .35988 .38897 Mtetra
.65 .765 .933 r
.35988 .38897 .37078 .40012 .3886 .39386 .37777 .38269 Mtetra
.653 .767 .933 r
.37777 .38269 .3886 .39386 .40655 .38738 .39579 .37624 Mtetra
.659 .771 .932 r
.39579 .37624 .40655 .38738 .42462 .38051 .41393 .36949 Mtetra
.671 .779 .931 r
.41393 .36949 .42462 .38051 .44282 .37295 .4322 .36222 Mtetra
.691 .793 .928 r
.4322 .36222 .44282 .37295 .46115 .36413 .45061 .35402 Mtetra
.727 .816 .92 r
.45061 .35402 .46115 .36413 .47961 .35307 .46915 .34413 Mtetra
.783 .851 .902 r
.46915 .34413 .47961 .35307 .49817 .33817 .48781 .33127 Mtetra
.856 .893 .862 r
.48781 .33127 .49817 .33817 .51676 .31716 .50655 .31349 Mtetra
.926 .925 .789 r
.50655 .31349 .51676 .31716 .53529 .28778 .52528 .28835 Mtetra
.966 .932 .693 r
.52528 .28835 .53529 .28778 .55358 .24966 .54385 .25425 Mtetra
.973 .922 .61 r
.54385 .25425 .55358 .24966 .57154 .20648 .56213 .21267 Mtetra
.967 .917 .576 r
.56213 .21267 .57154 .20648 .58922 .16507 .58008 .16928 Mtetra
.963 .932 .612 r
.58008 .16928 .58922 .16507 .60679 .131 .59781 .1309 Mtetra
.953 .951 .709 r
.59781 .1309 .60679 .131 .62444 .10572 .61554 .10115 Mtetra
.909 .938 .815 r
.61554 .10115 .62444 .10572 .64227 .0876 .63341 .07961 Mtetra
.835 .887 .879 r
.63341 .07961 .64227 .0876 .66029 .07425 .65148 .06403 Mtetra
.767 .833 .902 r
.65148 .06403 .66029 .07425 .67851 .06373 .66974 .05218 Mtetra
.722 .794 .908 r
.66974 .05218 .67851 .06373 .6969 .05479 .68819 .04245 Mtetra
.695 .77 .909 r
.68819 .04245 .6969 .05479 .71545 .04669 .7068 .03388 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45397 .15895 .44341 Mtetra
.15895 .44341 .17073 .45397 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43183 Mtetra
.19246 .43183 .20411 .44252 .22097 .43674 .20938 .42598 Mtetra
.20938 .42598 .22097 .43674 .23793 .43093 .22641 .42009 Mtetra
.22641 .42009 .23793 .43093 .25501 .42507 .24355 .41417 Mtetra
.24355 .41417 .25501 .42507 .2722 .41918 .26081 .4082 Mtetra
.26081 .4082 .2722 .41918 .2895 .41324 .27818 .40219 Mtetra
.646 .763 .934 r
.27818 .40219 .2895 .41324 .30692 .40726 .29566 .39614 Mtetra
.29566 .39614 .30692 .40726 .32445 .40123 .31327 .39004 Mtetra
.647 .763 .934 r
.31327 .39004 .32445 .40123 .34211 .39514 .33099 .38389 Mtetra
.33099 .38389 .34211 .39514 .35988 .38897 .34883 .37767 Mtetra
.649 .764 .933 r
.34883 .37767 .35988 .38897 .37777 .38269 .3668 .37135 Mtetra
.651 .766 .933 r
.3668 .37135 .37777 .38269 .39579 .37624 .38489 .3649 Mtetra
.656 .769 .933 r
.38489 .3649 .39579 .37624 .41393 .36949 .40311 .35822 Mtetra
.664 .774 .932 r
.40311 .35822 .41393 .36949 .4322 .36222 .42145 .35114 Mtetra
.68 .785 .929 r
.42145 .35114 .4322 .36222 .45061 .35402 .43994 .34337 Mtetra
.707 .803 .925 r
.43994 .34337 .45061 .35402 .46915 .34413 .45856 .33433 Mtetra
.752 .832 .913 r
.45856 .33433 .46915 .34413 .48781 .33127 .47731 .32304 Mtetra
.818 .872 .886 r
.47731 .32304 .48781 .33127 .50655 .31349 .49616 .30788 Mtetra
.893 .912 .83 r
.49616 .30788 .50655 .31349 .52528 .28835 .51506 .28657 Mtetra
.951 .932 .742 r
.51506 .28657 .52528 .28835 .54385 .25425 .53389 .25684 Mtetra
.973 .928 .647 r
.53389 .25684 .54385 .25425 .56213 .21267 .55248 .21834 Mtetra
.97 .918 .585 r
.55248 .21834 .56213 .21267 .58008 .16928 .57074 .17475 Mtetra
.964 .922 .585 r
.57074 .17475 .58008 .16928 .59781 .1309 .58869 .13295 Mtetra
.961 .943 .655 r
.58869 .13295 .59781 .1309 .61554 .10115 .60654 .09855 Mtetra
.937 .95 .766 r
.60654 .09855 .61554 .10115 .63341 .07961 .62447 .07297 Mtetra
.873 .915 .853 r
.62447 .07297 .63341 .07961 .65148 .06403 .64257 .05459 Mtetra
.799 .858 .894 r
.64257 .05459 .65148 .06403 .66974 .05218 .66088 .041 Mtetra
.742 .811 .907 r
.66088 .041 .66974 .05218 .68819 .04245 .67938 .03025 Mtetra
.707 .78 .909 r
.67938 .03025 .68819 .04245 .7068 .03388 .69806 .02108 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43183 .18066 .421 Mtetra
.18066 .421 .19246 .43183 .20938 .42598 .19765 .41508 Mtetra
.19765 .41508 .20938 .42598 .22641 .42009 .21474 .40912 Mtetra
.21474 .40912 .22641 .42009 .24355 .41417 .23195 .40313 Mtetra
.23195 .40313 .24355 .41417 .26081 .4082 .24927 .39709 Mtetra
.24927 .39709 .26081 .4082 .27818 .40219 .26671 .39101 Mtetra
.26671 .39101 .27818 .40219 .29566 .39614 .28427 .38488 Mtetra
.646 .763 .934 r
.28427 .38488 .29566 .39614 .31327 .39004 .30194 .37871 Mtetra
.30194 .37871 .31327 .39004 .33099 .38389 .31974 .37249 Mtetra
.647 .763 .934 r
.31974 .37249 .33099 .38389 .34883 .37767 .33765 .36621 Mtetra
.648 .764 .934 r
.33765 .36621 .34883 .37767 .3668 .37135 .35569 .35984 Mtetra
.65 .765 .933 r
.35569 .35984 .3668 .37135 .38489 .3649 .37386 .35337 Mtetra
.653 .767 .933 r
.37386 .35337 .38489 .3649 .40311 .35822 .39215 .34671 Mtetra
.659 .771 .932 r
.39215 .34671 .40311 .35822 .42145 .35114 .41057 .33976 Mtetra
.671 .779 .931 r
.41057 .33976 .42145 .35114 .43994 .34337 .42913 .33228 Mtetra
.691 .793 .928 r
.42913 .33228 .43994 .34337 .45856 .33433 .44783 .32386 Mtetra
.727 .816 .92 r
.44783 .32386 .45856 .33433 .47731 .32304 .46666 .31374 Mtetra
.783 .851 .902 r
.46666 .31374 .47731 .32304 .49616 .30788 .48562 .30063 Mtetra
.856 .893 .862 r
.48562 .30063 .49616 .30788 .51506 .28657 .50466 .28256 Mtetra
.926 .926 .789 r
.50466 .28256 .51506 .28657 .53389 .25684 .5237 .2571 Mtetra
.966 .932 .693 r
.5237 .2571 .53389 .25684 .55248 .21834 .54259 .22262 Mtetra
.973 .922 .61 r
.54259 .22262 .55248 .21834 .57074 .17475 .56117 .18064 Mtetra
.967 .917 .576 r
.56117 .18064 .57074 .17475 .58869 .13295 .5794 .13684 Mtetra
.963 .932 .612 r
.5794 .13684 .58869 .13295 .60654 .09855 .59742 .0981 Mtetra
.954 .951 .709 r
.59742 .0981 .60654 .09855 .62447 .07297 .61543 .06803 Mtetra
.909 .937 .816 r
.61543 .06803 .62447 .07297 .64257 .05459 .63358 .04621 Mtetra
.835 .887 .879 r
.63358 .04621 .64257 .05459 .66088 .041 .65193 .03038 Mtetra
.767 .833 .902 r
.65193 .03038 .66088 .041 .67938 .03025 .67048 .01829 Mtetra
.722 .794 .908 r
.67048 .01829 .67938 .03025 .69806 .02108 .68922 .00833 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001oogooFa`0
07oo0000Egoo003EOol30005Ool2Fa`01E/l001K77oo0000EWoo003BOol30006Ool02E/LFcaK75/l
Fa`005/LOol0001FOol00=1oo`8000Qoo`04GcaSG5/LFc`2Fa`01@00FcaK77oo0000EGoo003=Ool3
0008Ool03V=LGc]SG5lkFcaK75/lFa`005LLFaaFo7oo001DOol00<]oo`8000Yoo`06HeaO?6=LGeaS
G5ll0e/L00H005/LEaaK77oo001DOol00<Qoo`<00003Ool007oo00Moo`0BGc]SG5lkHeaO>f=LGc]S
G5KlFaaG75/L001K75LLFaaoo`00Dgoo001WOol20002Ool2001IOol20004Ool00`00Oomoo`05Ool0
26]kJi]O?6=LGeaSG5llHe`2Gc`01eLLFaaG7000EaaK75LL009oo`03001oogoo051oo`00J7oo00@0
07ooOol005Moo`<000eoo`0EIg][W6MkJi]O>f=LGc]O?5/LGcaK?5llE_aK7000FaaFo5/LE_aoo`00
059oo`00JGoo0P00EWoo0P003Woo0V]k00I[VfMkJg][Nf^KFc`3Gc`01U/lGcaO?5llE_`0009G7005
E_aG75LLOol0001AOol006Uoo`8005=oo`<000moo`0JJi]WNf^LIg][VfMkJiaSFfMlFaaO?5/lGcaK
75/lFaaK?000FaaFo5LLE_aK75KlOol0051oo`00J7oo00@007ooOol0051oo`80015oo`9c^@0=Ji]W
Nf]kJg][Vf=KIeaSFellFcaO?5/LFc`00e/L00<005KlEa`00ULL0eKl00<007ooOol0CWoo001WOol2
0002Ool2001<Ool3000BOol07G>iLiUc^G>iJi]WNfMlHe]WO6=KIgaSFe/lFaaK?5/LFcaK75/l001G
75KlEaaFo5LLD_aG77oo0000Cgoo002fOol30002Ool00`00Oomoo`0@Ool5LkT02FMlHe]WG6=KIgaS
Ff=LGeaK?003Fa`01E/lFa`005KlEa`00eKl00AG75KlE_`004moo`00]7oo0P005goo019cVG>iLkUc
^G>IKk]_VVMlHe]WO5lkHeaO>f=LGc]K?5/LFc`2Fa`02`00FaaFo5LLD_aG75KlEaaBo7oo0000CWoo
002aOol3000HOol5LkT4KiX04F=LGcaSG5mLHeaO?6=LGeaK75LLFaaG7000EaaK75KlEa`01EKl00=o
o`00Ool0C7oo002_Ool2000JOol08W>ILkUc^G>iLiU_^fnJKk][VV^LIg]SG5lkHeaO>f=LGc]O?5/l
FaaFo5/L001K75KlFaaBo5KlD_aG75;lE_aoo`004Goo1@00=goo002/Ool3000KOol00gNfNmIc^@02
LkT4KiX01f^KIg][Nf]kHeaO?6=L009O?006FcaO?5LLFaaG70000ULL00=Fo5LLE_`01EKl00=oo`00
Ool03goo00D007ooOomoo`0003Moo`00ZWoo0P007Woo029keWNeNmIg]FnkKiY_^f^JJiaWNf^KIg][
W6MkGcaK75llFcaO?5/LGcaG75/L001K75KlEaaFo5LLD_aFo5;lEaaBo09oo`03001oogoo00ioo`03
001oogoo03Qoo`00Ygoo0`000Woo00<007ooOol06Woo00IkeWNeNkIg]WOHMkL2KiX02V^KIg][Nf]k
Ji]WNfMLHe]O?5/l0ell00EK?5LLEa`005Kl00=G70AFo005D_aFo5KlOol00007Ool60004Ool00`00
Oomoo`0gOol00:Eoo`80029oo`0FMkEkeWNeMmQg]gOHLkM[W6MkJi]WNf^LIg]WO6=KIgaK?5llFaaO
?5/LFc`2Fa`03`00EaaFo5/LE_aG75;lE_aBo5KlD_aFo5;lOol0000AOol00`00Oomoo`0fOol00:9o
o`<002=oo`07MkEk]WNfMmQg]gNhMkL00W>i0V]k00U[Vf=KIeaSFfMlHe]WG5/LFc`00e/L00=K?5/L
00000ULL0eKl00=G75;lE_`00UKl00EBo5KlE_aoo`00015oo`03001oogoo03Eoo`00MGoo10009goo
0P009Woo00IkeWNeNmIg]gOHLkL5LkT07V=KIgaSFfMlHe]WO5lkHeaK75/lFaaK?5/LFc`005LLE_aG
75;lEaaFo5LLD_aFo5;lE_aBg5KlD_`000eoo`05001oogooOol0000gOol007Aoo`03001oogoo009o
o`03001oogoo025oo`<002Moo`07NkIg]W_FMkMg^7NgMmP017>i0VnJ00YSFfMlHe]WG5mLHeaO?6=L
FaaK?09K7003Ea`005LL009Fo00=EaaFo5KlE_aG75;lE_aBo5KlD_aFo7oo00003Goo0`00>7oo001d
Ool00`00Oomoo`02Ool00`00Oomoo`0NOol3000ZOol01WNeNmIg]gOHLkMgf0Ac^@0RKiY_^f^JIgaS
Ff=LGc]SG5lkHeaO>f=LEaaK75KlFaaG7000D_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo7oo0017
Ool007Aoo`03001oogoo009oo`03001oogoo01aoo`80009oo`03001oogoo02Moo`06MkIkeWNgMkQg
]gOH17>i1FnJ00mSG5mLHeaO?6=LGeaSG5/lGcaG75/LEaaK7000Fa`025Kl00MBo5KlD_aFo5;lOol0
0017Ool007Aoo`03001oogoo009oo`03001oogoo01Uoo`<002ioo`05Nk=gTW^dMk=ke004LkT03VnJ
Kk][VVnkKiY[VfMkHeaO>f=LGc]O?5/lGc`2Fa`05ELLFaaFo000E_aG75;lEaaBo5KlD_aG75;lE_aB
g5KlD_aFo5;LOol00016Ool007Aoo`03001oogoo009oo`03001oogoo01Moo`80031oo`03Nk=k/W^d
009k]004MkEg]WNfNmH5KiX2Jg/00f^KIg][N`02Gc`01U/lGcaO?5llFcaK709G7004001G75LLEa`6
E_`00e;lE_aBo002D_`015KlOomoo`00AGoo001dOol00`00Oomoo`02Ool00`00Oomoo`0DOol3000b
Ool087NBNk=g/g_DMkAkeWNeNmIg]gOHJiY_^fMkJi]WNf^LIg][Vf=KIgaK?5llFaaO?5/lGcaFo5/L
E_`005KlFa`2E_`03U;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo7oo0015Ool007Eoo`@001Eoo`8003Ao
o`03Nk9k/g^d009k]09g]P06NmIg]GNgMkMgf6Mk0V]k00I[VfMkJg]SFfMlHe/3Gc`02E/lFaaK75/l
E_aG7000EaaFo002Ea`00eKlD_aFo002E_`3D_`01eKlD_aBo5;lE_aoo`0004Aoo`00Rgoo0`00=Woo
00]k/gNBNmAg]7^dMkEkeWNeMmQc]gOH009c^@0FIg][W6MkIgaSFfMlHe]WO6=KFcaK75/lFaaK?5/L
FcaFo000E_aG75;lEa`2E_`03U;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo7oo0013Ool008Uoo`80009o
o`03001oogoo03=oo`03Nk=k/W^d009k]003MkIkeWNe009g]`03MmQc^G>i00=c^@08IeaSFfMlHe]W
G6=KHeaO?09K7006FcaK75/LFaaK?0000UKl00=G75KlE_`00UKl00ABo5KlD_aFo0=Bo006E_aBo5;l
D_aoo`00@goo0026Ool3000jOol02gNBNk=g]7^dMkEkeWNeMmQc]gOHMkL017>i00e_^f^JIgaSFfMl
He]SG5lkHeaO>e/lFaaK?002Fa`05eLL001Bo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;L
E_aBg7oo0000@Woo0024Ool2000lOol00g^bNk=k]002Nk@01W_FMkEg]WNgMmQg]`Ac^@=_VP0@He]W
G5mLHeaO?6=LGeaSG5llFaaG75/LEaaK7000Ea`6E_`01U;lE_aBo5KlD_aFo0=Bo006E_aBo5;lD_ao
o`00@Goo0021Ool3000nOol02W^cMi9k]7NcNmIg]G_FLkMgf7Ng17>i00e_^f^JKk]_VVnkGc]SG5lk
HeaO>f=LFcaO?002Fa`06ULLFaaFo000EaaFo5;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5Kl
D]aFo7oo0011Ool007ioo`<0041oo`04Nk=k/W^bNi82Nk8017^cNk9k]7^d17>i1FnJ00M[Nf^KGcaS
G5mLGcaK?003Gc`01ELLFaaG75/L00000ULL1eKl00=Bo5KlD_`00U;l00=Fo5;lD_`015;l00=oo`00
Ool0?goo001lOol20013Ool0>W^ANk9gTG^bMi9k/gNBNmAg]7_FMkEkeWNeKk][VVnkKiY_^fMkJiaW
Nf^KFaaO?5/lGcaK75llFcaO?5KlFaaFo000E_aK75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;lE_aB
g5KlD]aFo5;LE_aoo`00?goo001iOol30002Ool20011Ool01g^ANi9k/W^ANk=k/W^c009k]003MkIk
eWNe009g]`9_VP9[N`06Ji]WNf]kHe]WO5/l0ell00YK?5llGcaG75KlEa`005LLE_aG70IFo0=Bo003
E_aBo5;l00MBo003Ool007oo03ioo`00Mgoo0P00Agoo02Ek/WNANk9gTG^cMi9k/gNdNkAg]G_FMkEk
eW>gMmQg]f^KIg][W6MkJi]SFfMlHe]WO5/LGcaK?5llFaaK?5/LEaaFo000E_aG7002E_`05E;lE_aB
o5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LOol0000nOol007Aoo`<004Uoo`03Ni5k/W^A
009k/P0:Nk=k/W^dNkAkeWNeMkIg]gOHMkL2LkT02F^KIg]WG6=KIgaSFfMLHe]WO003Fa`00e/lFaaK
7002Ea`01000EaaFo5LL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo09oo`03001oogoo03]oo`00
LWoo0P00Bgoo00mgTG^bMi5k/WNBNk=gTW^dMk=keWNeNmIc]gOHMkL017>i02]WO6=KIgaSFfMlHe]W
O5llHeaK75/lFaaK?5/LFcaFo000D_aG75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlOol0000mOol006moo`<004eoo`0=Ni9kTG^bNi9k/g^bNk=k]7_FMkEg]WNgMmP00WNg
0g>i0VnJ00UWO6=KIeaSFf=LGcaSG5mLFc`015/L00AG75/LE_`000=Fo009EaaFo5KlD_aFo5;lE_aB
o5Kl00=Bo003E_aBo5;l00EBo09oo`03001oogoo03Yoo`00KGoo0P0000=oo`00Ool0CGoo00ikTG^b
Mi5k/gNBNk=g/g_DMkEkeWNeMmQg]gOH0g>i02a_^f^JKk]_VVnkGc]SG5llHeaO>f=LGcaK75KlFaaG
75/LE_aK7000EaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L0Woo
00<007ooOol0>Goo001ZOol3001AOol2Ni401g^BNk9k/W^cNk9k]7Ne009g]P03MmQg]gNg00Ac^@A_
VP06Jg][VellHeaOG6=L0ell00MK75LLFaaG75/LEa`00006E_`015;lE_aBo5Kl3e;l00=oo`00Ool0
>Woo001WOol3001DOol03G^bMi5k/WNBNk=gTW^bMi5k/gNBNk=g]7^d00Ac^@0BJiY_^fnJKk]WNf^L
Ig]SG5lkHeaK?5llFaaO?5/lFaaFo5/L0ULL01d005/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aoo`0003Yoo`00IGoo0P00Egoo00=kTG^bNi400W^A00EkTW^A
Nk=k/W^c009k]004MkIkeWNeMkH4KiX00f]kJi]WN`02Jg/00ellFcaO?002Gc`01E/lGcaO?5LLE_`0
0ULL00<005KlE_`01UKl0e;l00=Fo5;lD_`03E;l00<007ooOol0>7oo001ROol3001HOol0:7NANk9g
TG^bMi5k/WNANk9gTW^cMi9k]7NcNmIg]G_FLkMgf6nJKk]WNf^LIg][VfMkIgaSFellFaaO?5/lGcaK
75/lFaaG75KlFa`005LL0UKl01YBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg000>Goo001POol2001KOol01W^BNi5kTW^ANi9kT@9k/P06Nk=k/W^dNkAkeWNe0WNf
00Igf7NgMkM[Nf^KIg/2Jg/02FMlHe]WG6=KGcaK?5llFaaK?002Fa`2Ea`015Kl001Fo5LL15Kl00AB
o5KlE_aFo0=Bo003E_aBo5;l00IBo008D]aBo5;lD_aBg5;lOol003Qoo`00GGoo0`0000=oo`00Ool0
FGoo01=k/W^BNk9kTG^bNi5k/WNANk=gTW^cMk=ke7NeNmIg]GOHMkMgf002LkT0<FMkJi]SFfMlHe]W
O6=KIgaSFe/lFaaK?5/LFcaK75/lE_aG7000EaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo00003Qoo`00Fgoo0P00Ggoo17^B0W^A00AkTW^cNk9k/`9k
]004MkEg]WNfMmP2MkL4LkT02V=KIgaSFfMLHe]WO6=KHeaOG5/l0e/L00EK?5LLFaaFo00000=Fo009
EaaBo5KlD_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l00IBo007D]aBo5;lD_aBg7oo0000=goo000^Ool4
000VOol3001POol04g^BNk=kTG^bNi5k/WNANk9gTW^cMi9ke7NeNmIg]GOHMkMgf7>g00=c^@0<JiY_
^f=KIgaSFfMlGcaSG5lkHeaK75/l0U/L02EG75/LE_aG7000EaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LOol0000ROol3000AOol002eoo`03001o
ogoo009oo`03001oogoo025oo`8006=oo`03Nk=kTW^b00=kT@9k/P04Nk=k/W^dNk@2MkH017_FMkMg
]gNg0g>i1FnJ00mSG5llHeaOG6=LGcaSG5LLFaaG75/LEaaK75LL00001UKl00IBo5KlD_aFo5;lE_`>
D_`01U;LD_aBo5;lOol002Aoo`03001oogoo00moo`00<Woo00<007ooOol07Goo1000I7oo019k/g^B
Nk9kTG^bMi5k/WNANk=gTW^cMkAkeWNeNmIg]gOHLkL4LkT02FnkKiY_^f^JJiaWNf=LGc]SG002Gc`0
1U/LGcaG75/LE_aK709G700R001G75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LD_aBg5KlD]aBo7oo000SOol00`00Oomoo`0?Ool002Eoo`H000Moo`03001oogoo
01aoo`<006Ioo`0;Ni9k/g^ANi9kTG^BNi5k/g^bNk=kT@02Nk8017^cNk9k]7^d17>i16nJ00I[VfMk
Jg][NellFc`3Gc`01E/lFaaG75/LE_`00ULL00<005KlE_`01UKl0e;l00=Fo5;lD_`03U;l00IBg5;l
D_aBo7oo000QOol00`00Ool0000@Ool002ioo`@001aoo`<006Qoo`0TNi9o/g^ANk9kTG^bMi5k/WNA
Nk9kTG^bMi9k/gNBNkAg/g_FMkEkeWNeKk]_VVnkIg][W6MkJi]WNfMlHe]O?5/LGcaK?5ll0U/L02MF
o5LLE_aK7000EaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg7oo00008Goo00<007oo000047oo000^Ool00`00Oomoo`0JOol3001[Ool00g^c
Ni9kTP02Ni802W^ANk9kTW^BNi5k/W^BNk=k/W^c0W^d00Ag]GNfMkIgf09g]`03Jg][VfMk009[N`0:
IgaSFfMLHe]O?5/lGcaK75/lFa`3Ea`01EKl001G75LLD_`00eKl00ABo5KlD_aFo0=Bo003E_aBo5;l
00IBo005D]aBo5;lD_aBg003D_`00e;LD_aBo002000OOol01@00Oomoogoo00003goo000^Ool00`00
Oomoo`0HOol2001]Ool05gncNi9k/W^ANk9kTG^bNi5k/W^ANk9gTG^cMi9k/gNcNmAg]G_FMkEgf7Ng
MmP00W>i00iWNf^KHe]WO6=KIgaSFfMlHe]K?5/LFcaK75/l0U/L02MFo5LL001G75KlEaaBo5KlD_aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo0000
7Woo00D007ooOomoo`0000moo`00;Woo1@004goo0`00Kgoo00QkTW^cNi9k/W^ANk=kTW^b0W^A00Ek
TW^bNk9k/g^b009k]09g]P03NmIg]gNg00Ac^@0:He]WO6=KIeaSFfMlHe]SG5mLFc`3Fa`01E/lFaaF
o5Kl000015Kl00QBo5KlE_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo004
D]aBo7oo000MOol3000017oo000000003Woo0014Ool2001aOol05g^BNk=kTG^bNi5k/g^ANk9kTG^b
Mi5k/WNBNk=gTW_DMkAkeWNeNmIg]gOHLkL00g>i01I[VVnkHe]WO6=KIgaO?6=LGc]SG5/LFcaK75/l
EaaK75KlEa`005LLD_aG709Fo00PD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlOol000Uoo`@002Aoo`00@Goo0`0000=oo`00Ool0L7oo00Mk/g^B
NkAkTg^dNi9k/P03Ni401W^BNi5k/g^bNk=k]09g]P04NmIg]gNgMkL3LkT5KiX03F=LGcaSG5mLHeaO
?6=LEaaK75LLFaaG75/L009Fo003001G75Kl00=Fo004D_aFo5;lE_`@D_`01E;LD_aBo5;lD]`00e;l
00ABg5;lOol000Moo`03001oogoo009oo`03001oogoo025oo`00?goo0P00MGoo01Ik]GNENkIkTg^d
Ni9k/W^ANk9gTG^bMi5k/gNBNk=g]7^dMkEkeWNgMmQc]`Ac^@0jKk]_VVnkJiY[W6MkHeaO>f=LGcaS
G5/LGcaG75/LE_aK75LLFaaBo000D_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo0007Ool00`00Oomoo`02Ool00`00Oomoo`0Q
Ool003aoo`<007Moo`9k]@09Ni=k]7^dNk=kTG^BNi5kTW^A009k/P06Nk=k/W^dNk9k/g^b0W^d17>i
16nJ00E[VfMkJg]OG6=L00AO?004FcaK75LLFa`4Ea`00`00E_aFo003E_`00e;lE_aBo002D_`00eKl
D_aBo00:D_`01E;LD_aBo5;lD]`00e;l00MBg5;lD_aBo5;LOol00006Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol003Yoo`8007Uoo`0XMiEk]W^ENkAkTgncNi9k/W^ANk9kTG^bMi9k/gNBNk9gTG^cMi9k
]7NcNmIg]G_FMkE_^fnJKk]WNf^LIg][VfMkJiaK?5llFaaO?5/lGc`2Fa`0:UKlEaaFo5/LE_`005;l
EaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo09oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo025oo`00=goo0`00Ngoo
0W^e0g^d0g^B00=k/W^ANi400W^B0W^A00AkTW^cNk9k/`9k]004MkEg]WNfMmP2MkL00f]kJi]WN`02
Jg/00f^KHe]WG002Gc`01E/lGcaK75/lFa`00eLL00EFo5LL001Fo5;l00=Fo0=Bo005E_aBo5;lD_aF
o00<D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo0005Ool00`00Oomoo`02Ool00`00Oomoo`0Q
Ool003Eoo`800003Ool007oo07Yoo`0KNkIkUG^eNi=o]7^CNk=kTG^bNi5k/WNANk9kTG^bMi5k/WNB
Nk=g/g_DMkEkeWNeNmIg]gOH009c^@0DIg][VfMkIgaSFfMlHe]WO5/LFcaK75/lFaaK?5KlFaaFo5LL
D_`0009Fo00SD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0QOol0
039oo`<007moo`9k]@9k]004Ni=k/g^BNk83Ni4017^bNi5kTG^A0W^b00Ak/g^bNkAk]09g]P03NmIg
]gNg00Ac^@0:He]WO6=KIeaSFfMlGcaSG5/LFc`3Fa`01U/lE_aFo5KlEa`000=Fo004D_aFo5;lE_`3
D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo0<000Aoo`@002Aoo`00
;goo0`00PGoo01]kUG^eMiEo]7^CNkAkTW^bNi5k/WNAOk=kTG^bMi5k/WNANk=gTW_DMkAkeWNeNmIg
]gOHLkL00g>i00a[VVnkHe]WO6=KHeaO?6=LGc]SG5/LFc`2Fa`025LLFaaBo5LLE_`005;lEa`2E_`0
9E;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aoo`0002aoo`00;Goo0P00Q7oo0W^e00Ik]7^CNkAkTW^bNi42Ni802W^cNi5kTG^A
Ni9kTG^cNk9k/g^d0WNf00AkeWNgMkMg]`=c^@E_VP0>HeaO?6=LGeaSG5llHeaG75/LEaaK75LLFaaF
o0800003EaaFo5Kl009Fo004D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo7ooOol0000[Ool002Yoo`<008Eoo`0JNkEgUG^fNi=k]7^COk=kTg^dNi=o/g^BNk9gTG^b
Mi5k/WNBNk=g]7^dMkEkeWNeMmQc]`Ac^@09Kk]_VVnkJiY[W6MkHeaO>f=L009O?005FaaO?5LLFaaF
o0030000:U;lEa`005KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo09oo`03001oogoo02Qoo`00:7oo0P0000=oo`00
Ool0QGoo0W^e00EkTg^dNkAk/g^e009k]003Nk=kTW^B009kTP09Ni5k/W^bNk=k/W^dMkIkeWNe009g
]`Ac^@A_VP06Ji]WNf]kJg]O?5/l0ell00AK?000000000AG7003E_`005Kl00=Fo003D_aFo5;l009B
o003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol002Yoo`00
9Woo0P00RGoo02YgUG^fNiEk]7^COkAkUG^dNi=o]7^BNk=kTG^bNi5k/WNANk=gTW^bMi5k/gNBNkAg
/g_FMkEkeWNeKk]_VVnkIg][W6MkJi]WNfMlHe]O?5/LGc`20002Fa`015KlEaaFo5/L0UKl02UBo000
D_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;L009oo`03001oogoo02Moo`009Woo0P00R7oo0WNh00AcV7NgMkMk]`9k
]@9k]004Ni9k/g^BNk82Ni42Ni82Ni4017^BNk=k/W^c0W^d00Ag]GNfMkIgf09g]`03Jg][VfMk009[
N`03IgaSFfML00<00004GcaK75/lFa`3Ea`01UKlEaaG75KlD_`0009Fo0=Bo005E_aBo5;lD_aFo008
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002Ool00`00Oomoo`0V
Ool002Ioo`<008Moo`0OMkUcV7NhMiIk]gNFNkEkTgndNi=k/g^BNk9kTG^bMi5k/W^ANk9gTG^bMi9k
/gNcNmAg]G_FMkEkeWNgMmP00W>i00AWNf^KHe]WO0<0000=IgaK75/lFaaK?5/LFcaK75LLE_aG75;l
Ea`00UKl02]Bo000D_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000XOol002Ioo`04001oogoo0025Ool01WNh
LiQg^7NgNkMg]P9k]@05NkAkTg^cNi9k/`03Ni402W^bNi5kTG^ANk9kTG^cNk9k]7Nd0WNf00=keWNg
MkL017>i0`0000MWG6=KIgaO?6=LFaaK?004Fa`015LLE_aFo5LL15Kl00@005KlD_aFo0=Bo003E_aB
o5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00ABg5;lD_aBo09oo`03001oogoo
02Eoo`009Goo00<007ooOol00Woo00<007ooOol0PGoo025g^G>HMkQgUW^gMiIk]GNEOkAkTg^dNi9o
/g^ANk9gTGncNi5k/WNANk9gTG^cMi9ke7NdNmIg]G_FMkMgf7>gLkT00`00045_^f=KIgaSFf=LGcaS
G5lkFcaK75/lE_aK75LLFaaBo5LLE_aG75;lEaaBo5Kl001Fo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0002Mo
o`009Goo00<007ooOol00goo00<007ooOol0Ogoo00Mg^7>HMkQg^7^gMkIg]`02NkD017^CNkAkTW^c
0g^B00Ik/g^BNi9kTG^BNi42Nk801G^cMkAg]WNfNmH00WNg0`0000=c^FnJKiX00VnJ00iOG6=LGcaS
G5mLHeaO?5/LEaaK75LLFaaG75/L1UKl00IBo5Kl001Fo5;lE_`@D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo006D]aBo5;lD_aoo`009Woo000UOol00`00Oomoo`04Ool00`00Oomoo`1nOol0
77>HMkQcV7^gMiIk]gNENkIkTg^dNi=o/g^BNk9kTgncNi9k/WNANk9gTG^bMi9k/gNdNkAg]G_F0`00
17>i00]_^fnJKk]WNf^LGcaSG5lkHeaK?5ll009K700eEaaK75KlFaaFo5LLD_aG75;lE_aBo5LLD_aF
o000E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg002Ool00`00Oomoo`0SOol002Eoo`8000Ioo`8007eoo`06LiQg^7Nh
NkMg]WNg0g^e0W^d00Ek/g^BNk=k]7^c00AkTP07Ni5k/W^BNk=k/W^dMkH00P000WNg17>i0fnJ00=[
Nf^KIg/00V]k00=O?5/lGc`00Ull00EK?5llEaaG75Kl00=G70AFo004D_aFo5;l000@D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0TOol002Eoo`03
001oogoo00Moo`03001oogoo07Uoo`0ILiQg^7>HMkUgUW^gMiIk]W^ENkAkTgndNiEk]GNEOkAkTW^c
Ni5k/W^ANk9gTG^bMi800`0004mgTW^dMk=ke7NeNmIg]FnkKiY_^fMkJiaWNf^KIg]WO6=KGcaK75ll
FcaO?5/LFcaFo5LLE_aK75KlEaaBo5KlD_aFo5;lE_aBo000D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000T
Ool002Eoo`03001oogoo00Qoo`03001oogoo07Moo`05JgY[Vf]jKi]g]P02MkL3NkD00gNgNkMg]P02
NkD01G^dNi9k/g^BNk800W^A00QkTP00000007^BNk=k/W^c0W^d00Ag]GNfMkEgf09g]`03Jg][VfMk
009[N`03IgaSFfMl009O?005FcaK75/LFcaK7003Ea`3E_`00eLLD_aFo002E_`015;lE_aBo00035;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`00
02=oo`009Goo00<007ooOol02Goo00<007ooOol0MGoo01E[NVnKJgY_VfnILiY_VGNiLiQg^7NFNkMg
UW^eMiEk]W^CNk=kTW^bNi400`0000igTG^bMi5k/WNBNk=g/g_DMkAkeWNeMmQg]gOH0W>i01AWNf^K
He]WO6=KIgaSFfMlFaaK?5/LFcaK75/lFaaG75KlEaaBo5LL0UKl031Bo5KlD_aFo5;LE_aBg000D]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo7oo000SOol002Aoo`8000aoo`03001oogoo07=oo`0>JgY[Vf]jKi]_VG>JKiUc
VW>HMkQgV7^gMkIg]`9k]@03Ni=k]7^B00<0000>Ni5k/W^BNi9kTG^bNi5k/g^bNkAg]7NfMkEkeP9g
]`Ac^@0:HeaWO6=KIgaSG6MlGcaSG5/LFc`2Fa`00eLLFaaG7002E_`00eLLE_aFo002E_`015;lE_aB
o5Kl0U;l00<005KlD_`01e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00QBg5;lD_aBo5;LD_aoo`008Woo000TOol00`00Oomoo`0<Ool00`00Oomoo`1aOol04F]j
Ki][NVnKJgYcVVnILkYcV7NhLiQk]gNFNkMgUG^fNiD00`0001=kTG^bMi5o/g^ANk9gTG^bMi5k/gNB
NmAg]7^dMkEkeWNgMmQc]`03LkT0AF^JKk]SFfMlHe]SG5llHeaO>f=LEaaK75KlFaaG75/LD_aG75Kl
EaaBo5LLD_aFo5;LE_aBo5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0OOol002Ao
o`03001oogoo00eoo`03001oogoo06moo`0=JgY[Vf]jKi][NW>JKiUcVW>HMkQgV7NhMkH00WNg0`00
00=k]7^cNi800W^B00=k/g^BNi800W^B00QkTG^bNk9k/gNdNkAg]G_F0gNg0g>i16nJ00iOG6=LGcaS
G5mLHeaK?5llEaaK75LLFaaG75/L1UKl00IBo5KlD_aFo5;lE_`2D_`00`00D_aBo007D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01e;LD_aBo5;lD]aoo`00025o
o`0097oo00<007ooOol03Woo00<007ooOol0KGoo00iSFf=LJgY_Vf]jLiY_VG>jLiQg^7>HMkUgUW^g
0P0001MkUG^eNi=o/g^BNk9kTGndNi9k/W^ANk9gTG^bMi9k/gNdNkAg/g_FMkMgf7>g00=c^@0<JiY_
^fnJKk]WNf^LGcaSG5lkGcaK?5ll0U/L03eG75/LE_aK75KlEaaBo5LLD_aFo5;lEaaBo5KlD]aFo5;l
E_aBg000D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000POol002Aoo`03001oogoo00moo`03001oogoo06Yo
o`ISG007LiY_VG>JKiUg^7NHMkP00`0000=k]g^eNkD00W^d00AkTW^cNkAk]0=kTP06Nk9kTG^bNi9k
/g^b0W^d00Ak/g^bNkAk]0=c^@=_VP9[N`06Ji]WNf]kJg]O?5/l0ell00EK?5LLEaaG75Kl009G70EF
o004D_aFo5;lE_`3D_`00eKlD_`0000:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol07Goo000TOol2000AOol00`00Oomoo`1W
Ool036=KHgaSFf=LHe]SO6=KIgaWFf]lIg]g^0<0000]NkMgUW^gNiEk]GNEOkAkTW^cMiEo]7^CNk=k
TG^bNi5k/WNANk9gTW^bMi5k/WNBNkAg/g_FMkEkeW>gMmQg]f^KIg][W6MkJi]WNfMlHe]O?5/LGcaK
75/l009K7004E_aG75KlFa`2E_`0=U;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lOol001moo`008goo00<007ooOol04Woo00<007ooOol0I7oo0U/l00=K?F=LHe`00f=L0fMk
0`0000I_Vf]jMkMg]g^gMkH2NkD037^dNi=k]G^eNkAkTg^cNi9k/W^BNi5kTP9k/P05Ni5kTW^bNk9k
/`02Nk@01GNeMkIg]GOHMkL00W>i00U[VfMkJg]SG6MlHe]WO6=LFc`00e/L00EK?5/LFaaFo5LL00AF
o004D_aFo5KlE_`3D_`00eKlD_aBo003D_`00`00D_aBo004D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=oo`00Ool07Goo000JOol4
0005Ool00`00Oomoo`0COol00`00Oomoo`1QOol02U/lGceK?5lmFcaO?F=KHgaWNfMl0`0002A_Vf]j
Ki][NW>JKiUc^VnINkEgUG^fMiIk]GNENkIkTg^dNi9k/W^ANk9gTG^bMi5k/WNANk9gTG^cMk=ke7Ne
NmIg]GOHMkL4LkT04fMlHe]WO6=KIgaSFf=LGcaK?5/LFcaK75/lE_aK75KlEaaBo5LL009Fo00cD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`03001oogoo01]oo`006Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol057oo00<007ooOol0GWoo00EK?E/lFcaK?5/m
00=K?004Fcd000000002Ig/03F^KJgY_Vf]jLiY_VG>JKiUg^7NHMkQg]WNg009k]@04Ni=k]7^dNk<2
Ni803W^ANk9kTW^BNi5k/W^ANk=k/W^dMkAg]WNeMmP2MkL3LkT2KiX02FMlHe]WO5mLHeaO?6=LFaaK
?002Fa`00eLLFaaG7002E_`00eLLE_aFo002E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`00U;l00<005;l
D_`01E;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L009Bo003Ool007oo01aoo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
5Goo00<007ooOol0G7oo00MG?ELLGceK?5lmFcaO?@030000:EmLIe][O6MkKi][NVnKJgY_VfnILkY_
VGNhLiQg^G>HNkMgUG^fNiEk]7^COk=kTG^bMi5o/g^ANk9gTG^bMi5k/WNBNmAg]7_FMkEgf7NgMmP0
0g>i04i_^f^JKk]_VV=LGc]SG5llHeaO>f=LEaaK75KlFaaG75/LE_aG75;lE_aBo5LLD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000LOol001Uoo`03001oogoo009o
o`03001oogoo009oo`8001Moo`8005Yoo`03EaeG?ELL009G7@0FFceK?000001OG5llGeaO?5mLGca[
Vf]jKi][NV^KKiUcVVnIMkQgV7NhLiP2MkL2NkD3Nk@3Ni800g^cNi9kTP02Ni8027^ANk9k/W^cMkAk
]7NeNmH2MkL4LkT3KiX2Jg/02f=LGcaSG5mLGcaK?5llEaaK75LLFa`00ULL25Kl0e;l00=Fo5;lD_`0
1U;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0JOol001Uoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo01Qoo`03001oogoo05Eoo`06EceG75LmEaaG?ELL0`0002aO?5mMGcaOG5llGeeO
?6=LHe]_Vf]jKi]_VG>jKiUcVW>HMkUcV7^gMiIk]W^ENkEkTgndNi9k/W^AOkAkTW^bNi5k/W^ANk9g
TG^cMkAk]7NeNmIg]gOH17>i051[VVnkKiY[VfMkJiaWNellFaaO?5/lGcaK75llE_aG75KlFaaFo5LL
D_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000
6goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`1BOol3Dad0
0eLmEa`00002000025LLFceG?5mLGcaOG5llGe`6He`01fnILiY_VG>JMiQg^7>H009g]`03NkMk]G^e
009k]00ANi=k/g^dNkAkTW^cNi9k/W^ANk9kTW^cNk9k]7^BNk=g]002Nk@00g_FMkEg]P03KiX2Jg/0
1V^KIg]WO6=LGcaK?09O?003FcaK75/L009G7005E_aG75LLEaaBo003E_`015;lE_aBo5Kl0e;l00=F
o5;lD_`01E;l00<005;lD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000JOol001Uoo`03001oogoo009oo`05001o
ogooOol0000MOol00`00Oomoo`1>Ool01E;lEaeC75LMD_`00`0004AG75LmEaaK?ELLFceG75mLGcaO
GF=KHeaSFf=lHe]SG6MKJga_VG>JLiQg^G>HMkQgUW^gNiEk]GNEOkAkTg^cMiEo]7^CNk=kTG^bNi5k
/WNANk9gTW^bMi5k/gNBNkAg/g_FMkEkeW>gMmQg]f^KIg][W6=KIgaSFfMlHe]WO5/LFcaK75/l0U/L
049Fo5LLE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg000D]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo7oo0007Ool5000=Ool001Yoo`@000Aoo`8001eoo`03001oogoo04]oo`AC7@<000=C
7@08FceG75/mEcaK?ELLFceG?0MSG0AWN`07MiQg^7>HMkQg]g^gMkH00W^e00Yk]7^CNkAk]G^dNi=k
/g^BNk9kTP9kT@04Nk9kTG^ANi82Nk83Nk@01GNeMkIg]gOHMkL00g>i00QSFfMlHeaWO6=KIgaOG6=L
0e/L00EK?5/LE_aFo5LL00AFo008D_aFo5KlE_aBo5KlD_aFo0]Bo003001Bg5;l009Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;L
Ool00007Ool01@00Oomoogoo00003Goo000ROol00`00Oomoo`0MOol00`00Oomoo`16Ool01E;lDaeB
o5<MD_`00`0003]Bo5LMDaaG7E<LEaeC75/mEaaK?ELLFceG75lmFcaSG6=KHgaSFfMlIe][O6MkIga[
NVnKJgY_VgNFNkMgUW^eMiEk]WNFNkMgUG^fNi=k]7^BOk=kTG^bMi5k/W^ANk9gTG^bMi9k/gNcNmAg
]G_FMkEgf7Ng00=c^@0DKiY_^f=KIgaSFf=LGc]SG5llFcaK75/lEaaK75KlEaaFo5LLD_aG709Fo00k
D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol00007
Ool00`00Oomoo`0>Ool0029oo`03001oogoo01ioo`03001oogoo04=oo`04DaeBoE<MD_d300001E;m
DaeC7E<MEa`00eLM00QG75LMEaeK?ELLFceK?5/m0e/l0V=L1FMk00][NVnKJgY[VfnILiY_VGNhMiQg
^7Nf009g]`05NkEkTg^dNkAk/`02Ni800g^ANi9kTP02Ni400g^bNi5k/`02Nk@01GNdMkIg]GOHMkL0
0g>i16nJ00iO?6=LGeaSG5llHeaOG5/LEaaK75LLFaaG75/L1UKl00ABo5KlD_aFo0iBo003001Bo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`2Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool0029oo`03001oogoo01moo`03001oogoo
03moo`05DaeBo5<MC_aC7@020000?e;lDaeBo5<MD_aG7E;lDaeC75LMDaaG7E<LEaeC75lmFcaO?E/l
GceK?5lmFcaWO6MKJgaWNfMlJgY_Vf]jKi]_VG>jKiUcVW>HMkUcV7^gMiIk]W^ENkAkTgncNi9k/WNA
Nk9kTW^bMi5k/WNANk=gTW_DMkAkeWNeMmQg]`04LkT03fnkJiY_^fMkJi]O>f=LGcaSG5/LGcaK?5/L
E_aK7002Ea`0@UKlFaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_`005;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lOol000Qoo`03001oogoo00aoo`008Woo00<007ooOol087oo00<007oo
Ool0?7oo00ABoE<MD_eC7@<00003DaeBoE<M00QC7@05EaaG7ELMEaeG7002Ead025/mFcaK?5/lFceK
?5mLGc`3Ig/02f]jKi][NV^KJgYcVVnILiYgV7NhLiP00WNg00=k]g^eNk@00W^d00AkTW^cNi9k/`9k
TP03Ni5kTW^A009k/P06NkAg]7^dMkEgf7Ng17>i0fnJ00EWNf]kJg][Ve/l00=O?005FcaO?5llEaaF
o003Ea`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`2Ool00`00
Oomoo`06Ool00`00Oomoo`0;Ool0025oo`8002=oo`03001oogoo03Qoo`04C_aC7DklDad30000Fe<M
D_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMD_aC7ELLEceG75LmEaaG?ELLGceK?5lmGcaOG5llGeeO?5mL
JgY_Vf]jKi][NW>jKiUcVW>HMkUcV7NhMiIk]g^ENkEkTgndNi9k/g^AOkAkTW^cNi5k/W^ANk9gTW^c
MkAk]7NBNk=g/g^dMkEkeWNeKk][VVnkIg][VfMkJiaSFfMlFaaO?5/lGcaK75/lFaaG75KlFaaFo5LL
009Fo00mD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg000D]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]`00Woo00D007ooOomoo`0000=oo`03001oogoo00]oo`008Goo00<007ooOol08goo00<0
07ooOol0<Woo00I>oE;mD_eC7DkmD_d30002D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m1U<M00IG7ELL
EaeG7ELmEa`2Ead01emLGcaOG5llGeaO?5mL009SG00>JgY[Vf]jLiY_VG>JMiQg^7>HMkQg]g^gMkIk
]@9k]00ENi=k/g^BNkAkTW^cNi9k/W^ANk9kTW^cNi5k/W^BNk=g]7^dMkEkeWNe009g]`0:MmQWNf]k
Jg]WO6=KIgaSG6MlHe/2Fa`00e/lFaaK7002Ea`015KlEaaFo5LL15Kl00ABo5KlD_aFo0=Bo003E_aB
o5;l00IBo006D]aBo5;lD_aBg0000U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]aBo5;l008000Aoo`<000ioo`008Goo00<007oo
Ool097oo00<007ooOol0;goo00EC7DkmDae>o5<M00<0001=Dae>o5<MC_aC7DklDae>o5<MD_aC7Dkl
DaeBo5<MC_aG7E<LEaeBo5LMDaaG7ELLEceG75LmEaaK?ELLGeaO?5mMGcaOG6=KHgaSFf=LHe]c^VnI
LiY_VGNiLiQg^7NFNkMgUW^eMiEo]7^CNk=kTW^fNi=k/g^BNk9kTG^bMi5k/g^ANk9gTG^cMi9k]7Nc
NmIg]GOHLkMgf003LkT0E6MlHe]WO6=KIgaSFf=LGc]K?5/LFcaK75/lE_aG75;lEaaFo5LLD_aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
Ool001Aoo`008Goo00<007ooOol09Goo00<007ooOol0:goo0U;m00=C7DkmD_d00`000U;m00iC7Dkm
D_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@0:EaeG75/mEcaK?ELLFceG?5mL
Gc`6He`4Ig/02gNhLiQg^7NHNkMg]WNgNkEk]7^CNk@00W^e00EkTg^cNi9k/g^B009kT@04Nk9kTG^b
Ni82Nk82Nk@01G_FMkEg]WNgMmP00g>i0VnJ00MWO6=LIgaO?6=LGeaSG004Fa`015LLFaaFo5LL0eKl
00EG75;lE_aBo5Kl00=Bo003E_aBo5;l00YBo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`00
01=oo`008Goo00<007ooOol09Woo00<007ooOol0:7oo00A>oE<MC_aC7@<0001ADae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK?ELL
FceG76=LHe]SO6=KHeaSFf]lIg]WO6MKKi][NVnKJgYk]gNFNkMgUG^fMiIk]gNENkIkUG^dNi9o/g^A
Nk9gTG^bNi5k/WNANk9gTW^cMk=ke7NeNmIc]gOH00=c^@1GKk]_VVnkJiYSG5llHeaO>f=LGcaSG5Kl
FaaG75/LE_aK75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
D_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`0001=oo`008Goo0P00:7oo0P009Goo00=BoE<MC_d0
0U;m0P000U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<M
D_d00eLM00QG75LMEaeG7ELLFceG?5/m0e/l0f=L1FMk00U_Vf]jJi][NW>JKiUcVWNHMkP00gNg0W^e
0W^d00Ak/g^BNi9kT@9kTP9kT@03Nk9kTG^b009k]004MkEg]WNgMmP3LkT4KiX01F^KIg]SG5mLHe`0
15ll00IG75/LEaaG75KlEa`6E_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo008D]aB
o5;lD_aBg5;lOol0019oo`008Goo00<007ooOol0:Goo00<007ooOol087oo00AC7DklDae>o@<0001D
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<M
D_aG7E<LEaeC75LMDaaG7E/lGceK?5lmFcaO?E/lGceWFf]lIg]WO6MKKi][NVnKJgYc^VnILiYcV7Ni
LiQk]gNFNkIkUG^eNi=o/g^BNk9gTG^bNi9k/WNANk9gTG^cMi9ke7NcNmIc]gOH0g>i05Y_^fnJKk][
VV^LIg][VfMkGcaK?5llFaaO?5/lGcaFo5/LE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl000BOol0021o
o`03001oogoo02]oo`03001oogoo01aoo`04Dae>oE;mD_d300000e;mDae>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@QC7@=G7@04EaaG7ELMEcd3Fc`01E/m
FcaK?5llGe`00fMk00Y_Vf]jJi][NVnKKiUcVWNHMkQcV09g]`03NkMk]G^e009k]004Ni9k/g^BNk<4
Ni801G^ANk9k/W^dMk@00W^b00Ak]7NdMkIg]@A_VP06Ji]WNf]kJg]WO6=K0ell00EK?5/LFaaK?5Kl
00=G70AFo004D_aFo5KlE_`3D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00U;l00<005;LD_`00U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo003D]aoo`00015oo`0087oo00<007ooOol0;7oo00<007ooOol05Woo00IC7DkmDae>o5<MC_d3
0000^DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aC7DklEaeBo5<MD_aG7E;lDaeC75LMDaaG?ELLEceG75LmFcaO?E/lGeaO?5mMGcaOG5llKi][NVnK
JgY_VfnILiY_VGNiLiQg^7NFNkMkUG^eMiEo]7^BNk=kTGndNi9k/g^ANk9gTG^bMi9k/gNANk9gTW_D
Mk=keWNeMmQg]gOHLkM[W6MkJi]SFfMlHe]WO6=KFcaK75/lFaaK?5/LEaaFo5/LE_aG75;lE_aBo5Kl
D_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg7oo000047oo000POol00`00Ool0000]Ool00`00Oomoo`0COol00e;mDae>o@02D_d3
00000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M
00=Bo@06DaeBoE<MD_eC7E;m1e<M00EG75LMEaeG?ELL009G7@08EceO?5mLGcaOG5llGeaO?09SG00<
Ji][NVnKKiUcVVnIMkQcV7NhMkMk]gNg0W^e00ik]7^CNk=kTW^dNi9k/g^BNk9kTG^bNi9k/g^A0W^b
00Ek/gNdNkAg]G_F00=g]`=c^@04HeaWO6=KIg`2He`015llFaaK75/l0e/L00EG75KlE_aFo5LL009F
o006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l001Bg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l0P0047oo000POol2000_Ool00`00Oomoo`0?Ool01DkmDae>o5<MC_d00`0006=>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC
7DklDaeBo5<MD_aG7E;lDaeBo5LMDaaG7ELLEceG75LmEaaG?ELLFceO?5mMGcaOG5llHgaSFf=LHe]S
O6nILiY_VGNiLiQg^7NFNkMgUW^eMiEk]W^CNk=kTW^fNi=k/g^BNk9kTG^bMi5k/W^ANk9gTG^cMk=k
]7NeNmIg]gOHLkL00g>i00i[VVnkHe]WO5lkHeaO?6=LGc]SG5LLFaaFo5/L0ULL04YBo5LLD_aFo5;l
E_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aoo`003goo0005Ool50005Ool20005Ool40006Ool00`00Oomoo`0_Ool00`00
Oomoo`0<Ool015<MC_eBoE;m0`0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_d4Dad01ULMDaeC
7E<MEaeG709G7@07FceG75/mEcaK?EllGe`01V=L0fMk00Eg^7>HMkQgV7^g009g]`9k]@0<Ni=k]7^e
NkEkU7^dNi9k/W^BNi5kTW^b0W^A00=kTW^cNk800W^d00AkeWNgMkMg]`=c^@0AKiY_^VnJKiYOG6=L
GcaSG5mLHeaK?5llEaaK75LLFaaG7007E_`00e;lE_aBo00?D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg002D_`2Ool00`00Oomoo`0<Ool000Aoo`800005Ool00000Ool00004Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool01E<MC_aC7DkmDad0
0P0006M>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK
?ELLFceG75/mHe]SO6=KHeaSFf=lIg]WO6MKKi][NVnKJgYk]gNFNkMgUG^fNiEk]gNENkIkUG^dNi9o
/g^ANk9gTG^bNi5k/WNANk9gTW^dMk=keWNeMmQc]`03LkT036^JKk]_VVnkIg][W5llHeaO>ellFcaO
?09K7004EaaK75KlFa`2E_`0BE;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0000ioo`0017oo0P000Woo
00<007oo00003goo00<007ooOol00goo00<007ooOol0<Goo00<007ooOol01Goo00A>oE;mD_eC7@<0
0006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;m
D_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00=BoE<MDad015<M00=G7E<MEad00ULM00EG
75/mEcaK?ELL009K?004FceSG6=LHe`4Ig/02VnKJgY[Vf]jLiY_VG>JMiQg^7>H0WNg0W^e0W^d00Ik
/g^BNi9kTG^cNi82Ni43Nk82Nk@00gNeMkMg]`03LkT026nJKkY_VVnJJg][VfMkJg/2Gc`01E/lGcaO
?5llFc`00eLL00=Fo5LLE_`01EKl0e;l00=Fo5;lD_`03U;l00EBg5;lD_aBo5;L00=Bo005D]aBo000
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00U;l00=oo`00Ool037oo0004Ool20002Ool00`00Ool0000?Ool00`00Oomoo`02Ool2
000dOol02000OomoogooC_aC7DkmDad30000OE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7Dkl
DaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeC75LMDaaO?E/lGceK?5lmFcaO?E/lJgaWNfMlIe]_Vf]j
Ki][NW>jKiUcVVnIMkUcV7NiMiIk]W^ENkEkTgncNi9k/W^AOk=kTG^bMi5k/WNANk=g/g_DMi9k/gNc
NmAg]G_FJiY_^fnJKk]WNf^LIg][Vf=KIgaK?5llFaaO?5/LFc`00U/L04mFo5LLE_aK75;lE_aBo5Kl
D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LOol0000<Ool000Aoo`80009oo`03001oo`0000]oo`@000Eoo`03001o
ogoo039oo`03D_eC7Dkm009Bo@06Dad00000001C7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m
00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM00EG75LMEaeG?ELL009K?006FceK?5/lGcaO
G5ll0VMk00e_Vf]jJi][NVnKKiUcVVnIMkQcV7NhMkMk]`02NkD2Nk@3Ni801W^dNi9kTW^ANi9kT@=k
/P08Ni5k/W^dNkAg]GNfMkMgf09g]`0:Jg][VfMkIgaSG6MlHe]WO5/LFc`3Fa`01E/lFaaFo5KlEa`0
15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo008D]aBo5;lD_aBg5;lOol000aoo`000goo0`0000Eoo`00001oo`0000]oo`03001oogoo00Io
o`03001oogoo031oo`05Dae>o5<MC_eC7@030000ME<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5<MDaaG7E<LEceG75LmEaaG?E/lGceK?5mLGcaO
GEllGeaO?6nKJgY_Vf]jKi]_VG>JKiUg^G>HMkUcV7^gNiEk]GNEOkAkTg^cNi=o]7^BNk9kTG^bMi5k
/WNBNk9gTG^cMi9ke7NcNmIg]GOHMkMgf003LkT0GFMlHe]WO6=KIgaO>f=LFaaK?5/LFcaG75/LE_aG
75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg000D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol0000;Ool000Eoo`03001oogoo009oo`03
001oogoo00Uoo`03001oogoo00Ioo`03001oogoo02eoo`05Dae>oE;mD_eC7@0300001U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d7Dad01ELL
EaeG7ELmEa`00ULM00QG?EllGeaO?5mLGcaOG5ll0V=L00a[Vf]jKi]_VG>JKiUg^7>HMkQgV7^gMkL2
NkD03W^dNiAk/g^eNkAkU7^cNi9k/W^ANk9kTG^BNi42Nk801G^dMkAg]WNeMmP00WNg0g>i0VnJ00eW
O6=KHeaOG6=LGcaSG5LLFaaG75/LEaaK7006E_`01U;lE_aBo5KlD_aFo0aBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg5;l0P002Woo0006Ool4000<Ool50004Ool0
0`00Oomoo`0[Ool014klDae>oE<M0`0007UC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E<LEaeG75LmEaaG?ELLFceG75/m
GcaOGEllGeaO?6=lHe]SG6=KHga_VG>JKiUc^W>HMkUcV7^gMiIk]GNENkIkTg^dMiEo]7^CNk=kTW^b
Ni5k/W^ANk9kTG^bMi9k/gNcNkAg]GOHMkMgf003LkT01fnkJiY_^fnJHeaO>f=L009O?01GFaaO?5LL
FaaFo5/LEaaK75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0000Yoo`007goo00<0
07ooOol0:7oo00E>oE;mD_eC7Dkm00800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@0BDae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00mG7E<MDaeC7ELM
DaeK?ELlFceG75/mEcaK?EllGe`01V=L16Mk00AcV7NhMiQg^09g]`9k]@9g]`9k]@06NiAk]7^BNk9k
TW^A0W^B00QkTG^bNi9k/gNdNkAg]G_F0WNg0W>i0fnJ00I_^VnJJg][Nf^KFc`3Gc`01E/lGcaG75LL
E_`00eLL1EKl0U;l00=Fo5;lD_`03U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01@00
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L008000Uoo`007Woo0P009Goo00M>oE<MC_aC7DkmDae>o0030000O4klDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7E;lDaeBo5LMDaaG7E;lEaeC75LMDaaK?ELLFceG75/mEaaK?F=KHgaSFf=LHe]SO6MKIgaWFf]l
JgY_Vf]jKi]gUW^gLiQg^GNFNkMgUW^fNi=k]7^BOk=kTG^bNi9k/W^ANk9gTG^bMi9k]7NcNmIg]gOH
0W>i00a_VVnkJiY_^fMkJi]WNf^LHe]WO5/LGc`2Fc`0EU/LFcaFo5LLE_aK75KlEaaBo5KlD_aFo5;l
E_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0009Ool001ioo`03001oogoo029oo`06Dae>oE;mD_eC7Dkm
0`0000E>oE;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@0>DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeG7003Ead01ELLFceG?5/m
Ea`00U/l00AK?F=LHeaSG0EWN`09JgY[Vf]jKi]_VG>JMiQg^7>H009g]`9k]@9k]008Nk=kTW^BNi5k
/W^BNi5kTP9k/P9k]005Nk=k/W^dNkAkeP03MkL02GOHIg][Nf]kJi]SFfMlHeaWO003Fa`00e/lFaaG
7002Ea`3E_`00eLLD_aFo002E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo00000Uoo`007Woo00<007ooOol087oo
00E>o5<MC_eC7Dkl00<00026C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E<L
EaeC75LMDaaO?E/lGceK?5lmFcaO?E/lJgaWFfMlIe][O6]jKi][NVnKKiUcVVnIMkUcV7^gMiIk]g^E
NkAkTgncNi9k/W^AOk=kTG^bMi5k/WNANk=gTG^bMi9k]7NcNmIg]GOHLkMgf09c^@0BIg][W6=KIgaS
FfMlGcaSG5/LFcaK75/lFaaG75KlEaaBo5LL0UKl04MBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L00Aoo`03
001oogoo00Moo`007Woo00<007ooOol07Woo0U;m00=C7Dkm00000P0000E>oE;mD_eC7Dkm009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC
7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_d7Dad2Ead01ELLEaeG7ELmEa`00U/l00IK?E/lFcaK?5mLGc`3
Ig/036]jJi][NVnKKiUcVVnIMkQcV7NhMkMk]`9k]@9k]0=kTP08NkAkTW^BNi5k/W^ANk9kT@=k/P9k
]004MkEg]gNgMmP4LkT026=KIgaSG6=LGcaSG5mLFc`2Fa`00eLLFaaG7002E_`00eLLE_aFo002E_`0
15;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l1goo00<007ooOol01Woo000NOol00`00Oomoo`0KOol015<MC_eC7Dkl0`0008]>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMEaaG?ELLEceG
75LmEaaO?E/lGceO?5mMGcaOG5llGee[NVnKJgY_VfnILiY_VGNiLiQg^GNFNkMgUW^eNi=o]7^BNk=k
TgndNi9k/W^ANk9gTG^bMi5k/WNANk=g/g_DMkEkeW>gMmQg]`03LkT0EVnJKk][VV=LGcaSG5lkHeaO
?5/LE_aK75LLFaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L001Bg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`:Ool00`00Oomoo`06Ool001eoo`8001Qo
o`06Dae>oE;mD_eC7Dkm0`0000E>oE;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;m
DaeBoE<MD_eC7E;mDaeBo@AC7@06EaeC7E<MEaeG?ELL0ULM00UG?ELLGeaO?5mLGcaOG5llGe`016=L
00U_VG>JKiUg^7>HMkQg]g^gMkL00W^e00Mk]7^DNkEk]G^dNiAk/`02Ni801G^ANk9kTW^BNi400W^b
00Ik]7NdMkIg]gOHMkL3LkT3KiX01V^KJg]SG5mLHeaK?09O?003FaaG75/L009G7003E_aG75Kl00EF
o0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l3Woo00<007ooOol0
1Woo000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@80002?C_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMDaaG7E;lEaeG75LmEaaG?ELLFceG
75mMGcaOG5llHgaSFf=LHe]SO6MKIga_VG>jLiQg^G>HNkMgUW^gMiEo]7^CNkEgUGndNi=k/g^BNk9k
TG^bNi5k/WNANk9gTW_DMk=keWNeMmQg]`02LkT0D6nkKiY_^f^JJiaWNf^KIg]O?5/lGcaK75llFcaG
75KlFaaFo5LLE_aK75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_`005;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]`COol00`00Oomoo`06Ool001eoo`03001oogoo01=oo`9Bo@03Dae>oE;m00<0009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE<MD_eC7E;mDaeBoE<MD_eC7E;m
DaeBo@9C7@05EaeC7E<MDaeG7@02Dad025LlFceG75/mEcaK?ELLFcd6He`4Ig/017>HMkQgV7^g0WNg
0W^e0WNg0W^e015kU7^dNi9k/W^BNk=kTW^bNi5k/W^BNk=g]7^dMkEgf7Ng009c^@05KkY_VVnJKiY[
V`03Jg/00fMlHe]O?002Gc`3Fa`00eLLE_aG7002Ea`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L
00=Bo006D]aBo5;lD_aBg5;l5Goo00<007ooOol01Woo000MOol00`00Oomoo`0AOol014kmDae>o5<M
0`000>9C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75LMEaaK?ELLFceG75/mFcaO?F=KHeaSFf]lIe]WO6MKJga[
NVnKJgYcVVnILiYcV7NiMiIk]gNENkIkTg^dNi9o/g^ANk9kTG^bNi5k/WNANk=g/g^dMi9k/gNcNmIg
]GOHMkMgf7>gJiaWNf^KHe]WO6=KIgaSFe/lFaaK?5/LFcaK75LLD_aG75KlEaaBo5KlD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg1Moo`03001oogoo00Ioo`007Goo0P00
3goo00ABoE<MC_eBo@<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;m
D_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@05EaaG7ELlFceG
7002Fc`015/mFcaK?5/l1FMk00U[NV^KJgYcVVnILiY_VGNhLiP00WNg0W^e0W^d00Qk/g^BNi9kTW^b
Ni9kTG^B0g^b00IkTW^cMkAk]7NeNmH3MkL3LkT01f=LIgaSFfMlGeaSG5ll009K7003FcaG75/L009G
70=Fo009EaaFo5KlD_aFo5;lE_aBo5Kl00QBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg0000U;l00=Bg7ooOol06Woo00<007ooOol01Woo000M
Ool00`00Oomoo`09Ool01TklDae>oE<MC_aC7@<0002LDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC
75LMDaaG7E<LEaeK?5lmFcaO?E/lGceK?5mMGcaWO6MKKi][NVnKJgY_VfnILiY_VGNiLiQk]gNFNkIk
UG^eNi=o/g^BNk9kTgncNi5k/WNANk9gTW^bMi5k/gNBNkAg]G_FMkMgf7>g0g>i049[VVnkKiYSG5lk
HeaO?6=LGc]K75LLFaaFo5/LEaaFo5;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo
000OOol00`00Oomoo`05Ool001eoo`03001oogoo00Moo`9Bo@03Dae>oE;m00<0009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08
DaeBoE<MD_eC7E;mDaeBo@QC7@09EaeG75LMEaeG?ELLEaeK?5/m009K?00?GcaOG5llGeaO?6^KJgY[
Vf]jJi]_VG>JKiUg^7>H009g]`03NkMk]G^e009k]004Ni9k/g^dNk<2Ni801G^ANk9kTG^ANi800W^b
0W^d00AkeWNgMkMg]`=c^@03KiY_^VnJ009[N`03HeaO?6=L009O?005FcaK75LLFaaFo002Ea`6E_`2
D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`00e;LOomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`05Ool001eoo`03001oogoo00Eoo`04C_eC
7DklDad30000X5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMD_aG?ELLEceG75Lm
EaaG?ELLGeaO?5mMGcaOG5llHgaSFfnKJgY_VfnILiY_VGNiLiQk]gNFNkMkUG^eMiEo]7^ENkEgUGnd
Ni9k/WNANk9gTG^bMi5k/WNBNk=g/g_FMkEgf7>g0W>i00e_^f^JKk]_VV^KIg][W6MkGcaK75llFcaO
?002Fa`0;eKlEaaFo5/LD_aFo5;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`027oo00<007ooOol06goo00<0
07ooOol01Goo000MOol01000Oomoodkm0U;m00AC7DkmD_eBo@80009Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;m
Dad00e;m00QC7E;mDaeBoE<MD_eC7E;m25<M00aG?ELLEaeG7ELmEaaK?ELlGeaO?5mLGc`5He`02FnI
LiY_VG>JLiQg^7NgNkMg]`02NkD01g^dNkEk]G^eNkAkTW^c00AkTP04Ni5kTW^ANk82Nk@00gNeMkMg
]`02LkT2KiX03VnjKiY[Nf]kJi][NfMlHeaO?5/lGcaK75/lFa`3Ea`01EKlEaaFo5KlD_`00eKl0e;l
00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l37oo00<0
07ooOol06goo00<007ooOol01Goo000LOol02000OomC7DkmDae>o5<MC_d30000gDkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lEaeC75LmEaaG?ELLFceG75/mEaaO
G5llHgaSFf=LHe]SO6MKIgaWFf]lLiQg^GNFNkMgUW^eMiEk]WNFNkEgUG^fNi=k/g^ANk9kTW^bNi5k
/WNANk=gTW_DMi9k/gNcNmIg]GOHLkMgf7NgJi]WNf^LHe]WO6=KIgaSFe/lFaaK?5/LFcaK75LLE_aG
75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]`04Goo00<007ooOol06Woo00<007ooOol01Goo000LOol00`00Dae>o@02D_d30000
0e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00=BoE<MDad0
15<M00aG7E<MDaeC7E/mEaaK?ELlFceG75/mEc`5He`4Ig/02F]jJi]_VG>JKiUg^7NHMkQg]`03NkD0
17^DNk=kTW^b17^B00IkTG^bNk9k/W^ANk82Nk@01GNeMkIg]gOHMkL00g>i00QSFfMlHeaWO6=KHeaO
G5/l0U/L00=G75/LEa`00UKl00UG75KlE_aBo5KlD_aFo5;lE_`00e;l00=Fo5;lD_`01U;l00EBg5;l
D_aBo5;L00=Bo003D]aoogoo01Eoo`03001oogoo01Uoo`03001oogoo00Eoo`004Woo1@001Goo00<0
04km00000P000:e>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeB
o5<MD_aC7E;lEaeC75LMDaaG7E<LFceG75/mEaaK?E/lGceK?6=LHe][O6MKIgaWFf]lJgY_Vf]jLiY_
VG>JLiQg^G>HNkMgUG^fNiEk]7^BOk=kTg^cNi5k/W^ANk9gTW^bMi5k/gNBNmAg]G_FLkMgf7Ng00=c
^@0/KiY_^f=KIgaO?6=LGc]SG5llFaaFo5/LEaaK75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo1Yoo`03001oogoo01Qoo`03001oogoo00Eoo`00
57oo00<007ooOol01Goo0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7Dkm
D_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@04EaaG7ELMEad3Fc`015/m
FcaK?5/l1FMk00Y[NV^KJgYcVVnILiYgV7NhLiQg]`=k]@07NkAkTW^cNi9k/g^BNk800W^A0W^B00Uk
TG^bNk9k]7NdMkIg]gOHMkL00g>i0fnJ00I_^UllHeaOG6=LFc`2Gc`00e/LEaaK7002Ea`6E_`00e;l
E_aBo00?D_`00e;LD_aBo00LOol00`00Oomoo`0IOol00`00Oomoo`04Ool001Aoo`03001oogoo00Io
o`2_001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E;lDaeC75LMDaaG7E<LEceG75LmFcaO?E/lGceK?5mMGcaWO6MKJga[NVnKJgYcVVnILiYc
V7NiLiQg^GNFNkIkUG^eNi=o/g^BNkAkTW^bNi5k/WNANk9kTG^bMi9k/gNcNmIg]GOHMkL00W>i02U_
^fnJKk][VVnkIg][VfMkGcaK?5llFaaO?5/lEaaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aF
o5;LE_aBg5KlD]aFo5;LE_aBg5Kl025oo`03001oogoo01Qoo`03001oogoo00Aoo`0057oo00<007oo
Ool01goo0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@06DaeBoE<MD_eC7E;m25<M0ULM00EG?ELLEaeG7E/m009K?00AGcaOG5llGeaO?5mLJgY[Vf]jJi]_
VG>JMiQg^7>HMkQg]`03NkD00g^dNkEk]@02Nk@01G^cNi9kTG^ANk800g^A00Ik/gNdNkAg]GOHMkL2
LkT01FnjKiY_VVnJJi/00f]k00=WO6=KGc`00Ull0e/L00=G75KlEa`00ULL00ABo5KlE_aFo0=Bo003
E_aBo5;l00MBo2Ioo`03001oogoo01Moo`03001oogoo00Aoo`0057oo00<007ooOol02Goo0=4007oo
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E<L
EaeBo5LmEaaG?ELLEceG75mLGcaOGEllGeaO?5mMHe]SG6=KHga_VG>JKiUg^G>HMkUgUW^gNiEk]GNE
NkMkUG^eNi=o/g^ANk9gTG^bNi5k/WNANk9gTW^dMi9k/gNcNmIg]GOHMkMgf7>gJiaWNf^KHe]WO6=K
IgaSFe/lFaaK?5/LFcaK75LLD_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl02Qoo`03
001oogoo01Moo`03001oogoo00Aoo`0057oo00<007ooOol02Woo00@007ooDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@0>Dae>oE<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@9C7@06EaeC7E<MDaeG
7E<M0ULM00QG?ELLFceG?5mLGcaOG5ll1F=L0fMk00Eg^7>HMkQgV7^g00=k]@03NkMk]G^e009k]09k
TP05Ni5kTW^BNi9kT@02Nk801g^dNi5k/gNdNkAg]G_F00=g]`=c^@04HeaWO6=KIg`2He`01UllFaaK
75/lEaaK709G70=Fo005EaaBo5KlD_aFo003D_`00eKlD_aBo00/Ool00`00Oomoo`0FOol00`00Oomo
o`04Ool0019oo`<000eoo`2/001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMD_aK?ELLFceG75/mEaaK?F=KHgaSFf=LHe]SO6MKIgaWFfnK
JgY_Vf]jLiYcV7NiLiQk]gNFNkEgUGndNi9k/g^AOk=kTW^bMi5k/WNANk=gTG^cMi9k]7NeNmIg]gOH
LkL3LkT06F^JKk]SFfMlGc]SG5llHeaO>e/LEaaK75KlFaaG75KlD_aG75;lE_aBg5KlD_aFo5;L035o
o`03001oogoo01Eoo`03001oogoo00Aoo`0057oo00<007ooOol037oo0P0000IoodkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@9C7@9G7@05
EaaK?ELlFceG7002Fc`015/mHeaSG6=L16Mk00Y[Vf]jJi][NW>JKiUg^7>HMkQg]`9k]@07NkAkU7^c
Ni9k]7^BNk<00W^B00=kTG^bNi400W^b0W^d00AkeWNgMkMg]`=c^@08KiY_^VnJKiYOG6=LGcaSG09O
?005FcaK75LLFaaFo002Ea`5E_`fOol00`00Oomoo`0DOol00`00Oomoo`04Ool002Eoo`2W001oodkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7E<L
GceK?5lmFcaO?E/lGceK?6]lIe]WO6MKKi][NVnKJgYcVVnIMkUcV7NiMiIk]gNENkIkTg^dNi9o]7^B
Nk=kTG^bNi5k/WNANk9gTW^cMk=keWNeMmQc]`02LkT03FnkJiY_^fnJKk]WNf^LIg]O?5/LGcaK?5ll
009K7007E_aG75KlFaaBo5KlD_`0>7oo00<007ooOol05Goo00<007ooOol00goo000VOol00`00Oomo
o`02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@MC7@9G7@05EaaG7ELM
EaeG7002Fc`01U/mFcaK?5/lGeaO?09WN`09Ji][NV^KJgYcVVnILiYcV7Nh009g]`9k]@0:NiAk]7^B
NkEkU7^cNi9k/W^ANk82Ni801G^ANk9k]7^dMkD00WNg0W>i0VnJ00i_^VnJJg][Nf^KJg]WO6=LGcaK
?5llFaaK?5/L0eLL00=Fo5LLOol0>Woo00<007ooOol057oo00<007ooOol00goo000WOol0]`00Oomo
oe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeG75LmEaaK?ELLEceG
75lmFcaO?EllGeeO?5mLGca_Vf]jKi][NW>JKiUcVW>HMkUgUW^gMiIk]W^ENkAkTg^fNi=k]7^BNk9k
TG^bNi5k/WNANk9gTW_DMi9k/gNcNmIg]GOHLkMgf6MkJi]WNf^LHe]WO6=KIgaSFe/lFaaK?5/LFcaK
7010Ool00`00Oomoo`0COol00`00Oomoo`03Ool002Qoo`800005OomBoE;mDae>o@02D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00aC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_d4Dad00eLMDaeC7@02Ead02eLLEaeG7ELMEaaOG5llGeaO
?5mLGc`016=L00IcVVnILiY_VGNhLiP2MkL2NkD2MkL2NkD027^dNi9k/g^BNi5kTW^bNi42Nk800g^d
Ni5k/P02Nk@017NeMkIg]gOH0g>i00UWO6=KIgaSG6MlGcaSG5mLFc`00U/L@goo00<007ooOol04Woo
00<007ooOol00goo000ZOol0X`00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG
7E<LEaeBo5LMEaaG?ELLFceG75/mEaaOGEllGeaSFf=lHe]SG6=KJgaWFfMlIe]g^G>HNkMgUW^gLiQg
^GNFNkMkUG^dNi=o/g^ANk9kTW^bNi5k/WNANk=gTG^cMi9ke7NeNmIc]gOH00=c^@0:Kk]_VVnkGc]S
G5llHeaO>f=LGca5Ool00`00Oomoo`0BOol00`00Oomoo`03Ool002]oo`06001ooe;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d6Dad02eLMDaeC7ELlFceG75/mEcaK?ELLFcd01F=L
16Mk00U[Vf]jLiY_VG>JLiQg^7NgNkL00W^e00Mk]7^cNi9kTW^dNk=kTP02Ni402W^cNi5k/W^bNkAg
]7NfMkMgf7Ng0W>i00U_^VnJKiY[Nf^KGcaSG5mLHe`0B7oo00<007ooOol04Goo00<007ooOol00goo
000/Ool0X000OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75LMEaaK
?ELLFceG75lmFcaO?F=KHeaWFf]lIe]WO6MKKi][NVnKKiUcVVnIMkUcV7^gMiIk]GNEOkAkTW^bNi=o
/g^ANk9gTG^bNi5k/WNBNk=g/g_FMkEgf7Ng0W>i00M_^fnJKk]WNf^LIg][V`1<Ool00`00Oomoo`0@
Ool00`00Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EB
oE<MDaeG7ELL00=G7@04EaaG7ELMFcd3Fc`00e/mFcaK?004Ig/02f]jJi][NV^KKiUcVVnIMkQcV7^g
MkL00W^e00=k]7^DNk<00W^d0W^B00=kTG^bNi800W^A00Ik/gNdNkAg]GOHMkL2LkT01fnjKiY_VV]k
Ji][Nf^K04ioo`03001oogoo011oo`03001oogoo009oo`00;goo0:<005<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7DklDaeBo5<MD_aG7E;lEaeC75LMDaaG7ELLFceG75lmFcaO?E/lGceO?5mMGcaOG6]jKi][NVnKKiUc
VVnIMkUcV7NiMiIk]gNENkIkTg^cMiEo]7^BNk9kTG^bNi5k/WNANk9gTW^dMi9k/gNcNmIg]GOHMkMg
f6MkJiaWN`1@Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool0031oo`05001ooe;mDae>o@02D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03
D_d01U<MD_eC7E;mDaeBo@MC7@05EaaG7ELMEaeG7002Ead01e/mFcaOG5llGeaO?5mL009SG008JgY[
Vf]jLiY_VGNhLiQg^09g]`9k]@08NiAk]7^eNkAkU7^cNi9k/P9kTP0<Ni5k/W^bNkAkTG^cMkAk]7Ne
NmIg]gOG0g>iDWoo00<007ooOol03goo00<007ooOol00Woo000aOol0W`00Oomooe<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MC_aG7E;lDaeBo5LMDaaG7ELLFceG75LmEaaK?ELLGeaO?5mMGcaOG6=KHgaSFf=LHe]cVVnILiYc
V7NiLiQk]gNFNkIkUG^gMiEk]W^CNk=kTG^bNi5k/W^ANk9gTG^cMi5k/gNBNkAg]G_FMkMgf7>iLmUc
^@1DOol00`00Oomoo`0>Ool00`00Oomoo`02Ool0039oo`05001oogooDae>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE<MD_eC7E;mDaeBoE<M
D_eC7E;mDaeBo@9C7@06EaeC7E<MDaeG7ELL0eLM00EG75/mEcaOG5ll00ISG0=WN`03LiQg^7>H009g
]`0;MkQcV7NgMkMk]G^DNkAkTW^bNi9k/`02Ni800g^ANk9kT@02Nk82Nk@017_FMkMgegNg0W>iEGoo
00<007ooOol03Woo00<007ooOol00Woo000cOol20000VGooDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMDaaG7E;l
EaeC75LMEaaK?ELLFceG75/mEaaSG6=KHgaSFf=LIe][O6MKIga[NVnKJgYcVVnIMkUcV7NiMiIk]W^E
NkAkTW^bNi5k]7^BNk9kTG^bMi5k/WNBNk=g/g_FMkEgf7>gLmUc^@1GOol00`00Oomoo`0=Ool00`00
Oomoo`02Ool003Eoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MC_eBoE;mDad00e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05D_eC7ELMEaeG7003Ead015LL
FceG?5/m0e/l00=K?E/lIg/016Mk00][NV^KJgYcVVnILiYcV7NhMkMk]g^e009k]007Nk=kU7^dNi9k
/W^ANk800W^B00MkTG^bNkAk]7NeMmMg]`02LkUIOol00`00Oomoo`0<Ool00`00Oomoo`02Ool003Io
o`2G001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7E;lDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7E<LGceK?5lmFcaO?E/lGeaO?6]lIe]_
Vf]jKi][NW>JKiUcVW>HMkUcV7^gNiEk]W^COk=kUG^dNi=o/g^ANk9kTG^bMi5k/WNBNmAgTW^cMk=k
e7NeNmH0FWoo00<007ooOol02goo00<007ooOol00Woo000gOol01000OomC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@MC
7@9G7@05EaaG7ELMEaeG7002Fc`04E/mGcaOG5llGeaO?6^KJgY[Vf]jLiY_VG>JLiQg^7>HNkL00W^e
0W^d00Ak]G^dNkAk/`=kTP07Nk9kTG^bNk9k]7^ANk800W^d00=g]GNfOol0FWoo00<007ooOol037oo
00<007ooOol00Goo000hOol20000TU<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7ELLEceG75/mEaaG?ELLGeeO?5mL
GcaOGEllHeaSFf=lHe]cVVnILiY_VGNiLiQk]gNFNkIgUG^gMiIk]W^COkAkTW^bMi5k/W^ANk9gTG^c
Mi5k/gNBNmAg/g_FMkELOol00`00Oomoo`0;Ool00`00Oomoo`01Ool003Yoo`03001oodkm009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeB
oE<MD_d4Dad00eLMDaeC7@02Ead025LLEaeG?5/mEaaOG5llGe`5He`4Ig/02GNhLiQg^7NgMkQcV7^g
MkMk]@02Nk@01G^BNk=kTW^cNi800W^A00Qk/g^ANk9k/W^dMkAg]WNeGWoo00<007ooOol02Woo00<0
07ooOol00Goo000kOol0T000Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E<LEaeBo5LMDaaK?ELLFceG75/mEaaK?F=KHeaSFf=l
He]WO6MKJgaWFfnKJgY_VfnIMkUcV7NiMiIk]gNEOkAkTg^cNi5o]7^BNk9gTG^bNi5k/WNBNk=g/g^d
MkEkeUmoo`03001oogoo00Uoo`03001oogoo005oo`00?7oo00<007ooOol00U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@04D_eC7E<MEad3Dad0
2ELMEaaG7ELMFceG75/mEcaK?@02Fc`2He`5Ig/01f^KJgY[VfnILiYcV7Nh009g]`9k]@04NiAk/g^B
Nk@2Ni800g^ANk9kTP02Ni401G^cMkAk]7NeNmH0H7oo00<007ooOol02Goo00<007ooOol00Goo000m
Ool20000RgooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MD_aC7E;lDaeC75LMDaaG7E<LEaeG75/mEaaO?E/lGceK?5lmIe]WO6MKJgaWFfnKJgY_VfnILiYc
V7NiLiQk]gNFNkIkTg^dNi9k]W^CNk=kTG^bNi5k/WNANk9gTW^dMk=k/gNB065oo`03001oogoo00Qo
o`03001oogoo005oo`00?goo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eB
oE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@04EaaG7E/lFcd3Fc`00e/mGcaO
G003Ig/026^KJgY[VfnILiY_VGNhLiP2MkL2NkD01g^dNkEk]G^DNk=kTW^b009kTP03Ni5k/W^b009k
]09k/V=oo`03001oogoo00Moo`03001oogoo005oo`00@7oo08T007ooDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lDaeBo5/mEaaG?ELLFceK?5lm
FcaOGEllGeaO?5mMGca_Vf]jKi]_VG>JKiUg^G>HNkMgUW^gNiEk]7NFNkIkUG^dNi9k/W^ANk9kTG^b
Mi5k/gNANk9gTW^c06Aoo`03001oogoo00Moo`40005oo`5oo`00@Goo00H007ooOomBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m1U<M00=G7E<MEad00ULM
00UG75LMEaeOG5llGeaO?5mLGc`00f=L00Q_VG>JKiUcVW>HMkQg]g^g0W^e00=g]g^eNkD00W^d00=k
/g^BNk<00W^B00IkTG^bNi5k/W^ANk9UOol00`00Oomoo`07Ool10001Ool1Ool0049oo`800024Oom>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeC75LMD_aG7E<LEaeG
75/mEaaG?ELLFceG75mLGcaOGF=KHeaSFf=lIe]WO6MKJgacV7NiMiIk]gNFMkUgUW^gNiEk]W^COk=k
TG^dNi9k/W^ANk9gTG^bMi5k/gNBIWoo00<007ooOol01Woo0@000Goo0Goo0014Ool01@00OomBoE<M
C_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@9C7@0<EaeC
7E<MDaeG7ELLFceG?5/mEaaK?ELl16=L1FMk00Q[NV^KKiUcVVnIMkQcV7^g0W^e0W^d00IkTW^dNi9k
/W^ANk82Ni800g^ANk9k/P1XOol00`00Oomoo`05Ool10001Ool1Ool004Eoo`22001oodkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7ELLFceG75/m
FcaO?E/lGceK?6]lIe]WO6MKJga[NVnKKiUcVVnIMkUcV7^gMiIk]WNEOkAkTW^fNi=o/g^ANk9kTG^b
Ni5k/WNBNk=XOol00`00Oomoo`05Ool10001Ool1Ool004Ioo`05001ooe;mDae>o@02D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;m
D_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1U<M00=G7ELLEad00ULM00AG75/lFcaK?@=K?00>
GeaO?6MkIg][Vf]jJi][NW>JKiUcVW>HMkQg]`9k]@05NkAkU7^eNkAk/`02Ni800g^CNk9kT@02Ni40
0g^cOomoo`1XOol00`00Oomoo`04Ool10001Ool1Ool004Moo`80001mOomC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMDaaG7E<LEaeG75LmEaaO?E/lGceO?5mMGcaOG5ll
Ki][NVnKJgYcVVnILiYcV7NiMiIk]gNENkIkTg^fMiEo]7^BNk9gTG^bNi5k/WNANk=kT@1[Ool00`00
Oomoo`03Ool10001Ool1Ool004Uoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eBoE;m
DaeBoE<MD_d7Dad2Ead02eLLEaeG7ELMEaaOG5llGeaO?5mLGc`016=L00McVVnILiYcV7NhLiQg]`02
NkD02GNGMkMk]G^dNiAk/g^BNk=kTP02Ni400g^bNi5oo`1/Ool00`00Oomoo`03Ool10001Ool004Yo
o`1k001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMDaaG7E;lEaeG75LmEaaK
?ELLFceG75mMGcaOG6=KHgaSFf=LHe][O6MKIgacV7NiLiQk]gNFMkUgUW^gMiEk]W^CNk=kTGndNi9k
/WNANk9kTG^b06eoo`03001oogoo00=oo`40005oo`00Bgoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<M
D_eC7E;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@07FceG75/mEcaK?ELLFcd01F=L0fMk00M[
NV^KJgYcVVnIMkQcV002MkL2NkD00g^dNi9k]002Ni8017^ANi9kTG^AKgoo00<007ooOol00Woo0@00
0Goo001<Ool20000MU<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeC
75/mEaaK?ELLGceK?5lmHe]SG6MKJgaWFfMlJgY_Vf]jLiY_VG>JLiQk]gNFNkIkUG^dNi9k]W^CNk=k
TG^bNi5k/WNAL7oo00D007ooOomoo`00005oo`00CWoo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<M
D_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@04EaaG7ELMFcd3Fc`00e/mFcaK?004Ig/02V]jJi][NW>J
KiUcVW>HMkQg]g^g0W^e00Ak]7^eNiAk/`9kTP04Ni5k/g^BNi9aOol01000Oomoo`000Goo001?Ool0
M000Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E<LEaeC75LMEaaK?ELLGceK?5lmFcaO
G5llGeeO?5mLJgY_Vf]jLiY_VG>JLiQg^GNFNkMkUG^fNi=k]g^ENkAkTW^bNi9k/g^ANk9bOol01000
Oomoo`000Goo001@Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0<DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;m1U<M0eLM00YG
75LMEaeG7EllGeaO?5mLGcaOG0=SG008LiY_VG>JKiUg^7>HNkMgU`9k]@0:NkMk]G^dNkAk/g^DNk=k
Tg^bNi5cOol00`00Ool00001Ool0055oo`80001_C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E<L
EaeBo5/mEaaG?ELLFceG75/mGcaOGEllHeaSFf=lHe]WO6MKJgaWFgNiLiQk]gNFMkUcV7^gMiIk]W^C
Ok=kTG^cNi9k/W^A07Eoo`40005oo`400000Dgoo00H004kmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d2
Dad03ELMDaeC7E<MEaeC7E/mEcaK?ELLFceG?5/m00ESG0AWN`09Jg][NW>JKiUg^7>HMkQgUg^e009k
]006Ni9k]7^CNk=kTW^AMWoo0P00001DOol0KP00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeC75LMD_aG7E<L
EaeC75/mEaaK?ELLGceK?5lmHe]SO6=KIgaWFf]lIe]_Vf]jLiY_VG>JLiQg^GNFNkMgUGndNi9k]W^B
Ok=kTW^bNi9fOol2000005Eoo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeG7003Ead0
15LLEaeK?5/m0e/l00=K?E/lIg/00VMk011[NV]kJgY[VfnILiYcV7NhMiMg]g^eNkAkU7^eNkAk/`9k
TP03Ni5oogoo07Eoo`800000EWoo06/007ooOom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E<LEaeC75LmEaaK
?E/lGceK?5lmGcaOG5llGee[NVnKJgY_VfnILiYcV7NiMiIk]gNFNkIgUW^gMiEo]7^BNk=kTGnc07=o
o`@0009oo`00Egoo0P0000Aooe;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d6Dad00eLMEaaG7@02Ead025LLEaeO?5mLGcaO
G5llGe`4He`01FnILiY_VGNhLiP00WNg00Yg^7NGMkMk]G^dNi9k/g^BNkAkTVmoo`@000Ioo`00FGoo
06L007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7DklDaeC75LMD_aG7E<LEceG75/mEaaK?ELLFceO?5mLGcaSO6=KHeaSFf=lIe]WO6MK
MkUcV7>JKiUg^G>HNkMgUW^fNi=k/g^BOkAkTP1/Ool4000:Ool005Yoo`05001ooe;mDae>o@02D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eC7E;mDaeBoE<MD_eC
7E;m0U<M00aG7E<MDaeC7ELMEaaK?ELlFceG75/mEc`4He`4Ig/01V^KJgYcVVnIMkQcV09g]`07NkEk
U7^cNi=k]7^DNk<0J7oo10003Woo001KOol0I000Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeBo5LMDaaG7ELLFceG75/m
FcaO?E/lGceWFf]lIe]WO6MKKi][NW>JKiUcVW>HMkUgUW^gNiEk]7NENkIkTg^cIGoo10004Woo001L
Ool200000gooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06
DaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7ELL00=G7@=K?005FceK?5/lGcaOG003Ig/046^KJgY[NfnI
LiYcV7NhMkMk]g^eNkAg]g^eNiAk]7^CHWoo0`005Woo001NOol0H@00OomC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75LMDaaK?ELL
EceK?5lmFcaOG5llGeeO?5mLGca_Vf]jKi]_VG>JLiQg^G>HNkMgUW^fMiIk]W^ENkAkTgnc05ioo`@0
01Uoo`00Ggoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad0
0e;m00AC7E;mDaeBo@MC7@9G7@0;EaaG7ELMEaeG75mLGcaOG5llGeaO?003He`02fnILiYcV7NhLiQk
]gNGMiQg]g^gNkD00W^d00=k/gooOol0FGoo10007Goo001POol0GP00OomC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMDaaG7E;lEaeG75LmEaaK?ELL
FceG75mMGcaOG6=KHgaSFf=LIe][O6]jKi][NW>JKiUg^G>HNkMkUG^fNi=o]7^BEgoo10008Goo001Q
Ool200001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MC_eC7E;mDaeBoE<MD_eC7E;m
0e<M00ABoE<MDaeG7@=C7@06FceG75/mEcaK?ELL16=L0fMk00Y[NV]kJgYcVVnILiYcV7^gMiMk]@9k
]003Ni9k]Goo059oo`@002Eoo`00Hgoo05X005<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LFceG75/mFcaO?E/lGceK?6MlIe][O6]j
Ki][NW>JKiUcVW>HMkUgUW^fMiEo]7^CNkIAOol3000YOol006Aoo`03001C7Dkm009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00=BoE<MDad00U<M0eLM00AG75LMEaeK?@=K
?00BFceK?5mLGcaOG6]jJg][NW>JKiUcVW>HMkQgUgNgNkEk]gNG0W^eCGoo1000;7oo001UOol0E`00
Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7ELL
EceG75/mEaaO?E/lGceO?5mLGcaOGF=KHeaSFg>JKiUcVVnIMkUcV7^gLiQk]gNFNkMgU@1:Ool4000`
Ool006Ioo`800005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d015<MD_eC7E;m
15<M00=G7E<MDad00ULM00MG75LMEaeOG5llGeaO?004He`4Ig/01gNhLiQcVW>HMkQgUgNg009k]DIo
o`@003Aoo`00J7oo05<007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LM
D_aG7E<LEaeBo5LMEaaK?ELLFceG75/mEaaSO6=KHeaSFf]lIe]WO6MKKi][NW>JKiUg^GNFNkMgUW^f
04=oo`@003Qoo`00JGoo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m0e<M00AB
oE<MDaeG7@=C7@0:EaeG75LMEcaK?ELLFceK?5/mFc`2He`4Ig/01V^KJgYcVVnIMkQcV09g]`9k]Cmo
o`@003aoo`00JWoo050007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<M
DaaG7E<LEaeC75LMFcaO?E/lGceK?5lmFca[O6MKIga[NVnKJgY_VfnIMkUcV7^gMiIk]W^E?Goo0`00
@7oo001[Ool20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0<DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;m1E<M00QG75LMEaeG
7ELLEaeK?5/m0U/l00iO?5mLGcaOG6]jJi][NV]kKiUcVW>HMiQg]g^g0W^e>Goo1000@goo001]Ool0
C000Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MEaaK?ELLEceG75/mEaaO
G5llGeeO?5mLHe]SO6=KHea_VG>JLiQg^GNFNkMcV7Ni=Woo1000Agoo001^Ool01@00OomBoE<MC_d0
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7Dkm
D_eBoE<M00=Bo@09DaeBoE<MD_eC7E;mDaeBoELM00=C7@03EaeG75LM009G7@05EaaK?ELlGeaO?005
He`2Ig/01f]jJg]_VG>JLiQgV7>H039oo`@004]oo`00Kgoo04T007ooOomC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MD_aC7E;lEaeBo5LMDaaG7E;lFceG75/mEaaK?ELLHeaSFf=lHe]WO6MKJga[NVnKKiUcVVnI
MkUcV00_Ool4001?Ool0071oo`800003OomC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELM
Ea`00eLM00AG75/mEcaK?@=K?003FceK?6Mk009WN`08JgY[Nf]jLiY_VGNHLiQg^2aoo`<005=oo`00
LWoo04D004kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMDaaG7E<LEaeC75lmFcaO?E/lGceK
?5mLGcaOGF]jKi][NW>JKiUg^G>HMkT0:Goo1000EWoo001cOol01000D_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;m
DaeBo@MC7@05EaaG7ELMEaeG7002Fc`01E/mGcaOG5llGe`00f=L00IcVVnILiYcV7NhLiPUOol4001J
Ool007Aoo`12001>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMDaaG7ELLFceG75LmEaaOGEllGeaO
?6=lHe]SG6=KJgaWFfMlLiQg^G>H8Woo1000GWoo001eOol200001U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d2
Dad035LMDaeC7E<MEaeG75/mEcaK?ELLFceG?0=SG0AWN`03JgY[Vf]j01moo`@0069oo`00Mgoo03d0
05<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeBo5LMDaaG7ELLFceG75/mFcaO?E/lGceWFf]lIe]WO6]jKi][
NP0LOol4001VOol007Qoo`03001C7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMEa`00eLM0e/l00EK?E/l
FcaO?5mL009WN`03JgY[Vgoo01Yoo`<006Yoo`00NGoo03P005<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E<LEaeC
75/mEaaG?E/lGceK?5mLGcaOGEllGea[NVnK67oo1000KGoo001jOol00`00Oom>o@02D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m1E<M
0ULM00UG75LMEaeG7ELLGeaO?5mLGc`00f=L5Goo1000LGoo001kOol20000<TklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMDaaG7E;l
EaeG75LmEaaK?ELLFceG75/mHe]SG6=KHg`BOol4001eOol007eoo`06001>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad015;mDaeC7ELM0e<M
00EK?ELLFceG?5/m009K?09SG0moo`@007Uoo`00OWoo02l004klDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5<MDaaG7E<LEaeC75LMFcaO
?E/lGceK?5lm00aoo`@007eoo`00Ogoo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05
Dae>oE;mD_eC7@03D_d015<MD_eC7E;m1e<M0ULM00AG75LMEaeG7@=K?0]oo`<0085oo`00P7oo0P00
02MC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LM
D_aC7E;lEaeG75LmEaaK?ELLEcd02Goo1000Q7oo0022Ool01@00D_eBoE<MC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad00eLMDaeC7@02Ead00eLLOomo
o`05Ool40028Ool008=oo`0R001C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7E;lDaeBo5LMDaaG7E;lEad5Ool4002<Ool008Aoo`05001ooe;mDae>o@02D_d01E<M
C_eBoE;mDad00e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@03D_eoogoo00=oo`@0091oo`00QGoo
0P0001I>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7@Ioo`<009Aoo`00
Qgoo00@005;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00AC7E;mD_eBo@Ioo`@009Moo`00R7oo00l0
04kmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDad017oo1000Vgoo0029Ool01000OomC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2Ool4002OOol008Yoo`800005Dae>o5<MC_eC7@02Ool4002SOol008aoo`800003
Ool0000000800:Moo`00SGoo0P00Zgoo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mo
oc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.646 .763 .934 r
.38973 .799 .39806 .80575 .41196 .80206 .40367 .79529 Mtetra
.647 .763 .934 r
.40367 .79529 .41196 .80206 .42593 .79834 .41769 .79154 Mtetra
.648 .764 .933 r
.41769 .79154 .42593 .79834 .43998 .79454 .43178 .78773 Mtetra
.65 .765 .933 r
.43178 .78773 .43998 .79454 .4541 .79062 .44595 .78384 Mtetra
.654 .768 .933 r
.44595 .78384 .4541 .79062 .46829 .7865 .46019 .77979 Mtetra
.661 .772 .932 r
.46019 .77979 .46829 .7865 .48257 .78201 .47451 .77546 Mtetra
.675 .781 .93 r
.47451 .77546 .48257 .78201 .49691 .77683 .48891 .77063 Mtetra
.698 .796 .926 r
.48891 .77063 .49691 .77683 .51132 .77042 .50337 .76487 Mtetra
.738 .822 .917 r
.50337 .76487 .51132 .77042 .52579 .76178 .51791 .75744 Mtetra
.798 .858 .895 r
.51791 .75744 .52579 .76178 .54028 .74936 .53248 .74708 Mtetra
.872 .899 .849 r
.53248 .74708 .54028 .74936 .55473 .73106 .54705 .73191 Mtetra
.938 .927 .77 r
.54705 .73191 .55473 .73106 .56904 .70501 .56153 .70977 Mtetra
.97 .93 .674 r
.56153 .70977 .56904 .70501 .58312 .6715 .57582 .67959 Mtetra
.972 .92 .596 r
.57582 .67959 .58312 .6715 .59695 .63453 .58986 .64347 Mtetra
.963 .918 .571 r
.58986 .64347 .59695 .63453 .61066 .60036 .6037 .60699 Mtetra
.959 .937 .619 r
.6037 .60699 .61066 .60036 .62439 .57333 .61748 .57595 Mtetra
.946 .956 .728 r
.61748 .57595 .62439 .57333 .63827 .55404 .63136 .55281 Mtetra
.895 .934 .834 r
.63136 .55281 .63827 .55404 .65232 .54074 .64541 .53669 Mtetra
.819 .878 .888 r
.64541 .53669 .65232 .54074 .66652 .53133 .65962 .52551 Mtetra
.755 .824 .906 r
.65962 .52551 .66652 .53133 .68087 .52421 .67399 .51734 Mtetra
.714 .788 .91 r
.67399 .51734 .68087 .52421 .69533 .51836 .68848 .51089 Mtetra
.691 .767 .91 r
.68848 .51089 .69533 .51836 .70989 .51318 .70308 .50538 Mtetra
.678 .755 .909 r
.70308 .50538 .70989 .51318 .72454 .50836 .71778 .50035 Mtetra
.671 .749 .909 r
.71778 .50035 .72454 .50836 .73928 .50372 .73257 .49558 Mtetra
.668 .745 .908 r
.73257 .49558 .73928 .50372 .7541 .49915 .74744 .49093 Mtetra
.666 .743 .908 r
.74744 .49093 .7541 .49915 .769 .49462 .76239 .48633 Mtetra
.665 .742 .908 r
.76239 .48633 .769 .49462 .78398 .49009 .77742 .48175 Mtetra
.664 .742 .908 r
.77742 .48175 .78398 .49009 .79903 .48556 .79254 .47716 Mtetra
.79254 .47716 .79903 .48556 .81417 .48101 .80773 .47257 Mtetra
.664 .741 .908 r
.80773 .47257 .81417 .48101 .82939 .47644 .823 .46795 Mtetra
.823 .46795 .82939 .47644 .84469 .47185 .83836 .46331 Mtetra
.83836 .46331 .84469 .47185 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.646 .763 .934 r
.38132 .79218 .38973 .799 .40367 .79529 .39531 .78844 Mtetra
.647 .763 .934 r
.39531 .78844 .40367 .79529 .41769 .79154 .40937 .78467 Mtetra
.648 .763 .934 r
.40937 .78467 .41769 .79154 .43178 .78773 .42351 .78085 Mtetra
.649 .764 .933 r
.42351 .78085 .43178 .78773 .44595 .78384 .43772 .77696 Mtetra
.652 .766 .933 r
.43772 .77696 .44595 .78384 .46019 .77979 .45201 .77295 Mtetra
.657 .77 .932 r
.45201 .77295 .46019 .77979 .47451 .77546 .46638 .76873 Mtetra
.667 .776 .931 r
.46638 .76873 .47451 .77546 .48891 .77063 .48082 .76414 Mtetra
.685 .788 .928 r
.48082 .76414 .48891 .77063 .50337 .76487 .49534 .75886 Mtetra
.716 .808 .922 r
.49534 .75886 .50337 .76487 .51791 .75744 .50993 .75233 Mtetra
.765 .839 .908 r
.50993 .75233 .51791 .75744 .53248 .74708 .52458 .74356 Mtetra
.834 .879 .876 r
.52458 .74356 .53248 .74708 .54705 .73191 .53925 .73099 Mtetra
.908 .916 .813 r
.53925 .73099 .54705 .73191 .56153 .70977 .55388 .71248 Mtetra
.959 .931 .722 r
.55388 .71248 .56153 .70977 .57582 .67959 .56837 .68618 Mtetra
.974 .925 .63 r
.56837 .68618 .57582 .67959 .58986 .64347 .58263 .65235 Mtetra
.967 .917 .575 r
.58263 .65235 .58986 .64347 .6037 .60699 .59664 .61507 Mtetra
.96 .925 .585 r
.59664 .61507 .6037 .60699 .61748 .57595 .61051 .5806 Mtetra
.956 .949 .669 r
.61051 .5806 .61748 .57595 .63136 .55281 .62442 .55333 Mtetra
.926 .951 .786 r
.62442 .55333 .63136 .55281 .64541 .53669 .63846 .53383 Mtetra
.857 .908 .867 r
.63846 .53383 .64541 .53669 .65962 .52551 .65268 .52037 Mtetra
.784 .849 .9 r
.65268 .52037 .65962 .52551 .67399 .51734 .66706 .51083 Mtetra
.732 .804 .909 r
.66706 .51083 .67399 .51734 .68848 .51089 .68158 .50359 Mtetra
.701 .776 .91 r
.68158 .50359 .68848 .51089 .70308 .50538 .69622 .49762 Mtetra
.683 .76 .909 r
.69622 .49762 .70308 .50538 .71778 .50035 .71096 .49234 Mtetra
.674 .751 .909 r
.71096 .49234 .71778 .50035 .73257 .49558 .72579 .4874 Mtetra
.669 .747 .908 r
.72579 .4874 .73257 .49558 .74744 .49093 .74071 .48265 Mtetra
.666 .744 .908 r
.74071 .48265 .74744 .49093 .76239 .48633 .75572 .47797 Mtetra
.665 .743 .908 r
.75572 .47797 .76239 .48633 .77742 .48175 .77081 .47333 Mtetra
.664 .742 .908 r
.77081 .47333 .77742 .48175 .79254 .47716 .78598 .46869 Mtetra
.78598 .46869 .79254 .47716 .80773 .47257 .80123 .46404 Mtetra
.80123 .46404 .80773 .47257 .823 .46795 .81656 .45938 Mtetra
.664 .741 .908 r
.81656 .45938 .823 .46795 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44999 Mtetra
.84747 .44999 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.646 .763 .934 r
.37283 .7853 .38132 .79218 .39531 .78844 .38686 .78153 Mtetra
.38686 .78153 .39531 .78844 .40937 .78467 .40097 .77772 Mtetra
.647 .763 .934 r
.40097 .77772 .40937 .78467 .42351 .78085 .41516 .77388 Mtetra
.648 .764 .933 r
.41516 .77388 .42351 .78085 .43772 .77696 .42942 .76999 Mtetra
.65 .765 .933 r
.42942 .76999 .43772 .77696 .45201 .77295 .44375 .766 Mtetra
.654 .768 .933 r
.44375 .766 .45201 .77295 .46638 .76873 .45817 .76185 Mtetra
.661 .772 .932 r
.45817 .76185 .46638 .76873 .48082 .76414 .47266 .75742 Mtetra
.675 .781 .93 r
.47266 .75742 .48082 .76414 .49534 .75886 .48723 .75249 Mtetra
.698 .796 .926 r
.48723 .75249 .49534 .75886 .50993 .75233 .50188 .74662 Mtetra
.738 .822 .917 r
.50188 .74662 .50993 .75233 .52458 .74356 .51659 .73906 Mtetra
.798 .858 .895 r
.51659 .73906 .52458 .74356 .53925 .73099 .53135 .72856 Mtetra
.872 .899 .849 r
.53135 .72856 .53925 .73099 .55388 .71248 .5461 .7132 Mtetra
.938 .927 .77 r
.5461 .7132 .55388 .71248 .56837 .68618 .56076 .69084 Mtetra
.97 .93 .674 r
.56076 .69084 .56837 .68618 .58263 .65235 .57524 .66037 Mtetra
.972 .92 .596 r
.57524 .66037 .58263 .65235 .59664 .61507 .58945 .62392 Mtetra
.963 .918 .571 r
.58945 .62392 .59664 .61507 .61051 .5806 .60346 .58713 Mtetra
.959 .937 .619 r
.60346 .58713 .61051 .5806 .62442 .55333 .61742 .55582 Mtetra
.946 .956 .728 r
.61742 .55582 .62442 .55333 .63846 .53383 .63147 .53245 Mtetra
.895 .934 .834 r
.63147 .53245 .63846 .53383 .65268 .52037 .64569 .51616 Mtetra
.819 .878 .888 r
.64569 .51616 .65268 .52037 .66706 .51083 .66008 .50483 Mtetra
.755 .824 .906 r
.66008 .50483 .66706 .51083 .68158 .50359 .67462 .49653 Mtetra
.714 .788 .91 r
.67462 .49653 .68158 .50359 .69622 .49762 .68929 .48996 Mtetra
.691 .767 .91 r
.68929 .48996 .69622 .49762 .71096 .49234 .70407 .48433 Mtetra
.678 .755 .909 r
.70407 .48433 .71096 .49234 .72579 .4874 .71896 .47919 Mtetra
.671 .749 .909 r
.71896 .47919 .72579 .4874 .74071 .48265 .73393 .47431 Mtetra
.668 .745 .908 r
.73393 .47431 .74071 .48265 .75572 .47797 .74899 .46954 Mtetra
.666 .743 .908 r
.74899 .46954 .75572 .47797 .77081 .47333 .76413 .46483 Mtetra
.665 .742 .908 r
.76413 .46483 .77081 .47333 .78598 .46869 .77935 .46014 Mtetra
.664 .742 .908 r
.77935 .46014 .78598 .46869 .80123 .46404 .79466 .45544 Mtetra
.79466 .45544 .80123 .46404 .81656 .45938 .81005 .45072 Mtetra
.664 .741 .908 r
.81005 .45072 .81656 .45938 .83197 .45469 .82552 .44599 Mtetra
.82552 .44599 .83197 .45469 .84747 .44999 .84107 .44124 Mtetra
.84107 .44124 .84747 .44999 .86305 .44525 .85671 .43646 Mtetra
.85671 .43646 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.646 .763 .934 r
.36425 .77834 .37283 .7853 .38686 .78153 .37833 .77454 Mtetra
.37833 .77454 .38686 .78153 .40097 .77772 .39249 .77071 Mtetra
.647 .763 .934 r
.39249 .77071 .40097 .77772 .41516 .77388 .40672 .76684 Mtetra
.648 .763 .934 r
.40672 .76684 .41516 .77388 .42942 .76999 .42103 .76293 Mtetra
.649 .764 .933 r
.42103 .76293 .42942 .76999 .44375 .766 .43541 .75894 Mtetra
.652 .766 .933 r
.43541 .75894 .44375 .766 .45817 .76185 .44987 .75483 Mtetra
.657 .77 .932 r
.44987 .75483 .45817 .76185 .47266 .75742 .46442 .75052 Mtetra
.667 .776 .931 r
.46442 .75052 .47266 .75742 .48723 .75249 .47904 .74582 Mtetra
.685 .788 .928 r
.47904 .74582 .48723 .75249 .50188 .74662 .49374 .74043 Mtetra
.716 .808 .922 r
.49374 .74043 .50188 .74662 .51659 .73906 .50851 .73379 Mtetra
.765 .839 .908 r
.50851 .73379 .51659 .73906 .53135 .72856 .52334 .72488 Mtetra
.834 .879 .876 r
.52334 .72488 .53135 .72856 .5461 .7132 .5382 .71214 Mtetra
.908 .916 .813 r
.5382 .71214 .5461 .7132 .56076 .69084 .55301 .69343 Mtetra
.959 .931 .722 r
.55301 .69343 .56076 .69084 .57524 .66037 .56769 .66686 Mtetra
.974 .925 .63 r
.56769 .66686 .57524 .66037 .58945 .62392 .58213 .63273 Mtetra
.967 .917 .575 r
.58213 .63273 .58945 .62392 .60346 .58713 .59631 .59512 Mtetra
.96 .925 .585 r
.59631 .59512 .60346 .58713 .61742 .55582 .61036 .56035 Mtetra
.956 .949 .67 r
.61036 .56035 .61742 .55582 .63147 .53245 .62444 .53283 Mtetra
.926 .951 .786 r
.62444 .53283 .63147 .53245 .64569 .51616 .63865 .51313 Mtetra
.857 .908 .867 r
.63865 .51313 .64569 .51616 .66008 .50483 .65305 .49951 Mtetra
.784 .849 .9 r
.65305 .49951 .66008 .50483 .67462 .49653 .66761 .48983 Mtetra
.732 .804 .909 r
.66761 .48983 .67462 .49653 .68929 .48996 .68231 .48246 Mtetra
.701 .776 .91 r
.68231 .48246 .68929 .48996 .70407 .48433 .69713 .47637 Mtetra
.683 .76 .909 r
.69713 .47637 .70407 .48433 .71896 .47919 .71205 .47097 Mtetra
.674 .751 .909 r
.71205 .47097 .71896 .47919 .73393 .47431 .72708 .46592 Mtetra
.669 .747 .908 r
.72708 .46592 .73393 .47431 .74899 .46954 .74219 .46105 Mtetra
.666 .744 .908 r
.74219 .46105 .74899 .46954 .76413 .46483 .75738 .45626 Mtetra
.665 .743 .908 r
.75738 .45626 .76413 .46483 .77935 .46014 .77266 .4515 Mtetra
.664 .742 .908 r
.77266 .4515 .77935 .46014 .79466 .45544 .78803 .44675 Mtetra
.78803 .44675 .79466 .45544 .81005 .45072 .80347 .44198 Mtetra
.80347 .44198 .81005 .45072 .82552 .44599 .819 .4372 Mtetra
.664 .741 .908 r
.819 .4372 .82552 .44599 .84107 .44124 .83462 .4324 Mtetra
.83462 .4324 .84107 .44124 .85671 .43646 .85032 .42757 Mtetra
.85032 .42757 .85671 .43646 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.646 .763 .934 r
.35559 .77132 .36425 .77834 .37833 .77454 .36972 .76748 Mtetra
.36972 .76748 .37833 .77454 .39249 .77071 .38392 .76362 Mtetra
.38392 .76362 .39249 .77071 .40672 .76684 .3982 .75972 Mtetra
.647 .763 .934 r
.3982 .75972 .40672 .76684 .42103 .76293 .41256 .75579 Mtetra
.648 .764 .933 r
.41256 .75579 .42103 .76293 .43541 .75894 .42699 .75179 Mtetra
.65 .765 .933 r
.42699 .75179 .43541 .75894 .44987 .75483 .4415 .7477 Mtetra
.654 .768 .933 r
.4415 .7477 .44987 .75483 .46442 .75052 .45609 .74345 Mtetra
.661 .772 .932 r
.45609 .74345 .46442 .75052 .47904 .74582 .47076 .73892 Mtetra
.674 .781 .93 r
.47076 .73892 .47904 .74582 .49374 .74043 .48551 .73388 Mtetra
.698 .797 .926 r
.48551 .73388 .49374 .74043 .50851 .73379 .50034 .7279 Mtetra
.738 .822 .917 r
.50034 .7279 .50851 .73379 .52334 .72488 .51524 .72022 Mtetra
.798 .859 .895 r
.51524 .72022 .52334 .72488 .5382 .71214 .53018 .70956 Mtetra
.872 .9 .849 r
.53018 .70956 .5382 .71214 .55301 .69343 .54512 .69402 Mtetra
.938 .927 .77 r
.54512 .69402 .55301 .69343 .56769 .66686 .55998 .67142 Mtetra
.97 .93 .673 r
.55998 .67142 .56769 .66686 .58213 .63273 .57464 .64066 Mtetra
.972 .92 .596 r
.57464 .64066 .58213 .63273 .59631 .59512 .58904 .60389 Mtetra
.963 .918 .571 r
.58904 .60389 .59631 .59512 .61036 .56035 .60323 .56678 Mtetra
.959 .937 .62 r
.60323 .56678 .61036 .56035 .62444 .53283 .61736 .53518 Mtetra
.946 .956 .729 r
.61736 .53518 .62444 .53283 .63865 .51313 .63158 .51159 Mtetra
.895 .934 .834 r
.63158 .51159 .63865 .51313 .65305 .49951 .64597 .49512 Mtetra
.819 .878 .888 r
.64597 .49512 .65305 .49951 .66761 .48983 .66054 .48363 Mtetra
.755 .824 .906 r
.66054 .48363 .66761 .48983 .68231 .48246 .67526 .4752 Mtetra
.714 .788 .91 r
.67526 .4752 .68231 .48246 .69713 .47637 .69012 .46851 Mtetra
.691 .767 .91 r
.69012 .46851 .69713 .47637 .71205 .47097 .70509 .46276 Mtetra
.678 .755 .909 r
.70509 .46276 .71205 .47097 .72708 .46592 .72016 .4575 Mtetra
.671 .749 .909 r
.72016 .4575 .72708 .46592 .74219 .46105 .73532 .4525 Mtetra
.668 .745 .908 r
.73532 .4525 .74219 .46105 .75738 .45626 .75057 .44762 Mtetra
.666 .743 .908 r
.75057 .44762 .75738 .45626 .77266 .4515 .76591 .44279 Mtetra
.665 .742 .908 r
.76591 .44279 .77266 .4515 .78803 .44675 .78133 .43798 Mtetra
.664 .742 .908 r
.78133 .43798 .78803 .44675 .80347 .44198 .79683 .43316 Mtetra
.79683 .43316 .80347 .44198 .819 .4372 .81242 .42833 Mtetra
.664 .741 .908 r
.81242 .42833 .819 .4372 .83462 .4324 .8281 .42347 Mtetra
.8281 .42347 .83462 .4324 .85032 .42757 .84386 .4186 Mtetra
.84386 .4186 .85032 .42757 .8661 .42272 .85971 .41369 Mtetra
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.646 .762 .934 r
.34685 .76423 .35559 .77132 .36972 .76748 .36102 .76036 Mtetra
.646 .763 .934 r
.36102 .76036 .36972 .76748 .38392 .76362 .37527 .75646 Mtetra
.37527 .75646 .38392 .76362 .3982 .75972 .3896 .75253 Mtetra
.647 .763 .934 r
.3896 .75253 .3982 .75972 .41256 .75579 .404 .74857 Mtetra
.648 .763 .934 r
.404 .74857 .41256 .75579 .42699 .75179 .41848 .74455 Mtetra
.649 .764 .933 r
.41848 .74455 .42699 .75179 .4415 .7477 .43304 .74047 Mtetra
.652 .766 .933 r
.43304 .74047 .4415 .7477 .45609 .74345 .44768 .73626 Mtetra
.657 .77 .932 r
.44768 .73626 .45609 .74345 .47076 .73892 .4624 .73184 Mtetra
.667 .776 .931 r
.4624 .73184 .47076 .73892 .48551 .73388 .4772 .72704 Mtetra
.685 .788 .928 r
.4772 .72704 .48551 .73388 .50034 .7279 .49209 .72154 Mtetra
.716 .808 .922 r
.49209 .72154 .50034 .7279 .51524 .72022 .50705 .71477 Mtetra
.765 .839 .908 r
.50705 .71477 .51524 .72022 .53018 .70956 .52207 .70572 Mtetra
.834 .88 .876 r
.52207 .70572 .53018 .70956 .54512 .69402 .53711 .69281 Mtetra
.908 .916 .813 r
.53711 .69281 .54512 .69402 .55998 .67142 .55212 .67389 Mtetra
.959 .932 .722 r
.55212 .67389 .55998 .67142 .57464 .64066 .56699 .64706 Mtetra
.974 .925 .63 r
.56699 .64706 .57464 .64066 .58904 .60389 .58161 .61261 Mtetra
.967 .917 .575 r
.58161 .61261 .58904 .60389 .60323 .56678 .59598 .57467 Mtetra
.96 .925 .586 r
.59598 .57467 .60323 .56678 .61736 .53518 .61021 .53959 Mtetra
.956 .949 .67 r
.61021 .53959 .61736 .53518 .63158 .51159 .62446 .51182 Mtetra
.926 .951 .786 r
.62446 .51182 .63158 .51159 .64597 .49512 .63886 .49192 Mtetra
.857 .907 .867 r
.63886 .49192 .64597 .49512 .66054 .48363 .65343 .47813 Mtetra
.784 .849 .9 r
.65343 .47813 .66054 .48363 .67526 .4752 .66817 .4683 Mtetra
.732 .804 .909 r
.66817 .4683 .67526 .4752 .69012 .46851 .68305 .4608 Mtetra
.701 .776 .91 r
.68305 .4608 .69012 .46851 .70509 .46276 .69806 .45459 Mtetra
.683 .76 .909 r
.69806 .45459 .70509 .46276 .72016 .4575 .71318 .44907 Mtetra
.674 .751 .909 r
.71318 .44907 .72016 .4575 .73532 .4525 .72839 .4439 Mtetra
.669 .747 .908 r
.72839 .4439 .73532 .4525 .75057 .44762 .74369 .43891 Mtetra
.666 .744 .908 r
.74369 .43891 .75057 .44762 .76591 .44279 .75909 .434 Mtetra
.665 .743 .908 r
.75909 .434 .76591 .44279 .78133 .43798 .77456 .42912 Mtetra
.664 .742 .908 r
.77456 .42912 .78133 .43798 .79683 .43316 .79013 .42425 Mtetra
.79013 .42425 .79683 .43316 .81242 .42833 .80578 .41936 Mtetra
.80578 .41936 .81242 .42833 .8281 .42347 .82151 .41446 Mtetra
.664 .741 .908 r
.82151 .41446 .8281 .42347 .84386 .4186 .83734 .40953 Mtetra
.83734 .40953 .84386 .4186 .85971 .41369 .85324 .40458 Mtetra
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Mtetra
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.646 .762 .934 r
.33802 .75707 .34685 .76423 .36102 .76036 .35224 .75316 Mtetra
.646 .763 .934 r
.35224 .75316 .36102 .76036 .37527 .75646 .36654 .74922 Mtetra
.36654 .74922 .37527 .75646 .3896 .75253 .38091 .74526 Mtetra
.38091 .74526 .3896 .75253 .404 .74857 .39536 .74127 Mtetra
.647 .763 .934 r
.39536 .74127 .404 .74857 .41848 .74455 .40989 .73723 Mtetra
.648 .764 .933 r
.40989 .73723 .41848 .74455 .43304 .74047 .4245 .73313 Mtetra
.65 .765 .933 r
.4245 .73313 .43304 .74047 .44768 .73626 .43919 .72894 Mtetra
.654 .768 .933 r
.43919 .72894 .44768 .73626 .4624 .73184 .45396 .72459 Mtetra
.661 .772 .932 r
.45396 .72459 .4624 .73184 .4772 .72704 .46881 .71995 Mtetra
.674 .781 .93 r
.46881 .71995 .4772 .72704 .49209 .72154 .48375 .7148 Mtetra
.698 .797 .926 r
.48375 .7148 .49209 .72154 .50705 .71477 .49877 .7087 Mtetra
.738 .822 .917 r
.49877 .7087 .50705 .71477 .52207 .70572 .51385 .70088 Mtetra
.798 .859 .895 r
.51385 .70088 .52207 .70572 .53711 .69281 .52899 .69007 Mtetra
.872 .9 .849 r
.52899 .69007 .53711 .69281 .55212 .67389 .54412 .67434 Mtetra
.938 .927 .77 r
.54412 .67434 .55212 .67389 .56699 .64706 .55917 .6515 Mtetra
.97 .93 .673 r
.55917 .6515 .56699 .64706 .58161 .61261 .57403 .62045 Mtetra
.972 .92 .595 r
.57403 .62045 .58161 .61261 .59598 .57467 .58861 .58335 Mtetra
.963 .918 .571 r
.58861 .58335 .59598 .57467 .61021 .53959 .60298 .54591 Mtetra
.959 .937 .62 r
.60298 .54591 .61021 .53959 .62446 .51182 .61729 .51403 Mtetra
.947 .955 .729 r
.61729 .51403 .62446 .51182 .63886 .49192 .63169 .49021 Mtetra
.895 .934 .834 r
.63169 .49021 .63886 .49192 .65343 .47813 .64627 .47355 Mtetra
.819 .878 .888 r
.64627 .47355 .65343 .47813 .66817 .4683 .66102 .46191 Mtetra
.755 .824 .906 r
.66102 .46191 .66817 .4683 .68305 .4608 .67593 .45334 Mtetra
.714 .788 .91 r
.67593 .45334 .68305 .4608 .69806 .45459 .69097 .44652 Mtetra
.691 .767 .91 r
.69097 .44652 .69806 .45459 .71318 .44907 .70613 .44064 Mtetra
.678 .755 .909 r
.70613 .44064 .71318 .44907 .72839 .4439 .72139 .43527 Mtetra
.671 .749 .909 r
.72139 .43527 .72839 .4439 .74369 .43891 .73675 .43014 Mtetra
.668 .745 .908 r
.73675 .43014 .74369 .43891 .75909 .434 .7522 .42514 Mtetra
.666 .743 .908 r
.7522 .42514 .75909 .434 .77456 .42912 .76773 .42019 Mtetra
.665 .742 .908 r
.76773 .42019 .77456 .42912 .79013 .42425 .78336 .41525 Mtetra
.664 .742 .908 r
.78336 .41525 .79013 .42425 .80578 .41936 .79906 .41031 Mtetra
.79906 .41031 .80578 .41936 .82151 .41446 .81486 .40535 Mtetra
.664 .741 .908 r
.81486 .40535 .82151 .41446 .83734 .40953 .83074 .40037 Mtetra
.83074 .40037 .83734 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Mtetra
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.646 .762 .934 r
.32911 .74984 .33802 .75707 .35224 .75316 .34337 .74589 Mtetra
.34337 .74589 .35224 .75316 .36654 .74922 .35771 .74191 Mtetra
.646 .763 .934 r
.35771 .74191 .36654 .74922 .38091 .74526 .37214 .73792 Mtetra
.37214 .73792 .38091 .74526 .39536 .74127 .38663 .73389 Mtetra
.647 .763 .934 r
.38663 .73389 .39536 .74127 .40989 .73723 .40121 .72982 Mtetra
.648 .763 .934 r
.40121 .72982 .40989 .73723 .4245 .73313 .41587 .72571 Mtetra
.649 .764 .933 r
.41587 .72571 .4245 .73313 .43919 .72894 .43061 .72152 Mtetra
.652 .766 .933 r
.43061 .72152 .43919 .72894 .45396 .72459 .44543 .7172 Mtetra
.657 .77 .932 r
.44543 .7172 .45396 .72459 .46881 .71995 .46034 .71268 Mtetra
.667 .776 .931 r
.46034 .71268 .46881 .71995 .48375 .7148 .47533 .70776 Mtetra
.685 .788 .928 r
.47533 .70776 .48375 .7148 .49877 .7087 .4904 .70215 Mtetra
.715 .808 .922 r
.4904 .70215 .49877 .7087 .51385 .70088 .50555 .69525 Mtetra
.765 .839 .908 r
.50555 .69525 .51385 .70088 .52899 .69007 .52076 .68607 Mtetra
.834 .88 .876 r
.52076 .68607 .52899 .69007 .54412 .67434 .536 .67298 Mtetra
.908 .917 .813 r
.536 .67298 .54412 .67434 .55917 .6515 .55121 .65384 Mtetra
.959 .932 .721 r
.55121 .65384 .55917 .6515 .57403 .62045 .56627 .62674 Mtetra
.974 .925 .629 r
.56627 .62674 .57403 .62045 .58861 .58335 .58109 .59197 Mtetra
.967 .917 .575 r
.58109 .59197 .58861 .58335 .60298 .54591 .59564 .55369 Mtetra
.96 .925 .586 r
.59564 .55369 .60298 .54591 .61729 .51403 .61005 .51831 Mtetra
.956 .949 .67 r
.61005 .51831 .61729 .51403 .63169 .49021 .62449 .49027 Mtetra
.926 .951 .786 r
.62449 .49027 .63169 .49021 .64627 .47355 .63906 .47017 Mtetra
.857 .907 .867 r
.63906 .47017 .64627 .47355 .66102 .46191 .65382 .45621 Mtetra
.784 .849 .9 r
.65382 .45621 .66102 .46191 .67593 .45334 .66874 .44623 Mtetra
.732 .804 .909 r
.66874 .44623 .67593 .45334 .69097 .44652 .68382 .4386 Mtetra
.701 .776 .91 r
.68382 .4386 .69097 .44652 .70613 .44064 .69902 .43226 Mtetra
.683 .76 .909 r
.69902 .43226 .70613 .44064 .72139 .43527 .71433 .42661 Mtetra
.674 .751 .909 r
.71433 .42661 .72139 .43527 .73675 .43014 .72974 .42132 Mtetra
.669 .747 .908 r
.72974 .42132 .73675 .43014 .7522 .42514 .74524 .41621 Mtetra
.666 .744 .908 r
.74524 .41621 .7522 .42514 .76773 .42019 .76083 .41117 Mtetra
.665 .743 .908 r
.76083 .41117 .76773 .42019 .78336 .41525 .77651 .40617 Mtetra
.664 .742 .908 r
.77651 .40617 .78336 .41525 .79906 .41031 .79228 .40117 Mtetra
.79228 .40117 .79906 .41031 .81486 .40535 .80814 .39616 Mtetra
.80814 .39616 .81486 .40535 .83074 .40037 .82409 .39113 Mtetra
.664 .741 .908 r
.82409 .39113 .83074 .40037 .84672 .39537 .84012 .38607 Mtetra
.84012 .38607 .84672 .39537 .86278 .39034 .85624 .38099 Mtetra
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Mtetra
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .762 .934 r
.3201 .74253 .32911 .74984 .34337 .74589 .33441 .73855 Mtetra
.33441 .73855 .34337 .74589 .35771 .74191 .3488 .73453 Mtetra
.646 .763 .934 r
.3488 .73453 .35771 .74191 .37214 .73792 .36327 .7305 Mtetra
.36327 .7305 .37214 .73792 .38663 .73389 .37782 .72643 Mtetra
.37782 .72643 .38663 .73389 .40121 .72982 .39245 .72233 Mtetra
.647 .763 .934 r
.39245 .72233 .40121 .72982 .41587 .72571 .40716 .71819 Mtetra
.648 .764 .933 r
.40716 .71819 .41587 .72571 .43061 .72152 .42195 .71399 Mtetra
.65 .765 .933 r
.42195 .71399 .43061 .72152 .44543 .7172 .43682 .7097 Mtetra
.654 .768 .933 r
.43682 .7097 .44543 .7172 .46034 .71268 .45177 .70524 Mtetra
.661 .772 .932 r
.45177 .70524 .46034 .71268 .47533 .70776 .46682 .70049 Mtetra
.674 .781 .93 r
.46682 .70049 .47533 .70776 .4904 .70215 .48194 .69522 Mtetra
.698 .797 .926 r
.48194 .69522 .4904 .70215 .50555 .69525 .49715 .689 Mtetra
.738 .822 .917 r
.49715 .689 .50555 .69525 .52076 .68607 .51243 .68105 Mtetra
.798 .859 .895 r
.51243 .68105 .52076 .68607 .536 .67298 .52776 .67007 Mtetra
.872 .9 .849 r
.52776 .67007 .536 .67298 .55121 .65384 .5431 .65415 Mtetra
.938 .928 .769 r
.5431 .65415 .55121 .65384 .56627 .62674 .55835 .63106 Mtetra
.97 .93 .673 r
.55835 .63106 .56627 .62674 .58109 .59197 .57339 .59971 Mtetra
.971 .92 .595 r
.57339 .59971 .58109 .59197 .59564 .55369 .58817 .56227 Mtetra
.963 .918 .571 r
.58817 .56227 .59564 .55369 .61005 .51831 .60273 .5245 Mtetra
.959 .937 .62 r
.60273 .5245 .61005 .51831 .62449 .49027 .61722 .49234 Mtetra
.947 .955 .729 r
.61722 .49234 .62449 .49027 .63906 .47017 .63181 .46828 Mtetra
.895 .933 .834 r
.63181 .46828 .63906 .47017 .65382 .45621 .64657 .45143 Mtetra
.819 .877 .888 r
.64657 .45143 .65382 .45621 .66874 .44623 .6615 .43963 Mtetra
.755 .824 .906 r
.6615 .43963 .66874 .44623 .68382 .4386 .6766 .43092 Mtetra
.714 .788 .91 r
.6766 .43092 .68382 .4386 .69902 .43226 .69184 .42397 Mtetra
.691 .767 .91 r
.69184 .42397 .69902 .43226 .71433 .42661 .7072 .41796 Mtetra
.678 .755 .909 r
.7072 .41796 .71433 .42661 .72974 .42132 .72266 .41246 Mtetra
.671 .749 .909 r
.72266 .41246 .72974 .42132 .74524 .41621 .73821 .40721 Mtetra
.668 .745 .908 r
.73821 .40721 .74524 .41621 .76083 .41117 .75386 .40208 Mtetra
.666 .743 .908 r
.75386 .40208 .76083 .41117 .77651 .40617 .7696 .397 Mtetra
.665 .742 .908 r
.7696 .397 .77651 .40617 .79228 .40117 .78543 .39194 Mtetra
.664 .742 .908 r
.78543 .39194 .79228 .40117 .80814 .39616 .80135 .38687 Mtetra
.80135 .38687 .80814 .39616 .82409 .39113 .81736 .38178 Mtetra
.664 .741 .908 r
.81736 .38178 .82409 .39113 .84012 .38607 .83346 .37667 Mtetra
.83346 .37667 .84012 .38607 .85624 .38099 .84965 .37154 Mtetra
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Mtetra
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .762 .934 r
.31101 .73516 .3201 .74253 .33441 .73855 .32537 .73113 Mtetra
.32537 .73113 .33441 .73855 .3488 .73453 .3398 .72708 Mtetra
.3398 .72708 .3488 .73453 .36327 .7305 .35432 .723 Mtetra
.646 .763 .934 r
.35432 .723 .36327 .7305 .37782 .72643 .36892 .7189 Mtetra
.36892 .7189 .37782 .72643 .39245 .72233 .38359 .71476 Mtetra
.647 .763 .934 r
.38359 .71476 .39245 .72233 .40716 .71819 .39835 .71059 Mtetra
.648 .763 .934 r
.39835 .71059 .40716 .71819 .42195 .71399 .41319 .70637 Mtetra
.649 .764 .933 r
.41319 .70637 .42195 .71399 .43682 .7097 .42812 .70208 Mtetra
.652 .766 .933 r
.42812 .70208 .43682 .7097 .45177 .70524 .44312 .69765 Mtetra
.657 .77 .932 r
.44312 .69765 .45177 .70524 .46682 .70049 .45822 .69302 Mtetra
.667 .776 .931 r
.45822 .69302 .46682 .70049 .48194 .69522 .4734 .68799 Mtetra
.685 .788 .928 r
.4734 .68799 .48194 .69522 .49715 .689 .48866 .68225 Mtetra
.715 .808 .922 r
.48866 .68225 .49715 .689 .51243 .68105 .50401 .67522 Mtetra
.765 .839 .908 r
.50401 .67522 .51243 .68105 .52776 .67007 .51942 .66589 Mtetra
.834 .88 .876 r
.51942 .66589 .52776 .67007 .5431 .65415 .53486 .65263 Mtetra
.908 .917 .813 r
.53486 .65263 .5431 .65415 .55835 .63106 .55027 .63326 Mtetra
.959 .932 .721 r
.55027 .63326 .55835 .63106 .57339 .59971 .56553 .60589 Mtetra
.974 .925 .629 r
.56553 .60589 .57339 .59971 .58817 .56227 .58055 .5708 Mtetra
.967 .917 .575 r
.58055 .5708 .58817 .56227 .60273 .5245 .5953 .53218 Mtetra
.96 .925 .586 r
.5953 .53218 .60273 .5245 .61722 .49234 .60989 .49648 Mtetra
.956 .949 .671 r
.60989 .49648 .61722 .49234 .63181 .46828 .62451 .46818 Mtetra
.926 .95 .787 r
.62451 .46818 .63181 .46828 .64657 .45143 .63927 .44786 Mtetra
.857 .907 .867 r
.63927 .44786 .64657 .45143 .6615 .43963 .65421 .43373 Mtetra
.784 .849 .9 r
.65421 .43373 .6615 .43963 .6766 .43092 .66933 .4236 Mtetra
.732 .804 .909 r
.66933 .4236 .6766 .43092 .69184 .42397 .6846 .41583 Mtetra
.701 .776 .91 r
.6846 .41583 .69184 .42397 .7072 .41796 .7 .40936 Mtetra
.683 .76 .909 r
.7 .40936 .7072 .41796 .72266 .41246 .71551 .40358 Mtetra
.674 .751 .909 r
.71551 .40358 .72266 .41246 .73821 .40721 .73112 .39816 Mtetra
.669 .747 .908 r
.73112 .39816 .73821 .40721 .75386 .40208 .74683 .39292 Mtetra
.666 .744 .908 r
.74683 .39292 .75386 .40208 .7696 .397 .76263 .38775 Mtetra
.665 .743 .908 r
.76263 .38775 .7696 .397 .78543 .39194 .77852 .38262 Mtetra
.664 .742 .908 r
.77852 .38262 .78543 .39194 .80135 .38687 .7945 .37749 Mtetra
.7945 .37749 .80135 .38687 .81736 .38178 .81057 .37235 Mtetra
.81057 .37235 .81736 .38178 .83346 .37667 .82673 .36718 Mtetra
.664 .741 .908 r
.82673 .36718 .83346 .37667 .84965 .37154 .84298 .36199 Mtetra
.84298 .36199 .84965 .37154 .86593 .36638 .85933 .35678 Mtetra
.85933 .35678 .86593 .36638 .88229 .36119 .87576 .35153 Mtetra
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .762 .934 r
.30182 .7277 .31101 .73516 .32537 .73113 .31623 .72364 Mtetra
.31623 .72364 .32537 .73113 .3398 .72708 .33071 .71954 Mtetra
.33071 .71954 .3398 .72708 .35432 .723 .34528 .71543 Mtetra
.646 .763 .934 r
.34528 .71543 .35432 .723 .36892 .7189 .35992 .71129 Mtetra
.35992 .71129 .36892 .7189 .38359 .71476 .37465 .70712 Mtetra
.37465 .70712 .38359 .71476 .39835 .71059 .38946 .70291 Mtetra
.647 .763 .934 r
.38946 .70291 .39835 .71059 .41319 .70637 .40435 .69866 Mtetra
.648 .764 .933 r
.40435 .69866 .41319 .70637 .42812 .70208 .41933 .69435 Mtetra
.65 .765 .933 r
.41933 .69435 .42812 .70208 .44312 .69765 .43439 .68995 Mtetra
.654 .768 .933 r
.43439 .68995 .44312 .69765 .45822 .69302 .44953 .68538 Mtetra
.661 .772 .932 r
.44953 .68538 .45822 .69302 .4734 .68799 .46476 .68051 Mtetra
.674 .781 .93 r
.46476 .68051 .4734 .68799 .48866 .68225 .48009 .67512 Mtetra
.698 .797 .926 r
.48009 .67512 .48866 .68225 .50401 .67522 .49549 .66877 Mtetra
.738 .822 .917 r
.49549 .66877 .50401 .67522 .51942 .66589 .51097 .66068 Mtetra
.798 .859 .895 r
.51097 .66068 .51942 .66589 .53486 .65263 .52651 .64954 Mtetra
.872 .9 .849 r
.52651 .64954 .53486 .65263 .55027 .63326 .54204 .63342 Mtetra
.938 .928 .769 r
.54204 .63342 .55027 .63326 .56553 .60589 .5575 .61008 Mtetra
.97 .93 .673 r
.5575 .61008 .56553 .60589 .58055 .5708 .57275 .57843 Mtetra
.971 .92 .595 r
.57275 .57843 .58055 .5708 .5953 .53218 .58772 .54065 Mtetra
.963 .918 .571 r
.58772 .54065 .5953 .53218 .60989 .49648 .60247 .50254 Mtetra
.959 .937 .621 r
.60247 .50254 .60989 .49648 .62451 .46818 .61716 .47009 Mtetra
.947 .955 .73 r
.61716 .47009 .62451 .46818 .63927 .44786 .63193 .44579 Mtetra
.895 .933 .834 r
.63193 .44579 .63927 .44786 .65421 .43373 .64687 .42875 Mtetra
.819 .877 .888 r
.64687 .42875 .65421 .43373 .66933 .4236 .662 .41679 Mtetra
.755 .824 .906 r
.662 .41679 .66933 .4236 .6846 .41583 .6773 .40793 Mtetra
.714 .788 .91 r
.6773 .40793 .6846 .41583 .7 .40936 .69273 .40084 Mtetra
.691 .767 .91 r
.69273 .40084 .7 .40936 .71551 .40358 .70829 .3947 Mtetra
.678 .755 .909 r
.70829 .3947 .71551 .40358 .73112 .39816 .72395 .38906 Mtetra
.671 .749 .909 r
.72395 .38906 .73112 .39816 .74683 .39292 .73972 .38368 Mtetra
.668 .745 .908 r
.73972 .38368 .74683 .39292 .76263 .38775 .75557 .37842 Mtetra
.666 .743 .908 r
.75557 .37842 .76263 .38775 .77852 .38262 .77153 .37321 Mtetra
.665 .742 .908 r
.77153 .37321 .77852 .38262 .7945 .37749 .78757 .36802 Mtetra
.664 .742 .908 r
.78757 .36802 .7945 .37749 .81057 .37235 .8037 .36281 Mtetra
.8037 .36281 .81057 .37235 .82673 .36718 .81993 .35759 Mtetra
.664 .741 .908 r
.81993 .35759 .82673 .36718 .84298 .36199 .83625 .35235 Mtetra
.83625 .35235 .84298 .36199 .85933 .35678 .85266 .34708 Mtetra
.85266 .34708 .85933 .35678 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .762 .934 r
.29254 .72018 .30182 .7277 .31623 .72364 .30699 .71607 Mtetra
.30699 .71607 .31623 .72364 .33071 .71954 .32153 .71193 Mtetra
.32153 .71193 .33071 .71954 .34528 .71543 .33614 .70778 Mtetra
.33614 .70778 .34528 .71543 .35992 .71129 .35084 .70359 Mtetra
.646 .763 .934 r
.35084 .70359 .35992 .71129 .37465 .70712 .36561 .69938 Mtetra
.36561 .69938 .37465 .70712 .38946 .70291 .38047 .69514 Mtetra
.647 .763 .934 r
.38047 .69514 .38946 .70291 .40435 .69866 .39542 .69086 Mtetra
.648 .763 .934 r
.39542 .69086 .40435 .69866 .41933 .69435 .41044 .68653 Mtetra
.649 .764 .933 r
.41044 .68653 .41933 .69435 .43439 .68995 .42556 .68212 Mtetra
.652 .766 .933 r
.42556 .68212 .43439 .68995 .44953 .68538 .44076 .67759 Mtetra
.657 .77 .932 r
.44076 .67759 .44953 .68538 .46476 .68051 .45604 .67283 Mtetra
.667 .776 .931 r
.45604 .67283 .46476 .68051 .48009 .67512 .47142 .66769 Mtetra
.685 .788 .928 r
.47142 .66769 .48009 .67512 .49549 .66877 .48688 .66183 Mtetra
.715 .808 .922 r
.48688 .66183 .49549 .66877 .51097 .66068 .50243 .65466 Mtetra
.765 .839 .908 r
.50243 .65466 .51097 .66068 .52651 .64954 .51804 .64517 Mtetra
.834 .88 .876 r
.51804 .64517 .52651 .64954 .54204 .63342 .53369 .63173 Mtetra
.908 .917 .813 r
.53369 .63173 .54204 .63342 .5575 .61008 .5493 .61214 Mtetra
.959 .932 .721 r
.5493 .61214 .5575 .61008 .57275 .57843 .56477 .58448 Mtetra
.974 .925 .629 r
.56477 .58448 .57275 .57843 .58772 .54065 .57999 .54906 Mtetra
.967 .917 .575 r
.57999 .54906 .58772 .54065 .60247 .50254 .59494 .5101 Mtetra
.961 .925 .587 r
.59494 .5101 .60247 .50254 .61716 .47009 .60973 .47408 Mtetra
.957 .949 .671 r
.60973 .47408 .61716 .47009 .63193 .44579 .62454 .44552 Mtetra
.926 .95 .787 r
.62454 .44552 .63193 .44579 .64687 .42875 .63949 .42498 Mtetra
.857 .907 .867 r
.63949 .42498 .64687 .42875 .662 .41679 .65462 .41067 Mtetra
.784 .849 .9 r
.65462 .41067 .662 .41679 .6773 .40793 .66994 .40038 Mtetra
.732 .804 .908 r
.66994 .40038 .6773 .40793 .69273 .40084 .68541 .39247 Mtetra
.701 .776 .91 r
.68541 .39247 .69273 .40084 .70829 .3947 .701 .38586 Mtetra
.683 .76 .909 r
.701 .38586 .70829 .3947 .72395 .38906 .71672 .37994 Mtetra
.674 .751 .909 r
.71672 .37994 .72395 .38906 .73972 .38368 .73254 .37439 Mtetra
.669 .747 .908 r
.73254 .37439 .73972 .38368 .75557 .37842 .74845 .36902 Mtetra
.666 .744 .908 r
.74845 .36902 .75557 .37842 .77153 .37321 .76446 .36372 Mtetra
.665 .743 .908 r
.76446 .36372 .77153 .37321 .78757 .36802 .78057 .35845 Mtetra
.664 .742 .908 r
.78057 .35845 .78757 .36802 .8037 .36281 .79677 .35319 Mtetra
.79677 .35319 .8037 .36281 .81993 .35759 .81306 .3479 Mtetra
.81306 .3479 .81993 .35759 .83625 .35235 .82944 .3426 Mtetra
.664 .741 .908 r
.82944 .3426 .83625 .35235 .85266 .34708 .84592 .33727 Mtetra
.84592 .33727 .85266 .34708 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72018 .30699 .71607 .29767 .70842 Mtetra
.29767 .70842 .30699 .71607 .32153 .71193 .31225 .70425 Mtetra
.31225 .70425 .32153 .71193 .33614 .70778 .32691 .70005 Mtetra
.32691 .70005 .33614 .70778 .35084 .70359 .34166 .69582 Mtetra
.646 .763 .934 r
.34166 .69582 .35084 .70359 .36561 .69938 .35649 .69157 Mtetra
.35649 .69157 .36561 .69938 .38047 .69514 .3714 .68729 Mtetra
.3714 .68729 .38047 .69514 .39542 .69086 .38639 .68298 Mtetra
.647 .763 .934 r
.38639 .68298 .39542 .69086 .41044 .68653 .40147 .67862 Mtetra
.648 .764 .933 r
.40147 .67862 .41044 .68653 .42556 .68212 .41664 .6742 Mtetra
.65 .765 .933 r
.41664 .6742 .42556 .68212 .44076 .67759 .43189 .66967 Mtetra
.654 .768 .933 r
.43189 .66967 .44076 .67759 .45604 .67283 .44723 .66499 Mtetra
.661 .772 .932 r
.44723 .66499 .45604 .67283 .47142 .66769 .46266 .66 Mtetra
.674 .781 .93 r
.46266 .66 .47142 .66769 .48688 .66183 .47818 .65449 Mtetra
.698 .797 .926 r
.47818 .65449 .48688 .66183 .50243 .65466 .49379 .64801 Mtetra
.738 .822 .917 r
.49379 .64801 .50243 .65466 .51804 .64517 .50947 .63977 Mtetra
.798 .859 .895 r
.50947 .63977 .51804 .64517 .53369 .63173 .52522 .62846 Mtetra
.872 .901 .849 r
.52522 .62846 .53369 .63173 .5493 .61214 .54096 .61213 Mtetra
.938 .928 .769 r
.54096 .61213 .5493 .61214 .56477 .58448 .55662 .58854 Mtetra
.97 .93 .672 r
.55662 .58854 .56477 .58448 .57999 .54906 .57208 .55658 Mtetra
.971 .92 .595 r
.57208 .55658 .57999 .54906 .59494 .5101 .58726 .51845 Mtetra
.963 .918 .571 r
.58726 .51845 .59494 .5101 .60973 .47408 .60221 .48001 Mtetra
.96 .937 .621 r
.60221 .48001 .60973 .47408 .62454 .44552 .61708 .44726 Mtetra
.947 .955 .73 r
.61708 .44726 .62454 .44552 .63949 .42498 .63205 .42272 Mtetra
.895 .933 .834 r
.63205 .42272 .63949 .42498 .65462 .41067 .64719 .40548 Mtetra
.819 .877 .888 r
.64719 .40548 .65462 .41067 .66994 .40038 .66252 .39334 Mtetra
.755 .824 .906 r
.66252 .39334 .66994 .40038 .68541 .39247 .67801 .38433 Mtetra
.714 .788 .91 r
.67801 .38433 .68541 .39247 .701 .38586 .69365 .3771 Mtetra
.691 .767 .91 r
.69365 .3771 .701 .38586 .71672 .37994 .70941 .37082 Mtetra
.678 .755 .909 r
.70941 .37082 .71672 .37994 .73254 .37439 .72528 .36505 Mtetra
.671 .749 .909 r
.72528 .36505 .73254 .37439 .74845 .36902 .74126 .35954 Mtetra
.668 .745 .908 r
.74126 .35954 .74845 .36902 .76446 .36372 .75733 .35414 Mtetra
.666 .743 .908 r
.75733 .35414 .76446 .36372 .78057 .35845 .7735 .34879 Mtetra
.665 .742 .908 r
.7735 .34879 .78057 .35845 .79677 .35319 .78976 .34346 Mtetra
.664 .742 .908 r
.78976 .34346 .79677 .35319 .81306 .3479 .80611 .33812 Mtetra
.80611 .33812 .81306 .3479 .82944 .3426 .82256 .33276 Mtetra
.664 .741 .908 r
.82256 .33276 .82944 .3426 .84592 .33727 .83911 .32737 Mtetra
.83911 .32737 .84592 .33727 .86249 .33192 .85575 .32196 Mtetra
.85575 .32196 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70842 .28825 .7007 Mtetra
.28825 .7007 .29767 .70842 .31225 .70425 .30288 .69648 Mtetra
.30288 .69648 .31225 .70425 .32691 .70005 .31759 .69224 Mtetra
.31759 .69224 .32691 .70005 .34166 .69582 .33239 .68797 Mtetra
.33239 .68797 .34166 .69582 .35649 .69157 .34726 .68368 Mtetra
.646 .763 .934 r
.34726 .68368 .35649 .69157 .3714 .68729 .36223 .67936 Mtetra
.36223 .67936 .3714 .68729 .38639 .68298 .37727 .675 Mtetra
.647 .763 .934 r
.37727 .675 .38639 .68298 .40147 .67862 .3924 .67061 Mtetra
.648 .763 .934 r
.3924 .67061 .40147 .67862 .41664 .6742 .40762 .66616 Mtetra
.649 .764 .933 r
.40762 .66616 .41664 .6742 .43189 .66967 .42293 .66164 Mtetra
.652 .766 .933 r
.42293 .66164 .43189 .66967 .44723 .66499 .43832 .65699 Mtetra
.657 .77 .932 r
.43832 .65699 .44723 .66499 .46266 .66 .45381 .65211 Mtetra
.667 .776 .931 r
.45381 .65211 .46266 .66 .47818 .65449 .46939 .64684 Mtetra
.685 .788 .929 r
.46939 .64684 .47818 .65449 .49379 .64801 .48505 .64085 Mtetra
.715 .808 .923 r
.48505 .64085 .49379 .64801 .50947 .63977 .5008 .63354 Mtetra
.765 .84 .908 r
.5008 .63354 .50947 .63977 .52522 .62846 .51663 .6239 Mtetra
.834 .88 .876 r
.51663 .6239 .52522 .62846 .54096 .61213 .53249 .61027 Mtetra
.908 .917 .813 r
.53249 .61027 .54096 .61213 .55662 .58854 .54831 .59045 Mtetra
.959 .932 .721 r
.54831 .59045 .55662 .58854 .57208 .55658 .56399 .5625 Mtetra
.973 .925 .629 r
.56399 .5625 .57208 .55658 .58726 .51845 .57942 .52675 Mtetra
.967 .917 .575 r
.57942 .52675 .58726 .51845 .60221 .48001 .59457 .48743 Mtetra
.961 .925 .587 r
.59457 .48743 .60221 .48001 .61708 .44726 .60956 .45109 Mtetra
.957 .949 .671 r
.60956 .45109 .61708 .44726 .63205 .42272 .62456 .42225 Mtetra
.926 .95 .787 r
.62456 .42225 .63205 .42272 .64719 .40548 .63971 .4015 Mtetra
.857 .907 .867 r
.63971 .4015 .64719 .40548 .66252 .39334 .65504 .387 Mtetra
.784 .849 .9 r
.65504 .387 .66252 .39334 .67801 .38433 .67056 .37656 Mtetra
.732 .804 .908 r
.67056 .37656 .67801 .38433 .69365 .3771 .68623 .36849 Mtetra
.701 .776 .91 r
.68623 .36849 .69365 .3771 .70941 .37082 .70204 .36174 Mtetra
.683 .76 .909 r
.70204 .36174 .70941 .37082 .72528 .36505 .71796 .35569 Mtetra
.674 .751 .909 r
.71796 .35569 .72528 .36505 .74126 .35954 .73399 .34999 Mtetra
.669 .747 .908 r
.73399 .34999 .74126 .35954 .75733 .35414 .75012 .34448 Mtetra
.666 .744 .908 r
.75012 .34448 .75733 .35414 .7735 .34879 .76635 .33904 Mtetra
.665 .743 .908 r
.76635 .33904 .7735 .34879 .78976 .34346 .78268 .33364 Mtetra
.664 .742 .908 r
.78268 .33364 .78976 .34346 .80611 .33812 .7991 .32823 Mtetra
.7991 .32823 .80611 .33812 .82256 .33276 .81561 .32281 Mtetra
.81561 .32281 .82256 .33276 .83911 .32737 .83223 .31736 Mtetra
.664 .741 .908 r
.83223 .31736 .83911 .32737 .85575 .32196 .84893 .31189 Mtetra
.84893 .31189 .85575 .32196 .87248 .31651 .86574 .30639 Mtetra
.86574 .30639 .87248 .31651 .88931 .31104 .88264 .30085 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .7007 .27873 .69289 Mtetra
.27873 .69289 .28825 .7007 .30288 .69648 .29341 .68863 Mtetra
.29341 .68863 .30288 .69648 .31759 .69224 .30817 .68435 Mtetra
.30817 .68435 .31759 .69224 .33239 .68797 .32302 .68004 Mtetra
.32302 .68004 .33239 .68797 .34726 .68368 .33794 .6757 Mtetra
.646 .763 .934 r
.33794 .6757 .34726 .68368 .36223 .67936 .35296 .67134 Mtetra
.35296 .67134 .36223 .67936 .37727 .675 .36806 .66694 Mtetra
.36806 .66694 .37727 .675 .3924 .67061 .38324 .66251 Mtetra
.647 .763 .934 r
.38324 .66251 .3924 .67061 .40762 .66616 .39851 .65804 Mtetra
.648 .764 .933 r
.39851 .65804 .40762 .66616 .42293 .66164 .41387 .6535 Mtetra
.65 .765 .933 r
.41387 .6535 .42293 .66164 .43832 .65699 .42932 .64885 Mtetra
.654 .768 .933 r
.42932 .64885 .43832 .65699 .45381 .65211 .44487 .64404 Mtetra
.661 .772 .932 r
.44487 .64404 .45381 .65211 .46939 .64684 .4605 .63894 Mtetra
.674 .781 .93 r
.4605 .63894 .46939 .64684 .48505 .64085 .47622 .6333 Mtetra
.698 .797 .926 r
.47622 .6333 .48505 .64085 .5008 .63354 .49204 .62668 Mtetra
.738 .822 .917 r
.49204 .62668 .5008 .63354 .51663 .6239 .50793 .61829 Mtetra
.798 .859 .895 r
.50793 .61829 .51663 .6239 .53249 .61027 .52389 .60681 Mtetra
.872 .901 .849 r
.52389 .60681 .53249 .61027 .54831 .59045 .53985 .59027 Mtetra
.938 .928 .769 r
.53985 .59027 .54831 .59045 .56399 .5625 .55573 .56641 Mtetra
.97 .931 .672 r
.55573 .56641 .56399 .5625 .57942 .52675 .5714 .53413 Mtetra
.971 .92 .595 r
.5714 .53413 .57942 .52675 .59457 .48743 .58679 .49566 Mtetra
.963 .918 .571 r
.58679 .49566 .59457 .48743 .60956 .45109 .60194 .45687 Mtetra
.96 .937 .622 r
.60194 .45687 .60956 .45109 .62456 .42225 .61701 .42382 Mtetra
.947 .955 .73 r
.61701 .42382 .62456 .42225 .63971 .4015 .63218 .39903 Mtetra
.895 .933 .834 r
.63218 .39903 .63971 .4015 .65504 .387 .64752 .38159 Mtetra
.819 .877 .888 r
.64752 .38159 .65504 .387 .67056 .37656 .66305 .36928 Mtetra
.755 .824 .906 r
.66305 .36928 .67056 .37656 .68623 .36849 .67875 .36012 Mtetra
.714 .788 .909 r
.67875 .36012 .68623 .36849 .70204 .36174 .69459 .35273 Mtetra
.691 .767 .91 r
.69459 .35273 .70204 .36174 .71796 .35569 .71056 .34631 Mtetra
.678 .755 .909 r
.71056 .34631 .71796 .35569 .73399 .34999 .72665 .3404 Mtetra
.671 .749 .909 r
.72665 .3404 .73399 .34999 .75012 .34448 .74284 .33474 Mtetra
.668 .745 .908 r
.74284 .33474 .75012 .34448 .76635 .33904 .75913 .32921 Mtetra
.666 .743 .908 r
.75913 .32921 .76635 .33904 .78268 .33364 .77552 .32372 Mtetra
.665 .742 .908 r
.77552 .32372 .78268 .33364 .7991 .32823 .79201 .31824 Mtetra
.664 .742 .908 r
.79201 .31824 .7991 .32823 .81561 .32281 .80859 .31275 Mtetra
.80859 .31275 .81561 .32281 .83223 .31736 .82527 .30725 Mtetra
.664 .741 .908 r
.82527 .30725 .83223 .31736 .84893 .31189 .84205 .30171 Mtetra
.84205 .30171 .84893 .31189 .86574 .30639 .85892 .29615 Mtetra
.85892 .29615 .86574 .30639 .88264 .30085 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .68501 Mtetra
.26911 .68501 .27873 .69289 .29341 .68863 .28384 .6807 Mtetra
.28384 .6807 .29341 .68863 .30817 .68435 .29865 .67637 Mtetra
.29865 .67637 .30817 .68435 .32302 .68004 .31355 .67202 Mtetra
.31355 .67202 .32302 .68004 .33794 .6757 .32853 .66764 Mtetra
.32853 .66764 .33794 .6757 .35296 .67134 .34359 .66323 Mtetra
.646 .763 .934 r
.34359 .66323 .35296 .67134 .36806 .66694 .35875 .65879 Mtetra
.35875 .65879 .36806 .66694 .38324 .66251 .37398 .65432 Mtetra
.647 .763 .934 r
.37398 .65432 .38324 .66251 .39851 .65804 .38931 .64981 Mtetra
.648 .763 .934 r
.38931 .64981 .39851 .65804 .41387 .6535 .40473 .64525 Mtetra
.649 .764 .933 r
.40473 .64525 .41387 .6535 .42932 .64885 .42023 .6406 Mtetra
.652 .766 .933 r
.42023 .6406 .42932 .64885 .44487 .64404 .43583 .63582 Mtetra
.657 .77 .932 r
.43583 .63582 .44487 .64404 .4605 .63894 .45151 .63083 Mtetra
.667 .776 .931 r
.45151 .63083 .4605 .63894 .47622 .6333 .4673 .62543 Mtetra
.685 .788 .929 r
.4673 .62543 .47622 .6333 .49204 .62668 .48317 .6193 Mtetra
.715 .808 .923 r
.48317 .6193 .49204 .62668 .50793 .61829 .49914 .61185 Mtetra
.765 .84 .908 r
.49914 .61185 .50793 .61829 .52389 .60681 .51517 .60204 Mtetra
.834 .881 .876 r
.51517 .60204 .52389 .60681 .53985 .59027 .53125 .58821 Mtetra
.908 .918 .813 r
.53125 .58821 .53985 .59027 .55573 .56641 .5473 .56816 Mtetra
.959 .932 .72 r
.5473 .56816 .55573 .56641 .5714 .53413 .5632 .53992 Mtetra
.973 .925 .628 r
.5632 .53992 .5714 .53413 .58679 .49566 .57884 .50383 Mtetra
.967 .917 .575 r
.57884 .50383 .58679 .49566 .60194 .45687 .5942 .46416 Mtetra
.961 .925 .587 r
.5942 .46416 .60194 .45687 .61701 .42382 .60939 .42749 Mtetra
.957 .949 .672 r
.60939 .42749 .61701 .42382 .63218 .39903 .62459 .39838 Mtetra
.926 .95 .787 r
.62459 .39838 .63218 .39903 .64752 .38159 .63994 .37739 Mtetra
.857 .906 .867 r
.63994 .37739 .64752 .38159 .66305 .36928 .65547 .36271 Mtetra
.784 .848 .9 r
.65547 .36271 .66305 .36928 .67875 .36012 .6712 .3521 Mtetra
.732 .804 .908 r
.6712 .3521 .67875 .36012 .69459 .35273 .68708 .34387 Mtetra
.701 .776 .91 r
.68708 .34387 .69459 .35273 .71056 .34631 .7031 .33697 Mtetra
.683 .76 .909 r
.7031 .33697 .71056 .34631 .72665 .3404 .71924 .33078 Mtetra
.674 .751 .909 r
.71924 .33078 .72665 .3404 .74284 .33474 .73549 .32494 Mtetra
.669 .747 .908 r
.73549 .32494 .74284 .33474 .75913 .32921 .75184 .31928 Mtetra
.666 .744 .908 r
.75184 .31928 .75913 .32921 .77552 .32372 .76829 .3137 Mtetra
.665 .743 .908 r
.76829 .3137 .77552 .32372 .79201 .31824 .78484 .30815 Mtetra
.664 .742 .908 r
.78484 .30815 .79201 .31824 .80859 .31275 .80149 .3026 Mtetra
.80149 .3026 .80859 .31275 .82527 .30725 .81824 .29703 Mtetra
.81824 .29703 .82527 .30725 .84205 .30171 .83509 .29143 Mtetra
.664 .741 .908 r
.83509 .29143 .84205 .30171 .85892 .29615 .85203 .28581 Mtetra
.85203 .28581 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .68501 .25939 .67704 Mtetra
.25939 .67704 .26911 .68501 .28384 .6807 .27417 .67269 Mtetra
.27417 .67269 .28384 .6807 .29865 .67637 .28903 .66832 Mtetra
.28903 .66832 .29865 .67637 .31355 .67202 .30398 .66392 Mtetra
.30398 .66392 .31355 .67202 .32853 .66764 .31901 .65949 Mtetra
.31901 .65949 .32853 .66764 .34359 .66323 .33413 .65504 Mtetra
.646 .763 .934 r
.33413 .65504 .34359 .66323 .35875 .65879 .34934 .65056 Mtetra
.34934 .65056 .35875 .65879 .37398 .65432 .36463 .64604 Mtetra
.36463 .64604 .37398 .65432 .38931 .64981 .38001 .64149 Mtetra
.647 .763 .934 r
.38001 .64149 .38931 .64981 .40473 .64525 .39548 .6369 Mtetra
.648 .764 .933 r
.39548 .6369 .40473 .64525 .42023 .6406 .41104 .63223 Mtetra
.65 .765 .933 r
.41104 .63223 .42023 .6406 .43583 .63582 .42669 .62747 Mtetra
.654 .768 .933 r
.42669 .62747 .43583 .63582 .45151 .63083 .44244 .62253 Mtetra
.661 .773 .932 r
.44244 .62253 .45151 .63083 .4673 .62543 .45828 .6173 Mtetra
.674 .781 .93 r
.45828 .6173 .4673 .62543 .48317 .6193 .47421 .61152 Mtetra
.698 .797 .926 r
.47421 .61152 .48317 .6193 .49914 .61185 .49024 .60476 Mtetra
.738 .822 .917 r
.49024 .60476 .49914 .61185 .51517 .60204 .50635 .59621 Mtetra
.798 .86 .895 r
.50635 .59621 .51517 .60204 .53125 .58821 .52253 .58456 Mtetra
.873 .901 .849 r
.52253 .58456 .53125 .58821 .5473 .56816 .53871 .5678 Mtetra
.938 .929 .769 r
.53871 .5678 .5473 .56816 .5632 .53992 .55481 .54368 Mtetra
.97 .931 .672 r
.55481 .54368 .5632 .53992 .57884 .50383 .5707 .51108 Mtetra
.971 .92 .595 r
.5707 .51108 .57884 .50383 .5942 .46416 .5863 .47225 Mtetra
.963 .918 .572 r
.5863 .47225 .5942 .46416 .60939 .42749 .60166 .43311 Mtetra
.96 .937 .622 r
.60166 .43311 .60939 .42749 .62459 .39838 .61694 .39975 Mtetra
.947 .955 .73 r
.61694 .39975 .62459 .39838 .63994 .37739 .6323 .37472 Mtetra
.894 .932 .834 r
.6323 .37472 .63994 .37739 .65547 .36271 .64785 .35706 Mtetra
.819 .877 .888 r
.64785 .35706 .65547 .36271 .6712 .3521 .66359 .34458 Mtetra
.755 .824 .906 r
.66359 .34458 .6712 .3521 .68708 .34387 .6795 .33525 Mtetra
.714 .788 .909 r
.6795 .33525 .68708 .34387 .7031 .33697 .69556 .32771 Mtetra
.691 .767 .91 r
.69556 .32771 .7031 .33697 .71924 .33078 .71175 .32115 Mtetra
.678 .755 .909 r
.71175 .32115 .71924 .33078 .73549 .32494 .72805 .31509 Mtetra
.671 .748 .909 r
.72805 .31509 .73549 .32494 .75184 .31928 .74447 .30928 Mtetra
.668 .745 .908 r
.74447 .30928 .75184 .31928 .76829 .3137 .76099 .3036 Mtetra
.666 .743 .908 r
.76099 .3036 .76829 .3137 .78484 .30815 .7776 .29796 Mtetra
.665 .742 .908 r
.7776 .29796 .78484 .30815 .80149 .3026 .79432 .29233 Mtetra
.664 .742 .908 r
.79432 .29233 .80149 .3026 .81824 .29703 .81114 .2867 Mtetra
.81114 .2867 .81824 .29703 .83509 .29143 .82805 .28104 Mtetra
.664 .741 .908 r
.82805 .28104 .83509 .29143 .85203 .28581 .84507 .27535 Mtetra
.84507 .27535 .85203 .28581 .86907 .28015 .86218 .26964 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .6646 Mtetra
.2644 .6646 .27417 .67269 .28903 .66832 .27932 .66018 Mtetra
.27932 .66018 .28903 .66832 .30398 .66392 .29431 .65573 Mtetra
.29431 .65573 .30398 .66392 .31901 .65949 .3094 .65126 Mtetra
.3094 .65126 .31901 .65949 .33413 .65504 .32457 .64676 Mtetra
.32457 .64676 .33413 .65504 .34934 .65056 .33983 .64223 Mtetra
.646 .763 .934 r
.33983 .64223 .34934 .65056 .36463 .64604 .35517 .63767 Mtetra
.35517 .63767 .36463 .64604 .38001 .64149 .37061 .63308 Mtetra
.647 .763 .934 r
.37061 .63308 .38001 .64149 .39548 .6369 .38613 .62845 Mtetra
.648 .763 .934 r
.38613 .62845 .39548 .6369 .41104 .63223 .40175 .62376 Mtetra
.649 .764 .933 r
.40175 .62376 .41104 .63223 .42669 .62747 .41746 .61899 Mtetra
.652 .766 .933 r
.41746 .61899 .42669 .62747 .44244 .62253 .43326 .61408 Mtetra
.657 .77 .932 r
.43326 .61408 .44244 .62253 .45828 .6173 .44916 .60895 Mtetra
.667 .776 .931 r
.44916 .60895 .45828 .6173 .47421 .61152 .46515 .60342 Mtetra
.685 .788 .929 r
.46515 .60342 .47421 .61152 .49024 .60476 .48124 .59715 Mtetra
.715 .808 .923 r
.48124 .59715 .49024 .60476 .50635 .59621 .49742 .58955 Mtetra
.765 .84 .909 r
.49742 .58955 .50635 .59621 .52253 .58456 .51368 .57957 Mtetra
.834 .881 .876 r
.51368 .57957 .52253 .58456 .53871 .5678 .52998 .56555 Mtetra
.908 .918 .813 r
.52998 .56555 .53871 .5678 .55481 .54368 .54625 .54525 Mtetra
.959 .933 .72 r
.54625 .54525 .55481 .54368 .5707 .51108 .56237 .51672 Mtetra
.973 .925 .628 r
.56237 .51672 .5707 .51108 .5863 .47225 .57824 .48028 Mtetra
.967 .917 .575 r
.57824 .48028 .5863 .47225 .60166 .43311 .59381 .44024 Mtetra
.961 .925 .587 r
.59381 .44024 .60166 .43311 .61694 .39975 .60921 .40325 Mtetra
.957 .949 .672 r
.60921 .40325 .61694 .39975 .6323 .37472 .62462 .37385 Mtetra
.926 .95 .787 r
.62462 .37385 .6323 .37472 .64785 .35706 .64017 .35264 Mtetra
.857 .906 .867 r
.64017 .35264 .64785 .35706 .66359 .34458 .65592 .33776 Mtetra
.784 .848 .899 r
.65592 .33776 .66359 .34458 .6795 .33525 .67185 .32698 Mtetra
.732 .804 .908 r
.67185 .32698 .6795 .33525 .69556 .32771 .68795 .3186 Mtetra
.701 .776 .91 r
.68795 .3186 .69556 .32771 .71175 .32115 .70419 .31154 Mtetra
.683 .76 .909 r
.70419 .31154 .71175 .32115 .72805 .31509 .72055 .30519 Mtetra
.674 .751 .909 r
.72055 .30519 .72805 .31509 .74447 .30928 .73702 .29921 Mtetra
.669 .747 .908 r
.73702 .29921 .74447 .30928 .76099 .3036 .7536 .2934 Mtetra
.666 .744 .908 r
.7536 .2934 .76099 .3036 .7776 .29796 .77029 .28767 Mtetra
.665 .743 .908 r
.77029 .28767 .7776 .29796 .79432 .29233 .78707 .28197 Mtetra
.664 .742 .908 r
.78707 .28197 .79432 .29233 .81114 .2867 .80395 .27626 Mtetra
.80395 .27626 .81114 .2867 .82805 .28104 .82094 .27053 Mtetra
.82094 .27053 .82805 .28104 .84507 .27535 .83803 .26478 Mtetra
.664 .741 .908 r
.83803 .26478 .84507 .27535 .86218 .26964 .85521 .259 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .6646 .25453 .65642 Mtetra
.25453 .65642 .2644 .6646 .27932 .66018 .2695 .65195 Mtetra
.2695 .65195 .27932 .66018 .29431 .65573 .28454 .64745 Mtetra
.28454 .64745 .29431 .65573 .3094 .65126 .29968 .64293 Mtetra
.29968 .64293 .3094 .65126 .32457 .64676 .3149 .63839 Mtetra
.3149 .63839 .32457 .64676 .33983 .64223 .33021 .63381 Mtetra
.646 .763 .934 r
.33021 .63381 .33983 .64223 .35517 .63767 .34561 .62921 Mtetra
.34561 .62921 .35517 .63767 .37061 .63308 .3611 .62457 Mtetra
.3611 .62457 .37061 .63308 .38613 .62845 .37668 .6199 Mtetra
.647 .763 .934 r
.37668 .6199 .38613 .62845 .40175 .62376 .39236 .61518 Mtetra
.648 .764 .933 r
.39236 .61518 .40175 .62376 .41746 .61899 .40812 .61038 Mtetra
.65 .765 .933 r
.40812 .61038 .41746 .61899 .43326 .61408 .42398 .60549 Mtetra
.654 .768 .933 r
.42398 .60549 .43326 .61408 .44916 .60895 .43994 .60042 Mtetra
.661 .773 .932 r
.43994 .60042 .44916 .60895 .46515 .60342 .45599 .59505 Mtetra
.674 .781 .93 r
.45599 .59505 .46515 .60342 .48124 .59715 .47214 .58914 Mtetra
.698 .797 .926 r
.47214 .58914 .48124 .59715 .49742 .58955 .48839 .58223 Mtetra
.738 .823 .917 r
.48839 .58223 .49742 .58955 .51368 .57957 .50473 .57352 Mtetra
.798 .86 .896 r
.50473 .57352 .51368 .57957 .52998 .56555 .52112 .56168 Mtetra
.873 .901 .849 r
.52112 .56168 .52998 .56555 .54625 .54525 .53754 .5447 Mtetra
.938 .929 .769 r
.53754 .5447 .54625 .54525 .56237 .51672 .55386 .52031 Mtetra
.97 .931 .671 r
.55386 .52031 .56237 .51672 .57824 .48028 .56998 .48738 Mtetra
.971 .92 .594 r
.56998 .48738 .57824 .48028 .59381 .44024 .5858 .44819 Mtetra
.963 .918 .572 r
.5858 .44819 .59381 .44024 .60921 .40325 .60137 .4087 Mtetra
.96 .937 .622 r
.60137 .4087 .60921 .40325 .62462 .37385 .61686 .37503 Mtetra
.947 .954 .731 r
.61686 .37503 .62462 .37385 .64017 .35264 .63244 .34974 Mtetra
.894 .932 .834 r
.63244 .34974 .64017 .35264 .65592 .33776 .64819 .33188 Mtetra
.819 .877 .888 r
.64819 .33188 .65592 .33776 .67185 .32698 .66414 .3192 Mtetra
.755 .824 .905 r
.66414 .3192 .67185 .32698 .68795 .3186 .68027 .30971 Mtetra
.714 .788 .909 r
.68027 .30971 .68795 .3186 .70419 .31154 .69655 .30201 Mtetra
.691 .767 .91 r
.69655 .30201 .70419 .31154 .72055 .30519 .71296 .29529 Mtetra
.678 .755 .909 r
.71296 .29529 .72055 .30519 .73702 .29921 .7295 .28908 Mtetra
.671 .748 .909 r
.7295 .28908 .73702 .29921 .7536 .2934 .74614 .28312 Mtetra
.668 .745 .908 r
.74614 .28312 .7536 .2934 .77029 .28767 .76289 .27728 Mtetra
.666 .743 .908 r
.76289 .27728 .77029 .28767 .78707 .28197 .77974 .27149 Mtetra
.665 .742 .908 r
.77974 .27149 .78707 .28197 .80395 .27626 .7967 .26571 Mtetra
.664 .742 .908 r
.7967 .26571 .80395 .27626 .82094 .27053 .81375 .25992 Mtetra
.81375 .25992 .82094 .27053 .83803 .26478 .83091 .2541 Mtetra
.664 .741 .908 r
.83091 .2541 .83803 .26478 .85521 .259 .84817 .24825 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65642 .24456 .64815 Mtetra
.24456 .64815 .25453 .65642 .2695 .65195 .25957 .64363 Mtetra
.25957 .64363 .2695 .65195 .28454 .64745 .27467 .63909 Mtetra
.27467 .63909 .28454 .64745 .29968 .64293 .28986 .63452 Mtetra
.28986 .63452 .29968 .64293 .3149 .63839 .30513 .62993 Mtetra
.30513 .62993 .3149 .63839 .33021 .63381 .3205 .62531 Mtetra
.3205 .62531 .33021 .63381 .34561 .62921 .33595 .62065 Mtetra
.646 .763 .934 r
.33595 .62065 .34561 .62921 .3611 .62457 .3515 .61597 Mtetra
.3515 .61597 .3611 .62457 .37668 .6199 .36714 .61125 Mtetra
.647 .763 .934 r
.36714 .61125 .37668 .6199 .39236 .61518 .38287 .60649 Mtetra
.648 .763 .934 r
.38287 .60649 .39236 .61518 .40812 .61038 .39869 .60167 Mtetra
.649 .764 .933 r
.39869 .60167 .40812 .61038 .42398 .60549 .41461 .59677 Mtetra
.652 .766 .933 r
.41461 .59677 .42398 .60549 .43994 .60042 .43062 .59173 Mtetra
.657 .77 .932 r
.43062 .59173 .43994 .60042 .45599 .59505 .44673 .58647 Mtetra
.667 .776 .931 r
.44673 .58647 .45599 .59505 .47214 .58914 .46295 .58079 Mtetra
.685 .788 .929 r
.46295 .58079 .47214 .58914 .48839 .58223 .47926 .57438 Mtetra
.715 .808 .923 r
.47926 .57438 .48839 .58223 .50473 .57352 .49566 .56662 Mtetra
.765 .84 .909 r
.49566 .56662 .50473 .57352 .52112 .56168 .51215 .55647 Mtetra
.835 .881 .876 r
.51215 .55647 .52112 .56168 .53754 .5447 .52868 .54224 Mtetra
.909 .918 .813 r
.52868 .54224 .53754 .5447 .55386 .52031 .54518 .5217 Mtetra
.959 .933 .72 r
.54518 .5217 .55386 .52031 .56998 .48738 .56153 .49286 Mtetra
.973 .925 .628 r
.56153 .49286 .56998 .48738 .5858 .44819 .57762 .45607 Mtetra
.967 .917 .575 r
.57762 .45607 .5858 .44819 .60137 .4087 .59341 .41567 Mtetra
.961 .925 .588 r
.59341 .41567 .60137 .4087 .61686 .37503 .60902 .37834 Mtetra
.957 .948 .673 r
.60902 .37834 .61686 .37503 .63244 .34974 .62464 .34866 Mtetra
.926 .949 .787 r
.62464 .34866 .63244 .34974 .64819 .33188 .64041 .32721 Mtetra
.857 .906 .867 r
.64041 .32721 .64819 .33188 .66414 .3192 .65637 .31213 Mtetra
.784 .848 .899 r
.65637 .31213 .66414 .3192 .68027 .30971 .67252 .30117 Mtetra
.732 .804 .908 r
.67252 .30117 .68027 .30971 .69655 .30201 .68884 .29262 Mtetra
.701 .776 .91 r
.68884 .29262 .69655 .30201 .71296 .29529 .7053 .28541 Mtetra
.683 .76 .909 r
.7053 .28541 .71296 .29529 .7295 .28908 .72189 .27891 Mtetra
.674 .751 .909 r
.72189 .27891 .7295 .28908 .74614 .28312 .7386 .27277 Mtetra
.669 .747 .908 r
.7386 .27277 .74614 .28312 .76289 .27728 .75541 .2668 Mtetra
.666 .744 .908 r
.75541 .2668 .76289 .27728 .77974 .27149 .77233 .26092 Mtetra
.665 .743 .908 r
.77233 .26092 .77974 .27149 .7967 .26571 .78936 .25505 Mtetra
.664 .742 .908 r
.78936 .25505 .7967 .26571 .81375 .25992 .80648 .24919 Mtetra
.80648 .24919 .81375 .25992 .83091 .2541 .82371 .2433 Mtetra
.82371 .2433 .83091 .2541 .84817 .24825 .84105 .23739 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63909 .26469 .63064 Mtetra
.26469 .63064 .27467 .63909 .28986 .63452 .27993 .62602 Mtetra
.27993 .62602 .28986 .63452 .30513 .62993 .29526 .62138 Mtetra
.29526 .62138 .30513 .62993 .3205 .62531 .31068 .61671 Mtetra
.31068 .61671 .3205 .62531 .33595 .62065 .32619 .61201 Mtetra
.646 .763 .934 r
.32619 .61201 .33595 .62065 .3515 .61597 .34179 .60727 Mtetra
.34179 .60727 .3515 .61597 .36714 .61125 .35748 .60251 Mtetra
.35748 .60251 .36714 .61125 .38287 .60649 .37327 .5977 Mtetra
.647 .763 .934 r
.37327 .5977 .38287 .60649 .39869 .60167 .38915 .59285 Mtetra
.648 .764 .933 r
.38915 .59285 .39869 .60167 .41461 .59677 .40513 .58793 Mtetra
.65 .765 .933 r
.40513 .58793 .41461 .59677 .43062 .59173 .4212 .5829 Mtetra
.654 .768 .933 r
.4212 .5829 .43062 .59173 .44673 .58647 .43737 .57769 Mtetra
.661 .773 .932 r
.43737 .57769 .44673 .58647 .46295 .58079 .45364 .57218 Mtetra
.674 .781 .93 r
.45364 .57218 .46295 .58079 .47926 .57438 .47002 .56612 Mtetra
.698 .797 .926 r
.47002 .56612 .47926 .57438 .49566 .56662 .48649 .55906 Mtetra
.738 .823 .917 r
.48649 .55906 .49566 .56662 .51215 .55647 .50305 .55019 Mtetra
.798 .86 .896 r
.50305 .55019 .51215 .55647 .52868 .54224 .51968 .53815 Mtetra
.873 .901 .849 r
.51968 .53815 .52868 .54224 .54518 .5217 .53633 .52095 Mtetra
.938 .929 .769 r
.53633 .52095 .54518 .5217 .56153 .49286 .55289 .49628 Mtetra
.97 .931 .671 r
.55289 .49628 .56153 .49286 .57762 .45607 .56924 .46302 Mtetra
.971 .92 .594 r
.56924 .46302 .57762 .45607 .59341 .41567 .58529 .42346 Mtetra
.963 .918 .572 r
.58529 .42346 .59341 .41567 .60902 .37834 .60108 .38361 Mtetra
.96 .937 .623 r
.60108 .38361 .60902 .37834 .62464 .34866 .61678 .34963 Mtetra
.947 .954 .731 r
.61678 .34963 .62464 .34866 .64041 .32721 .63257 .32408 Mtetra
.894 .932 .834 r
.63257 .32408 .64041 .32721 .65637 .31213 .64854 .30599 Mtetra
.819 .876 .888 r
.64854 .30599 .65637 .31213 .67252 .30117 .66471 .29313 Mtetra
.755 .824 .905 r
.66471 .29313 .67252 .30117 .68884 .29262 .68106 .28347 Mtetra
.714 .788 .909 r
.68106 .28347 .68884 .29262 .7053 .28541 .69757 .2756 Mtetra
.691 .767 .91 r
.69757 .2756 .7053 .28541 .72189 .27891 .71421 .26872 Mtetra
.678 .755 .909 r
.71421 .26872 .72189 .27891 .7386 .27277 .73098 .26235 Mtetra
.671 .748 .909 r
.73098 .26235 .7386 .27277 .75541 .2668 .74786 .25623 Mtetra
.668 .745 .908 r
.74786 .25623 .75541 .2668 .77233 .26092 .76484 .25024 Mtetra
.666 .743 .908 r
.76484 .25024 .77233 .26092 .78936 .25505 .78194 .24428 Mtetra
.665 .742 .908 r
.78194 .24428 .78936 .25505 .80648 .24919 .79914 .23834 Mtetra
.664 .742 .908 r
.79914 .23834 .80648 .24919 .82371 .2433 .81644 .23238 Mtetra
.81644 .23238 .82371 .2433 .84105 .23739 .83385 .2264 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62674 Mtetra
.2394 .62674 .24954 .63523 .26469 .63064 .2546 .6221 Mtetra
.2546 .6221 .26469 .63064 .27993 .62602 .2699 .61743 Mtetra
.2699 .61743 .27993 .62602 .29526 .62138 .28528 .61274 Mtetra
.28528 .61274 .29526 .62138 .31068 .61671 .30075 .60801 Mtetra
.30075 .60801 .31068 .61671 .32619 .61201 .31632 .60326 Mtetra
.31632 .60326 .32619 .61201 .34179 .60727 .33197 .59848 Mtetra
.646 .763 .934 r
.33197 .59848 .34179 .60727 .35748 .60251 .34772 .59367 Mtetra
.34772 .59367 .35748 .60251 .37327 .5977 .36357 .58881 Mtetra
.647 .763 .934 r
.36357 .58881 .37327 .5977 .38915 .59285 .37951 .58392 Mtetra
.648 .763 .934 r
.37951 .58392 .38915 .59285 .40513 .58793 .39554 .57897 Mtetra
.649 .764 .933 r
.39554 .57897 .40513 .58793 .4212 .5829 .41168 .57393 Mtetra
.652 .766 .933 r
.41168 .57393 .4212 .5829 .43737 .57769 .42791 .56875 Mtetra
.657 .77 .932 r
.42791 .56875 .43737 .57769 .45364 .57218 .44424 .56335 Mtetra
.667 .776 .931 r
.44424 .56335 .45364 .57218 .47002 .56612 .46068 .55753 Mtetra
.685 .788 .929 r
.46068 .55753 .47002 .56612 .48649 .55906 .47721 .55096 Mtetra
.715 .808 .923 r
.47721 .55096 .48649 .55906 .50305 .55019 .49385 .54304 Mtetra
.765 .84 .909 r
.49385 .54304 .50305 .55019 .51968 .53815 .51057 .53271 Mtetra
.835 .881 .876 r
.51057 .53271 .51968 .53815 .53633 .52095 .52733 .51827 Mtetra
.909 .918 .813 r
.52733 .51827 .53633 .52095 .55289 .49628 .54407 .49747 Mtetra
.959 .933 .72 r
.54407 .49747 .55289 .49628 .56924 .46302 .56066 .46832 Mtetra
.973 .925 .628 r
.56066 .46832 .56924 .46302 .58529 .42346 .57698 .43118 Mtetra
.967 .917 .575 r
.57698 .43118 .58529 .42346 .60108 .38361 .593 .39041 Mtetra
.961 .925 .588 r
.593 .39041 .60108 .38361 .61678 .34963 .60884 .35274 Mtetra
.957 .948 .673 r
.60884 .35274 .61678 .34963 .63257 .32408 .62467 .32277 Mtetra
.926 .949 .787 r
.62467 .32277 .63257 .32408 .64854 .30599 .64066 .30108 Mtetra
.857 .906 .867 r
.64066 .30108 .64854 .30599 .66471 .29313 .65684 .28579 Mtetra
.784 .848 .899 r
.65684 .28579 .66471 .29313 .68106 .28347 .67322 .27465 Mtetra
.732 .803 .908 r
.67322 .27465 .68106 .28347 .69757 .2756 .68976 .26593 Mtetra
.701 .776 .91 r
.68976 .26593 .69757 .2756 .71421 .26872 .70645 .25856 Mtetra
.683 .76 .909 r
.70645 .25856 .71421 .26872 .73098 .26235 .72328 .25189 Mtetra
.674 .751 .909 r
.72328 .25189 .73098 .26235 .74786 .25623 .74022 .24559 Mtetra
.669 .747 .908 r
.74022 .24559 .74786 .25623 .76484 .25024 .75728 .23946 Mtetra
.666 .744 .908 r
.75728 .23946 .76484 .25024 .78194 .24428 .77444 .23341 Mtetra
.665 .743 .908 r
.77444 .23341 .78194 .24428 .79914 .23834 .79171 .22738 Mtetra
.664 .742 .908 r
.79171 .22738 .79914 .23834 .81644 .23238 .80909 .22135 Mtetra
.80909 .22135 .81644 .23238 .83385 .2264 .82657 .21529 Mtetra
.646 .762 .934 r
.18391 .63206 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62674 .22915 .61815 Mtetra
.22915 .61815 .2394 .62674 .2546 .6221 .24441 .61346 Mtetra
.24441 .61346 .2546 .6221 .2699 .61743 .25975 .60874 Mtetra
.25975 .60874 .2699 .61743 .28528 .61274 .27519 .604 Mtetra
.27519 .604 .28528 .61274 .30075 .60801 .29072 .59922 Mtetra
.29072 .59922 .30075 .60801 .31632 .60326 .30634 .59442 Mtetra
.30634 .59442 .31632 .60326 .33197 .59848 .32205 .58959 Mtetra
.646 .763 .934 r
.32205 .58959 .33197 .59848 .34772 .59367 .33786 .58472 Mtetra
.33786 .58472 .34772 .59367 .36357 .58881 .35376 .57982 Mtetra
.35376 .57982 .36357 .58881 .37951 .58392 .36976 .57488 Mtetra
.647 .763 .934 r
.36976 .57488 .37951 .58392 .39554 .57897 .38585 .56989 Mtetra
.648 .764 .933 r
.38585 .56989 .39554 .57897 .41168 .57393 .40205 .56483 Mtetra
.65 .765 .933 r
.40205 .56483 .41168 .57393 .42791 .56875 .41834 .55966 Mtetra
.654 .768 .933 r
.41834 .55966 .42791 .56875 .44424 .56335 .43473 .55431 Mtetra
.661 .773 .932 r
.43473 .55431 .44424 .56335 .46068 .55753 .45123 .54866 Mtetra
.674 .781 .93 r
.45123 .54866 .46068 .55753 .47721 .55096 .46783 .54245 Mtetra
.698 .797 .926 r
.46783 .54245 .47721 .55096 .49385 .54304 .48453 .53522 Mtetra
.738 .823 .917 r
.48453 .53522 .49385 .54304 .51057 .53271 .50133 .52618 Mtetra
.798 .86 .896 r
.50133 .52618 .51057 .53271 .52733 .51827 .5182 .51395 Mtetra
.873 .902 .849 r
.5182 .51395 .52733 .51827 .54407 .49747 .53509 .49651 Mtetra
.938 .929 .769 r
.53509 .49651 .54407 .49747 .56066 .46832 .55189 .47155 Mtetra
.97 .931 .671 r
.55189 .47155 .56066 .46832 .57698 .43118 .56848 .43796 Mtetra
.971 .92 .594 r
.56848 .43796 .57698 .43118 .593 .39041 .58476 .39803 Mtetra
.963 .918 .572 r
.58476 .39803 .593 .39041 .60884 .35274 .60078 .35782 Mtetra
.96 .937 .623 r
.60078 .35782 .60884 .35274 .62467 .32277 .6167 .32352 Mtetra
.947 .954 .731 r
.6167 .32352 .62467 .32277 .64066 .30108 .63271 .2977 Mtetra
.894 .932 .834 r
.63271 .2977 .64066 .30108 .65684 .28579 .6489 .27939 Mtetra
.819 .876 .888 r
.6489 .27939 .65684 .28579 .67322 .27465 .6653 .26634 Mtetra
.755 .823 .905 r
.6653 .26634 .67322 .27465 .68976 .26593 .68188 .25649 Mtetra
.714 .788 .909 r
.68188 .25649 .68976 .26593 .70645 .25856 .69862 .24846 Mtetra
.691 .767 .91 r
.69862 .24846 .70645 .25856 .72328 .25189 .7155 .24141 Mtetra
.678 .755 .909 r
.7155 .24141 .72328 .25189 .74022 .24559 .7325 .23487 Mtetra
.671 .748 .909 r
.7325 .23487 .74022 .24559 .75728 .23946 .74962 .22859 Mtetra
.668 .745 .908 r
.74962 .22859 .75728 .23946 .77444 .23341 .76686 .22242 Mtetra
.666 .743 .908 r
.76686 .22242 .77444 .23341 .79171 .22738 .7842 .2163 Mtetra
.665 .742 .908 r
.7842 .2163 .79171 .22738 .80909 .22135 .80165 .21019 Mtetra
.664 .742 .908 r
.80165 .21019 .80909 .22135 .82657 .21529 .81921 .20406 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63206 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .604 .26499 .59517 Mtetra
.26499 .59517 .27519 .604 .29072 .59922 .28057 .59034 Mtetra
.28057 .59034 .29072 .59922 .30634 .59442 .29625 .58548 Mtetra
.29625 .58548 .30634 .59442 .32205 .58959 .31202 .5806 Mtetra
.31202 .5806 .32205 .58959 .33786 .58472 .32788 .57568 Mtetra
.646 .763 .934 r
.32788 .57568 .33786 .58472 .35376 .57982 .34384 .57073 Mtetra
.34384 .57073 .35376 .57982 .36976 .57488 .3599 .56574 Mtetra
.647 .763 .934 r
.3599 .56574 .36976 .57488 .38585 .56989 .37605 .56071 Mtetra
.648 .763 .934 r
.37605 .56071 .38585 .56989 .40205 .56483 .39231 .55561 Mtetra
.649 .764 .933 r
.39231 .55561 .40205 .56483 .41834 .55966 .40866 .55043 Mtetra
.652 .766 .933 r
.40866 .55043 .41834 .55966 .43473 .55431 .42512 .54511 Mtetra
.657 .77 .932 r
.42512 .54511 .43473 .55431 .45123 .54866 .44168 .53956 Mtetra
.667 .776 .931 r
.44168 .53956 .45123 .54866 .46783 .54245 .45834 .53359 Mtetra
.684 .788 .929 r
.45834 .53359 .46783 .54245 .48453 .53522 .47511 .52687 Mtetra
.715 .808 .923 r
.47511 .52687 .48453 .53522 .50133 .52618 .49198 .51878 Mtetra
.765 .84 .909 r
.49198 .51878 .50133 .52618 .5182 .51395 .50894 .50826 Mtetra
.835 .881 .876 r
.50894 .50826 .5182 .51395 .53509 .49651 .52595 .49361 Mtetra
.909 .919 .813 r
.52595 .49361 .53509 .49651 .55189 .47155 .54293 .47254 Mtetra
.959 .933 .72 r
.54293 .47254 .55189 .47155 .56848 .43796 .55977 .44308 Mtetra
.973 .925 .627 r
.55977 .44308 .56848 .43796 .58476 .39803 .57633 .40557 Mtetra
.967 .917 .574 r
.57633 .40557 .58476 .39803 .60078 .35782 .59258 .36443 Mtetra
.961 .925 .588 r
.59258 .36443 .60078 .35782 .6167 .32352 .60864 .32641 Mtetra
.957 .948 .673 r
.60864 .32641 .6167 .32352 .63271 .2977 .6247 .29615 Mtetra
.926 .949 .788 r
.6247 .29615 .63271 .2977 .6489 .27939 .64091 .27422 Mtetra
.857 .905 .867 r
.64091 .27422 .6489 .27939 .6653 .26634 .65732 .25872 Mtetra
.784 .848 .899 r
.65732 .25872 .6653 .26634 .68188 .25649 .67393 .24739 Mtetra
.732 .803 .908 r
.67393 .24739 .68188 .25649 .69862 .24846 .69071 .23849 Mtetra
.701 .776 .91 r
.69071 .23849 .69862 .24846 .7155 .24141 .70764 .23094 Mtetra
.683 .76 .909 r
.70764 .23094 .7155 .24141 .7325 .23487 .7247 .22411 Mtetra
.674 .751 .909 r
.7247 .22411 .7325 .23487 .74962 .22859 .74189 .21763 Mtetra
.669 .747 .908 r
.74189 .21763 .74962 .22859 .76686 .22242 .75919 .21134 Mtetra
.666 .744 .908 r
.75919 .21134 .76686 .22242 .7842 .2163 .7766 .20512 Mtetra
.665 .743 .908 r
.7766 .20512 .7842 .2163 .80165 .21019 .79413 .19892 Mtetra
.664 .742 .908 r
.79413 .19892 .80165 .21019 .81921 .20406 .81176 .19271 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .59591 Mtetra
.22368 .59591 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59517 .25468 .58623 Mtetra
.25468 .58623 .26499 .59517 .28057 .59034 .27032 .58136 Mtetra
.27032 .58136 .28057 .59034 .29625 .58548 .28605 .57645 Mtetra
.28605 .57645 .29625 .58548 .31202 .5806 .30187 .57151 Mtetra
.30187 .57151 .31202 .5806 .32788 .57568 .3178 .56654 Mtetra
.646 .763 .934 r
.3178 .56654 .32788 .57568 .34384 .57073 .33382 .56153 Mtetra
.33382 .56153 .34384 .57073 .3599 .56574 .34993 .55649 Mtetra
.34993 .55649 .3599 .56574 .37605 .56071 .36615 .55141 Mtetra
.647 .763 .934 r
.36615 .55141 .37605 .56071 .39231 .55561 .38246 .54628 Mtetra
.648 .764 .933 r
.38246 .54628 .39231 .55561 .40866 .55043 .39888 .54107 Mtetra
.65 .765 .933 r
.39888 .54107 .40866 .55043 .42512 .54511 .41539 .53576 Mtetra
.654 .768 .933 r
.41539 .53576 .42512 .54511 .44168 .53956 .43202 .53026 Mtetra
.661 .773 .932 r
.43202 .53026 .44168 .53956 .45834 .53359 .44875 .52445 Mtetra
.674 .781 .93 r
.44875 .52445 .45834 .53359 .47511 .52687 .46558 .51808 Mtetra
.698 .797 .926 r
.46558 .51808 .47511 .52687 .49198 .51878 .48252 .51069 Mtetra
.738 .823 .917 r
.48252 .51069 .49198 .51878 .50894 .50826 .49956 .50147 Mtetra
.798 .86 .896 r
.49956 .50147 .50894 .50826 .52595 .49361 .51667 .48904 Mtetra
.873 .902 .849 r
.51667 .48904 .52595 .49361 .54293 .47254 .53381 .47136 Mtetra
.938 .929 .768 r
.53381 .47136 .54293 .47254 .55977 .44308 .55086 .44611 Mtetra
.97 .931 .671 r
.55086 .44611 .55977 .44308 .57633 .40557 .5677 .41217 Mtetra
.971 .92 .594 r
.5677 .41217 .57633 .40557 .59258 .36443 .58422 .37186 Mtetra
.963 .918 .572 r
.58422 .37186 .59258 .36443 .60864 .32641 .60047 .33129 Mtetra
.96 .937 .623 r
.60047 .33129 .60864 .32641 .6247 .29615 .61662 .29667 Mtetra
.947 .954 .731 r
.61662 .29667 .6247 .29615 .64091 .27422 .63285 .27058 Mtetra
.894 .931 .834 r
.63285 .27058 .64091 .27422 .65732 .25872 .64928 .25204 Mtetra
.819 .876 .888 r
.64928 .25204 .65732 .25872 .67393 .24739 .6659 .23878 Mtetra
.755 .823 .905 r
.6659 .23878 .67393 .24739 .69071 .23849 .68272 .22875 Mtetra
.714 .788 .909 r
.68272 .22875 .69071 .23849 .70764 .23094 .6997 .22054 Mtetra
.691 .767 .909 r
.6997 .22054 .70764 .23094 .7247 .22411 .71682 .21332 Mtetra
.678 .755 .909 r
.71682 .21332 .7247 .22411 .74189 .21763 .73407 .20661 Mtetra
.671 .748 .909 r
.73407 .20661 .74189 .21763 .75919 .21134 .75144 .20015 Mtetra
.668 .745 .908 r
.75144 .20015 .75919 .21134 .7766 .20512 .76893 .19381 Mtetra
.666 .743 .908 r
.76893 .19381 .7766 .20512 .79413 .19892 .78652 .18752 Mtetra
.665 .742 .908 r
.78652 .18752 .79413 .19892 .81176 .19271 .80423 .18123 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .59591 .21314 .58698 Mtetra
.21314 .58698 .22368 .59591 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58623 .24425 .57721 Mtetra
.24425 .57721 .25468 .58623 .27032 .58136 .25994 .57227 Mtetra
.25994 .57227 .27032 .58136 .28605 .57645 .27573 .56731 Mtetra
.27573 .56731 .28605 .57645 .30187 .57151 .29162 .56231 Mtetra
.29162 .56231 .30187 .57151 .3178 .56654 .3076 .55729 Mtetra
.3076 .55729 .3178 .56654 .33382 .56153 .32367 .55223 Mtetra
.646 .763 .934 r
.32367 .55223 .33382 .56153 .34993 .55649 .33985 .54714 Mtetra
.33985 .54714 .34993 .55649 .36615 .55141 .35613 .54201 Mtetra
.647 .763 .934 r
.35613 .54201 .36615 .55141 .38246 .54628 .3725 .53683 Mtetra
.648 .763 .934 r
.3725 .53683 .38246 .54628 .39888 .54107 .38898 .53158 Mtetra
.649 .764 .933 r
.38898 .53158 .39888 .54107 .41539 .53576 .40556 .52625 Mtetra
.652 .766 .933 r
.40556 .52625 .41539 .53576 .43202 .53026 .42225 .52078 Mtetra
.657 .77 .932 r
.42225 .52078 .43202 .53026 .44875 .52445 .43904 .51508 Mtetra
.667 .776 .931 r
.43904 .51508 .44875 .52445 .46558 .51808 .45594 .50895 Mtetra
.684 .788 .929 r
.45594 .50895 .46558 .51808 .48252 .51069 .47295 .50206 Mtetra
.715 .808 .923 r
.47295 .50206 .48252 .51069 .49956 .50147 .49006 .4938 Mtetra
.765 .84 .909 r
.49006 .4938 .49956 .50147 .51667 .48904 .50727 .48309 Mtetra
.835 .882 .876 r
.50727 .48309 .51667 .48904 .53381 .47136 .52453 .46821 Mtetra
.909 .919 .813 r
.52453 .46821 .53381 .47136 .55086 .44611 .54176 .44688 Mtetra
.959 .933 .719 r
.54176 .44688 .55086 .44611 .5677 .41217 .55885 .4171 Mtetra
.973 .926 .627 r
.55885 .4171 .5677 .41217 .58422 .37186 .57566 .37922 Mtetra
.967 .917 .574 r
.57566 .37922 .58422 .37186 .60047 .33129 .59215 .33771 Mtetra
.961 .926 .589 r
.59215 .33771 .60047 .33129 .61662 .29667 .60844 .29933 Mtetra
.957 .948 .674 r
.60844 .29933 .61662 .29667 .63285 .27058 .62473 .26877 Mtetra
.926 .949 .788 r
.62473 .26877 .63285 .27058 .64928 .25204 .64117 .24659 Mtetra
.857 .905 .867 r
.64117 .24659 .64928 .25204 .6659 .23878 .65781 .23088 Mtetra
.784 .848 .899 r
.65781 .23088 .6659 .23878 .68272 .22875 .67466 .21935 Mtetra
.732 .803 .908 r
.67466 .21935 .68272 .22875 .6997 .22054 .69168 .21027 Mtetra
.701 .776 .91 r
.69168 .21027 .6997 .22054 .71682 .21332 .70885 .20254 Mtetra
.683 .76 .909 r
.70885 .20254 .71682 .21332 .73407 .20661 .72617 .19553 Mtetra
.674 .751 .909 r
.72617 .19553 .73407 .20661 .75144 .20015 .7436 .18888 Mtetra
.669 .747 .908 r
.7436 .18888 .75144 .20015 .76893 .19381 .76116 .1824 Mtetra
.666 .744 .908 r
.76116 .1824 .76893 .19381 .78652 .18752 .77883 .17601 Mtetra
.665 .743 .908 r
.77883 .17601 .78652 .18752 .80423 .18123 .79662 .16963 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .57721 .23371 .56808 Mtetra
.23371 .56808 .24425 .57721 .25994 .57227 .24946 .56309 Mtetra
.24946 .56309 .25994 .57227 .27573 .56731 .2653 .55807 Mtetra
.2653 .55807 .27573 .56731 .29162 .56231 .28124 .55302 Mtetra
.28124 .55302 .29162 .56231 .3076 .55729 .29728 .54794 Mtetra
.29728 .54794 .3076 .55729 .32367 .55223 .31342 .54282 Mtetra
.646 .763 .934 r
.31342 .54282 .32367 .55223 .33985 .54714 .32966 .53767 Mtetra
.32966 .53767 .33985 .54714 .35613 .54201 .34599 .53249 Mtetra
.34599 .53249 .35613 .54201 .3725 .53683 .36243 .52726 Mtetra
.647 .763 .934 r
.36243 .52726 .3725 .53683 .38898 .53158 .37897 .52198 Mtetra
.648 .764 .933 r
.37897 .52198 .38898 .53158 .40556 .52625 .39561 .51662 Mtetra
.65 .765 .933 r
.39561 .51662 .40556 .52625 .42225 .52078 .41236 .51115 Mtetra
.654 .768 .933 r
.41236 .51115 .42225 .52078 .43904 .51508 .42922 .5055 Mtetra
.661 .773 .932 r
.42922 .5055 .43904 .51508 .45594 .50895 .44619 .49953 Mtetra
.674 .781 .93 r
.44619 .49953 .45594 .50895 .47295 .50206 .46326 .493 Mtetra
.698 .797 .926 r
.46326 .493 .47295 .50206 .49006 .4938 .48045 .48544 Mtetra
.738 .823 .917 r
.48045 .48544 .49006 .4938 .50727 .48309 .49774 .47603 Mtetra
.798 .86 .896 r
.49774 .47603 .50727 .48309 .52453 .46821 .5151 .46338 Mtetra
.873 .902 .849 r
.5151 .46338 .52453 .46821 .54176 .44688 .53249 .44546 Mtetra
.938 .93 .768 r
.53249 .44546 .54176 .44688 .55885 .4171 .5498 .41992 Mtetra
.97 .931 .67 r
.5498 .41992 .55885 .4171 .57566 .37922 .56689 .38562 Mtetra
.971 .92 .594 r
.56689 .38562 .57566 .37922 .59215 .33771 .58366 .34494 Mtetra
.963 .918 .572 r
.58366 .34494 .59215 .33771 .60844 .29933 .60015 .30399 Mtetra
.961 .937 .624 r
.60015 .30399 .60844 .29933 .62473 .26877 .61653 .26904 Mtetra
.947 .954 .732 r
.61653 .26904 .62473 .26877 .64117 .24659 .633 .24268 Mtetra
.894 .931 .834 r
.633 .24268 .64117 .24659 .65781 .23088 .64966 .22391 Mtetra
.819 .876 .887 r
.64966 .22391 .65781 .23088 .67466 .21935 .66652 .21044 Mtetra
.755 .823 .905 r
.66652 .21044 .67466 .21935 .69168 .21027 .68358 .20022 Mtetra
.714 .788 .909 r
.68358 .20022 .69168 .21027 .70885 .20254 .70081 .19182 Mtetra
.691 .767 .909 r
.70081 .19182 .70885 .20254 .72617 .19553 .71818 .18442 Mtetra
.678 .755 .909 r
.71818 .18442 .72617 .19553 .7436 .18888 .73568 .17753 Mtetra
.671 .748 .909 r
.73568 .17753 .7436 .18888 .76116 .1824 .75331 .17089 Mtetra
.668 .745 .908 r
.75331 .17089 .76116 .1824 .77883 .17601 .77105 .16437 Mtetra
.666 .743 .908 r
.77105 .16437 .77883 .17601 .79662 .16963 .78892 .1579 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56808 .22305 .55884 Mtetra
.22305 .55884 .23371 .56808 .24946 .56309 .23885 .5538 Mtetra
.23885 .5538 .24946 .56309 .2653 .55807 .25476 .54872 Mtetra
.25476 .54872 .2653 .55807 .28124 .55302 .27075 .54362 Mtetra
.27075 .54362 .28124 .55302 .29728 .54794 .28685 .53848 Mtetra
.28685 .53848 .29728 .54794 .31342 .54282 .30305 .53331 Mtetra
.30305 .53331 .31342 .54282 .32966 .53767 .31934 .5281 Mtetra
.646 .763 .934 r
.31934 .5281 .32966 .53767 .34599 .53249 .33574 .52286 Mtetra
.33574 .52286 .34599 .53249 .36243 .52726 .35224 .51758 Mtetra
.647 .763 .934 r
.35224 .51758 .36243 .52726 .37897 .52198 .36885 .51225 Mtetra
.648 .763 .934 r
.36885 .51225 .37897 .52198 .39561 .51662 .38555 .50685 Mtetra
.649 .764 .933 r
.38555 .50685 .39561 .51662 .41236 .51115 .40237 .50137 Mtetra
.652 .766 .933 r
.40237 .50137 .41236 .51115 .42922 .5055 .41929 .49574 Mtetra
.657 .77 .932 r
.41929 .49574 .42922 .5055 .44619 .49953 .43632 .48987 Mtetra
.667 .776 .931 r
.43632 .48987 .44619 .49953 .46326 .493 .45347 .48358 Mtetra
.684 .788 .929 r
.45347 .48358 .46326 .493 .48045 .48544 .47072 .47652 Mtetra
.715 .808 .923 r
.47072 .47652 .48045 .48544 .49774 .47603 .48809 .46808 Mtetra
.765 .84 .909 r
.48809 .46808 .49774 .47603 .5151 .46338 .50555 .45716 Mtetra
.835 .882 .877 r
.50555 .45716 .5151 .46338 .53249 .44546 .52306 .44206 Mtetra
.909 .919 .813 r
.52306 .44206 .53249 .44546 .5498 .41992 .54056 .42045 Mtetra
.959 .934 .719 r
.54056 .42045 .5498 .41992 .56689 .38562 .5579 .39034 Mtetra
.973 .926 .627 r
.5579 .39034 .56689 .38562 .58366 .34494 .57497 .3521 Mtetra
.967 .917 .574 r
.57497 .3521 .58366 .34494 .60015 .30399 .59171 .3102 Mtetra
.961 .926 .589 r
.59171 .3102 .60015 .30399 .61653 .26904 .60824 .27147 Mtetra
.957 .948 .674 r
.60824 .27147 .61653 .26904 .633 .24268 .62476 .2406 Mtetra
.926 .948 .788 r
.62476 .2406 .633 .24268 .64966 .22391 .64144 .21817 Mtetra
.857 .905 .867 r
.64144 .21817 .64966 .22391 .66652 .21044 .65832 .20223 Mtetra
.784 .848 .899 r
.65832 .20223 .66652 .21044 .68358 .20022 .67541 .1905 Mtetra
.732 .803 .908 r
.67541 .1905 .68358 .20022 .70081 .19182 .69268 .18123 Mtetra
.701 .776 .91 r
.69268 .18123 .70081 .19182 .71818 .18442 .7101 .17331 Mtetra
.684 .76 .909 r
.7101 .17331 .71818 .18442 .73568 .17753 .72767 .16612 Mtetra
.674 .751 .909 r
.72767 .16612 .73568 .17753 .75331 .17089 .74537 .15928 Mtetra
.669 .747 .908 r
.74537 .15928 .75331 .17089 .77105 .16437 .76319 .15263 Mtetra
.666 .744 .908 r
.76319 .15263 .77105 .16437 .78892 .1579 .78113 .14604 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .5538 .22813 .54441 Mtetra
.22813 .54441 .23885 .5538 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27075 .54362 .26015 .53411 Mtetra
.26015 .53411 .27075 .54362 .28685 .53848 .2763 .52891 Mtetra
.2763 .52891 .28685 .53848 .30305 .53331 .29256 .52368 Mtetra
.29256 .52368 .30305 .53331 .31934 .5281 .30891 .51842 Mtetra
.646 .763 .934 r
.30891 .51842 .31934 .5281 .33574 .52286 .32537 .51312 Mtetra
.32537 .51312 .33574 .52286 .35224 .51758 .34194 .50778 Mtetra
.34194 .50778 .35224 .51758 .36885 .51225 .3586 .5024 Mtetra
.647 .763 .934 r
.3586 .5024 .36885 .51225 .38555 .50685 .37538 .49696 Mtetra
.648 .764 .933 r
.37538 .49696 .38555 .50685 .40237 .50137 .39226 .49144 Mtetra
.65 .765 .933 r
.39226 .49144 .40237 .50137 .41929 .49574 .40924 .48581 Mtetra
.654 .768 .933 r
.40924 .48581 .41929 .49574 .43632 .48987 .42634 .48 Mtetra
.661 .773 .932 r
.42634 .48 .43632 .48987 .45347 .48358 .44355 .47387 Mtetra
.674 .781 .93 r
.44355 .47387 .45347 .48358 .47072 .47652 .46088 .46717 Mtetra
.698 .797 .926 r
.46088 .46717 .47072 .47652 .48809 .46808 .47832 .45942 Mtetra
.738 .823 .917 r
.47832 .45942 .48809 .46808 .50555 .45716 .49586 .44982 Mtetra
.798 .86 .896 r
.49586 .44982 .50555 .45716 .52306 .44206 .51348 .43696 Mtetra
.873 .902 .849 r
.51348 .43696 .52306 .44206 .54056 .42045 .53114 .41878 Mtetra
.939 .93 .768 r
.53114 .41878 .54056 .42045 .5579 .39034 .54871 .39293 Mtetra
.97 .931 .67 r
.54871 .39293 .5579 .39034 .57497 .3521 .56606 .35829 Mtetra
.971 .92 .593 r
.56606 .35829 .57497 .3521 .59171 .3102 .58308 .31722 Mtetra
.963 .918 .572 r
.58308 .31722 .59171 .3102 .60824 .27147 .59982 .27589 Mtetra
.961 .937 .624 r
.59982 .27589 .60824 .27147 .62476 .2406 .61645 .24061 Mtetra
.947 .954 .732 r
.61645 .24061 .62476 .2406 .64144 .21817 .63315 .21396 Mtetra
.894 .931 .834 r
.63315 .21396 .64144 .21817 .65832 .20223 .65005 .19496 Mtetra
.819 .876 .887 r
.65005 .19496 .65832 .20223 .67541 .1905 .66716 .18128 Mtetra
.755 .823 .905 r
.66716 .18128 .67541 .1905 .69268 .18123 .68447 .17085 Mtetra
.714 .788 .909 r
.68447 .17085 .69268 .18123 .7101 .17331 .70195 .16227 Mtetra
.691 .766 .909 r
.70195 .16227 .7101 .17331 .72767 .16612 .71958 .15467 Mtetra
.678 .755 .909 r
.71958 .15467 .72767 .16612 .74537 .15928 .73734 .14759 Mtetra
.671 .748 .909 r
.73734 .14759 .74537 .15928 .76319 .15263 .75523 .14077 Mtetra
.668 .745 .908 r
.75523 .14077 .76319 .15263 .78113 .14604 .77325 .13406 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54007 Mtetra
.20137 .54007 .21227 .54951 .22813 .54441 .21728 .53491 Mtetra
.21728 .53491 .22813 .54441 .24409 .53927 .2333 .52972 Mtetra
.2333 .52972 .24409 .53927 .26015 .53411 .24942 .52449 Mtetra
.24942 .52449 .26015 .53411 .2763 .52891 .26563 .51924 Mtetra
.26563 .51924 .2763 .52891 .29256 .52368 .28195 .51395 Mtetra
.28195 .51395 .29256 .52368 .30891 .51842 .29837 .50862 Mtetra
.29837 .50862 .30891 .51842 .32537 .51312 .31489 .50326 Mtetra
.646 .763 .934 r
.31489 .50326 .32537 .51312 .34194 .50778 .33151 .49787 Mtetra
.33151 .49787 .34194 .50778 .3586 .5024 .34824 .49243 Mtetra
.647 .763 .934 r
.34824 .49243 .3586 .5024 .37538 .49696 .36508 .48694 Mtetra
.648 .763 .934 r
.36508 .48694 .37538 .49696 .39226 .49144 .38202 .48138 Mtetra
.649 .764 .933 r
.38202 .48138 .39226 .49144 .40924 .48581 .39908 .47573 Mtetra
.652 .766 .933 r
.39908 .47573 .40924 .48581 .42634 .48 .41624 .46994 Mtetra
.657 .77 .932 r
.41624 .46994 .42634 .48 .44355 .47387 .43352 .46391 Mtetra
.667 .776 .931 r
.43352 .46391 .44355 .47387 .46088 .46717 .45092 .45745 Mtetra
.684 .788 .929 r
.45092 .45745 .46088 .46717 .47832 .45942 .46843 .45021 Mtetra
.715 .809 .923 r
.46843 .45021 .47832 .45942 .49586 .44982 .48605 .44158 Mtetra
.765 .84 .909 r
.48605 .44158 .49586 .44982 .51348 .43696 .50377 .43045 Mtetra
.835 .882 .877 r
.50377 .43045 .51348 .43696 .53114 .41878 .52155 .41511 Mtetra
.909 .919 .813 r
.52155 .41511 .53114 .41878 .54871 .39293 .53931 .39323 Mtetra
.959 .934 .719 r
.53931 .39323 .54871 .39293 .56606 .35829 .55693 .36278 Mtetra
.973 .926 .626 r
.55693 .36278 .56606 .35829 .58308 .31722 .57425 .32416 Mtetra
.967 .917 .574 r
.57425 .32416 .58308 .31722 .59982 .27589 .59125 .28187 Mtetra
.962 .926 .589 r
.59125 .28187 .59982 .27589 .61645 .24061 .60803 .24278 Mtetra
.957 .948 .674 r
.60803 .24278 .61645 .24061 .63315 .21396 .6248 .21161 Mtetra
.926 .948 .788 r
.6248 .21161 .63315 .21396 .65005 .19496 .64172 .18891 Mtetra
.857 .905 .867 r
.64172 .18891 .65005 .19496 .66716 .18128 .65885 .17275 Mtetra
.784 .848 .899 r
.65885 .17275 .66716 .18128 .68447 .17085 .67618 .16081 Mtetra
.732 .803 .908 r
.67618 .16081 .68447 .17085 .70195 .16227 .69371 .15134 Mtetra
.701 .776 .91 r
.69371 .15134 .70195 .16227 .71958 .15467 .71139 .14323 Mtetra
.684 .76 .909 r
.71139 .14323 .71958 .15467 .73734 .14759 .72922 .13584 Mtetra
.674 .751 .909 r
.72922 .13584 .73734 .14759 .75523 .14077 .74719 .12881 Mtetra
.669 .747 .908 r
.74719 .12881 .75523 .14077 .77325 .13406 .76528 .12196 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54007 .19034 .53052 Mtetra
.19034 .53052 .20137 .54007 .21728 .53491 .20631 .5253 Mtetra
.20631 .5253 .21728 .53491 .2333 .52972 .22239 .52005 Mtetra
.22239 .52005 .2333 .52972 .24942 .52449 .23856 .51476 Mtetra
.23856 .51476 .24942 .52449 .26563 .51924 .25484 .50945 Mtetra
.25484 .50945 .26563 .51924 .28195 .51395 .27121 .5041 Mtetra
.27121 .5041 .28195 .51395 .29837 .50862 .28769 .49871 Mtetra
.28769 .49871 .29837 .50862 .31489 .50326 .30428 .49329 Mtetra
.646 .763 .934 r
.30428 .49329 .31489 .50326 .33151 .49787 .32097 .48783 Mtetra
.32097 .48783 .33151 .49787 .34824 .49243 .33776 .48234 Mtetra
.33776 .48234 .34824 .49243 .36508 .48694 .35466 .47679 Mtetra
.647 .763 .934 r
.35466 .47679 .36508 .48694 .38202 .48138 .37167 .47119 Mtetra
.648 .764 .933 r
.37167 .47119 .38202 .48138 .39908 .47573 .3888 .46551 Mtetra
.65 .765 .933 r
.3888 .46551 .39908 .47573 .41624 .46994 .40603 .45971 Mtetra
.654 .768 .933 r
.40603 .45971 .41624 .46994 .43352 .46391 .42338 .45373 Mtetra
.661 .773 .932 r
.42338 .45373 .43352 .46391 .45092 .45745 .44084 .44743 Mtetra
.674 .781 .93 r
.44084 .44743 .45092 .45745 .46843 .45021 .45842 .44054 Mtetra
.698 .797 .926 r
.45842 .44054 .46843 .45021 .48605 .44158 .47612 .43262 Mtetra
.738 .823 .917 r
.47612 .43262 .48605 .44158 .50377 .43045 .49392 .42281 Mtetra
.798 .861 .896 r
.49392 .42281 .50377 .43045 .52155 .41511 .51182 .40973 Mtetra
.873 .903 .849 r
.51182 .40973 .52155 .41511 .53931 .39323 .52974 .39129 Mtetra
.939 .93 .768 r
.52974 .39129 .53931 .39323 .55693 .36278 .54758 .36513 Mtetra
.97 .931 .67 r
.54758 .36513 .55693 .36278 .57425 .32416 .5652 .33012 Mtetra
.971 .92 .593 r
.5652 .33012 .57425 .32416 .59125 .28187 .58249 .28866 Mtetra
.963 .918 .572 r
.58249 .28866 .59125 .28187 .60803 .24278 .59948 .24696 Mtetra
.961 .937 .624 r
.59948 .24696 .60803 .24278 .6248 .21161 .61635 .21134 Mtetra
.947 .954 .732 r
.61635 .21134 .6248 .21161 .64172 .18891 .63331 .18441 Mtetra
.894 .931 .834 r
.63331 .18441 .64172 .18891 .65885 .17275 .65046 .16515 Mtetra
.819 .876 .887 r
.65046 .16515 .65885 .17275 .67618 .16081 .66782 .15125 Mtetra
.755 .823 .905 r
.66782 .15125 .67618 .16081 .69371 .15134 .68538 .14062 Mtetra
.714 .787 .909 r
.68538 .14062 .69371 .15134 .71139 .14323 .70312 .13183 Mtetra
.691 .766 .909 r
.70312 .13183 .71139 .14323 .72922 .13584 .72102 .12404 Mtetra
.678 .755 .909 r
.72102 .12404 .72922 .13584 .74719 .12881 .73905 .11677 Mtetra
.671 .748 .909 r
.73905 .11677 .74719 .12881 .76528 .12196 .75721 .10975 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52005 .21135 .51027 Mtetra
.21135 .51027 .22239 .52005 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50945 .24392 .49955 Mtetra
.24392 .49955 .25484 .50945 .27121 .5041 .26036 .49413 Mtetra
.26036 .49413 .27121 .5041 .28769 .49871 .2769 .48869 Mtetra
.2769 .48869 .28769 .49871 .30428 .49329 .29354 .4832 Mtetra
.29354 .4832 .30428 .49329 .32097 .48783 .3103 .47768 Mtetra
.646 .763 .934 r
.3103 .47768 .32097 .48783 .33776 .48234 .32716 .47212 Mtetra
.32716 .47212 .33776 .48234 .35466 .47679 .34412 .46652 Mtetra
.647 .763 .934 r
.34412 .46652 .35466 .47679 .37167 .47119 .3612 .46086 Mtetra
.648 .763 .934 r
.3612 .46086 .37167 .47119 .3888 .46551 .37839 .45514 Mtetra
.649 .764 .933 r
.37839 .45514 .3888 .46551 .40603 .45971 .39569 .44933 Mtetra
.652 .766 .933 r
.39569 .44933 .40603 .45971 .42338 .45373 .41311 .44336 Mtetra
.657 .77 .932 r
.41311 .44336 .42338 .45373 .44084 .44743 .43064 .43715 Mtetra
.667 .776 .931 r
.43064 .43715 .44084 .44743 .45842 .44054 .44829 .43051 Mtetra
.684 .788 .929 r
.44829 .43051 .45842 .44054 .47612 .43262 .46606 .42309 Mtetra
.715 .809 .923 r
.46606 .42309 .47612 .43262 .49392 .42281 .48395 .41426 Mtetra
.765 .841 .909 r
.48395 .41426 .49392 .42281 .51182 .40973 .50194 .40292 Mtetra
.835 .882 .877 r
.50194 .40292 .51182 .40973 .52974 .39129 .52 .38733 Mtetra
.909 .92 .813 r
.52 .38733 .52974 .39129 .54758 .36513 .53803 .36516 Mtetra
.959 .934 .719 r
.53803 .36516 .54758 .36513 .5652 .33012 .55592 .33438 Mtetra
.973 .926 .626 r
.55592 .33438 .5652 .33012 .58249 .28866 .57352 .29537 Mtetra
.967 .917 .574 r
.57352 .29537 .58249 .28866 .59948 .24696 .59078 .25269 Mtetra
.962 .926 .589 r
.59078 .25269 .59948 .24696 .61635 .21134 .60781 .21324 Mtetra
.958 .948 .675 r
.60781 .21324 .61635 .21134 .63331 .18441 .62483 .18175 Mtetra
.926 .948 .788 r
.62483 .18175 .63331 .18441 .65046 .16515 .642 .15878 Mtetra
.857 .905 .867 r
.642 .15878 .65046 .16515 .66782 .15125 .65938 .14239 Mtetra
.784 .847 .899 r
.65938 .14239 .66782 .15125 .68538 .14062 .67698 .13023 Mtetra
.732 .803 .908 r
.67698 .13023 .68538 .14062 .70312 .13183 .69477 .12055 Mtetra
.701 .775 .909 r
.69477 .12055 .70312 .13183 .72102 .12404 .71272 .11224 Mtetra
.684 .76 .909 r
.71272 .11224 .72102 .12404 .73905 .11677 .73082 .10465 Mtetra
.674 .751 .909 r
.73082 .10465 .73905 .11677 .75721 .10975 .74906 .09743 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50038 Mtetra
.20018 .50038 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49955 .23287 .48953 Mtetra
.23287 .48953 .24392 .49955 .26036 .49413 .24937 .48405 Mtetra
.24937 .48405 .26036 .49413 .2769 .48869 .26597 .47854 Mtetra
.26597 .47854 .2769 .48869 .29354 .4832 .28268 .47299 Mtetra
.28268 .47299 .29354 .4832 .3103 .47768 .2995 .46741 Mtetra
.646 .763 .934 r
.2995 .46741 .3103 .47768 .32716 .47212 .31643 .46179 Mtetra
.31643 .46179 .32716 .47212 .34412 .46652 .33346 .45612 Mtetra
.33346 .45612 .34412 .46652 .3612 .46086 .3506 .45041 Mtetra
.647 .763 .934 r
.3506 .45041 .3612 .46086 .37839 .45514 .36786 .44464 Mtetra
.648 .764 .933 r
.36786 .44464 .37839 .45514 .39569 .44933 .38523 .43879 Mtetra
.65 .765 .933 r
.38523 .43879 .39569 .44933 .41311 .44336 .40272 .43282 Mtetra
.654 .768 .933 r
.40272 .43282 .41311 .44336 .43064 .43715 .42032 .42666 Mtetra
.661 .773 .932 r
.42032 .42666 .43064 .43715 .44829 .43051 .43804 .42017 Mtetra
.674 .781 .93 r
.43804 .42017 .44829 .43051 .46606 .42309 .45588 .4131 Mtetra
.698 .797 .926 r
.45588 .4131 .46606 .42309 .48395 .41426 .47385 .40498 Mtetra
.738 .823 .918 r
.47385 .40498 .48395 .41426 .50194 .40292 .49193 .39496 Mtetra
.798 .861 .896 r
.49193 .39496 .50194 .40292 .52 .38733 .5101 .38165 Mtetra
.873 .903 .849 r
.5101 .38165 .52 .38733 .53803 .36516 .5283 .36294 Mtetra
.939 .93 .768 r
.5283 .36294 .53803 .36516 .55592 .33438 .54642 .33647 Mtetra
.97 .931 .669 r
.54642 .33647 .55592 .33438 .57352 .29537 .56432 .30109 Mtetra
.971 .92 .593 r
.56432 .30109 .57352 .29537 .59078 .25269 .58188 .25923 Mtetra
.963 .918 .573 r
.58188 .25923 .59078 .25269 .60781 .21324 .59913 .21715 Mtetra
.961 .937 .625 r
.59913 .21715 .60781 .21324 .62483 .18175 .61626 .18119 Mtetra
.947 .953 .732 r
.61626 .18119 .62483 .18175 .642 .15878 .63347 .15396 Mtetra
.894 .93 .834 r
.63347 .15396 .642 .15878 .65938 .14239 .65087 .13446 Mtetra
.819 .875 .887 r
.65087 .13446 .65938 .14239 .67698 .13023 .6685 .12033 Mtetra
.755 .823 .905 r
.6685 .12033 .67698 .13023 .69477 .12055 .68633 .10948 Mtetra
.714 .787 .909 r
.68633 .10948 .69477 .12055 .71272 .11224 .70433 .10049 Mtetra
.691 .766 .909 r
.70433 .10049 .71272 .11224 .73082 .10465 .7225 .09249 Mtetra
.678 .755 .909 r
.7225 .09249 .73082 .10465 .74906 .09743 .74081 .08501 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50038 .18889 .49037 Mtetra
.18889 .49037 .20018 .50038 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48953 .2217 .47939 Mtetra
.2217 .47939 .23287 .48953 .24937 .48405 .23826 .47385 Mtetra
.23826 .47385 .24937 .48405 .26597 .47854 .25492 .46828 Mtetra
.25492 .46828 .26597 .47854 .28268 .47299 .2717 .46267 Mtetra
.2717 .46267 .28268 .47299 .2995 .46741 .28858 .45702 Mtetra
.28858 .45702 .2995 .46741 .31643 .46179 .30557 .45133 Mtetra
.646 .763 .934 r
.30557 .45133 .31643 .46179 .33346 .45612 .32267 .4456 Mtetra
.32267 .4456 .33346 .45612 .3506 .45041 .33988 .43982 Mtetra
.647 .763 .934 r
.33988 .43982 .3506 .45041 .36786 .44464 .3572 .434 Mtetra
.648 .763 .934 r
.3572 .434 .36786 .44464 .38523 .43879 .37464 .4281 Mtetra
.649 .764 .933 r
.37464 .4281 .38523 .43879 .40272 .43282 .3922 .4221 Mtetra
.652 .766 .933 r
.3922 .4221 .40272 .43282 .42032 .42666 .40987 .41596 Mtetra
.657 .77 .932 r
.40987 .41596 .42032 .42666 .43804 .42017 .42767 .40957 Mtetra
.667 .776 .931 r
.42767 .40957 .43804 .42017 .45588 .4131 .44558 .40274 Mtetra
.684 .788 .929 r
.44558 .40274 .45588 .4131 .47385 .40498 .46362 .39512 Mtetra
.715 .809 .923 r
.46362 .39512 .47385 .40498 .49193 .39496 .48178 .38609 Mtetra
.765 .841 .909 r
.48178 .38609 .49193 .39496 .5101 .38165 .50005 .37453 Mtetra
.835 .882 .877 r
.50005 .37453 .5101 .38165 .5283 .36294 .51839 .35869 Mtetra
.909 .92 .813 r
.51839 .35869 .5283 .36294 .54642 .33647 .53671 .33622 Mtetra
.959 .934 .719 r
.53671 .33622 .54642 .33647 .56432 .30109 .55489 .30509 Mtetra
.973 .926 .626 r
.55489 .30509 .56432 .30109 .58188 .25923 .57276 .26569 Mtetra
.967 .917 .574 r
.57276 .26569 .58188 .25923 .59913 .21715 .59029 .22261 Mtetra
.962 .926 .59 r
.59029 .22261 .59913 .21715 .61626 .18119 .60758 .1828 Mtetra
.958 .948 .675 r
.60758 .1828 .61626 .18119 .63347 .15396 .62486 .15099 Mtetra
.926 .948 .788 r
.62486 .15099 .63347 .15396 .65087 .13446 .64229 .12775 Mtetra
.857 .904 .867 r
.64229 .12775 .65087 .13446 .6685 .12033 .65994 .11111 Mtetra
.784 .847 .899 r
.65994 .11111 .6685 .12033 .68633 .10948 .6778 .09873 Mtetra
.732 .803 .908 r
.6778 .09873 .68633 .10948 .70433 .10049 .69586 .08884 Mtetra
.701 .775 .909 r
.69586 .08884 .70433 .10049 .7225 .09249 .71409 .08032 Mtetra
.684 .76 .909 r
.71409 .08032 .7225 .09249 .74081 .08501 .73247 .07252 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47385 .22701 .46353 Mtetra
.22701 .46353 .23826 .47385 .25492 .46828 .24374 .45789 Mtetra
.24374 .45789 .25492 .46828 .2717 .46267 .26058 .45221 Mtetra
.26058 .45221 .2717 .46267 .28858 .45702 .27752 .4465 Mtetra
.27752 .4465 .28858 .45702 .30557 .45133 .29458 .44074 Mtetra
.646 .763 .934 r
.29458 .44074 .30557 .45133 .32267 .4456 .31175 .43495 Mtetra
.31175 .43495 .32267 .4456 .33988 .43982 .32903 .42911 Mtetra
.32903 .42911 .33988 .43982 .3572 .434 .34642 .42322 Mtetra
.647 .763 .934 r
.34642 .42322 .3572 .434 .37464 .4281 .36393 .41727 Mtetra
.648 .764 .933 r
.36393 .41727 .37464 .4281 .3922 .4221 .38155 .41123 Mtetra
.65 .765 .933 r
.38155 .41123 .3922 .4221 .40987 .41596 .3993 .40508 Mtetra
.654 .768 .933 r
.3993 .40508 .40987 .41596 .42767 .40957 .41717 .39874 Mtetra
.661 .773 .932 r
.41717 .39874 .42767 .40957 .44558 .40274 .43516 .39206 Mtetra
.674 .781 .93 r
.43516 .39206 .44558 .40274 .46362 .39512 .45327 .3848 Mtetra
.698 .797 .927 r
.45327 .3848 .46362 .39512 .48178 .38609 .47151 .37647 Mtetra
.738 .823 .918 r
.47151 .37647 .48178 .38609 .50005 .37453 .48987 .36624 Mtetra
.798 .861 .896 r
.48987 .36624 .50005 .37453 .51839 .35869 .50832 .35268 Mtetra
.873 .903 .849 r
.50832 .35268 .51839 .35869 .53671 .33622 .52681 .3337 Mtetra
.939 .931 .768 r
.52681 .3337 .53671 .33622 .55489 .30509 .54523 .3069 Mtetra
.97 .932 .669 r
.54523 .3069 .55489 .30509 .57276 .26569 .56341 .27115 Mtetra
.971 .92 .593 r
.56341 .27115 .57276 .26569 .59029 .22261 .58125 .22889 Mtetra
.963 .918 .573 r
.58125 .22889 .59029 .22261 .60758 .1828 .59877 .18642 Mtetra
.961 .937 .625 r
.59877 .18642 .60758 .1828 .62486 .15099 .61617 .15012 Mtetra
.947 .953 .733 r
.61617 .15012 .62486 .15099 .64229 .12775 .63364 .12259 Mtetra
.894 .93 .834 r
.63364 .12259 .64229 .12775 .65994 .11111 .6513 .10283 Mtetra
.819 .875 .887 r
.6513 .10283 .65994 .11111 .6778 .09873 .6692 .08846 Mtetra
.755 .823 .905 r
.6692 .08846 .6778 .09873 .69586 .08884 .6873 .07739 Mtetra
.714 .787 .909 r
.6873 .07739 .69586 .08884 .71409 .08032 .70558 .06818 Mtetra
.691 .766 .909 r
.70558 .06818 .71409 .08032 .73247 .07252 .72403 .05997 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45789 .23242 .44738 Mtetra
.23242 .44738 .24374 .45789 .26058 .45221 .24932 .44163 Mtetra
.24932 .44163 .26058 .45221 .27752 .4465 .26633 .43585 Mtetra
.26633 .43585 .27752 .4465 .29458 .44074 .28346 .43003 Mtetra
.28346 .43003 .29458 .44074 .31175 .43495 .30069 .42416 Mtetra
.646 .763 .934 r
.30069 .42416 .31175 .43495 .32903 .42911 .31804 .41826 Mtetra
.31804 .41826 .32903 .42911 .34642 .42322 .3355 .4123 Mtetra
.647 .763 .934 r
.3355 .4123 .34642 .42322 .36393 .41727 .35308 .40629 Mtetra
.648 .763 .934 r
.35308 .40629 .36393 .41727 .38155 .41123 .37078 .40021 Mtetra
.649 .764 .933 r
.37078 .40021 .38155 .41123 .3993 .40508 .3886 .39403 Mtetra
.652 .766 .933 r
.3886 .39403 .3993 .40508 .41717 .39874 .40654 .3877 Mtetra
.657 .77 .933 r
.40654 .3877 .41717 .39874 .43516 .39206 .4246 .38112 Mtetra
.667 .776 .931 r
.4246 .38112 .43516 .39206 .45327 .3848 .44279 .37409 Mtetra
.684 .788 .929 r
.44279 .37409 .45327 .3848 .47151 .37647 .46111 .36627 Mtetra
.715 .809 .923 r
.46111 .36627 .47151 .37647 .48987 .36624 .47955 .35702 Mtetra
.765 .841 .909 r
.47955 .35702 .48987 .36624 .50832 .35268 .49811 .34523 Mtetra
.835 .883 .877 r
.49811 .34523 .50832 .35268 .52681 .3337 .51673 .32913 Mtetra
.909 .92 .813 r
.51673 .32913 .52681 .3337 .54523 .3069 .53535 .30636 Mtetra
.959 .934 .718 r
.53535 .30636 .54523 .3069 .56341 .27115 .55382 .27487 Mtetra
.973 .926 .626 r
.55382 .27487 .56341 .27115 .58125 .22889 .57198 .23508 Mtetra
.967 .917 .574 r
.57198 .23508 .58125 .22889 .59877 .18642 .58979 .1916 Mtetra
.962 .926 .59 r
.58979 .1916 .59877 .18642 .61617 .15012 .60735 .15142 Mtetra
.958 .948 .675 r
.60735 .15142 .61617 .15012 .63364 .12259 .6249 .11929 Mtetra
.926 .948 .788 r
.6249 .11929 .63364 .12259 .6513 .10283 .6426 .09577 Mtetra
.857 .904 .867 r
.6426 .09577 .6513 .10283 .6692 .08846 .66051 .07888 Mtetra
.784 .847 .899 r
.66051 .07888 .6692 .08846 .6873 .07739 .67865 .06627 Mtetra
.732 .803 .908 r
.67865 .06627 .6873 .07739 .70558 .06818 .69698 .05615 Mtetra
.701 .775 .909 r
.69698 .05615 .70558 .06818 .72403 .05997 .7155 .04741 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45397 Mtetra
.17073 .45397 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44738 .22097 .43674 Mtetra
.22097 .43674 .23242 .44738 .24932 .44163 .23793 .43093 Mtetra
.23793 .43093 .24932 .44163 .26633 .43585 .25501 .42507 Mtetra
.25501 .42507 .26633 .43585 .28346 .43003 .2722 .41918 Mtetra
.2722 .41918 .28346 .43003 .30069 .42416 .2895 .41325 Mtetra
.646 .763 .934 r
.2895 .41325 .30069 .42416 .31804 .41826 .30692 .40727 Mtetra
.30692 .40727 .31804 .41826 .3355 .4123 .32445 .40125 Mtetra
.32445 .40125 .3355 .4123 .35308 .40629 .3421 .39517 Mtetra
.647 .763 .934 r
.3421 .39517 .35308 .40629 .37078 .40021 .35987 .38904 Mtetra
.648 .764 .933 r
.35987 .38904 .37078 .40021 .3886 .39403 .37776 .38282 Mtetra
.65 .765 .933 r
.37776 .38282 .3886 .39403 .40654 .3877 .39578 .37647 Mtetra
.654 .768 .933 r
.39578 .37647 .40654 .3877 .4246 .38112 .41391 .36993 Mtetra
.661 .773 .932 r
.41391 .36993 .4246 .38112 .44279 .37409 .43218 .36306 Mtetra
.674 .781 .93 r
.43218 .36306 .44279 .37409 .46111 .36627 .45057 .35559 Mtetra
.698 .797 .927 r
.45057 .35559 .46111 .36627 .47955 .35702 .4691 .34706 Mtetra
.738 .823 .918 r
.4691 .34706 .47955 .35702 .49811 .34523 .48775 .3366 Mtetra
.798 .861 .896 r
.48775 .3366 .49811 .34523 .51673 .32913 .50649 .32279 Mtetra
.873 .903 .849 r
.50649 .32279 .51673 .32913 .53535 .30636 .52528 .30352 Mtetra
.939 .931 .768 r
.52528 .30352 .53535 .30636 .55382 .27487 .54399 .27639 Mtetra
.97 .932 .669 r
.54399 .27639 .55382 .27487 .57198 .23508 .56247 .24026 Mtetra
.971 .92 .593 r
.56247 .24026 .57198 .23508 .58979 .1916 .5806 .1976 Mtetra
.963 .918 .573 r
.5806 .1976 .58979 .1916 .60735 .15142 .5984 .15473 Mtetra
.961 .937 .625 r
.5984 .15473 .60735 .15142 .6249 .11929 .61607 .11808 Mtetra
.947 .953 .733 r
.61607 .11808 .6249 .11929 .6426 .09577 .63381 .09026 Mtetra
.894 .93 .834 r
.63381 .09026 .6426 .09577 .66051 .07888 .65175 .07022 Mtetra
.818 .875 .887 r
.65175 .07022 .66051 .07888 .67865 .06627 .66991 .05562 Mtetra
.755 .823 .905 r
.66991 .05562 .67865 .06627 .69698 .05615 .6883 .04431 Mtetra
.714 .787 .909 r
.6883 .04431 .69698 .05615 .7155 .04741 .70687 .03488 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45397 .15895 .44341 Mtetra
.15895 .44341 .17073 .45397 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43183 Mtetra
.19246 .43183 .20411 .44252 .22097 .43674 .20938 .42598 Mtetra
.20938 .42598 .22097 .43674 .23793 .43093 .22641 .42009 Mtetra
.22641 .42009 .23793 .43093 .25501 .42507 .24355 .41417 Mtetra
.24355 .41417 .25501 .42507 .2722 .41918 .26081 .4082 Mtetra
.26081 .4082 .2722 .41918 .2895 .41325 .27818 .4022 Mtetra
.27818 .4022 .2895 .41325 .30692 .40727 .29566 .39615 Mtetra
.646 .763 .934 r
.29566 .39615 .30692 .40727 .32445 .40125 .31327 .39006 Mtetra
.31327 .39006 .32445 .40125 .3421 .39517 .33099 .38391 Mtetra
.647 .763 .934 r
.33099 .38391 .3421 .39517 .35987 .38904 .34883 .37771 Mtetra
.648 .763 .934 r
.34883 .37771 .35987 .38904 .37776 .38282 .36679 .37144 Mtetra
.649 .764 .933 r
.36679 .37144 .37776 .38282 .39578 .37647 .38488 .36507 Mtetra
.652 .766 .933 r
.38488 .36507 .39578 .37647 .41391 .36993 .40309 .35854 Mtetra
.657 .77 .933 r
.40309 .35854 .41391 .36993 .43218 .36306 .42143 .35175 Mtetra
.667 .776 .931 r
.42143 .35175 .43218 .36306 .45057 .35559 .43991 .34452 Mtetra
.684 .788 .929 r
.43991 .34452 .45057 .35559 .4691 .34706 .45851 .33649 Mtetra
.715 .809 .923 r
.45851 .33649 .4691 .34706 .48775 .3366 .47725 .32702 Mtetra
.765 .841 .909 r
.47725 .32702 .48775 .3366 .50649 .32279 .4961 .31499 Mtetra
.835 .883 .877 r
.4961 .31499 .50649 .32279 .52528 .30352 .51502 .29861 Mtetra
.909 .92 .813 r
.51502 .29861 .52528 .30352 .54399 .27639 .53394 .27553 Mtetra
.959 .934 .718 r
.53394 .27553 .54399 .27639 .56247 .24026 .55271 .24369 Mtetra
.973 .926 .625 r
.55271 .24369 .56247 .24026 .5806 .1976 .57118 .2035 Mtetra
.967 .917 .574 r
.57118 .2035 .5806 .1976 .5984 .15473 .58927 .15961 Mtetra
.962 .926 .59 r
.58927 .15961 .5984 .15473 .61607 .11808 .60712 .11905 Mtetra
.958 .948 .676 r
.60712 .11905 .61607 .11808 .63381 .09026 .62494 .0866 Mtetra
.926 .947 .788 r
.62494 .0866 .63381 .09026 .65175 .07022 .64291 .06279 Mtetra
.856 .904 .867 r
.64291 .06279 .65175 .07022 .66991 .05562 .6611 .04564 Mtetra
.784 .847 .899 r
.6611 .04564 .66991 .05562 .6883 .04431 .67952 .03279 Mtetra
.732 .803 .908 r
.67952 .03279 .6883 .04431 .70687 .03488 .69814 .02244 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43183 .18066 .421 Mtetra
.18066 .421 .19246 .43183 .20938 .42598 .19765 .41508 Mtetra
.19765 .41508 .20938 .42598 .22641 .42009 .21474 .40912 Mtetra
.21474 .40912 .22641 .42009 .24355 .41417 .23195 .40313 Mtetra
.23195 .40313 .24355 .41417 .26081 .4082 .24927 .39709 Mtetra
.24927 .39709 .26081 .4082 .27818 .4022 .26671 .39101 Mtetra
.26671 .39101 .27818 .4022 .29566 .39615 .28427 .38489 Mtetra
.646 .763 .934 r
.28427 .38489 .29566 .39615 .31327 .39006 .30194 .37872 Mtetra
.30194 .37872 .31327 .39006 .33099 .38391 .31974 .37251 Mtetra
.31974 .37251 .33099 .38391 .34883 .37771 .33765 .36624 Mtetra
.647 .763 .934 r
.33765 .36624 .34883 .37771 .36679 .37144 .35569 .35991 Mtetra
.648 .764 .933 r
.35569 .35991 .36679 .37144 .38488 .36507 .37385 .35349 Mtetra
.65 .765 .933 r
.37385 .35349 .38488 .36507 .40309 .35854 .39214 .34695 Mtetra
.654 .768 .933 r
.39214 .34695 .40309 .35854 .42143 .35175 .41056 .3402 Mtetra
.661 .773 .932 r
.41056 .3402 .42143 .35175 .43991 .34452 .42911 .33312 Mtetra
.674 .781 .93 r
.42911 .33312 .43991 .34452 .45851 .33649 .44779 .32544 Mtetra
.698 .797 .927 r
.44779 .32544 .45851 .33649 .47725 .32702 .46661 .31668 Mtetra
.737 .823 .918 r
.46661 .31668 .47725 .32702 .4961 .31499 .48555 .30599 Mtetra
.798 .861 .896 r
.48555 .30599 .4961 .31499 .51502 .29861 .5046 .29192 Mtetra
.873 .904 .849 r
.5046 .29192 .51502 .29861 .53394 .27553 .52369 .27236 Mtetra
.939 .931 .768 r
.52369 .27236 .53394 .27553 .55271 .24369 .54272 .24489 Mtetra
.97 .932 .669 r
.54272 .24489 .55271 .24369 .57118 .2035 .5615 .20838 Mtetra
.971 .92 .592 r
.5615 .20838 .57118 .2035 .58927 .15961 .57993 .16531 Mtetra
.963 .918 .573 r
.57993 .16531 .58927 .15961 .60712 .11905 .59802 .12205 Mtetra
.961 .937 .626 r
.59802 .12205 .60712 .11905 .62494 .0866 .61596 .08504 Mtetra
.947 .953 .733 r
.61596 .08504 .62494 .0866 .64291 .06279 .63398 .0569 Mtetra
.894 .93 .834 r
.63398 .0569 .64291 .06279 .6611 .04564 .6522 .0366 Mtetra
.818 .875 .887 r
.6522 .0366 .6611 .04564 .67952 .03279 .67066 .02174 Mtetra
.755 .823 .905 r
.67066 .02174 .67952 .03279 .69814 .02244 .68933 .0102 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001oogooOol0
07oo0000Egoo003EOol30007Ool01Ell000007oo0000EWoo003BOol30008Ool01elkHeaO?000Gc]o
o`0005Ioo`00d7oo0P002Goo1Ell00D005llGcaoo`0005Eoo`00cGoo0`002Woo00aWO6MKHeaO?5mL
Gc/005/LGcaK77oo001DOol00<]oo`8000]oo`=WN`03IgaO?5ll009O?006001K?5/lGcaoo`00E7oo
0038Ool300000goo001oo`09Ool046MkIgaWFf]lIg]WO5/LGcaK75ll001O?5/LGcaoo`00Dgoo001W
Ool20002Ool2001IOol20004Ool00`00Oomoo`06Ool01FMlIg]WNfMkIg`00VMk0V=L00EK75/lFc`0
05/L009K?09oo`03001oogoo051oo`00J7oo00@007ooOol005Moo`<000ioo`0DLkY_VFMlIe][O6Mk
IgaSFf=LHe]SG5/LGc`005llFaaK?5LLOol0059oo`00JGoo0P00EWoo0P0047oo00Ic^VniLkY_^VMl
Ig/6He`00ellFa`00005Fa`00goo001oo`1@Ool006Uoo`8005=oo`<0019oo`0DKiUc^VnILkY_VF=L
He]SG6=KHeaSFf=LHe]K7000FcaG75/LEaaK?09oo`03001oogoo04ioo`00J7oo00@007ooOol0051o
o`8001Aoo`05KkUc^VnjLkY_^@02Ji/6He`2Gc`00`00FaaK7004Fa`00goo001oo`1?Ool006Moo`80
009oo`8004aoo`<001Eoo`0JKiUc^VnILkY_VFnKJgY_Vf^JHeaSFf=LGcaOG5lkHe`005/LEaaK?5LL
FaaFo5/LOol004moo`00]Woo0`000Woo00<007ooOol04Woo00E_^G>jKkYc^Vni009[V`04Ki][VV^K
Ji/6Gc`00`00EaaK7003Ea`015/LEa`00000Cgoo002dOol2000IOol07GNfNmM_VG>jKiU_Vf]jKi][
VVnKJgY[O6MkGeaO>f=LGcaOG000GcaFo5/LE_aK75KlFaaFo7oo0000CWoo002aOol3000KOol2MkH0
2GOGMkI[Vf^KKi][VV^KIg]WO002Ig/3Gc`2Fc`01@00FaaK?5LLFa`00ULL00EFo5LLE_aoo`0004eo
o`00[goo0P007Goo01mkegNfNmMg]WOHLkQ_Vf^JKi]WFf]lIg]WO6MKJgaK75llFaaO?000GcaK75ll
E_aG75KlEaaFo5LLOol0000AOol5000gOol00:aoo`<001moo`04MkIgegNfMkH2MkP017>hIg]WNfMl
0fMk00QWO6=LHeaK?5llFa`005/l0e/L00QFo5LLE_aG75KlEaaoo`0047oo00D007ooOomoo`0003Mo
o`00ZWoo0P008Goo01Qg]W_GMkIkeg>hMmUc^7>jKiU[O6MkIgaWFf]lHe]SG6=KGcaK75ll001K?5LL
Fa`2Ea`01EKlEaaFo5LLE_`00Woo00<007ooOol03Woo00<007ooOol0>7oo002WOol30002Ool00`00
Oomoo`0MOol017NfMmMg]WNf0WNh00Ec^7>jKkYc^Vni009WN`ISG09K7003001K75/L00=K7003EaaF
o5LL00=Fo003Ool007oo00Ioo`H000Aoo`03001oogoo03Moo`00YGoo0P009Goo02AkegNfNmMc^7OI
LkQgf6nILkY_VG>jKiUSG6=KHeaSFf=LHe]OG5lkFc`005/LEaaK?5LLFaaBo5LLE_aG75;lEaaFo7oo
000AOol00`00Oomoo`0fOol00:9oo`<002Ioo`0>MmMg]WNfMkIg^7>hMkQ_^W>jKkUc^VnjKi][VP=S
G0EO?004001K75/LFa`2Ea`00e/LE_aFo005E_`00goo001oo`0@Ool00`00Oomoo`0eOol007Eoo`@0
02Moo`8002Uoo`0VMk=k/gNCMmUc^7OHKiUc^VnILkY_VFnKJiY_Vf]jHeaO?5mLGc]SG5llGe`005/L
E_aK75KlFaaFo5/LD_aG75KlEaaBo5LLD_`000eoo`05001oogooOol0000gOol007Aoo`03001oogoo
009oo`03001oogoo025oo`<002Yoo`=k/`0:NkEg]7^eKkYc^VniLkY[VfnKJiX2Ji/00fMlIg]O?005
Gc`01@00FaaG75LLFa`00eLL00=K75;lE_`00UKl00ABo5KlOol000eoo`<003Qoo`00M7oo00<007oo
Ool00Woo00<007ooOol07Woo0`00;Goo02Uk/gNCNk=g]7_EMkIkegNfNmM[NVnKJiY_Vf]jJgaWNfMl
Ie]SG5llGeaK75llFa`005KlFaaFo5/LE_aG75KlEaaBo5LLD_aFo5;lEaaoo`0004Moo`00M7oo00<0
07ooOol00Woo00<007ooOol077oo0P000Woo00<007ooOol0:Woo0g^c00Ag]7^eNkEge`9g]P9g^004
JiY[VfMkIg`3Ig/02FMlIg]K?5/lGcaK75/l001O?002Ea`015KlEaaFo5LL0UKl00MBo5KlE_aFo5;l
Ool00017Ool007Aoo`03001oogoo009oo`03001oogoo01Uoo`<0035oo`0RMi=k/gNcNmEg]7_GMkIk
egNfMmUc^7OHIe][O6MkIgaWFf]lIg]SG6=KGcaK75llFa`005/LEaaFo5LLE_aG75KlEa`2E_`01e;l
EaaBo5KlD_aoo`0004Ioo`00M7oo00<007ooOol00Woo00<007ooOol05goo0P00<goo0g^c0g^e0gNf
00Eg^7>hMkQ_^W>j00=WN`03IgaWNf=L009SG005FaaK?5/lGc`00002Fa`03ELLE_aG75KlEaaFo5LL
D_aFo5;lE_aBo5Kl009oo`03001oogoo04=oo`00M7oo00<007ooOol00Woo00<007ooOol057oo0`00
=Goo01ek/gNcNk=g]7_EMkIkegNfMmUc^7OHKiUc^VnILkYWFf]lHe]SG6=KHeaSFf=LEaaK?5LL001G
75/l009G700>E_aG75KlEaaBo5LLD_aFo5;lE_aBo5KlOol004Eoo`00MGoo10005Goo0P00=goo0g^c
0W^e0gNf00Ug^7>hMkQg^7>jKkUc^VnjLkX01V=L0Ull0U/L00<005/LFa`00U/L1eKl00=Bo5KlD_`0
0U;l00=Fo7oo0000A7oo002;Ool3000iOol0<7NcNk=gTg_EMkAkegNfNmMc^7OHLkQc^VnILkY_VG>j
JiY_Vf=KHeaSFemLGc]SG5llGeaG7000EaaK75KlFaaFo5LLD_aG75KlEaaBo5KlD_aFo5;LE_aBo5Kl
Ool004=oo`00RGoo0P000Woo00<007ooOol0=Woo0g^c00Ik]GNdMkIg]WOGLkP2MkP01W>jKkUc^Vnj
LkY[VP9[V`03Ki]O?5ll00IO?004001G75LLFa`2Ea`6E_`3D_`01UKlD_aBo5;lOol004=oo`00QWoo
0`00?Goo039k/WNANk9gTW^bMi9k/gNdNmEg]7>jKiUc^VnIKi][VVnKJgY_VfMkIgaO>f=LGcaOG5lk
HeaK7000E_aK75KlFaaFo5/LD_aFo5;lEaaBo5KlD_aFo5;lE_aBg5KlD_aoo`00@Woo0024Ool20010
Ool017^ANk5kTW^b0g^c00=k]G^dMmL00gNf00E_Vf^JJi][VfnK00=WN`03IgaO?5ll009O?004FaaK
?000Fa`3Ea`00e/LE_aG7002E_`015;lE_aFo5Kl0e;l00IFo5;lD_aBo7oo0011Ool0085oo`<0045o
o`0NMi5k/WNANk9gTG^cMk=keGNdNmEg]W_GMkIgfG>hKi][NV]lIg]WO6MKJgaWNfMlFaaO?5/LGcaK
70000U/L01AFo5LLE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aoo`00@Goo001nOol30014
Ool017^aNi5k/W^b0g^c00=k]7^eMkH00WNf00Egeg>hMkQg^6Ml00=WN`03IgaWNfMk009SG00<FaaK
?5/lGc`005/lE_aG75KlEaaFo5LL15Kl00ABo5KlD_aFo0=Bo005E_aBo5;lOol00010Ool007aoo`80
04Ioo`0gNk9gTG^bMi5k/WNcNk=g]7_EMkAkegNfNmMc^7OHLkQc^VnIIgaWFf]lIg]WO6=KHeaSFell
FaaO?5/L001G75/lE_aG75KlEaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo7oo0000?goo
001iOol30002Ool20014Ool3Ni401W^bNk=k/g^cNkEg]09g]P0:MmMc^7NhMkQc^VniLkY_^VMlIg/6
He`3Fa`01P00FaaK75LLE_aG70AFo008D_aFo5;lE_aBo5KlD_aFo0=Bo004E_aBo7oo000oOol007Mo
o`8004]oo`0QNk9gTG^bMi9k/gNBNmEg]7_GMkIkeg>hMmQc^7OIKiUc^VnILkY_VF=LHe]SG6=KHeaS
Ff=LGcaK75LL001G75/L009G700EE_aG75;lEaaFo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]ao
o`0003ioo`00M7oo0`00C7oo0W^A00=k/G^BNk<00W^c00Eg]7^eMkIgegNf00=g^005KkUc^VnjLkY_
^@02Ji/3He`4Gc`2Fa`01@00FaaG75/LEa`01eKl0e;l00EFo5;lD_aBo5Kl00=Bo004E_aoogoo000m
Ool0079oo`8004moo`0jMi5k/WNBNk9gTW^cMkAkeGNfNmMg]WOHLkQgfFnILkY_VG>jKiU_Vf]jKi][
VUmLGc]SG5llGeaO>f=LE_`005KlFaaFo5/LE_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo7oo000mOol006moo`<0051oo`07Ni5k/G^ANk9kTG^aNi400W^b0W^c00Qk]G^dNkE_^G>j
KkYc^V^J0V^K00A_Vf^JIg]WN`EO?004FaaK?5LL0003Ea`00e/LEaaFo002E_`015;lE_aFo5Kl0e;l
00=Fo5;lD_`01E;l0Woo00<007ooOol0>Woo001]Ool200000goo001oo`1@Ool0>W^bMi5k/WNANk9g
TG^bMi5k/gNcNk=g]7_EMkIkegNfNmM[VVnKJgY_Vf^JIgaWNf]lGcaOG5lkGcaK75llFaaO?000FaaF
o5/LE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L0Woo00<007ooOol0>Goo
001ZOol3001DOol01G^aNi5kTG^ANk400W^A0W^b0W^c00=k]7^eMk@00WNf00Egeg>hMkQ[VfnK00=W
N`06IgaWNfMkFcaO?5/L0U/l00YO?5/L001Fo5LLE_aG75KlEaaBo0=Fo004D_aFo5;lE_`3D_`00eKl
D_aBo005D_`00goo001oo`0jOol006Moo`<005Moo`0oNi9k/W^ANk9gTG^bMi5k/WNcNk=gTW_EMkAk
egNfNmMg]WOHLkQgfFMkIgaWNf]lIg]WO6=KHgaK75llFaaO?5/LGc`005/lE_aG75KlEaaFo5LLD_aF
o5;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aoo`0003Yoo`00IGoo0P00FWoo0W^B17^A
00Yk/W^BNk=k/g^eMkAk]GNfMmMg]P=g^005KkUc^VMkIgaWN`05He`00e/lGcaK7002Fa`01@00FaaG
75KlEa`015Kl00QBo5KlD_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01E;l00<007ooOol0>7oo001ROol3
001KOol09G^bNi5k/W^ANk9gTG^bMi9k/gNBNk=g]7_EMkIkegNfMmQc^7OIKiUc^VnILkYSFf=LHe]S
O6=KHeaSFf=lEaaK75LLFc`005/L009G7004E_aG75;lEa`2E_`055;lE_aBo5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;L000iOol0061oo`8005ioo`03Ni9k/W^A009kT@03Nk5kTW^b009k/`05
MkAk]GNfMmMg]P03MkP01W>hLkY_^W>jJiY[V`ISG09O?0=K7004001K75/LEa`7E_`015;lE_aBo5Kl
0e;l00EFo5;lD_aBo5Kl00IBo003Ool007oo03Moo`00GGoo0`0000=oo`00Ool0G7oo04=kTG^bNi9k
/WNANk9gTG^bMi9k/gNcNmEg]7_GMkIkeg>hMmUc^7>jKiUc^V^JKi][NVnKHe]SG6=KHeaO?5mLGc]K
?5LLFa`005/LE_aK75;lEaaFo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_`0000hOol005]oo`80069oo`06Nk9kTW^ANi5k/G^A0W^b0W^c00=k]G^dMmL00WNf0WNh00Ec
^7>jKkYc^V^J009[V`03Ki][VV^K00MO?09G7005001G75LLEaaK7004E_`015;lE_aBo5Kl0e;l00=F
o5;lD_`02e;l00=oo`00Ool0=Woo000^Ool4000VOol3001TOol08W^BNk9gTG^bMi5k/WNANk9gTG^b
Mi5k/WNcNk=g]7_EMkAc^VnILkY[VVnKJgY_Vf^JKi]WNf]lGcaOG5lkHeaK75ll0U/L00@005/LE_aK
709Fo00KD_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aoo`00
029oo`<0015oo`00;Goo00<007ooOol00Woo00<007ooOol08Goo0P00IWoo0W^B17^A00Ak/W^ANi5k
T@9k/P=k/`06NkEg]7OFMkIgef^J0V^K00E_Vf^JJi]WNfMl009WN`03FcaO?5/L009K?007GcaG7000
EaaK75KlEa`00UKl00QBo5KlE_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00IBg5;lD_aBo7oo000T
Ool00`00Oomoo`0?Ool0039oo`03001oogoo01eoo`@006Qoo`0[Nk9kTG^bMi5k/WNANk9gTG^bMi5k
/WNBNk=gTW_EMkAkeGNfNmMc^7OHJgY_Vf^JIgaWNf]lIg]WO6=KHgaK75llFaaO?5/LGc`005LLE_aG
75KlEa`00UKl01YBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_ao
o`008goo00<007ooOol03goo000UOol60007Ool00`00Oomoo`0LOol3001YOol2Ni82Ni42Ni801W^b
Ni5kTG^ANk9kTP=k/`05MkAk]GNfMmMg]P03MkP017>hIg]WNfMl0VMk0f=L0U/l00]O?5/LFaaK7000
E_aG75KlEaaFo5LL009Fo004D_aFo5;lE_`3D_`01EKlD_aBo5;lE_`025;l00IBg5;lD_aBo7oo000Q
Ool00`00Ool0000@Ool002ioo`@001aoo`<006aoo`19Ni5k/W^ANk=kTG^bNi5k/WNANk9gTW^bMi9k
/gNdNmEg]W_GMkIgf7>hMmUc^7>jKiU[O6MkHeaSFf=lHe]SG6=KFcaG75/LEaaK?000FaaFo5LLE_aG
75;lEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg7oo0000
8Goo00<007oo000047oo000^Ool00`00Oomoo`0JOol3001^Ool01g^BNk9kTg^cNi9k/W^B009kT@03
Nk5kTW^b00=k/`04NkEg]WOGMkH3MkP01G>hLkY_^W>jKkT01V=L0Ull15/L00<005/LFa`01UKl00IB
o5KlD_aFo5;lE_`3D_`00eKlD_aBo00:D_`00e;LD_aBo002000OOol01@00Oomoogoo00003goo000^
Ool00`00Oomoo`0HOol2001aOol0C7^eNiAk/g^BNk9kTW^bMi5k/WNANk9gTG^cMk=keGNdNmMg]W_G
LkQgfG>hLkY_VG>jKiU_Vf]jHgaSFf=LGc]SG5llGeaO>e/lEaaK7000FaaFo5/LD_aG75;lEaaBo5LL
D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aoo`007Woo00D0
07ooOomoo`0000moo`00;Woo1@004goo0`00LWoo00Ek]G^dNk=k/g^b009kTP03Ni5k/G^A009k/P=k
/`04NkAgegNfMmH2MkP01G>hLkY_^W>jKkT00V^K00=_Vf^JJi/01ell0ULL00@005LLEaaG70EFo004
D_aFo5;lE_`3D_`00eKlD_aBo00:D_`025;LD_aBo5;lD]aBo7oo000MOol3000017oo000000003Woo
0014Ool2001eOol097^DNkEkTWncNi9k/W^ANk9gTG^bMi5k/WNcNk=gTG^bMk=k/gNdNmEg]7>jKiUc
^V^JKi][NVnKJiY_VfMkJgaO?5mLGc]SG09O?09K7004001K75KlFa`2E_`085;lEaaBo5KlD_aFo5;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo7oo0009Ool4000TOol0
045oo`<00003Ool007oo07=oo`9k]09k/`03Ni=kTW^B00=kT@9k/P=kT@0:Nk9k/g^cNk=k]GNdMmIg
]WOGJiX2Ji/01VnKJiY[VfMkIgaWN`=O?004FaaK?5/lGc`2Ea`01000FaaFo5LL0UKl00ABo5KlE_aF
o0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`015;LD_aoo`001goo00<007ooOol00Woo00<0
07ooOol08Goo000oOol2001iOol0D7^eNiAo/g^CNk9kTG^bNi5k/WNANk9kTG^bMi5k/WNANk=gTW_E
MkAkeGNfNmMc^7OHJgY_Vf^JIgaWNf]lIg]WO6MkGcaK75llFaaO?5/LGcaFo000E_aG75KlEaaBo5Kl
D_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg7oo
0007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003aoo`<007Yoo`9k]005Nk=kTg^cNi9k/P03Ni40
1W^bNi5kTG^ANk5kTP=k/`05MkAk]GNfMmMg]P03MkP017>hIg]WNfMl0fMk0V=L0U/l00=O?5/LFa`0
0U/L00`005LLE_aG75KlEaaBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l
00MBg5;lD_aBo5;LOol00006Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003Yoo`8007eoo`1@NiAk
]G^CNk=kTW^bNi9k/W^ANk9kTG^bMi5k/WNANk9gTW^cMkAkeGNdNmMg]WOHLkQgfG>hLkY_VF]lIg]W
O6=KHgaSFf=LHe]K?5LLFaaG75/lEa`005KlEaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo09oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo025oo`00=goo0`00OWoo00=k]7^eNi<00W^c00Ik/W^BNi5k/g^bNi82Ni400g^a
Ni5k/P03Nk<01G^eMkAgegNfMmH00WNh00Ec^7>jKkYc^Vni00ISG09O?0EK7003001Fo5Kl00EFo003
D_aFo5;l009Bo005E_aBo5;lD_aFo008D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo7oo0005Ool0
0`00Oomoo`02Ool00`00Oomoo`0QOol003Eoo`800003Ool007oo07ioo`1BNkEkU7^cNi9o/g^BNk9k
Tg^bNi9k/WNANk9gTG^bMi5k/gNcNmEg]7_GMkIkeg>hMmUc^7>jKiUc^VnIKi][NV=lHe]SG5lkHeaO
?5mLEaaK?5LLFaaFo000E_aG75;lEaaBo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`2Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol0039oo`<0089oo`03NkEk]7^c009k/`9kTP9k/`9kTPAkT@0?Nk9k/g^cNk=g]7^eMkIg
eWNfMkQc^7>jKkYc^Vni009[V`03Ki][VUll00IO?0=G7004Fa`005LLEa`5E_`3D_`00eKlD_aBo00>
D_`01E;LD_aBo5;lD]`00e;l00=Bg5;lD_`00`0017oo100097oo000_Ool30025Ool0<7^DNkEkTWnc
Ni=k]G^DOk=kTW^bNi5k/WNANk9gTG^bMk=k/gNdNmEg]W_GMkIgfG>hLkY_VG>jJiY_Vf]jKi][VVMl
Ig]SG5llGeaO>f=LFaaO?5KlFaaFo000E_aK709Fo00UD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo0000;7oo000]Ool20027
Ool02GNgMkQg]g^fMkIk]W^dNk=kT`02Ni84Ni401W^bNi5kTG^ANk9kTP9k/`06NkEg]7OFMkIgef^J
0V^K00I_Vf^JIg]WNfMlIg/3Gc`01E/LFcaK?5llEa`00P0000=K75KlEa`00UKl00ABo5KlE_aFo0=B
o003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lOomoo`0002]o
o`00:Woo0`00R7oo02]gUgNhMiMk]WNfNkIkU7^eNi=k/g^ANk9kTG^bMi5k/W^ANk9gTG^bMi5k/gNB
Nk=g]7_EMkIkeg>hMmQ[NVnKJiYWO6MkJgaWNfMlIg]O?5/LGcaK70030000:UKlEa`005LLE_aG75;l
E_aBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo09oo`03001oogoo02Qoo`00:7oo0P0000=oo`00Ool0R7oo00Ag^7NgMkQg]P9k]P06
NkEkTg^cNi9k/W^B0W^A00Mk/G^ANi5kTG^aNi9k/P02Nk<01GNdNkEg]WOGMkH00gNh00Ac^6MkIg]W
O0=WN`9SG0<000AK700<E_`005KlEaaFo5LLD_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`00:Woo000VOol2002<Ool09gNhMiMg^7Nf
NkIgUG^eNiAk/g^CNk9kTW^bMi5k/W^BNk9gTG^bMi5k/WNBNk=g/g_EMkAkegNfMmQc^7OILkQc^VnI
JgaWNfMlHe]SO00200001V=KFcaG75/LEaaK?09G700YE_`005KlEaaBo5LLD_aFo5;lE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool0
0`00Oomoo`0WOol002Ioo`8008aoo`03MkMg^7Ng00=k]P04NkAk/g^cNk82Ni800g^ANk9kTP02Ni40
17^aNi5k/W^b0W^c00Ek]GNdMmMg]WOF009g^006LkQc^VnjLkY_^F=L0`000V=L0Ull1U/L0UKl00<0
05KlE_`00UKl00=Bo5KlD_`00U;l00EFo5;lD_aBo5Kl00QBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00ABg7ooOol002Qoo`009Woo0`00RWoo029gUgNhMiMk]WNENkIkU7^eNi=o/g^BNk9g
TGncNi9k/WNANk9gTG^bMi5k/WNcNmEg]7_GMkIkeg>hMmUc^7>jKiUc^P<0000jHgaSFf=LGc]SG5ll
GeaG75/lEaaK75KlFaaFo5LLD_`005;lEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000XOol002Ioo`04001oogoo
0028Ool017NgMkQg]gNh0W^f00Ag]W^dNk=k/`=kTP03Nk=kTW^B00AkT@9k/P9k/`08MkAk]GNfMmIg
]WNhLkQc^P<0009[V`03Ki][VUll00IO?0=G7003FaaG75LL009Fo004001Fo5KlE_`3D_`00eKlD_aB
o00>D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03001oogoo02Eoo`009Goo00<0
07ooOol00Woo00<007ooOol0QGoo01eg^7NGMkQgUG^fMkIk]G^DOk=kTg^eNiAk]G^CNk9kTG^bNi5k
/WNANk9gTG^cMkAkeGNfNmMg]WOI00<00011LkY[VVnKJgY_Vf^JIgaWNf=LGcaOG5lkGcaK75llE_aK
75KlFaaFo5/LD_aFo000EaaBo5KlD]aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000WOol002Eoo`03001oogoo00=oo`03
001oogoo08=oo`0>MkQg]gNhMkMk]WNfNkIk]7^fMkIk]W^dNkEkT`9kTP0;Nk9kTG^ANi5k/W^BNk=k
TG^bNi9k/`03000017OFMkIgef^J0V^K00I_Vf^JIg]WNfMlIg/2Fc`01EllFaaK?5/lFa`015LL00EF
o5LLE_aFo00000=Fo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00IBg5;lD_aBo7oo000VOol002Eoo`03001oogoo00Aoo`03001oogoo085oo`0IKi]_VVnJJgYk]WNf
NkIgUg^fMkIk]W^DNkEkU7^cNi5k/W^ANk9gTG^bMi5k/WNANk800`0004Ik/gNdNmEg]W_GLkQgf6]j
Ki][VVMlIg][O6MkHeaSFellFaaO?5/LGcaK75LLE_aG75KlEaaFo5LLD_aFo000E_aBo5KlD]aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg09oo`03001oogoo02=oo`009Goo0P001Woo0P00P7oo16nJ00Ic^G>ILiUg]gNhMkH2NkH01W^e
NkAk/g^cNk9kTP9kT@04Nk5kTG^ANi42000027^bNk=k/gNdNkEg]WOGMkH3MkP017>hIg]WNfMl1F=L
0U/l00UO?5/LFaaK75LLE_aG75KlEa`00UKl00IBo000D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0TOol002Eo
o`03001oogoo00Moo`03001oogoo07]oo`0GJgY_VfnJKiY[NW>iLiUc^G>IMkQg]W^fMiEk]G^DNkEk
Tg^bNi9k/WNANk9kTP030000CgNANk9gTW^cMk=keGNdNmMg]WOHLkQgfG>hLkY_VG>jHe]SG6=KHgaS
Ff=LHe]K?5LLFaaG75/lEaaK75;lEaaBo5LLD_aFo5;l001Bo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0002Ao
o`009Goo00<007ooOol027oo00<007ooOol0NGoo1FnJ00Ic^G>ILiUcVGNhMkL3NkH2Nk@2Nk<2Ni80
17^A000000000g^A0W^b0W^c00Ak]GNdMmMg]P=g^006LkQc^VnjLkY[VV^K1F=L0Ull15/L0ULL00=K
75KlE_`015Kl00=Bo000D_`00U;l00EFo5;lD_aBo5Kl00QBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00IBg5;lD_aBo5;LD_`2Ool00`00Oomoo`0QOol002Eoo`03001oogoo00Uoo`03001o
ogoo07Moo`0CJgY_VfnJKiY[NW>iLiUc^G>IMkQgUg^fMiEk]W^DNkEkU7ncNi800`0005IkTg^bMi5k
/WNANk9gTG^bMk=keGNdNmMg]W_GLkQgfG>hLkY_VG>jJiY_Vf]jHgaSFf=LGc]SG5llGeaO>e/LE_aK
75KlFaaFo5LLD_aG75;lE_aBo5LLD_`005;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`008goo000TOol2000<Ool0
0`00Oomoo`1eOol00f=LIga_VP02KiX01g>iLiUcVG>IMkQg]gNh009k]P03MkIk]7^d00<00004Ni9k
/g^CNi84Ni42Nk82Nk<017NdNkEg]WOF0WNh00Ec^7>jKkYc^V^J009[V`03Ki][VUll00IO?004FaaG
75LLFa`3Ea`00eKlD_aFo002E_`2D_`00`00E_aBo00;D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`008Woo000TOol00`00Oomoo`0<Ool00`00Oomo
o`1cOol03f=KIgaSFfMlHe]c^G>ILkUcVG>iMiMg^7NENkIg]P030000;7^CNk9kTG^eNi=k/g^ANk9k
TG^bMi5k/WNANk=g]7_EMk=k/gNdNmEg]7>jKiUc^V^JKi][NVnKJiYWO6MkHeaO?5mLFaaO?5/LGcaF
o5/LE_aK75KlEa`2E_`0;E;lEaaBo5KlD_aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0O
Ool002Aoo`03001oogoo00eoo`03001oogoo071oo`08IgaSG6MlHe]WO6=LJg]WN`9cV@04LkUg]gNh
MkL300002W^dNkEkTg^cNkAk]G^CNk=kTW^b0g^A00Ik/W^BNk=kTG^bNi82Nk<01W^eMkAgeWNfMmM[
VP9[V`06Ki]WNfMkIg]WO6Mk0U/l00]O?5/LFcaK?5llE_aG75KlEaaFo5LL009Fo004D_aFo5;lE_`2
D_`00`00E_aBo007D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01e;LD_aBo5;lD]aoo`00025oo`0097oo00<007ooOol03Woo00<007ooOol0KWoo00eWO6=KIgaS
FfMlHe][VfMkJi]WNf^KMiMg^0020000IGNfNkIkU7^eNiAk]WNFNkEkU7^cNi=k/W^ANk9gTG^bMi5k
/WNANk9gTG^cMi9keGNdNmEg]W_GLkQgf7>hJgaWNfMlIg][O6MkHeaSFellFaaO?5/LFcaG75/LE_aG
75KlEaaFo5LLD_aFo5;lE_aBo5KlD]`005;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000087oo000TOol00`00
Oomoo`0?Ool00`00Oomoo`1/Ool025llFcaWO6=KIgaSG6]kIg/3Jg/300001W>iLiUcVG>IMkQg]`9k
]P03NkEk]7^c009k/`04Ni9kTG^ANk43Ni400g^aNi9k/P02Nk<01GNdNkEg]WOGMkH00WNh00Ec^Vni
Ig]WNfMl00ESG0IK7003EaaFo5LL00AFo00:D_aFo5;lE_aBo5KlD_`005;lE_`8D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol0
7Goo000TOol2000AOol00`00Oomoo`1YOol02U/lGeeK?5mMFcaWO6=KJi]WNf^K0`0003=_VV]jKi]c
VG>iLiUg^7NGMkQgUW^fNiAk]G^COk=kTW^bMi5k/W^BNk9gTG^bMi5k/WNBNk=g]7_EMkIkegNfMmQc
^7>jKiUc^VnILkYSFf=LHe]SO6=KGeaO>e/lEaaK75LLFc`00ULL03IBo5LLD_aG75;lE_aBo5KlD_aF
o5;lE_aBg000D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000OOol002=oo`03001oogoo019oo`03001oogoo06Io
o`09GceK?5llFcaO?E/lGcaK?6]k00<00003Jg]_VVnJ009_VP=cV@03LkUg]gNh009k]P9k]09k/`05
Ni=kTW^ANi5kTP04Ni42Nk801W^cMk=k]GNfMmMg]P=g^006KkUc^VnjLkY[VV^K0V=L1Ell0e/L0eLL
1UKl0U;l00MFo5;lD_aBo5KlD_`0000:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01U;LD_aBo5;lOol001ioo`006Woo10001Goo00<007ooOol04goo00<007oo
Ool0Hgoo00QG75/mEaaOGE/lGeeK?5mM0`0000=[VfMkJi/00VnJ06][NVnKLiUc^G>ILkUgUgNhMiMk
]WNfNkEkU7ncNi=k/WNANk9kTg^bMi5k/WNANk9gTG^cMk=keGNdNmMg]W_GLkQgfFnILkY_VG>jJiY_
Vf]jKi]O?5mLGc]SG5llGeaO>e/LE_aK75KlFaaBo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5Kl001F
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L009oo`03001oogoo01]oo`006Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol057oo00<007ooOol0H7oo00MG?ELMEceG75LmEaeO?@0300001F=LGeaOG5mLHe`016nJ
0g>I00Ic^GNgMkQg]g^fMkH2Nk@01g^cNi=k/g^BNk=kTg^B00AkT@9k/P06Mk=k/gNdMmMg]WOF0WNh
00E_^G>jKkY_Vf^J009[V`03Ki]WNfMk00AO?003FcaO?5/L009G7003FaaG75LL009Fo004D_aFo5Kl
E_`3D_`00eKlD_aBo002D_`00`00D_aBo005D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool077oo000IOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`1MOol01ULLFceG75/mEaaK?@<0001jHeaO
?6=LGeaSG5llHeaSFfMlJgY_VfnJLkUcVG>iMiMg^7NGMkQg]W^fNiAk]G^CNk=kTG^eNi=k/g^ANk9k
TG^bMi5k/WNcNk=gTG^bMk=k/gNdNmEg]W_GMkI_Vf^JKi][NVnKIg]WO6MkJgaK75llFaaO?5/LGcaK
75LLE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0
01aoo`006Goo00<007ooOol00Woo00<007ooOol00Woo0P005goo0P00Fgoo00IG7E<MEaeG7ELmEa`2
00001ELmFcaK?E/lHe`00emL00ISG6=KIgaSG6MlHe/2LiT02W>iLiUg^7NgMkQg]W^fNkAk]G^C0W^c
00Ek]G^CNk=kTW^b00=kT@06Nk9kTW^ANi5k/WNc0W^c00Ik]GNdMmIg]WNhLkP2Ji/01FMlIg]WNfMk
Ig`00V=L00=K?5llFa`00U/l0U/L00EG75KlEaaFo5LL009Fo004D_aFo5;lE_`3D_`00eKlD_aBo002
D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo01Yoo`006Goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol067oo00<007ooOol0EGoo00IG7E;lEaeC75LMD_`30000P5LLFceK?5/mEaaK?E/l
HeaO?6MlHe]WO6=KIgaSFf^KIg][VfMkMkQgUgNhMiMk]WNFNkEkU7^fMiIk]W^DNk=kTg^bNi5k/WNA
Nk9gTG^bMi5k/WNANk=gTW_EMkAkegNfNmMc^7OHLkQ[O6MkIgaWNf=lHe]SG6=KGcaK75llEaaK?5LL
FaaFo5LLE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg000D]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
000KOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo059oo`05
D_eC7E<MEaeC7@0300004E<MEaeK?5/mFcaK?E/lFceK?5/mFcaWO6=KIgaSG6MlHe/00f]k00=WNfnJ
KiX00VnJ0W^f00=g^7NgNkH00W^f00Ek]7^cNk=k/g^B009kT@06Nk5kTG^ANi5k/G^B0g^c00Eg]7^e
MkIgeg>h009g^004LkY_^G>jKkX6He`7Fa`6E_`00e;lE_aBo002D_`01EKlD_aBo5;lE_`00e;l00<0
05;lD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo004D]aBo7oo000JOol001Uoo`03001oogoo009oo`05001oogooOol0000MOol0
0`00Oomoo`1>Ool01E;lEaeBo5<MD_`00`0008QBo5LMDaaG7E<LEceK?5/mEaaK?E/lFceK?5mMFcaW
O6=KIgaWNf^KIg][VfMkKiY[NVnKKiYc^G>IMkQgUgNhMiIk]WNfNkEkTgncNi9k/WNANk9kTW^bMi5k
/WNANk9gTW^cMkAkeGNfNmMc^7OHLkQc^VnILkY_VFnKJiYSG6=KHgaO?5mLGc]K?5LLFaaG75/LE_aK
75;lEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol0
00Moo`D000eoo`006Woo100017oo0P007Goo00<007ooOol0Bgoo00AC7E;mDaeBo@<00005D_eC7E<M
EaeG7003Ead03ELLEaeK?5/mFcaO?5/lGceK?5llFcaO?FMk00=[N`03Ig]_VVnJ009_VP9cV@03LkUg
]gNh009k]P06MkIk]7^cNk=kTg^B0W^A00ekTW^ANi5k/G^ANk9kTW^cMk=k]GNfMmMg]P03MkP01Fni
LkY_^VnKJiX00V^K1Ull0ULL00AK75LLEaaG70EFo004D_aFo5;lE_`;D_`00`00D_aBo002D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00=Bg7oo00001goo00D007ooOomoo`0000eoo`008Woo00<007ooOol07Goo00<007ooOol0AWoo00E>
o5<MD_aC7Dkl00<0001<D_aG7E;lDaeBo5LMD_aG7E<LEceG75LMDaaG?E/lGeeK?5mMFcaOGE/lGeeO
G6=LIg][VfMkKiY[NVnKKiYc^G>ILkUgUgNhMiMk]WNfNkIkU7ncNi=k/WNANk9kTg^bMi5k/WNANk9g
TG^cMk=keGNdNmMg]WOHLkQgfFnILkY_VFnKJiY_Vf]jJgaWNemLGc]SG5/LGc`2Fa`015KlFaaFo5/L
0UKl03]Bo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_`005KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]ao
o`0000Moo`03001oogoo00ioo`008Woo00<007ooOol07Woo00<007ooOol0@goo0U;m00=C7E;m0000
0P0000=BoE<MD_d025<M00eG7ELLEaeG7ELmEaaG?E/lGceK?5llFcaSG003Ge`00f]kIg]_VP03KiX2
LiT03W>iMkMg^7NgNkIg]W^fNkAk/g^CNk=kTW^cNi<2Ni83Ni403g^BNk9g/g^cMkAk/gNcNkEg]7^e
KkUc^VnjKi][VP02Ji/01VMlIg]WNfMkGcaK709K?007GcaK75LLEaaK75KlEa`00UKl00ABo5KlE_aF
o0=Bo003E_aBo5;l00QBo003001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`2Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool0
029oo`03001oogoo01moo`03001oogoo03moo`05Dae>o5<MC_aC7@020000FTklDaeBo5<MC_aC7E;l
DaeBo5LMD_aG7E;lEaeBo5/mEaaK?ELLFceG75/mFcaOGE/lHeaOG6=LGcaSG5mLKiY[NVnKKiYc^G>I
LkUgUgNhMiMg^7NfNkIgUW^eNi=k/g^ANkEkTg^cNi9k/W^ANk9gTG^bMk=k/gNANk9g/g^cMkAkeGNf
NmMg]VnKJiY_VfMkJgaWNfMlIg]SO6=KGcaK75llFaaO?5/LEaaFo5LLE_aG709Fo00jD_aFo5;lE_aB
o5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0008Ool00`00Oomoo`0<
Ool0029oo`03001oogoo021oo`03001oogoo03aoo`04D_eC7DkmD_d30002D_d00e<MD_eC7@02Dad0
0e;mDaeC7@06Dad02eLMDaeG?ELLEceG7ELmEaaG?EmLHe`00emL00ISG5mLIgaSG6MlHe/2LiT01W>i
LiUg^7NgMkQg]P9k]P09NkEkTg^cNk=k]G^CNk=kTW^b00=kT@0ANk9kTW^ANi5k/WNcNk=g]7^eMkAg
eWNfMmQc^7NhIg]WO002Ig/4He`015/lGcaK75/l0e/L00=G75KlEa`015Kl00ABo5KlD_aFo0=Bo003
E_aBo5;l00IBo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l0Woo00<007ooOol01Woo00<007ooOol02goo000Q
Ool2000SOol00`00Oomoo`0hOol014klDae>o5<M0`0005]C7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC
7E;lEaeBo5LMDaaG7E;lEaeC75/mEaaK?ELLFceG75/mGeaSG5llHeaSFfMlHe]WO6=KJg]WNf^KIg]g
^7NGMkQgUg^fMiIk]W^DNkIgUW^fNiAk/g^CNk9kTW^bMi5k/WNANk9gTG^bMi5k/gNBNmEg]7_GMkIk
eg>hMmQ_VG>jKiUSG6=KHgaSFf=LHe]SO5LLFaaG75/lEaaK7002Ea`0?E;lEaaBo5LLD_aFo5;lE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L009oo`05001oogooOol0
0003Ool00`00Oomoo`0;Ool0025oo`03001oogoo02=oo`03001oogoo039oo`06C_eBoE;mDae>oE;m
0`000U;m00YC7DkmDaeBoE<MD_eC7E;mDaeBo@=C7@0ID_eC7E<MEaeC7ELMDaeG7E<MEaeC7E/mFcaK
?E/lFceK?5/mFcaWO6=KIgaSG6MlHe/00f]k00=WNfnJKiX00VnJ0g^f00Ag]g^fNkIk]P9k]09k/`04
Ni9kTG^ANk43Ni403W^aNi9k/g^cNkEg]7OFMkIgeg>hMkQ_^W>jKkT2Ji/4He`3Gc`4Fa`00eLLFaaG
7005E_`00e;lE_aBo002D_`01EKlD_aBo5;lE_`025;l00EBg000D_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`20004Ool3
000>Ool0025oo`03001oogoo02Aoo`03001oogoo02moo`05Dae>oE<MC_aC7@030000Y5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklEaeBo5<MD_aG7E;lEaeBo5LMDaaG7E;lEceG75/mEaaK?E/l
FceG75mMFcaWO6=KIgaSFf]kIg][VfMkKiY[NVnKKiYc^G>ILkUgUgNhMiIk]WNfNkEkTgncNi9k/WNA
Nk9kTW^bMi5k/WNANk9gTW^cMkAkegNfNmMc^7OHLkQc^VnIKi][NVnKJiY_VelkHeaO?5mLGc]SG5Kl
FaaFo5/LE_aK75;lEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg7oo000DOol0025oo`03001oogoo02Eoo`03001oogoo02]oo`9Bo@03Dae>
oE;m00<0009Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG
7E<M00=G7@0=EaaG7ELMFceK?5/mFcaO?E/lGcaK?6MlHe/00f]k00=WNf]kKiX00VnJ0W>I00=c^G>I
MkP00W^f00Eg]W^dNkAk/g^C009kTP07Ni5kTW^ANi5k/G^ANk800W^c00Eg]7^eMkIgegNf009g^009
LkY_^G>jJi]_Vf^JJi]WNfMl00AO?004FaaK?5LLFa`3Ea`00e/LD_aFo002E_`3D_`01EKlD_aBo5;l
E_`025;l00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo00004goo000QOol00`00Oomoo`0VOol0
0`00Oomoo`0XOol014kmDae>o5<M0`0003EC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMD_aG7E<LEceG75LMDaaG?ELLGeeK?5mMFcaOGE/lGeeK?6]k
Ig][VfMkJg][NVnK009_VP0/LiUc^G>IMkQgUg^fMkIk]W^DOk=kTg^bNi9k/W^CNk9gTG^bMi5k/WNA
Nk=g/g_EMkIkegNfMmQc^7>jKiUc^V]jKi][VVnKIg][O6MkIgaK75llFaaO?09K7016E_aK75KlEaaF
o5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo7oo000COol0025oo`8002Qoo`8002Eoo`03D_eC7Dkm009Bo@80009Bo@06Dae>oE;mD_eC
7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d6Dad00eLMEaaG7@02Ead0
2ELLEceG7ElmFcaO?5/lGceK?002Ge`00f]kIg][N`04KiX03g>ILkUcVG>IMkMk]WNfNkIk]7^eNi=k
/g^BNk9kT`02Ni83Ni403g^BNk=g/g^bNi9k/gNcNkEg]7OFMkIgeV^KKi][VP02Ig/00fMlIg]WN`02
He`045/LFcaK?5llFaaG75KlEaaFo5LLE_aG75;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aB
o5;L00=Bo005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo000BOol0025oo`03001oogoo02Uoo`03001oogoo021o
o`04Dae>o5<MC_d30000>4kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<M
C_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7E;lEaeC75LmEaaK?ELLFceG75mMFcaOGEmLHeaO?6=L
GeaSG6]jKi/2KiX0<7>ILkUcVG>iMiMg^7NfNkIgUW^eNiAk/g^BNk9kU7^cNi9k/W^ANk9gTG^bMi5k
/WNANk=g/g^cMkAkeGNfNmMc^7OILkQWO6MkJgaWNf=LHe]SO6=KGcaK75llEaaK709G7015E_aG75Kl
EaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l001Fo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo000019oo`0087oo00<007ooOol0:goo00<007ooOol077oo00AC7DkmD_eBo@<00003
D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<M
D_eC7E;m2U<M00UG?ELLEceG7ELmEaaG?ELMHe`00emL00USG5mLGeaSG6MlHe]WO7>ILkT00W>I00=g
]gNhMkH00W^f00Uk]G^dNk=k/g^eNkAk/g^BNk800g^A00ik/W^ANi5kTW^bMk=k/gNdNkEg]WOFMkIg
f7>h0g>j1f=L1U/L1eKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg002D_`00`00
D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00=Bg7oo00004Goo000POol00`00Oomoo`0/Ool00`00Oomoo`0FOol01U<MC_eC
7DklDae>o@<0002iC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E<LFceG75/mEaaK?ELLFceK?6=L
GcaSG5mLHeaSFfMlHe]WO6MkJi]cVG>iLiUg^7NGNkIgUW^fNiAk]GNFNkIkU7^eNi=k/W^BNk9gTG^b
Ni5k/WNANk9g/g^cMi9keGNfNmMg]WOILkQc^VnILkY[VVnKHe]SO6=KHeaO>f=LGcaK75LLFcaFo5/L
E_aG75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LOol0000@Ool0021oo`03001oo`0002eoo`03001oogoo01=oo`03D_eC
7Dkm009Bo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m0e<M00=BoE<MDad00U<M01EG7E<MEaeC7ELMDaeG?ELL
EceK?5/mFcaK?E/lHeaOG6MlHeaWO6=KIg`00V]k00EWNf]kJg]g^7Ng00=k]P04MkMg^7^fNkH2Nk@2
Nk<01G^BNi5kTG^aNi800W^A00]k/G^BNk=k/g^eMkIgeWNfMmQc^7Nh009c^P04JiY[Vf^KKi/7Gc`0
1E/LEaaG75LLFa`015Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg002D_`00`00
D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l0P0047oo000POol2000_Ool00`00Oomoo`0?Ool01DkmDae>o5<MC_d00`0007A>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aC7E;lEaeC75LMD_aG7E<LFceG75/mFcaK?ELLFceK
?6MlHe]WO6=KIgaWNf^KIg][NfMkKi]_VW>iLiUc^GNGMkQgUg^fMkIk]G^DOk=kTW^bMi5k/W^BNk9g
TG^bMi5k/WNBNmEg]7_GMkIkeg>hMmQ_VG>jJiY_Vf^JKi]WNfMlGc]SG5llGeaK75ll0U/L04YFo5/L
E_aK75;lEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aoo`003goo0005Ool50005Ool20005Ool40006Ool00`00Oomoo`0_
Ool00`00Oomoo`0<Ool015<MC_eBoE;m0`0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m
0e<M00=BoE<MDad00U<M00AG7E<MEaeG709G7@0;FceK?5/mFcaK?E/lGcaK?6MlHe]WO002Jg/00fMk
Jg][N`02KiX2LiT01W>iLiUg^7NgNkIg]P9k]005Nk=kTg^BNi9k/`02Ni8017^ANk5kTG^b0W^c00Ig
]7OFMkIgeW>hMkP2LkX016^JJi][VfnK0fMk00IWO6MkFcaK?5llFa`2Fc`01ULLE_aG75KlEaaBo0=F
o004D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`2Ool00`00Oomo
o`0<Ool000Aoo`800005Ool00000Ool00004Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`0`Ool00`00Oomoo`08Ool01E<MC_aC7DkmDad00P0004a>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG7E;lDaeC75LmEaaG7E<LEceG75LMFcaOGE/lGeeK?5mMFcaO
GFMkJi]WNf]kJgY_V`9_VP0^LiUc^G>IMkQgUgNhMkIk]W^DNkEkTg^bNi9k/W^BNk9gTG^bMi5k/WNA
Nk=gTG^bMi9k/gNdNmEg]W_GLkQgf6^JKi]WNfMlIg][O6MkHeaSFellFaaO?5LLFc`2Ea`015KlEaaF
o5LL0UKl04=Bo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l
D]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LOol0000>Ool000Aoo`80009oo`03001oo`0000moo`03001oogoo00=o
o`03001oogoo035oo`03001oogoo00Eoo`04C_eBoE;mDad300001U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03
D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7ELL00=G7@0>EaaG7ELMEceK?5llFcaO
?E/lGcaOG6=LIg][N`A_VP0?LiUc^G>IMkQg]gNhMkIk]W^dNkEkTg^cNi9k/W^C00=kTP9kT@04Ni9k
/g^ANk82Nk<01GNcNkEg]7OFMkH00WNh00Egf6MkIg]WNfMl00ESG0EK7004E_aG75KlEa`4E_`01U;l
E_aBo5KlD_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo00ao
o`0017oo0P000Woo00<007oo00003goo00<007ooOol00Woo0P00=7oo00P007ooOomoodklDae>oE<M
0`0004mC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeB
o5LMD_aG7E<LEceG75/mEaaK?ELLFceK?5mMFcaSG5llHeaOG6=LJgY_V`02KiX0OG>ILkUcVGNhMiMg
^7NGNkIgUW^eNiAk/g^BNk9kU7^cNi9k/W^ANk9gTG^bMi5k/WNANk=g/g_EMkAkegNfMmQc^7OIKiUc
^VnIHgaSFf=LHe]SO6=KGeaO>e/lEaaK75LLFcaBo5LLD_aG75;lEaaBo5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo0000
37oo0004Ool20002Ool00`00Ool0000;Ool40005Ool00`00Oomoo`0bOol00e;mDae>o@02D_d01U<M
00000000Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m
2e<M00QG75LmEaeG?ELLEceG7ELm0emL00USG5mLGeaSG6MlHe]WO7>ILkT00W>I00=g]gNhMkL00W^f
00Uk]G^dNk=k/g^eNkAk/g^BNk800g^A00Yk/W^ANi5kTW^cMk=k/gNdMmIg]P9g^006MmQ_^G>jLkY_
Vf^J0f=L15ll15/L0ULL1UKl0e;l00EFo5;lD_aBo5Kl00aBo005D]aBo5;lD_aBg003D_`01E;L001B
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QB
g5;lD_aBo5;LD_aoo`0037oo0003Ool300001Goo000007oo00002goo00<007ooOol01Woo00<007oo
Ool0<7oo00EC7DklDae>oE<M00<0003EDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMEaaK?ELLFceG75/mFcaK?Ell
HeaOG6=LHe]WO6=KIgaWNf^KIg][NgNGMkQgUgNhMiIk]W^DNkEgUW^fNiAk]G^CNk9kTW^bMi5k/W^A
Nk9gTG^bMk=k/gNdNmMg]W_GLkQgfG>hLkY_VFnKJiY_Vf^JHeaO?5mLGc]SG5llGeaFo5/LE_aK75Kl
FaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`0000]oo`001Goo00<007ooOol00Woo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol0;Goo00EC7DkmD_eBoE<M00<00006Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE;mD_eC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02
Dad05ELMDaeG7E<MEaeC7ELmEaaG?E/lFceK?5/mFcaSG5mLIgaSG6MlHe]WO002Jg/00fMkJg]_VP03
KiX2NkH017NgMkQk]W^f0W^d00=kTg^cNi800W^A00ik/G^BNi5kTG^bMk=k/gNdNkEg]WOFMkQgf7>h
0W>j00I_Vf^JJi][VfMlIg/4Gc`2Fc`00ellEaaG7002Ea`01EKlEaaFo5KlD_`00eKl0e;l00=Fo5;l
D_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L001Bo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;lD_aBo5;LD_`2000:
Ool000Ioo`@000aoo`D000Aoo`03001oogoo02]oo`04C_aC7DkmDad30000g5<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LM
D_aC7E;lEaeC75LMD_aG7E<LFceG75/mFcaK?ELLFceK?6MlHe]WO6=KIgaWNf^KIg][Nf]jKi]_NVnJ
LiUc^GNGMkQgUg^fMiIk]G^DOk=kTW^bMi5k/W^BNk9gTG^bMi5k/gNBNmEg/g^cMkAkeGNdLkY_VFnK
JiY_VfMkJgaWNfMlIg]O?5/LGcaK75llFaaO?5KlEaaFo5LLE_aG75;lE_aBo5KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aoo`002Woo000OOol00`00Oomoo`0XOol01DkmD_eBoE<MC_d00P0000IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<M
D_d3Dad00e;mDaeC7@02Dad015LMDaeG7ELL0ULM00]K?E/lFceK?5/mFcaO?5/lIgaSFfMl009[N`03
Ig][Nf]k00=_VP07LiUc^G>IMkQg]g^fMkH00W^d00Ek/g^CNi9kTG^c009kTP03Ni5k/G^B009k/`0=
Nk9kTW^cNk=k]GNdMmIg]WOHLkQg^6MkIg`00fMk0V=L0U/l00=O?5/LFa`00U/L00AFo5LLE_aG709F
o006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L008000Uoo`007Woo0P009Goo00M>oE<MC_aC7DkmDae>o0030000hTkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5<MDaaG?ELLEaeC75LmEaaG7E/lGeeK?5mMFcaOGE/l
GeeWNf^KIg][NfMkKi]_NVnJJgYc^G>IMkQgUgNhMiIk]W^DNkEkTg^cNi9o/g^BNk9gTG^bMi5k/WNA
Nk9gTG^cMi9keGNdNmEg]W_GLkQgf6nILkYWNfMlHe]SO6=KHeaSFe/lEaaK75LLFcaG75/LD_aG75;l
EaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`002Goo000NOol00`00Oomoo`0ROol01U<MC_eBoE;m
Dae>o@<00005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG7003
Ead03ELLEaeG7ELmFcaO?5/lGcaK?5llGeaSG6Mk009[N`A_VP0>LkUcVGNhMkMg^7NfNkIk]7^eNi=k
/g^BNkEkT`=kTP=kT@03Nk5kTW^b009k/`06MkAk]7NfMmIc^7Nh0W>j00=_^G>jHe`00f=L0ell15/L
0ULL00=K75KlE_`00eKl0U;l00EFo5;lD_aBo5Kl00=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00009Ool001ioo`03001oogoo021oo`05C_aC
7DkmDae>o0030000hdklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMD_aG
7E<LEceG75/mEaaK?ELLFceK?5mMFcaSG5llHeaOG6=LGca_VfmjKiY[NW>iLiUg^7NGMkQgUW^fMiIk
]G^DNk=kTg^eNi=k/g^BNk9kTG^bMi5k/WNANk9gTW^cMkAkeGNfNmMc^7OHLkQc^VnILkY[VVnKJiYO
G5lkHeaO?5mLGc]K75KlFaaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`017oo00<007ooOol0
1goo000NOol00`00Oomoo`0NOol2D_d00e<MC_d0000200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;m
Dad00e;m00IC7E;mD_eBoE<MD_d3Dad00e;mDaeC7@05Dad025LLEceG7ELmEaaG?ELMEcd3Ge`02F=L
GeaOG5mLIgaSFfMlHeac^@02LiT00gNgMkQg]`02NkH02G^eNkAk]W^fNkEk]7^cNi9k/P03Ni402W^B
Ni5k/W^BNk=g/g^dMkIgeWNf0WNh00Ic^VniLkY[VfnKJiX2Ig/3Gc`00e/lGcaK7002Ea`01U/LEaaG
75LLE_aBo0=Fo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo0Moo`03001oogoo00Ioo`007Woo00<007ooOol06goo00AC7DkmDae>o0<0002R
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LM
DaaG7ELLFceG75/mEaaK?E/lFceO?6=LGeaSG6=KIgaSFfMlHe][VfMkJg]gUgNhMiMk]WNFNkIgUg^f
MiIk]W^DNk=kTg^bNi5k/WNANk9kTG^bMi5k/gNcNmEg]7_GMkIgf7>hLkY_VG>jJiY_Vf^JIgaWNf]l
Ig]O?5/LGcaK75llFaaO?5KlEaaFo5LL0UKl041Bo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo0Yoo`03001oogoo00Ioo`007Goo0P00
67oo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;m
D_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@0JD_eG7E<MEaeC7ELMDaeG7E<MFceK?5/mFcaK?E/lFceK
?6MlHeaWO6=KIgaSG6]kIg][N`=_VP9cV@03LkUgUgNh009k]P9k]003Ni=k/W^B009kT@0BNk9kTG^A
Ni5k/WNcNk=g]7^cMk=k]7NdMmIg]WOFJi]_Vf^J0VMk00IWO6MkHeaSG5llFa`2Fc`3Fa`015KlEaaF
o5LL0UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0U;l3Woo00<007ooOol01Woo000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@80002TC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;l
EaeC75LMD_aG7ELLEaeC75/mFcaK?ELLFceK?5mMFcaWO6=KIgaWNf^KIg][Nf]jKi]_NW>iLiUc^G>I
MkQgUW^fMiIk]G^COk=kTW^bMi5o/g^BNk9gTG^bMk=k/gNANk9g/W^cMkAkeGNfNmMc^7OILkQWO6Mk
JgaSFf=LHe]SO6=KFaaG75/lEaaK709G700kE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg00COol00`00Oomoo`06Ool001eoo`03001oogoo01=oo`9B
o@03Dae>oE;m00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC
7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7ELL00=G7@0:EaaK?E/lFceK?5ll
FcaO?5/lGc`2Jg/00fMkJg]_VP03KiX01g>ILkUcVGNhMkMk]WNf009k]006Nk=kTg^BNi=k/g^B0W^A
00ik/G^BNi5kTG^bMk=k/gNdNkEg]WOFMkQgf7>h0g>j1F=L0Ull1U/L1eKl0e;l00EFo5;lD_aBo5Kl
00QBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l
00IBg5;lD_aBo5;LD_`EOol00`00Oomoo`06Ool001eoo`03001oogoo015oo`04C_eC7DklDad30000
hU<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG75LMDaaG?ELLEaeC75mMFcaOGE/lGeeK?5mMGcaSG6MkJg][
NVnKKgY_VW>ILkUcVGNhMiMk]WNFNkIkU7ncNi=k/W^DOk=kTg^bMi5k/WNANk9gTG^bMi5k/gNBNmEg
]W_GMkIgfG>hLkY_VG>jJiY_Vf=KHgaO?5mLGc]SG5llFaaFo5/LE_aK75KlEaaBo5LLD_aG75;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;L5goo00<007ooOol01Woo000MOol2000?Ool0
15;mDae>oE;m0`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01E<MC_eBoE;mDad00e;m00QC7E;mDaeBoE<MD_eC7E;m1e<M0ULM00UG75LMEaeG?ELLGcaK
?5llFc`00UmL00=SG5mLGe`016nJ019cVG>iLiUg^7NgMkQg]W^fNkAk]G^CNk=k]7^cNi=kTW^ANi83
Ni402g^aNi9k/g^cNkEg]WOFMkIgf7>hMkP00W>j00A[VV^KJi]_V`EO?09K?006FaaG75LLEaaK75LL
0eKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]`005;lD_aBg00LOol00`00Oomoo`06Ool001eoo`03001oogoo00Uo
o`06C_aC7DkmDae>o5<M0`000>5C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMD_aG7ELL
FceG75/mEaaK?ELLFceOG6=LGcaSG5mLHeaSFfMlHe]WO7>ILkUcVG>iMiMg^7NFNkIgUW^eNi=k/g^D
NkEkTg^cNi9k/W^ANk9gTG^bMi5k/WNBNmEg]7_GMkIgfG>hMmQ_VG>jJiY_Vf^JKi]WNfMlGc]SG5/L
GcaK75llE_aK75KlFaaFo5LLE_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo00007goo00<007oo
Ool01Goo000MOol00`00Oomoo`07Ool2D_d00e<MC_eBo@030002D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M
00=Bo@03DaeBoE<M009C7@03D_eC7E<M00AC7@0=EaeC7ELMEaeG?ELLEceG7ELmFcaK?EmLHe`00UmL
00ASG6MlHe]WO09[N`05Ig][NgNgMkQgU`02NkH01g^eNkAk]W^fNkEk]7^c009kTP=kT@03Ni9kTG^b
009k/`06MkAk/g^cNkEg]7^d0W>j00A[VV^KJi]WO0=WN`0=IgaK75/lFcaO?5/LFcaFo5LLE_aG75Kl
Ea`00UKl00IBo5KlD_aFo5;lE_`8D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`00e;LOomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`05Ool001eoo`03001oogoo
00Eoo`04C_eC7DklDad30000h5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG
7E;lEaeC75LMD_aG7ELLFceG75/mFaaK?ELLHeaOG6MlHe]WO6=KIgaWNf^KIg][Nf]jKi]_NW>iLiUg
^7NGMkQgUW^eNiAk/g^CNk9kTG^bNi9k/WNANk9gTG^cMi5k/WNBNk=g]7_EMkIkeg>hMmQc^6]lIg]W
O6MkHgaSFf=LHe]K?5LLFaaG75/lE_aG75KlEaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`8Ool00`00Oomoo`0K
Ool00`00Oomoo`05Ool001eoo`04001oogooC_d2D_d015<MC_eBoE;m0P000U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00YC7DkmDaeBoE<MD_eC7E;mDaeBo@=C7@0FD_eC7E<MEaeC7ELMDaeG7E<MEaeK
?5/mFcaK?E/lFceK?6MlHeaWO6=KIg`2Jg/00fMkJg]_VP02KiX2LiT00g>iMiMg^002NkH2Nk@01W^C
Nk9kTG^ANi=k/P9kT@04Ni9k/g^ANk82Nk<01GNdNkAg]7OFMkH00WNh00=c^VniLkX01F=L0Ull1E/L
1UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
37oo00<007ooOol06goo00<007ooOol01Goo000LOol02000OomC7DkmDae>o5<MC_d30000gDkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeBo5LMD_aG7E<LEaeC
75LmFaaK?ELLFceK?5mMFcaWO6=KIgaWNf^KIg][Nf]jKi]_NW>iLiUc^GNGMkQgUg^fNiAk]G^COk=k
TW^cNi=k/W^ANk9gTG^bMi5k/WNANk=g/W_EMkAkegNfMmQc^7>jKkUc^V^JKi]SFf=LGc]SG5llGeaG
75/lEaaK75KlFaaBo5LLD_aG75;lEaaBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`04Goo00<007ooOol06Woo00<007ooOol01Goo000LOol00`00Dae>o@02
D_d300000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MD_eBoE;mDaeBoE<MD_eC
7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMEa`00eLM00YG75LMEaeO?5/lGcaK?5llFcaO?09[N`03Ig][
NfnJ00=_VP07LiUc^G>IMkQg]g^fMkH00W^d00Ik/g^BNkAkTg^cNi82Ni402W^bNi5kTG^BNk=g/g^d
MkAgeWNf0WNh00Mgf6niLkY[VfnKJiY[V`06Gc`3Ea`00e/LEaaG7002E_`015;lE_aFo5Kl0e;l00=F
o5;lD_`02U;l00EBg5;lD_aBo5;L01Moo`03001oogoo01Uoo`03001oogoo00Eoo`004Woo1@001Goo
00<004km00000P000=a>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;l
Dae>o5<MD_aC7E;lEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LFceG75mMFcaOGE/lGeeO?6=LGeaSG6]j
Ki]_NVnJLiUc^G>IMkQgUgNhMiIk]G^DNkEkTg^eNi=o/g^BNk9gTG^bNi5k/WNANk9g/W^cMkAkeGNf
NmMc^7OIKkUc^V^JKi][VVnKIg][O5llGeaO>ellFaaO?5KlFaaFo5LLE_aG75;lE_aBo5LLD_aFo5;L
E_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo1Yoo`03001oogoo01Qoo`03001oogoo00Eo
o`0057oo00<007ooOol01Goo0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@QC7@0:EaeG75LMEaeG?ELLEceK
?5llFc`2Ge`01F=LGeaOG6=LIg`00VnJ00]cVG>iLiUg^7NgMkQg]W^fNkAk]G^C009k]006Nk=kTg^B
Ni5k/G^B0W^A00ik/WNcNk=g]7^eMkIgeWNhMmQ_^G>jJi]_Vf^J0VMk00IWO6MkIg]K?5llFa`2Fc`0
3EllE_aG75KlEaaFo5LLD_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l00IBo003D]aBo5;l01aoo`03001o
ogoo01Uoo`03001oogoo00Aoo`0057oo00<007ooOol01Woo0=X007ooC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E;l
FceG75/mEaaK?ELLFceOG6=LGcaSG5mLHeaSFfMlHe]WO7>ILkUcVG>iMiMg^7NGNkIkU7^eNiAk]W^D
Ok=kTg^bNi9k/W^BNk9gTG^bMi5k/gNBNmEgTG^cMkAkeGNfNmMc^7OILkQWO6MkJgaWNf=LHe]SO5/L
GcaK75/lEaaK75KlEaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl8Goo00<0
07ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07Ool200000e;mDae>o@02D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE;mD_eC7E;m0e<M01YBoE<MDaeC
7E;mEaeC7ELMDaeG7E<MEceG75LmEaeK?E/lFceOG6=LGeaWO6=LIgaSFfMl0V]k01EWNf]kMkMg^7NG
LiUg]gNhMiMk]W^dNkEkTg^cNi9k/W^CNi9kTG^aNi800W^c00Yk/WNBNk=k/g^eMkAgeWNfMmQc^0=c
^PISG0IK70IFo003D_aFo5;l009Bo006E_aBo5;lD_aFo5;l9Woo00<007ooOol05goo00<007ooOol0
17oo000DOol00`00Oomoo`09Ool0d@00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LFceG75/mFaaK?ELLFceK76Ml
He]WO6=KIgaWNf^KIg][Nf]jKi]_NW>iLiUg^7NGMkQgUW^eNiAk/g^BNk9kTG^bNi9k/WNANk9gTG^b
Mi5k/WNBNmEg]7_GMkIgfG>hLkY_VG>jJiY_Vf=KHgaSFemLGc]SG5LLFaaG75/LE_aK75;lEaaBo5LL
D_aFo5;lE_aBg5KlD]aFo5;LE_`0:7oo00<007ooOol05goo00<007ooOol017oo000DOol00`00Oomo
o`0:Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06
DaeBoE<MD_eC7E;m0e<M00UBoE<MDaeC7E;mEaeC7ELMEa`00ULM00]K?E/lFceK?5/mFcaO?5/lIgaS
FfMl009[N`03Ig][NfnJ009_VP9cV@0;MkQgUgNhNkIk]G^dNk=kTg^bNi9k/`02Ni801W^ANk9kTG^a
Mi9k/P9k/`06MkAk]7NfMmQc^7Nh0W>j00A[VV^KJi]_V`IO?003EaaK75LL009G7003FaaBo5Kl009F
o0=Bo003E_aBo5;l02aoo`03001oogoo01Ioo`03001oogoo00Aoo`004Woo0`003Goo0;T007ooDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lDaeB
o5LmEaaG7E<LEceG75/mEaaK?E/lGeeK?5mMFcaOGFMkJi]WNf]kJgY_VfmjKiYcVG>iMiMg^7NGNkIk
U7^eNi=k/W^BNkEkTW^bNi5k/WNANk9gTG^bMi5k/gNdNmEg]W_GLkQgf6nILkY[VVnKJiY_VfMkIgaO
>f=L009O?00=FaaO?5KlFaaFo5LLE_aG75;lEaaBo5KlD_`0<Goo00<007ooOol05Goo00<007ooOol0
17oo000DOol00`00Oomoo`0<Ool200001WooC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad0
0e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@=G7@0>EaaG7ELMGcaK?5llFcaO
?5/lGcaOG6=LIg][N`A_VP06LiUc^GNGMkQg]g^f0W^d00IkTg^cNkAk]G^CNk82Ni42Ni802W^ANk9k
TW^cMkAk]7NdMmIc^7Nh0W>j00A[VV^KJi]WO0=WN`0=IgaK75/lFcaO?5/LFcaFo5LLE_aG75KlEa`0
=Woo00<007ooOol057oo00<007ooOol017oo000UOol0^000Oom>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E;lEaeC75LmEaaG7ELLFceG75mMFcaOGE/l
HeaO?6=LGeaSG6]jKi]_NVnJLiUc^GNGMkQgUg^fMiIk]G^DNkIgUW^eNiAk/W^BNk9gTG^bNi5k/WNA
Nk9g/W_EMkAk/gNbNmEg]W_GLkQgf7>hJgaWNfMlIg]SO6=KHeaK75ll0U/L00EG75/lE_aG75Kl03Qo
o`03001oogoo01Eoo`03001oogoo00=oo`009Woo00<007ooOol00U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@03DaeBoE<M009C7@03D_eC7E<M00EC7@08EaaG?ELMEceG75Lm
EaeG?@=OG00EHeaOG5mLHeaWO6=KIgacVG>iLiUg^7NgMkQg]WNhMkMk]WNfNkEk]7^c009kTP03Ni5k
/W^A009kT@0:Nk9g/g^bNi9k/gNcNkAg]7OFMkH2MkP00g>jKkUc^P06He`6Fa`kOol00`00Oomoo`0D
Ool00`00Oomoo`03Ool002Moo`2g001oogooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDaeBo5<MD_aG7E;lEaeBo5LMDaaG7ELLFceG75/mEaaK?E/LFceO?6=LGeaWO6=KIgaSFfMlIg][
VfMkMkQgUgNhLiUg^7NGMkQgUW^fNiAk]G^BNk9gTGndNi9k/WNANk9gTG^bMi5k/WNbNk=g]7_GMkIg
f7>hLkY_^G>jJiY_Vf=KHeaSFf=LGcaOG5lk041oo`03001oogoo01=oo`03001oogoo00=oo`00:7oo
0P0000Eooe;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDae>oE<MD_eC7E;mDaeBoE<MD_d3Dad0
5U;mEaeC7ELMDaeG7E<MEaeC7E/mFcaK?E/lFceK?5/mHe]WO6=LIgaSFfMl0V]k00AWNfnJKiY_VP9c
V@07MkMg^7NfNkIk]7^eNi<00W^B00ik/g^BNi5kTG^aMi9kTG^BNk9g/g^cMkAk]GNf0WNh00Mgf6ni
LkY[VfnKJiY[V`04Gca3Ool00`00Oomoo`0BOol00`00Oomoo`03Ool002Yoo`2`001ooe<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeC75LMD_aG7ELLEaeC75/mFaaK?ELL
FceK?5mMHe]WO6=KJg]WNf^KIg]_VV]jKi]cVG>iMiMg^7NGNkIgUW^eNiAk/W^BNkEkTg^bMi5k/WNA
Nk9gTG^bMi5k/gNBNmEg]W_GLkQgfFniLkY[VVnKJiY_VfMkJgaWNdEoo`03001oogoo019oo`03001o
ogoo00=oo`00:goo00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<M
D_eC7E;m0e<M00EBoE<MEaeG7ELL00=G7@09EaaK?E/lGcaK?5llFcaO?5/l00=[N`03Ig]_VVnJ009_
VP9cV@0;MkQgUg^fNkIk]G^dNk=k]7^eNi=k/`02Ni83Ni403W^bMi9k/g^cNkEg]7OFMkQgf6niLkY[
VfnKJiX2Ig/00fMlIg]oo`16Ool00`00Oomoo`0AOol00`00Oomoo`03Ool002aoo`2[001ooe<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeG75LMDaaG?ELLEaeC75mMFcaO
GE/lGeeK?6=LGcaSG5mLKiY[NVnKKgYc^G>IMkQgUg^fMiIk]W^DNkEgUW^eNiAk/g^BNk9gTG^bMi5k
/WNANk9gTW^cMkAk/gNBNmEg]W_GLkQgfG>hIgaWNf]l04Yoo`03001oogoo011oo`03001oogoo00=o
o`00;Goo0P000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d7Dad2Ead0
25LLEaeG7ELmEaaO?5/lGc`3Ge`016=LGeaWO6=L0VnJ0W>I00=c^GNGMkP00W^f00ik]7^eNkIk]G^d
Nk=kTg^bNi5kTW^ANk5kTG^b0W^c00UgTW^bNk=k]GNdMmIg]WOHLkP00g>jC7oo00<007ooOol047oo
00<007ooOol00Woo000_Ool0YP00Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeB
o5LMD_aG7ELLFceG75/mEaaK?ELLHeaOG6=LGcaSG5mLIgaSFfMlHe]c^G>ILkUgUgNhMiIk]WNFMkQg
Ug^fNiAk]G^CNk9kTW^cNi9k/WNANk9gTG^cMi5k/WNBNk=g]7_GMkIgfG>hLkY_VG>jCGoo00<007oo
Ool047oo00<007ooOol00Woo000`Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE;mD_eC7E;m
0e<M00=BoE<MDad00U<M00AG7E<MEaeC7@9G7@06EceG75LmFcaK?E/l0UmL00ISG6=KIgaSG6MlHe/3
Jg/2KiX03W>ILkUcVGNhMkMk]W^dNkEkTg^cNi9kTG^BNk82Ni4037^BNk5kTG^bNi9k/gNdMmIg]WOH
LkQg^09c^Tmoo`03001oogoo00moo`03001oogoo009oo`00<Goo0:8007ooOomC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5<MD_aG7E;lDaeBo5LMDaaG7E;lEaeC75/mEaaK?E/LFceG75/mHe]WO6=KIgaSFf]kIg][
VfmjKiY[NW>iLiUc^GNGMkQgUW^eNiAo]7^CNk9kTg^bNi5k/WNANk9gTG^bMi5k/gNbNmEg]W_GLkQg
f6nILkYAOol00`00Oomoo`0>Ool00`00Oomoo`02Ool0039oo`05001oogooDae>o@02D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d0
1U<MD_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@04EaeC7ELMEa`2Ead02U/mFcaK?E/lGcaK?5llHeaW
O6=K0f]k0fnJ00ic^G>ILiUg]gNhMkIk]G^dNk=kTg^BNkAk/g^B0W^A00]kTW^ANi5kTW^bMk=k]7Nf
MmIc^7Nh009c^U9oo`03001oogoo00ioo`03001oogoo009oo`00<goo0P0009aooe<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MC_aG7E;lDaeBo5LMD_aC7E<LEceG75LMDaaG?ELLGeeK?5mMFcaOGE/lGeeK?6]kIg][VfmjKiY[
NW>iLiUc^GNGMkQgUg^fNiAk]G^CNk=kU7ndNi9k/WNANk9kTG^bMi5k/WNbNk=gTG^cMk9keGNfNmMD
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool003Eoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;m
DaeBo@=C7@05D_eC7E<MDaeG7003Ead02ELLEceG7EllFcaO?5/lGcaK?002Ge`00f=LKiY_VP02KiX2
LiT03WNgMkQgUg^fNkAk]GNfNkIk]7^eNi=kTW^ANk83Ni402G^bMi9k/g^BNk=g/g^dMkAgeP1FOol0
0`00Oomoo`0<Ool00`00Oomoo`02Ool003Ioo`2J001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lEaeBo5LM
D_aG7E;lFceG75/mEaaK?ELLGeeK?5mMGeaSG5llHeaSFfMlHe]WO7>ILkUcVGNhMiMg^7NFMkQgUg^f
MiIk]G^CNk9kTWndNi9k/WNANk9gTG^cMi5k/WNbNk=g]7_GMkIGOol00`00Oomoo`0;Ool00`00Oomo
o`02Ool003Moo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d00e<MD_eC7@02Dad00e;mDaeC7@04Dad02ELMDaeG
?ELMEceG75LmEaeSG003Ge`01V=LHe]WO6=LIgaWN`9[N`06MkQgUgNhLiUg^7NG0W^f00=k]G^dNk<0
17^B00]kTG^aMi9k/W^ANk9g/g^cMkAgeWNf05Qoo`03001oogoo00aoo`03001oogoo005oo`00>7oo
0P0009AC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMD_aG7E<LEaeG75/mEaaK?ELLFceK76=LGcaWO6=KIgaS
FfMlIg][NfMkKi]_NVnJLiUc^GNGMkQgUW^fNiAk]G^CNk9kTg^bMi5k/WNANk9gTG^bMi5k/gNBNmEg
]UYoo`03001oogoo00]oo`03001oogoo005oo`00>Woo00<007ooC_d00U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eC7E;mDaeBoE<MD_eC7E;m0e<M
01EBoE<MDaeG7E<MEaeC7ELMFcaK?E/lFceK?5/mFcaWO6=KIgaSG6]kIg/00V]k0fnJ00AcVG>iMiMg
^09k]P06NkAk]G^CNk9k]7^c0W^B0g^A00Mk/GNANk=k/g^eMk=k/`1KOol00`00Oomoo`0:Ool00`00
Oomoo`01Ool003]oo`2B001oogooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeC75LMD_aG?ELLEaeG75/mFaaK?E/lGeeK
?5mMFca[VfMkJg]WNf^KKgY_VV]jLkUgUgNhMiMk]WNFNkEkU7ndNiAk/g^BNk9gTG^bMi5k/WNANk9g
TW^cMi5k/eeoo`03001oogoo00Uoo`03001oogoo005oo`00?7oo00<007ooOol00U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<M
D_d3Dad01E;mDaeG7ELMEa`00eLM00UG75llFcaO?5/lGcaK?6=LGe`00f]k0fnJ015c^GNGMkQg]g^f
MkIk]G^dNk=k]7^eNi=k/W^ANi9kTG^B009kT@9k/`03Mi5k/g^c05eoo`03001oogoo00Uoo`03001o
ogoo005oo`00?Goo0P0008eooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaG7E<LEceG75/mEaaOGE/lGeeO?6=LGeaS
G5llHea_NVnJJgYc^G>IMkQgUgNhMiIk]W^DNkEgUW^eNi=k/W^BNk=kTW^bNi5k/WNANk9gTG^bMi80
Ggoo00<007ooOol027oo00<007ooOol00Goo000oOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d9Dad01eLMEceG75LmEaeG
?ELL009OG00IHeaOG5mLGeaSG6=KIgaSG7>iLiUg^7NgMkQg]W^fMkMg^7NfNkEk]7^cNi9kTG^BNk80
0g^A00=kTW^ANk800W^cH7oo00<007ooOol01goo00<007ooOol00Goo0010Ool0R`00OomC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeB
o5LMD_aG7ELLFceG75/mFaaK?ELLHeaOG6=LGcaWO6=KIgaSFf^KIg]_VV]jKi]cVG>iMiMg^7NGNkIk
U7^eNi=k/W^CNk9kTG^bMi5k/WNANk9gTG^c069oo`03001oogoo00Moo`40005oo`5oo`00@Goo00H0
07ooOomBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;mDaeB
o@=C7@03D_eC7E<M009C7@0DEaeC7ELMDaeG7E<MFceK?5/mFcaK?E/lFceSG6MlHe]WO6=LJg]WN`=_
VP=cV@0:MkQgUg^fNkAk]G^CNi9k]7^cNi82Ni401W^aNi5kTG^BNk=g/f9oo`03001oogoo00Moo`40
005oo`5oo`00@Woo0P0008IoodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75LMDaaG?ELLFceG75/mFaaOGE/lGeeSFfMlIg][VfMkJg][
NVnKKgYc^G>IMkQgUgNhMiIk]G^DNk=kU7ndNi9k/WNANk9kTW^bMi5k/WNbI7oo00<007ooOol01Woo
0@000Goo0Goo0014Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03
D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG7003Ead02ULLEaeG7EllFcaO?5/lGcaK?5ll0V]k
00=WNf]kKiX00VnJ0g>I00egUgNhNkIk]G^dNk=k]W^eNi=kTW^ANk9kTP02Ni400g^bMk=kT@1UOol0
0`00Oomoo`05Ool10001Ool1Ool004Eoo`24001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E<LEceG75LMEaaK?ELLGeeK?5mMFcaSG5llHeaO
G6=LJgY_VfmjLkUcVG>iMiMg^7NFNkIkU7^eMiIk]G^CNk9kTWndNi9k/WNANk9gTG^bIWoo00<007oo
Ool01Goo0@000Goo0Goo0016Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;m
D_eC7@03D_d01U<MD_eC7E;mDaeBo@QC7@07EceG7ELmEaaG?ELMEcd00emL00ISG5mLGeaSG6MlHe/4
LiT01GNhMkMk]WNGMkP00W^f00=k]7^cNi800g^B00=kTG^aMi400W^AIgoo00<007ooOol017oo0@00
0Goo0Goo0017Ool20000OgooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<M
D_aC7E;lEaeBo5LMDaaG7E;lFceG75/mEaaK?E/LFceO?6=LGeaWO6=KIgaSFf]kIg][VfMkMkQgUg>i
MiMg^7NGNkIkU7^eNi=k/W^CNk9kTW^bMi5k/WNA06Uoo`03001oogoo00=oo`40005oo`5oo`00BGoo
00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M01EBoE<M
DaeG7E<MEaeC7ELMEaaG?ELMFceK?5/mFcaK?F=KIeaSG6MlHe/00f]k00=WNfnJKiX00W>I00mg^7Ng
NkIg]W^eNi=k/W^dNk=kTW^bNi5kTW^ANk40JWoo00<007ooOol00goo0@000Goo001:Ool0OP00OomC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aG7E;lDaeBo5LMDaaG7E;lEaeC75LMEaaK
?E/LFceG75/mFcaOGF=KIgaSFf]kIg][VfMkKiY[NW>iLiUg^7NGMkQgUW^eNiAo]7^DNk=kTW^bNi5k
/WNANk9gTFYoo`03001oogoo00=oo`40005oo`00Bgoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMEa`00eLM00UK?5/mFcaO?5/lGcaK?5ll
Fc`00f]k16nJ0W>I00ag]gNhMkIk]W^dNk=g]W^eNi=k/W^BNi42Ni800g^AOomoo`1ZOol00`00Oomo
o`02Ool10001Ool004aoo`80001iDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeB
o5<MD_aG7E;lEaeC75LmEaaG7E<LGeeK?5mMFcaOGE/lHeaO?6=LKgY_VV]jKi]cVG>iMiMg^7NFNkIk
U7^eMiIk]G^CNk9kTW^bNi=k/W^ANk80KGoo00D007ooOomoo`00005oo`00CWoo00<007ooC_d00U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@08DaeBoE;mD_eC7E;mDaeBo@MC7@9G7@08EaaG7ELMEceG75llFcaO?0=O
G005HeaSFfMLHeaWO003LiT02GNhMiMk]W^fMkQg]W^fNkAk/`02Ni8017^CNk9kTG^AKgoo00@007oo
Ool0005oo`00Cgoo07L007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;l
EaeG75/mEaaK?ELLFceG76=LGeaSG5llIgaSFfMlHe]WO6MkJg]WNgNhMiMc^G>IMkQgUg^fNiAo]7^C
Nk9kU7ndNi9k/WNA06moo`04001oogoo0001Ool0051oo`03001oodkm009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@06DaeBoE<MD_eC7E;m0e<M00EBoELMDaeG7E<M009G7@0>EceG75LmFcaK?E/lFceK?6MlHe]WG6=L
IgaWN`9[N`9_VP=cV@09MiMk]W^fNkEkTg^BNkAk/g^B009kT@03Nk9oogoo06ioo`03001oo`00005o
o`00DGoo0P00079>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LFceG
75/mFaaK?ELLGeeK?6MlHe][VfMkJg]WNfnKKgYc^G>ILkUgUgNhMiIk]G^CNk=kU7^eNi=k/WNANk9b
Ool10001Ool1000005=oo`06001>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeC7E;m
00=G7@0=EaaG7ELMFceK?5/mFcaO?5/lGcaK?6]kIg/00V]k0fnJ0W>I00EgUgNhNkIk]W^d009k]P06
NkEkTg^cNi9k/g^BLgoo0P00001DOol0L000OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeB
o5LmEaaG7E<LEceG75mMFcaOGE/lGeeK?6=LGcaSG5llKi]_NVnJLiUc^GNGMkQgUg^fNiAg^7NFNkEk
U7^cNi9k/W^BM7oo0P00001EOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d6Dad3Ead0
25LLEceG7EllFcaO?5mLHe`3Ge`00fMlHe]WG003LiT01GNhMkMk]WNfMkP00W^f00Ik]7^cNi=k/W^C
Ni9dOol2000005Ioo`1^001oogooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E;lFceG75/mEaaK
?ELLFceO?6=LGcaSG6=KIgaSFfMlIg][VfMkKiY[NW>iLiUg^7NGNkIkU7^eNi=k/W^DNk=kTW1oo`@0
009oo`00Egoo0P0000Aooe;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@05Dae>oE;mD_eC7@03D_d00e<MD_eC7@02Dad05U;mDaeC7ELMDaeG7E<MEaeC7ELmEaeG
?ELLFceK?5/mFcaWG6=LIgaSFfML0V]k00=WNfnJKiX00g>I00Ug^7^fMkIk]G^CNk=k]7^cNi80KGoo
10001Woo001IOol0JP00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMD_aK?E/LFceG75/mFaaO
GE/lIgaSFfMlIg][VfMkKiY[NVnKLiUc^GNGMkQgUW^eNiAo]7^DNkEkTg^bJGoo10002Woo001JOol0
1@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC
7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeG7003Ead02ULLFceK?5/mFcaO?5/lGcaK?5ll
0V]k00AWNfnJKiY_VP9cV@9g^008MkIk]W^dNkIg]W^eNi=k/VIoo`@000ioo`00Fgoo06L007ooC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC
7DklEaeBo5<MD_aG7E;lEaeC75LmEaaG7E<LEceK?5mMFcaOGE/lGeeO?6=LGca_VV]jKi]cVG>iLiUg
^7NGNkIgUgNhMiIk]G^DOkAkTP1ROol4000BOol005aoo`800003OomC7Dkm009Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d7Dad02ELL
EceG7ELmEaaG?E/lGcaK?002Ge`01F=LGeaWG6=LIg`00g>I00=g^7NGLiT00WNh00Ig]W^fNkAk]G^C
NkEOOol3000FOol005ioo`1S001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMDaaG7ELLFceG75/mEaaK?EllHeaO?6=L
He]WO6=KIgaWNf]kIg]_VfmjLkUcVGNhMiMk]W^DNkEkTg^b05aoo`@001Uoo`00Ggoo00@007ooDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m
0e<M01EBoE<MDaeG7E<MEaeC7ELMEaaG?ELMFceK?5/mFcaK?F=KIeaSG6MlIg/00V]k0fnJ00=cVGNh
MiL00W^f00Ak]G^dNk=k]5Qoo`@001eoo`00H7oo060007ooDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aG7E;lDaeBo5LMDaaG7E;lEaeC75LMEaaK?E/L
FceG75mMFcaOGF=KIgaWNf]kIg]_VfmjKiYcVG>iMiMg^7NFNkEkU7^cMiIEOol4000QOol0065oo`80
0006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeB
oE<MD_d3Dad01E;mDaeC7ELMEa`00eLM00UG75llFcaO?5/lGcaK?5llIg/00V]k0fnJ0W>I00QgUgNh
NkIk]W^dNkEk]W^eDGoo10009Goo001SOol0G@00Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMD_aG7E<LEceG75/mEaaOGE/lGeeK?6=L
GcaSG5llKi]_NVnJJgYc^G>IMkQgUg^fMiMg^7NFNkIkU01>Ool3000YOol006Aoo`03001C7Dkm009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00AC7E;mDaeBo@QC7@09EceG
75LmEaeG?ELLEceOG6=L00=OG004IgaSFfMLHe`2LiT2MkP01W>IMiMg^7NhNkIk]4]oo`@002aoo`00
IGoo05X007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC
7E;lEaeBo5LMD_aG7E<LFceG75/mEaaK?ELLFceO?6=LHe]WO6=KIgaSFf^KIg]_VV]jLkUcVGNhMiMk
]WNFNkE7Ool4000`Ool006Ioo`800005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7E;mDaeBoE<MD_d3Dad04U;mEaeC7ELMDaeG7E<MFceK?5/mFcaK?E/lFceSG6MlHe]WG09[
N`03Ig]_VVnJ009cV@9g^003NkIg]W^e04Aoo`@003Aoo`00J7oo05H007ooDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aG7E;lDaeBo5LMDaaG7E<LEceG75/mEaaK?E/LGeeK
?5mMFca[NfMkJi]WNfnJJgY_Vg>IMkQgUg^fMiIk]W^D@7oo1000>7oo001YOol01P00OomBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M00EBoELMEaeG7ELL00=G
7@05FcaO?5/lGcaK?002Ge`00f=LGea_VP02KiX2LiT2MkP00gNfNkIg^00mOol4000lOol006Yoo`1C
001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG?ELL
EaeC75/mEaaK?E/lGeeO?6=LGcaSG5llIgaSFfMlLiUc^GNGMkQcVG>iMiMg^00jOol30010Ool006]o
o`80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE;mD_eC7E;m25<M00MG?ELMEceG75Lm
EaeG?@03Ge`01f=LHe]WG6=LIgaWNf]k009_VP=cV@03MkQoogoo03Eoo`@004=oo`00KGoo04l007oo
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aK?ELLFceG75/m
FaaK?ELLIgaSFfMlHe]WO6MkJg][NVnKLiUc^G>IMkQgU`0cOol40017Ool006ioo`05001ooe;mDae>
o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m0e<M00=BoE<MDad00U<M011G7E<MEaeC7ELMFcaK?E/l
FceK?5llFcaWG6=LIgaWN`9[N`9_VP=cV@03MiMoogoo02ioo`@004]oo`00Kgoo04`007ooOomC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aC7E;lEceG75LMDaaG?E/LFceK?5mMFcaOGE/l
GeeWNf]kIg]_VfmjLkUcVG>iMiMg^2aoo`@004moo`00L7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06
DaeBoE<MD_eC7E;m0e<M00=BoE<MDad00U<M0eLM00QG75LMFcaO?5/lGcaK?6=L0emL0VnJ17>I00=g
^7ooOol0:7oo0`00Dgoo001bOol0A`00C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LM
D_aG7E;lFceG75/mEaaK?ELLFceO?6=LGcaSG5llIgaSFf]kIg][VfMkKiX09goo1000EWoo001cOol0
1000D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00EC7DkmD_eBoE<M00=Bo@03DaeBoE<M009C7@03D_eC7E<M00AC7@09EaeC7ELmEaeG?ELLFceK
?5/m009OG003HeaWO6=K00=[N`03Ig]_VVnJ02=oo`@005Yoo`00M7oo04@004kmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeBo5/mFaaK?ELLFceK75/mHe]WO6=KJg]WNf^KIg]_VV]j
87oo1000GWoo001eOol200001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMDad00eLM00UG
75/mFcaK?E/lGcaK?5llFc`00f]k0fnJ7Goo1000HWoo001gOol0@000Dae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aC7E;lEaeBo5LMDaaG?ELLEaeC75LmFcaOGE/lGeeO?6=LGcaSG6mjKiY[NVnK6Goo1000IWoo001h
Ool00`00Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1U<M00IG7ELLEaeG7ELmEa`2Ead02F=LGeaOG5mLHeaS
FfMLHeaWO00GOol3001ZOol007Uoo`0l001C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lFceG75/m
EaaK?ELLFceK76=LGcaWO6=KIgaSFfMl57oo1000KGoo001jOol00`00Oom>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;mDaeBo@=C7@0C
D_eC7E<MEaeC7ELMDaeG7E<MFceK?5/mFcaK?E/lIgaSFfMLHe`04Woo1000LGoo001kOol20000=4kl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5LMD_aC7E;lEaeC75LMD_aG7ELLEaeC75/mFaaK?E/lGeeK?5mM47oo1000MGoo001mOol01P00
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeB
oE<MD_eC7E;m0e<M00EBoE<MDaeG7ELL00=G7@06EaaO?5/lGcaK?5ll3Goo1000NGoo001nOol0<000
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7DklDaeBo5LMD_aG7E;lEaeC75LmEaaK?ELLGeeK?0]oo`@007eoo`00Ogoo00H007ooD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mD_eBoE<MD_d3Dad00e;m
DaeC7@04Dad01ULmEaaG7ELMEceG70Uoo`<0085oo`00P7oo0P0002MC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMD_aG7E<LEad0
2Goo1000Q7oo0022Ool01@00D_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7E<M00Moo`@008Qoo`00Pgoo028005<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7@Eo
o`@008aoo`00Q7oo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@06DaeBoE<MD_eC7E;m1Goo1000T7oo0025Ool200005TkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<M1Woo0`00U7oo0027Ool01000D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDaeBo@Aoo`@009Moo`00R7oo014004kmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<M009oo`@009]oo`00RGoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0Woo1000Wgoo002:
Ool200001E<MC_aC7DkmDad00Woo1000Xgoo002<Ool200000goo00000002002WOol008eoo`800:]o
o`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003o
OolkOol00001\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.646 .763 .934 r
.38973 .79901 .39806 .80576 .41196 .80209 .40367 .79531 Mtetra
.647 .763 .934 r
.40367 .79531 .41196 .80209 .42593 .79838 .41769 .79157 Mtetra
.41769 .79157 .42593 .79838 .43998 .79463 .43178 .7878 Mtetra
.648 .764 .933 r
.43178 .7878 .43998 .79463 .4541 .79079 .44595 .78396 Mtetra
.651 .766 .933 r
.44595 .78396 .4541 .79079 .46829 .78682 .46019 .78002 Mtetra
.655 .769 .933 r
.46019 .78002 .46829 .78682 .48256 .78262 .47451 .77591 Mtetra
.664 .774 .932 r
.47451 .77591 .48256 .78262 .4969 .77799 .4889 .77148 Mtetra
.679 .784 .929 r
.4889 .77148 .4969 .77799 .51132 .77259 .50336 .76647 Mtetra
.705 .801 .925 r
.50336 .76647 .51132 .77259 .52579 .76576 .5179 .7604 Mtetra
.749 .83 .913 r
.5179 .7604 .52579 .76576 .54031 .75641 .53249 .75242 Mtetra
.814 .869 .887 r
.53249 .75242 .54031 .75641 .55483 .74284 .54711 .74114 Mtetra
.889 .909 .834 r
.54711 .74114 .55483 .74284 .56926 .72289 .56168 .72455 Mtetra
.949 .931 .748 r
.56168 .72455 .56926 .72289 .58351 .69498 .57613 .70059 Mtetra
.972 .929 .65 r
.57613 .70059 .58351 .69498 .59749 .66015 .59033 .6687 Mtetra
.968 .918 .58 r
.59033 .6687 .59749 .66015 .61123 .62322 .60427 .63188 Mtetra
.959 .92 .569 r
.60427 .63188 .61123 .62322 .62489 .59036 .61803 .59615 Mtetra
.957 .943 .636 r
.61803 .59615 .62489 .59036 .63864 .5651 .6318 .56677 Mtetra
.939 .957 .753 r
.6318 .56677 .63864 .5651 .65256 .5473 .64572 .54531 Mtetra
.879 .925 .851 r
.64572 .54531 .65256 .5473 .66668 .53502 .65982 .53047 Mtetra
.803 .866 .895 r
.65982 .53047 .66668 .53502 .68096 .52622 .67411 .52008 Mtetra
.744 .815 .908 r
.67411 .52008 .68096 .52622 .69538 .51944 .68856 .51237 Mtetra
.708 .782 .91 r
.68856 .51237 .69538 .51944 .70992 .51376 .70313 .50617 Mtetra
.687 .764 .91 r
.70313 .50617 .70992 .51376 .72456 .50866 .71781 .50077 Mtetra
.676 .753 .909 r
.71781 .50077 .72456 .50866 .73929 .50388 .73258 .4958 Mtetra
.67 .748 .909 r
.73258 .4958 .73929 .50388 .7541 .49924 .74745 .49105 Mtetra
.667 .745 .908 r
.74745 .49105 .7541 .49924 .769 .49466 .7624 .48639 Mtetra
.665 .743 .908 r
.7624 .48639 .769 .49466 .78398 .49012 .77743 .48178 Mtetra
.664 .742 .908 r
.77743 .48178 .78398 .49012 .79903 .48557 .79254 .47718 Mtetra
.79254 .47718 .79903 .48557 .81417 .48102 .80773 .47257 Mtetra
.80773 .47257 .81417 .48102 .82939 .47644 .823 .46795 Mtetra
.664 .741 .908 r
.823 .46795 .82939 .47644 .84469 .47185 .83836 .46331 Mtetra
.83836 .46331 .84469 .47185 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.646 .763 .934 r
.38132 .79219 .38973 .79901 .40367 .79531 .39531 .78845 Mtetra
.39531 .78845 .40367 .79531 .41769 .79157 .40937 .78469 Mtetra
.647 .763 .934 r
.40937 .78469 .41769 .79157 .43178 .7878 .42351 .7809 Mtetra
.648 .764 .934 r
.42351 .7809 .43178 .7878 .44595 .78396 .43772 .77705 Mtetra
.649 .765 .933 r
.43772 .77705 .44595 .78396 .46019 .78002 .45201 .77312 Mtetra
.653 .767 .933 r
.45201 .77312 .46019 .78002 .47451 .77591 .46637 .76906 Mtetra
.659 .771 .932 r
.46637 .76906 .47451 .77591 .4889 .77148 .48082 .76476 Mtetra
.67 .778 .931 r
.48082 .76476 .4889 .77148 .50336 .76647 .49533 .76003 Mtetra
.69 .792 .928 r
.49533 .76003 .50336 .76647 .5179 .7604 .50992 .75451 Mtetra
.725 .814 .92 r
.50992 .75451 .5179 .7604 .53249 .75242 .52458 .74757 Mtetra
.779 .848 .903 r
.52458 .74757 .53249 .75242 .54711 .74114 .53928 .73808 Mtetra
.851 .89 .865 r
.53928 .73808 .54711 .74114 .56168 .72455 .55398 .72434 Mtetra
.923 .923 .794 r
.55398 .72434 .56168 .72455 .57613 .70059 .56859 .70418 Mtetra
.965 .933 .698 r
.56859 .70418 .57613 .70059 .59033 .6687 .58302 .676 Mtetra
.972 .923 .609 r
.58302 .676 .59033 .6687 .60427 .63188 .59718 .64086 Mtetra
.963 .916 .566 r
.59718 .64086 .60427 .63188 .61803 .59615 .61109 .60361 Mtetra
.957 .93 .593 r
.61109 .60361 .61803 .59615 .6318 .56677 .62492 .57046 Mtetra
.952 .954 .692 r
.62492 .57046 .6318 .56677 .64572 .54531 .63884 .54496 Mtetra
.913 .947 .809 r
.63884 .54496 .64572 .54531 .65982 .53047 .65293 .52698 Mtetra
.84 .896 .879 r
.65293 .52698 .65982 .53047 .67411 .52008 .66722 .51454 Mtetra
.77 .838 .904 r
.66722 .51454 .67411 .52008 .68856 .51237 .68167 .50561 Mtetra
.723 .797 .91 r
.68167 .50561 .68856 .51237 .70313 .50617 .69627 .49871 Mtetra
.696 .772 .91 r
.69627 .49871 .70313 .50617 .71781 .50077 .71099 .49291 Mtetra
.681 .758 .909 r
.71099 .49291 .71781 .50077 .73258 .4958 .72581 .48771 Mtetra
.673 .75 .909 r
.72581 .48771 .73258 .4958 .74745 .49105 .74073 .48281 Mtetra
.668 .746 .908 r
.74073 .48281 .74745 .49105 .7624 .48639 .75573 .47806 Mtetra
.666 .744 .908 r
.75573 .47806 .7624 .48639 .77743 .48178 .77081 .47337 Mtetra
.665 .743 .908 r
.77081 .47337 .77743 .48178 .79254 .47718 .78598 .46871 Mtetra
.664 .742 .908 r
.78598 .46871 .79254 .47718 .80773 .47257 .80123 .46405 Mtetra
.80123 .46405 .80773 .47257 .823 .46795 .81656 .45938 Mtetra
.664 .741 .908 r
.81656 .45938 .823 .46795 .83836 .46331 .83197 .4547 Mtetra
.83197 .4547 .83836 .46331 .8538 .45865 .84747 .44999 Mtetra
.84747 .44999 .8538 .45865 .86932 .45397 .86305 .44526 Mtetra
.86305 .44526 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.646 .763 .934 r
.37283 .7853 .38132 .79219 .39531 .78845 .38686 .78154 Mtetra
.38686 .78154 .39531 .78845 .40937 .78469 .40097 .77774 Mtetra
.647 .763 .934 r
.40097 .77774 .40937 .78469 .42351 .7809 .41515 .77392 Mtetra
.41515 .77392 .42351 .7809 .43772 .77705 .42941 .77005 Mtetra
.648 .764 .933 r
.42941 .77005 .43772 .77705 .45201 .77312 .44375 .76612 Mtetra
.651 .766 .933 r
.44375 .76612 .45201 .77312 .46637 .76906 .45816 .76209 Mtetra
.655 .769 .933 r
.45816 .76209 .46637 .76906 .48082 .76476 .47265 .75787 Mtetra
.664 .774 .932 r
.47265 .75787 .48082 .76476 .49533 .76003 .48722 .75334 Mtetra
.679 .784 .929 r
.48722 .75334 .49533 .76003 .50992 .75451 .50187 .74822 Mtetra
.705 .801 .925 r
.50187 .74822 .50992 .75451 .52458 .74757 .51658 .74204 Mtetra
.749 .83 .914 r
.51658 .74204 .52458 .74757 .53928 .73808 .53136 .73393 Mtetra
.814 .869 .888 r
.53136 .73393 .53928 .73808 .55398 .72434 .54615 .7225 Mtetra
.889 .909 .834 r
.54615 .7225 .55398 .72434 .56859 .70418 .56092 .70572 Mtetra
.949 .931 .747 r
.56092 .70572 .56859 .70418 .58302 .676 .57554 .68151 Mtetra
.972 .929 .65 r
.57554 .68151 .58302 .676 .59718 .64086 .58993 .64933 Mtetra
.968 .918 .58 r
.58993 .64933 .59718 .64086 .61109 .60361 .60404 .61218 Mtetra
.959 .92 .57 r
.60404 .61218 .61109 .60361 .62492 .57046 .61798 .57614 Mtetra
.957 .943 .636 r
.61798 .57614 .62492 .57046 .63884 .54496 .63192 .5465 Mtetra
.939 .957 .754 r
.63192 .5465 .63884 .54496 .65293 .52698 .646 .52483 Mtetra
.879 .924 .851 r
.646 .52483 .65293 .52698 .66722 .51454 .66028 .50982 Mtetra
.803 .866 .895 r
.66028 .50982 .66722 .51454 .68167 .50561 .67474 .49929 Mtetra
.744 .815 .908 r
.67474 .49929 .68167 .50561 .69627 .49871 .68937 .49145 Mtetra
.708 .782 .91 r
.68937 .49145 .69627 .49871 .71099 .49291 .70412 .48512 Mtetra
.687 .764 .91 r
.70412 .48512 .71099 .49291 .72581 .48771 .71898 .47961 Mtetra
.676 .753 .909 r
.71898 .47961 .72581 .48771 .74073 .48281 .73394 .47453 Mtetra
.67 .748 .909 r
.73394 .47453 .74073 .48281 .75573 .47806 .74899 .46966 Mtetra
.667 .745 .908 r
.74899 .46966 .75573 .47806 .77081 .47337 .76413 .46489 Mtetra
.665 .743 .908 r
.76413 .46489 .77081 .47337 .78598 .46871 .77935 .46017 Mtetra
.664 .742 .908 r
.77935 .46017 .78598 .46871 .80123 .46405 .79466 .45545 Mtetra
.79466 .45545 .80123 .46405 .81656 .45938 .81005 .45073 Mtetra
.81005 .45073 .81656 .45938 .83197 .4547 .82552 .44599 Mtetra
.664 .741 .908 r
.82552 .44599 .83197 .4547 .84747 .44999 .84107 .44124 Mtetra
.84107 .44124 .84747 .44999 .86305 .44526 .85671 .43646 Mtetra
.85671 .43646 .86305 .44526 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.646 .762 .934 r
.36425 .77835 .37283 .7853 .38686 .78154 .37833 .77455 Mtetra
.646 .763 .934 r
.37833 .77455 .38686 .78154 .40097 .77774 .39249 .77072 Mtetra
.39249 .77072 .40097 .77774 .41515 .77392 .40672 .76687 Mtetra
.647 .763 .934 r
.40672 .76687 .41515 .77392 .42941 .77005 .42103 .76297 Mtetra
.648 .764 .934 r
.42103 .76297 .42941 .77005 .44375 .76612 .43541 .75903 Mtetra
.649 .765 .933 r
.43541 .75903 .44375 .76612 .45816 .76209 .44987 .75501 Mtetra
.653 .767 .933 r
.44987 .75501 .45816 .76209 .47265 .75787 .46441 .75085 Mtetra
.659 .771 .932 r
.46441 .75085 .47265 .75787 .48722 .75334 .47903 .74645 Mtetra
.67 .778 .931 r
.47903 .74645 .48722 .75334 .50187 .74822 .49373 .74161 Mtetra
.69 .792 .928 r
.49373 .74161 .50187 .74822 .51658 .74204 .5085 .73599 Mtetra
.725 .814 .92 r
.5085 .73599 .51658 .74204 .53136 .73393 .52334 .72892 Mtetra
.779 .848 .903 r
.52334 .72892 .53136 .73393 .54615 .7225 .53822 .71929 Mtetra
.852 .89 .865 r
.53822 .71929 .54615 .7225 .56092 .70572 .55311 .70538 Mtetra
.923 .923 .794 r
.55311 .70538 .56092 .70572 .57554 .68151 .56791 .68499 Mtetra
.965 .933 .698 r
.56791 .68499 .57554 .68151 .58993 .64933 .58252 .65654 Mtetra
.972 .923 .609 r
.58252 .65654 .58993 .64933 .60404 .61218 .59686 .62108 Mtetra
.963 .916 .566 r
.59686 .62108 .60404 .61218 .61798 .57614 .61095 .58351 Mtetra
.958 .93 .594 r
.61095 .58351 .61798 .57614 .63192 .5465 .62495 .55007 Mtetra
.952 .954 .693 r
.62495 .55007 .63192 .5465 .646 .52483 .63904 .52433 Mtetra
.913 .946 .809 r
.63904 .52433 .646 .52483 .66028 .50982 .6533 .50615 Mtetra
.84 .896 .878 r
.6533 .50615 .66028 .50982 .67474 .49929 .66777 .49356 Mtetra
.77 .838 .904 r
.66777 .49356 .67474 .49929 .68937 .49145 .6824 .48449 Mtetra
.723 .797 .909 r
.6824 .48449 .68937 .49145 .70412 .48512 .69718 .47746 Mtetra
.696 .772 .91 r
.69718 .47746 .70412 .48512 .71898 .47961 .71209 .47155 Mtetra
.681 .758 .909 r
.71209 .47155 .71898 .47961 .73394 .47453 .72709 .46623 Mtetra
.673 .75 .909 r
.72709 .46623 .73394 .47453 .74899 .46966 .7422 .46121 Mtetra
.668 .746 .908 r
.7422 .46121 .74899 .46966 .76413 .46489 .75739 .45635 Mtetra
.666 .744 .908 r
.75739 .45635 .76413 .46489 .77935 .46017 .77267 .45155 Mtetra
.665 .743 .908 r
.77267 .45155 .77935 .46017 .79466 .45545 .78803 .44677 Mtetra
.664 .742 .908 r
.78803 .44677 .79466 .45545 .81005 .45073 .80347 .442 Mtetra
.80347 .442 .81005 .45073 .82552 .44599 .819 .43721 Mtetra
.664 .741 .908 r
.819 .43721 .82552 .44599 .84107 .44124 .83462 .4324 Mtetra
.83462 .4324 .84107 .44124 .85671 .43646 .85032 .42757 Mtetra
.85032 .42757 .85671 .43646 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.646 .762 .934 r
.35559 .77133 .36425 .77835 .37833 .77455 .36972 .76749 Mtetra
.646 .763 .934 r
.36972 .76749 .37833 .77455 .39249 .77072 .38392 .76363 Mtetra
.38392 .76363 .39249 .77072 .40672 .76687 .3982 .75974 Mtetra
.647 .763 .934 r
.3982 .75974 .40672 .76687 .42103 .76297 .41256 .75582 Mtetra
.41256 .75582 .42103 .76297 .43541 .75903 .42699 .75186 Mtetra
.648 .764 .933 r
.42699 .75186 .43541 .75903 .44987 .75501 .4415 .74783 Mtetra
.651 .766 .933 r
.4415 .74783 .44987 .75501 .46441 .75085 .45609 .74369 Mtetra
.655 .769 .933 r
.45609 .74369 .46441 .75085 .47903 .74645 .47075 .73938 Mtetra
.664 .774 .932 r
.47075 .73938 .47903 .74645 .49373 .74161 .4855 .73474 Mtetra
.679 .784 .929 r
.4855 .73474 .49373 .74161 .5085 .73599 .50033 .72952 Mtetra
.705 .801 .925 r
.50033 .72952 .5085 .73599 .52334 .72892 .51523 .72322 Mtetra
.749 .83 .914 r
.51523 .72322 .52334 .72892 .53822 .71929 .53019 .71498 Mtetra
.814 .869 .888 r
.53019 .71498 .53822 .71929 .55311 .70538 .54518 .70338 Mtetra
.889 .909 .834 r
.54518 .70338 .55311 .70538 .56791 .68499 .56013 .68641 Mtetra
.949 .931 .747 r
.56013 .68641 .56791 .68499 .58252 .65654 .57495 .66195 Mtetra
.972 .929 .65 r
.57495 .66195 .58252 .65654 .59686 .62108 .58952 .62947 Mtetra
.968 .918 .58 r
.58952 .62947 .59686 .62108 .61095 .58351 .60381 .59199 Mtetra
.959 .92 .57 r
.60381 .59199 .61095 .58351 .62495 .55007 .61792 .55564 Mtetra
.957 .943 .637 r
.61792 .55564 .62495 .55007 .63904 .52433 .63203 .52572 Mtetra
.939 .956 .754 r
.63203 .52572 .63904 .52433 .6533 .50615 .64629 .50384 Mtetra
.879 .924 .851 r
.64629 .50384 .6533 .50615 .66777 .49356 .66075 .48865 Mtetra
.803 .865 .895 r
.66075 .48865 .66777 .49356 .6824 .48449 .67539 .47797 Mtetra
.744 .815 .908 r
.67539 .47797 .6824 .48449 .69718 .47746 .6902 .47001 Mtetra
.708 .782 .91 r
.6902 .47001 .69718 .47746 .71209 .47155 .70513 .46356 Mtetra
.687 .764 .91 r
.70513 .46356 .71209 .47155 .72709 .46623 .72018 .45793 Mtetra
.676 .753 .909 r
.72018 .45793 .72709 .46623 .7422 .46121 .73533 .45272 Mtetra
.67 .748 .909 r
.73533 .45272 .7422 .46121 .75739 .45635 .75058 .44774 Mtetra
.667 .745 .908 r
.75058 .44774 .75739 .45635 .77267 .45155 .76591 .44285 Mtetra
.665 .743 .908 r
.76591 .44285 .77267 .45155 .78803 .44677 .78133 .43801 Mtetra
.664 .742 .908 r
.78133 .43801 .78803 .44677 .80347 .442 .79684 .43318 Mtetra
.79684 .43318 .80347 .442 .819 .43721 .81242 .42833 Mtetra
.81242 .42833 .819 .43721 .83462 .4324 .8281 .42348 Mtetra
.664 .741 .908 r
.8281 .42348 .83462 .4324 .85032 .42757 .84386 .4186 Mtetra
.84386 .4186 .85032 .42757 .8661 .42272 .85971 .4137 Mtetra
.85971 .4137 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.646 .762 .934 r
.34685 .76423 .35559 .77133 .36972 .76749 .36102 .76036 Mtetra
.36102 .76036 .36972 .76749 .38392 .76363 .37527 .75646 Mtetra
.646 .763 .934 r
.37527 .75646 .38392 .76363 .3982 .75974 .3896 .75254 Mtetra
.3896 .75254 .3982 .75974 .41256 .75582 .404 .74859 Mtetra
.647 .763 .934 r
.404 .74859 .41256 .75582 .42699 .75186 .41848 .7446 Mtetra
.648 .764 .934 r
.41848 .7446 .42699 .75186 .4415 .74783 .43304 .74056 Mtetra
.649 .765 .933 r
.43304 .74056 .4415 .74783 .45609 .74369 .44768 .73643 Mtetra
.653 .767 .933 r
.44768 .73643 .45609 .74369 .47075 .73938 .4624 .73217 Mtetra
.659 .771 .932 r
.4624 .73217 .47075 .73938 .4855 .73474 .4772 .72766 Mtetra
.67 .778 .931 r
.4772 .72766 .4855 .73474 .50033 .72952 .49208 .72272 Mtetra
.69 .792 .928 r
.49208 .72272 .50033 .72952 .51523 .72322 .50704 .71698 Mtetra
.725 .814 .92 r
.50704 .71698 .51523 .72322 .53019 .71498 .52206 .70979 Mtetra
.779 .848 .903 r
.52206 .70979 .53019 .71498 .54518 .70338 .53714 .70001 Mtetra
.852 .89 .865 r
.53714 .70001 .54518 .70338 .56013 .68641 .55221 .68592 Mtetra
.923 .924 .794 r
.55221 .68592 .56013 .68641 .57495 .66195 .56721 .66531 Mtetra
.965 .933 .697 r
.56721 .66531 .57495 .66195 .58952 .62947 .58201 .63658 Mtetra
.972 .923 .609 r
.58201 .63658 .58952 .62947 .60381 .59199 .59653 .6008 Mtetra
.963 .916 .566 r
.59653 .6008 .60381 .59199 .61792 .55564 .6108 .5629 Mtetra
.958 .93 .594 r
.6108 .5629 .61792 .55564 .63203 .52572 .62498 .52916 Mtetra
.952 .954 .693 r
.62498 .52916 .63203 .52572 .64629 .50384 .63924 .50318 Mtetra
.913 .946 .809 r
.63924 .50318 .64629 .50384 .66075 .48865 .65369 .48481 Mtetra
.84 .895 .878 r
.65369 .48481 .66075 .48865 .67539 .47797 .66833 .47206 Mtetra
.77 .838 .904 r
.66833 .47206 .67539 .47797 .6902 .47001 .68315 .46285 Mtetra
.723 .797 .909 r
.68315 .46285 .6902 .47001 .70513 .46356 .69812 .45569 Mtetra
.696 .772 .91 r
.69812 .45569 .70513 .46356 .72018 .45793 .71321 .44965 Mtetra
.681 .758 .909 r
.71321 .44965 .72018 .45793 .73533 .45272 .72841 .44421 Mtetra
.673 .75 .909 r
.72841 .44421 .73533 .45272 .75058 .44774 .7437 .43907 Mtetra
.668 .746 .908 r
.7437 .43907 .75058 .44774 .76591 .44285 .75909 .43409 Mtetra
.666 .744 .908 r
.75909 .43409 .76591 .44285 .78133 .43801 .77457 .42917 Mtetra
.665 .743 .908 r
.77457 .42917 .78133 .43801 .79684 .43318 .79013 .42427 Mtetra
.664 .742 .908 r
.79013 .42427 .79684 .43318 .81242 .42833 .80578 .41937 Mtetra
.80578 .41937 .81242 .42833 .8281 .42348 .82151 .41446 Mtetra
.664 .741 .908 r
.82151 .41446 .8281 .42348 .84386 .4186 .83734 .40953 Mtetra
.83734 .40953 .84386 .4186 .85971 .4137 .85324 .40458 Mtetra
.85324 .40458 .85971 .4137 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38957 Mtetra
.9015 .38957 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.646 .762 .934 r
.33802 .75707 .34685 .76423 .36102 .76036 .35224 .75316 Mtetra
.35224 .75316 .36102 .76036 .37527 .75646 .36654 .74923 Mtetra
.646 .763 .934 r
.36654 .74923 .37527 .75646 .3896 .75254 .38091 .74527 Mtetra
.38091 .74527 .3896 .75254 .404 .74859 .39536 .74128 Mtetra
.647 .763 .934 r
.39536 .74128 .404 .74859 .41848 .7446 .40989 .73726 Mtetra
.40989 .73726 .41848 .7446 .43304 .74056 .4245 .7332 Mtetra
.648 .764 .933 r
.4245 .7332 .43304 .74056 .44768 .73643 .43919 .72907 Mtetra
.651 .766 .933 r
.43919 .72907 .44768 .73643 .4624 .73217 .45396 .72483 Mtetra
.655 .769 .933 r
.45396 .72483 .4624 .73217 .4772 .72766 .46881 .72041 Mtetra
.664 .774 .932 r
.46881 .72041 .4772 .72766 .49208 .72272 .48374 .71567 Mtetra
.679 .784 .93 r
.48374 .71567 .49208 .72272 .50704 .71698 .49875 .71033 Mtetra
.705 .802 .925 r
.49875 .71033 .50704 .71698 .52206 .70979 .51384 .7039 Mtetra
.749 .83 .914 r
.51384 .7039 .52206 .70979 .53714 .70001 .529 .69553 Mtetra
.814 .869 .888 r
.529 .69553 .53714 .70001 .55221 .68592 .54418 .68377 Mtetra
.889 .909 .834 r
.54418 .68377 .55221 .68592 .56721 .66531 .55932 .6666 Mtetra
.949 .932 .747 r
.55932 .6666 .56721 .66531 .58201 .63658 .57433 .64189 Mtetra
.972 .929 .649 r
.57433 .64189 .58201 .63658 .59653 .6008 .58909 .6091 Mtetra
.968 .918 .579 r
.58909 .6091 .59653 .6008 .6108 .5629 .60357 .57128 Mtetra
.959 .92 .57 r
.60357 .57128 .6108 .5629 .62498 .52916 .61786 .53461 Mtetra
.957 .943 .637 r
.61786 .53461 .62498 .52916 .63924 .50318 .63215 .50443 Mtetra
.939 .956 .754 r
.63215 .50443 .63924 .50318 .65369 .48481 .64659 .48233 Mtetra
.878 .924 .851 r
.64659 .48233 .65369 .48481 .66833 .47206 .66123 .46696 Mtetra
.803 .865 .895 r
.66123 .46696 .66833 .47206 .68315 .46285 .67605 .45613 Mtetra
.744 .815 .908 r
.67605 .45613 .68315 .46285 .69812 .45569 .69105 .44802 Mtetra
.708 .782 .91 r
.69105 .44802 .69812 .45569 .71321 .44965 .70617 .44145 Mtetra
.687 .764 .91 r
.70617 .44145 .71321 .44965 .72841 .44421 .72142 .43569 Mtetra
.676 .753 .909 r
.72142 .43569 .72841 .44421 .7437 .43907 .73676 .43037 Mtetra
.67 .748 .909 r
.73676 .43037 .7437 .43907 .75909 .43409 .7522 .42526 Mtetra
.667 .745 .908 r
.7522 .42526 .75909 .43409 .77457 .42917 .76774 .42025 Mtetra
.665 .743 .908 r
.76774 .42025 .77457 .42917 .79013 .42427 .78336 .41529 Mtetra
.664 .742 .908 r
.78336 .41529 .79013 .42427 .80578 .41937 .79907 .41033 Mtetra
.79907 .41033 .80578 .41937 .82151 .41446 .81486 .40536 Mtetra
.81486 .40536 .82151 .41446 .83734 .40953 .83075 .40038 Mtetra
.664 .741 .908 r
.83075 .40038 .83734 .40953 .85324 .40458 .84672 .39537 Mtetra
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Mtetra
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38957 .89516 .3802 Mtetra
.89516 .3802 .9015 .38957 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.646 .762 .934 r
.32911 .74984 .33802 .75707 .35224 .75316 .34337 .74589 Mtetra
.34337 .74589 .35224 .75316 .36654 .74923 .35771 .74192 Mtetra
.35771 .74192 .36654 .74923 .38091 .74527 .37214 .73792 Mtetra
.646 .763 .934 r
.37214 .73792 .38091 .74527 .39536 .74128 .38663 .7339 Mtetra
.38663 .7339 .39536 .74128 .40989 .73726 .40121 .72985 Mtetra
.647 .763 .934 r
.40121 .72985 .40989 .73726 .4245 .7332 .41587 .72576 Mtetra
.648 .764 .934 r
.41587 .72576 .4245 .7332 .43919 .72907 .43061 .72161 Mtetra
.649 .765 .933 r
.43061 .72161 .43919 .72907 .45396 .72483 .44543 .71738 Mtetra
.653 .767 .933 r
.44543 .71738 .45396 .72483 .46881 .72041 .46033 .71301 Mtetra
.659 .771 .932 r
.46033 .71301 .46881 .72041 .48374 .71567 .47532 .7084 Mtetra
.67 .778 .931 r
.47532 .7084 .48374 .71567 .49875 .71033 .49039 .70334 Mtetra
.69 .792 .928 r
.49039 .70334 .49875 .71033 .51384 .7039 .50553 .69748 Mtetra
.725 .814 .92 r
.50553 .69748 .51384 .7039 .529 .69553 .52075 .69016 Mtetra
.779 .848 .903 r
.52075 .69016 .529 .69553 .54418 .68377 .53602 .68024 Mtetra
.852 .89 .865 r
.53602 .68024 .54418 .68377 .55932 .6666 .5513 .66596 Mtetra
.923 .924 .794 r
.5513 .66596 .55932 .6666 .57433 .64189 .56649 .64512 Mtetra
.965 .933 .697 r
.56649 .64512 .57433 .64189 .58909 .6091 .58148 .61611 Mtetra
.972 .923 .609 r
.58148 .61611 .58909 .6091 .60357 .57128 .5962 .58 Mtetra
.963 .916 .566 r
.5962 .58 .60357 .57128 .61786 .53461 .61065 .54176 Mtetra
.958 .93 .594 r
.61065 .54176 .61786 .53461 .63215 .50443 .62501 .50773 Mtetra
.952 .954 .693 r
.62501 .50773 .63215 .50443 .64659 .48233 .63945 .4815 Mtetra
.913 .946 .809 r
.63945 .4815 .64659 .48233 .66123 .46696 .65408 .46293 Mtetra
.84 .895 .878 r
.65408 .46293 .66123 .46696 .67605 .45613 .66891 .45001 Mtetra
.77 .838 .903 r
.66891 .45001 .67605 .45613 .69105 .44802 .68392 .44066 Mtetra
.723 .797 .909 r
.68392 .44066 .69105 .44802 .70617 .44145 .69908 .43336 Mtetra
.696 .772 .91 r
.69908 .43336 .70617 .44145 .72142 .43569 .71436 .4272 Mtetra
.681 .758 .909 r
.71436 .4272 .72142 .43569 .73676 .43037 .72976 .42163 Mtetra
.673 .75 .909 r
.72976 .42163 .73676 .43037 .7522 .42526 .74525 .41637 Mtetra
.668 .746 .908 r
.74525 .41637 .7522 .42526 .76774 .42025 .76084 .41126 Mtetra
.666 .744 .908 r
.76084 .41126 .76774 .42025 .78336 .41529 .77652 .40622 Mtetra
.665 .743 .908 r
.77652 .40622 .78336 .41529 .79907 .41033 .79229 .40119 Mtetra
.664 .742 .908 r
.79229 .40119 .79907 .41033 .81486 .40536 .80814 .39617 Mtetra
.80814 .39617 .81486 .40536 .83075 .40038 .82409 .39113 Mtetra
.664 .741 .908 r
.82409 .39113 .83075 .40038 .84672 .39537 .84012 .38607 Mtetra
.84012 .38607 .84672 .39537 .86278 .39034 .85625 .38099 Mtetra
.85625 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37075 Mtetra
.88876 .37075 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .762 .934 r
.3201 .74254 .32911 .74984 .34337 .74589 .33441 .73855 Mtetra
.33441 .73855 .34337 .74589 .35771 .74192 .3488 .73454 Mtetra
.3488 .73454 .35771 .74192 .37214 .73792 .36327 .7305 Mtetra
.646 .763 .934 r
.36327 .7305 .37214 .73792 .38663 .7339 .37782 .72644 Mtetra
.37782 .72644 .38663 .7339 .40121 .72985 .39245 .72235 Mtetra
.647 .763 .934 r
.39245 .72235 .40121 .72985 .41587 .72576 .40716 .71823 Mtetra
.40716 .71823 .41587 .72576 .43061 .72161 .42194 .71406 Mtetra
.648 .764 .933 r
.42194 .71406 .43061 .72161 .44543 .71738 .43682 .70982 Mtetra
.651 .766 .933 r
.43682 .70982 .44543 .71738 .46033 .71301 .45177 .70548 Mtetra
.655 .769 .933 r
.45177 .70548 .46033 .71301 .47532 .7084 .46681 .70095 Mtetra
.664 .774 .932 r
.46681 .70095 .47532 .7084 .49039 .70334 .48193 .69609 Mtetra
.679 .784 .93 r
.48193 .69609 .49039 .70334 .50553 .69748 .49714 .69064 Mtetra
.705 .802 .925 r
.49714 .69064 .50553 .69748 .52075 .69016 .51242 .68409 Mtetra
.749 .83 .914 r
.51242 .68409 .52075 .69016 .53602 .68024 .52777 .67557 Mtetra
.814 .869 .888 r
.52777 .67557 .53602 .68024 .5513 .66596 .54315 .66365 Mtetra
.889 .91 .834 r
.54315 .66365 .5513 .66596 .56649 .64512 .55849 .64627 Mtetra
.949 .932 .747 r
.55849 .64627 .56649 .64512 .58148 .61611 .5737 .6213 Mtetra
.972 .929 .649 r
.5737 .6213 .58148 .61611 .5962 .58 .58866 .5882 Mtetra
.968 .918 .579 r
.58866 .5882 .5962 .58 .61065 .54176 .60332 .55004 Mtetra
.959 .92 .57 r
.60332 .55004 .61065 .54176 .62501 .50773 .6178 .51305 Mtetra
.957 .943 .637 r
.6178 .51305 .62501 .50773 .63945 .4815 .63227 .48259 Mtetra
.939 .956 .754 r
.63227 .48259 .63945 .4815 .65408 .46293 .64689 .46026 Mtetra
.878 .924 .851 r
.64689 .46026 .65408 .46293 .66891 .45001 .66172 .44471 Mtetra
.803 .865 .895 r
.66172 .44471 .66891 .45001 .68392 .44066 .67673 .43373 Mtetra
.744 .815 .908 r
.67673 .43373 .68392 .44066 .69908 .43336 .69192 .42548 Mtetra
.708 .782 .91 r
.69192 .42548 .69908 .43336 .71436 .4272 .70724 .41877 Mtetra
.687 .763 .91 r
.70724 .41877 .71436 .4272 .72976 .42163 .72268 .41289 Mtetra
.676 .753 .909 r
.72268 .41289 .72976 .42163 .74525 .41637 .73823 .40744 Mtetra
.67 .748 .909 r
.73823 .40744 .74525 .41637 .76084 .41126 .75387 .4022 Mtetra
.667 .745 .908 r
.75387 .4022 .76084 .41126 .77652 .40622 .76961 .39707 Mtetra
.665 .743 .908 r
.76961 .39707 .77652 .40622 .79229 .40119 .78544 .39197 Mtetra
.664 .742 .908 r
.78544 .39197 .79229 .40119 .80814 .39617 .80136 .38689 Mtetra
.80136 .38689 .80814 .39617 .82409 .39113 .81736 .38179 Mtetra
.81736 .38179 .82409 .39113 .84012 .38607 .83346 .37668 Mtetra
.664 .741 .908 r
.83346 .37668 .84012 .38607 .85625 .38099 .84965 .37154 Mtetra
.84965 .37154 .85625 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37075 .8823 .36119 Mtetra
.8823 .36119 .88876 .37075 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .762 .934 r
.31101 .73516 .3201 .74254 .33441 .73855 .32537 .73113 Mtetra
.32537 .73113 .33441 .73855 .3488 .73454 .3398 .72708 Mtetra
.3398 .72708 .3488 .73454 .36327 .7305 .35432 .723 Mtetra
.35432 .723 .36327 .7305 .37782 .72644 .36892 .7189 Mtetra
.646 .763 .934 r
.36892 .7189 .37782 .72644 .39245 .72235 .38359 .71478 Mtetra
.38359 .71478 .39245 .72235 .40716 .71823 .39835 .71062 Mtetra
.647 .763 .934 r
.39835 .71062 .40716 .71823 .42194 .71406 .41319 .70642 Mtetra
.648 .764 .934 r
.41319 .70642 .42194 .71406 .43682 .70982 .42811 .70217 Mtetra
.649 .765 .933 r
.42811 .70217 .43682 .70982 .45177 .70548 .44312 .69783 Mtetra
.653 .767 .933 r
.44312 .69783 .45177 .70548 .46681 .70095 .45821 .69335 Mtetra
.659 .771 .932 r
.45821 .69335 .46681 .70095 .48193 .69609 .47339 .68863 Mtetra
.67 .778 .931 r
.47339 .68863 .48193 .69609 .49714 .69064 .48865 .68346 Mtetra
.69 .792 .928 r
.48865 .68346 .49714 .69064 .51242 .68409 .50399 .67747 Mtetra
.725 .814 .92 r
.50399 .67747 .51242 .68409 .52777 .67557 .51941 .67001 Mtetra
.779 .849 .903 r
.51941 .67001 .52777 .67557 .54315 .66365 .53488 .65993 Mtetra
.852 .891 .865 r
.53488 .65993 .54315 .66365 .55849 .64627 .55036 .64548 Mtetra
.923 .924 .794 r
.55036 .64548 .55849 .64627 .5737 .6213 .56575 .6244 Mtetra
.965 .933 .697 r
.56575 .6244 .5737 .6213 .58866 .5882 .58095 .5951 Mtetra
.972 .923 .608 r
.58095 .5951 .58866 .5882 .60332 .55004 .59585 .55866 Mtetra
.963 .916 .566 r
.59585 .55866 .60332 .55004 .6178 .51305 .6105 .52008 Mtetra
.958 .93 .595 r
.6105 .52008 .6178 .51305 .63227 .48259 .62504 .48574 Mtetra
.952 .954 .694 r
.62504 .48574 .63227 .48259 .64689 .46026 .63967 .45926 Mtetra
.913 .946 .809 r
.63967 .45926 .64689 .46026 .66172 .44471 .65448 .44049 Mtetra
.84 .895 .878 r
.65448 .44049 .66172 .44471 .67673 .43373 .6695 .4274 Mtetra
.77 .838 .903 r
.6695 .4274 .67673 .43373 .69192 .42548 .6847 .4179 Mtetra
.723 .796 .909 r
.6847 .4179 .69192 .42548 .70724 .41877 .70006 .41047 Mtetra
.696 .772 .91 r
.70006 .41047 .70724 .41877 .72268 .41289 .71554 .40417 Mtetra
.681 .758 .909 r
.71554 .40417 .72268 .41289 .73823 .40744 .73114 .39847 Mtetra
.673 .75 .909 r
.73114 .39847 .73823 .40744 .75387 .4022 .74684 .39308 Mtetra
.668 .746 .908 r
.74684 .39308 .75387 .4022 .76961 .39707 .76263 .38784 Mtetra
.666 .744 .908 r
.76263 .38784 .76961 .39707 .78544 .39197 .77852 .38267 Mtetra
.665 .743 .908 r
.77852 .38267 .78544 .39197 .80136 .38689 .7945 .37751 Mtetra
.664 .742 .908 r
.7945 .37751 .80136 .38689 .81736 .38179 .81057 .37236 Mtetra
.81057 .37236 .81736 .38179 .83346 .37668 .82673 .36719 Mtetra
.664 .741 .908 r
.82673 .36719 .83346 .37668 .84965 .37154 .84298 .362 Mtetra
.84298 .362 .84965 .37154 .86593 .36638 .85933 .35678 Mtetra
.85933 .35678 .86593 .36638 .8823 .36119 .87576 .35153 Mtetra
.87576 .35153 .8823 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .762 .934 r
.30182 .7277 .31101 .73516 .32537 .73113 .31623 .72364 Mtetra
.31623 .72364 .32537 .73113 .3398 .72708 .33071 .71954 Mtetra
.33071 .71954 .3398 .72708 .35432 .723 .34528 .71543 Mtetra
.34528 .71543 .35432 .723 .36892 .7189 .35992 .71129 Mtetra
.646 .763 .934 r
.35992 .71129 .36892 .7189 .38359 .71478 .37465 .70712 Mtetra
.37465 .70712 .38359 .71478 .39835 .71062 .38946 .70293 Mtetra
.647 .763 .934 r
.38946 .70293 .39835 .71062 .41319 .70642 .40435 .6987 Mtetra
.40435 .6987 .41319 .70642 .42811 .70217 .41932 .69442 Mtetra
.648 .764 .933 r
.41932 .69442 .42811 .70217 .44312 .69783 .43438 .69008 Mtetra
.651 .766 .933 r
.43438 .69008 .44312 .69783 .45821 .69335 .44953 .68562 Mtetra
.655 .769 .933 r
.44953 .68562 .45821 .69335 .47339 .68863 .46476 .68098 Mtetra
.664 .774 .932 r
.46476 .68098 .47339 .68863 .48865 .68346 .48007 .676 Mtetra
.679 .784 .93 r
.48007 .676 .48865 .68346 .50399 .67747 .49548 .67043 Mtetra
.705 .802 .925 r
.49548 .67043 .50399 .67747 .51941 .67001 .51096 .66375 Mtetra
.749 .83 .914 r
.51096 .66375 .51941 .67001 .53488 .65993 .52651 .65508 Mtetra
.814 .869 .888 r
.52651 .65508 .53488 .65993 .55036 .64548 .54209 .64299 Mtetra
.889 .91 .834 r
.54209 .64299 .55036 .64548 .56575 .6244 .55764 .6254 Mtetra
.949 .932 .747 r
.55764 .6254 .56575 .6244 .58095 .5951 .57305 .60016 Mtetra
.972 .929 .649 r
.57305 .60016 .58095 .5951 .59585 .55866 .58821 .56675 Mtetra
.968 .918 .579 r
.58821 .56675 .59585 .55866 .6105 .52008 .60307 .52825 Mtetra
.959 .92 .57 r
.60307 .52825 .6105 .52008 .62504 .48574 .61774 .49092 Mtetra
.957 .943 .638 r
.61774 .49092 .62504 .48574 .63967 .45926 .6324 .46018 Mtetra
.939 .956 .754 r
.6324 .46018 .63967 .45926 .65448 .44049 .64721 .43763 Mtetra
.878 .924 .851 r
.64721 .43763 .65448 .44049 .6695 .4274 .66222 .42189 Mtetra
.803 .865 .895 r
.66222 .42189 .6695 .4274 .6847 .4179 .67743 .41075 Mtetra
.744 .815 .908 r
.67743 .41075 .6847 .4179 .70006 .41047 .69281 .40236 Mtetra
.708 .782 .91 r
.69281 .40236 .70006 .41047 .71554 .40417 .70834 .39551 Mtetra
.687 .763 .91 r
.70834 .39551 .71554 .40417 .73114 .39847 .72398 .38949 Mtetra
.676 .753 .909 r
.72398 .38949 .73114 .39847 .74684 .39308 .73973 .38391 Mtetra
.67 .748 .909 r
.73973 .38391 .74684 .39308 .76263 .38784 .75558 .37854 Mtetra
.667 .745 .908 r
.75558 .37854 .76263 .38784 .77852 .38267 .77153 .37328 Mtetra
.665 .743 .908 r
.77153 .37328 .77852 .38267 .7945 .37751 .78757 .36805 Mtetra
.664 .742 .908 r
.78757 .36805 .7945 .37751 .81057 .37236 .8037 .36283 Mtetra
.8037 .36283 .81057 .37236 .82673 .36719 .81993 .3576 Mtetra
.81993 .3576 .82673 .36719 .84298 .362 .83625 .35235 Mtetra
.664 .741 .908 r
.83625 .35235 .84298 .362 .85933 .35678 .85266 .34708 Mtetra
.85266 .34708 .85933 .35678 .87576 .35153 .86916 .34178 Mtetra
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .762 .934 r
.29254 .72018 .30182 .7277 .31623 .72364 .30699 .71607 Mtetra
.30699 .71607 .31623 .72364 .33071 .71954 .32153 .71193 Mtetra
.32153 .71193 .33071 .71954 .34528 .71543 .33614 .70778 Mtetra
.33614 .70778 .34528 .71543 .35992 .71129 .35084 .7036 Mtetra
.35084 .7036 .35992 .71129 .37465 .70712 .36561 .69939 Mtetra
.646 .763 .934 r
.36561 .69939 .37465 .70712 .38946 .70293 .38047 .69516 Mtetra
.38047 .69516 .38946 .70293 .40435 .6987 .39542 .69089 Mtetra
.647 .763 .934 r
.39542 .69089 .40435 .6987 .41932 .69442 .41044 .68658 Mtetra
.648 .764 .934 r
.41044 .68658 .41932 .69442 .43438 .69008 .42555 .68222 Mtetra
.649 .765 .933 r
.42555 .68222 .43438 .69008 .44953 .68562 .44075 .67777 Mtetra
.653 .767 .933 r
.44075 .67777 .44953 .68562 .46476 .68098 .45604 .67317 Mtetra
.659 .771 .932 r
.45604 .67317 .46476 .68098 .48007 .676 .47141 .66833 Mtetra
.67 .778 .931 r
.47141 .66833 .48007 .676 .49548 .67043 .48687 .66304 Mtetra
.69 .792 .928 r
.48687 .66304 .49548 .67043 .51096 .66375 .50241 .65693 Mtetra
.725 .814 .921 r
.50241 .65693 .51096 .66375 .52651 .65508 .51803 .64933 Mtetra
.779 .849 .904 r
.51803 .64933 .52651 .65508 .54209 .64299 .53371 .63909 Mtetra
.852 .891 .865 r
.53371 .63909 .54209 .64299 .55764 .6254 .54939 .62444 Mtetra
.923 .924 .794 r
.54939 .62444 .55764 .6254 .57305 .60016 .56499 .60313 Mtetra
.965 .933 .697 r
.56499 .60313 .57305 .60016 .58821 .56675 .58039 .57353 Mtetra
.972 .923 .608 r
.58039 .57353 .58821 .56675 .60307 .52825 .5955 .53675 Mtetra
.963 .916 .566 r
.5955 .53675 .60307 .52825 .61774 .49092 .61034 .49783 Mtetra
.958 .93 .595 r
.61034 .49783 .61774 .49092 .6324 .46018 .62507 .46318 Mtetra
.953 .953 .694 r
.62507 .46318 .6324 .46018 .64721 .43763 .63989 .43644 Mtetra
.913 .945 .809 r
.63989 .43644 .64721 .43763 .66222 .42189 .6549 .41746 Mtetra
.84 .895 .878 r
.6549 .41746 .66222 .42189 .67743 .41075 .67011 .4042 Mtetra
.77 .838 .903 r
.67011 .4042 .67743 .41075 .69281 .40236 .68551 .39455 Mtetra
.723 .796 .909 r
.68551 .39455 .69281 .40236 .70834 .39551 .70107 .38697 Mtetra
.696 .771 .91 r
.70107 .38697 .70834 .39551 .72398 .38949 .71675 .38054 Mtetra
.681 .758 .909 r
.71675 .38054 .72398 .38949 .73973 .38391 .73256 .3747 Mtetra
.673 .75 .909 r
.73256 .3747 .73973 .38391 .75558 .37854 .74846 .36918 Mtetra
.668 .746 .908 r
.74846 .36918 .75558 .37854 .77153 .37328 .76447 .36381 Mtetra
.666 .744 .908 r
.76447 .36381 .77153 .37328 .78757 .36805 .78057 .3585 Mtetra
.665 .743 .908 r
.78057 .3585 .78757 .36805 .8037 .36283 .79677 .35321 Mtetra
.664 .742 .908 r
.79677 .35321 .8037 .36283 .81993 .3576 .81306 .34792 Mtetra
.81306 .34792 .81993 .3576 .83625 .35235 .82944 .34261 Mtetra
.664 .741 .908 r
.82944 .34261 .83625 .35235 .85266 .34708 .84592 .33728 Mtetra
.84592 .33728 .85266 .34708 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Mtetra
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72018 .30699 .71607 .29767 .70842 Mtetra
.29767 .70842 .30699 .71607 .32153 .71193 .31225 .70425 Mtetra
.31225 .70425 .32153 .71193 .33614 .70778 .32691 .70005 Mtetra
.32691 .70005 .33614 .70778 .35084 .7036 .34166 .69583 Mtetra
.34166 .69583 .35084 .7036 .36561 .69939 .35649 .69158 Mtetra
.646 .763 .934 r
.35649 .69158 .36561 .69939 .38047 .69516 .3714 .6873 Mtetra
.3714 .6873 .38047 .69516 .39542 .69089 .38639 .683 Mtetra
.647 .763 .934 r
.38639 .683 .39542 .69089 .41044 .68658 .40147 .67865 Mtetra
.40147 .67865 .41044 .68658 .42555 .68222 .41663 .67426 Mtetra
.648 .764 .933 r
.41663 .67426 .42555 .68222 .44075 .67777 .43189 .6698 Mtetra
.651 .766 .933 r
.43189 .6698 .44075 .67777 .45604 .67317 .44722 .66523 Mtetra
.655 .769 .933 r
.44722 .66523 .45604 .67317 .47141 .66833 .46265 .66047 Mtetra
.664 .774 .932 r
.46265 .66047 .47141 .66833 .48687 .66304 .47817 .65538 Mtetra
.679 .784 .93 r
.47817 .65538 .48687 .66304 .50241 .65693 .49377 .64967 Mtetra
.705 .802 .925 r
.49377 .64967 .50241 .65693 .51803 .64933 .50946 .64286 Mtetra
.749 .83 .914 r
.50946 .64286 .51803 .64933 .53371 .63909 .52522 .63404 Mtetra
.814 .87 .888 r
.52522 .63404 .53371 .63909 .54939 .62444 .54101 .62177 Mtetra
.889 .91 .834 r
.54101 .62177 .54939 .62444 .56499 .60313 .55677 .60397 Mtetra
.949 .932 .747 r
.55677 .60397 .56499 .60313 .58039 .57353 .57239 .57846 Mtetra
.972 .929 .649 r
.57239 .57846 .58039 .57353 .5955 .53675 .58775 .54472 Mtetra
.968 .918 .579 r
.58775 .54472 .5955 .53675 .61034 .49783 .60282 .50588 Mtetra
.959 .92 .571 r
.60282 .50588 .61034 .49783 .62507 .46318 .61768 .46822 Mtetra
.957 .943 .638 r
.61768 .46822 .62507 .46318 .63989 .43644 .63253 .43719 Mtetra
.939 .956 .755 r
.63253 .43719 .63989 .43644 .6549 .41746 .64753 .41441 Mtetra
.878 .923 .851 r
.64753 .41441 .6549 .41746 .67011 .4042 .66274 .39848 Mtetra
.803 .865 .895 r
.66274 .39848 .67011 .4042 .68551 .39455 .67815 .38717 Mtetra
.744 .815 .908 r
.67815 .38717 .68551 .39455 .70107 .38697 .69373 .37863 Mtetra
.708 .782 .91 r
.69373 .37863 .70107 .38697 .71675 .38054 .70946 .37164 Mtetra
.687 .763 .91 r
.70946 .37164 .71675 .38054 .73256 .3747 .72531 .36548 Mtetra
.676 .753 .909 r
.72531 .36548 .73256 .3747 .74846 .36918 .74127 .35976 Mtetra
.67 .748 .909 r
.74127 .35976 .74846 .36918 .76447 .36381 .75734 .35426 Mtetra
.667 .745 .908 r
.75734 .35426 .76447 .36381 .78057 .3585 .7735 .34886 Mtetra
.665 .743 .908 r
.7735 .34886 .78057 .3585 .79677 .35321 .78976 .34349 Mtetra
.664 .742 .908 r
.78976 .34349 .79677 .35321 .81306 .34792 .80612 .33813 Mtetra
.80612 .33813 .81306 .34792 .82944 .34261 .82256 .33276 Mtetra
.82256 .33276 .82944 .34261 .84592 .33728 .83911 .32737 Mtetra
.664 .741 .908 r
.83911 .32737 .84592 .33728 .86249 .33192 .85575 .32196 Mtetra
.85575 .32196 .86249 .33192 .87915 .32653 .87248 .31651 Mtetra
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70842 .28825 .7007 Mtetra
.28825 .7007 .29767 .70842 .31225 .70425 .30288 .69648 Mtetra
.30288 .69648 .31225 .70425 .32691 .70005 .31759 .69224 Mtetra
.31759 .69224 .32691 .70005 .34166 .69583 .33239 .68797 Mtetra
.33239 .68797 .34166 .69583 .35649 .69158 .34726 .68368 Mtetra
.34726 .68368 .35649 .69158 .3714 .6873 .36223 .67936 Mtetra
.646 .763 .934 r
.36223 .67936 .3714 .6873 .38639 .683 .37727 .67502 Mtetra
.37727 .67502 .38639 .683 .40147 .67865 .3924 .67064 Mtetra
.647 .763 .934 r
.3924 .67064 .40147 .67865 .41663 .67426 .40762 .66621 Mtetra
.648 .764 .934 r
.40762 .66621 .41663 .67426 .43189 .6698 .42293 .66173 Mtetra
.649 .765 .933 r
.42293 .66173 .43189 .6698 .44722 .66523 .43832 .65717 Mtetra
.653 .767 .933 r
.43832 .65717 .44722 .66523 .46265 .66047 .4538 .65245 Mtetra
.659 .771 .932 r
.4538 .65245 .46265 .66047 .47817 .65538 .46937 .64749 Mtetra
.67 .778 .931 r
.46937 .64749 .47817 .65538 .49377 .64967 .48504 .64207 Mtetra
.69 .792 .928 r
.48504 .64207 .49377 .64967 .50946 .64286 .50079 .63583 Mtetra
.725 .814 .921 r
.50079 .63583 .50946 .64286 .52522 .63404 .51662 .62808 Mtetra
.779 .849 .904 r
.51662 .62808 .52522 .63404 .54101 .62177 .5325 .61768 Mtetra
.852 .891 .865 r
.5325 .61768 .54101 .62177 .55677 .60397 .5484 .60283 Mtetra
.923 .925 .794 r
.5484 .60283 .55677 .60397 .57239 .57846 .56421 .58128 Mtetra
.965 .933 .696 r
.56421 .58128 .57239 .57846 .58775 .54472 .57982 .55138 Mtetra
.972 .923 .608 r
.57982 .55138 .58775 .54472 .60282 .50588 .59514 .51426 Mtetra
.963 .916 .566 r
.59514 .51426 .60282 .50588 .61768 .46822 .61018 .47499 Mtetra
.958 .93 .595 r
.61018 .47499 .61768 .46822 .63253 .43719 .62511 .44003 Mtetra
.953 .953 .694 r
.62511 .44003 .63253 .43719 .64753 .41441 .64012 .41303 Mtetra
.913 .945 .809 r
.64012 .41303 .64753 .41441 .66274 .39848 .65532 .39384 Mtetra
.84 .895 .878 r
.65532 .39384 .66274 .39848 .67815 .38717 .67073 .3804 Mtetra
.77 .838 .903 r
.67073 .3804 .67815 .38717 .69373 .37863 .68634 .37058 Mtetra
.723 .796 .909 r
.68634 .37058 .69373 .37863 .70946 .37164 .7021 .36286 Mtetra
.696 .771 .91 r
.7021 .36286 .70946 .37164 .72531 .36548 .718 .35628 Mtetra
.681 .757 .909 r
.718 .35628 .72531 .36548 .74127 .35976 .73401 .35031 Mtetra
.673 .75 .909 r
.73401 .35031 .74127 .35976 .75734 .35426 .75014 .34465 Mtetra
.668 .746 .908 r
.75014 .34465 .75734 .35426 .7735 .34886 .76636 .33913 Mtetra
.666 .744 .908 r
.76636 .33913 .7735 .34886 .78976 .34349 .78268 .33368 Mtetra
.665 .743 .908 r
.78268 .33368 .78976 .34349 .80612 .33813 .7991 .32825 Mtetra
.664 .742 .908 r
.7991 .32825 .80612 .33813 .82256 .33276 .81562 .32282 Mtetra
.81562 .32282 .82256 .33276 .83911 .32737 .83223 .31737 Mtetra
.664 .741 .908 r
.83223 .31737 .83911 .32737 .85575 .32196 .84893 .31189 Mtetra
.84893 .31189 .85575 .32196 .87248 .31651 .86574 .30639 Mtetra
.86574 .30639 .87248 .31651 .88931 .31104 .88264 .30086 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .7007 .27873 .69289 Mtetra
.27873 .69289 .28825 .7007 .30288 .69648 .29341 .68863 Mtetra
.29341 .68863 .30288 .69648 .31759 .69224 .30817 .68435 Mtetra
.30817 .68435 .31759 .69224 .33239 .68797 .32302 .68004 Mtetra
.32302 .68004 .33239 .68797 .34726 .68368 .33794 .6757 Mtetra
.33794 .6757 .34726 .68368 .36223 .67936 .35296 .67134 Mtetra
.646 .763 .934 r
.35296 .67134 .36223 .67936 .37727 .67502 .36806 .66695 Mtetra
.36806 .66695 .37727 .67502 .3924 .67064 .38324 .66253 Mtetra
.647 .763 .934 r
.38324 .66253 .3924 .67064 .40762 .66621 .39851 .65807 Mtetra
.39851 .65807 .40762 .66621 .42293 .66173 .41387 .65356 Mtetra
.648 .764 .933 r
.41387 .65356 .42293 .66173 .43832 .65717 .42932 .64898 Mtetra
.651 .766 .933 r
.42932 .64898 .43832 .65717 .4538 .65245 .44486 .64429 Mtetra
.655 .769 .933 r
.44486 .64429 .4538 .65245 .46937 .64749 .46049 .63941 Mtetra
.663 .774 .932 r
.46049 .63941 .46937 .64749 .48504 .64207 .47621 .63419 Mtetra
.679 .784 .93 r
.47621 .63419 .48504 .64207 .50079 .63583 .49202 .62835 Mtetra
.705 .802 .925 r
.49202 .62835 .50079 .63583 .51662 .62808 .50792 .6214 Mtetra
.749 .83 .914 r
.50792 .6214 .51662 .62808 .5325 .61768 .52389 .61243 Mtetra
.814 .87 .888 r
.52389 .61243 .5325 .61768 .5484 .60283 .53989 .59998 Mtetra
.889 .91 .834 r
.53989 .59998 .5484 .60283 .56421 .58128 .55587 .58195 Mtetra
.949 .933 .746 r
.55587 .58195 .56421 .58128 .57982 .55138 .57171 .55617 Mtetra
.972 .929 .648 r
.57171 .55617 .57982 .55138 .59514 .51426 .58728 .5221 Mtetra
.968 .918 .579 r
.58728 .5221 .59514 .51426 .61018 .47499 .60255 .4829 Mtetra
.96 .92 .571 r
.60255 .4829 .61018 .47499 .62511 .44003 .61761 .44491 Mtetra
.958 .943 .639 r
.61761 .44491 .62511 .44003 .64012 .41303 .63266 .41359 Mtetra
.939 .955 .755 r
.63266 .41359 .64012 .41303 .65532 .39384 .64786 .39057 Mtetra
.878 .923 .851 r
.64786 .39057 .65532 .39384 .67073 .3804 .66327 .37445 Mtetra
.803 .865 .894 r
.66327 .37445 .67073 .3804 .68634 .37058 .67888 .36297 Mtetra
.744 .815 .907 r
.67888 .36297 .68634 .37058 .7021 .36286 .69467 .35427 Mtetra
.708 .782 .91 r
.69467 .35427 .7021 .36286 .718 .35628 .71061 .34713 Mtetra
.687 .763 .91 r
.71061 .34713 .718 .35628 .73401 .35031 .72668 .34084 Mtetra
.676 .753 .909 r
.72668 .34084 .73401 .35031 .75014 .34465 .74286 .33497 Mtetra
.67 .748 .909 r
.74286 .33497 .75014 .34465 .76636 .33913 .75914 .32933 Mtetra
.667 .745 .908 r
.75914 .32933 .76636 .33913 .78268 .33368 .77553 .32378 Mtetra
.665 .743 .908 r
.77553 .32378 .78268 .33368 .7991 .32825 .79201 .31827 Mtetra
.664 .742 .908 r
.79201 .31827 .7991 .32825 .81562 .32282 .80859 .31277 Mtetra
.80859 .31277 .81562 .32282 .83223 .31737 .82527 .30726 Mtetra
.82527 .30726 .83223 .31737 .84893 .31189 .84205 .30172 Mtetra
.664 .741 .908 r
.84205 .30172 .84893 .31189 .86574 .30639 .85892 .29615 Mtetra
.85892 .29615 .86574 .30639 .88264 .30086 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .68501 Mtetra
.26911 .68501 .27873 .69289 .29341 .68863 .28384 .6807 Mtetra
.28384 .6807 .29341 .68863 .30817 .68435 .29865 .67637 Mtetra
.29865 .67637 .30817 .68435 .32302 .68004 .31355 .67202 Mtetra
.31355 .67202 .32302 .68004 .33794 .6757 .32853 .66764 Mtetra
.32853 .66764 .33794 .6757 .35296 .67134 .34359 .66323 Mtetra
.34359 .66323 .35296 .67134 .36806 .66695 .35875 .6588 Mtetra
.646 .763 .934 r
.35875 .6588 .36806 .66695 .38324 .66253 .37398 .65434 Mtetra
.37398 .65434 .38324 .66253 .39851 .65807 .38931 .64984 Mtetra
.647 .763 .934 r
.38931 .64984 .39851 .65807 .41387 .65356 .40472 .6453 Mtetra
.648 .764 .934 r
.40472 .6453 .41387 .65356 .42932 .64898 .42023 .6407 Mtetra
.649 .765 .933 r
.42023 .6407 .42932 .64898 .44486 .64429 .43582 .63601 Mtetra
.653 .767 .933 r
.43582 .63601 .44486 .64429 .46049 .63941 .45151 .63117 Mtetra
.659 .771 .932 r
.45151 .63117 .46049 .63941 .47621 .63419 .46729 .62608 Mtetra
.67 .778 .931 r
.46729 .62608 .47621 .63419 .49202 .62835 .48316 .62053 Mtetra
.69 .792 .928 r
.48316 .62053 .49202 .62835 .50792 .6214 .49912 .61415 Mtetra
.725 .814 .921 r
.49912 .61415 .50792 .6214 .52389 .61243 .51516 .60625 Mtetra
.779 .849 .904 r
.51516 .60625 .52389 .61243 .53989 .59998 .53127 .59568 Mtetra
.852 .891 .865 r
.53127 .59568 .53989 .59998 .55587 .58195 .54738 .58063 Mtetra
.923 .925 .794 r
.54738 .58063 .55587 .58195 .57171 .55617 .56341 .55883 Mtetra
.965 .933 .696 r
.56341 .55883 .57171 .55617 .58728 .5221 .57924 .52862 Mtetra
.972 .923 .608 r
.57924 .52862 .58728 .5221 .60255 .4829 .59477 .49116 Mtetra
.963 .916 .566 r
.59477 .49116 .60255 .4829 .61761 .44491 .61001 .45153 Mtetra
.958 .93 .596 r
.61001 .45153 .61761 .44491 .63266 .41359 .62514 .41625 Mtetra
.953 .953 .695 r
.62514 .41625 .63266 .41359 .64786 .39057 .64035 .38899 Mtetra
.913 .945 .809 r
.64035 .38899 .64786 .39057 .66327 .37445 .65576 .36958 Mtetra
.84 .894 .878 r
.65576 .36958 .66327 .37445 .67888 .36297 .67137 .35596 Mtetra
.77 .837 .903 r
.67137 .35596 .67888 .36297 .69467 .35427 .68719 .34598 Mtetra
.723 .796 .909 r
.68719 .34598 .69467 .35427 .71061 .34713 .70316 .3381 Mtetra
.696 .771 .91 r
.70316 .3381 .71061 .34713 .72668 .34084 .71927 .33138 Mtetra
.681 .757 .909 r
.71927 .33138 .72668 .34084 .74286 .33497 .73551 .32526 Mtetra
.673 .75 .909 r
.73551 .32526 .74286 .33497 .75914 .32933 .75185 .31945 Mtetra
.668 .746 .908 r
.75185 .31945 .75914 .32933 .77553 .32378 .7683 .31379 Mtetra
.666 .744 .908 r
.7683 .31379 .77553 .32378 .79201 .31827 .78485 .3082 Mtetra
.665 .743 .908 r
.78485 .3082 .79201 .31827 .80859 .31277 .8015 .30262 Mtetra
.664 .742 .908 r
.8015 .30262 .80859 .31277 .82527 .30726 .81824 .29704 Mtetra
.81824 .29704 .82527 .30726 .84205 .30172 .83509 .29144 Mtetra
.664 .741 .908 r
.83509 .29144 .84205 .30172 .85892 .29615 .85203 .28581 Mtetra
.85203 .28581 .85892 .29615 .87589 .29056 .86907 .28016 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .68501 .25939 .67704 Mtetra
.25939 .67704 .26911 .68501 .28384 .6807 .27417 .67269 Mtetra
.27417 .67269 .28384 .6807 .29865 .67637 .28903 .66832 Mtetra
.28903 .66832 .29865 .67637 .31355 .67202 .30398 .66392 Mtetra
.30398 .66392 .31355 .67202 .32853 .66764 .31901 .65949 Mtetra
.31901 .65949 .32853 .66764 .34359 .66323 .33413 .65504 Mtetra
.33413 .65504 .34359 .66323 .35875 .6588 .34934 .65056 Mtetra
.646 .763 .934 r
.34934 .65056 .35875 .6588 .37398 .65434 .36463 .64605 Mtetra
.36463 .64605 .37398 .65434 .38931 .64984 .38001 .64151 Mtetra
.647 .763 .934 r
.38001 .64151 .38931 .64984 .40472 .6453 .39548 .63693 Mtetra
.39548 .63693 .40472 .6453 .42023 .6407 .41104 .6323 Mtetra
.648 .764 .933 r
.41104 .6323 .42023 .6407 .43582 .63601 .42669 .6276 Mtetra
.651 .766 .933 r
.42669 .6276 .43582 .63601 .45151 .63117 .44243 .62278 Mtetra
.655 .769 .933 r
.44243 .62278 .45151 .63117 .46729 .62608 .45827 .61777 Mtetra
.663 .774 .932 r
.45827 .61777 .46729 .62608 .48316 .62053 .4742 .61242 Mtetra
.679 .784 .93 r
.4742 .61242 .48316 .62053 .49912 .61415 .49022 .60645 Mtetra
.705 .802 .925 r
.49022 .60645 .49912 .61415 .51516 .60625 .50633 .59935 Mtetra
.749 .83 .914 r
.50633 .59935 .51516 .60625 .53127 .59568 .52252 .59022 Mtetra
.814 .87 .888 r
.52252 .59022 .53127 .59568 .54738 .58063 .53875 .57758 Mtetra
.89 .911 .834 r
.53875 .57758 .54738 .58063 .56341 .55883 .55495 .55932 Mtetra
.949 .933 .746 r
.55495 .55932 .56341 .55883 .57924 .52862 .57101 .53326 Mtetra
.972 .929 .648 r
.57101 .53326 .57924 .52862 .59477 .49116 .5868 .49886 Mtetra
.968 .917 .579 r
.5868 .49886 .59477 .49116 .61001 .45153 .60228 .45931 Mtetra
.96 .92 .571 r
.60228 .45931 .61001 .45153 .62514 .41625 .61754 .42097 Mtetra
.958 .943 .639 r
.61754 .42097 .62514 .41625 .64035 .38899 .6328 .38936 Mtetra
.939 .955 .755 r
.6328 .38936 .64035 .38899 .65576 .36958 .6482 .3661 Mtetra
.878 .923 .851 r
.6482 .3661 .65576 .36958 .67137 .35596 .66381 .34977 Mtetra
.803 .864 .894 r
.66381 .34977 .67137 .35596 .68719 .34598 .67964 .33812 Mtetra
.744 .815 .907 r
.67964 .33812 .68719 .34598 .70316 .3381 .69564 .32926 Mtetra
.708 .782 .91 r
.69564 .32926 .70316 .3381 .71927 .33138 .7118 .32197 Mtetra
.687 .763 .91 r
.7118 .32197 .71927 .33138 .73551 .32526 .72808 .31552 Mtetra
.676 .753 .909 r
.72808 .31552 .73551 .32526 .75185 .31945 .74448 .30951 Mtetra
.67 .748 .909 r
.74448 .30951 .75185 .31945 .7683 .31379 .761 .30372 Mtetra
.667 .745 .908 r
.761 .30372 .7683 .31379 .78485 .3082 .77761 .29802 Mtetra
.665 .743 .908 r
.77761 .29802 .78485 .3082 .8015 .30262 .79432 .29237 Mtetra
.664 .742 .908 r
.79432 .29237 .8015 .30262 .81824 .29704 .81114 .28671 Mtetra
.81114 .28671 .81824 .29704 .83509 .29144 .82805 .28105 Mtetra
.82805 .28105 .83509 .29144 .85203 .28581 .84507 .27536 Mtetra
.664 .741 .908 r
.84507 .27536 .85203 .28581 .86907 .28016 .86218 .26964 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .6646 Mtetra
.2644 .6646 .27417 .67269 .28903 .66832 .27932 .66018 Mtetra
.27932 .66018 .28903 .66832 .30398 .66392 .29431 .65573 Mtetra
.29431 .65573 .30398 .66392 .31901 .65949 .3094 .65126 Mtetra
.3094 .65126 .31901 .65949 .33413 .65504 .32457 .64676 Mtetra
.32457 .64676 .33413 .65504 .34934 .65056 .33983 .64223 Mtetra
.33983 .64223 .34934 .65056 .36463 .64605 .35517 .63768 Mtetra
.646 .763 .934 r
.35517 .63768 .36463 .64605 .38001 .64151 .37061 .63309 Mtetra
.37061 .63309 .38001 .64151 .39548 .63693 .38613 .62847 Mtetra
.647 .763 .934 r
.38613 .62847 .39548 .63693 .41104 .6323 .40175 .62381 Mtetra
.648 .764 .934 r
.40175 .62381 .41104 .6323 .42669 .6276 .41745 .61908 Mtetra
.649 .765 .933 r
.41745 .61908 .42669 .6276 .44243 .62278 .43325 .61426 Mtetra
.653 .767 .933 r
.43325 .61426 .44243 .62278 .45827 .61777 .44915 .6093 Mtetra
.659 .771 .932 r
.44915 .6093 .45827 .61777 .4742 .61242 .46514 .60408 Mtetra
.67 .778 .931 r
.46514 .60408 .4742 .61242 .49022 .60645 .48123 .59839 Mtetra
.69 .792 .928 r
.48123 .59839 .49022 .60645 .50633 .59935 .4974 .59187 Mtetra
.725 .815 .921 r
.4974 .59187 .50633 .59935 .52252 .59022 .51367 .58382 Mtetra
.779 .849 .904 r
.51367 .58382 .52252 .59022 .53875 .57758 .52999 .57307 Mtetra
.852 .891 .865 r
.52999 .57307 .53875 .57758 .55495 .55932 .54633 .55781 Mtetra
.923 .925 .794 r
.54633 .55781 .55495 .55932 .57101 .53326 .56259 .53575 Mtetra
.965 .934 .696 r
.56259 .53575 .57101 .53326 .5868 .49886 .57864 .50524 Mtetra
.972 .923 .607 r
.57864 .50524 .5868 .49886 .60228 .45931 .59438 .46742 Mtetra
.963 .916 .566 r
.59438 .46742 .60228 .45931 .61754 .42097 .60984 .42744 Mtetra
.959 .93 .596 r
.60984 .42744 .61754 .42097 .6328 .38936 .62518 .39183 Mtetra
.953 .953 .695 r
.62518 .39183 .6328 .38936 .6482 .3661 .64059 .3643 Mtetra
.913 .945 .809 r
.64059 .3643 .6482 .3661 .66381 .34977 .6562 .34467 Mtetra
.84 .894 .878 r
.6562 .34467 .66381 .34977 .67964 .33812 .67203 .33086 Mtetra
.77 .837 .903 r
.67203 .33086 .67964 .33812 .69564 .32926 .68806 .32071 Mtetra
.724 .796 .909 r
.68806 .32071 .69564 .32926 .7118 .32197 .70425 .31268 Mtetra
.696 .771 .91 r
.70425 .31268 .7118 .32197 .72808 .31552 .72058 .3058 Mtetra
.681 .757 .909 r
.72058 .3058 .72808 .31552 .74448 .30951 .73704 .29953 Mtetra
.673 .75 .909 r
.73704 .29953 .74448 .30951 .761 .30372 .75361 .29357 Mtetra
.668 .746 .908 r
.75361 .29357 .761 .30372 .77761 .29802 .77029 .28776 Mtetra
.666 .744 .908 r
.77029 .28776 .77761 .29802 .79432 .29237 .78707 .28201 Mtetra
.665 .743 .908 r
.78707 .28201 .79432 .29237 .81114 .28671 .80396 .27628 Mtetra
.664 .742 .908 r
.80396 .27628 .81114 .28671 .82805 .28105 .82094 .27055 Mtetra
.82094 .27055 .82805 .28105 .84507 .27536 .83803 .26479 Mtetra
.664 .741 .908 r
.83803 .26479 .84507 .27536 .86218 .26964 .85521 .25901 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .6646 .25453 .65642 Mtetra
.25453 .65642 .2644 .6646 .27932 .66018 .2695 .65195 Mtetra
.2695 .65195 .27932 .66018 .29431 .65573 .28454 .64745 Mtetra
.28454 .64745 .29431 .65573 .3094 .65126 .29968 .64294 Mtetra
.29968 .64294 .3094 .65126 .32457 .64676 .3149 .63839 Mtetra
.3149 .63839 .32457 .64676 .33983 .64223 .33021 .63382 Mtetra
.33021 .63382 .33983 .64223 .35517 .63768 .34561 .62921 Mtetra
.646 .763 .934 r
.34561 .62921 .35517 .63768 .37061 .63309 .3611 .62458 Mtetra
.3611 .62458 .37061 .63309 .38613 .62847 .37668 .61992 Mtetra
.647 .763 .934 r
.37668 .61992 .38613 .62847 .40175 .62381 .39236 .61521 Mtetra
.39236 .61521 .40175 .62381 .41745 .61908 .40812 .61045 Mtetra
.648 .764 .933 r
.40812 .61045 .41745 .61908 .43325 .61426 .42398 .60562 Mtetra
.651 .766 .933 r
.42398 .60562 .43325 .61426 .44915 .6093 .43993 .60068 Mtetra
.655 .769 .933 r
.43993 .60068 .44915 .6093 .46514 .60408 .45598 .59553 Mtetra
.663 .774 .932 r
.45598 .59553 .46514 .60408 .48123 .59839 .47213 .59004 Mtetra
.679 .784 .93 r
.47213 .59004 .48123 .59839 .4974 .59187 .48837 .58393 Mtetra
.705 .802 .925 r
.48837 .58393 .4974 .59187 .51367 .58382 .50471 .57668 Mtetra
.749 .83 .914 r
.50471 .57668 .51367 .58382 .52999 .57307 .52112 .56738 Mtetra
.814 .87 .888 r
.52112 .56738 .52999 .57307 .54633 .55781 .53757 .55455 Mtetra
.89 .911 .834 r
.53757 .55455 .54633 .55781 .56259 .53575 .554 .53606 Mtetra
.949 .933 .746 r
.554 .53606 .56259 .53575 .57864 .50524 .57029 .50972 Mtetra
.972 .929 .648 r
.57029 .50972 .57864 .50524 .59438 .46742 .5863 .47498 Mtetra
.968 .917 .579 r
.5863 .47498 .59438 .46742 .60984 .42744 .602 .43506 Mtetra
.96 .92 .571 r
.602 .43506 .60984 .42744 .62518 .39183 .61747 .39638 Mtetra
.958 .943 .639 r
.61747 .39638 .62518 .39183 .64059 .3643 .63294 .36447 Mtetra
.939 .955 .755 r
.63294 .36447 .64059 .3643 .6562 .34467 .64855 .34096 Mtetra
.878 .923 .85 r
.64855 .34096 .6562 .34467 .67203 .33086 .66437 .32443 Mtetra
.803 .864 .894 r
.66437 .32443 .67203 .33086 .68806 .32071 .68041 .31259 Mtetra
.744 .814 .907 r
.68041 .31259 .68806 .32071 .70425 .31268 .69664 .30357 Mtetra
.708 .782 .91 r
.69664 .30357 .70425 .31268 .72058 .3058 .71301 .29612 Mtetra
.687 .763 .91 r
.71301 .29612 .72058 .3058 .73704 .29953 .72953 .28952 Mtetra
.676 .753 .909 r
.72953 .28952 .73704 .29953 .75361 .29357 .74616 .28335 Mtetra
.67 .748 .909 r
.74616 .28335 .75361 .29357 .77029 .28776 .7629 .27741 Mtetra
.667 .745 .908 r
.7629 .27741 .77029 .28776 .78707 .28201 .77975 .27156 Mtetra
.665 .743 .908 r
.77975 .27156 .78707 .28201 .80396 .27628 .7967 .26574 Mtetra
.664 .742 .908 r
.7967 .26574 .80396 .27628 .82094 .27055 .81375 .25993 Mtetra
.81375 .25993 .82094 .27055 .83803 .26479 .83091 .25411 Mtetra
.83091 .25411 .83803 .26479 .85521 .25901 .84817 .24826 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65642 .24456 .64815 Mtetra
.24456 .64815 .25453 .65642 .2695 .65195 .25957 .64363 Mtetra
.25957 .64363 .2695 .65195 .28454 .64745 .27467 .63909 Mtetra
.27467 .63909 .28454 .64745 .29968 .64294 .28986 .63452 Mtetra
.28986 .63452 .29968 .64294 .3149 .63839 .30513 .62993 Mtetra
.30513 .62993 .3149 .63839 .33021 .63382 .3205 .62531 Mtetra
.3205 .62531 .33021 .63382 .34561 .62921 .33595 .62066 Mtetra
.33595 .62066 .34561 .62921 .3611 .62458 .3515 .61598 Mtetra
.646 .763 .934 r
.3515 .61598 .3611 .62458 .37668 .61992 .36714 .61127 Mtetra
.36714 .61127 .37668 .61992 .39236 .61521 .38286 .60652 Mtetra
.647 .763 .934 r
.38286 .60652 .39236 .61521 .40812 .61045 .39869 .60172 Mtetra
.648 .764 .934 r
.39869 .60172 .40812 .61045 .42398 .60562 .4146 .59687 Mtetra
.649 .765 .933 r
.4146 .59687 .42398 .60562 .43993 .60068 .43062 .59192 Mtetra
.653 .767 .933 r
.43062 .59192 .43993 .60068 .45598 .59553 .44673 .58682 Mtetra
.659 .771 .932 r
.44673 .58682 .45598 .59553 .47213 .59004 .46293 .58146 Mtetra
.67 .778 .931 r
.46293 .58146 .47213 .59004 .48837 .58393 .47924 .57563 Mtetra
.69 .792 .928 r
.47924 .57563 .48837 .58393 .50471 .57668 .49564 .56896 Mtetra
.725 .815 .921 r
.49564 .56896 .50471 .57668 .52112 .56738 .51213 .56075 Mtetra
.779 .849 .904 r
.51213 .56075 .52112 .56738 .53757 .55455 .52868 .54982 Mtetra
.852 .892 .865 r
.52868 .54982 .53757 .55455 .554 .53606 .54525 .53435 Mtetra
.923 .925 .793 r
.54525 .53435 .554 .53606 .57029 .50972 .56174 .51203 Mtetra
.965 .934 .696 r
.56174 .51203 .57029 .50972 .5863 .47498 .57802 .4812 Mtetra
.972 .923 .607 r
.57802 .4812 .5863 .47498 .602 .43506 .59399 .44302 Mtetra
.963 .916 .566 r
.59399 .44302 .602 .43506 .61747 .39638 .60966 .40267 Mtetra
.959 .93 .596 r
.60966 .40267 .61747 .39638 .63294 .36447 .62521 .36674 Mtetra
.953 .953 .695 r
.62521 .36674 .63294 .36447 .64855 .34096 .64084 .33894 Mtetra
.913 .944 .809 r
.64084 .33894 .64855 .34096 .66437 .32443 .65666 .31908 Mtetra
.84 .894 .878 r
.65666 .31908 .66437 .32443 .68041 .31259 .67271 .30508 Mtetra
.77 .837 .903 r
.67271 .30508 .68041 .31259 .69664 .30357 .68895 .29475 Mtetra
.724 .796 .909 r
.68895 .29475 .69664 .30357 .71301 .29612 .70537 .28655 Mtetra
.696 .771 .91 r
.70537 .28655 .71301 .29612 .72953 .28952 .72193 .27951 Mtetra
.681 .757 .909 r
.72193 .27951 .72953 .28952 .74616 .28335 .73862 .27309 Mtetra
.673 .75 .909 r
.73862 .27309 .74616 .28335 .7629 .27741 .75543 .26697 Mtetra
.668 .746 .908 r
.75543 .26697 .7629 .27741 .77975 .27156 .77234 .261 Mtetra
.666 .744 .908 r
.77234 .261 .77975 .27156 .7967 .26574 .78936 .2551 Mtetra
.665 .743 .908 r
.78936 .2551 .7967 .26574 .81375 .25993 .80649 .24921 Mtetra
.664 .742 .908 r
.80649 .24921 .81375 .25993 .83091 .25411 .82372 .24331 Mtetra
.82372 .24331 .83091 .25411 .84817 .24826 .84105 .23739 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63909 .26469 .63064 Mtetra
.26469 .63064 .27467 .63909 .28986 .63452 .27993 .62602 Mtetra
.27993 .62602 .28986 .63452 .30513 .62993 .29526 .62138 Mtetra
.29526 .62138 .30513 .62993 .3205 .62531 .31068 .61671 Mtetra
.31068 .61671 .3205 .62531 .33595 .62066 .32619 .61201 Mtetra
.32619 .61201 .33595 .62066 .3515 .61598 .34179 .60728 Mtetra
.646 .763 .934 r
.34179 .60728 .3515 .61598 .36714 .61127 .35748 .60252 Mtetra
.35748 .60252 .36714 .61127 .38286 .60652 .37327 .59772 Mtetra
.647 .763 .934 r
.37327 .59772 .38286 .60652 .39869 .60172 .38915 .59289 Mtetra
.38915 .59289 .39869 .60172 .4146 .59687 .40512 .588 Mtetra
.648 .764 .933 r
.40512 .588 .4146 .59687 .43062 .59192 .4212 .58303 Mtetra
.651 .766 .933 r
.4212 .58303 .43062 .59192 .44673 .58682 .43737 .57795 Mtetra
.655 .769 .933 r
.43737 .57795 .44673 .58682 .46293 .58146 .45363 .57267 Mtetra
.663 .774 .932 r
.45363 .57267 .46293 .58146 .47924 .57563 .47 .56704 Mtetra
.679 .784 .93 r
.47 .56704 .47924 .57563 .49564 .56896 .48647 .56077 Mtetra
.705 .802 .925 r
.48647 .56077 .49564 .56896 .51213 .56075 .50303 .55336 Mtetra
.749 .83 .914 r
.50303 .55336 .51213 .56075 .52868 .54982 .51967 .5439 Mtetra
.814 .87 .888 r
.51967 .5439 .52868 .54982 .54525 .53435 .53636 .53087 Mtetra
.89 .911 .834 r
.53636 .53087 .54525 .53435 .56174 .51203 .55302 .51214 Mtetra
.949 .933 .746 r
.55302 .51214 .56174 .51203 .57802 .4812 .56954 .4855 Mtetra
.972 .929 .647 r
.56954 .4855 .57802 .4812 .59399 .44302 .58579 .45042 Mtetra
.968 .917 .579 r
.58579 .45042 .59399 .44302 .60966 .40267 .60171 .41013 Mtetra
.96 .92 .571 r
.60171 .41013 .60966 .40267 .62521 .36674 .6174 .3711 Mtetra
.958 .943 .64 r
.6174 .3711 .62521 .36674 .64084 .33894 .63308 .33889 Mtetra
.939 .955 .756 r
.63308 .33889 .64084 .33894 .65666 .31908 .6489 .31513 Mtetra
.878 .922 .85 r
.6489 .31513 .65666 .31908 .67271 .30508 .66495 .29838 Mtetra
.803 .864 .894 r
.66495 .29838 .67271 .30508 .68895 .29475 .68121 .28636 Mtetra
.744 .814 .907 r
.68121 .28636 .68895 .29475 .70537 .28655 .69766 .27717 Mtetra
.708 .782 .91 r
.69766 .27717 .70537 .28655 .72193 .27951 .71426 .26956 Mtetra
.687 .763 .91 r
.71426 .26956 .72193 .27951 .73862 .27309 .73101 .26279 Mtetra
.676 .753 .909 r
.73101 .26279 .73862 .27309 .75543 .26697 .74787 .25647 Mtetra
.67 .748 .909 r
.74787 .25647 .75543 .26697 .77234 .261 .76485 .25036 Mtetra
.667 .745 .908 r
.76485 .25036 .77234 .261 .78936 .2551 .78194 .24435 Mtetra
.665 .743 .908 r
.78194 .24435 .78936 .2551 .80649 .24921 .79914 .23837 Mtetra
.664 .742 .908 r
.79914 .23837 .80649 .24921 .82372 .24331 .81644 .2324 Mtetra
.81644 .2324 .82372 .24331 .84105 .23739 .83385 .22641 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62674 Mtetra
.2394 .62674 .24954 .63523 .26469 .63064 .2546 .6221 Mtetra
.2546 .6221 .26469 .63064 .27993 .62602 .2699 .61743 Mtetra
.2699 .61743 .27993 .62602 .29526 .62138 .28528 .61274 Mtetra
.28528 .61274 .29526 .62138 .31068 .61671 .30075 .60801 Mtetra
.30075 .60801 .31068 .61671 .32619 .61201 .31632 .60326 Mtetra
.31632 .60326 .32619 .61201 .34179 .60728 .33197 .59848 Mtetra
.33197 .59848 .34179 .60728 .35748 .60252 .34772 .59367 Mtetra
.646 .763 .934 r
.34772 .59367 .35748 .60252 .37327 .59772 .36357 .58883 Mtetra
.36357 .58883 .37327 .59772 .38915 .59289 .37951 .58395 Mtetra
.647 .763 .934 r
.37951 .58395 .38915 .59289 .40512 .588 .39554 .57902 Mtetra
.648 .764 .934 r
.39554 .57902 .40512 .588 .4212 .58303 .41167 .57402 Mtetra
.649 .765 .933 r
.41167 .57402 .4212 .58303 .43737 .57795 .4279 .56894 Mtetra
.653 .767 .933 r
.4279 .56894 .43737 .57795 .45363 .57267 .44423 .5637 Mtetra
.659 .771 .932 r
.44423 .5637 .45363 .57267 .47 .56704 .46066 .55819 Mtetra
.67 .778 .931 r
.46066 .55819 .47 .56704 .48647 .56077 .4772 .55222 Mtetra
.69 .792 .928 r
.4772 .55222 .48647 .56077 .50303 .55336 .49383 .54539 Mtetra
.725 .815 .921 r
.49383 .54539 .50303 .55336 .51967 .5439 .51055 .53702 Mtetra
.779 .849 .904 r
.51055 .53702 .51967 .5439 .53636 .53087 .52734 .5259 Mtetra
.852 .892 .865 r
.52734 .5259 .53636 .53087 .55302 .51214 .54414 .51021 Mtetra
.923 .926 .793 r
.54414 .51021 .55302 .51214 .56954 .4855 .56087 .48762 Mtetra
.965 .934 .695 r
.56087 .48762 .56954 .4855 .58579 .45042 .57739 .45647 Mtetra
.972 .923 .607 r
.57739 .45647 .58579 .45042 .60171 .41013 .59359 .41793 Mtetra
.963 .916 .566 r
.59359 .41793 .60171 .41013 .6174 .3711 .60948 .37722 Mtetra
.959 .93 .597 r
.60948 .37722 .6174 .3711 .63308 .33889 .62525 .34096 Mtetra
.953 .953 .696 r
.62525 .34096 .63308 .33889 .6489 .31513 .64109 .31287 Mtetra
.913 .944 .809 r
.64109 .31287 .6489 .31513 .66495 .29838 .65714 .29278 Mtetra
.84 .894 .878 r
.65714 .29278 .66495 .29838 .68121 .28636 .6734 .27858 Mtetra
.77 .837 .903 r
.6734 .27858 .68121 .28636 .69766 .27717 .68988 .26807 Mtetra
.724 .796 .909 r
.68988 .26807 .69766 .27717 .71426 .26956 .70652 .2597 Mtetra
.696 .771 .91 r
.70652 .2597 .71426 .26956 .73101 .26279 .72332 .2525 Mtetra
.681 .757 .909 r
.72332 .2525 .73101 .26279 .74787 .25647 .74024 .24591 Mtetra
.673 .75 .909 r
.74024 .24591 .74787 .25647 .76485 .25036 .75729 .23963 Mtetra
.668 .746 .908 r
.75729 .23963 .76485 .25036 .78194 .24435 .77445 .2335 Mtetra
.666 .744 .908 r
.77445 .2335 .78194 .24435 .79914 .23837 .79171 .22743 Mtetra
.665 .743 .908 r
.79171 .22743 .79914 .23837 .81644 .2324 .80909 .22137 Mtetra
.664 .742 .908 r
.80909 .22137 .81644 .2324 .83385 .22641 .82657 .21531 Mtetra
.646 .762 .934 r
.18391 .63206 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62674 .22915 .61815 Mtetra
.22915 .61815 .2394 .62674 .2546 .6221 .24441 .61346 Mtetra
.24441 .61346 .2546 .6221 .2699 .61743 .25975 .60874 Mtetra
.25975 .60874 .2699 .61743 .28528 .61274 .27519 .604 Mtetra
.27519 .604 .28528 .61274 .30075 .60801 .29072 .59923 Mtetra
.29072 .59923 .30075 .60801 .31632 .60326 .30634 .59442 Mtetra
.30634 .59442 .31632 .60326 .33197 .59848 .32205 .58959 Mtetra
.32205 .58959 .33197 .59848 .34772 .59367 .33786 .58473 Mtetra
.646 .763 .934 r
.33786 .58473 .34772 .59367 .36357 .58883 .35376 .57983 Mtetra
.35376 .57983 .36357 .58883 .37951 .58395 .36976 .5749 Mtetra
.647 .763 .934 r
.36976 .5749 .37951 .58395 .39554 .57902 .38585 .56993 Mtetra
.38585 .56993 .39554 .57902 .41167 .57402 .40204 .5649 Mtetra
.648 .764 .933 r
.40204 .5649 .41167 .57402 .4279 .56894 .41833 .5598 Mtetra
.651 .766 .933 r
.41833 .5598 .4279 .56894 .44423 .5637 .43473 .55457 Mtetra
.655 .769 .933 r
.43473 .55457 .44423 .5637 .46066 .55819 .45122 .54914 Mtetra
.663 .774 .932 r
.45122 .54914 .46066 .55819 .4772 .55222 .46782 .54337 Mtetra
.678 .784 .93 r
.46782 .54337 .4772 .55222 .49383 .54539 .48451 .53695 Mtetra
.705 .802 .925 r
.48451 .53695 .49383 .54539 .51055 .53702 .50131 .52938 Mtetra
.749 .831 .914 r
.50131 .52938 .51055 .53702 .52734 .5259 .51819 .51973 Mtetra
.814 .87 .888 r
.51819 .51973 .52734 .5259 .54414 .51021 .53512 .5065 Mtetra
.89 .911 .834 r
.53512 .5065 .54414 .51021 .56087 .48762 .55202 .48753 Mtetra
.949 .933 .746 r
.55202 .48753 .56087 .48762 .57739 .45647 .56878 .46059 Mtetra
.972 .929 .647 r
.56878 .46059 .57739 .45647 .59359 .41793 .58527 .42516 Mtetra
.968 .917 .578 r
.58527 .42516 .59359 .41793 .60948 .37722 .60142 .3845 Mtetra
.96 .92 .572 r
.60142 .3845 .60948 .37722 .62525 .34096 .61733 .34511 Mtetra
.958 .943 .64 r
.61733 .34511 .62525 .34096 .64109 .31287 .63323 .31259 Mtetra
.939 .955 .756 r
.63323 .31259 .64109 .31287 .65714 .29278 .64927 .28858 Mtetra
.878 .922 .85 r
.64927 .28858 .65714 .29278 .6734 .27858 .66554 .27162 Mtetra
.803 .864 .894 r
.66554 .27162 .6734 .27858 .68988 .26807 .68203 .2594 Mtetra
.744 .814 .907 r
.68203 .2594 .68988 .26807 .70652 .2597 .69871 .25003 Mtetra
.708 .782 .91 r
.69871 .25003 .70652 .2597 .72332 .2525 .71555 .24225 Mtetra
.687 .763 .91 r
.71555 .24225 .72332 .2525 .74024 .24591 .73253 .23531 Mtetra
.676 .753 .909 r
.73253 .23531 .74024 .24591 .75729 .23963 .74964 .22882 Mtetra
.67 .748 .909 r
.74964 .22882 .75729 .23963 .77445 .2335 .76687 .22255 Mtetra
.667 .745 .908 r
.76687 .22255 .77445 .2335 .79171 .22743 .7842 .21637 Mtetra
.665 .743 .908 r
.7842 .21637 .79171 .22743 .80909 .22137 .80165 .21023 Mtetra
.664 .742 .908 r
.80165 .21023 .80909 .22137 .82657 .21531 .81921 .20408 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63206 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .604 .26499 .59517 Mtetra
.26499 .59517 .27519 .604 .29072 .59923 .28057 .59034 Mtetra
.28057 .59034 .29072 .59923 .30634 .59442 .29625 .58548 Mtetra
.29625 .58548 .30634 .59442 .32205 .58959 .31202 .5806 Mtetra
.31202 .5806 .32205 .58959 .33786 .58473 .32788 .57569 Mtetra
.32788 .57569 .33786 .58473 .35376 .57983 .34384 .57074 Mtetra
.646 .763 .934 r
.34384 .57074 .35376 .57983 .36976 .5749 .3599 .56576 Mtetra
.3599 .56576 .36976 .5749 .38585 .56993 .37605 .56073 Mtetra
.647 .763 .934 r
.37605 .56073 .38585 .56993 .40204 .5649 .39231 .55566 Mtetra
.648 .764 .934 r
.39231 .55566 .40204 .5649 .41833 .5598 .40866 .55053 Mtetra
.649 .765 .933 r
.40866 .55053 .41833 .5598 .43473 .55457 .42511 .5453 Mtetra
.653 .767 .933 r
.42511 .5453 .43473 .55457 .45122 .54914 .44167 .53991 Mtetra
.659 .771 .932 r
.44167 .53991 .45122 .54914 .46782 .54337 .45833 .53426 Mtetra
.67 .778 .931 r
.45833 .53426 .46782 .54337 .48451 .53695 .47509 .52813 Mtetra
.69 .792 .928 r
.47509 .52813 .48451 .53695 .50131 .52938 .49196 .52114 Mtetra
.725 .815 .921 r
.49196 .52114 .50131 .52938 .51819 .51973 .50892 .5126 Mtetra
.779 .849 .904 r
.50892 .5126 .51819 .51973 .53512 .5065 .52595 .50129 Mtetra
.852 .892 .866 r
.52595 .50129 .53512 .5065 .55202 .48753 .543 .48537 Mtetra
.923 .926 .793 r
.543 .48537 .55202 .48753 .56878 .46059 .55998 .46251 Mtetra
.965 .934 .695 r
.55998 .46251 .56878 .46059 .58527 .42516 .57674 .43103 Mtetra
.972 .923 .607 r
.57674 .43103 .58527 .42516 .60142 .3845 .59317 .39212 Mtetra
.963 .916 .566 r
.59317 .39212 .60142 .3845 .61733 .34511 .6093 .35103 Mtetra
.959 .93 .597 r
.6093 .35103 .61733 .34511 .63323 .31259 .62529 .31444 Mtetra
.953 .953 .696 r
.62529 .31444 .63323 .31259 .64927 .28858 .64135 .28607 Mtetra
.913 .944 .809 r
.64135 .28607 .64927 .28858 .66554 .27162 .65762 .26575 Mtetra
.84 .894 .878 r
.65762 .26575 .66554 .27162 .68203 .2594 .67412 .25133 Mtetra
.77 .837 .903 r
.67412 .25133 .68203 .2594 .69871 .25003 .69082 .24064 Mtetra
.724 .796 .909 r
.69082 .24064 .69871 .25003 .71555 .24225 .70771 .23209 Mtetra
.696 .771 .91 r
.70771 .23209 .71555 .24225 .73253 .23531 .72474 .22472 Mtetra
.681 .757 .909 r
.72474 .22472 .73253 .23531 .74964 .22882 .74191 .21796 Mtetra
.673 .75 .909 r
.74191 .21796 .74964 .22882 .76687 .22255 .7592 .21151 Mtetra
.668 .746 .908 r
.7592 .21151 .76687 .22255 .7842 .21637 .77661 .20521 Mtetra
.666 .744 .908 r
.77661 .20521 .7842 .21637 .80165 .21023 .79413 .19896 Mtetra
.665 .743 .908 r
.79413 .19896 .80165 .21023 .81921 .20408 .81176 .19273 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .59591 Mtetra
.22368 .59591 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59517 .25468 .58623 Mtetra
.25468 .58623 .26499 .59517 .28057 .59034 .27032 .58136 Mtetra
.27032 .58136 .28057 .59034 .29625 .58548 .28605 .57645 Mtetra
.28605 .57645 .29625 .58548 .31202 .5806 .30187 .57151 Mtetra
.30187 .57151 .31202 .5806 .32788 .57569 .3178 .56654 Mtetra
.3178 .56654 .32788 .57569 .34384 .57074 .33381 .56154 Mtetra
.646 .763 .934 r
.33381 .56154 .34384 .57074 .3599 .56576 .34993 .5565 Mtetra
.34993 .5565 .3599 .56576 .37605 .56073 .36615 .55143 Mtetra
.647 .763 .934 r
.36615 .55143 .37605 .56073 .39231 .55566 .38246 .54631 Mtetra
.38246 .54631 .39231 .55566 .40866 .55053 .39887 .54114 Mtetra
.648 .764 .933 r
.39887 .54114 .40866 .55053 .42511 .5453 .41539 .53589 Mtetra
.651 .766 .933 r
.41539 .53589 .42511 .5453 .44167 .53991 .43201 .53052 Mtetra
.655 .769 .933 r
.43201 .53052 .44167 .53991 .45833 .53426 .44873 .52494 Mtetra
.663 .774 .932 r
.44873 .52494 .45833 .53426 .47509 .52813 .46556 .51901 Mtetra
.678 .784 .93 r
.46556 .51901 .47509 .52813 .49196 .52114 .4825 .51243 Mtetra
.705 .802 .925 r
.4825 .51243 .49196 .52114 .50892 .5126 .49954 .50469 Mtetra
.749 .831 .914 r
.49954 .50469 .50892 .5126 .52595 .50129 .51666 .49486 Mtetra
.814 .871 .888 r
.51666 .49486 .52595 .50129 .543 .48537 .53383 .48142 Mtetra
.89 .912 .834 r
.53383 .48142 .543 .48537 .55998 .46251 .55099 .46219 Mtetra
.949 .934 .746 r
.55099 .46219 .55998 .46251 .57674 .43103 .568 .43495 Mtetra
.972 .93 .647 r
.568 .43495 .57674 .43103 .59317 .39212 .58473 .39917 Mtetra
.967 .917 .578 r
.58473 .39917 .59317 .39212 .6093 .35103 .60111 .35813 Mtetra
.96 .92 .572 r
.60111 .35813 .6093 .35103 .62529 .31444 .61726 .31838 Mtetra
.958 .943 .64 r
.61726 .31838 .62529 .31444 .64135 .28607 .63338 .28555 Mtetra
.939 .955 .756 r
.63338 .28555 .64135 .28607 .65762 .26575 .64965 .26127 Mtetra
.878 .922 .85 r
.64965 .26127 .65762 .26575 .67412 .25133 .66615 .24409 Mtetra
.803 .864 .894 r
.66615 .24409 .67412 .25133 .69082 .24064 .68287 .23168 Mtetra
.744 .814 .907 r
.68287 .23168 .69082 .24064 .70771 .23209 .69979 .22212 Mtetra
.708 .782 .91 r
.69979 .22212 .70771 .23209 .72474 .22472 .71687 .21416 Mtetra
.687 .763 .909 r
.71687 .21416 .72474 .22472 .74191 .21796 .7341 .20705 Mtetra
.676 .753 .909 r
.7341 .20705 .74191 .21796 .7592 .21151 .75146 .20039 Mtetra
.67 .748 .909 r
.75146 .20039 .7592 .21151 .77661 .20521 .76894 .19394 Mtetra
.667 .745 .908 r
.76894 .19394 .77661 .20521 .79413 .19896 .78653 .18759 Mtetra
.665 .743 .908 r
.78653 .18759 .79413 .19896 .81176 .19273 .80423 .18127 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .59591 .21314 .58698 Mtetra
.21314 .58698 .22368 .59591 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58623 .24425 .57721 Mtetra
.24425 .57721 .25468 .58623 .27032 .58136 .25994 .57227 Mtetra
.25994 .57227 .27032 .58136 .28605 .57645 .27573 .56731 Mtetra
.27573 .56731 .28605 .57645 .30187 .57151 .29162 .56232 Mtetra
.29162 .56232 .30187 .57151 .3178 .56654 .3076 .55729 Mtetra
.3076 .55729 .3178 .56654 .33381 .56154 .32367 .55224 Mtetra
.32367 .55224 .33381 .56154 .34993 .5565 .33985 .54715 Mtetra
.646 .763 .934 r
.33985 .54715 .34993 .5565 .36615 .55143 .35613 .54202 Mtetra
.35613 .54202 .36615 .55143 .38246 .54631 .3725 .53685 Mtetra
.647 .763 .934 r
.3725 .53685 .38246 .54631 .39887 .54114 .38898 .53164 Mtetra
.648 .764 .934 r
.38898 .53164 .39887 .54114 .41539 .53589 .40556 .52635 Mtetra
.649 .765 .933 r
.40556 .52635 .41539 .53589 .43201 .53052 .42224 .52097 Mtetra
.653 .767 .933 r
.42224 .52097 .43201 .53052 .44873 .52494 .43903 .51543 Mtetra
.659 .771 .932 r
.43903 .51543 .44873 .52494 .46556 .51901 .45593 .50963 Mtetra
.67 .778 .931 r
.45593 .50963 .46556 .51901 .4825 .51243 .47293 .50334 Mtetra
.69 .792 .928 r
.47293 .50334 .4825 .51243 .49954 .50469 .49004 .49618 Mtetra
.725 .815 .921 r
.49004 .49618 .49954 .50469 .51666 .49486 .50725 .48745 Mtetra
.779 .85 .904 r
.50725 .48745 .51666 .49486 .53383 .48142 .52453 .47595 Mtetra
.852 .892 .866 r
.52453 .47595 .53383 .48142 .55099 .46219 .54183 .4598 Mtetra
.924 .926 .793 r
.54183 .4598 .55099 .46219 .568 .43495 .55906 .43666 Mtetra
.965 .934 .695 r
.55906 .43666 .568 .43495 .58473 .39917 .57607 .40484 Mtetra
.971 .923 .606 r
.57607 .40484 .58473 .39917 .60111 .35813 .59274 .36556 Mtetra
.963 .916 .566 r
.59274 .36556 .60111 .35813 .61726 .31838 .60911 .3241 Mtetra
.959 .93 .597 r
.60911 .3241 .61726 .31838 .63338 .28555 .62533 .28716 Mtetra
.953 .953 .696 r
.62533 .28716 .63338 .28555 .64965 .26127 .64162 .25851 Mtetra
.913 .944 .809 r
.64162 .25851 .64965 .26127 .66615 .24409 .65812 .23794 Mtetra
.84 .893 .878 r
.65812 .23794 .66615 .24409 .68287 .23168 .67485 .22331 Mtetra
.77 .837 .903 r
.67485 .22331 .68287 .23168 .69979 .22212 .6918 .21243 Mtetra
.724 .796 .909 r
.6918 .21243 .69979 .22212 .71687 .21416 .70892 .2037 Mtetra
.696 .771 .91 r
.70892 .2037 .71687 .21416 .7341 .20705 .72621 .19614 Mtetra
.681 .757 .909 r
.72621 .19614 .7341 .20705 .75146 .20039 .74363 .1892 Mtetra
.673 .75 .909 r
.74363 .1892 .75146 .20039 .76894 .19394 .76117 .18258 Mtetra
.668 .746 .908 r
.76117 .18258 .76894 .19394 .78653 .18759 .77884 .1761 Mtetra
.666 .744 .908 r
.77884 .1761 .78653 .18759 .80423 .18127 .79662 .16967 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .57721 .23371 .56808 Mtetra
.23371 .56808 .24425 .57721 .25994 .57227 .24946 .56309 Mtetra
.24946 .56309 .25994 .57227 .27573 .56731 .2653 .55807 Mtetra
.2653 .55807 .27573 .56731 .29162 .56232 .28124 .55302 Mtetra
.28124 .55302 .29162 .56232 .3076 .55729 .29728 .54794 Mtetra
.29728 .54794 .3076 .55729 .32367 .55224 .31342 .54283 Mtetra
.31342 .54283 .32367 .55224 .33985 .54715 .32966 .53768 Mtetra
.646 .763 .934 r
.32966 .53768 .33985 .54715 .35613 .54202 .34599 .5325 Mtetra
.34599 .5325 .35613 .54202 .3725 .53685 .36243 .52728 Mtetra
.647 .763 .934 r
.36243 .52728 .3725 .53685 .38898 .53164 .37897 .52201 Mtetra
.37897 .52201 .38898 .53164 .40556 .52635 .39561 .51669 Mtetra
.648 .764 .933 r
.39561 .51669 .40556 .52635 .42224 .52097 .41236 .51129 Mtetra
.651 .766 .933 r
.41236 .51129 .42224 .52097 .43903 .51543 .42921 .50576 Mtetra
.655 .769 .933 r
.42921 .50576 .43903 .51543 .45593 .50963 .44618 .50003 Mtetra
.663 .774 .932 r
.44618 .50003 .45593 .50963 .47293 .50334 .46325 .49393 Mtetra
.678 .784 .93 r
.46325 .49393 .47293 .50334 .49004 .49618 .48043 .48719 Mtetra
.705 .802 .925 r
.48043 .48719 .49004 .49618 .50725 .48745 .49771 .47927 Mtetra
.749 .831 .914 r
.49771 .47927 .50725 .48745 .52453 .47595 .51509 .46925 Mtetra
.814 .871 .888 r
.51509 .46925 .52453 .47595 .54183 .4598 .53252 .45559 Mtetra
.89 .912 .834 r
.53252 .45559 .54183 .4598 .55906 .43666 .54992 .4361 Mtetra
.949 .934 .745 r
.54992 .4361 .55906 .43666 .57607 .40484 .56719 .40856 Mtetra
.972 .93 .647 r
.56719 .40856 .57607 .40484 .59274 .36556 .58417 .37241 Mtetra
.967 .917 .578 r
.58417 .37241 .59274 .36556 .60911 .3241 .6008 .33099 Mtetra
.96 .92 .572 r
.6008 .33099 .60911 .3241 .62533 .28716 .61718 .29087 Mtetra
.958 .943 .641 r
.61718 .29087 .62533 .28716 .64162 .25851 .63353 .25773 Mtetra
.939 .954 .756 r
.63353 .25773 .64162 .25851 .65812 .23794 .65004 .23318 Mtetra
.878 .922 .85 r
.65004 .23318 .65812 .23794 .67485 .22331 .66677 .21577 Mtetra
.803 .864 .894 r
.66677 .21577 .67485 .22331 .6918 .21243 .68374 .20316 Mtetra
.744 .814 .907 r
.68374 .20316 .6918 .21243 .70892 .2037 .7009 .19341 Mtetra
.708 .782 .91 r
.7009 .19341 .70892 .2037 .72621 .19614 .71823 .18526 Mtetra
.687 .763 .909 r
.71823 .18526 .72621 .19614 .74363 .1892 .73571 .17797 Mtetra
.676 .753 .909 r
.73571 .17797 .74363 .1892 .76117 .18258 .75333 .17113 Mtetra
.67 .748 .909 r
.75333 .17113 .76117 .18258 .77884 .1761 .77106 .1645 Mtetra
.667 .745 .908 r
.77106 .1645 .77884 .1761 .79662 .16967 .78892 .15796 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56808 .22305 .55884 Mtetra
.22305 .55884 .23371 .56808 .24946 .56309 .23885 .5538 Mtetra
.23885 .5538 .24946 .56309 .2653 .55807 .25476 .54872 Mtetra
.25476 .54872 .2653 .55807 .28124 .55302 .27075 .54362 Mtetra
.27075 .54362 .28124 .55302 .29728 .54794 .28685 .53848 Mtetra
.28685 .53848 .29728 .54794 .31342 .54283 .30305 .53331 Mtetra
.30305 .53331 .31342 .54283 .32966 .53768 .31934 .52811 Mtetra
.31934 .52811 .32966 .53768 .34599 .5325 .33574 .52287 Mtetra
.646 .763 .934 r
.33574 .52287 .34599 .5325 .36243 .52728 .35224 .51759 Mtetra
.35224 .51759 .36243 .52728 .37897 .52201 .36884 .51227 Mtetra
.647 .763 .934 r
.36884 .51227 .37897 .52201 .39561 .51669 .38555 .5069 Mtetra
.648 .764 .934 r
.38555 .5069 .39561 .51669 .41236 .51129 .40236 .50147 Mtetra
.649 .765 .933 r
.40236 .50147 .41236 .51129 .42921 .50576 .41928 .49593 Mtetra
.653 .767 .933 r
.41928 .49593 .42921 .50576 .44618 .50003 .43631 .49023 Mtetra
.659 .771 .932 r
.43631 .49023 .44618 .50003 .46325 .49393 .45345 .48426 Mtetra
.67 .778 .931 r
.45345 .48426 .46325 .49393 .48043 .48719 .4707 .47781 Mtetra
.69 .792 .928 r
.4707 .47781 .48043 .48719 .49771 .47927 .48806 .47048 Mtetra
.725 .815 .921 r
.48806 .47048 .49771 .47927 .51509 .46925 .50552 .46156 Mtetra
.779 .85 .904 r
.50552 .46156 .51509 .46925 .53252 .45559 .52306 .44985 Mtetra
.852 .892 .866 r
.52306 .44985 .53252 .45559 .54992 .4361 .54062 .43346 Mtetra
.924 .926 .793 r
.54062 .43346 .54992 .4361 .56719 .40856 .55811 .41003 Mtetra
.965 .934 .695 r
.55811 .41003 .56719 .40856 .58417 .37241 .57537 .37787 Mtetra
.971 .923 .606 r
.57537 .37787 .58417 .37241 .6008 .33099 .5923 .33821 Mtetra
.963 .916 .566 r
.5923 .33821 .6008 .33099 .61718 .29087 .60891 .29637 Mtetra
.959 .93 .598 r
.60891 .29637 .61718 .29087 .63353 .25773 .62537 .25909 Mtetra
.953 .953 .697 r
.62537 .25909 .63353 .25773 .65004 .23318 .6419 .23014 Mtetra
.913 .944 .81 r
.6419 .23014 .65004 .23318 .66677 .21577 .65863 .20933 Mtetra
.84 .893 .878 r
.65863 .20933 .66677 .21577 .68374 .20316 .67561 .19448 Mtetra
.77 .837 .903 r
.67561 .19448 .68374 .20316 .7009 .19341 .6928 .1834 Mtetra
.724 .796 .909 r
.6928 .1834 .7009 .19341 .71823 .18526 .71018 .17448 Mtetra
.696 .771 .91 r
.71018 .17448 .71823 .18526 .73571 .17797 .72771 .16673 Mtetra
.681 .757 .909 r
.72771 .16673 .73571 .17797 .75333 .17113 .74539 .15961 Mtetra
.673 .75 .909 r
.74539 .15961 .75333 .17113 .77106 .1645 .7632 .1528 Mtetra
.668 .746 .908 r
.7632 .1528 .77106 .1645 .78892 .15796 .78113 .14613 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .5538 .22813 .54441 Mtetra
.22813 .54441 .23885 .5538 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27075 .54362 .26015 .53411 Mtetra
.26015 .53411 .27075 .54362 .28685 .53848 .2763 .52891 Mtetra
.2763 .52891 .28685 .53848 .30305 .53331 .29256 .52368 Mtetra
.29256 .52368 .30305 .53331 .31934 .52811 .30891 .51842 Mtetra
.30891 .51842 .31934 .52811 .33574 .52287 .32537 .51312 Mtetra
.646 .763 .934 r
.32537 .51312 .33574 .52287 .35224 .51759 .34194 .50779 Mtetra
.34194 .50779 .35224 .51759 .36884 .51227 .3586 .50242 Mtetra
.647 .763 .934 r
.3586 .50242 .36884 .51227 .38555 .5069 .37537 .49699 Mtetra
.37537 .49699 .38555 .5069 .40236 .50147 .39225 .49151 Mtetra
.648 .764 .933 r
.39225 .49151 .40236 .50147 .41928 .49593 .40924 .48595 Mtetra
.651 .766 .933 r
.40924 .48595 .41928 .49593 .43631 .49023 .42633 .48026 Mtetra
.655 .769 .933 r
.42633 .48026 .43631 .49023 .45345 .48426 .44354 .47437 Mtetra
.663 .774 .932 r
.44354 .47437 .45345 .48426 .4707 .47781 .46086 .4681 Mtetra
.678 .784 .93 r
.46086 .4681 .4707 .47781 .48806 .47048 .47829 .46119 Mtetra
.705 .802 .925 r
.47829 .46119 .48806 .47048 .50552 .46156 .49583 .45309 Mtetra
.749 .831 .914 r
.49583 .45309 .50552 .46156 .52306 .44985 .51346 .44287 Mtetra
.814 .871 .889 r
.51346 .44287 .52306 .44985 .54062 .43346 .53116 .42898 Mtetra
.89 .912 .834 r
.53116 .42898 .54062 .43346 .55811 .41003 .54883 .40923 Mtetra
.949 .934 .745 r
.54883 .40923 .55811 .41003 .57537 .37787 .56636 .38137 Mtetra
.972 .93 .646 r
.56636 .38137 .57537 .37787 .5923 .33821 .5836 .34485 Mtetra
.967 .917 .578 r
.5836 .34485 .5923 .33821 .60891 .29637 .60048 .30304 Mtetra
.96 .92 .572 r
.60048 .30304 .60891 .29637 .62537 .25909 .6171 .26256 Mtetra
.958 .943 .641 r
.6171 .26256 .62537 .25909 .6419 .23014 .63369 .22909 Mtetra
.939 .954 .756 r
.63369 .22909 .6419 .23014 .65863 .20933 .65044 .20428 Mtetra
.878 .921 .85 r
.65044 .20428 .65863 .20933 .67561 .19448 .66742 .18663 Mtetra
.803 .864 .894 r
.66742 .18663 .67561 .19448 .6928 .1834 .68463 .17381 Mtetra
.744 .814 .907 r
.68463 .17381 .6928 .1834 .71018 .17448 .70204 .16386 Mtetra
.708 .782 .91 r
.70204 .16386 .71018 .17448 .72771 .16673 .71963 .15552 Mtetra
.687 .763 .909 r
.71963 .15552 .72771 .16673 .74539 .15961 .73737 .14804 Mtetra
.676 .753 .909 r
.73737 .14804 .74539 .15961 .7632 .1528 .75525 .14101 Mtetra
.67 .748 .909 r
.75525 .14101 .7632 .1528 .78113 .14613 .77326 .13419 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54007 Mtetra
.20137 .54007 .21227 .54951 .22813 .54441 .21728 .53491 Mtetra
.21728 .53491 .22813 .54441 .24409 .53927 .2333 .52972 Mtetra
.2333 .52972 .24409 .53927 .26015 .53411 .24942 .52449 Mtetra
.24942 .52449 .26015 .53411 .2763 .52891 .26563 .51924 Mtetra
.26563 .51924 .2763 .52891 .29256 .52368 .28195 .51395 Mtetra
.28195 .51395 .29256 .52368 .30891 .51842 .29837 .50862 Mtetra
.29837 .50862 .30891 .51842 .32537 .51312 .31489 .50327 Mtetra
.31489 .50327 .32537 .51312 .34194 .50779 .33151 .49787 Mtetra
.646 .763 .934 r
.33151 .49787 .34194 .50779 .3586 .50242 .34824 .49244 Mtetra
.34824 .49244 .3586 .50242 .37537 .49699 .36508 .48696 Mtetra
.647 .763 .934 r
.36508 .48696 .37537 .49699 .39225 .49151 .38202 .48143 Mtetra
.648 .764 .934 r
.38202 .48143 .39225 .49151 .40924 .48595 .39908 .47583 Mtetra
.649 .765 .933 r
.39908 .47583 .40924 .48595 .42633 .48026 .41624 .47013 Mtetra
.653 .767 .933 r
.41624 .47013 .42633 .48026 .44354 .47437 .43351 .46427 Mtetra
.659 .771 .932 r
.43351 .46427 .44354 .47437 .46086 .4681 .4509 .45813 Mtetra
.67 .778 .931 r
.4509 .45813 .46086 .4681 .47829 .46119 .4684 .4515 Mtetra
.69 .792 .928 r
.4684 .4515 .47829 .46119 .49583 .45309 .48602 .44399 Mtetra
.725 .815 .921 r
.48602 .44399 .49583 .45309 .51346 .44287 .50374 .43488 Mtetra
.779 .85 .904 r
.50374 .43488 .51346 .44287 .53116 .42898 .52154 .42295 Mtetra
.852 .893 .866 r
.52154 .42295 .53116 .42898 .54883 .40923 .53937 .40632 Mtetra
.924 .927 .793 r
.53937 .40632 .54883 .40923 .56636 .38137 .55713 .3826 Mtetra
.965 .934 .694 r
.55713 .3826 .56636 .38137 .5836 .34485 .57466 .35009 Mtetra
.971 .923 .606 r
.57466 .35009 .5836 .34485 .60048 .30304 .59185 .31005 Mtetra
.963 .916 .566 r
.59185 .31005 .60048 .30304 .6171 .26256 .60871 .26782 Mtetra
.959 .93 .598 r
.60871 .26782 .6171 .26256 .63369 .22909 .62541 .23019 Mtetra
.953 .953 .697 r
.62541 .23019 .63369 .22909 .65044 .20428 .64218 .20095 Mtetra
.913 .943 .81 r
.64218 .20095 .65044 .20428 .66742 .18663 .65916 .17988 Mtetra
.84 .893 .878 r
.65916 .17988 .66742 .18663 .68463 .17381 .67639 .16481 Mtetra
.77 .837 .903 r
.67639 .16481 .68463 .17381 .70204 .16386 .69383 .15352 Mtetra
.724 .796 .909 r
.69383 .15352 .70204 .16386 .71963 .15552 .71147 .1444 Mtetra
.696 .771 .91 r
.71147 .1444 .71963 .15552 .73737 .14804 .72927 .13646 Mtetra
.681 .757 .909 r
.72927 .13646 .73737 .14804 .75525 .14101 .74721 .12914 Mtetra
.673 .75 .909 r
.74721 .12914 .75525 .14101 .77326 .13419 .76529 .12213 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54007 .19034 .53052 Mtetra
.19034 .53052 .20137 .54007 .21728 .53491 .20631 .5253 Mtetra
.20631 .5253 .21728 .53491 .2333 .52972 .22239 .52005 Mtetra
.22239 .52005 .2333 .52972 .24942 .52449 .23856 .51476 Mtetra
.23856 .51476 .24942 .52449 .26563 .51924 .25484 .50945 Mtetra
.25484 .50945 .26563 .51924 .28195 .51395 .27121 .5041 Mtetra
.27121 .5041 .28195 .51395 .29837 .50862 .28769 .49871 Mtetra
.28769 .49871 .29837 .50862 .31489 .50327 .30428 .49329 Mtetra
.30428 .49329 .31489 .50327 .33151 .49787 .32097 .48784 Mtetra
.646 .763 .934 r
.32097 .48784 .33151 .49787 .34824 .49244 .33776 .48235 Mtetra
.33776 .48235 .34824 .49244 .36508 .48696 .35466 .47681 Mtetra
.647 .763 .934 r
.35466 .47681 .36508 .48696 .38202 .48143 .37167 .47123 Mtetra
.37167 .47123 .38202 .48143 .39908 .47583 .38879 .46558 Mtetra
.648 .764 .933 r
.38879 .46558 .39908 .47583 .41624 .47013 .40602 .45985 Mtetra
.651 .766 .933 r
.40602 .45985 .41624 .47013 .43351 .46427 .42337 .454 Mtetra
.655 .769 .933 r
.42337 .454 .43351 .46427 .4509 .45813 .44083 .44793 Mtetra
.663 .774 .932 r
.44083 .44793 .4509 .45813 .4684 .4515 .4584 .44149 Mtetra
.678 .784 .93 r
.4584 .44149 .4684 .4515 .48602 .44399 .47609 .43439 Mtetra
.705 .802 .925 r
.47609 .43439 .48602 .44399 .50374 .43488 .49389 .4261 Mtetra
.749 .831 .914 r
.49389 .4261 .50374 .43488 .52154 .42295 .51179 .41567 Mtetra
.814 .871 .889 r
.51179 .41567 .52154 .42295 .53937 .40632 .52975 .40155 Mtetra
.89 .912 .834 r
.52975 .40155 .53937 .40632 .55713 .3826 .5477 .38153 Mtetra
.949 .934 .745 r
.5477 .38153 .55713 .3826 .57466 .35009 .5655 .35335 Mtetra
.972 .93 .646 r
.5655 .35335 .57466 .35009 .59185 .31005 .583 .31646 Mtetra
.967 .917 .578 r
.583 .31646 .59185 .31005 .60871 .26782 .60014 .27426 Mtetra
.96 .92 .572 r
.60014 .27426 .60871 .26782 .62541 .23019 .61702 .2334 Mtetra
.959 .942 .642 r
.61702 .2334 .62541 .23019 .64218 .20095 .63386 .19961 Mtetra
.939 .954 .757 r
.63386 .19961 .64218 .20095 .65916 .17988 .65085 .17452 Mtetra
.878 .921 .85 r
.65085 .17452 .65916 .17988 .67639 .16481 .66808 .15663 Mtetra
.803 .863 .894 r
.66808 .15663 .67639 .16481 .69383 .15352 .68554 .14359 Mtetra
.744 .814 .907 r
.68554 .14359 .69383 .15352 .71147 .1444 .70322 .13343 Mtetra
.708 .782 .91 r
.70322 .13343 .71147 .1444 .72927 .13646 .72107 .1249 Mtetra
.687 .763 .909 r
.72107 .1249 .72927 .13646 .74721 .12914 .73908 .11722 Mtetra
.676 .753 .909 r
.73908 .11722 .74721 .12914 .76529 .12213 .75723 .10999 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52005 .21135 .51027 Mtetra
.21135 .51027 .22239 .52005 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50945 .24392 .49955 Mtetra
.24392 .49955 .25484 .50945 .27121 .5041 .26036 .49413 Mtetra
.26036 .49413 .27121 .5041 .28769 .49871 .2769 .48869 Mtetra
.2769 .48869 .28769 .49871 .30428 .49329 .29354 .48321 Mtetra
.29354 .48321 .30428 .49329 .32097 .48784 .3103 .47769 Mtetra
.3103 .47769 .32097 .48784 .33776 .48235 .32716 .47213 Mtetra
.646 .763 .934 r
.32716 .47213 .33776 .48235 .35466 .47681 .34412 .46653 Mtetra
.34412 .46653 .35466 .47681 .37167 .47123 .3612 .46089 Mtetra
.647 .763 .934 r
.3612 .46089 .37167 .47123 .38879 .46558 .37839 .4552 Mtetra
.648 .764 .934 r
.37839 .4552 .38879 .46558 .40602 .45985 .39569 .44943 Mtetra
.649 .765 .933 r
.39569 .44943 .40602 .45985 .42337 .454 .4131 .44355 Mtetra
.653 .767 .933 r
.4131 .44355 .42337 .454 .44083 .44793 .43063 .43752 Mtetra
.659 .771 .932 r
.43063 .43752 .44083 .44793 .4584 .44149 .44827 .4312 Mtetra
.67 .779 .931 r
.44827 .4312 .4584 .44149 .47609 .43439 .46604 .42439 Mtetra
.69 .792 .928 r
.46604 .42439 .47609 .43439 .49389 .4261 .48392 .41669 Mtetra
.725 .815 .921 r
.48392 .41669 .49389 .4261 .51179 .41567 .50191 .40738 Mtetra
.779 .85 .904 r
.50191 .40738 .51179 .41567 .52975 .40155 .51998 .39523 Mtetra
.852 .893 .866 r
.51998 .39523 .52975 .40155 .5477 .38153 .53809 .37834 Mtetra
.924 .927 .793 r
.53809 .37834 .5477 .38153 .5655 .35335 .55612 .35432 Mtetra
.965 .935 .694 r
.55612 .35432 .5655 .35335 .583 .31646 .57393 .32146 Mtetra
.971 .923 .606 r
.57393 .32146 .583 .31646 .60014 .27426 .59138 .28102 Mtetra
.963 .916 .566 r
.59138 .28102 .60014 .27426 .61702 .2334 .6085 .23841 Mtetra
.96 .93 .598 r
.6085 .23841 .61702 .2334 .63386 .19961 .62545 .20043 Mtetra
.953 .952 .697 r
.62545 .20043 .63386 .19961 .65085 .17452 .64248 .17088 Mtetra
.913 .943 .81 r
.64248 .17088 .65085 .17452 .66808 .15663 .65971 .14955 Mtetra
.839 .893 .878 r
.65971 .14955 .66808 .15663 .68554 .14359 .67719 .13425 Mtetra
.77 .837 .903 r
.67719 .13425 .68554 .14359 .70322 .13343 .69489 .12274 Mtetra
.724 .796 .909 r
.69489 .12274 .70322 .13343 .72107 .1249 .7128 .11341 Mtetra
.696 .771 .91 r
.7128 .11341 .72107 .1249 .73908 .11722 .73087 .10527 Mtetra
.681 .757 .909 r
.73087 .10527 .73908 .11722 .75723 .10999 .74908 .09776 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50038 Mtetra
.20018 .50038 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49955 .23287 .48953 Mtetra
.23287 .48953 .24392 .49955 .26036 .49413 .24937 .48405 Mtetra
.24937 .48405 .26036 .49413 .2769 .48869 .26597 .47854 Mtetra
.26597 .47854 .2769 .48869 .29354 .48321 .28268 .473 Mtetra
.28268 .473 .29354 .48321 .3103 .47769 .2995 .46741 Mtetra
.2995 .46741 .3103 .47769 .32716 .47213 .31642 .46179 Mtetra
.646 .763 .934 r
.31642 .46179 .32716 .47213 .34412 .46653 .33346 .45613 Mtetra
.33346 .45613 .34412 .46653 .3612 .46089 .3506 .45043 Mtetra
.647 .763 .934 r
.3506 .45043 .3612 .46089 .37839 .4552 .36786 .44468 Mtetra
.36786 .44468 .37839 .4552 .39569 .44943 .38523 .43886 Mtetra
.648 .764 .933 r
.38523 .43886 .39569 .44943 .4131 .44355 .40271 .43296 Mtetra
.651 .766 .933 r
.40271 .43296 .4131 .44355 .43063 .43752 .42031 .42692 Mtetra
.655 .769 .933 r
.42031 .42692 .43063 .43752 .44827 .4312 .43803 .42067 Mtetra
.663 .774 .932 r
.43803 .42067 .44827 .4312 .46604 .42439 .45586 .41406 Mtetra
.678 .784 .93 r
.45586 .41406 .46604 .42439 .48392 .41669 .47382 .40677 Mtetra
.705 .802 .925 r
.47382 .40677 .48392 .41669 .50191 .40738 .49189 .39828 Mtetra
.749 .831 .915 r
.49189 .39828 .50191 .40738 .51998 .39523 .51007 .38763 Mtetra
.814 .871 .889 r
.51007 .38763 .51998 .39523 .53809 .37834 .52831 .37327 Mtetra
.89 .913 .834 r
.52831 .37327 .53809 .37834 .55612 .35432 .54653 .35297 Mtetra
.949 .934 .745 r
.54653 .35297 .55612 .35432 .57393 .32146 .56462 .32446 Mtetra
.972 .93 .646 r
.56462 .32446 .57393 .32146 .59138 .28102 .5824 .2872 Mtetra
.967 .917 .578 r
.5824 .2872 .59138 .28102 .6085 .23841 .5998 .24459 Mtetra
.96 .92 .573 r
.5998 .24459 .6085 .23841 .62545 .20043 .61694 .20336 Mtetra
.959 .942 .642 r
.61694 .20336 .62545 .20043 .64248 .17088 .63403 .16924 Mtetra
.939 .954 .757 r
.63403 .16924 .64248 .17088 .65971 .14955 .65128 .14386 Mtetra
.878 .921 .85 r
.65128 .14386 .65971 .14955 .67719 .13425 .66876 .12573 Mtetra
.803 .863 .894 r
.66876 .12573 .67719 .13425 .69489 .12274 .68649 .11246 Mtetra
.744 .814 .907 r
.68649 .11246 .69489 .12274 .7128 .11341 .70443 .10209 Mtetra
.708 .782 .91 r
.70443 .10209 .7128 .11341 .73087 .10527 .72256 .09335 Mtetra
.687 .763 .909 r
.72256 .09335 .73087 .10527 .74908 .09776 .74084 .08546 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50038 .18889 .49037 Mtetra
.18889 .49037 .20018 .50038 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48953 .2217 .47939 Mtetra
.2217 .47939 .23287 .48953 .24937 .48405 .23826 .47385 Mtetra
.23826 .47385 .24937 .48405 .26597 .47854 .25492 .46828 Mtetra
.25492 .46828 .26597 .47854 .28268 .473 .2717 .46267 Mtetra
.2717 .46267 .28268 .473 .2995 .46741 .28858 .45702 Mtetra
.28858 .45702 .2995 .46741 .31642 .46179 .30557 .45133 Mtetra
.30557 .45133 .31642 .46179 .33346 .45613 .32267 .44561 Mtetra
.646 .763 .934 r
.32267 .44561 .33346 .45613 .3506 .45043 .33988 .43984 Mtetra
.33988 .43984 .3506 .45043 .36786 .44468 .3572 .43402 Mtetra
.647 .763 .934 r
.3572 .43402 .36786 .44468 .38523 .43886 .37464 .42815 Mtetra
.648 .764 .934 r
.37464 .42815 .38523 .43886 .40271 .43296 .39219 .42221 Mtetra
.649 .765 .933 r
.39219 .42221 .40271 .43296 .42031 .42692 .40987 .41615 Mtetra
.653 .767 .933 r
.40987 .41615 .42031 .42692 .43803 .42067 .42766 .40994 Mtetra
.659 .771 .932 r
.42766 .40994 .43803 .42067 .45586 .41406 .44557 .40344 Mtetra
.67 .779 .931 r
.44557 .40344 .45586 .41406 .47382 .40677 .4636 .39644 Mtetra
.69 .792 .928 r
.4636 .39644 .47382 .40677 .49189 .39828 .48175 .38854 Mtetra
.725 .815 .921 r
.48175 .38854 .49189 .39828 .51007 .38763 .50002 .37901 Mtetra
.779 .85 .904 r
.50002 .37901 .51007 .38763 .52831 .37327 .51837 .36663 Mtetra
.852 .893 .866 r
.51837 .36663 .52831 .37327 .54653 .35297 .53676 .34948 Mtetra
.924 .927 .793 r
.53676 .34948 .54653 .35297 .56462 .32446 .55508 .32515 Mtetra
.965 .935 .694 r
.55508 .32515 .56462 .32446 .5824 .2872 .57317 .29194 Mtetra
.971 .923 .605 r
.57317 .29194 .5824 .2872 .5998 .24459 .5909 .25111 Mtetra
.963 .916 .566 r
.5909 .25111 .5998 .24459 .61694 .20336 .60828 .2081 Mtetra
.96 .93 .599 r
.60828 .2081 .61694 .20336 .63403 .16924 .6255 .16976 Mtetra
.953 .952 .698 r
.6255 .16976 .63403 .16924 .65128 .14386 .64278 .1399 Mtetra
.913 .943 .81 r
.64278 .1399 .65128 .14386 .66876 .12573 .66027 .1183 Mtetra
.839 .893 .878 r
.66027 .1183 .66876 .12573 .68649 .11246 .67801 .10277 Mtetra
.77 .836 .903 r
.67801 .10277 .68649 .11246 .70443 .10209 .69599 .09104 Mtetra
.724 .796 .909 r
.69599 .09104 .70443 .10209 .72256 .09335 .71416 .08149 Mtetra
.696 .771 .91 r
.71416 .08149 .72256 .09335 .74084 .08546 .73251 .07314 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47385 .22701 .46353 Mtetra
.22701 .46353 .23826 .47385 .25492 .46828 .24374 .45789 Mtetra
.24374 .45789 .25492 .46828 .2717 .46267 .26058 .45221 Mtetra
.26058 .45221 .2717 .46267 .28858 .45702 .27752 .4465 Mtetra
.27752 .4465 .28858 .45702 .30557 .45133 .29458 .44074 Mtetra
.29458 .44074 .30557 .45133 .32267 .44561 .31175 .43495 Mtetra
.646 .763 .934 r
.31175 .43495 .32267 .44561 .33988 .43984 .32902 .42912 Mtetra
.32902 .42912 .33988 .43984 .3572 .43402 .34642 .42324 Mtetra
.647 .763 .934 r
.34642 .42324 .3572 .43402 .37464 .42815 .36393 .4173 Mtetra
.36393 .4173 .37464 .42815 .39219 .42221 .38155 .41131 Mtetra
.648 .764 .933 r
.38155 .41131 .39219 .42221 .40987 .41615 .39929 .40522 Mtetra
.651 .766 .933 r
.39929 .40522 .40987 .41615 .42766 .40994 .41716 .39901 Mtetra
.655 .769 .933 r
.41716 .39901 .42766 .40994 .44557 .40344 .43514 .39257 Mtetra
.663 .774 .932 r
.43514 .39257 .44557 .40344 .4636 .39644 .45325 .38576 Mtetra
.678 .784 .93 r
.45325 .38576 .4636 .39644 .48175 .38854 .47148 .37828 Mtetra
.705 .802 .925 r
.47148 .37828 .48175 .38854 .50002 .37901 .48983 .36958 Mtetra
.749 .831 .915 r
.48983 .36958 .50002 .37901 .51837 .36663 .50829 .35871 Mtetra
.814 .871 .889 r
.50829 .35871 .51837 .36663 .53676 .34948 .52682 .3441 Mtetra
.89 .913 .834 r
.52682 .3441 .53676 .34948 .55508 .32515 .54533 .32351 Mtetra
.949 .935 .745 r
.54533 .32351 .55508 .32515 .57317 .29194 .5637 .29466 Mtetra
.971 .93 .645 r
.5637 .29466 .57317 .29194 .5909 .25111 .58177 .25701 Mtetra
.967 .917 .578 r
.58177 .25701 .5909 .25111 .60828 .2081 .59945 .21401 Mtetra
.96 .92 .573 r
.59945 .21401 .60828 .2081 .6255 .16976 .61685 .1724 Mtetra
.959 .942 .642 r
.61685 .1724 .6255 .16976 .64278 .1399 .6342 .13794 Mtetra
.939 .954 .757 r
.6342 .13794 .64278 .1399 .66027 .1183 .65171 .11228 Mtetra
.878 .921 .85 r
.65171 .11228 .66027 .1183 .67801 .10277 .66946 .09389 Mtetra
.803 .863 .894 r
.66946 .09389 .67801 .10277 .69599 .09104 .68746 .08039 Mtetra
.744 .814 .907 r
.68746 .08039 .69599 .09104 .71416 .08149 .70568 .0698 Mtetra
.708 .782 .909 r
.70568 .0698 .71416 .08149 .73251 .07314 .72409 .06083 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45789 .23242 .44738 Mtetra
.23242 .44738 .24374 .45789 .26058 .45221 .24932 .44164 Mtetra
.24932 .44164 .26058 .45221 .27752 .4465 .26633 .43585 Mtetra
.26633 .43585 .27752 .4465 .29458 .44074 .28346 .43003 Mtetra
.28346 .43003 .29458 .44074 .31175 .43495 .30069 .42417 Mtetra
.30069 .42417 .31175 .43495 .32902 .42912 .31804 .41826 Mtetra
.646 .763 .934 r
.31804 .41826 .32902 .42912 .34642 .42324 .3355 .41232 Mtetra
.3355 .41232 .34642 .42324 .36393 .4173 .35308 .40632 Mtetra
.647 .763 .934 r
.35308 .40632 .36393 .4173 .38155 .41131 .37078 .40026 Mtetra
.648 .764 .934 r
.37078 .40026 .38155 .41131 .39929 .40522 .38859 .39413 Mtetra
.649 .765 .933 r
.38859 .39413 .39929 .40522 .41716 .39901 .40653 .38789 Mtetra
.653 .767 .933 r
.40653 .38789 .41716 .39901 .43514 .39257 .42459 .38149 Mtetra
.659 .771 .932 r
.42459 .38149 .43514 .39257 .45325 .38576 .44277 .37479 Mtetra
.67 .779 .931 r
.44277 .37479 .45325 .38576 .47148 .37828 .46108 .36759 Mtetra
.69 .792 .928 r
.46108 .36759 .47148 .37828 .48983 .36958 .47952 .35949 Mtetra
.724 .815 .921 r
.47952 .35949 .48983 .36958 .50829 .35871 .49807 .34975 Mtetra
.779 .85 .904 r
.49807 .34975 .50829 .35871 .52682 .3441 .51671 .33713 Mtetra
.852 .893 .866 r
.51671 .33713 .52682 .3441 .54533 .32351 .5354 .3197 Mtetra
.924 .927 .793 r
.5354 .3197 .54533 .32351 .5637 .29466 .55401 .29506 Mtetra
.965 .935 .694 r
.55401 .29506 .5637 .29466 .58177 .25701 .57239 .26148 Mtetra
.971 .923 .605 r
.57239 .26148 .58177 .25701 .59945 .21401 .5904 .22025 Mtetra
.963 .916 .566 r
.5904 .22025 .59945 .21401 .61685 .1724 .60806 .17684 Mtetra
.96 .93 .599 r
.60806 .17684 .61685 .1724 .6342 .13794 .62554 .13814 Mtetra
.954 .952 .698 r
.62554 .13814 .6342 .13794 .65171 .11228 .64309 .10797 Mtetra
.913 .943 .81 r
.64309 .10797 .65171 .11228 .66946 .09389 .66085 .0861 Mtetra
.839 .892 .877 r
.66085 .0861 .66946 .09389 .68746 .08039 .67886 .07032 Mtetra
.77 .836 .902 r
.67886 .07032 .68746 .08039 .70568 .0698 .69712 .05836 Mtetra
.724 .796 .909 r
.69712 .05836 .70568 .0698 .72409 .06083 .71557 .04859 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45397 Mtetra
.17073 .45397 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44738 .22097 .43674 Mtetra
.22097 .43674 .23242 .44738 .24932 .44164 .23793 .43093 Mtetra
.23793 .43093 .24932 .44164 .26633 .43585 .25501 .42508 Mtetra
.25501 .42508 .26633 .43585 .28346 .43003 .2722 .41918 Mtetra
.2722 .41918 .28346 .43003 .30069 .42417 .2895 .41325 Mtetra
.2895 .41325 .30069 .42417 .31804 .41826 .30692 .40728 Mtetra
.646 .763 .934 r
.30692 .40728 .31804 .41826 .3355 .41232 .32445 .40126 Mtetra
.32445 .40126 .3355 .41232 .35308 .40632 .3421 .39519 Mtetra
.647 .763 .934 r
.3421 .39519 .35308 .40632 .37078 .40026 .35987 .38908 Mtetra
.35987 .38908 .37078 .40026 .38859 .39413 .37776 .38289 Mtetra
.648 .764 .933 r
.37776 .38289 .38859 .39413 .40653 .38789 .39577 .37661 Mtetra
.651 .766 .933 r
.39577 .37661 .40653 .38789 .42459 .38149 .4139 .3702 Mtetra
.655 .769 .933 r
.4139 .3702 .42459 .38149 .44277 .37479 .43216 .36357 Mtetra
.663 .774 .932 r
.43216 .36357 .44277 .37479 .46108 .36759 .45055 .35656 Mtetra
.678 .784 .93 r
.45055 .35656 .46108 .36759 .47952 .35949 .46907 .34887 Mtetra
.705 .802 .925 r
.46907 .34887 .47952 .35949 .49807 .34975 .48771 .33996 Mtetra
.749 .831 .915 r
.48771 .33996 .49807 .34975 .51671 .33713 .50646 .32886 Mtetra
.814 .872 .889 r
.50646 .32886 .51671 .33713 .5354 .3197 .52528 .31399 Mtetra
.89 .913 .834 r
.52528 .31399 .5354 .3197 .55401 .29506 .54409 .29311 Mtetra
.949 .935 .745 r
.54409 .29311 .55401 .29506 .57239 .26148 .56276 .26391 Mtetra
.971 .93 .645 r
.56276 .26391 .57239 .26148 .5904 .22025 .58112 .22588 Mtetra
.967 .917 .577 r
.58112 .22588 .5904 .22025 .60806 .17684 .59908 .18246 Mtetra
.96 .92 .573 r
.59908 .18246 .60806 .17684 .62554 .13814 .61676 .14047 Mtetra
.959 .942 .643 r
.61676 .14047 .62554 .13814 .64309 .10797 .63438 .10567 Mtetra
.939 .953 .757 r
.63438 .10567 .64309 .10797 .66085 .0861 .65216 .07971 Mtetra
.878 .92 .85 r
.65216 .07971 .66085 .0861 .67886 .07032 .67019 .06107 Mtetra
.803 .863 .894 r
.67019 .06107 .67886 .07032 .69712 .05836 .68847 .04732 Mtetra
.744 .814 .907 r
.68847 .04732 .69712 .05836 .71557 .04859 .70697 .0365 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45397 .15895 .44341 Mtetra
.15895 .44341 .17073 .45397 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43183 Mtetra
.19246 .43183 .20411 .44252 .22097 .43674 .20938 .42598 Mtetra
.20938 .42598 .22097 .43674 .23793 .43093 .22641 .42009 Mtetra
.22641 .42009 .23793 .43093 .25501 .42508 .24355 .41417 Mtetra
.24355 .41417 .25501 .42508 .2722 .41918 .26081 .4082 Mtetra
.26081 .4082 .2722 .41918 .2895 .41325 .27818 .4022 Mtetra
.27818 .4022 .2895 .41325 .30692 .40728 .29566 .39615 Mtetra
.29566 .39615 .30692 .40728 .32445 .40126 .31327 .39006 Mtetra
.646 .763 .934 r
.31327 .39006 .32445 .40126 .3421 .39519 .33099 .38393 Mtetra
.33099 .38393 .3421 .39519 .35987 .38908 .34883 .37774 Mtetra
.647 .763 .934 r
.34883 .37774 .35987 .38908 .37776 .38289 .36679 .37149 Mtetra
.648 .764 .934 r
.36679 .37149 .37776 .38289 .39577 .37661 .38488 .36517 Mtetra
.649 .765 .933 r
.38488 .36517 .39577 .37661 .4139 .3702 .40309 .35873 Mtetra
.653 .767 .933 r
.40309 .35873 .4139 .3702 .43216 .36357 .42142 .35213 Mtetra
.659 .771 .932 r
.42142 .35213 .43216 .36357 .45055 .35656 .43989 .34523 Mtetra
.67 .779 .931 r
.43989 .34523 .45055 .35656 .46907 .34887 .45848 .33782 Mtetra
.69 .792 .928 r
.45848 .33782 .46907 .34887 .48771 .33996 .47721 .3295 Mtetra
.724 .815 .921 r
.47721 .3295 .48771 .33996 .50646 .32886 .49605 .31953 Mtetra
.779 .85 .905 r
.49605 .31953 .50646 .32886 .52528 .31399 .515 .30667 Mtetra
.852 .894 .866 r
.515 .30667 .52528 .31399 .54409 .29311 .53398 .28896 Mtetra
.924 .928 .793 r
.53398 .28896 .54409 .29311 .56276 .26391 .5529 .264 Mtetra
.965 .935 .693 r
.5529 .264 .56276 .26391 .58112 .22588 .57158 .23005 Mtetra
.971 .923 .605 r
.57158 .23005 .58112 .22588 .59908 .18246 .58989 .18841 Mtetra
.963 .916 .566 r
.58989 .18841 .59908 .18246 .61676 .14047 .60783 .1446 Mtetra
.96 .93 .599 r
.60783 .1446 .61676 .14047 .63438 .10567 .62559 .10553 Mtetra
.954 .952 .698 r
.62559 .10553 .63438 .10567 .65216 .07971 .64341 .07505 Mtetra
.913 .942 .81 r
.64341 .07505 .65216 .07971 .67019 .06107 .66144 .0529 Mtetra
.839 .892 .877 r
.66144 .0529 .67019 .06107 .68847 .04732 .67974 .03686 Mtetra
.77 .836 .902 r
.67974 .03686 .68847 .04732 .70697 .0365 .69828 .02466 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43183 .18066 .421 Mtetra
.18066 .421 .19246 .43183 .20938 .42598 .19765 .41508 Mtetra
.19765 .41508 .20938 .42598 .22641 .42009 .21474 .40913 Mtetra
.21474 .40913 .22641 .42009 .24355 .41417 .23195 .40313 Mtetra
.23195 .40313 .24355 .41417 .26081 .4082 .24927 .39709 Mtetra
.24927 .39709 .26081 .4082 .27818 .4022 .26671 .39101 Mtetra
.26671 .39101 .27818 .4022 .29566 .39615 .28427 .38489 Mtetra
.28427 .38489 .29566 .39615 .31327 .39006 .30194 .37873 Mtetra
.646 .763 .934 r
.30194 .37873 .31327 .39006 .33099 .38393 .31974 .37252 Mtetra
.31974 .37252 .33099 .38393 .34883 .37774 .33765 .36626 Mtetra
.647 .763 .934 r
.33765 .36626 .34883 .37774 .36679 .37149 .35569 .35995 Mtetra
.35569 .35995 .36679 .37149 .38488 .36517 .37385 .35356 Mtetra
.648 .764 .933 r
.37385 .35356 .38488 .36517 .40309 .35873 .39213 .34709 Mtetra
.651 .766 .933 r
.39213 .34709 .40309 .35873 .42142 .35213 .41055 .34047 Mtetra
.655 .769 .933 r
.41055 .34047 .42142 .35213 .43989 .34523 .42909 .33364 Mtetra
.663 .774 .932 r
.42909 .33364 .43989 .34523 .45848 .33782 .44776 .32642 Mtetra
.678 .784 .93 r
.44776 .32642 .45848 .33782 .47721 .3295 .46657 .31851 Mtetra
.705 .802 .925 r
.46657 .31851 .47721 .3295 .49605 .31953 .48551 .30937 Mtetra
.749 .831 .915 r
.48551 .30937 .49605 .31953 .515 .30667 .50456 .29803 Mtetra
.814 .872 .889 r
.50456 .29803 .515 .30667 .53398 .28896 .52369 .28289 Mtetra
.89 .913 .834 r
.52369 .28289 .53398 .28896 .5529 .264 .54281 .26171 Mtetra
.95 .935 .744 r
.54281 .26171 .5529 .264 .57158 .23005 .56179 .23216 Mtetra
.971 .93 .645 r
.56179 .23216 .57158 .23005 .58989 .18841 .58045 .19373 Mtetra
.967 .917 .577 r
.58045 .19373 .58989 .18841 .60783 .1446 .59871 .14991 Mtetra
.961 .92 .573 r
.59871 .14991 .60783 .1446 .62559 .10553 .61667 .10752 Mtetra
.959 .942 .643 r
.61667 .10752 .62559 .10553 .64341 .07505 .63457 .07238 Mtetra
.939 .953 .757 r
.63457 .07238 .64341 .07505 .66144 .0529 .65263 .04613 Mtetra
.878 .92 .85 r
.65263 .04613 .66144 .0529 .67974 .03686 .67094 .02721 Mtetra
.803 .863 .894 r
.67094 .02721 .67974 .03686 .69828 .02466 .6895 .01321 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001oogooOol0
07oo0000Egoo003EOol30008Ool200000goo001oo`1EOol00=9oo`<000Yoo`05He/007ooOol0001F
Ool00=1oo`8000aoo`04He]WO000Ig`2Ool00`00Oomoo`1COol00<eoo`<000aoo`07IgaSFfMlHe/0
06=KIg`00Woo00<007ooOol0DWoo003;Ool2000>Ool01fMlHe]WO6MKIg`006Ml009SG003Ool007oo
05=oo`00b7oo0`0000=oo`00Ool037oo00Y_^fnJIgaSFfMlHe]SG000HeaO>`9oo`03001oogoo055o
o`00Igoo0P000Woo0P00FGoo0P0017oo00<007ooOol02Woo00I_^VnJKiYWFfMlHe/2He`01000GeaS
G6=L0Woo00<007ooOol0D7oo001XOol01000Oomoo`00Egoo0`004Woo011_^fnJKkY_VVnkGc]SG5lk
He`006=LGc]O?5/lOol0059oo`00JGoo0P00EWoo0P0057oo00M_^VnJKiY_VVnjJg][V`02He`00emL
001SG004Gc`00goo001oo`1@Ool006Uoo`8005=oo`<001Eoo`0AKk]_VVnjKiY_^fMkJi]WNf^KGc]S
G000GcaK?5llFcaO?002Ool00`00Oomoo`1>Ool006Qoo`04001oogoo001@Ool2000GOol03GOGMkM_
VVnJJi][Nf^KJg][Vf]kJi]O?00000IO?003Ool007oo04moo`00Igoo0P000Woo0P00C7oo0`006Goo
011g]gOGMkM[VfMkJi]WNf^KIg][Vf=KIg`005llFcaO?09K?004FaaO?7oo001?Ool00;Ioo`<0009o
o`03001oogoo01Ioo`=g]`9c^@09Ji][Nf^KJg]WO6MKIgaSF`00009O?0=K7004FcaK7000001?Ool0
0;Aoo`8001eoo`04MkMgegNgMmT2LkT04g>hMmUSFfMlHe]WO6=KIg`005llFaaK?5/LGcaK75/lFaao
o`0004ioo`00/Goo0`007Woo0gNg00=geg>iLkT00W>i0VnJ00MWFfMlHe]WO6MK001OG002Fa`00e/l
FaaK7002Fa`00eLLOol0001=Ool00:moo`80025oo`03MmMg]gOH009c^@0FLkQgfFnJKkY_VVMlHe]W
O5lkHe`006=LGc]O?5/LFcaG75/LEaaK77oo000AOol5000gOol00:aoo`<0029oo`9g]`03MmMc^G>i
009c^@=_VP03KkY_VV=L009SG005Ge`006=LHeaOG003Fa`01ULLFaaK75/LOol0011oo`05001oogoo
Ool0000gOol00:Yoo`8002Aoo`03MmMg]gOH009c^@0GLkQgfFnJKkY_VVnkKiY[VfMkHeaO>f=L001S
G5lkGcaK?5/LEaaK75LLFaaG7002Ool00`00Oomoo`0>Ool00`00Oomoo`0hOol00:Moo`<0009oo`03
001oogoo025oo`04Nk=k]7NeNkD2LkT3KiX01VnjKiY[Vf]kJi][N`9SG003001O?5ll009O?005EaaK
75/LFaaFo002Ea`00goo001oo`06Ool60004Ool00`00Oomoo`0gOol00:Eoo`8002Qoo`0QMk=ke7Nc
NmIg]G_FKiY_^VnJKk]_VV^KIg][VfMkJi]WNell001O?5/lGcaK?5llE_aK75KlFaaFo5/LE_aoo`00
015oo`03001oogoo03Ioo`00XWoo0`00:Woo00Ek]7NcNkEg]G_E009g]`0<KiY_^VnJJi][Nf^KJg][
Vf]kIgaSF`0015ll00=K75/lE_`00eLL00EFo5LLEaaoo`00015oo`03001oogoo03Eoo`00MGoo1000
9goo0P00;7oo01Eke7NcNkAg]G_FMkEgegNgMmQg]f^KIg][VfMkJi]SFfMlHe]WO000Gc`00U/l00aK
75llFaaK?5KlFaaFo5/LE_aG75Kl000=Ool01@00Oomoogoo0000=goo001dOol00`00Oomoo`02Ool0
0`00Oomoo`0QOol3000^Ool01GNcNkAg]G_EMkD00WNg00egegNgLkUc^F^KJg][VfMKIgaSFfMlIe/0
0003Fa`02E/lFaaK75/LEaaFo5LLE_aG7002E_`00goo001oo`0<Ool3000hOol007Aoo`03001oogoo
009oo`03001oogoo01ioo`<0031oo`0VMk=k]7NcNmIg]GOGMkMgf7NgLkUc^7OILkUWO6=KIgaSFfMl
He]WO5ll001K75llFaaK?5/LGcaK75LLD_aG75KlEaaBo5LLOol004Moo`00M7oo00<007ooOol00Woo
00<007ooOol077oo0P000Woo00<007ooOol0;Woo00Ak]7^cNmEg]@9g]`03MmMg]gNg00=c^@9_VP09
IgaSFfMlIe]SG5mLHe`005/l00=K7005FcaG75/LFaaG7003E_`015LLE_aoo`00Agoo001dOol00`00
Oomoo`02Ool00`00Oomoo`0IOol3000dOol0:7^dMk=ke7NeNmIg]gOHMkMgeg>hMmUc^FnjKiY_^fnJ
KkYO>f=LGcaSG5lk001O?5/LEaaK75LLFaaG75/LE_aG75;lEaaBo5KlD_aoo`00AWoo001dOol00`00
Oomoo`02Ool00`00Oomoo`0GOol2000gOol01W^cNkAg]G^eMkMge`9g]`=c^@9_VP06KkY_VVnJJg][
VemL0f=L00D005llGcaK75LL00=K7003EaaK75Kl00EFo09oo`03001oogoo04=oo`00M7oo00<007oo
Ool00Woo00<007ooOol057oo0`00>7oo02YgTG^bMi5k/WNBNmAg/g^dLkQgfG>iKkY_VVnkKiY_^VMk
Ji]WNf=LGc]SG5/l001K?5llFcaK75LLFaaG75/LE_aK75;lE_aBo5LLD_aFo7oo0015Ool007Eoo`@0
01Eoo`8003]oo`0:Nk5kTG^bNk9k]7NcNkAg]G_EMkD2KiX026njKiY_VV]kJi][Nf^KJg/3Gc`00`00
GcaO?002Gc`00eLLE_aG7002Ea`8E_`00goo001oo`13Ool008]oo`<003aoo`0MNk9gTG^bMi9k/gNc
NkAg/g_FMkEgegNgKk]_VVnjIg][VfMkJi]WNfMlHe]O?5/l001K?5llFcaO?002Fa`015KlFaaFo5/L
0UKl00QBo5KlD_aFo5;lE_aoo`00@goo0029Ool20002Ool00`00Oomoo`0jOol2Ni42Nk8067NcNkAk
/g_EMkEk]GNgMmMg]gOGJg][Vf]kJi][NfMlHe]WO6MKGc`005llFaaK?09K709G7004E_aG75LLEa`4
E_`01E;lE_aFo7oo0000@goo0026Ool30010Ool0;gNANk9gTG^cMi9k]7NcNmAg]G_FMkMgf7NgMmMc
^7OIIg][Vf=KIgaSFfMlHe]WO6=K001K75llFaaK?5/LGcaFo5/LD_aG75KlEaaBo5KlD_aFo5;lE_aB
o7oo0000@Woo0024Ool20013Ool2Ni402g^bMk9k]7^cNkAg]G^eMkMgegNgMmL017>i00YWFfMlHe]W
O6MKIgaSFf=L001K?0=K7005FcaK75KlE_aG7003E_`00eLLD_aFo002E_`01E;lE_aBo7oo0000@Goo
0021Ool30015Ool03WNANk9gTW^bMk=ke7NeNmIg]gOHMkMgegNgMmT2LkT046nJKk]SFfMlHe]WO5ll
HeaO>`00FaaK?5/LGcaG75/L0ULL00iFo5LLD_aG75KlEaaBg5KlD_aFo5;LE_aoo`00@Goo001nOol3
0017Ool03G^ANk5g/W^bNk=k]7NcNkEg]GOGMkMgegNg00=c^@03KiY_^VnJ009_VP03HeaOG6=L009S
G005001SG5/LFaaG7003Fa`3E_`00eLLE_aFo002E_`025;lE_aBo5KlD_aFo7oo0010Ool007aoo`80
04Yoo`0=Nk9gTG^bMi9ke7NcNmIg]GOHMkMgegNgMmT00W>i02A_VVnkKiY_^VnJJi]WNf=LGc]SG5ll
001K?5llEaaK75LLFaaG75/LD_aG75;lE_aBo5LLD_aFo5;LE_aBo5KlD]aFo7oo000oOol007Uoo`<0
009oo`8004Moo`07Nk5kTG^bNk9k/GNANi400W^b00=g/g^dNk<00g>i00=_VVnjKiX00VnJ00=[Vf]k
Ji/00V=L00=OG5ll00000Ull0e/L15LL25Kl0e;l00AFo5;lOol003moo`00Mgoo0P00CWoo03EgTG^b
Mi5k/GNANk9gTW^cMk=k]7NcNmIg]G_FKiY_^fnJKkY_VV^KIg][VfMkJi]K?5llFc`005/lGcaK?5/L
E_aK75KlFaaFo5/LD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aoo`0003ioo`00M7oo0`00Cgoo17^A
00QgTG^ANi5k/WNbNkAk/g^d0WNe00=g]gOGKiX00VnJ00M[Vf]kJi][Nf^KHe]WO002Gc`01@00GcaO
?5/lFa`00eLL00EFo5LLEaaG75;l00=Fo004D_aFo5;lE_`3D_`015KlOomoo`00?Goo001bOol2001B
Ool08G^bMi5k/GNANk9gTG^cMi9k]7NcNmAg]G_FMkEgf7NgMmMg]f^KIg][VfMkJi]SFfMlHe]O?5/l
001K75llFaaK?002Fa`055KlFaaFo5LLE_aG75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo7oo000mOol0
06moo`<005Aoo`03Ni5kTW^A009kT@06Nk5g/W^bNk=k]7Nc0WNe00AgegNgMmMg]`9c^@08Ji][NfMl
He]WO6MKIgaSF`9K7006001K75/LFaaK?5/L0UKl00=G75KlE_`00UKl00ABo5KlE_aFo0=Bo004E_aB
o5;lD_`2Ool00`00Oomoo`0jOol006eoo`800003Ool007oo05=oo`0BMi5k/WNANk5gTG^bMi9k/WNc
NmAg/g_FMkEgf7NgMmMg]gOI0W>i00ic^6MlHe]WO6=KIgaSFf=LGc]O?000FcaK75ll0U/L0ULL00AF
o5LLD_aG709Fo00;D_aFo5;lE_aBg5KlD]aFo5;LE_aBg002Ool00`00Oomoo`0iOol006Yoo`<005Qo
o`06Ni9kTG^ANi5k/GNA0W^b00Uk]7NcMkEg]GOGMkMgegNgMmL00g>i00I_^VnJIgaWFfMlGe`3He`0
1EmL001K75/lEa`00e/L0eKl00UG75KlE_aBo5KlD_aFo5;lE_`00e;l00IFo5;lD_aBo7oo000kOol0
06Moo`<005Yoo`0ANk9kTG^bMi5k/WNANk9gTW_DMk=k]7NeNmIg]gOGMkMgf002LkT05W>hKk]_VVnj
KiYSG5llHeaO>f=LGcaSG000FaaG75/LEaaK75LLFaaBo5LL0UKl015Bo5LLD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aoo`0003Yoo`00IGoo0P00GGoo17^A00agTG^ANk9k/WNcNkAg]G_EMkMgegNgMmL3
LkT01VnjKiY_VVnJJi][N`=SG005GeaSG6=L001O?003Fa`00eLLFaaK7007E_`00e;lE_aBo002D_`0
0eKlD_aBo005D_`00`00Oomoo`0hOol0069oo`<005moo`0?Nk9gTG^aMi5k/WNBNk=gTG^bMi5k/gNB
NkAg/g_D009c^@0FLkQ_^fnJKkY_VV^KJg][VfMkHeaO?6=LFcaO?000GcaG75/LEaaK75KlFa`2E_`0
55;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L000iOol0061oo`80065oo`9kT@03
Ni9kTG^A00EkT@05Nk9g/W^dNk=k]003MkD02VnjKiY_VV]kJi][Nf^KJg][Vf]k15ll00@005llGcaF
o0=G7003E_aG75Kl00EFo0=Bo005E_aBo5;lD_aFo006D_`00goo001oo`0gOol005eoo`<00003Ool0
07oo061oo`0oMi5k/WNANk9gTG^bMi5k/WNANk9gTW^bMk=ke7NcNmIg]GOHMkMgefMkJi][Nf^KIg][
Vf]kIgaSFellFcaO?000GcaK75/lE_aK75KlFaaFo5/LD_aFo5;lE_aBo5KlD_aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo00003Qoo`00Fgoo0P00IGoo00=kTG^BNi400W^A00YkTW^ANi5kTG^aMk9k/W^c
NkAg/`9g]@03NmEg]gOG009c^@09Jg][Vf]kJi]SFfMlIg]WO6=K009K7006001K75/LFaaG75Kl0eLL
15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00MBo003Ool007oo03Ioo`00;Woo10009Woo0`00Igoo01Ek
/W^ANk5kTW^bNi5k/GNANk9gTG^bMi9ke7NcNkAg]G_FMkMgegNgMmT00W>i02]c^6MlHe]WO6=KIgaS
Ff=LGc]O?000FcaK75llFaaG75;lEaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LOol0000ROol3000AOol002eoo`03001oogoo009oo`03001oogoo025oo`8006Uoo`03
Ni9kTG^A009kTP=kT@0<Nk5gTG^bNk9k]7NcNkAg]G_EMkMgegNg17>i00I_^VnJIgaWNfMlGe`3He`0
1E/L001K75/lEa`00U/L00EG75KlE_aFo5LL009Fo006D_aFo5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l
00=oo`00Ool08goo00<007ooOol03goo000bOol00`00Oomoo`0MOol4001[Ool057^CNkAkTg^cNi5k
/WNANk5gTG^bMi9k/gNcNkAg]G_FMkMgegNgMmT2LkT04W>hKk]_VVnjKiYSG5llHeaO>f=LGcaSG000
FaaG75/LEaaK709G700JD_aG75KlE_aBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlOol002=oo`03001oogoo00moo`009Goo1P001goo00<007ooOol077oo0`00KGoo0W^d00=k/W^A
Ni400W^A00agTG^ANk9k/WNcNkAk/g_EMkEgegNgMmL3LkT01VnjKiY_VVnJJi][N`=SG005GeaSG5ll
001G7003Fa`00eLLFaaK7007E_`00e;lE_aBo002D_`00eKlD_aBo00:D_`00goo001oo`0POol00`00
Ool0000@Ool002ioo`@001aoo`<006moo`0CNkAkTg^dNi9k/WNANk5gTG^bMi5k/gNBNkAg/g_FMkEg
egNgMmP00W>i00Yc^6nkKiY_^VnJJi][Nf^KGc]SG09O?00:FcaO?000GcaG75/LEaaK75KlFa`2E_`0
6E;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aoo`00025oo`03001o
o`00011oo`00;Woo00<007ooOol06Woo0`00LWoo0W^d00AkTW^bNi5kTP=kT@09Nk9g/W^ANi5k/GNb
Nk9k/g^d00=g]@09KkY_VVnJKiY[Vf]kJi][Nf^K00EO?004001O?5llE_`3Ea`00eKlEaaFo005E_`3
D_`00eKlD_aBo00=D_`2000OOol01@00Oomoogoo00003goo000^Ool00`00Oomoo`0HOol2001dOol0
BG^CNkAkTg^cMi5k/W^ANk5gTG^bMi5k/GNANk9gTW^bMk=ke7NcNmIg]GOHMkM_^VnJJi][Nf^KIg][
Vf=KIgaK?5llFcaO?000GcaK75/lE_aK75KlFaaFo5/LD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aoo`0001ioo`05001oogooOol0000?Ool002ioo`D001=oo`<0
07Ioo`03NkAk/g^b009kTP=kT@06Nk5kTG^ANi5k/GNA0W^b015k]7NcMkEg]G_EMkMgegNgJi][Nf^K
Jg][Vf=KIgaWNfMl00=O?006001K75/LFaaG75Kl0eLL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00IB
o008D]aBo5;lD_aBg5;lOol001eoo`<00004Ool00000000>Ool004Aoo`8007Qoo`1;NkAkTg^dNi9k
/W^ANk9gTG^bNi5k/GNANk9gTG^bMi9ke7NcNkAg]G_FMkMgegNgMmUc^F^KIg][Vf=KIgaSFfMlHe]W
O5/LGc`005/lFaaO?5/LEaaBo5LLE_aG75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aoo`0000Uoo`@002Aoo`00@Goo0`0000=oo`00Ool0Mgoo00Ak/g^dNi9k
/P=kT@03Nk9kTG^A009kT@0<Mi5kTG^bNk9g/g^dMkEkeGNgMmMg]gOG17>i00ISFfMlIg]WO6=KIg`2
He`2Fa`00`00FcaG7002Fa`01ELLE_aFo5KlEa`00UKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006
D_`025;LD_aBo5;lD]aBo7oo0007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003moo`8007aoo`0H
Ni=k]7^CNk=kTG^bMi5k/g^ANk9gTG^aMi5k/WNBNk=g/g^dMk=keWNgMmMg]gOH0W>i03=c^7OIKiY_
^V=KIgaSFf=LGc]SG5llHeaG7000EaaK75LLFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg7oo00001goo00<007ooOol00Woo00<007ooOol0
8Goo000lOol3001nOol2Nk@00g^bNi9k]002Nk@00g^BNi5kT@04Ni402G^bMk9k]7^cNmEg]GOGMkMg
e`04LkT01FnJKkY_VVnjGe`00f=L00EOG6=LGcaO?00000=K7003EaaK75Kl00EFo004D_aFo5;lE_`@
D_`01e;LD_aBo5;lD]aoo`0000Ioo`03001oogoo009oo`03001oogoo025oo`00>Woo0P00P7oo02=k
]7^CNkAkTW^eNi=k]7^BNk9gTG^bMi5k/GNANk=gTW^dMk=ke7NeMmMg]gOHMkMc^G>hKk]_VVnjKiY_
^f]kJi]O>f=L009O?00XFcaO?5/l001G75/LEaaK75KlFaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_`2Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0QOol003Moo`<0089oo`9k]09k]@9k]004Nk=k/W^ANi83Ni402W^aMk9k/W^cNkAg
/W^bNk=k]7Nc0W>i00U_^VnJKkY_VVnjJg][Vf]kJi/01Ull00<005LLE_`00eLL25Kl0e;l00=Fo5;l
D_`03U;l00IBg5;lD_aBo7oo0005Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003Eoo`800003Ool0
07oo085oo`0ZMiIk]g^eNkEgUG^dNi=k/g^BNk9kTG^aMi5k/WNBNk9gTG^bMi5k/WNcNmAg/g_FMkEg
f7NgKkY_VV^KJg][VfMkJi]SFfMlFcaO?5/lGcaK?0000U/L00AFo5/LE_aK709Fo00MD_aFo5;lE_aB
o5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg002Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0QOol0039oo`<008Ioo`07NkMg]g^eNkEk]7^cNk@00W^B
17^A00EgTG^ANi5k/GNA009k/P0@NkAg/g^dMkEkeGNgMmMg]f^KJg][Vf]kJi]SFfMlIg/3Gc`00e/L
Fc`00002Fa`01ELLE_aG75KlEa`015Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aB
g003D_`00e;LD_aBo0030004Ool4000TOol002moo`<008Qoo`1DNkMg]W^eMiEk]W^CNkAkTg^cNi5k
/WNANk5gTG^bMi5k/WNANk9gTW_DMk=k]7NeNmIg]gOGMkMgfG>iJi]WNfMlHe]WO6=KIgaSFe/lFaaO
?5/L001K75llFaaG75;lEaaFo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`00;7oo000]Ool2002:Ool00g^gMkMg]`02NkD017^cNkAk
]7^b27^A00]gTG^ANk9k/WNcNkAk/g_EMkMgegNg00Ac^@06IgaSFfMlIg]WO6=K0V=L00IK?5/L0000
05/lEa`2Fa`01ELLE_aFo5KlEa`00UKl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lOomoo`0002]oo`00:Woo0`00S7oo01ag]W^gMiEk]W^eNkAkTg^dNi9k/WNA
Nk5gTG^cMi5k/GNANk9gTG^cMk=k]7NcNmIg]gOGMkMgf09c^@09LkQ_^fnJIgaSFfMlGcaSG5lk00<0
000ZEaaK7000FaaG75/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl0Woo00<007ooOol0:7oo000XOol200000goo001oo`2;
Ool3MkL2NkD3Nk@00g^BNi5kT@02Ni800g^bNi5kT@03Ni402G^bMk9k]7^cNmEg]GOGMkMge`03LkT0
1VnjKiY_^VnJKkYOG0<00006GeaSG5llGcaG70000U/L00=G75/LE_`01EKl00ABo5KlD_aFo11Bo005
D]aBo5;lD_aBg003D_`015;LD_aoo`00:Woo000VOol2002?Ool017NfNkMgUW^f0W^e01IkTg^dNi=k
/g^CNkAkTg^cNi9k/WNANk5gTG^bMi9k]7NcNmAg]GOGMkMgf09c^@06LkQgfFnJKkY_VVnk0P00035O
>f=LGcaO?5/lGcaK?5/LEa`005LLFaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0WOol002Ioo`80
08moo`9g]`03NkMk]G^e009k]006Nk=k/W^eNkAk/g^b0W^B0g^A00Uk/GNbNk9k/g^dMk9k/W^cNk@0
17>i00=_VVnj00000P0000=[Vf]kJi/01ell00=G75Kl00000ULL25Kl0e;l00=Fo5;lD_`03U;l00EB
g5;lD_aBo5;L00=Bo004D]aoogoo000XOol002Ioo`<008eoo`03NkMgUW^g009k]@0JMiEk]7^CNkAg
UG^dNi=k]7^BNk=kTG^aMi5k/WNANk9gTG^bMi5k/WNcNmAg/g_FMkEkeP<0000=Ji][Nf^KIg][Vf=K
IgaK?5llFcaO?5/LGc`00U/L00AFo000E_aK709Fo00UD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo0000:7oo000VOol01000
Oomoo`00Rgoo0VnJ00AcVW>HMkQc^0=g]`9k]@05Nk=k]7^BNk9kTP03Ni401GNANi5kTG^aMi400W^b
00=k]7NcMkD00`0000]gegNgJi][Nf^KJg]WO6=KIgaWNfMl00=K7003FcaK75/L009G7004001G75Kl
Ea`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003
D_`2Ool00`00Oomoo`0UOol002Eoo`03001oogoo009oo`03001oogoo08Moo`0KLiY_VG>jKiUg^G>H
MkUg]W^gMiIk]W^CNkAkTg^cNi9k/WNANk5gTG^bMi5k/WNANk9gTW_D00<00005NmIg]gOGMkMgf@02
LkT0>V=KIgaSFfMlHe]WO5llHeaK75llFaaK?5/LGcaFo5LL001G75KlEaaBo5KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`00
9goo000UOol00`00Oomoo`03Ool00`00Oomoo`26Ool01VnJLiY_VGNhLkQg^@=g]`9k]@9k]003Nk9k
TW^b00IkT@03Mi5kT@0000800006NkAg]G_EMkEgegNg0g>i00M_VVnjHe]WO6MkHeaOG002He`00e/l
FaaK7002Fa`01ELLFaaFo5LL00000UKl00UG75;lE_aBo5KlD_aFo5;lE_`035;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`00goo001oo`0UOol002Eoo`03001oogoo00Aoo`03001oogoo08Ao
o`0FKiUc^VnIMkUcV7NiLiQk]gNFNkIk]G^dNi=k]7^BNk=gTG^aMi5k/gNANk4300002G^cMk=k]7Nc
NmIg]GOGMkMgf002LkT046nJKk]_VVnjKiYSG5llHeaO>f=LGcaK75LLFaaG75/L0ULL02UFo5LL001G
75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L009oo`03001oogoo02=oo`009Goo0P001Woo0P00Pgoo00M_VW>JKiUg^7>h
MkUcV003MkL2NkD2Nk@00g^BNk9kTP02Ni8017^bNi4000000W^A00Uk/WNbNkAk/g_EMkEgegNgMmL0
0g>i00I_^VnJKkY_VV^KJg/3He`01EmLGcaO?5/LEa`00e/L00AG75KlE_`000AFo004D_aFo5;lE_`@
D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo02Aoo`009Goo00<007ooOol0
1goo00<007ooOol0Ogoo00Y_VG>jKiUcVW>HMkUcV7NiMiIk]`9k]@07Ni=k]7^CNk=kTW^bNi<00`00
00agTG^aMi5k/WNBNkAg/g_DMkEgegNgMmP2LkT0@G>hKk]_VVnjKiY[Vf]kJi]O>f=LFcaO?5/lGcaK
?5/LEaaK75KlFaaFo5LLD_`005;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000097oo000UOol00`00Oomoo`08
Ool00`00Oomoo`1mOol026MkIgaWNfMkLkQg^G>HMkP2MkL3NkD017^dNk=k/W^B0`000W^B0g^A00Uk
/GNbNk9k/g^dMk9k/W^cNk@00g>i00U_^VnJKkY[Nf^KJg][Vf]kJi/01ell00=G75KlEa`00ULL0eKl
00<005;lE_`00UKl0e;l00=Fo5;lD_`03U;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;lD_aBg5;l0Woo
00<007ooOol08Goo000UOol00`00Oomoo`09Ool00`00Oomoo`1jOol046MlIe]WO6MkIga[NVnKLiQg
^G>HNkMg]W^eMiEk]7^C0`0002Ak]G^dNi9k/g^ANk5gTG^bMi5k/WNANk9gTG^bMk=ke7NcNmIg]GOH
MkMgefMkJi][Nf^KIg][Vf=KIgaK?5llFcaO?5/LGc`2Fa`015KlFaaFo5/L0UKl02YBo000D_aFo5;l
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo7oo000SOol002Aoo`8000aoo`03001oogoo07Qoo`9WN`08IgaWNfMkJg][Vf]jJi][
N`9g]`9k]@<00007MkMk]G^eNkAkTW^cNi800g^A00EgTG^bNi5k/GNA009k/P07NkAg/gNeMkEkeGNg
MmL00W>i00Q[Nf^KJg]WO6=KIgaWNfMl0e/L00EK?5/LFaaK75LL00=Fo009EaaFo5Kl001Fo5;lE_aB
o5Kl00=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QBg5;lD_aB
o5;LD_aoo`008Woo000TOol00`00Oomoo`0<Ool00`00Oomoo`1eOol03FMkIgaWFfMlIg]_Vf]jKi][
NVnKJgYc^VnI00<00004MkIk]gNFNkH2NkD05W^CNk=kTW^bMi5k/GNANk9gTG^bMi5k/WNBNmAg/g^d
MkEkeWNgMmMc^7OI0W>i00aSFfMlHe]WO6=KIgaO?6=LFaaO?5/LFc`2Fa`2Ea`0;E;lEaaFo5LLD_aF
o000E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0OOol002Aoo`03001oogoo00eoo`03001oogoo
07=oo`0;GcaOG6MkIgaWNf^KJg][Vf]jJi][N`0300000g>hMkUcV003MkL2NkD2Nk@00g^BNk9kT@05
Ni402gNANi5k/W^bMk=k/gNeNmEg]gOGMkL00g>i00M_VVnjHe]WO6MkHeaOG002He`00e/lFaaK7002
Fa`015LLFaaFo5LL1UKl00<005KlD_`00U;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01e;LD_aBo5;lD]aoo`00025oo`0097oo00<007ooOol03Woo00<007ooOol0L7oo
00]OGEllGeeK?5mMGca_Vf]jKi][NVnK00800008KiUcVW>HMkUcV7^gMiIk]`9k]@0FMiEk]7^BNk=g
TG^aMi5k/gNANk5gTG^bMi5k/WNBNkAg/g_FMkMgegNgMmT2LkT0@fnJKk]_VVnjGc]SG5llHeaO>f=L
GcaK75LLFaaG75/LEaaK75;lE_aBo5LLD_aFo5;L001Bo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00021oo`00
97oo00<007ooOol03goo00<007ooOol0KGoo00MO?5mLGcaOG5llGeaO?002He`02f^K00000000LiY_
VFnJLkQg^G>HMkP00gNg0W^e00=k]7^cNk800g^B00=k/W^ANi800g^A00Qk/WNbNk=k/g_EMkEgegNg
17>i00I_^VnJKkY[Nf^KGe`3He`3Gc`01e/LEaaK75/LEaaFo5LL00IFo004D_`005;lE_`@D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo5;lD_`2Ool00`00Oomoo`0MOol002Aoo`80
015oo`03001oogoo06]oo`08EaaK?EllGeeK?5mMGcaSG0<0000SKi][NW>jKiUcVW>HMkUcV7NiMiIk
]gNfNkEgUG^fNi=k/g^BNk9kTg^cNi9k/WNANk5gTG^bMi9k/WNcNmAg]GOGMkMgf@02LkT0AW>hKk]_
VVnjIg][Vf]kJi]WNellFcaO?5/lGcaK?5/LE_aK75KlFaaFo5LLD_aFo5;lE_aBo5KlD]`005;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aoo`007goo000SOol00`00Oomoo`0BOol00`00Oomoo`1XOol01e/mEcaK?ELLFceO
?5mL00<000ASG007LiY_VFnJKiYg^G>HMkP017Ng0W^e00=k/g^dNi800W^c00=k/W^BNi800g^A00Uk
/GNbNk9k/g^dMk9k/W^cNk@00gNe00Y_^VnJKkY[Nf^KJg][Vf]kIgaSF`=O?0=K7003EaaFo5LL009G
70AFo008D_aFo5KlE_aBo000D_aFo0aBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo003Ool007oo01eoo`006Woo10001Goo00<007ooOol04goo00<007ooOol0IGoo
00IG75/mEaaK?ELLFcd300000f=LGe]SO002He`0JemKIgaWNfMlIe]g^G>HMkUcV7^gMkIk]gNENkIk
]G^dNi9k/g^eNkAkTW^cNi5k/GNANk9gTG^bMi9k/WNANk9g/g_DMkEkeWNeMmQg]gOGIg][Vf]kJi]W
NfMlHe]WO6=KGcaK75/lFaaO?5KlFaaFo5/LE_aG75;lE_aBo5KlD_aFo5;lE_`005KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]`00Woo00<007ooOol06goo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0D
Ool00`00Oomoo`1ROol01ELMDaeG7ELlFcd00`0000=K?E/lFc`01F=L00QWO6MkIg]WNf^KJgY[Vf]k
17Ng0W^e0W^d0W^e00Ak]7^BNk=kTP=kT@05Mi5kTG^ANi5gT@02Nk801g^dMk=g]GNeNmEg]gOG009c
^@09Jg][VfMkIgaSFfMlIg]SG5mL009K7005FcaK75/LE_aG7003E_`00eLLD_aFo002E_`01E;lE_aB
o5Kl00000U;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_aoo`0001eoo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool05Goo00<007ooOol0GGoo00IC75LMDaaG7E<LEad300001e/mEaaO?E/lFceK?5lm009SG00>Ie]W
O6MkIgaWFfnKJgY_Vf]jLkY_VG>JKiUk]P9k]@0JMiIk]W^eNkEkTg^cNi9k/WNANk5gTG^bMi5k/GNA
Nk9gTW_DMk=keWNeNmIg]gOGLkQgf@9c^@0:He]WO6=KIgaO>f=LGcaSG5/LGc`2Fa`0>ELLFaaFo5LL
D_aG75KlEaaBg5KlD_aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000LOol001Uoo`03001o
ogoo009oo`03001oogoo009oo`8001Moo`8005]oo`=C7@9G7@08Dad00000EaeC7ELMFcaK?@=K?005
FceK?5/lIg]WO003Ig/01V^KJgY[Vf]kLiY_V@9_VP03MkUcV7Nh009g]`9k]@9k]003Ni9k/W^A00Mk
T@9k/P07Mk=k/gNeNmEg]gOGMkL00g>i00=_VVnjKiX00f=L00EOG6=LHeaSG5LL00=K7003EaaK75/L
00EFo006D_aFo5;lE_aBo5Kl0U;l00<005;lD_`02E;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0001]oo`006Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol067oo00<007ooOol0EGoo00IC7E;lEaeBo5<MD_`300007U<LEaeC75LmEaaG
?E/lFceK?5lmFcaK?E/lGeeWNfMlIe]_Vf]jKi][NVnKKiUcVVnILkYcV7NiLiQk]`9k]@0FMiEk]7^B
Nk=gTG^aMi5k/gNANk5gTG^bMi5k/WNcNkAg]G_FMkMgegNgMmT2LkT04VnJKk]_VV^KIg]SG5llHeaO
>ellFcaO?5LLFaaG75/LE_aK709Fo00dD_aG75;lE_aBg5KlD_aFo5;LE_aBg000D]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;L000KOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo
059oo`03D_eC7E;m009C7@<0009C7@9G7@0EEaaG7ELMEaeG75LMFcaK?E/lGeaO?5mLGcaOG5llJi][
NV^KJg][VfnI009_VP04LiYcV7NhLkP2MkL2NkD00g^dNk=k/P03Ni800g^bNi5kTP03Ni4027^bMk9k
/g^cNmEg]GOGMkL2LkT026njKiY_^VnJJi][Nf^KJg/7Gc`01UKlEaaG75LLE_aG70IFo0=Bo005E_aB
o5;lD_`0000<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
15;LD_aoo`006Woo000IOol00`00Oomoo`02Ool01@00Oomoogoo00007Goo00<007ooOol0CWoo00E>
o5<MD_aC7Dkl00<00028D_aG7E;lEaeBo5LMEaaG?ELLEceG75LmEaaG?EllGeeK?5mMGcaOGE/lHgaS
G6nKJgY_VfnILiY_VG>jLiQg^G>HNkMg]W^eMiEk]W^CNk=kTW^bNi=k/g^BNk9gTG^aMi5k/WNBNkAg
/g_FMkEgegNgMmUc^FnjKiY_^fnJJi]WNf^KJg]WO6=KGcaK?5llFcaO?5/LFcaFo5/LE_aK75KlFaaB
o5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg000D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0007Ool5000=Ool001Yo
o`@000Aoo`8001eoo`03001oogoo04]oo`04DaeBoE<MD_d3000015;mDaeBoELM0e<M00=G7E<MDad0
0ULM00]G75LMEaeK?ELLFceO?5mLGcaOG5ll00ESG007KiU_VVnJLiYcV7NhLkP00gNg0W^e00=k/g^d
Ni800W^c00=k/W^BNi800g^A01Ek/GNbNk9kTG^aMk9k/W^cNkAg]GOGMkMgegNgJi][Nf^KJg]WO6Mk
Ig`00ell00IK?5/LFaaK75LLE_`3Ea`4E_`015;lE_aFo5Kl0e;l00EFo5;lD_aBo00000ABo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
0e;LOol00007Ool01@00Oomoogoo00003Goo000ROol00`00Oomoo`0MOol00`00Oomoo`16Ool01Dkl
Dae>o5<MC_`00`0001Y>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeBo5LMEaaK?ELLFceG75/mEaaK?Ell
GeeOFf=l0V=L07=OFf=lIe]WO6nILkY_VGNiLiQg^GNfNkMgUG^fNkEk]7^BNk=k]G^dNi9k/g^ANk9g
TG^bMi5k/WNANk9gTW^bMk=ke7NeNmEg]gOHMkMc^G>hJi][NfMlHe]WO6=KIgaK75llFaaK?5/LGcaK
75LLD_aG75KlEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0
0007Ool00`00Oomoo`0>Ool0029oo`03001oogoo01ioo`03001oogoo04=oo`9Bo@03DaeBo@000080
0005D_eC7E;mDaeBo@03Dad015;mDaeC7ELM0e<M00]G7E<MEaeG?5/mEaaK?ELlFceG75/m00ESG009
IgaWNfMkIg]WO6MkMkQc^7Ni00=g]`9k]@9k]09k]@9k]003Nk=kTW^A009kT@05Mi5kTG^ANk5gT@02
Nk801W^dMk=g]GNgMmMg]`Ac^@04IgaWNfMlHe/3He`3Fa`01E/lEaaK75/LEa`00eKl00UG75KlE_aB
o5KlD_aFo5;lE_`01U;l00<005;lD_`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo09oo`03001oogoo00Eoo`03001oogoo00eoo`00
8Woo00<007ooOol07goo00<007ooOol0?goo00EC7DklDae>o5<M0080000NC_aC7DklDae>o5<MD_aC
7E;lDaeBo5<MD_aC7E<LEaeBo5LMDaaG7E<LEaeG75/mEaaK?ELLFceK?5lm0V=L00iOFfMlIe]WO6MK
IgaWFfnKJgY_VgNfNkMgUW^f0W^e06IgUW^fNkEk]G^CNk=kTW^bMi5k/GNANk9gTG^aMi5k/WNBNmAg
/g_EMkEgf7NgMmMc^7OILkU_^VnJKk]O?6=LGc]SG5llHeaO>e/LEaaK75LLFaaFo5LLD_aG75;lE_aB
o5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0008Ool00`00Oomoo`0<
Ool0029oo`03001oogoo021oo`03001oogoo03aoo`04D_eC7DkmD_d30002D_d02U<MD_eC7E;mDaeB
oE<MD_eC7E;m0e<M00EBoE<MEaeG7E<M00=G7@04DaeK?ELlFcd3Fc`01E/mFcaK?6MkIg`00fMk00IW
O6MkJi][Nf^KKiT2KiX00gNiLiQg^002MkL2NkD2Nk@017^BNk9kTG^B17^A00YgTG^ANk9k/WNcNk=g
]GOGMkMge`=c^@05KkY_VVnjJg][V`02He`00emLHeaO?002Gc`3Fa`00eLLFaaFo005E_`015;lE_aB
o5Kl2E;l00<005;lD_`015;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L009Bo09oo`03001oogoo00Ioo`03001oogoo00]oo`008Goo0P008goo
00<007ooOol0>7oo00A>oE<MC_aC7@<0000eDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC
7E;lDaeBo5LMDaaG7E<LEaeC75LMDaaO?E/lFceK?5lmFcaK?E/lGeeWFfMlIe]WO6]jKi][NVnKKiUc
VVnILkYcV7NiLiQk]`02NkD0HgNENkAkTg^cMi5k/WNANk=gTG^aMi5k/WNBNk9g/g^dMkEkeWNgMmMc
^7OIKiY_^VnJKk][Nf^KIg][Ve/lGcaK?5llFcaO?5/lFaaFo5/LE_aK75;lE_aBo5LLD_aFo5;LE_aB
o5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg002Ool01@00Oomoogoo00000goo00<0
07ooOol02goo000QOol00`00Oomoo`0SOol00`00Oomoo`0bOol01TkmD_eBoE<MC_eBo@<0009Bo@05
Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d7Dad2Ead01E<MEaeG7ELMEa`00U/l00iK?E/l
GeaO?5mLGcaOG6MkIga[NV^KJg][VfnI0VnJ00AcVW>HMkQc^09g]`9k]@03NkAk/g^b009kTP04Ni5k
/W^ANi83Ni401g^bMk9k/g^cNmEg]gOG009c^@0:KiY_^VnJJi][Nf^KJg][Vf=KIg`5Gc`00e/lFaaG
7002Ea`01EKlEaaFo5KlD_`00eKl0e;l00=Fo5;lD_`01e;l00@005;lD_aBg0=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`20004Ool3
000>Ool0025oo`03001oogoo02Aoo`03001oogoo02moo`05Dae>oE<MC_aC7@030000Y5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeG75LmEaaG?ELL
EceG75LmGcaOGE/lGeeO?5mMFcaOGF]jKi][NVnKKiUcVVnILkYcV7NiLiQg^GNfNkEgUG^fNi=k]7^B
Nk9kTG^dNi9k/WNANk5gTG^bMi9k]7NcNk9gTW^dMk=keWNgMmMg]f^KJg][VfMkJi]SFfMlHe]O?5/l
GcaK75llFaaK?5KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg7oo000DOol0025oo`03001oogoo02Eoo`03001oogoo02]oo`9Bo@03Dae>
oE;m00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeB
o@AC7@03EaeC7E<M009G7@0<EaaG7ELMEaeG75/mGcaOG5llGeaO?5mL16=L00Q_VFnJKiYcVW>HMkQc
^7Ni0WNg0W^e00=k/g^dNk@00W^c00=k]7^BNi800g^A00Ik/GNbNk9kTG^aMk82Nk<017_EMkEgegNg
0W>i00Q[Vf]kJi]SFfMlIg]WO6=K0U/L00EK?5/LFaaK75/l00=Fo003EaaFo5Kl009Fo004D_aFo5;l
E_`3D_`00eKlD_aBo006D_`01@00D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo019oo`008Goo00<007oo
Ool09Woo00<007ooOol0:7oo00A>oE<MC_aC7@<0000aDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMDaaG7E;lEaeG75LmEaaK?ELLFceG
75/mGcaOGE/lHg`00V=L02IOFf=lIe]WO6nILkY_VGNiLiQg^GNfNkMgUG^fNkEk]7^CNk=k]G^dNi=k
/g^ANk9gTG^bMi9k/WNANk9gTW^bMk=ke7NeMmMg]gOH0W>i00ac^7OIHe]WO6=KIgaO?6=LGc]O?5/L
Fc`2Fa`0@ULLFaaBo5LLE_aG75;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_`0
05KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlOol001=oo`008Goo0P00:7oo0P009Goo00=BoE<MC_d00U;m0P000U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE<MD_eC7E;mDaeBoE<MD_eC7E;mDaeB
o@9C7@05EaeC7E<MDaeG7@02Dad025LlFceG75/mEcaK?ELLFcd6He`3Ig/01VMlIg]g^7>hMkUcV09g
]`9k]@=k]005NkEk]7^dNk=kTP03Ni4027NANi5kTG^aMi5k/W^cNk@2MkD00gNgMmMc^@03LkT01FnJ
KkY_VV=LGe`00f=L00EOG5/LFaaK75LL009K7003EaaFo5Kl00AFo004D_aFo5;lE_`>D_`01@00D_aB
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QB
g5;lD_aBo5;LD_aoo`004Woo000QOol00`00Oomoo`0YOol00`00Oomoo`0POol015<MC_aC7Dkm0`00
03A>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75LMEaaK?ELLFceG75/mFcaO?@9SG00>Ge]SO6MKIgaW
FfMlIe]_Vf]jKi][NW^gMiIk]P9k]@0FMiIk]g^eNkEkTg^dNi9k/WNANk5gTG^bMi5k/GNANk9gTW_D
Mk=keGNgMmP2LkT04W>hMmU_VVnjKiY[Vf]kHeaO>f=LFcaO?5/lFaaG75/LEaaK709G700oD_aG75;l
EaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000
019oo`0087oo00<007ooOol0:goo00<007ooOol077oo00AC7DkmD_eBo@<00003D_eC7Dkm009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<M
D_d3Dad01E;mDaeC7ELMDad00eLM00EC7ELMEcaK?ELL009K?003FceK?5/l009SG0=WN`06IgaWNf^K
Jg][Vf]j0VnJ00=g^G>HMkP00gNg00Mk]G^dNkAkTW^bNi5kTP04Ni401GNANi5k/W^dMk<00WNe00Yg
egNgLkUc^FnjKiY_^VnJJi][N`9[V`IO?0=G7003E_aG75LL00EFo0=Bo003E_aBo5;l00eBo003001B
g5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`00e;LOol0000AOol0021oo`03001oogoo02aoo`03001oogoo01Ioo`06Dae>oE<M
C_aC7Dkm0`00079>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75LMDaaG7E/lFceK
?5lmFcaK?E/lGceWFfMlIe]WO6MKKi][NVnKJgYcVVnILkYcV7NiLiQk]gNfNkEgUG^dNi=k/gNANk9g
TG^cMi5k/GNANk9gTW^bMk=k]7NeMmQg]g>iLkQ_^fnJKkYWNf^KJg][VfMkIgaSFellFcaO?5/LFc`2
Fa`015KlFaaFo5/L0UKl03mBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aF
o5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg7oo000047oo000POol00`00Ool0000]Ool00`00Oomoo`0COol00e;m
Dae>o@02D_d300000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@QC7@03EaeC7ELM009G7@04EaaG
7E/lFcd3Fc`02U/mGcaOG6MkIgaWNf^KJg][Vf]j0VnJ00AcVW>HMkQc^0=g]`04NkEk]7^cNk82Ni80
17^ANk9kTG^B0g^A00=k/WNcNk<00W^b00Ig/g^cMkEgegNgMmL2Ji/01F]kJi][VfMlHe/00VMl00IK
?5/LFaaK75/lE_`3Ea`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L009Bo003
001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`2000@Ool0021oo`8002moo`03001oogoo00moo`05C_eC7DklDae>o@030000
`4kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeBo5LMD_aG?ELLEceG75LmEaaG
?E/lFceK?5mMGcaOGE/lGeeO?6nKJgY_Vf]jLiY_VG>jLiQg^G>HMkUg]W^gMiEk]W^CNkAkTW^bNi5k
]7^BNk9gTG^aMi5k/WNBNk9gTG^bMk=k]7NeNmIg]gOGLkQgfF]kJi]SFfMlHe]WO6=KHeaO?5/lFaaO
?5/LFcaBo5LLE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lOol000moo`001Goo1@001Goo0P001Goo10001Woo00<007ooOol0
;goo00<007ooOol037oo00AC7DkmD_eBo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eBoE<M
D_eC7E;mDaeBoE<MD_d8Dad00eLMEaaG7@02Ead02ELLEaeO?5mLGcaOG5llGeaO?004He`2KiX01G>J
LiQg^7>hMkT00gNg00Ak]G^cNkAkTP9k/`03NkAkTW^B00=kT@06Nk5g/W^ANi5k/WNb0W^c00AkeGNg
MmMg]`=c^@9WO008He]WO6=LHeaOG6=LFaaK?0AK70=Fo009EaaFo5KlD_aFo5;lE_aBo5Kl00aBo009
D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`2Ool00`00Oomoo`0<Ool000Aoo`800005Ool00000Ool0
0004Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool0
1E<MC_aC7DkmDad00P0004Q>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC
7E;lDaeBo5LMDaaG7E;lEaeC75LmEaaG?ELLFceG75/mGcaOGE/lGed2He`09UmKHgaSG6MlIe]c^VnI
MkUcV7NiMkIk]gNFNkIk]G^dNi=k]W^eNkAkTg^cNi5k/GNANk9gTG^aMi5k/WNBNkAg/g_FMkEgegNg
MmT2LkT046nJKk]_VVnjGc]SG5llHeaO>f=LEaaK75LLFaaG75/L0ULL04=Bo5LLD_aG75;lE_aBg5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol0000>
Ool000Aoo`80009oo`03001oo`0000moo`03001oogoo00=oo`03001oogoo035oo`03001oogoo00Eo
o`04C_eBoE;mDad300001U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmDaeBoE<MD_eC7E;mDaeB
oE<MD_eC7E;m1U<M00aG7E<MDaeC7E/mEaaK?ELlFceG75/mEc`6He`2Ig/01VMlIg]g^7>hMkUcV0=g
]`05NkEg]gNgMkMk]@02Nk@01G^cNi5kTG^ANk400g^A00Qk/GNbNk9k/g^dMkEgegNg0g>i00A_VVnj
KiY_^P9[V`03GeaSG6=L00=O?09K7004EaaK75LLEa`6E_`00e;lE_aBo00?D_`02E;LD_aBo5;lD]aB
o000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00U;l00=oo`00Ool037oo0004Ool20002Ool00`00Ool0000?Ool00`00Oomoo`02
Ool2000dOol02000OomoogooC_aC7DkmDad30000Ge<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaK?ELLFceG75/mEaaO
?E/lHeaOFf=lIe]WO6MKIgaWFfnKJgY_Vf]jNkMgUW^gLiQk]gNFNkL00W^e019kTg^dNi9k/WNANk5k
TG^aMi5k/WNANk9g/g_DMkEkeGNgMmP2LkT0FFnJKk]_VVnjIg][Vf]kJi]K?5llFcaO?5/lGcaFo5/L
E_aK75KlFaaBo5LLD_aFo5;lE_aBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000037oo0004Ool20002Ool00`00Ool0000;Ool40005Ool0
0`00Oomoo`0bOol00e;mDae>o@02D_d01U<M00000000Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d03U<MC_eBoE;mDae>oE<MD_eC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad3Ead025<MEaeG
7E/mEaaK?E/lFcd2Fc`2He`3Ig/01VMlIg][Vf]kJi][NP9_VP03LiYcV7Nh00=g]`04NkEk]7^dNi83
Ni42Ni82Ni4027NANk9k/W^dMk=g]GNgMmL2LkT00fnJKkY_VP03Ji/016]kJi]WO6Ml0ell00=K?5/L
Fa`00ULL00EFo5LLEaaG75;l00=Fo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;L001B
o5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00QB
g5;lD_aBo5;LD_aoo`0037oo0003Ool300001Goo000007oo00002goo00<007ooOol01Woo00<007oo
Ool0<7oo00EC7DklDae>oE<M00<0003EDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5<MDaaG7E<LEaeC75LMDaaK?E/l
GceK?5/mFcaO?FMKIgaWFfMlIe]_Vf]jKi][NW>JKiUc^VnIMkUgUW^gMkIk]GNENkAkTg^cMi5k/W^B
Nk9gTG^aMi5k/WNBNmAg/g^bMi9ke7NeNmEg]gOHMkM[VfMkJi][NfMlHe]WO6=KIgaK75llFaaK?5/L
GcaFo5LLD_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aoo`0000]oo`001Goo00<007ooOol00Woo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol0;Goo00EC7DkmD_eBoE<M00<00006Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d8
Dad00eLMDaeG7@02Ead015LLEaeG7E/m0e/l00YOG5llGeaWNfMlIg][Vf]kJi][NP9_VP04LiY_VGNh
LkP3MkL027^eNkAk/g^bNi5kTW^CNk84Ni42Nk801GNANi5k/W^dMk<00WNe00=gegNgLkT00W>i00IS
FfMlIgaWO6=KIg`2He`4Fa`015LLFaaFo5LL0eKl00EG75;lE_aBo5Kl00=Bo003E_aBo5;l00IBo005
D]aBo5;lD_aBg003D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_`000002Woo0006Ool4000<Ool5
0004Ool00`00Oomoo`0[Ool014klDae>oE<M0`00095C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;l
EaeBo5LmEaaG?ELLEceG75LmEaaOG5/lGeeO?5mLFcaOGEllKi][NVnKJgYcVVnILkY_VGNiLiQk]gNf
NkMgUG^fNi=k]7^BNkAkTg^cNi9k/WNANk9gTG^bMi5k/WNBNk9g/g_EMkEgf7NgLkUc^7OIKiY_^V=K
IgaSFf=LGc]SG5llHeaG75/LEaaK7002Ea`0BEKlEaaBo5LLD_aG75;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0000Yoo`00
7goo00<007ooOol0:7oo00E>oE;mD_eC7Dkm00800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;m
DaeBo@QC7@03EaeG75LM009G7@09EaaK?ELlGeaO?5mLGcaOG5ll00ASG09_VP04LiY_VGNhLkP4MkL0
1g^eNk=k]7^BNkEkTg^d009kTPMkT@07Nk9g/g^cMkEkeGNgMmL00W>i00E_VVnjKiY_^UmL00=SG005
GeaSG5llGcaG7003Fa`00eLLE_aFo005E_`015;lE_aBo5Kl35;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00=Bg00000002Goo000NOol2000UOol01dkmDae>o5<MC_eC7Dkl00<0001N
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lEaeC75LmEaaG?ELLFceG75/m
EaaOG5/lGed2He`0;UmKHgaSG6MlIe]c^VnILiYcV7NiMkIk]gNFNkIk]G^dNi=k]W^CNkAkTW^cNi5k
/GNANk9gTG^aMi5k/WNBNkAg]G_FMkMgeg>hMmUc^FnjKiY_^f]kJi]O>f=L0Ull059K?5llFcaK75LL
FaaFo5/LE_aG75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol000Uoo`007Woo00<007ooOol08Woo00IC7Dkm
D_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d6Dad0
35LMDaeC7E<MFceG75/mEcaK?ELLFceG?0ISG09WN`05IgaWNfMkLkQg^@04MkL00g^eMkMg]`02NkD2
Nk@01G^cNi5kTW^ANi800g^A00Mk/GNbNk=k/g_EMkEge`03LkT016njKiY_^V]k0f^K1ell00=G75Kl
Ea`00ULL15Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
00000e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo003001oogoo00Moo`007Woo00<007ooOol087oo00E>o5<MC_eC7Dkl00<0002JC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaK
?ELLFceG75/mEaaO?E/lHeaOFf=lIe]WO6MKIgaWFfMlJgY_VfnILiY_VG>jLiQg^GNFNkMk]G^dNi=k
/g^BNk9gTG^cNi5k/GNANk9gTW^bMk=keWNeNkAg/g_FMkE_^VnJKk][Nf^KIg][Vf=KIgaK?5llFcaO
?5/LGc`2Fa`0AeKlFaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`017oo00<007ooOol01goo000NOol00`00Oomo
o`0NOol2D_d00e<MC_d0000200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE;m
D_eC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad3Ead025<MEaeG7E/mEaaK?E/lFcd3Fc`01E/mIg]W
NfMkIg`00VMk00=[Nf^KKiT00VnJ00=cVW>HMkP00WNg0W^e0W^d01EkTW^bNi5k/g^ANi9kTG^aMi5k
/W^cNk5g/W^bMk=keGNeMmMg]gOGJg/00V^K00=WO6=KIg`00VMl00QSFe/lFaaK?5/LFcaK75LL0eKl
00=G75;lE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00U;l00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l1goo00<007ooOol01Woo000NOol00`00Oomoo`0KOol015<MC_eC7Dkl0`000:9>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<M
DaaG7E<LEaeC75LMDaaK?E/lGceK?5/mFcaO?EllGeaWFfMlIe]_Vf]jKi][NW>JKiUc^W>HMkUcV7^g
MkIk]GNENkAkTW^cMi5k]7^BNk9gTG^aMi5k/WNBNk9gTW^bMk=ke7NeNmEg]gOHLkUcfG>hIgaSFfMl
He]WO5llHeaO>ellFaaK?5LLFa`2Ea`0@5;lEaaFo5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l2Woo00<007ooOol01Woo000MOol2000HOol0
1U<MC_eBoE;mDae>o@<00005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M
00=Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d8Dad3Ead015LLEaeG7E/m0e/l00YOG5llGeaO?5mLGca[
Vf]kJi][NP9_VP04LiY_VGNhLkP2MkL2NkD01g^dNi=k/W^BNkAkTW^b009kT@05Mi5kTG^bNi5gT@02
Nk801G^dMkEg]GNgMmL00g>i00=_^VnJKkX00V=L00EOG6=LHeaSG5mL00=K7003EaaK75/L00EFo006
D_aFo5;lE_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00`00D]aBo002D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo0ioo`03001oogoo00Ioo`007Woo00<007ooOol0
57oo00I>o5<MC_eC7DklDad20000hDklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5<MEaaG?ELLEceG75LmEaaG?E/l
GeeO?5mLFcaOGEllHeaOFfnKJgYcVVnILkY_VGNiLiQg^GNfNkMgUG^fNi=k/g^BNkIkTg^cMi5k/GNA
Nk9gTG^aMi5k/WNBNmAg/g_EMkMgf7NgLmUc^6nkKiY_^VMkJi]O?6=LGc]SG5/lGcaK?5/LEaaK75Kl
FaaFo5LLD_aG75;lEaaBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg00COol00`00
Oomoo`06Ool001eoo`03001oogoo01=oo`9Bo@03Dae>oE;m00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC
7E;m1U<M00=G7ELLEad00ULM00UG75/mEcaK?EllGeaO?5mLGc`016=L0VnJ00EcVVnIMkQc^7Ni009g
]`9k]@06Ni=k]7^eNkEkTg^b0W^B1W^A0W^b00Eg/gNeMkEgegNg009c^@03KkY_VVnj009[V`03Jg][
Vell00IO?0=G7003E_aG75Kl00EFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;LD_aB
o5;lD]`00e;l00EBg5;l001Bo5;L00=Bo006D]aBo5;lD_aBg5;l5Goo00<007ooOol01Woo000MOol0
0`00Oomoo`0AOol014kmDae>o5<M0`0007EC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LMDaaG7E;lEaeC75LM
D_aK?ELLFceG75/mEaaK?E/lGed00V=L03AOFf=lHeaWO6MKIgaWFgNiLiQg^G>HNkMgUW^fNkEk]gNE
NkIk]G^dNi9k/W^ANk5gTG^aMi5k/WNANk9g/g^dMkEgf7NgLmUc^6nkKiY_^VMkJi][Nf^KHe]WO5/l
GcaK?5llFaaK?09K700eE_aK75KlFaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo000D_aBg5KlD]aBo5;LE_aB
g00GOol00`00Oomoo`06Ool001eoo`8000moo`04D_eC7DkmD_d30002D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mDaeB
oE<MD_eC7E;mDaeBo@=C7@04D_eC7E<MEad2Dad2Ead025<MFceG?5/mEaaK?ELlFcd5He`2Ig/01VMl
Ig][Vf]kJi][NP9g]`04MkUcV7NgMkL2NkD00g^dNi9k/`02Ni42Ni83Ni400g^bMk9k/`02Nk801WNc
MmEg]GOGMkMge`9[V`0=Jg]WO6MlIgaSFfMlFaaK?5/LFcaK75/lFa`00UKl00=G75KlE_`00UKl00AB
o5KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00IBg5;l
D_aBo5;L0002D_`00e;LOomoo`0JOol00`00Oomoo`06Ool001eoo`03001oogoo00Uoo`06C_aC7Dkm
Dae>o5<M0`0008eC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG
7E<LFceG75/mEaaO?E/lFceOFf=lIe]WO6MKIgaWFfnKJgY_Vf]jLiY_VGNiLiQg^GNFNkH00W^e02Ak
Tg^cNi9k/W^BNk9kTG^aMi5k/WNBNkAgTG^bMk=k]7NeNmIg]gOGLkQgfG>iIgaSFfMlHe]WO5lkHeaK
75/lFaaO?5LLFa`2Ea`0;5KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo000OOol00`00Oomoo`05Ool0
01eoo`03001oogoo00Moo`9Bo@03Dae>oE;m00<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:
DaeBoE<MD_eC7E;mDaeBoE<MD_d5Dad2Ead01E<MEaeG7ELMDad00U/l00EK?E/lFcaK?5/m00=WN`06
IgaWNf^KJg][Vf]j0VnJ00=g^G>HMkP00WNg0W^e00Ik]7^cNi9kTW^dNk<3Ni402g^aMk9k/W^ANk9g
/W^cMkEkeGNgMmL00g>i00A_^VnJIgaSF`=SG005GeaSG5/LFaaG7003Fa`00eLLE_aFo003E_`015;l
E_aBo5Kl3U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LOomoo`02Ool00`00Oomo
o`0LOol00`00Oomoo`05Ool001eoo`03001oogoo00Eoo`04C_eC7DklDad30000TE<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEaeC75LMEaaG?ELLGceK
?5/mFcaO?EllGeaWFfMlIe]_Vf]jKi][NW>JKiUc^W>HMkUcV7^g009k]@0NMiEk]7^BNk=kTg^cNi9k
/WNANk9gTG^aMi5k/WNBNkAg/g_FMkEgegNgMmUc^FnjKiY_^fnJHeaO>f=L0Ull02eK?5llEaaK75LL
FaaFo5/LE_aG75;lEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]`027oo00<007ooOol06goo00<007ooOol01Goo000MOol01000Oomo
odkm0U;m00AC7DkmD_eBo@80009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03
D_d025<MD_eC7E;mDaeBoE<MD_d7Dad2Ead015LLEaeG7ELM0e/l00YOG5llGeaO?5mLGca[Vf]kJi][
NP9_VP04LiYcV7NhLkP2MkL2NkD01G^dNi9k/W^eNk@00W^B0W^A00]gTG^BNi5k/GNbNk9g/g_EMkEg
egNg00=c^@03KiY_^VnJ00=[V`IO?09G7004E_aG75LLEa`4E_`015;lE_aBo5Kl45;l00EBg5;lD_aB
o5;L00=Bo0aoo`03001oogoo01]oo`03001oogoo00Eoo`0077oo00P007ooDae>oE<MC_aC7Dkm0`00
0;Q>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;l
EaeBo5LMD_aG7ELLEceG75LmEaaG?E/lGeeO?5mLFcaOGEllHeaOFf=lHeacVVnILkYcV7NiLiQk]gNF
NkEgUG^fNi=k]WNENkAkTg^cMi5k/GNANk9gTG^aMi5k/WNcNmAg]G_EMkMgfG>iLmU_VVnkJg][VfMk
Ji]SFfMlFcaO?09K?00SFaaO?5KlFaaFo5/LE_aK75;lE_aBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg00AOol00`00Oomoo`0JOol00`00Oomoo`05Ool001aoo`03
001C7Dkm009Bo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eG7@03Dad00eLMDaeC7@02Ead025LLFceG?5/m
GcaOG5llGe`5He`2Ig/01FMlLiQg^7>hMkT00WNg0W^e0WNg0W^e00IkTg^bNi5kTW^ANi82Ni403GNA
Ni5k/W^dMkEgeGNcNkAg]GOEKiY_^V]k009[V`03IgaSFfMl009WO008FaaK?5/LFcaK75/lE_aG70=F
o003EaaBo5Kl009Fo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg00GOol00`00Oomoo`0IOol00`00
Oomoo`05Ool0019oo`D000Eoo`03001>o@000080002<C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeBo5LMEaaK
?ELLFceG75/mEaaSO09SG00bGe]SO6=LIgaWFfMlJgY_Vf]jKi]gUW^gLiQg^GNFNkMgUG^fNi=k]7^B
Nk9gTG^cMi5k/GNANk9gTW_DMi5k/WNBNmAg]G_EMkMgf7>iLmUc^6MlHe]WO6=KIgaO?6=LFaaO?09K
7006EaaK75KlEaaBo5LL0UKl019Bg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_`JOol0
0`00Oomoo`0HOol00`00Oomoo`05Ool001Aoo`03001oogoo00Eoo`800003D_eC7Dkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MC_eC7E;mDaeBoE<M
D_eC7E;m0e<M00ABoE<MDaeG7@=C7@0:EaeC7ELMEcaK?ELLFceK?5/mFc`3He`3Ig/02VMlJgY[Vf]k
Ji]_VFnJLkQg^G>H0WNg0W^e00Mk]7^BNk=kTG^bNi5k/P03Ni402G^bMi5k/W^bNkAg/gOEMkEge`03
LkT01VnjKiYWO6MlHeaOG0=SG005EaaK75/LFaaG7002E_`00eLLE_aFo002E_`015;lE_aBo5Kl2e;l
77oo00<007ooOol06Goo00<007ooOol017oo000DOol00`00Oomoo`06Ool0b000Oom>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;l
DaeBo5<MD_aG7E<LEaeC75LMDaaG7E/lFceK?5lmFcaK?E/lGceWFfMlIe]WO6]jKi][NVnKKiUcVVnI
MkUcV7^gMiIk]W^eNkAkTg^cNi5k]7^BNk9kTG^aMi5k/WNANk5gTW^bMk=keGNeMmQg]g?ILkQc^fnJ
KkY_VV=LGcaSG5lkGcaK?5llEaaK75LLFa`2Ea`045;lEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aB
g5Kl8Goo00<007ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07Ool200000e;mDae>o@02
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d0
1U<MD_eC7E;mDaeBo@IC7@03EaeC7ELM009G7@04EaaG7E/lFcd3Fc`02U/mGcaOG6MkIga[NV^KJg][
VfnI0VnJ00=g^G>HMkP00WNg0W^e0W^d00AkTW^dNi9k/`=kT@03Nk5kTG^A009k/P05Mk=k/gNeMmMg
]`03LkT01VnJKkY_VV^KJg][V`IO?004E_aG75LLEa`4E_`015;lE_aFo5Kl0e;l00=Fo5;lOol09Goo
00<007ooOol05goo00<007ooOol017oo000DOol00`00Oomoo`09Ool0a`00OomC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG
7E<LEaeC75LmEaaG?ELLEceK?5/mFcaOGEllGeaK?5mMJgY_Vf]jKi]_VG>JKiUg^G>HMkUgUW^gNkEk
]W^CNkAkTW^fNi=k/g^ANk9gTG^bNi5k/GNANk9gTW^dMkEkeWNgLmUc^7OIKiY_^VMkJi][Nf^KHe]W
O5/lGcaK?5llFaaK?5KlFaaFo5/L009Fo008D_aFo5;lE_aBo5KlD]aFo2Qoo`03001oogoo01Moo`03
001oogoo00Aoo`0057oo00<007ooOol02Woo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@04DaeBoE<MD_d7Dad2Ead035LLEaeG
7ELMEaaG7EllGeaO?5mLGcaOG0ASG006KiU_VVnJLiYcV7Nh0gNg0W^e00=k]7^CNkD00W^d0W^B00=k
TG^bNi400W^A00]k/GNbNk=g/g_EMk=k/gNeNmE_VVnj009[V`0<Jg]WO6MlIgaSFfMlFaaK?5/LFcaK
75/l0eKl00=G75KlE_`00UKl00=Bo5KlOol0:goo00<007ooOol05Woo00<007ooOol017oo000BOol3
000=Ool0S@00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7E;lDae>o5<MD_aC7DklEaeC75LMD_aG7ELLEceG75LmEaaK?ELLFceO?5mLFcaSO002He`0<5mKHgaW
FfMlIe]WO7>HMkUcV7^gMiIk]WNENkMgUW^fMiEk]7^BNk9gTG^cNi5k/WNANk9gTW^bMk=k/WNBNkAg
]G_FMkMgeg>hMmUc^FMlHe]WO6=KIgaO>f=LFaaK?09K7007EaaK75;lEaaFo5LLD_`0<Goo00<007oo
Ool05Goo00<007ooOol017oo000DOol00`00Oomoo`0<Ool200001WooC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@04D_eC7E<M
Ead3Dad025/mEaaK?ELlFceG75/mEc`5He`3Ig/016MlJgY[Vf]k0gNg00QcV7NgMkMg]g^eNkAkTg^b
0g^A00ekTW^ANk5gTG^bNi5k/GNbNk=g/g_EMkEge`03LkT016njKiYWO6=K0f=L00EOG6=LFaaK75LL
00=K73Ioo`03001oogoo01Aoo`03001oogoo00Aoo`009Goo0;P007ooC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaK?ELL
FceG75/mEaaO?E/lHeaOFfMlIe]WO6MKIga[NVnKJgYc^VnILiYcV7NiMiIk]gNENkIkTg^cNi9k/W^B
Nk9gTG^aMi5k/WNANk9gTW^bMk=keWNeMmMg]gOILkU_^VnJLk]_VV=LGc]SG09O?005FcaO?5LLFaaG
700hOol00`00Oomoo`0EOol00`00Oomoo`03Ool002Ioo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad3Ead0
25<MEaeG7E/mEaaK?E/lFcd3Fc`03FMlIg]WNfMkIga[NV^KJg]cVVnIKiYcV7Ni00=g]`07NkEkTg^d
Ni9k/W^CNk800W^A00]gTG^ANi5k/GNANk9g/g^dMkEgegNg00=c^@03KiY_^VnJ00=[V`IO?3]oo`03
001oogoo01Aoo`03001oogoo00=oo`009goo0;T007ooOomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MDaaG7E<LEaeC75LMDaaK?E/lGceK?5/mFcaO
GEllIgaWFfMlJgY_Vf]jLkY_VG>JKiUg^G>HNkMgUW^fNkEk]7^CNk=kTg^cMi5k/WNANk5gTG^aMi5k
/WNBNmAg]G_EMkMgfG>iLmU_VW>kJg][VfMkJiaSFfMlFcaO?5/l03ioo`03001oogoo01=oo`03001o
ogoo00=oo`00:7oo0P0000Eooe;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeB
oE;mD_eC7E;mDaeBoE<MD_d8Dad3Ead015LLEaeG7E/m0U/l00]O?5mLGcaOG5llGea[NV^KJg]cVVnI
009_VP03MkUcV7Ng009g]`08NkEk]7^dNk=k]G^dNi9k/PIkT@0;Nk9k]7NcMmEg/g^dMkEgeFnJKkY[
N`02Ji/00fMlHe]WO002Iga1Ool00`00Oomoo`0BOol00`00Oomoo`03Ool002Yoo`27001ooe<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5<MD_aG7E;lDaeG75LmEaaG
?ELLEceG75mLFcaOGEllGeaK?5mM009SG00ZGe]c^VnILiY_VGNiLiQk]gNFNkMk]G^fNi=k]7^ENkAk
TW^bNi5k/GNANk9gTG^aMi9k/WNcNk9gTW_DMkEkeGNgMmQc^G?ILkQWO6=KIgaSFfMl@Woo00<007oo
Ool04Woo00<007ooOol00goo000[Ool01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d2Dad01ULMDaeC7E<MEaeG70=G7@07EaaK?ELlGeaO?5mL
Gc`016=L00MWO6MkIg]WNgNiLiQg^003MkL00g^eMkMg]`02NkD01W^dNk=kTG^ANi9k/P=kT@09Nk9g
TG^ANk9k]7NcMmEg]GOG00=c^@04KkY_VVMlIga5Ool00`00Oomoo`0AOol00`00Oomoo`03Ool002ao
o`23001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeC75LMD_aG
7E<LEaeBo5/mEaaK?ELLFceG75/mGe]SO002He`0:EmKIgaWFfMlIe]_Vf]jKi]gUW^gMiIg^GNFNkMg
UW^fNi=k]7^BNk9kTW^bNi5k/GNANk9gTG^aMi9k/WNcNmEg]GOHMkMcfG>hLk]_VVnjKiX0Agoo00<0
07ooOol047oo00<007ooOol00goo000]Ool20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<M
C_eC7E;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@9C7@9G7@05DaeK?ELlFceG7002Fc`01E/mHeaS
G6=LIg`00fMk00Q[Vf]jJi]_VW>JKiUg^7>H0WNg0W^e00Ek]7^BNi9k]7^c00=kT@0:Nk5kTG^ANi5k
/WNcNk=g]GOGMkL2LkT016njKiY_^VnJBGoo00<007ooOol047oo00<007ooOol00Woo000_Ool0Z000
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lDaeBo5<MD_aC7E<LEaeC75LMDaaG7E<L
GceK?5/mFcaO?E/lFceK?6MlIe]WO6MKKi][NVnKKiUc^VnIMkUcV7^gMiIk]gNENkIkTg^cNi=k/g^B
Nk9gTG^aNi5k/GNANk9gTW^dMkEkeWNgLmUc^7>kKiY_^T]oo`03001oogoo011oo`03001oogoo009o
o`00<7oo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d5
Dad2Ead01E<MEaeG7ELMEa`00U/l00IK?E/lFcaK?5mLGc`2Ig/02F^KJgY[Vf]kLiY_VFnJLiQg^@02
MkL2NkD017^CNk9k]G^d0W^B0W^A00igTG^ANi5k/GNbNk=g/g_EMk=k/gNeMmMg]gOGCGoo00<007oo
Ool03goo00<007ooOol00Woo000aOol0Y000Oomooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC
7E;lEaeBo5<MD_aG7E;lEceG75LmEaaG?ELLGceK?5/mFcaOGEllGeaK?6nKJgY_Vf]jLkY_VG>JLiQg
^GNFNkMgUG^fNiEk]7NENkAkTg^cMi5k/GNANk9gTG^bMi9k/WNcNk9gTW^dMkEkeWNgMmM?Ool00`00
Oomoo`0>Ool00`00Oomoo`02Ool0039oo`05001oogooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eBoE<M
D_eC7E;mDaeBoE<MD_d8Dad00eLMEaaG7@02Ead01eLLGeaO?5mLGcaOG5ll00ASG006LiY_VFnJLiQg
^G>H0WNg0W^e00Ek]7^eNkEkU7^b00=kT@0=Nk9kTG^AMi5k/W^ANk5g/W^cMk=keGNgMmL0D7oo00<0
07ooOol03Woo00<007ooOol00Woo000cOol20000O7ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeB
o5<MD_aG7E<LEaeBo5LMEaaG?ELLEceG75/mEaaOGEllGeaOFf=l0V=L025OFfMlIe]WO7>HMkUcV7^g
MiIk]W^ENkIgUW^fNi=k]7^BNk9kTW^cMi5k/GNANk9gTG^bMi9k/WNcNmIg]GOGMkL0DGoo00<007oo
Ool03Goo00<007ooOol00Woo000eOol01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE<MD_eC7E;mDaeB
oE<MD_d6Dad02eLMDaeC7ELlFceG75/mEcaK?ELLFcd01F=L00IWO6MkIg][Nf^KJgX2KiX017NiLiQg
^7Ng0W^e00Mk]7^BNk=kU7^bNi9k/P03Ni4027^aMi5k/WNcNk=g]GOGMkMCOol00`00Oomoo`0<Ool0
0`00Oomoo`02Ool003Ioo`1i001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LM
DaaG7ELLFceG75/mEaaK?E/lGcd00V=L025WFfMlIe]WO6]jKi][NW>JKiUc^W>HMkUcV7^gNiEk]W^C
Nk=kTG^cNi9k/WNANk5gTG^aMi5k/WNBNmAg]G_EMkL0EGoo00<007ooOol02goo00<007ooOol00Woo
000gOol01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m0e<M00=BoE<MDad00U<M0eLM00AC
7ELMEaeK?@=K?005FceK?5/lIg]WO002Ig/02V]kJi][NV^KKiYcVW>HMkQcV7Ng0W^e0W^d00AkTW^d
Ni9k/`IkT@05Nk9k/gNcMmEg/`1FOol00`00Oomoo`0<Ool00`00Oomoo`01Ool003Qoo`80002GDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MDaaG7E<LEaeG75LmEaaK?E/lGceK?5mLFcaOGEllGea[
NVnKJgY_VfnILkY_VGNiLiQk]gNFNkIgUG^dNi9k]W^CNk=kTG^bMi5k/WNANk5gTW^bMk=k/WNANm@0
Egoo00<007ooOol02goo00<007ooOol00Goo000jOol00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;m
DaeBo@MC7@05EaaG7ELMEaeG7002Ead01emLGcaOG5llGeaO?5mL009SG007JgY[VfnJLiY_VGNhLiP0
0WNg0W^e00Ek]7^DNkEk]7^c009kTP03Ni5k/g^A009kT@05Nk9gTG^AMk9k/`1IOol00`00Oomoo`0:
Ool00`00Oomoo`01Ool003]oo`1h001oogooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E<LEaeG75LmEaaG
?ELLFceG75mLFcaOGEllHeaOFf=l0V=L01]_VG>jKiUcVW>HMkUgUW^gMiEk]WNGNkMgUG^dNi9k/WNA
Nk=kTG^aMi5k/WNANk5gTG^bMk<0FWoo00<007ooOol02Goo00<007ooOol00Goo000lOol00`00Oomo
o`02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>
oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@9C7@0=EaeC7E<MDaeG7E<MFceG?5/mEaaK?ELlFcd01V=L
00IWNfMlIg]WNg>HMkT2MkL02W>HMkUg]gNgNkEk]7^BNk9kTG^d0W^B00=kTG^aNi400W^A00=k/WNc
Ool0FWoo00<007ooOol02Goo00<007ooOol00Goo000mOol20000T7ooDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LM
D_aG7E<LEaeC75/mEaaK?ELLFceK?5/mGe]SO6=LIgaWFfMlIe]WO6]jKi]_VG>JLiQg^G>HNkMgUW^f
Ni=k/gNANkAkTW^bMi5k/G^ANk5gTG^bMi9k]5aoo`03001oogoo00Qoo`03001oogoo005oo`00?goo
00H007ooD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;m
Dae>oE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMDad00eLM00AG75/mEcaK?@=K?005FceK?6Mk
Ig]WO002Ig/00f]kJi]_V@02KiX02gNiLiQg]gNgNkEkU7^dNi9k]7^DNk800W^A00IgTG^ANi5k/GNb
Nk=NOol00`00Oomoo`07Ool00`00Oomoo`01Ool0041oo`2>001ooe<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E<L
EaeC75LMFcaO?E/lFceK?5lmFcaOG5/lIgaWFfnKJgY_VfnILiY_VGNiLiQk]gNFNkMkUG^dNi9k]W^C
Nk=gTG^bMi5k/WNANk9gTW^bMi5OOol00`00Oomoo`07Ool10001Ool1Ool0045oo`06001oogooD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eBoE<MD_eC7E;mDaeB
oE<MD_d7Dad2Ead015<MEaeG7ELM0e/l00YK?EllGeaO?5mLGca[Vf]kJi]_V@9_VP03MkUcV7Ng009g
]`0:NkEk]7^dNkEkU7^dNi9k/W^ANk82Ni400gNANk9kT@1POol00`00Oomoo`07Ool10001Ool1Ool0
049oo`800029Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeB
o5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeG75LmEaaG?ELLEceG75mMGcaOG5/lGeeO?6=LGe]SO6nILiY_
VG>JLiQg^GNFNkMgUg^fMiIk]g^ENkAkTW^bNi5k/gNANk5gTG^bMi5k/P1QOol00`00Oomoo`06Ool1
0001Ool1Ool004Aoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@AC7@03EaeC7E<M009G7@08EaaG7ELlFceG75mLGcaO
G0ASG0=WN`03IgacV7Nh00=g]`04MkQg]gNgNkD2Nk@01G^cNi5k]7^BNk800g^A00=k/GooOol0HGoo
00<007ooOol01Goo0@000Goo0Goo0015Ool0JP00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lEaeG75/mEaaK?ELLFceG76=l
0V=L01]OFf=lIe]WO6MKIga[NVnKKiUcVVnIMkUcV7^gMiMk]W^CNk=kTG^dNi9k/WNANk5gTG^aMi40
Hgoo00<007ooOol01Goo0@000Goo0Goo0016Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@04Dad02ULMDaeG7ELlFceG
75/mFcaK?E/l0f=L0fMk00QWO6]jJi]_VW>JKiUg^7>H0WNg00Ak]G^dNkAkTP9k]003Nk=kTG^A009k
T@03Mi5kTGoo06=oo`03001oogoo00Aoo`40005oo`5oo`00Agoo0P00089ooe<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeC75/m
FcaO?E/lFceK?5lmIe]WO6MKKi][NVnKJgYcVVnILiYcV7NiMiMk]gNENkAkTW^fNi=k/g^BNk9gTG^b
Mi5k/FIoo`03001oogoo00=oo`40005oo`5oo`00BGoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m25<M0eLM00AG75LMEaeK?@=K?00=GeaO?5mL
Gca[Vf]jJi][Ng>JKiU_VW>HMkT00WNg00Ak]G^dNiAk]@9k]09kTP03Ni5k/g^A009kTFMoo`03001o
ogoo00=oo`40005oo`00BWoo06T007ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MC_aC7E;lDaeBo5LMD_aC7ELLEceG75LmEaaG?ELLGeaK?5mMGcaOG5/lHg`00V=L01EOFg>J
KiUcVW>HMkUcV7^gMiIk]WNGNkMgUG^dNi9k/gNANk=kTG^aMi40J7oo00<007ooOol00goo0@000Goo
001;Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;m
DaeBo@IC7@03EaeG75LM009G7@06EaaK?ELlGeaO?5mL1F=L00IWO6MkIg]cV7NiLiP2MkL02GNiMkMg
]g^eNkAkU7^bNi5k]002Ni800g^ANk5oo`1XOol00`00Oomoo`02Ool10001Ool004aoo`80001SDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E<LEaeBo5LMDaaG7E;lFceG
75/mEaaK?ELLFceOFf=l009SG00GGe]WO6MKIga[NVnKJgYcVVnIMkUcV7^gMiIk]W^CNk=kTW^dNi9k
/WNANk9kT@1ZOol01@00Oomoogoo00000Goo001>Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00YC7DkmD_eBoE<MD_eC7E;mDaeBo@=C7@04D_eC7E<MEad2Dad2Ead01E<MFceG?5/mEa`00U/l00EK
?F=LHeaWNfMl009WN`03Jg][Vf]j009_VP0;MkUcV7NgMkMk]G^DNkAkTW^eNiAk/P03Ni5/Ool01000
Oomoo`000Goo001?Ool0NP00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<M
D_aC7E<LEaeC75LMDaaG7E<LGceK?5/mFcaO?E/lFceWFfMlIe]WO6]jKi][NW>JKiUcVW>HMkUgUW^g
NiEk]7NENkIkTg^cNi9k/W^BNk9/Ool01000Oomoo`000Goo001@Ool00`00Oom>o@02D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@EC7@9G7@05DaeG7ELMEaeG7002Fc`02U/mFcaO
G5llGeaO?5mLJg][Vf]j0VnJ00=cVW>HMkP00WNg00=k]G^dMkL00W^e00Ek]7^BNk9kTG^B06ioo`03
001oo`00005oo`00DGoo0P0007E>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7DklEaeBo5<M
D_aG7E;lEceG75LmEaaG?ELLEceO?5mLFcaOGEllGeaOFf=lHeacVVnILiYcV7NiLiQk]gNGNkIgUW^f
NiEk]7^CNk=kTG^cMi40Kgoo0@000Goo0@00001COol01P00C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M
00=Bo@04DaeBoE<MD_d8Dad02ULMEaaG7ELMFceG75/mGcaOG5ll16=L0VMk00AWO7>HMkQcV09g]`03
MkQg]gNg009k]@06NkAk/g^ANkAkTW^bL7oo0P00001DOol0F`00OomC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeB
o5<MC_aC7E;lDaeBo5LMDaaG7E;lEaeC75/mEaaK?ELLFceG75/m009SG00FGe]SO6=LIgaWFfMlJgY_
Vf]jLiY_VGNiLiQk]g^ENkIkTg^dNi9k]7^BNk9aOol2000005Eoo`06001ooe;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<M
C_eC7E;mDaeBoE<MD_eC7E;m1U<M00UG7E<MEaeG7E/mEaaK?ELlFcd00U/l0f=L0VMk00QWO6]jJi][
Ng>JKiU_VW>H0WNg0W^e00Ik]7^BNkEk]7^cNi5aOol2000005Ioo`1`001oogooC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<M
C_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeK?5lmFcaK?E/lGceK?6MlIe]WO6]jKi][NW>J
KiUcVW>HMkUgUg^fMiEk]7^CNkIkTg^cNi5^Ool40002Ool005Moo`800004OomBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@08DaeB
oE;mD_eC7E;mDaeBo@IC7@=G7@04DaeG7ELMEad3Fc`03E/mGcaOG5llGea[NV^KJg]cVVnIKiYcV7Ni
009g]`9k]@04NiAk]G^eNk@2Ni9ZOol40006Ool005Uoo`1J001oodkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<M
D_aG7E;lDaeBo5LmEaaG?ELLEceG75LmFcaOGEllGeaK?5mM0V=L015OFg>JKiUcVVnIMkUcV7^gMiEk
]WNGNkMgUG^dNi=k/g^C06Ioo`@000Yoo`00FWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<M
D_d4Dad00eLMDaeG7@02Ead01eLLFceG?5/mGcaOG5ll00ASG006IgaWNfMkIg]g^G>H0WNg00=g^GNg
MkL00W^e00=kU7^bNi40Hgoo10003Woo001KOol0EP00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeC
75LMD_aG7ELLFceG75/mEaaK?ELLHg`2He`04UmKIgaWFfMlIe]_Vf]jLiY_VGNiLiQk]gNFNkIkTg^d
Ni9k]5moo`@0019oo`00G7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00YC7DkmD_eBoE<MD_eC7E;mDaeBo@=C7@04D_eC7E<MEad3Dad02ULMDaeG
7ELlFceG75/mFcaK?E/l0V=L00IWO6MkIg]WNf^KJgX2KiX017>JLiQg]gNg0W^e00=k]7^BNkD0GGoo
0`005Woo001NOol0IP00OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeK?5/mFcaO?E/lFceK
?6MlIe]WO6]jKi][NVnKKiUcVW>HMkUgUW^fNiEk]7^CNkIkTeUoo`@001Uoo`00Ggoo00@007ooDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE;mD_eC7E;m
DaeBoE<MD_d6Dad00eLMDaeG7@02Ead015LLEaeK?5/m0U/l00aO?5mLGcaOG6]kJi][NV]kKiYcVW>H
MkP2MkL2NkD2MkL00g^eNkAoo`1DOol4000MOol0061oo`1E001ooe<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7ELL
EceG75LmEaaG?ELLGeaK?5mMGcaOG5mKHg`00V=L00a_VG>JKiUg^G>HNkMcV7NiMiIk]g^ENkABOol4
000QOol0065oo`800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>
oE;mD_eC7@03D_d02E<MD_eC7E;mDaeBoE<MD_eG7@03Dad00eLMEaaG7@02Ead01ELLFceG?5mLGc`0
1F=L00UWNfMlIg]g^7>HLiYcV7NhLiP00WNg00=k]G^dOol0CGoo10009Goo001SOol0G`00Dae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<M
D_aG7E;lEaeC75LMEaaK?ELLFceG75/mEaaSG5mKHgaSG6MlIe]WO6MKKi][NW>JKiUg^G>HNkMgUg^f
Ni<0C7oo0`00:Goo001TOol00`00Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7@03Ead015LLFceG?5/m0e/l00IK
?FMkIg]WNfMlIg/2Jg/017>JKiUg^7>H0gNg00=k]G^dOol0Agoo1000;7oo001UOol0G@00Oom>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LM
D_aG7E<LEaeC75LMDaaO?E/lFceK?5lmGcaOG6MKIgaWFfnKJgY_VfnIMkUcV7^gMiMk]gNENkAgU`14
Ool4000`Ool006Ioo`800005C_eBoE;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC
7E;mD_eBoE<MD_eC7E;mDaeBo@EC7@9G7@05DaeG7ELMEaeG7002Fc`01UmLGcaOG5llGeaO?09[N`05
Ji]_VFnJLiQg^@03MkL00g^eMkMoo`10Ool4000dOol006Qoo`1;001ooe<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lDaeBo5LMEaaG?ELLEceG75LmEaaO
GEllGeaK?5mM009SG00<Ge]SO6nILiYcV7NiMiMk]gNFMkUgUg^g?Goo1000>7oo001YOol01P00OomB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M
00=G7E<MDad00ULM00IG75LMEcaK?ELLFcd6He`2Ig/00f]kJi]_V@02KiX00gNiLiQg]`0jOol4000l
Ool006Yoo`17001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7E;lDaeB
o5<MD_aG7E<LEaeBo5LMDaaK?ELLFceG75/mFcaO?@02He`03EmKIgaWFfMlJgY_VfnILiY_VGNiLiQk
]gNF03Moo`<0041oo`00Jgoo0P000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE;mD_eC
7E;mDaeBoE<MD_d3Dad01E;mEaeG7ELMDad00eLM0e/l00EK?E/lFcaK?6Ml009WN`03Jg][Vf]j009_
VP04LiYcV7NhMkLdOol40013Ool006eoo`1B001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeB
o5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75LMDaaG?ELLEceK?5lmFcaK?E/lGeeO?5mLJgY_Vf]jLiY_
VG>JLiQg^GNFNkL`Ool40017Ool006ioo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC
7@03D_d015<MD_eC7E;m1e<M0ULM00YG75LMEaeG7EllGeaO?5mLGcaOG0=SG09_VP05LiYcV7NhLiQg
]`0]Ool4001;Ool006moo`1>001oogooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
Dae>o5LMDaaG7E;lEaeG75LmEaaK?ELLFceK?5mMGcaSG5mKHgaSG6MlIe]WO7>HMkUcV7>J:Woo1000
Cgoo001`Ool200000gooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE<MD_eC7E;mDaeBoE<MD_d3Dad015;m
DaeC7ELM0U<M00MG?5/mEaaK?ELlFceG7003He`3Ig/01VMlJgY[Nf]kLiY_VBMoo`<005=oo`00LWoo
04X004kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E<LEaeG75/m
EaaK?E/lFceK?5lmIe]WO6MKKi][NV^KJgYcVVnI97oo1000EWoo001cOol01000D_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@=G7@04DaaG7ELMFcd3Fc`01U/mGcaOG5ll
Ji][NP9[N`03LiY_VGoo021oo`@005Yoo`00M7oo044004kmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7Dkl
DaeBo5<MD_aG7E;lDaeBo5LmEaaG?ELLEceG75/mFcaOGEllGeaK?6=l009SG004Ge]cVVnILiXMOol4
001NOol007Eoo`800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@04DaeBoE<MD_d4Dad00eLMDaeG7@02
Ead01ULLEaeG7EmLGcaOG0ESG003IgaWNfMk01Yoo`@0069oo`00Mgoo03`005<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7E;lDae>o5<MD_aG7E;lEaeC75LMD_aG7ELLFceG75/mEaaK?EmKHg`2He`015mKIgaWFfMl5goo
1000IWoo001hOol00`00Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@06EaeC75LM
EcaK?ELL0U/l00EK?F=LHeaWNfMl009WNaEoo`<006Yoo`00NGoo03h005<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC
7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7E/lFceK?5lmFcaK?FMKIgaWFfMl4Woo1000KGoo001jOol0
0`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1U<M00=G7E<LEad00ULM00YG75LMFcaK?E/lGeaO?5mLGcaO
G0moo`@0075oo`00Ngoo0P0003M>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MEaaG?ELLEceG75Lm
GcaOG5/lGeeO?00=Ool4001eOol007eoo`06001>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@0ADae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eG7@03Dad025LM
EaaG7ELMFceG75/mEc`<Ool4001iOol007ioo`0a001>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeC75LM
EaaK?ELLFcd02Woo1000OGoo001oOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoE<MDaeG7E<L00=G7@03Daao
ogoo00Moo`<0085oo`00P7oo0P0002UC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeC75LM00Moo`@008Aoo`00PWoo
00D005;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;m
DaeBoE<MD_eC7E;m1U<M1Goo1000R7oo0023Ool08P00Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5<M1Goo1000S7oo0024Ool01@00OomB
oE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m1Goo
1000T7oo0025Ool200005TkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<M
1Woo0`00U7oo0027Ool01000D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@Ao
o`@009Moo`00R7oo014004kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M009oo`@009]oo`00
RGoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0Woo1000Wgoo002:Ool200001E<MC_aC7DkmDad0
0Woo1000Xgoo002<Ool200000goo00000002002WOol008eoo`800:]oo`00ogoo>goo003oOolkOol0
0?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00001\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.646 .763 .934 r
.38973 .79901 .39806 .80577 .41196 .8021 .40367 .79532 Mtetra
.40367 .79532 .41196 .8021 .42593 .79841 .41769 .79159 Mtetra
.647 .763 .934 r
.41769 .79159 .42593 .79841 .43998 .79468 .43178 .78784 Mtetra
.43178 .78784 .43998 .79468 .45409 .79089 .44595 .78404 Mtetra
.649 .764 .933 r
.44595 .78404 .45409 .79089 .46829 .78702 .46019 .78017 Mtetra
.652 .766 .933 r
.46019 .78017 .46829 .78702 .48255 .783 .4745 .77618 Mtetra
.657 .77 .932 r
.4745 .77618 .48255 .783 .4969 .7787 .48889 .77199 Mtetra
.666 .776 .931 r
.48889 .77199 .4969 .7787 .51131 .77392 .50336 .76745 Mtetra
.683 .787 .929 r
.50336 .76745 .51131 .77392 .52579 .76825 .5179 .76223 Mtetra
.713 .807 .923 r
.5179 .76223 .52579 .76825 .54033 .76095 .5325 .75581 Mtetra
.762 .838 .91 r
.5325 .75581 .54033 .76095 .55489 .7508 .54714 .74721 Mtetra
.831 .879 .879 r
.54714 .74721 .55489 .7508 .56942 .73597 .56179 .7349 Mtetra
.905 .917 .817 r
.56179 .7349 .56942 .73597 .58383 .71427 .57636 .71679 Mtetra
.957 .934 .724 r
.57636 .71679 .58383 .71427 .59799 .68454 .59075 .69096 Mtetra
.972 .927 .627 r
.59075 .69096 .59799 .68454 .61187 .64866 .60486 .65751 Mtetra
.964 .916 .566 r
.60486 .65751 .61187 .64866 .62553 .61209 .61869 .62031 Mtetra
.956 .923 .572 r
.61869 .62031 .62553 .61209 .63916 .58073 .6324 .58561 Mtetra
.954 .949 .656 r
.6324 .58561 .63916 .58073 .65294 .55721 .64617 .55796 Mtetra
.929 .955 .778 r
.64617 .55796 .65294 .55721 .66692 .54081 .66013 .53813 Mtetra
.862 .914 .865 r
.66013 .53813 .66692 .54081 .68111 .52945 .67431 .52444 Mtetra
.788 .854 .9 r
.67431 .52444 .68111 .52945 .69547 .52119 .68867 .51476 Mtetra
.734 .807 .909 r
.68867 .51476 .69547 .52119 .70997 .51469 .7032 .50745 Mtetra
.702 .777 .91 r
.7032 .50745 .70997 .51469 .72459 .50916 .71785 .50146 Mtetra
.684 .761 .91 r
.71785 .50146 .72459 .50916 .73931 .50414 .7326 .49616 Mtetra
.674 .752 .909 r
.7326 .49616 .73931 .50414 .75411 .49937 .74746 .49124 Mtetra
.669 .747 .909 r
.74746 .49124 .75411 .49937 .76901 .49474 .7624 .48649 Mtetra
.667 .744 .908 r
.7624 .48649 .76901 .49474 .78398 .49016 .77743 .48183 Mtetra
.665 .743 .908 r
.77743 .48183 .78398 .49016 .79904 .48559 .79254 .47721 Mtetra
.664 .742 .908 r
.79254 .47721 .79904 .48559 .81417 .48103 .80773 .47259 Mtetra
.80773 .47259 .81417 .48103 .82939 .47645 .823 .46796 Mtetra
.823 .46796 .82939 .47645 .84469 .47185 .83836 .46332 Mtetra
.664 .741 .908 r
.83836 .46332 .84469 .47185 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .4626 .86932 .45397 Mtetra
.86932 .45397 .87552 .4626 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.646 .763 .934 r
.38132 .79219 .38973 .79901 .40367 .79532 .39531 .78846 Mtetra
.39531 .78846 .40367 .79532 .41769 .79159 .40937 .78471 Mtetra
.40937 .78471 .41769 .79159 .43178 .78784 .42351 .78093 Mtetra
.647 .763 .934 r
.42351 .78093 .43178 .78784 .44595 .78404 .43772 .7771 Mtetra
.648 .764 .933 r
.43772 .7771 .44595 .78404 .46019 .78017 .45201 .77322 Mtetra
.65 .765 .933 r
.45201 .77322 .46019 .78017 .4745 .77618 .46637 .76926 Mtetra
.654 .768 .933 r
.46637 .76926 .4745 .77618 .48889 .77199 .48081 .76514 Mtetra
.661 .772 .932 r
.48081 .76514 .48889 .77199 .50336 .76745 .49533 .76074 Mtetra
.673 .781 .93 r
.49533 .76074 .50336 .76745 .5179 .76223 .50992 .75586 Mtetra
.696 .796 .927 r
.50992 .75586 .5179 .76223 .5325 .75581 .52458 .75008 Mtetra
.735 .821 .918 r
.52458 .75008 .5325 .75581 .54714 .74721 .5393 .74266 Mtetra
.794 .858 .897 r
.5393 .74266 .54714 .74721 .56179 .7349 .55404 .73237 Mtetra
.869 .9 .852 r
.55404 .73237 .56179 .7349 .57636 .71679 .56876 .71735 Mtetra
.936 .929 .773 r
.56876 .71735 .57636 .71679 .59075 .69096 .58334 .69543 Mtetra
.969 .932 .673 r
.58334 .69543 .59075 .69096 .60486 .65751 .59769 .66542 Mtetra
.969 .92 .59 r
.59769 .66542 .60486 .65751 .61869 .62031 .61174 .62922 Mtetra
.958 .916 .559 r
.61174 .62922 .61869 .62031 .6324 .58561 .62557 .59233 Mtetra
.955 .935 .606 r
.62557 .59233 .6324 .58561 .64617 .55796 .63937 .56069 Mtetra
.947 .958 .718 r
.63937 .56069 .64617 .55796 .66013 .53813 .65331 .53695 Mtetra
.899 .939 .829 r
.65331 .53695 .66013 .53813 .67431 .52444 .66747 .52037 Mtetra
.823 .883 .887 r
.66747 .52037 .67431 .52444 .68867 .51476 .68183 .50886 Mtetra
.758 .828 .906 r
.68183 .50886 .68867 .51476 .7032 .50745 .69636 .50047 Mtetra
.716 .79 .91 r
.69636 .50047 .7032 .50745 .71785 .50146 .71104 .49385 Mtetra
.692 .768 .91 r
.71104 .49385 .71785 .50146 .7326 .49616 .72584 .48821 Mtetra
.678 .755 .909 r
.72584 .48821 .7326 .49616 .74746 .49124 .74074 .48307 Mtetra
.671 .749 .909 r
.74074 .48307 .74746 .49124 .7624 .48649 .75574 .47819 Mtetra
.668 .745 .908 r
.75574 .47819 .7624 .48649 .77743 .48183 .77082 .47345 Mtetra
.666 .743 .908 r
.77082 .47345 .77743 .48183 .79254 .47721 .78598 .46875 Mtetra
.665 .742 .908 r
.78598 .46875 .79254 .47721 .80773 .47259 .80123 .46407 Mtetra
.664 .742 .908 r
.80123 .46407 .80773 .47259 .823 .46796 .81656 .45939 Mtetra
.81656 .45939 .823 .46796 .83836 .46332 .83197 .4547 Mtetra
.664 .741 .908 r
.83197 .4547 .83836 .46332 .8538 .45865 .84747 .44999 Mtetra
.84747 .44999 .8538 .45865 .86932 .45397 .86305 .44526 Mtetra
.86305 .44526 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.646 .762 .934 r
.37283 .7853 .38132 .79219 .39531 .78846 .38686 .78154 Mtetra
.646 .763 .934 r
.38686 .78154 .39531 .78846 .40937 .78471 .40097 .77775 Mtetra
.40097 .77775 .40937 .78471 .42351 .78093 .41515 .77394 Mtetra
.647 .763 .934 r
.41515 .77394 .42351 .78093 .43772 .7771 .42941 .77009 Mtetra
.42941 .77009 .43772 .7771 .45201 .77322 .44375 .7662 Mtetra
.649 .764 .933 r
.44375 .7662 .45201 .77322 .46637 .76926 .45816 .76223 Mtetra
.652 .766 .933 r
.45816 .76223 .46637 .76926 .48081 .76514 .47265 .75815 Mtetra
.657 .77 .932 r
.47265 .75815 .48081 .76514 .49533 .76074 .48722 .75386 Mtetra
.666 .776 .931 r
.48722 .75386 .49533 .76074 .50992 .75586 .50186 .74921 Mtetra
.683 .787 .929 r
.50186 .74921 .50992 .75586 .52458 .75008 .51658 .74389 Mtetra
.713 .807 .923 r
.51658 .74389 .52458 .75008 .5393 .74266 .53136 .73735 Mtetra
.762 .838 .91 r
.53136 .73735 .5393 .74266 .55404 .73237 .54619 .72862 Mtetra
.831 .879 .879 r
.54619 .72862 .55404 .73237 .56876 .71735 .56102 .71615 Mtetra
.905 .918 .817 r
.56102 .71615 .56876 .71735 .58334 .69543 .57578 .69783 Mtetra
.958 .934 .724 r
.57578 .69783 .58334 .69543 .59769 .66542 .59035 .67174 Mtetra
.972 .927 .627 r
.59035 .67174 .59769 .66542 .61174 .62922 .60464 .63799 Mtetra
.964 .916 .566 r
.60464 .63799 .61174 .62922 .62557 .59233 .61864 .60046 Mtetra
.956 .923 .573 r
.61864 .60046 .62557 .59233 .63937 .56069 .63252 .56545 Mtetra
.954 .949 .657 r
.63252 .56545 .63937 .56069 .65331 .53695 .64646 .53755 Mtetra
.929 .955 .778 r
.64646 .53755 .65331 .53695 .66747 .52037 .66059 .51752 Mtetra
.862 .913 .865 r
.66059 .51752 .66747 .52037 .68183 .50886 .67494 .50367 Mtetra
.788 .853 .9 r
.67494 .50367 .68183 .50886 .69636 .50047 .68948 .49385 Mtetra
.734 .807 .909 r
.68948 .49385 .69636 .50047 .71104 .49385 .70419 .48642 Mtetra
.702 .777 .91 r
.70419 .48642 .71104 .49385 .72584 .48821 .71902 .4803 Mtetra
.684 .761 .91 r
.71902 .4803 .72584 .48821 .74074 .48307 .73396 .47489 Mtetra
.674 .752 .909 r
.73396 .47489 .74074 .48307 .75574 .47819 .74901 .46985 Mtetra
.669 .747 .909 r
.74901 .46985 .75574 .47819 .77082 .47345 .76414 .46499 Mtetra
.667 .744 .908 r
.76414 .46499 .77082 .47345 .78598 .46875 .77936 .46022 Mtetra
.665 .743 .908 r
.77936 .46022 .78598 .46875 .80123 .46407 .79466 .45548 Mtetra
.664 .742 .908 r
.79466 .45548 .80123 .46407 .81656 .45939 .81005 .45075 Mtetra
.81005 .45075 .81656 .45939 .83197 .4547 .82552 .446 Mtetra
.82552 .446 .83197 .4547 .84747 .44999 .84108 .44124 Mtetra
.664 .741 .908 r
.84108 .44124 .84747 .44999 .86305 .44526 .85671 .43646 Mtetra
.85671 .43646 .86305 .44526 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.646 .762 .934 r
.36425 .77835 .37283 .7853 .38686 .78154 .37833 .77455 Mtetra
.646 .763 .934 r
.37833 .77455 .38686 .78154 .40097 .77775 .39249 .77073 Mtetra
.39249 .77073 .40097 .77775 .41515 .77394 .40672 .76688 Mtetra
.40672 .76688 .41515 .77394 .42941 .77009 .42103 .763 Mtetra
.647 .763 .934 r
.42103 .763 .42941 .77009 .44375 .7662 .43541 .75909 Mtetra
.648 .764 .933 r
.43541 .75909 .44375 .7662 .45816 .76223 .44987 .75511 Mtetra
.65 .765 .933 r
.44987 .75511 .45816 .76223 .47265 .75815 .46441 .75105 Mtetra
.654 .768 .933 r
.46441 .75105 .47265 .75815 .48722 .75386 .47902 .74683 Mtetra
.661 .772 .932 r
.47902 .74683 .48722 .75386 .50186 .74921 .49372 .74233 Mtetra
.673 .781 .93 r
.49372 .74233 .50186 .74921 .51658 .74389 .50849 .73734 Mtetra
.696 .796 .927 r
.50849 .73734 .51658 .74389 .53136 .73735 .52334 .73144 Mtetra
.735 .821 .918 r
.52334 .73144 .53136 .73735 .54619 .72862 .53824 .7239 Mtetra
.794 .858 .897 r
.53824 .7239 .54619 .72862 .56102 .71615 .55317 .71346 Mtetra
.869 .9 .852 r
.55317 .71346 .56102 .71615 .57578 .69783 .56807 .69826 Mtetra
.936 .929 .773 r
.56807 .69826 .57578 .69783 .59035 .67174 .58285 .67611 Mtetra
.969 .932 .673 r
.58285 .67611 .59035 .67174 .60464 .63799 .59737 .64581 Mtetra
.969 .92 .59 r
.59737 .64581 .60464 .63799 .61864 .60046 .6116 .60928 Mtetra
.959 .916 .56 r
.6116 .60928 .61864 .60046 .63252 .56545 .6256 .57208 Mtetra
.956 .935 .606 r
.6256 .57208 .63252 .56545 .64646 .53755 .63958 .54015 Mtetra
.947 .957 .718 r
.63958 .54015 .64646 .53755 .66059 .51752 .65369 .51619 Mtetra
.899 .939 .829 r
.65369 .51619 .66059 .51752 .67494 .50367 .66802 .49943 Mtetra
.823 .883 .887 r
.66802 .49943 .67494 .50367 .68948 .49385 .68256 .48776 Mtetra
.758 .828 .906 r
.68256 .48776 .68948 .49385 .70419 .48642 .69728 .47924 Mtetra
.716 .79 .91 r
.69728 .47924 .70419 .48642 .71902 .4803 .71214 .4725 Mtetra
.692 .768 .91 r
.71214 .4725 .71902 .4803 .73396 .47489 .72712 .46673 Mtetra
.678 .755 .909 r
.72712 .46673 .73396 .47489 .74901 .46985 .74221 .46148 Mtetra
.671 .749 .909 r
.74221 .46148 .74901 .46985 .76414 .46499 .7574 .45649 Mtetra
.668 .745 .908 r
.7574 .45649 .76414 .46499 .77936 .46022 .77267 .45162 Mtetra
.666 .743 .908 r
.77267 .45162 .77936 .46022 .79466 .45548 .78803 .44681 Mtetra
.665 .742 .908 r
.78803 .44681 .79466 .45548 .81005 .45075 .80348 .44202 Mtetra
.664 .742 .908 r
.80348 .44202 .81005 .45075 .82552 .446 .81901 .43722 Mtetra
.81901 .43722 .82552 .446 .84108 .44124 .83462 .43241 Mtetra
.664 .741 .908 r
.83462 .43241 .84108 .44124 .85671 .43646 .85032 .42757 Mtetra
.85032 .42757 .85671 .43646 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.646 .762 .934 r
.35559 .77133 .36425 .77835 .37833 .77455 .36972 .76749 Mtetra
.36972 .76749 .37833 .77455 .39249 .77073 .38392 .76363 Mtetra
.646 .763 .934 r
.38392 .76363 .39249 .77073 .40672 .76688 .3982 .75975 Mtetra
.3982 .75975 .40672 .76688 .42103 .763 .41255 .75584 Mtetra
.647 .763 .934 r
.41255 .75584 .42103 .763 .43541 .75909 .42699 .7519 Mtetra
.42699 .7519 .43541 .75909 .44987 .75511 .44149 .7479 Mtetra
.649 .764 .933 r
.44149 .7479 .44987 .75511 .46441 .75105 .45608 .74384 Mtetra
.652 .766 .933 r
.45608 .74384 .46441 .75105 .47902 .74683 .47075 .73966 Mtetra
.657 .77 .933 r
.47075 .73966 .47902 .74683 .49372 .74233 .4855 .73527 Mtetra
.666 .776 .931 r
.4855 .73527 .49372 .74233 .50849 .73734 .50032 .73051 Mtetra
.683 .787 .929 r
.50032 .73051 .50849 .73734 .52334 .73144 .51523 .72508 Mtetra
.713 .807 .923 r
.51523 .72508 .52334 .73144 .53824 .7239 .5302 .71841 Mtetra
.762 .838 .91 r
.5302 .71841 .53824 .7239 .55317 .71346 .54521 .70955 Mtetra
.831 .879 .879 r
.54521 .70955 .55317 .71346 .56807 .69826 .56023 .69691 Mtetra
.905 .918 .817 r
.56023 .69691 .56807 .69826 .58285 .67611 .57518 .67839 Mtetra
.958 .934 .723 r
.57518 .67839 .58285 .67611 .59737 .64581 .58994 .65204 Mtetra
.972 .927 .626 r
.58994 .65204 .59737 .64581 .6116 .60928 .60441 .61797 Mtetra
.964 .916 .566 r
.60441 .61797 .6116 .60928 .6256 .57208 .61859 .58011 Mtetra
.956 .923 .573 r
.61859 .58011 .6256 .57208 .63958 .54015 .63264 .5448 Mtetra
.954 .949 .657 r
.63264 .5448 .63958 .54015 .65369 .51619 .64676 .51664 Mtetra
.929 .955 .779 r
.64676 .51664 .65369 .51619 .66802 .49943 .66106 .49641 Mtetra
.862 .913 .865 r
.66106 .49641 .66802 .49943 .68256 .48776 .67559 .48238 Mtetra
.788 .853 .9 r
.67559 .48238 .68256 .48776 .69728 .47924 .69032 .47242 Mtetra
.734 .807 .909 r
.69032 .47242 .69728 .47924 .71214 .4725 .7052 .46486 Mtetra
.702 .777 .91 r
.7052 .46486 .71214 .4725 .72712 .46673 .72022 .45862 Mtetra
.684 .761 .91 r
.72022 .45862 .72712 .46673 .74221 .46148 .73536 .45309 Mtetra
.674 .752 .909 r
.73536 .45309 .74221 .46148 .7574 .45649 .75059 .44793 Mtetra
.669 .747 .909 r
.75059 .44793 .7574 .45649 .77267 .45162 .76592 .44295 Mtetra
.667 .744 .908 r
.76592 .44295 .77267 .45162 .78803 .44681 .78133 .43806 Mtetra
.665 .743 .908 r
.78133 .43806 .78803 .44681 .80348 .44202 .79684 .4332 Mtetra
.664 .742 .908 r
.79684 .4332 .80348 .44202 .81901 .43722 .81243 .42835 Mtetra
.81243 .42835 .81901 .43722 .83462 .43241 .8281 .42348 Mtetra
.8281 .42348 .83462 .43241 .85032 .42757 .84386 .4186 Mtetra
.664 .741 .908 r
.84386 .4186 .85032 .42757 .8661 .42272 .85971 .4137 Mtetra
.85971 .4137 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.646 .762 .934 r
.34685 .76424 .35559 .77133 .36972 .76749 .36102 .76036 Mtetra
.36102 .76036 .36972 .76749 .38392 .76363 .37527 .75647 Mtetra
.646 .763 .934 r
.37527 .75647 .38392 .76363 .3982 .75975 .3896 .75255 Mtetra
.3896 .75255 .3982 .75975 .41255 .75584 .404 .74861 Mtetra
.404 .74861 .41255 .75584 .42699 .7519 .41848 .74463 Mtetra
.647 .763 .934 r
.41848 .74463 .42699 .7519 .44149 .7479 .43304 .74061 Mtetra
.648 .764 .933 r
.43304 .74061 .44149 .7479 .45608 .74384 .44768 .73654 Mtetra
.65 .765 .933 r
.44768 .73654 .45608 .74384 .47075 .73966 .46239 .73237 Mtetra
.654 .768 .933 r
.46239 .73237 .47075 .73966 .4855 .73527 .47719 .72805 Mtetra
.661 .772 .932 r
.47719 .72805 .4855 .73527 .50032 .73051 .49207 .72345 Mtetra
.673 .781 .93 r
.49207 .72345 .50032 .73051 .51523 .72508 .50703 .71835 Mtetra
.696 .796 .927 r
.50703 .71835 .51523 .72508 .5302 .71841 .52206 .71233 Mtetra
.735 .821 .918 r
.52206 .71233 .5302 .71841 .54521 .70955 .53715 .70466 Mtetra
.794 .858 .897 r
.53715 .70466 .54521 .70955 .56023 .69691 .55228 .69407 Mtetra
.869 .9 .852 r
.55228 .69407 .56023 .69691 .57518 .67839 .56737 .67868 Mtetra
.936 .93 .773 r
.56737 .67868 .57518 .67839 .58994 .65204 .58233 .65629 Mtetra
.969 .933 .673 r
.58233 .65629 .58994 .65204 .60441 .61797 .59705 .6257 Mtetra
.969 .92 .589 r
.59705 .6257 .60441 .61797 .61859 .58011 .61146 .58884 Mtetra
.959 .916 .56 r
.61146 .58884 .61859 .58011 .63264 .5448 .62564 .55131 Mtetra
.956 .935 .606 r
.62564 .55131 .63264 .5448 .64676 .51664 .63979 .5191 Mtetra
.947 .957 .718 r
.63979 .5191 .64676 .51664 .66106 .49641 .65408 .4949 Mtetra
.899 .939 .829 r
.65408 .4949 .66106 .49641 .67559 .48238 .66859 .47796 Mtetra
.823 .883 .887 r
.66859 .47796 .67559 .48238 .69032 .47242 .68331 .46614 Mtetra
.758 .828 .906 r
.68331 .46614 .69032 .47242 .7052 .46486 .69821 .45747 Mtetra
.716 .79 .91 r
.69821 .45747 .7052 .46486 .72022 .45862 .71326 .4506 Mtetra
.692 .768 .91 r
.71326 .4506 .72022 .45862 .73536 .45309 .72844 .44472 Mtetra
.678 .755 .909 r
.72844 .44472 .73536 .45309 .75059 .44793 .74372 .43934 Mtetra
.671 .749 .909 r
.74372 .43934 .75059 .44793 .76592 .44295 .7591 .43423 Mtetra
.668 .745 .908 r
.7591 .43423 .76592 .44295 .78133 .43806 .77457 .42924 Mtetra
.666 .743 .908 r
.77457 .42924 .78133 .43806 .79684 .4332 .79013 .42431 Mtetra
.665 .742 .908 r
.79013 .42431 .79684 .4332 .81243 .42835 .80578 .41939 Mtetra
.664 .742 .908 r
.80578 .41939 .81243 .42835 .8281 .42348 .82151 .41447 Mtetra
.82151 .41447 .8281 .42348 .84386 .4186 .83734 .40954 Mtetra
.664 .741 .908 r
.83734 .40954 .84386 .4186 .85971 .4137 .85324 .40458 Mtetra
.85324 .40458 .85971 .4137 .87564 .40877 .86924 .3996 Mtetra
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38957 Mtetra
.9015 .38957 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.646 .762 .934 r
.33802 .75707 .34685 .76424 .36102 .76036 .35224 .75316 Mtetra
.35224 .75316 .36102 .76036 .37527 .75647 .36654 .74923 Mtetra
.36654 .74923 .37527 .75647 .3896 .75255 .38091 .74528 Mtetra
.646 .763 .934 r
.38091 .74528 .3896 .75255 .404 .74861 .39536 .74129 Mtetra
.39536 .74129 .404 .74861 .41848 .74463 .40989 .73728 Mtetra
.647 .763 .934 r
.40989 .73728 .41848 .74463 .43304 .74061 .4245 .73324 Mtetra
.4245 .73324 .43304 .74061 .44768 .73654 .43918 .72915 Mtetra
.649 .764 .933 r
.43918 .72915 .44768 .73654 .46239 .73237 .45395 .72498 Mtetra
.652 .766 .933 r
.45395 .72498 .46239 .73237 .47719 .72805 .4688 .72069 Mtetra
.657 .77 .933 r
.4688 .72069 .47719 .72805 .49207 .72345 .48373 .7162 Mtetra
.666 .776 .931 r
.48373 .7162 .49207 .72345 .50703 .71835 .49875 .71133 Mtetra
.683 .787 .929 r
.49875 .71133 .50703 .71835 .52206 .71233 .51384 .70578 Mtetra
.713 .807 .923 r
.51384 .70578 .52206 .71233 .53715 .70466 .529 .69899 Mtetra
.762 .838 .91 r
.529 .69899 .53715 .70466 .55228 .69407 .54421 .68998 Mtetra
.831 .88 .879 r
.54421 .68998 .55228 .69407 .56737 .67868 .55943 .67718 Mtetra
.905 .918 .817 r
.55943 .67718 .56737 .67868 .58233 .65629 .57457 .65844 Mtetra
.958 .934 .723 r
.57457 .65844 .58233 .65629 .59705 .6257 .58952 .63182 Mtetra
.972 .927 .626 r
.58952 .63182 .59705 .6257 .61146 .58884 .60418 .59744 Mtetra
.964 .916 .566 r
.60418 .59744 .61146 .58884 .62564 .55131 .61854 .55924 Mtetra
.956 .923 .573 r
.61854 .55924 .62564 .55131 .63979 .5191 .63277 .52362 Mtetra
.955 .949 .657 r
.63277 .52362 .63979 .5191 .65408 .4949 .64706 .4952 Mtetra
.929 .955 .779 r
.64706 .4952 .65408 .4949 .66859 .47796 .66155 .47476 Mtetra
.862 .913 .865 r
.66155 .47476 .66859 .47796 .68331 .46614 .67626 .46056 Mtetra
.788 .853 .9 r
.67626 .46056 .68331 .46614 .69821 .45747 .69117 .45046 Mtetra
.734 .806 .909 r
.69117 .45046 .69821 .45747 .71326 .4506 .70625 .44275 Mtetra
.702 .777 .91 r
.70625 .44275 .71326 .4506 .72844 .44472 .72146 .43639 Mtetra
.684 .761 .91 r
.72146 .43639 .72844 .44472 .74372 .43934 .73679 .43074 Mtetra
.674 .752 .909 r
.73679 .43074 .74372 .43934 .7591 .43423 .75222 .42545 Mtetra
.669 .747 .909 r
.75222 .42545 .7591 .43423 .77457 .42924 .76774 .42035 Mtetra
.667 .744 .908 r
.76774 .42035 .77457 .42924 .79013 .42431 .78336 .41534 Mtetra
.665 .743 .908 r
.78336 .41534 .79013 .42431 .80578 .41939 .79907 .41036 Mtetra
.664 .742 .908 r
.79907 .41036 .80578 .41939 .82151 .41447 .81486 .40538 Mtetra
.81486 .40538 .82151 .41447 .83734 .40954 .83075 .40039 Mtetra
.83075 .40039 .83734 .40954 .85324 .40458 .84672 .39538 Mtetra
.664 .741 .908 r
.84672 .39538 .85324 .40458 .86924 .3996 .86278 .39035 Mtetra
.86278 .39035 .86924 .3996 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38957 .89516 .3802 Mtetra
.89516 .3802 .9015 .38957 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.646 .762 .934 r
.32911 .74984 .33802 .75707 .35224 .75316 .34337 .74589 Mtetra
.34337 .74589 .35224 .75316 .36654 .74923 .35771 .74192 Mtetra
.35771 .74192 .36654 .74923 .38091 .74528 .37213 .73793 Mtetra
.646 .763 .934 r
.37213 .73793 .38091 .74528 .39536 .74129 .38663 .73391 Mtetra
.38663 .73391 .39536 .74129 .40989 .73728 .40121 .72986 Mtetra
.40121 .72986 .40989 .73728 .4245 .73324 .41587 .72579 Mtetra
.647 .763 .934 r
.41587 .72579 .4245 .73324 .43918 .72915 .43061 .72167 Mtetra
.648 .764 .933 r
.43061 .72167 .43918 .72915 .45395 .72498 .44543 .71749 Mtetra
.65 .765 .933 r
.44543 .71749 .45395 .72498 .4688 .72069 .46033 .71321 Mtetra
.654 .768 .933 r
.46033 .71321 .4688 .72069 .48373 .7162 .47531 .70878 Mtetra
.661 .772 .932 r
.47531 .70878 .48373 .7162 .49875 .71133 .49038 .70408 Mtetra
.673 .781 .93 r
.49038 .70408 .49875 .71133 .51384 .70578 .50553 .69886 Mtetra
.696 .796 .927 r
.50553 .69886 .51384 .70578 .529 .69899 .52075 .69272 Mtetra
.735 .821 .918 r
.52075 .69272 .529 .69899 .54421 .68998 .53604 .68491 Mtetra
.794 .858 .898 r
.53604 .68491 .54421 .68998 .55943 .67718 .55136 .67416 Mtetra
.869 .901 .852 r
.55136 .67416 .55943 .67718 .57457 .65844 .56665 .65858 Mtetra
.936 .93 .773 r
.56665 .65858 .57457 .65844 .58952 .63182 .58181 .63595 Mtetra
.969 .933 .672 r
.58181 .63595 .58952 .63182 .60418 .59744 .59672 .60507 Mtetra
.969 .92 .589 r
.59672 .60507 .60418 .59744 .61854 .55924 .61132 .56788 Mtetra
.959 .916 .56 r
.61132 .56788 .61854 .55924 .63277 .52362 .62568 .53002 Mtetra
.956 .935 .607 r
.62568 .53002 .63277 .52362 .64706 .4952 .64001 .49752 Mtetra
.947 .957 .719 r
.64001 .49752 .64706 .4952 .66155 .47476 .65448 .47308 Mtetra
.899 .939 .829 r
.65448 .47308 .66155 .47476 .67626 .46056 .66917 .45594 Mtetra
.823 .883 .887 r
.66917 .45594 .67626 .46056 .69117 .45046 .68408 .44396 Mtetra
.758 .827 .906 r
.68408 .44396 .69117 .45046 .70625 .44275 .69917 .43516 Mtetra
.716 .79 .91 r
.69917 .43516 .70625 .44275 .72146 .43639 .71442 .42816 Mtetra
.692 .768 .91 r
.71442 .42816 .72146 .43639 .73679 .43074 .72979 .42214 Mtetra
.678 .755 .909 r
.72979 .42214 .73679 .43074 .75222 .42545 .74527 .41664 Mtetra
.671 .749 .909 r
.74527 .41664 .75222 .42545 .76774 .42035 .76085 .4114 Mtetra
.668 .745 .908 r
.76085 .4114 .76774 .42035 .78336 .41534 .77652 .40629 Mtetra
.666 .743 .908 r
.77652 .40629 .78336 .41534 .79907 .41036 .79229 .40123 Mtetra
.665 .742 .908 r
.79229 .40123 .79907 .41036 .81486 .40538 .80814 .39619 Mtetra
.664 .742 .908 r
.80814 .39619 .81486 .40538 .83075 .40039 .82409 .39114 Mtetra
.82409 .39114 .83075 .40039 .84672 .39538 .84012 .38608 Mtetra
.664 .741 .908 r
.84012 .38608 .84672 .39538 .86278 .39035 .85625 .38099 Mtetra
.85625 .38099 .86278 .39035 .87892 .38529 .87246 .37588 Mtetra
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37075 Mtetra
.88876 .37075 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .762 .934 r
.3201 .74254 .32911 .74984 .34337 .74589 .33441 .73855 Mtetra
.33441 .73855 .34337 .74589 .35771 .74192 .3488 .73454 Mtetra
.3488 .73454 .35771 .74192 .37213 .73793 .36327 .7305 Mtetra
.36327 .7305 .37213 .73793 .38663 .73391 .37782 .72645 Mtetra
.646 .763 .934 r
.37782 .72645 .38663 .73391 .40121 .72986 .39245 .72236 Mtetra
.39245 .72236 .40121 .72986 .41587 .72579 .40715 .71825 Mtetra
.647 .763 .934 r
.40715 .71825 .41587 .72579 .43061 .72167 .42194 .7141 Mtetra
.42194 .7141 .43061 .72167 .44543 .71749 .43681 .7099 Mtetra
.649 .764 .933 r
.43681 .7099 .44543 .71749 .46033 .71321 .45177 .70563 Mtetra
.652 .766 .933 r
.45177 .70563 .46033 .71321 .47531 .70878 .4668 .70123 Mtetra
.657 .77 .933 r
.4668 .70123 .47531 .70878 .49038 .70408 .48192 .69663 Mtetra
.666 .776 .931 r
.48192 .69663 .49038 .70408 .50553 .69886 .49713 .69165 Mtetra
.683 .787 .929 r
.49713 .69165 .50553 .69886 .52075 .69272 .51241 .68598 Mtetra
.713 .807 .923 r
.51241 .68598 .52075 .69272 .53604 .68491 .52777 .67906 Mtetra
.762 .839 .91 r
.52777 .67906 .53604 .68491 .55136 .67416 .54318 .6699 Mtetra
.831 .88 .879 r
.54318 .6699 .55136 .67416 .56665 .65858 .5586 .65693 Mtetra
.906 .918 .817 r
.5586 .65693 .56665 .65858 .58181 .63595 .57394 .63797 Mtetra
.958 .935 .723 r
.57394 .63797 .58181 .63595 .59672 .60507 .58909 .61108 Mtetra
.972 .927 .626 r
.58909 .61108 .59672 .60507 .61132 .56788 .60394 .57637 Mtetra
.963 .916 .566 r
.60394 .57637 .61132 .56788 .62568 .53002 .61849 .53784 Mtetra
.956 .923 .573 r
.61849 .53784 .62568 .53002 .64001 .49752 .6329 .5019 Mtetra
.955 .949 .658 r
.6329 .5019 .64001 .49752 .65448 .47308 .64738 .47322 Mtetra
.929 .955 .779 r
.64738 .47322 .65448 .47308 .66917 .45594 .66205 .45256 Mtetra
.861 .913 .865 r
.66205 .45256 .66917 .45594 .68408 .44396 .67694 .43819 Mtetra
.788 .853 .9 r
.67694 .43819 .68408 .44396 .69917 .43516 .69204 .42793 Mtetra
.734 .806 .909 r
.69204 .42793 .69917 .43516 .71442 .42816 .70731 .42009 Mtetra
.702 .777 .91 r
.70731 .42009 .71442 .42816 .72979 .42214 .72272 .41359 Mtetra
.684 .761 .91 r
.72272 .41359 .72979 .42214 .74527 .41664 .73825 .40781 Mtetra
.674 .752 .909 r
.73825 .40781 .74527 .41664 .76085 .4114 .75389 .4024 Mtetra
.669 .747 .909 r
.75389 .4024 .76085 .4114 .77652 .40629 .76962 .39717 Mtetra
.667 .744 .908 r
.76962 .39717 .77652 .40629 .79229 .40123 .78544 .39203 Mtetra
.665 .743 .908 r
.78544 .39203 .79229 .40123 .80814 .39619 .80136 .38692 Mtetra
.664 .742 .908 r
.80136 .38692 .80814 .39619 .82409 .39114 .81736 .38181 Mtetra
.81736 .38181 .82409 .39114 .84012 .38608 .83346 .37669 Mtetra
.83346 .37669 .84012 .38608 .85625 .38099 .84965 .37155 Mtetra
.664 .741 .908 r
.84965 .37155 .85625 .38099 .87246 .37588 .86593 .36638 Mtetra
.86593 .36638 .87246 .37588 .88876 .37075 .8823 .36119 Mtetra
.8823 .36119 .88876 .37075 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .762 .934 r
.31101 .73516 .3201 .74254 .33441 .73855 .32537 .73113 Mtetra
.32537 .73113 .33441 .73855 .3488 .73454 .3398 .72708 Mtetra
.3398 .72708 .3488 .73454 .36327 .7305 .35432 .72301 Mtetra
.35432 .72301 .36327 .7305 .37782 .72645 .36892 .71891 Mtetra
.646 .763 .934 r
.36892 .71891 .37782 .72645 .39245 .72236 .38359 .71479 Mtetra
.38359 .71479 .39245 .72236 .40715 .71825 .39835 .71064 Mtetra
.39835 .71064 .40715 .71825 .42194 .7141 .41319 .70645 Mtetra
.647 .763 .934 r
.41319 .70645 .42194 .7141 .43681 .7099 .42811 .70223 Mtetra
.648 .764 .933 r
.42811 .70223 .43681 .7099 .45177 .70563 .44312 .69794 Mtetra
.65 .765 .933 r
.44312 .69794 .45177 .70563 .4668 .70123 .45821 .69356 Mtetra
.654 .768 .933 r
.45821 .69356 .4668 .70123 .48192 .69663 .47338 .68902 Mtetra
.661 .772 .932 r
.47338 .68902 .48192 .69663 .49713 .69165 .48864 .68419 Mtetra
.673 .781 .93 r
.48864 .68419 .49713 .69165 .51241 .68598 .50399 .67886 Mtetra
.696 .796 .927 r
.50399 .67886 .51241 .68598 .52777 .67906 .51941 .6726 Mtetra
.735 .821 .918 r
.51941 .6726 .52777 .67906 .54318 .6699 .5349 .66464 Mtetra
.794 .858 .898 r
.5349 .66464 .54318 .6699 .5586 .65693 .55042 .65374 Mtetra
.869 .901 .852 r
.55042 .65374 .5586 .65693 .57394 .63797 .56591 .63796 Mtetra
.936 .93 .773 r
.56591 .63796 .57394 .63797 .58909 .61108 .58127 .61508 Mtetra
.969 .933 .672 r
.58127 .61508 .58909 .61108 .60394 .57637 .59638 .58389 Mtetra
.969 .92 .589 r
.59638 .58389 .60394 .57637 .61849 .53784 .61117 .54637 Mtetra
.959 .916 .56 r
.61117 .54637 .61849 .53784 .6329 .5019 .62572 .50817 Mtetra
.956 .935 .607 r
.62572 .50817 .6329 .5019 .64738 .47322 .64023 .47538 Mtetra
.947 .957 .719 r
.64023 .47538 .64738 .47322 .66205 .45256 .65489 .4507 Mtetra
.899 .938 .829 r
.65489 .4507 .66205 .45256 .67694 .43819 .66977 .43337 Mtetra
.823 .882 .887 r
.66977 .43337 .67694 .43819 .69204 .42793 .68487 .42122 Mtetra
.758 .827 .906 r
.68487 .42122 .69204 .42793 .70731 .42009 .70016 .41227 Mtetra
.716 .79 .91 r
.70016 .41227 .70731 .42009 .72272 .41359 .7156 .40513 Mtetra
.692 .768 .91 r
.7156 .40513 .72272 .41359 .73825 .40781 .73117 .39898 Mtetra
.678 .755 .909 r
.73117 .39898 .73825 .40781 .75389 .4024 .74686 .39335 Mtetra
.671 .749 .909 r
.74686 .39335 .75389 .4024 .76962 .39717 .76264 .38798 Mtetra
.668 .745 .908 r
.76264 .38798 .76962 .39717 .78544 .39203 .77853 .38274 Mtetra
.666 .743 .908 r
.77853 .38274 .78544 .39203 .80136 .38692 .7945 .37755 Mtetra
.665 .742 .908 r
.7945 .37755 .80136 .38692 .81736 .38181 .81057 .37238 Mtetra
.664 .742 .908 r
.81057 .37238 .81736 .38181 .83346 .37669 .82673 .3672 Mtetra
.82673 .3672 .83346 .37669 .84965 .37155 .84298 .362 Mtetra
.664 .741 .908 r
.84298 .362 .84965 .37155 .86593 .36638 .85933 .35678 Mtetra
.85933 .35678 .86593 .36638 .8823 .36119 .87576 .35154 Mtetra
.87576 .35154 .8823 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .762 .934 r
.30182 .7277 .31101 .73516 .32537 .73113 .31623 .72364 Mtetra
.31623 .72364 .32537 .73113 .3398 .72708 .33071 .71955 Mtetra
.33071 .71955 .3398 .72708 .35432 .72301 .34528 .71543 Mtetra
.34528 .71543 .35432 .72301 .36892 .71891 .35992 .71129 Mtetra
.35992 .71129 .36892 .71891 .38359 .71479 .37465 .70713 Mtetra
.646 .763 .934 r
.37465 .70713 .38359 .71479 .39835 .71064 .38946 .70294 Mtetra
.38946 .70294 .39835 .71064 .41319 .70645 .40435 .69872 Mtetra
.647 .763 .934 r
.40435 .69872 .41319 .70645 .42811 .70223 .41932 .69446 Mtetra
.41932 .69446 .42811 .70223 .44312 .69794 .43438 .69015 Mtetra
.649 .764 .933 r
.43438 .69015 .44312 .69794 .45821 .69356 .44952 .68577 Mtetra
.652 .766 .933 r
.44952 .68577 .45821 .69356 .47338 .68902 .46475 .68126 Mtetra
.657 .77 .933 r
.46475 .68126 .47338 .68902 .48864 .68419 .48007 .67654 Mtetra
.666 .776 .931 r
.48007 .67654 .48864 .68419 .50399 .67886 .49547 .67144 Mtetra
.683 .787 .929 r
.49547 .67144 .50399 .67886 .51941 .6726 .51095 .66565 Mtetra
.713 .807 .923 r
.51095 .66565 .51941 .6726 .5349 .66464 .52651 .6586 Mtetra
.762 .839 .91 r
.52651 .6586 .5349 .66464 .55042 .65374 .54212 .64929 Mtetra
.831 .88 .879 r
.54212 .64929 .55042 .65374 .56591 .63796 .55774 .63613 Mtetra
.906 .919 .817 r
.55774 .63613 .56591 .63796 .58127 .61508 .57329 .61695 Mtetra
.958 .935 .723 r
.57329 .61695 .58127 .61508 .59638 .58389 .58864 .58978 Mtetra
.972 .927 .626 r
.58864 .58978 .59638 .58389 .61117 .54637 .60369 .55475 Mtetra
.963 .916 .566 r
.60369 .55475 .61117 .54637 .62572 .50817 .61844 .51587 Mtetra
.956 .923 .574 r
.61844 .51587 .62572 .50817 .64023 .47538 .63304 .47961 Mtetra
.955 .949 .658 r
.63304 .47961 .64023 .47538 .65489 .4507 .6477 .45066 Mtetra
.929 .954 .779 r
.6477 .45066 .65489 .4507 .66977 .43337 .66256 .42978 Mtetra
.861 .912 .865 r
.66256 .42978 .66977 .43337 .68487 .42122 .67764 .41523 Mtetra
.788 .853 .9 r
.67764 .41523 .68487 .42122 .70016 .41227 .69294 .40482 Mtetra
.734 .806 .909 r
.69294 .40482 .70016 .41227 .7156 .40513 .70841 .39683 Mtetra
.702 .777 .91 r
.70841 .39683 .7156 .40513 .73117 .39898 .72402 .3902 Mtetra
.684 .761 .91 r
.72402 .3902 .73117 .39898 .74686 .39335 .73976 .38428 Mtetra
.674 .752 .909 r
.73976 .38428 .74686 .39335 .76264 .38798 .7556 .37874 Mtetra
.669 .747 .909 r
.7556 .37874 .76264 .38798 .77853 .38274 .77154 .37338 Mtetra
.667 .744 .908 r
.77154 .37338 .77853 .38274 .7945 .37755 .78758 .36811 Mtetra
.665 .743 .908 r
.78758 .36811 .7945 .37755 .81057 .37238 .80371 .36286 Mtetra
.664 .742 .908 r
.80371 .36286 .81057 .37238 .82673 .3672 .81993 .35762 Mtetra
.81993 .35762 .82673 .3672 .84298 .362 .83625 .35236 Mtetra
.83625 .35236 .84298 .362 .85933 .35678 .85266 .34708 Mtetra
.664 .741 .908 r
.85266 .34708 .85933 .35678 .87576 .35154 .86916 .34178 Mtetra
.86916 .34178 .87576 .35154 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .762 .934 r
.29254 .72018 .30182 .7277 .31623 .72364 .30699 .71607 Mtetra
.30699 .71607 .31623 .72364 .33071 .71955 .32153 .71193 Mtetra
.32153 .71193 .33071 .71955 .34528 .71543 .33614 .70778 Mtetra
.33614 .70778 .34528 .71543 .35992 .71129 .35084 .7036 Mtetra
.35084 .7036 .35992 .71129 .37465 .70713 .36561 .6994 Mtetra
.646 .763 .934 r
.36561 .6994 .37465 .70713 .38946 .70294 .38047 .69517 Mtetra
.38047 .69517 .38946 .70294 .40435 .69872 .39542 .69091 Mtetra
.39542 .69091 .40435 .69872 .41932 .69446 .41044 .68661 Mtetra
.647 .763 .934 r
.41044 .68661 .41932 .69446 .43438 .69015 .42555 .68227 Mtetra
.648 .764 .933 r
.42555 .68227 .43438 .69015 .44952 .68577 .44075 .67788 Mtetra
.65 .765 .933 r
.44075 .67788 .44952 .68577 .46475 .68126 .45603 .67338 Mtetra
.654 .768 .933 r
.45603 .67338 .46475 .68126 .48007 .67654 .4714 .66872 Mtetra
.661 .772 .932 r
.4714 .66872 .48007 .67654 .49547 .67144 .48686 .66378 Mtetra
.673 .781 .93 r
.48686 .66378 .49547 .67144 .51095 .66565 .5024 .65832 Mtetra
.696 .796 .927 r
.5024 .65832 .51095 .66565 .52651 .6586 .51803 .65193 Mtetra
.735 .821 .918 r
.51803 .65193 .52651 .6586 .54212 .64929 .53372 .64383 Mtetra
.794 .859 .898 r
.53372 .64383 .54212 .64929 .55774 .63613 .54945 .63276 Mtetra
.869 .901 .852 r
.54945 .63276 .55774 .63613 .57329 .61695 .56515 .61678 Mtetra
.936 .93 .773 r
.56515 .61678 .57329 .61695 .58864 .58978 .58072 .59365 Mtetra
.969 .933 .672 r
.58072 .59365 .58864 .58978 .60369 .55475 .59603 .56216 Mtetra
.969 .92 .589 r
.59603 .56216 .60369 .55475 .61844 .51587 .61102 .52429 Mtetra
.959 .916 .56 r
.61102 .52429 .61844 .51587 .63304 .47961 .62576 .48575 Mtetra
.956 .935 .608 r
.62576 .48575 .63304 .47961 .6477 .45066 .64046 .45266 Mtetra
.947 .957 .719 r
.64046 .45266 .6477 .45066 .66256 .42978 .65531 .42774 Mtetra
.899 .938 .829 r
.65531 .42774 .66256 .42978 .67764 .41523 .67038 .41021 Mtetra
.823 .882 .887 r
.67038 .41021 .67764 .41523 .69294 .40482 .68568 .39789 Mtetra
.758 .827 .906 r
.68568 .39789 .69294 .40482 .70841 .39683 .70116 .38878 Mtetra
.716 .79 .91 r
.70116 .38878 .70841 .39683 .72402 .3902 .71681 .3815 Mtetra
.692 .768 .91 r
.71681 .3815 .72402 .3902 .73976 .38428 .73259 .37522 Mtetra
.678 .755 .909 r
.73259 .37522 .73976 .38428 .7556 .37874 .74848 .36945 Mtetra
.671 .749 .909 r
.74848 .36945 .7556 .37874 .77154 .37338 .76448 .36395 Mtetra
.668 .745 .908 r
.76448 .36395 .77154 .37338 .78758 .36811 .78058 .35857 Mtetra
.666 .743 .908 r
.78058 .35857 .78758 .36811 .80371 .36286 .79677 .35325 Mtetra
.665 .742 .908 r
.79677 .35325 .80371 .36286 .81993 .35762 .81306 .34794 Mtetra
.664 .742 .908 r
.81306 .34794 .81993 .35762 .83625 .35236 .82944 .34262 Mtetra
.82944 .34262 .83625 .35236 .85266 .34708 .84592 .33728 Mtetra
.664 .741 .908 r
.84592 .33728 .85266 .34708 .86916 .34178 .86249 .33192 Mtetra
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32654 Mtetra
.87915 .32654 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72018 .30699 .71607 .29767 .70842 Mtetra
.29767 .70842 .30699 .71607 .32153 .71193 .31225 .70425 Mtetra
.31225 .70425 .32153 .71193 .33614 .70778 .32691 .70005 Mtetra
.32691 .70005 .33614 .70778 .35084 .7036 .34166 .69583 Mtetra
.34166 .69583 .35084 .7036 .36561 .6994 .35649 .69158 Mtetra
.35649 .69158 .36561 .6994 .38047 .69517 .3714 .68731 Mtetra
.646 .763 .934 r
.3714 .68731 .38047 .69517 .39542 .69091 .38639 .68301 Mtetra
.38639 .68301 .39542 .69091 .41044 .68661 .40147 .67868 Mtetra
.647 .763 .934 r
.40147 .67868 .41044 .68661 .42555 .68227 .41663 .6743 Mtetra
.41663 .6743 .42555 .68227 .44075 .67788 .43188 .66988 Mtetra
.649 .764 .933 r
.43188 .66988 .44075 .67788 .45603 .67338 .44722 .66538 Mtetra
.652 .766 .933 r
.44722 .66538 .45603 .67338 .4714 .66872 .46265 .66076 Mtetra
.657 .77 .933 r
.46265 .66076 .4714 .66872 .48686 .66378 .47816 .65592 Mtetra
.666 .776 .931 r
.47816 .65592 .48686 .66378 .5024 .65832 .49376 .6507 Mtetra
.683 .787 .929 r
.49376 .6507 .5024 .65832 .51803 .65193 .50945 .64477 Mtetra
.713 .807 .923 r
.50945 .64477 .51803 .65193 .53372 .64383 .52522 .63758 Mtetra
.762 .839 .91 r
.52522 .63758 .53372 .64383 .54945 .63276 .54104 .62812 Mtetra
.831 .88 .879 r
.54104 .62812 .54945 .63276 .56515 .61678 .55687 .61478 Mtetra
.906 .919 .817 r
.55687 .61478 .56515 .61678 .58072 .59365 .57263 .59537 Mtetra
.958 .935 .723 r
.57263 .59537 .58072 .59365 .59603 .56216 .58819 .56792 Mtetra
.972 .927 .625 r
.58819 .56792 .59603 .56216 .61102 .52429 .60344 .53255 Mtetra
.963 .916 .566 r
.60344 .53255 .61102 .52429 .62576 .48575 .61838 .49332 Mtetra
.956 .923 .574 r
.61838 .49332 .62576 .48575 .64046 .45266 .63317 .45674 Mtetra
.955 .949 .659 r
.63317 .45674 .64046 .45266 .65531 .42774 .64803 .42752 Mtetra
.929 .954 .779 r
.64803 .42752 .65531 .42774 .67038 .41021 .66308 .40642 Mtetra
.861 .912 .865 r
.66308 .40642 .67038 .41021 .68568 .39789 .67836 .39168 Mtetra
.788 .853 .9 r
.67836 .39168 .68568 .39789 .70116 .38878 .69386 .3811 Mtetra
.734 .806 .909 r
.69386 .3811 .70116 .38878 .71681 .3815 .70954 .37297 Mtetra
.702 .777 .91 r
.70954 .37297 .71681 .3815 .73259 .37522 .72536 .36619 Mtetra
.684 .761 .91 r
.72536 .36619 .73259 .37522 .74848 .36945 .7413 .36014 Mtetra
.674 .752 .909 r
.7413 .36014 .74848 .36945 .76448 .36395 .75735 .35446 Mtetra
.669 .747 .908 r
.75735 .35446 .76448 .36395 .78058 .35857 .77351 .34896 Mtetra
.667 .744 .908 r
.77351 .34896 .78058 .35857 .79677 .35325 .78977 .34355 Mtetra
.665 .743 .908 r
.78977 .34355 .79677 .35325 .81306 .34794 .80612 .33816 Mtetra
.664 .742 .908 r
.80612 .33816 .81306 .34794 .82944 .34262 .82257 .33278 Mtetra
.82257 .33278 .82944 .34262 .84592 .33728 .83911 .32738 Mtetra
.83911 .32738 .84592 .33728 .86249 .33192 .85575 .32196 Mtetra
.664 .741 .908 r
.85575 .32196 .86249 .33192 .87915 .32654 .87248 .31652 Mtetra
.87248 .31652 .87915 .32654 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70842 .28825 .7007 Mtetra
.28825 .7007 .29767 .70842 .31225 .70425 .30288 .69648 Mtetra
.30288 .69648 .31225 .70425 .32691 .70005 .31759 .69224 Mtetra
.31759 .69224 .32691 .70005 .34166 .69583 .33239 .68797 Mtetra
.33239 .68797 .34166 .69583 .35649 .69158 .34726 .68368 Mtetra
.34726 .68368 .35649 .69158 .3714 .68731 .36223 .67937 Mtetra
.646 .763 .934 r
.36223 .67937 .3714 .68731 .38639 .68301 .37727 .67502 Mtetra
.37727 .67502 .38639 .68301 .40147 .67868 .3924 .67065 Mtetra
.3924 .67065 .40147 .67868 .41663 .6743 .40762 .66624 Mtetra
.647 .763 .934 r
.40762 .66624 .41663 .6743 .43188 .66988 .42292 .66179 Mtetra
.648 .764 .933 r
.42292 .66179 .43188 .66988 .44722 .66538 .43832 .65727 Mtetra
.65 .765 .933 r
.43832 .65727 .44722 .66538 .46265 .66076 .4538 .65266 Mtetra
.654 .768 .933 r
.4538 .65266 .46265 .66076 .47816 .65592 .46937 .64788 Mtetra
.661 .772 .932 r
.46937 .64788 .47816 .65592 .49376 .6507 .48503 .64282 Mtetra
.673 .781 .93 r
.48503 .64282 .49376 .6507 .50945 .64477 .50078 .63723 Mtetra
.696 .796 .927 r
.50078 .63723 .50945 .64477 .52522 .63758 .51661 .6307 Mtetra
.735 .821 .918 r
.51661 .6307 .52522 .63758 .54104 .62812 .53251 .62246 Mtetra
.794 .859 .898 r
.53251 .62246 .54104 .62812 .55687 .61478 .54846 .61121 Mtetra
.869 .901 .853 r
.54846 .61121 .55687 .61478 .57263 .59537 .56437 .59503 Mtetra
.936 .931 .772 r
.56437 .59503 .57263 .59537 .58819 .56792 .58015 .57164 Mtetra
.969 .933 .672 r
.58015 .57164 .58819 .56792 .60344 .53255 .59568 .53983 Mtetra
.969 .92 .588 r
.59568 .53983 .60344 .53255 .61838 .49332 .61087 .50162 Mtetra
.959 .916 .56 r
.61087 .50162 .61838 .49332 .63317 .45674 .62581 .46274 Mtetra
.956 .935 .608 r
.62581 .46274 .63317 .45674 .64803 .42752 .6407 .42934 Mtetra
.947 .957 .719 r
.6407 .42934 .64803 .42752 .66308 .40642 .65574 .40417 Mtetra
.899 .938 .829 r
.65574 .40417 .66308 .40642 .67836 .39168 .67101 .38643 Mtetra
.823 .882 .887 r
.67101 .38643 .67836 .39168 .69386 .3811 .68651 .37394 Mtetra
.758 .827 .906 r
.68651 .37394 .69386 .3811 .70954 .37297 .7022 .36468 Mtetra
.716 .79 .91 r
.7022 .36468 .70954 .37297 .72536 .36619 .71806 .35725 Mtetra
.692 .768 .91 r
.71806 .35725 .72536 .36619 .7413 .36014 .73405 .35083 Mtetra
.678 .755 .909 r
.73405 .35083 .7413 .36014 .75735 .35446 .75015 .34492 Mtetra
.671 .749 .909 r
.75015 .34492 .75735 .35446 .77351 .34896 .76637 .33928 Mtetra
.668 .745 .908 r
.76637 .33928 .77351 .34896 .78977 .34355 .78269 .33376 Mtetra
.666 .743 .908 r
.78269 .33376 .78977 .34355 .80612 .33816 .7991 .32829 Mtetra
.665 .742 .908 r
.7991 .32829 .80612 .33816 .82257 .33278 .81562 .32284 Mtetra
.664 .742 .908 r
.81562 .32284 .82257 .33278 .83911 .32738 .83223 .31738 Mtetra
.83223 .31738 .83911 .32738 .85575 .32196 .84893 .3119 Mtetra
.664 .741 .908 r
.84893 .3119 .85575 .32196 .87248 .31652 .86574 .30639 Mtetra
.86574 .30639 .87248 .31652 .88931 .31104 .88264 .30086 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .7007 .27873 .69289 Mtetra
.27873 .69289 .28825 .7007 .30288 .69648 .29341 .68863 Mtetra
.29341 .68863 .30288 .69648 .31759 .69224 .30817 .68435 Mtetra
.30817 .68435 .31759 .69224 .33239 .68797 .32302 .68004 Mtetra
.32302 .68004 .33239 .68797 .34726 .68368 .33794 .6757 Mtetra
.33794 .6757 .34726 .68368 .36223 .67937 .35296 .67134 Mtetra
.35296 .67134 .36223 .67937 .37727 .67502 .36806 .66696 Mtetra
.646 .763 .934 r
.36806 .66696 .37727 .67502 .3924 .67065 .38324 .66254 Mtetra
.38324 .66254 .3924 .67065 .40762 .66624 .39851 .65809 Mtetra
.647 .763 .934 r
.39851 .65809 .40762 .66624 .42292 .66179 .41387 .65361 Mtetra
.41387 .65361 .42292 .66179 .43832 .65727 .42932 .64906 Mtetra
.649 .764 .933 r
.42932 .64906 .43832 .65727 .4538 .65266 .44486 .64444 Mtetra
.652 .766 .933 r
.44486 .64444 .4538 .65266 .46937 .64788 .46048 .6397 Mtetra
.657 .77 .933 r
.46048 .6397 .46937 .64788 .48503 .64282 .4762 .63474 Mtetra
.666 .776 .931 r
.4762 .63474 .48503 .64282 .50078 .63723 .49201 .62938 Mtetra
.683 .787 .929 r
.49201 .62938 .50078 .63723 .51661 .6307 .50791 .62333 Mtetra
.713 .807 .923 r
.50791 .62333 .51661 .6307 .53251 .62246 .52389 .61599 Mtetra
.762 .839 .91 r
.52389 .61599 .53251 .62246 .54846 .61121 .53992 .60637 Mtetra
.831 .88 .879 r
.53992 .60637 .54846 .61121 .56437 .59503 .55597 .59284 Mtetra
.906 .919 .817 r
.55597 .59284 .56437 .59503 .58015 .57164 .57194 .5732 Mtetra
.958 .935 .722 r
.57194 .5732 .58015 .57164 .59568 .53983 .58772 .54546 Mtetra
.972 .927 .625 r
.58772 .54546 .59568 .53983 .61087 .50162 .60318 .50976 Mtetra
.963 .916 .566 r
.60318 .50976 .61087 .50162 .62581 .46274 .61833 .47017 Mtetra
.957 .923 .574 r
.61833 .47017 .62581 .46274 .6407 .42934 .63332 .43326 Mtetra
.955 .948 .659 r
.63332 .43326 .6407 .42934 .65574 .40417 .64836 .40376 Mtetra
.929 .954 .779 r
.64836 .40376 .65574 .40417 .67101 .38643 .66361 .38243 Mtetra
.861 .912 .865 r
.66361 .38243 .67101 .38643 .68651 .37394 .6791 .3675 Mtetra
.788 .853 .899 r
.6791 .3675 .68651 .37394 .7022 .36468 .69481 .35676 Mtetra
.734 .806 .909 r
.69481 .35676 .7022 .36468 .71806 .35725 .71069 .34847 Mtetra
.702 .777 .91 r
.71069 .34847 .71806 .35725 .73405 .35083 .72672 .34155 Mtetra
.684 .761 .91 r
.72672 .34155 .73405 .35083 .75015 .34492 .74288 .33535 Mtetra
.674 .752 .909 r
.74288 .33535 .75015 .34492 .76637 .33928 .75916 .32953 Mtetra
.669 .747 .908 r
.75916 .32953 .76637 .33928 .78269 .33376 .77554 .32389 Mtetra
.667 .744 .908 r
.77554 .32389 .78269 .33376 .7991 .32829 .79202 .31833 Mtetra
.665 .743 .908 r
.79202 .31833 .7991 .32829 .81562 .32284 .8086 .3128 Mtetra
.664 .742 .908 r
.8086 .3128 .81562 .32284 .83223 .31738 .82527 .30727 Mtetra
.82527 .30727 .83223 .31738 .84893 .3119 .84205 .30173 Mtetra
.84205 .30173 .84893 .3119 .86574 .30639 .85892 .29616 Mtetra
.664 .741 .908 r
.85892 .29616 .86574 .30639 .88264 .30086 .87589 .29056 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .68501 Mtetra
.26911 .68501 .27873 .69289 .29341 .68863 .28384 .6807 Mtetra
.28384 .6807 .29341 .68863 .30817 .68435 .29865 .67637 Mtetra
.29865 .67637 .30817 .68435 .32302 .68004 .31355 .67202 Mtetra
.31355 .67202 .32302 .68004 .33794 .6757 .32853 .66764 Mtetra
.32853 .66764 .33794 .6757 .35296 .67134 .34359 .66324 Mtetra
.34359 .66324 .35296 .67134 .36806 .66696 .35875 .6588 Mtetra
.646 .763 .934 r
.35875 .6588 .36806 .66696 .38324 .66254 .37398 .65434 Mtetra
.37398 .65434 .38324 .66254 .39851 .65809 .38931 .64985 Mtetra
.38931 .64985 .39851 .65809 .41387 .65361 .40472 .64533 Mtetra
.647 .763 .934 r
.40472 .64533 .41387 .65361 .42932 .64906 .42023 .64075 Mtetra
.648 .764 .933 r
.42023 .64075 .42932 .64906 .44486 .64444 .43582 .63612 Mtetra
.65 .765 .933 r
.43582 .63612 .44486 .64444 .46048 .6397 .4515 .63138 Mtetra
.654 .768 .933 r
.4515 .63138 .46048 .6397 .4762 .63474 .46728 .62648 Mtetra
.661 .772 .932 r
.46728 .62648 .4762 .63474 .49201 .62938 .48315 .62128 Mtetra
.673 .781 .93 r
.48315 .62128 .49201 .62938 .50791 .62333 .49911 .61557 Mtetra
.696 .796 .927 r
.49911 .61557 .50791 .62333 .52389 .61599 .51516 .60889 Mtetra
.735 .822 .918 r
.51516 .60889 .52389 .61599 .53992 .60637 .53127 .6005 Mtetra
.794 .859 .898 r
.53127 .6005 .53992 .60637 .55597 .59284 .54743 .58907 Mtetra
.869 .902 .853 r
.54743 .58907 .55597 .59284 .57194 .5732 .56357 .57267 Mtetra
.936 .931 .772 r
.56357 .57267 .57194 .5732 .58772 .54546 .57957 .54903 Mtetra
.969 .933 .671 r
.57957 .54903 .58772 .54546 .60318 .50976 .59531 .5169 Mtetra
.969 .92 .588 r
.59531 .5169 .60318 .50976 .61833 .47017 .61071 .47833 Mtetra
.959 .916 .56 r
.61071 .47833 .61833 .47017 .63332 .43326 .62585 .4391 Mtetra
.956 .935 .608 r
.62585 .4391 .63332 .43326 .64836 .40376 .64094 .4054 Mtetra
.947 .957 .72 r
.64094 .4054 .64836 .40376 .66361 .38243 .65618 .37997 Mtetra
.899 .938 .829 r
.65618 .37997 .66361 .38243 .6791 .3675 .67165 .36203 Mtetra
.823 .882 .887 r
.67165 .36203 .6791 .3675 .69481 .35676 .68736 .34936 Mtetra
.758 .827 .906 r
.68736 .34936 .69481 .35676 .71069 .34847 .70326 .33993 Mtetra
.716 .79 .91 r
.70326 .33993 .71069 .34847 .72672 .34155 .71933 .33236 Mtetra
.692 .768 .91 r
.71933 .33236 .72672 .34155 .74288 .33535 .73554 .32578 Mtetra
.678 .755 .909 r
.73554 .32578 .74288 .33535 .75916 .32953 .75187 .31972 Mtetra
.671 .749 .909 r
.75187 .31972 .75916 .32953 .77554 .32389 .76831 .31394 Mtetra
.668 .745 .908 r
.76831 .31394 .77554 .32389 .79202 .31833 .78485 .30827 Mtetra
.666 .743 .908 r
.78485 .30827 .79202 .31833 .8086 .3128 .8015 .30266 Mtetra
.665 .742 .908 r
.8015 .30266 .8086 .3128 .82527 .30727 .81824 .29706 Mtetra
.664 .742 .908 r
.81824 .29706 .82527 .30727 .84205 .30173 .83509 .29145 Mtetra
.83509 .29145 .84205 .30173 .85892 .29616 .85203 .28582 Mtetra
.664 .741 .908 r
.85203 .28582 .85892 .29616 .87589 .29056 .86907 .28016 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .68501 .25939 .67704 Mtetra
.25939 .67704 .26911 .68501 .28384 .6807 .27417 .67269 Mtetra
.27417 .67269 .28384 .6807 .29865 .67637 .28903 .66832 Mtetra
.28903 .66832 .29865 .67637 .31355 .67202 .30398 .66392 Mtetra
.30398 .66392 .31355 .67202 .32853 .66764 .31901 .65949 Mtetra
.31901 .65949 .32853 .66764 .34359 .66324 .33413 .65504 Mtetra
.33413 .65504 .34359 .66324 .35875 .6588 .34934 .65056 Mtetra
.34934 .65056 .35875 .6588 .37398 .65434 .36463 .64606 Mtetra
.646 .763 .934 r
.36463 .64606 .37398 .65434 .38931 .64985 .38001 .64152 Mtetra
.38001 .64152 .38931 .64985 .40472 .64533 .39548 .63695 Mtetra
.647 .763 .934 r
.39548 .63695 .40472 .64533 .42023 .64075 .41103 .63234 Mtetra
.41103 .63234 .42023 .64075 .43582 .63612 .42668 .62768 Mtetra
.649 .764 .933 r
.42668 .62768 .43582 .63612 .4515 .63138 .44243 .62293 Mtetra
.652 .766 .933 r
.44243 .62293 .4515 .63138 .46728 .62648 .45826 .61806 Mtetra
.657 .77 .933 r
.45826 .61806 .46728 .62648 .48315 .62128 .47419 .61297 Mtetra
.666 .776 .931 r
.47419 .61297 .48315 .62128 .49911 .61557 .49021 .60749 Mtetra
.683 .787 .929 r
.49021 .60749 .49911 .61557 .51516 .60889 .50632 .60129 Mtetra
.713 .807 .924 r
.50632 .60129 .51516 .60889 .53127 .6005 .52252 .59381 Mtetra
.762 .839 .91 r
.52252 .59381 .53127 .6005 .54743 .58907 .53878 .58402 Mtetra
.831 .881 .879 r
.53878 .58402 .54743 .58907 .56357 .57267 .55505 .57029 Mtetra
.906 .919 .817 r
.55505 .57029 .56357 .57267 .57957 .54903 .57124 .55041 Mtetra
.958 .935 .722 r
.57124 .55041 .57957 .54903 .59531 .5169 .58724 .52238 Mtetra
.972 .927 .625 r
.58724 .52238 .59531 .5169 .61071 .47833 .60292 .48633 Mtetra
.963 .916 .566 r
.60292 .48633 .61071 .47833 .62585 .4391 .61827 .44639 Mtetra
.957 .923 .574 r
.61827 .44639 .62585 .4391 .64094 .4054 .63346 .40914 Mtetra
.955 .948 .659 r
.63346 .40914 .64094 .4054 .65618 .37997 .64871 .37936 Mtetra
.929 .954 .78 r
.64871 .37936 .65618 .37997 .67165 .36203 .66417 .3578 Mtetra
.861 .912 .865 r
.66417 .3578 .67165 .36203 .68736 .34936 .67986 .34268 Mtetra
.788 .853 .899 r
.67986 .34268 .68736 .34936 .70326 .33993 .69578 .33176 Mtetra
.734 .806 .909 r
.69578 .33176 .70326 .33993 .71933 .33236 .71188 .32332 Mtetra
.702 .777 .91 r
.71188 .32332 .71933 .33236 .73554 .32578 .72813 .31624 Mtetra
.684 .761 .91 r
.72813 .31624 .73554 .32578 .75187 .31972 .74451 .30989 Mtetra
.674 .752 .909 r
.74451 .30989 .75187 .31972 .76831 .31394 .76101 .30392 Mtetra
.669 .747 .908 r
.76101 .30392 .76831 .31394 .78485 .30827 .77762 .29813 Mtetra
.667 .744 .908 r
.77762 .29813 .78485 .30827 .8015 .30266 .79433 .29242 Mtetra
.665 .743 .908 r
.79433 .29242 .8015 .30266 .81824 .29706 .81114 .28674 Mtetra
.664 .742 .908 r
.81114 .28674 .81824 .29706 .83509 .29145 .82805 .28106 Mtetra
.82805 .28106 .83509 .29145 .85203 .28582 .84507 .27536 Mtetra
.84507 .27536 .85203 .28582 .86907 .28016 .86218 .26964 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .6646 Mtetra
.2644 .6646 .27417 .67269 .28903 .66832 .27932 .66018 Mtetra
.27932 .66018 .28903 .66832 .30398 .66392 .29431 .65573 Mtetra
.29431 .65573 .30398 .66392 .31901 .65949 .3094 .65126 Mtetra
.3094 .65126 .31901 .65949 .33413 .65504 .32457 .64676 Mtetra
.32457 .64676 .33413 .65504 .34934 .65056 .33983 .64224 Mtetra
.33983 .64224 .34934 .65056 .36463 .64606 .35517 .63768 Mtetra
.646 .763 .934 r
.35517 .63768 .36463 .64606 .38001 .64152 .37061 .6331 Mtetra
.37061 .6331 .38001 .64152 .39548 .63695 .38613 .62849 Mtetra
.38613 .62849 .39548 .63695 .41103 .63234 .40175 .62384 Mtetra
.647 .763 .934 r
.40175 .62384 .41103 .63234 .42668 .62768 .41745 .61914 Mtetra
.648 .764 .933 r
.41745 .61914 .42668 .62768 .44243 .62293 .43325 .61437 Mtetra
.65 .765 .933 r
.43325 .61437 .44243 .62293 .45826 .61806 .44914 .60951 Mtetra
.654 .768 .933 r
.44914 .60951 .45826 .61806 .47419 .61297 .46513 .60448 Mtetra
.661 .772 .932 r
.46513 .60448 .47419 .61297 .49021 .60749 .48122 .59915 Mtetra
.673 .781 .93 r
.48122 .59915 .49021 .60749 .50632 .60129 .49739 .59329 Mtetra
.696 .796 .927 r
.49739 .59329 .50632 .60129 .52252 .59381 .51366 .58648 Mtetra
.735 .822 .918 r
.51366 .58648 .52252 .59381 .53878 .58402 .53 .57792 Mtetra
.794 .859 .898 r
.53 .57792 .53878 .58402 .55505 .57029 .54638 .56631 Mtetra
.869 .902 .853 r
.54638 .56631 .55505 .57029 .57124 .55041 .56275 .5497 Mtetra
.936 .931 .772 r
.56275 .5497 .57124 .55041 .58724 .52238 .57897 .52578 Mtetra
.969 .933 .671 r
.57897 .52578 .58724 .52238 .60292 .48633 .59493 .49333 Mtetra
.969 .92 .588 r
.59493 .49333 .60292 .48633 .61827 .44639 .61054 .4544 Mtetra
.959 .916 .56 r
.61054 .4544 .61827 .44639 .63346 .40914 .62589 .41482 Mtetra
.957 .935 .609 r
.62589 .41482 .63346 .40914 .64871 .37936 .64119 .3808 Mtetra
.947 .957 .72 r
.64119 .3808 .64871 .37936 .66417 .3578 .65664 .35512 Mtetra
.899 .938 .829 r
.65664 .35512 .66417 .3578 .67986 .34268 .67232 .33696 Mtetra
.823 .882 .887 r
.67232 .33696 .67986 .34268 .69578 .33176 .68823 .32411 Mtetra
.758 .827 .906 r
.68823 .32411 .69578 .33176 .71188 .32332 .70436 .31452 Mtetra
.716 .79 .91 r
.70436 .31452 .71188 .32332 .72813 .31624 .72065 .30678 Mtetra
.692 .768 .91 r
.72065 .30678 .72813 .31624 .74451 .30989 .73708 .30005 Mtetra
.678 .755 .909 r
.73708 .30005 .74451 .30989 .76101 .30392 .75363 .29384 Mtetra
.671 .749 .909 r
.75363 .29384 .76101 .30392 .77762 .29813 .7703 .2879 Mtetra
.668 .745 .908 r
.7703 .2879 .77762 .29813 .79433 .29242 .78708 .28209 Mtetra
.666 .743 .908 r
.78708 .28209 .79433 .29242 .81114 .28674 .80396 .27632 Mtetra
.665 .742 .908 r
.80396 .27632 .81114 .28674 .82805 .28106 .82094 .27057 Mtetra
.664 .742 .908 r
.82094 .27057 .82805 .28106 .84507 .27536 .83803 .2648 Mtetra
.83803 .2648 .84507 .27536 .86218 .26964 .85522 .25901 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .6646 .25453 .65642 Mtetra
.25453 .65642 .2644 .6646 .27932 .66018 .2695 .65195 Mtetra
.2695 .65195 .27932 .66018 .29431 .65573 .28454 .64746 Mtetra
.28454 .64746 .29431 .65573 .3094 .65126 .29968 .64294 Mtetra
.29968 .64294 .3094 .65126 .32457 .64676 .3149 .63839 Mtetra
.3149 .63839 .32457 .64676 .33983 .64224 .33021 .63382 Mtetra
.33021 .63382 .33983 .64224 .35517 .63768 .34561 .62922 Mtetra
.34561 .62922 .35517 .63768 .37061 .6331 .3611 .62459 Mtetra
.646 .763 .934 r
.3611 .62459 .37061 .6331 .38613 .62849 .37668 .61993 Mtetra
.37668 .61993 .38613 .62849 .40175 .62384 .39236 .61523 Mtetra
.647 .763 .934 r
.39236 .61523 .40175 .62384 .41745 .61914 .40812 .6105 Mtetra
.40812 .6105 .41745 .61914 .43325 .61437 .42398 .6057 Mtetra
.649 .764 .933 r
.42398 .6057 .43325 .61437 .44914 .60951 .43993 .60083 Mtetra
.652 .766 .933 r
.43993 .60083 .44914 .60951 .46513 .60448 .45598 .59582 Mtetra
.657 .77 .933 r
.45598 .59582 .46513 .60448 .48122 .59915 .47212 .5906 Mtetra
.666 .776 .931 r
.47212 .5906 .48122 .59915 .49739 .59329 .48836 .58498 Mtetra
.683 .787 .929 r
.48836 .58498 .49739 .59329 .51366 .58648 .50469 .57864 Mtetra
.713 .807 .924 r
.50469 .57864 .51366 .58648 .53 .57792 .52111 .571 Mtetra
.762 .839 .91 r
.52111 .571 .53 .57792 .54638 .56631 .5376 .56103 Mtetra
.831 .881 .879 r
.5376 .56103 .54638 .56631 .56275 .5497 .5541 .54711 Mtetra
.906 .92 .817 r
.5541 .54711 .56275 .5497 .57897 .52578 .57052 .52698 Mtetra
.958 .935 .722 r
.57052 .52698 .57897 .52578 .59493 .49333 .58674 .49865 Mtetra
.972 .927 .624 r
.58674 .49865 .59493 .49333 .61054 .4544 .60264 .46226 Mtetra
.963 .916 .566 r
.60264 .46226 .61054 .4544 .62589 .41482 .61821 .42195 Mtetra
.957 .923 .575 r
.61821 .42195 .62589 .41482 .64119 .3808 .63361 .38437 Mtetra
.955 .948 .66 r
.63361 .38437 .64119 .3808 .65664 .35512 .64907 .3543 Mtetra
.929 .953 .78 r
.64907 .3543 .65664 .35512 .67232 .33696 .66473 .3325 Mtetra
.861 .912 .865 r
.66473 .3325 .67232 .33696 .68823 .32411 .68064 .31718 Mtetra
.788 .852 .899 r
.68064 .31718 .68823 .32411 .70436 .31452 .69677 .30608 Mtetra
.734 .806 .909 r
.69677 .30608 .70436 .31452 .72065 .30678 .7131 .29747 Mtetra
.702 .777 .91 r
.7131 .29747 .72065 .30678 .73708 .30005 .72957 .29024 Mtetra
.684 .761 .909 r
.72957 .29024 .73708 .30005 .75363 .29384 .74618 .28373 Mtetra
.674 .752 .909 r
.74618 .28373 .75363 .29384 .7703 .2879 .76291 .27761 Mtetra
.669 .747 .908 r
.76291 .27761 .7703 .2879 .78708 .28209 .77976 .27166 Mtetra
.667 .744 .908 r
.77976 .27166 .78708 .28209 .80396 .27632 .7967 .2658 Mtetra
.665 .743 .908 r
.7967 .2658 .80396 .27632 .82094 .27057 .81376 .25996 Mtetra
.664 .742 .908 r
.81376 .25996 .82094 .27057 .83803 .2648 .83091 .25412 Mtetra
.83091 .25412 .83803 .2648 .85522 .25901 .84817 .24827 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65642 .24456 .64815 Mtetra
.24456 .64815 .25453 .65642 .2695 .65195 .25957 .64363 Mtetra
.25957 .64363 .2695 .65195 .28454 .64746 .27467 .63909 Mtetra
.27467 .63909 .28454 .64746 .29968 .64294 .28986 .63452 Mtetra
.28986 .63452 .29968 .64294 .3149 .63839 .30513 .62993 Mtetra
.30513 .62993 .3149 .63839 .33021 .63382 .3205 .62531 Mtetra
.3205 .62531 .33021 .63382 .34561 .62922 .33595 .62066 Mtetra
.33595 .62066 .34561 .62922 .3611 .62459 .3515 .61598 Mtetra
.646 .763 .934 r
.3515 .61598 .3611 .62459 .37668 .61993 .36713 .61127 Mtetra
.36713 .61127 .37668 .61993 .39236 .61523 .38286 .60653 Mtetra
.38286 .60653 .39236 .61523 .40812 .6105 .39869 .60175 Mtetra
.647 .763 .934 r
.39869 .60175 .40812 .6105 .42398 .6057 .4146 .59692 Mtetra
.648 .764 .933 r
.4146 .59692 .42398 .6057 .43993 .60083 .43061 .59203 Mtetra
.65 .765 .933 r
.43061 .59203 .43993 .60083 .45598 .59582 .44672 .58703 Mtetra
.654 .768 .933 r
.44672 .58703 .45598 .59582 .47212 .5906 .46293 .58186 Mtetra
.661 .772 .932 r
.46293 .58186 .47212 .5906 .48836 .58498 .47923 .57639 Mtetra
.673 .781 .93 r
.47923 .57639 .48836 .58498 .50469 .57864 .49563 .5704 Mtetra
.696 .796 .927 r
.49563 .5704 .50469 .57864 .52111 .571 .51212 .56343 Mtetra
.735 .822 .918 r
.51212 .56343 .52111 .571 .5376 .56103 .52869 .5547 Mtetra
.794 .859 .898 r
.52869 .5547 .5376 .56103 .5541 .54711 .5453 .54291 Mtetra
.869 .902 .853 r
.5453 .54291 .5541 .54711 .57052 .52698 .5619 .52607 Mtetra
.936 .931 .772 r
.5619 .52607 .57052 .52698 .58674 .49865 .57836 .50188 Mtetra
.969 .933 .671 r
.57836 .50188 .58674 .49865 .60264 .46226 .59454 .4691 Mtetra
.969 .92 .588 r
.59454 .4691 .60264 .46226 .61821 .42195 .61038 .42981 Mtetra
.959 .916 .56 r
.61038 .42981 .61821 .42195 .63361 .38437 .62594 .38986 Mtetra
.957 .935 .609 r
.62594 .38986 .63361 .38437 .64907 .3543 .64145 .35553 Mtetra
.947 .956 .72 r
.64145 .35553 .64907 .3543 .66473 .3325 .6571 .32959 Mtetra
.899 .937 .829 r
.6571 .32959 .66473 .3325 .68064 .31718 .673 .31121 Mtetra
.823 .881 .887 r
.673 .31121 .68064 .31718 .69677 .30608 .68913 .29817 Mtetra
.758 .827 .906 r
.68913 .29817 .69677 .30608 .7131 .29747 .70548 .2884 Mtetra
.716 .79 .91 r
.70548 .2884 .7131 .29747 .72957 .29024 .722 .2805 Mtetra
.692 .768 .91 r
.722 .2805 .72957 .29024 .74618 .28373 .73866 .27361 Mtetra
.678 .755 .909 r
.73866 .27361 .74618 .28373 .76291 .27761 .75545 .26725 Mtetra
.671 .749 .909 r
.75545 .26725 .76291 .27761 .77976 .27166 .77235 .26115 Mtetra
.668 .745 .908 r
.77235 .26115 .77976 .27166 .7967 .2658 .78937 .25518 Mtetra
.666 .743 .908 r
.78937 .25518 .7967 .2658 .81376 .25996 .80649 .24925 Mtetra
.665 .742 .908 r
.80649 .24925 .81376 .25996 .83091 .25412 .82372 .24333 Mtetra
.664 .742 .908 r
.82372 .24333 .83091 .25412 .84817 .24827 .84105 .23741 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63909 .26469 .63064 Mtetra
.26469 .63064 .27467 .63909 .28986 .63452 .27993 .62602 Mtetra
.27993 .62602 .28986 .63452 .30513 .62993 .29526 .62138 Mtetra
.29526 .62138 .30513 .62993 .3205 .62531 .31068 .61671 Mtetra
.31068 .61671 .3205 .62531 .33595 .62066 .32619 .61201 Mtetra
.32619 .61201 .33595 .62066 .3515 .61598 .34179 .60728 Mtetra
.34179 .60728 .3515 .61598 .36713 .61127 .35748 .60252 Mtetra
.646 .763 .934 r
.35748 .60252 .36713 .61127 .38286 .60653 .37327 .59773 Mtetra
.37327 .59773 .38286 .60653 .39869 .60175 .38915 .59291 Mtetra
.647 .763 .934 r
.38915 .59291 .39869 .60175 .4146 .59692 .40512 .58804 Mtetra
.40512 .58804 .4146 .59692 .43061 .59203 .42119 .58311 Mtetra
.649 .764 .933 r
.42119 .58311 .43061 .59203 .44672 .58703 .43736 .5781 Mtetra
.652 .766 .933 r
.43736 .5781 .44672 .58703 .46293 .58186 .45363 .57296 Mtetra
.657 .77 .933 r
.45363 .57296 .46293 .58186 .47923 .57639 .46999 .56759 Mtetra
.666 .776 .931 r
.46999 .56759 .47923 .57639 .49563 .5704 .48646 .56183 Mtetra
.683 .787 .929 r
.48646 .56183 .49563 .5704 .51212 .56343 .50302 .55534 Mtetra
.713 .807 .924 r
.50302 .55534 .51212 .56343 .52869 .5547 .51967 .54754 Mtetra
.762 .839 .91 r
.51967 .54754 .52869 .5547 .5453 .54291 .53638 .5374 Mtetra
.831 .881 .879 r
.53638 .5374 .5453 .54291 .5619 .52607 .55312 .52326 Mtetra
.906 .92 .817 r
.55312 .52326 .5619 .52607 .57836 .50188 .56978 .50289 Mtetra
.958 .936 .722 r
.56978 .50289 .57836 .50188 .59454 .4691 .58624 .47425 Mtetra
.972 .927 .624 r
.58624 .47425 .59454 .4691 .61038 .42981 .60236 .4375 Mtetra
.963 .916 .565 r
.60236 .4375 .61038 .42981 .62594 .38986 .61815 .39683 Mtetra
.957 .923 .575 r
.61815 .39683 .62594 .38986 .64145 .35553 .63376 .3589 Mtetra
.955 .948 .66 r
.63376 .3589 .64145 .35553 .6571 .32959 .64943 .32854 Mtetra
.929 .953 .78 r
.64943 .32854 .6571 .32959 .673 .31121 .66531 .3065 Mtetra
.861 .911 .865 r
.66531 .3065 .673 .31121 .68913 .29817 .68144 .29097 Mtetra
.788 .852 .899 r
.68144 .29097 .68913 .29817 .70548 .2884 .6978 .2797 Mtetra
.734 .806 .909 r
.6978 .2797 .70548 .2884 .722 .2805 .71435 .27091 Mtetra
.702 .777 .91 r
.71435 .27091 .722 .2805 .73866 .27361 .73106 .26351 Mtetra
.684 .761 .909 r
.73106 .26351 .73866 .27361 .75545 .26725 .7479 .25685 Mtetra
.674 .752 .909 r
.7479 .25685 .75545 .26725 .77235 .26115 .76487 .25056 Mtetra
.669 .747 .908 r
.76487 .25056 .77235 .26115 .78937 .25518 .78195 .24445 Mtetra
.667 .744 .908 r
.78195 .24445 .78937 .25518 .80649 .24925 .79915 .23843 Mtetra
.665 .743 .908 r
.79915 .23843 .80649 .24925 .82372 .24333 .81644 .23243 Mtetra
.664 .742 .908 r
.81644 .23243 .82372 .24333 .84105 .23741 .83385 .22643 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62674 Mtetra
.2394 .62674 .24954 .63523 .26469 .63064 .2546 .6221 Mtetra
.2546 .6221 .26469 .63064 .27993 .62602 .2699 .61743 Mtetra
.2699 .61743 .27993 .62602 .29526 .62138 .28528 .61274 Mtetra
.28528 .61274 .29526 .62138 .31068 .61671 .30075 .60801 Mtetra
.30075 .60801 .31068 .61671 .32619 .61201 .31632 .60326 Mtetra
.31632 .60326 .32619 .61201 .34179 .60728 .33197 .59849 Mtetra
.33197 .59849 .34179 .60728 .35748 .60252 .34772 .59368 Mtetra
.646 .763 .934 r
.34772 .59368 .35748 .60252 .37327 .59773 .36357 .58884 Mtetra
.36357 .58884 .37327 .59773 .38915 .59291 .37951 .58396 Mtetra
.37951 .58396 .38915 .59291 .40512 .58804 .39554 .57905 Mtetra
.647 .763 .934 r
.39554 .57905 .40512 .58804 .42119 .58311 .41167 .57408 Mtetra
.648 .764 .933 r
.41167 .57408 .42119 .58311 .43736 .5781 .4279 .56905 Mtetra
.65 .765 .933 r
.4279 .56905 .43736 .5781 .45363 .57296 .44423 .56391 Mtetra
.654 .768 .933 r
.44423 .56391 .45363 .57296 .46999 .56759 .46066 .5586 Mtetra
.661 .772 .932 r
.46066 .5586 .46999 .56759 .48646 .56183 .47718 .55299 Mtetra
.673 .781 .931 r
.47718 .55299 .48646 .56183 .50302 .55534 .49381 .54684 Mtetra
.696 .796 .927 r
.49381 .54684 .50302 .55534 .51967 .54754 .51054 .53971 Mtetra
.735 .822 .918 r
.51054 .53971 .51967 .54754 .53638 .5374 .52734 .53082 Mtetra
.794 .859 .898 r
.52734 .53082 .53638 .5374 .55312 .52326 .54419 .51883 Mtetra
.869 .902 .853 r
.54419 .51883 .55312 .52326 .56978 .50289 .56103 .50176 Mtetra
.936 .932 .772 r
.56103 .50176 .56978 .50289 .58624 .47425 .57772 .47729 Mtetra
.969 .933 .67 r
.57772 .47729 .58624 .47425 .60236 .4375 .59414 .44418 Mtetra
.968 .92 .588 r
.59414 .44418 .60236 .4375 .61815 .39683 .6102 .40451 Mtetra
.959 .916 .561 r
.6102 .40451 .61815 .39683 .63376 .3589 .62599 .36421 Mtetra
.957 .935 .609 r
.62599 .36421 .63376 .3589 .64943 .32854 .64171 .32956 Mtetra
.948 .956 .721 r
.64171 .32956 .64943 .32854 .66531 .3065 .65758 .30335 Mtetra
.898 .937 .829 r
.65758 .30335 .66531 .3065 .68144 .29097 .6737 .28475 Mtetra
.823 .881 .887 r
.6737 .28475 .68144 .29097 .6978 .2797 .69006 .27151 Mtetra
.758 .827 .906 r
.69006 .27151 .6978 .2797 .71435 .27091 .70663 .26156 Mtetra
.716 .79 .91 r
.70663 .26156 .71435 .27091 .73106 .26351 .72338 .25349 Mtetra
.692 .768 .91 r
.72338 .25349 .73106 .26351 .7479 .25685 .74028 .24643 Mtetra
.678 .755 .909 r
.74028 .24643 .7479 .25685 .76487 .25056 .75731 .23991 Mtetra
.671 .749 .909 r
.75731 .23991 .76487 .25056 .78195 .24445 .77446 .23364 Mtetra
.668 .745 .908 r
.77446 .23364 .78195 .24445 .79915 .23843 .79172 .2275 Mtetra
.666 .743 .908 r
.79172 .2275 .79915 .23843 .81644 .23243 .80909 .22141 Mtetra
.665 .742 .908 r
.80909 .22141 .81644 .23243 .83385 .22643 .82657 .21533 Mtetra
.646 .762 .934 r
.18391 .63206 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62674 .22915 .61815 Mtetra
.22915 .61815 .2394 .62674 .2546 .6221 .24441 .61346 Mtetra
.24441 .61346 .2546 .6221 .2699 .61743 .25975 .60874 Mtetra
.25975 .60874 .2699 .61743 .28528 .61274 .27519 .604 Mtetra
.27519 .604 .28528 .61274 .30075 .60801 .29072 .59923 Mtetra
.29072 .59923 .30075 .60801 .31632 .60326 .30634 .59442 Mtetra
.30634 .59442 .31632 .60326 .33197 .59849 .32205 .58959 Mtetra
.32205 .58959 .33197 .59849 .34772 .59368 .33786 .58473 Mtetra
.33786 .58473 .34772 .59368 .36357 .58884 .35376 .57984 Mtetra
.646 .763 .934 r
.35376 .57984 .36357 .58884 .37951 .58396 .36976 .57491 Mtetra
.36976 .57491 .37951 .58396 .39554 .57905 .38585 .56995 Mtetra
.647 .763 .934 r
.38585 .56995 .39554 .57905 .41167 .57408 .40204 .56494 Mtetra
.40204 .56494 .41167 .57408 .4279 .56905 .41833 .55988 Mtetra
.649 .764 .933 r
.41833 .55988 .4279 .56905 .44423 .56391 .43472 .55473 Mtetra
.652 .766 .933 r
.43472 .55473 .44423 .56391 .46066 .5586 .45121 .54944 Mtetra
.657 .77 .933 r
.45121 .54944 .46066 .5586 .47718 .55299 .46781 .54393 Mtetra
.666 .776 .931 r
.46781 .54393 .47718 .55299 .49381 .54684 .4845 .53801 Mtetra
.683 .788 .929 r
.4845 .53801 .49381 .54684 .51054 .53971 .5013 .53137 Mtetra
.713 .808 .924 r
.5013 .53137 .51054 .53971 .52734 .53082 .51818 .5234 Mtetra
.762 .839 .911 r
.51818 .5234 .52734 .53082 .54419 .51883 .53514 .51307 Mtetra
.831 .881 .88 r
.53514 .51307 .54419 .51883 .56103 .50176 .55211 .49872 Mtetra
.906 .92 .817 r
.55211 .49872 .56103 .50176 .57772 .47729 .56902 .4781 Mtetra
.958 .936 .721 r
.56902 .4781 .57772 .47729 .59414 .44418 .58571 .44914 Mtetra
.971 .927 .624 r
.58571 .44914 .59414 .44418 .6102 .40451 .60207 .41204 Mtetra
.963 .916 .565 r
.60207 .41204 .6102 .40451 .62599 .36421 .61809 .37099 Mtetra
.957 .923 .575 r
.61809 .37099 .62599 .36421 .64171 .32956 .63392 .33272 Mtetra
.956 .948 .661 r
.63392 .33272 .64171 .32956 .65758 .30335 .64981 .30206 Mtetra
.929 .953 .78 r
.64981 .30206 .65758 .30335 .6737 .28475 .66591 .27977 Mtetra
.861 .911 .865 r
.66591 .27977 .6737 .28475 .69006 .27151 .68226 .26404 Mtetra
.788 .852 .899 r
.68226 .26404 .69006 .27151 .70663 .26156 .69885 .25257 Mtetra
.734 .806 .909 r
.69885 .25257 .70663 .26156 .72338 .25349 .71563 .24361 Mtetra
.702 .777 .91 r
.71563 .24361 .72338 .25349 .74028 .24643 .73258 .23604 Mtetra
.684 .761 .909 r
.73258 .23604 .74028 .24643 .75731 .23991 .74967 .22921 Mtetra
.674 .752 .909 r
.74967 .22921 .75731 .23991 .77446 .23364 .76688 .22275 Mtetra
.669 .747 .908 r
.76688 .22275 .77446 .23364 .79172 .2275 .78421 .21648 Mtetra
.667 .744 .908 r
.78421 .21648 .79172 .2275 .80909 .22141 .80166 .21028 Mtetra
.665 .743 .908 r
.80166 .21028 .80909 .22141 .82657 .21533 .81921 .20411 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63206 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .604 .26499 .59517 Mtetra
.26499 .59517 .27519 .604 .29072 .59923 .28057 .59034 Mtetra
.28057 .59034 .29072 .59923 .30634 .59442 .29625 .58549 Mtetra
.29625 .58549 .30634 .59442 .32205 .58959 .31202 .5806 Mtetra
.31202 .5806 .32205 .58959 .33786 .58473 .32788 .57569 Mtetra
.32788 .57569 .33786 .58473 .35376 .57984 .34384 .57074 Mtetra
.646 .763 .934 r
.34384 .57074 .35376 .57984 .36976 .57491 .3599 .56576 Mtetra
.3599 .56576 .36976 .57491 .38585 .56995 .37605 .56075 Mtetra
.37605 .56075 .38585 .56995 .40204 .56494 .3923 .55569 Mtetra
.647 .763 .934 r
.3923 .55569 .40204 .56494 .41833 .55988 .40866 .55059 Mtetra
.648 .764 .933 r
.40866 .55059 .41833 .55988 .43472 .55473 .42511 .54541 Mtetra
.65 .765 .933 r
.42511 .54541 .43472 .55473 .45121 .54944 .44166 .54013 Mtetra
.654 .768 .933 r
.44166 .54013 .45121 .54944 .46781 .54393 .45832 .53467 Mtetra
.661 .772 .932 r
.45832 .53467 .46781 .54393 .4845 .53801 .47508 .52891 Mtetra
.673 .781 .931 r
.47508 .52891 .4845 .53801 .5013 .53137 .49195 .52261 Mtetra
.696 .796 .927 r
.49195 .52261 .5013 .53137 .51818 .5234 .50891 .51531 Mtetra
.735 .822 .919 r
.50891 .51531 .51818 .5234 .53514 .51307 .52595 .50624 Mtetra
.794 .86 .898 r
.52595 .50624 .53514 .51307 .55211 .49872 .54305 .49405 Mtetra
.87 .903 .853 r
.54305 .49405 .55211 .49872 .56902 .4781 .56013 .47675 Mtetra
.937 .932 .772 r
.56013 .47675 .56902 .4781 .58571 .44914 .57707 .45199 Mtetra
.969 .933 .67 r
.57707 .45199 .58571 .44914 .60207 .41204 .59373 .41854 Mtetra
.968 .92 .587 r
.59373 .41854 .60207 .41204 .61809 .37099 .61003 .3785 Mtetra
.959 .916 .561 r
.61003 .3785 .61809 .37099 .63392 .33272 .62604 .33783 Mtetra
.957 .935 .61 r
.62604 .33783 .63392 .33272 .64981 .30206 .64198 .30285 Mtetra
.948 .956 .721 r
.64198 .30285 .64981 .30206 .66591 .27977 .65808 .27637 Mtetra
.898 .937 .829 r
.65808 .27637 .66591 .27977 .68226 .26404 .67442 .25753 Mtetra
.823 .881 .887 r
.67442 .25753 .68226 .26404 .69885 .25257 .69101 .24409 Mtetra
.758 .827 .906 r
.69101 .24409 .69885 .25257 .71563 .24361 .70782 .23397 Mtetra
.716 .79 .91 r
.70782 .23397 .71563 .24361 .73258 .23604 .72481 .22572 Mtetra
.692 .768 .91 r
.72481 .22572 .73258 .23604 .74967 .22921 .74195 .21849 Mtetra
.678 .755 .909 r
.74195 .21849 .74967 .22921 .76688 .22275 .75922 .21179 Mtetra
.671 .749 .909 r
.75922 .21179 .76688 .22275 .78421 .21648 .77662 .20535 Mtetra
.668 .745 .908 r
.77662 .20535 .78421 .21648 .80166 .21028 .79414 .19904 Mtetra
.666 .743 .908 r
.79414 .19904 .80166 .21028 .81921 .20411 .81177 .19278 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .59591 Mtetra
.22368 .59591 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59517 .25468 .58623 Mtetra
.25468 .58623 .26499 .59517 .28057 .59034 .27032 .58136 Mtetra
.27032 .58136 .28057 .59034 .29625 .58549 .28605 .57645 Mtetra
.28605 .57645 .29625 .58549 .31202 .5806 .30187 .57151 Mtetra
.30187 .57151 .31202 .5806 .32788 .57569 .3178 .56654 Mtetra
.3178 .56654 .32788 .57569 .34384 .57074 .33381 .56154 Mtetra
.33381 .56154 .34384 .57074 .3599 .56576 .34993 .55651 Mtetra
.646 .763 .934 r
.34993 .55651 .3599 .56576 .37605 .56075 .36614 .55144 Mtetra
.36614 .55144 .37605 .56075 .3923 .55569 .38246 .54634 Mtetra
.647 .763 .934 r
.38246 .54634 .3923 .55569 .40866 .55059 .39887 .54118 Mtetra
.39887 .54118 .40866 .55059 .42511 .54541 .41539 .53597 Mtetra
.649 .764 .933 r
.41539 .53597 .42511 .54541 .44166 .54013 .43201 .53067 Mtetra
.652 .766 .933 r
.43201 .53067 .44166 .54013 .45832 .53467 .44873 .52524 Mtetra
.657 .77 .933 r
.44873 .52524 .45832 .53467 .47508 .52891 .46555 .51957 Mtetra
.666 .776 .931 r
.46555 .51957 .47508 .52891 .49195 .52261 .48249 .5135 Mtetra
.683 .788 .929 r
.48249 .5135 .49195 .52261 .50891 .51531 .49952 .5067 Mtetra
.713 .808 .924 r
.49952 .5067 .50891 .51531 .52595 .50624 .51665 .49856 Mtetra
.762 .839 .911 r
.51665 .49856 .52595 .50624 .54305 .49405 .53385 .48804 Mtetra
.831 .881 .88 r
.53385 .48804 .54305 .49405 .56013 .47675 .55108 .47347 Mtetra
.906 .92 .817 r
.55108 .47347 .56013 .47675 .57707 .45199 .56823 .45258 Mtetra
.958 .936 .721 r
.56823 .45258 .57707 .45199 .59373 .41854 .58517 .42331 Mtetra
.971 .927 .624 r
.58517 .42331 .59373 .41854 .61003 .3785 .60178 .38584 Mtetra
.963 .916 .565 r
.60178 .38584 .61003 .3785 .62604 .33783 .61802 .34441 Mtetra
.957 .923 .576 r
.61802 .34441 .62604 .33783 .64198 .30285 .63408 .30579 Mtetra
.956 .948 .661 r
.63408 .30579 .64198 .30285 .65808 .27637 .6502 .27483 Mtetra
.929 .953 .78 r
.6502 .27483 .65808 .27637 .67442 .25753 .66653 .25229 Mtetra
.861 .911 .865 r
.66653 .25229 .67442 .25753 .69101 .24409 .68311 .23634 Mtetra
.788 .852 .899 r
.68311 .23634 .69101 .24409 .70782 .23397 .69993 .22467 Mtetra
.734 .806 .908 r
.69993 .22467 .70782 .23397 .72481 .22572 .71696 .21553 Mtetra
.702 .777 .91 r
.71696 .21553 .72481 .22572 .74195 .21849 .73415 .20778 Mtetra
.684 .761 .909 r
.73415 .20778 .74195 .21849 .75922 .21179 .75149 .20077 Mtetra
.674 .752 .909 r
.75149 .20077 .75922 .21179 .77662 .20535 .76895 .19414 Mtetra
.669 .747 .908 r
.76895 .19414 .77662 .20535 .79414 .19904 .78654 .18769 Mtetra
.667 .744 .908 r
.78654 .18769 .79414 .19904 .81177 .19278 .80424 .18132 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .59591 .21314 .58698 Mtetra
.21314 .58698 .22368 .59591 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58623 .24425 .57721 Mtetra
.24425 .57721 .25468 .58623 .27032 .58136 .25994 .57227 Mtetra
.25994 .57227 .27032 .58136 .28605 .57645 .27573 .56731 Mtetra
.27573 .56731 .28605 .57645 .30187 .57151 .29162 .56232 Mtetra
.29162 .56232 .30187 .57151 .3178 .56654 .3076 .55729 Mtetra
.3076 .55729 .3178 .56654 .33381 .56154 .32367 .55224 Mtetra
.32367 .55224 .33381 .56154 .34993 .55651 .33985 .54715 Mtetra
.646 .763 .934 r
.33985 .54715 .34993 .55651 .36614 .55144 .35612 .54203 Mtetra
.35612 .54203 .36614 .55144 .38246 .54634 .3725 .53687 Mtetra
.3725 .53687 .38246 .54634 .39887 .54118 .38898 .53167 Mtetra
.647 .763 .934 r
.38898 .53167 .39887 .54118 .41539 .53597 .40555 .52641 Mtetra
.648 .764 .933 r
.40555 .52641 .41539 .53597 .43201 .53067 .42224 .52109 Mtetra
.65 .765 .933 r
.42224 .52109 .43201 .53067 .44873 .52524 .43902 .51565 Mtetra
.654 .768 .933 r
.43902 .51565 .44873 .52524 .46555 .51957 .45592 .51004 Mtetra
.661 .772 .932 r
.45592 .51004 .46555 .51957 .48249 .5135 .47292 .50412 Mtetra
.673 .781 .931 r
.47292 .50412 .48249 .5135 .49952 .5067 .49002 .49765 Mtetra
.696 .796 .927 r
.49002 .49765 .49952 .5067 .51665 .49856 .50723 .49019 Mtetra
.735 .822 .919 r
.50723 .49019 .51665 .49856 .53385 .48804 .52453 .48094 Mtetra
.794 .86 .898 r
.52453 .48094 .53385 .48804 .55108 .47347 .54187 .46854 Mtetra
.87 .903 .853 r
.54187 .46854 .55108 .47347 .56823 .45258 .55921 .45099 Mtetra
.937 .932 .772 r
.55921 .45099 .56823 .45258 .58517 .42331 .5764 .42594 Mtetra
.969 .934 .67 r
.5764 .42594 .58517 .42331 .60178 .38584 .59331 .39214 Mtetra
.968 .92 .587 r
.59331 .39214 .60178 .38584 .61802 .34441 .60984 .35172 Mtetra
.959 .916 .561 r
.60984 .35172 .61802 .34441 .63408 .30579 .62609 .31068 Mtetra
.957 .935 .61 r
.62609 .31068 .63408 .30579 .6502 .27483 .64226 .27538 Mtetra
.948 .956 .721 r
.64226 .27538 .6502 .27483 .66653 .25229 .65859 .24861 Mtetra
.898 .937 .829 r
.65859 .24861 .66653 .25229 .68311 .23634 .67516 .22955 Mtetra
.823 .881 .887 r
.67516 .22955 .68311 .23634 .69993 .22467 .69199 .2159 Mtetra
.758 .827 .905 r
.69199 .2159 .69993 .22467 .71696 .21553 .70904 .20558 Mtetra
.716 .789 .91 r
.70904 .20558 .71696 .21553 .73415 .20778 .72627 .19715 Mtetra
.692 .768 .91 r
.72627 .19715 .73415 .20778 .75149 .20077 .74367 .18974 Mtetra
.678 .755 .909 r
.74367 .18974 .75149 .20077 .76895 .19414 .7612 .18286 Mtetra
.671 .749 .909 r
.7612 .18286 .76895 .19414 .78654 .18769 .77885 .17624 Mtetra
.668 .745 .908 r
.77885 .17624 .78654 .18769 .80424 .18132 .79663 .16975 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .57721 .23371 .56808 Mtetra
.23371 .56808 .24425 .57721 .25994 .57227 .24946 .56309 Mtetra
.24946 .56309 .25994 .57227 .27573 .56731 .2653 .55807 Mtetra
.2653 .55807 .27573 .56731 .29162 .56232 .28124 .55302 Mtetra
.28124 .55302 .29162 .56232 .3076 .55729 .29728 .54794 Mtetra
.29728 .54794 .3076 .55729 .32367 .55224 .31342 .54283 Mtetra
.31342 .54283 .32367 .55224 .33985 .54715 .32965 .53768 Mtetra
.32965 .53768 .33985 .54715 .35612 .54203 .34599 .5325 Mtetra
.646 .763 .934 r
.34599 .5325 .35612 .54203 .3725 .53687 .36243 .52729 Mtetra
.36243 .52729 .3725 .53687 .38898 .53167 .37897 .52204 Mtetra
.647 .763 .934 r
.37897 .52204 .38898 .53167 .40555 .52641 .39561 .51673 Mtetra
.39561 .51673 .40555 .52641 .42224 .52109 .41236 .51137 Mtetra
.649 .764 .933 r
.41236 .51137 .42224 .52109 .43902 .51565 .42921 .50592 Mtetra
.652 .766 .933 r
.42921 .50592 .43902 .51565 .45592 .51004 .44617 .50033 Mtetra
.657 .77 .933 r
.44617 .50033 .45592 .51004 .47292 .50412 .46324 .4945 Mtetra
.666 .776 .931 r
.46324 .4945 .47292 .50412 .49002 .49765 .48041 .48827 Mtetra
.683 .788 .929 r
.48041 .48827 .49002 .49765 .50723 .49019 .49769 .48129 Mtetra
.713 .808 .924 r
.49769 .48129 .50723 .49019 .52453 .48094 .51507 .47297 Mtetra
.762 .839 .911 r
.51507 .47297 .52453 .48094 .54187 .46854 .53253 .46226 Mtetra
.831 .882 .88 r
.53253 .46226 .54187 .46854 .55921 .45099 .55001 .44746 Mtetra
.906 .921 .817 r
.55001 .44746 .55921 .45099 .5764 .42594 .56742 .4263 Mtetra
.958 .936 .721 r
.56742 .4263 .5764 .42594 .59331 .39214 .58462 .3967 Mtetra
.971 .927 .623 r
.58462 .3967 .59331 .39214 .60984 .35172 .60147 .35887 Mtetra
.963 .916 .565 r
.60147 .35887 .60984 .35172 .62609 .31068 .61796 .31705 Mtetra
.957 .923 .576 r
.61796 .31705 .62609 .31068 .64226 .27538 .63425 .27807 Mtetra
.956 .948 .661 r
.63425 .27807 .64226 .27538 .65859 .24861 .6506 .24681 Mtetra
.929 .953 .78 r
.6506 .24681 .65859 .24861 .67516 .22955 .66716 .22401 Mtetra
.861 .911 .864 r
.66716 .22401 .67516 .22955 .69199 .2159 .68398 .20784 Mtetra
.788 .852 .899 r
.68398 .20784 .69199 .2159 .70904 .20558 .70105 .19598 Mtetra
.734 .806 .908 r
.70105 .19598 .70904 .20558 .72627 .19715 .71832 .18664 Mtetra
.702 .777 .91 r
.71832 .18664 .72627 .19715 .74367 .18974 .73576 .17871 Mtetra
.684 .761 .909 r
.73576 .17871 .74367 .18974 .7612 .18286 .75336 .17152 Mtetra
.674 .752 .909 r
.75336 .17152 .7612 .18286 .77885 .17624 .77108 .1647 Mtetra
.669 .747 .908 r
.77108 .1647 .77885 .17624 .79663 .16975 .78893 .15807 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56808 .22305 .55884 Mtetra
.22305 .55884 .23371 .56808 .24946 .56309 .23885 .5538 Mtetra
.23885 .5538 .24946 .56309 .2653 .55807 .25476 .54872 Mtetra
.25476 .54872 .2653 .55807 .28124 .55302 .27075 .54362 Mtetra
.27075 .54362 .28124 .55302 .29728 .54794 .28685 .53848 Mtetra
.28685 .53848 .29728 .54794 .31342 .54283 .30305 .53331 Mtetra
.30305 .53331 .31342 .54283 .32965 .53768 .31934 .52811 Mtetra
.31934 .52811 .32965 .53768 .34599 .5325 .33574 .52287 Mtetra
.646 .763 .934 r
.33574 .52287 .34599 .5325 .36243 .52729 .35224 .5176 Mtetra
.35224 .5176 .36243 .52729 .37897 .52204 .36884 .51229 Mtetra
.36884 .51229 .37897 .52204 .39561 .51673 .38555 .50693 Mtetra
.647 .763 .934 r
.38555 .50693 .39561 .51673 .41236 .51137 .40236 .50153 Mtetra
.648 .764 .934 r
.40236 .50153 .41236 .51137 .42921 .50592 .41928 .49604 Mtetra
.65 .765 .933 r
.41928 .49604 .42921 .50592 .44617 .50033 .43631 .49045 Mtetra
.654 .768 .933 r
.43631 .49045 .44617 .50033 .46324 .4945 .45344 .48468 Mtetra
.661 .772 .932 r
.45344 .48468 .46324 .4945 .48041 .48827 .47069 .47859 Mtetra
.673 .781 .931 r
.47069 .47859 .48041 .48827 .49769 .48129 .48804 .47196 Mtetra
.696 .796 .927 r
.48804 .47196 .49769 .48129 .51507 .47297 .5055 .46432 Mtetra
.735 .822 .919 r
.5055 .46432 .51507 .47297 .53253 .46226 .52305 .45487 Mtetra
.794 .86 .898 r
.52305 .45487 .53253 .46226 .55001 .44746 .54066 .44226 Mtetra
.87 .903 .853 r
.54066 .44226 .55001 .44746 .56742 .4263 .55825 .42446 Mtetra
.937 .932 .772 r
.55825 .42446 .56742 .4263 .58462 .3967 .57571 .39911 Mtetra
.969 .934 .669 r
.57571 .39911 .58462 .3967 .60147 .35887 .59287 .36496 Mtetra
.968 .92 .587 r
.59287 .36496 .60147 .35887 .61796 .31705 .60966 .32416 Mtetra
.959 .916 .561 r
.60966 .32416 .61796 .31705 .63425 .27807 .62614 .28274 Mtetra
.957 .935 .611 r
.62614 .28274 .63425 .27807 .6506 .24681 .64255 .2471 Mtetra
.948 .956 .721 r
.64255 .2471 .6506 .24681 .66716 .22401 .65911 .22005 Mtetra
.898 .936 .829 r
.65911 .22005 .66716 .22401 .68398 .20784 .67592 .20075 Mtetra
.823 .881 .887 r
.67592 .20075 .68398 .20784 .70105 .19598 .69299 .18689 Mtetra
.758 .827 .905 r
.69299 .18689 .70105 .19598 .71832 .18664 .71029 .17637 Mtetra
.716 .789 .91 r
.71029 .17637 .71832 .18664 .73576 .17871 .72778 .16774 Mtetra
.692 .768 .91 r
.72778 .16774 .73576 .17871 .75336 .17152 .74543 .16014 Mtetra
.678 .755 .909 r
.74543 .16014 .75336 .17152 .77108 .1647 .76322 .15308 Mtetra
.671 .749 .909 r
.76322 .15308 .77108 .1647 .78893 .15807 .78115 .14628 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .5538 .22813 .54441 Mtetra
.22813 .54441 .23885 .5538 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27075 .54362 .26015 .53411 Mtetra
.26015 .53411 .27075 .54362 .28685 .53848 .2763 .52891 Mtetra
.2763 .52891 .28685 .53848 .30305 .53331 .29256 .52368 Mtetra
.29256 .52368 .30305 .53331 .31934 .52811 .30891 .51842 Mtetra
.30891 .51842 .31934 .52811 .33574 .52287 .32537 .51313 Mtetra
.32537 .51313 .33574 .52287 .35224 .5176 .34194 .5078 Mtetra
.646 .763 .934 r
.34194 .5078 .35224 .5176 .36884 .51229 .3586 .50243 Mtetra
.3586 .50243 .36884 .51229 .38555 .50693 .37537 .49702 Mtetra
.647 .763 .934 r
.37537 .49702 .38555 .50693 .40236 .50153 .39225 .49156 Mtetra
.39225 .49156 .40236 .50153 .41928 .49604 .40924 .48603 Mtetra
.649 .764 .933 r
.40924 .48603 .41928 .49604 .43631 .49045 .42633 .48042 Mtetra
.652 .766 .933 r
.42633 .48042 .43631 .49045 .45344 .48468 .44353 .47467 Mtetra
.657 .77 .933 r
.44353 .47467 .45344 .48468 .47069 .47859 .46085 .46868 Mtetra
.666 .776 .932 r
.46085 .46868 .47069 .47859 .48804 .47196 .47828 .46227 Mtetra
.683 .788 .929 r
.47828 .46227 .48804 .47196 .5055 .46432 .49581 .45512 Mtetra
.713 .808 .924 r
.49581 .45512 .5055 .46432 .52305 .45487 .51345 .44661 Mtetra
.762 .84 .911 r
.51345 .44661 .52305 .45487 .54066 .44226 .53117 .43569 Mtetra
.831 .882 .88 r
.53117 .43569 .54066 .44226 .55825 .42446 .54891 .42066 Mtetra
.906 .921 .817 r
.54891 .42066 .55825 .42446 .57571 .39911 .56659 .39922 Mtetra
.958 .936 .721 r
.56659 .39922 .57571 .39911 .59287 .36496 .58405 .3693 Mtetra
.971 .927 .623 r
.58405 .3693 .59287 .36496 .60966 .32416 .60115 .33109 Mtetra
.963 .916 .565 r
.60115 .33109 .60966 .32416 .62614 .28274 .61789 .28889 Mtetra
.957 .923 .576 r
.61789 .28889 .62614 .28274 .64255 .2471 .63442 .24955 Mtetra
.956 .948 .662 r
.63442 .24955 .64255 .2471 .65911 .22005 .65101 .21797 Mtetra
.929 .952 .78 r
.65101 .21797 .65911 .22005 .67592 .20075 .66781 .19491 Mtetra
.861 .91 .864 r
.66781 .19491 .67592 .20075 .69299 .18689 .68488 .17851 Mtetra
.788 .852 .899 r
.68488 .17851 .69299 .18689 .71029 .17637 .7022 .16644 Mtetra
.734 .806 .908 r
.7022 .16644 .71029 .17637 .72778 .16774 .71972 .15691 Mtetra
.702 .777 .91 r
.71972 .15691 .72778 .16774 .74543 .16014 .73743 .14878 Mtetra
.684 .761 .909 r
.73743 .14878 .74543 .16014 .76322 .15308 .75528 .1414 Mtetra
.674 .752 .909 r
.75528 .1414 .76322 .15308 .78115 .14628 .77327 .13439 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54007 Mtetra
.20137 .54007 .21227 .54951 .22813 .54441 .21728 .53491 Mtetra
.21728 .53491 .22813 .54441 .24409 .53927 .2333 .52972 Mtetra
.2333 .52972 .24409 .53927 .26015 .53411 .24941 .52449 Mtetra
.24941 .52449 .26015 .53411 .2763 .52891 .26563 .51924 Mtetra
.26563 .51924 .2763 .52891 .29256 .52368 .28195 .51395 Mtetra
.28195 .51395 .29256 .52368 .30891 .51842 .29837 .50863 Mtetra
.29837 .50863 .30891 .51842 .32537 .51313 .31489 .50327 Mtetra
.31489 .50327 .32537 .51313 .34194 .5078 .33151 .49788 Mtetra
.646 .763 .934 r
.33151 .49788 .34194 .5078 .3586 .50243 .34824 .49245 Mtetra
.34824 .49245 .3586 .50243 .37537 .49702 .36508 .48698 Mtetra
.36508 .48698 .37537 .49702 .39225 .49156 .38202 .48147 Mtetra
.647 .763 .934 r
.38202 .48147 .39225 .49156 .40924 .48603 .39907 .4759 Mtetra
.648 .764 .934 r
.39907 .4759 .40924 .48603 .42633 .48042 .41623 .47025 Mtetra
.65 .765 .933 r
.41623 .47025 .42633 .48042 .44353 .47467 .43351 .46449 Mtetra
.654 .768 .933 r
.43351 .46449 .44353 .47467 .46085 .46868 .45089 .45855 Mtetra
.661 .772 .932 r
.45089 .45855 .46085 .46868 .47828 .46227 .46839 .4523 Mtetra
.673 .781 .931 r
.46839 .4523 .47828 .46227 .49581 .45512 .486 .44548 Mtetra
.696 .796 .927 r
.486 .44548 .49581 .45512 .51345 .44661 .50372 .43766 Mtetra
.735 .822 .919 r
.50372 .43766 .51345 .44661 .53117 .43569 .52154 .42801 Mtetra
.794 .86 .898 r
.52154 .42801 .53117 .43569 .54891 .42066 .53941 .41518 Mtetra
.87 .903 .853 r
.53941 .41518 .54891 .42066 .56659 .39922 .55727 .39712 Mtetra
.937 .933 .771 r
.55727 .39712 .56659 .39922 .58405 .3693 .575 .37147 Mtetra
.969 .934 .669 r
.575 .37147 .58405 .3693 .60115 .33109 .59243 .33696 Mtetra
.968 .92 .587 r
.59243 .33696 .60115 .33109 .61789 .28889 .60946 .29577 Mtetra
.959 .916 .561 r
.60946 .29577 .61789 .28889 .63442 .24955 .62619 .25397 Mtetra
.958 .935 .611 r
.62619 .25397 .63442 .24955 .65101 .21797 .64284 .21799 Mtetra
.948 .956 .722 r
.64284 .21799 .65101 .21797 .66781 .19491 .65965 .19066 Mtetra
.898 .936 .829 r
.65965 .19066 .66781 .19491 .68488 .17851 .67671 .1711 Mtetra
.823 .881 .886 r
.67671 .1711 .68488 .17851 .7022 .16644 .69403 .15702 Mtetra
.758 .826 .905 r
.69403 .15702 .7022 .16644 .71972 .15691 .71159 .14629 Mtetra
.716 .789 .91 r
.71159 .14629 .71972 .15691 .73743 .14878 .72934 .13747 Mtetra
.692 .768 .91 r
.72934 .13747 .73743 .14878 .75528 .1414 .74725 .12968 Mtetra
.679 .755 .909 r
.74725 .12968 .75528 .1414 .77327 .13439 .76531 .12242 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54007 .19034 .53052 Mtetra
.19034 .53052 .20137 .54007 .21728 .53491 .20631 .5253 Mtetra
.20631 .5253 .21728 .53491 .2333 .52972 .22239 .52005 Mtetra
.22239 .52005 .2333 .52972 .24941 .52449 .23856 .51476 Mtetra
.23856 .51476 .24941 .52449 .26563 .51924 .25484 .50945 Mtetra
.25484 .50945 .26563 .51924 .28195 .51395 .27121 .5041 Mtetra
.27121 .5041 .28195 .51395 .29837 .50863 .28769 .49871 Mtetra
.28769 .49871 .29837 .50863 .31489 .50327 .30428 .4933 Mtetra
.30428 .4933 .31489 .50327 .33151 .49788 .32097 .48784 Mtetra
.32097 .48784 .33151 .49788 .34824 .49245 .33776 .48235 Mtetra
.646 .763 .934 r
.33776 .48235 .34824 .49245 .36508 .48698 .35466 .47682 Mtetra
.35466 .47682 .36508 .48698 .38202 .48147 .37167 .47125 Mtetra
.647 .763 .934 r
.37167 .47125 .38202 .48147 .39907 .4759 .38879 .46563 Mtetra
.38879 .46563 .39907 .4759 .41623 .47025 .40602 .45994 Mtetra
.649 .764 .933 r
.40602 .45994 .41623 .47025 .43351 .46449 .42336 .45416 Mtetra
.652 .766 .933 r
.42336 .45416 .43351 .46449 .45089 .45855 .44082 .44823 Mtetra
.657 .77 .933 r
.44082 .44823 .45089 .45855 .46839 .4523 .45839 .44207 Mtetra
.666 .776 .932 r
.45839 .44207 .46839 .4523 .486 .44548 .47607 .43549 Mtetra
.683 .788 .929 r
.47607 .43549 .486 .44548 .50372 .43766 .49387 .42815 Mtetra
.713 .808 .924 r
.49387 .42815 .50372 .43766 .52154 .42801 .51178 .41945 Mtetra
.762 .84 .911 r
.51178 .41945 .52154 .42801 .53941 .41518 .52976 .40831 Mtetra
.831 .882 .88 r
.52976 .40831 .53941 .41518 .55727 .39712 .54778 .39304 Mtetra
.906 .921 .817 r
.54778 .39304 .55727 .39712 .575 .37147 .56573 .37132 Mtetra
.958 .937 .721 r
.56573 .37132 .575 .37147 .59243 .33696 .58346 .34106 Mtetra
.971 .927 .623 r
.58346 .34106 .59243 .33696 .60946 .29577 .60083 .30247 Mtetra
.963 .916 .565 r
.60083 .30247 .60946 .29577 .62619 .25397 .61782 .25987 Mtetra
.958 .923 .576 r
.61782 .25987 .62619 .25397 .64284 .21799 .6346 .22017 Mtetra
.956 .948 .662 r
.6346 .22017 .64284 .21799 .65965 .19066 .65143 .18828 Mtetra
.929 .952 .781 r
.65143 .18828 .65965 .19066 .67671 .1711 .66848 .16495 Mtetra
.861 .91 .864 r
.66848 .16495 .67671 .1711 .69403 .15702 .6858 .14831 Mtetra
.788 .852 .899 r
.6858 .14831 .69403 .15702 .71159 .14629 .70338 .13602 Mtetra
.734 .806 .908 r
.70338 .13602 .71159 .14629 .72934 .13747 .72117 .12629 Mtetra
.702 .777 .91 r
.72117 .12629 .72934 .13747 .74725 .12968 .73914 .11796 Mtetra
.684 .761 .909 r
.73914 .11796 .74725 .12968 .76531 .12242 .75726 .11038 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52005 .21135 .51027 Mtetra
.21135 .51027 .22239 .52005 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50945 .24392 .49955 Mtetra
.24392 .49955 .25484 .50945 .27121 .5041 .26036 .49413 Mtetra
.26036 .49413 .27121 .5041 .28769 .49871 .2769 .48869 Mtetra
.2769 .48869 .28769 .49871 .30428 .4933 .29354 .48321 Mtetra
.29354 .48321 .30428 .4933 .32097 .48784 .3103 .47769 Mtetra
.3103 .47769 .32097 .48784 .33776 .48235 .32716 .47214 Mtetra
.646 .763 .934 r
.32716 .47214 .33776 .48235 .35466 .47682 .34412 .46654 Mtetra
.34412 .46654 .35466 .47682 .37167 .47125 .3612 .46091 Mtetra
.3612 .46091 .37167 .47125 .38879 .46563 .37839 .45523 Mtetra
.647 .763 .934 r
.37839 .45523 .38879 .46563 .40602 .45994 .39568 .44949 Mtetra
.648 .764 .934 r
.39568 .44949 .40602 .45994 .42336 .45416 .4131 .44367 Mtetra
.65 .765 .933 r
.4131 .44367 .42336 .45416 .44082 .44823 .43062 .43774 Mtetra
.654 .768 .933 r
.43062 .43774 .44082 .44823 .45839 .44207 .44826 .43162 Mtetra
.661 .772 .932 r
.44826 .43162 .45839 .44207 .47607 .43549 .46602 .42519 Mtetra
.673 .781 .931 r
.46602 .42519 .47607 .43549 .49387 .42815 .4839 .41819 Mtetra
.696 .796 .927 r
.4839 .41819 .49387 .42815 .51178 .41945 .50189 .41017 Mtetra
.735 .822 .919 r
.50189 .41017 .51178 .41945 .52976 .40831 .51998 .40032 Mtetra
.794 .86 .898 r
.51998 .40032 .52976 .40831 .54778 .39304 .53812 .38726 Mtetra
.87 .903 .853 r
.53812 .38726 .54778 .39304 .56573 .37132 .55626 .36894 Mtetra
.937 .933 .771 r
.55626 .36894 .56573 .37132 .58346 .34106 .57426 .34297 Mtetra
.969 .934 .669 r
.57426 .34297 .58346 .34106 .60083 .30247 .59196 .3081 Mtetra
.968 .92 .587 r
.59196 .3081 .60083 .30247 .61782 .25987 .60926 .26651 Mtetra
.959 .916 .561 r
.60926 .26651 .61782 .25987 .6346 .22017 .62625 .22432 Mtetra
.958 .935 .611 r
.62625 .22432 .6346 .22017 .65143 .18828 .64315 .188 Mtetra
.948 .956 .722 r
.64315 .188 .65143 .18828 .66848 .16495 .6602 .16038 Mtetra
.898 .936 .829 r
.6602 .16038 .66848 .16495 .6858 .14831 .67751 .14057 Mtetra
.823 .88 .886 r
.67751 .14057 .6858 .14831 .70338 .13602 .6951 .12626 Mtetra
.758 .826 .905 r
.6951 .12626 .70338 .13602 .72117 .12629 .71292 .11532 Mtetra
.716 .789 .909 r
.71292 .11532 .72117 .12629 .73914 .11796 .73094 .10629 Mtetra
.692 .767 .91 r
.73094 .10629 .73914 .11796 .75726 .11038 .74913 .0983 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50038 Mtetra
.20018 .50038 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49955 .23287 .48953 Mtetra
.23287 .48953 .24392 .49955 .26036 .49413 .24937 .48405 Mtetra
.24937 .48405 .26036 .49413 .2769 .48869 .26597 .47854 Mtetra
.26597 .47854 .2769 .48869 .29354 .48321 .28268 .473 Mtetra
.28268 .473 .29354 .48321 .3103 .47769 .2995 .46742 Mtetra
.2995 .46742 .3103 .47769 .32716 .47214 .31642 .4618 Mtetra
.31642 .4618 .32716 .47214 .34412 .46654 .33346 .45614 Mtetra
.646 .763 .934 r
.33346 .45614 .34412 .46654 .3612 .46091 .3506 .45044 Mtetra
.3506 .45044 .3612 .46091 .37839 .45523 .36786 .4447 Mtetra
.647 .763 .934 r
.36786 .4447 .37839 .45523 .39568 .44949 .38523 .4389 Mtetra
.38523 .4389 .39568 .44949 .4131 .44367 .40271 .43304 Mtetra
.649 .764 .933 r
.40271 .43304 .4131 .44367 .43062 .43774 .4203 .42708 Mtetra
.652 .766 .933 r
.4203 .42708 .43062 .43774 .44826 .43162 .43802 .42098 Mtetra
.657 .77 .933 r
.43802 .42098 .44826 .43162 .46602 .42519 .45585 .41464 Mtetra
.666 .776 .932 r
.45585 .41464 .46602 .42519 .4839 .41819 .4738 .40787 Mtetra
.683 .788 .929 r
.4738 .40787 .4839 .41819 .50189 .41017 .49187 .40034 Mtetra
.713 .808 .924 r
.49187 .40034 .50189 .41017 .51998 .40032 .51005 .39143 Mtetra
.762 .84 .911 r
.51005 .39143 .51998 .40032 .53812 .38726 .52832 .38008 Mtetra
.831 .882 .88 r
.52832 .38008 .53812 .38726 .55626 .36894 .54661 .36456 Mtetra
.906 .921 .817 r
.54661 .36456 .55626 .36894 .57426 .34297 .56484 .34254 Mtetra
.958 .937 .72 r
.56484 .34254 .57426 .34297 .59196 .3081 .58285 .31194 Mtetra
.971 .927 .622 r
.58285 .31194 .59196 .3081 .60926 .26651 .60049 .27296 Mtetra
.963 .916 .565 r
.60049 .27296 .60926 .26651 .62625 .22432 .61775 .22997 Mtetra
.958 .923 .577 r
.61775 .22997 .62625 .22432 .64315 .188 .63478 .1899 Mtetra
.956 .948 .662 r
.63478 .1899 .64315 .188 .6602 .16038 .65186 .15769 Mtetra
.929 .952 .781 r
.65186 .15769 .6602 .16038 .67751 .14057 .66917 .13409 Mtetra
.861 .91 .864 r
.66917 .13409 .67751 .14057 .6951 .12626 .68675 .11721 Mtetra
.788 .852 .899 r
.68675 .11721 .6951 .12626 .71292 .11532 .70459 .1047 Mtetra
.734 .806 .908 r
.70459 .1047 .71292 .11532 .73094 .10629 .72265 .09475 Mtetra
.702 .777 .91 r
.72265 .09475 .73094 .10629 .74913 .0983 .7409 .08621 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50038 .18889 .49037 Mtetra
.18889 .49037 .20018 .50038 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48953 .2217 .47939 Mtetra
.2217 .47939 .23287 .48953 .24937 .48405 .23826 .47385 Mtetra
.23826 .47385 .24937 .48405 .26597 .47854 .25492 .46828 Mtetra
.25492 .46828 .26597 .47854 .28268 .473 .27169 .46267 Mtetra
.27169 .46267 .28268 .473 .2995 .46742 .28858 .45702 Mtetra
.28858 .45702 .2995 .46742 .31642 .4618 .30557 .45133 Mtetra
.30557 .45133 .31642 .4618 .33346 .45614 .32267 .44561 Mtetra
.646 .763 .934 r
.32267 .44561 .33346 .45614 .3506 .45044 .33988 .43985 Mtetra
.33988 .43985 .3506 .45044 .36786 .4447 .3572 .43404 Mtetra
.3572 .43404 .36786 .4447 .38523 .4389 .37464 .42818 Mtetra
.647 .763 .934 r
.37464 .42818 .38523 .4389 .40271 .43304 .39219 .42227 Mtetra
.648 .764 .934 r
.39219 .42227 .40271 .43304 .4203 .42708 .40986 .41627 Mtetra
.65 .765 .933 r
.40986 .41627 .4203 .42708 .43802 .42098 .42765 .41016 Mtetra
.654 .768 .933 r
.42765 .41016 .43802 .42098 .45585 .41464 .44556 .40386 Mtetra
.661 .772 .932 r
.44556 .40386 .45585 .41464 .4738 .40787 .46358 .39724 Mtetra
.673 .781 .931 r
.46358 .39724 .4738 .40787 .49187 .40034 .48173 .39005 Mtetra
.696 .796 .927 r
.48173 .39005 .49187 .40034 .51005 .39143 .5 .38183 Mtetra
.735 .822 .919 r
.5 .38183 .51005 .39143 .52832 .38008 .51836 .37176 Mtetra
.794 .86 .899 r
.51836 .37176 .52832 .38008 .54661 .36456 .5368 .35846 Mtetra
.87 .904 .853 r
.5368 .35846 .54661 .36456 .56484 .34254 .55522 .33987 Mtetra
.937 .933 .771 r
.55522 .33987 .56484 .34254 .58285 .31194 .57351 .31358 Mtetra
.969 .934 .669 r
.57351 .31358 .58285 .31194 .60049 .27296 .59149 .27833 Mtetra
.968 .92 .586 r
.59149 .27833 .60049 .27296 .61775 .22997 .60906 .23635 Mtetra
.959 .916 .561 r
.60906 .23635 .61775 .22997 .63478 .1899 .6263 .19378 Mtetra
.958 .935 .612 r
.6263 .19378 .63478 .1899 .65186 .15769 .64346 .15711 Mtetra
.948 .955 .722 r
.64346 .15711 .65186 .15769 .66917 .13409 .66077 .12918 Mtetra
.898 .936 .83 r
.66077 .12918 .66917 .13409 .68675 .11721 .67835 .10912 Mtetra
.823 .88 .886 r
.67835 .10912 .68675 .11721 .70459 .1047 .6962 .09457 Mtetra
.758 .826 .905 r
.6962 .09457 .70459 .1047 .72265 .09475 .71429 .08341 Mtetra
.716 .789 .909 r
.71429 .08341 .72265 .09475 .7409 .08621 .73259 .07417 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47385 .22701 .46353 Mtetra
.22701 .46353 .23826 .47385 .25492 .46828 .24374 .45789 Mtetra
.24374 .45789 .25492 .46828 .27169 .46267 .26058 .45221 Mtetra
.26058 .45221 .27169 .46267 .28858 .45702 .27752 .4465 Mtetra
.27752 .4465 .28858 .45702 .30557 .45133 .29458 .44075 Mtetra
.29458 .44075 .30557 .45133 .32267 .44561 .31174 .43495 Mtetra
.31174 .43495 .32267 .44561 .33988 .43985 .32902 .42912 Mtetra
.646 .763 .934 r
.32902 .42912 .33988 .43985 .3572 .43404 .34642 .42325 Mtetra
.34642 .42325 .3572 .43404 .37464 .42818 .36393 .41733 Mtetra
.647 .763 .934 r
.36393 .41733 .37464 .42818 .39219 .42227 .38155 .41135 Mtetra
.38155 .41135 .39219 .42227 .40986 .41627 .39929 .40531 Mtetra
.649 .764 .933 r
.39929 .40531 .40986 .41627 .42765 .41016 .41715 .39917 Mtetra
.652 .766 .933 r
.41715 .39917 .42765 .41016 .44556 .40386 .43513 .39288 Mtetra
.657 .77 .933 r
.43513 .39288 .44556 .40386 .46358 .39724 .45324 .38634 Mtetra
.666 .776 .932 r
.45324 .38634 .46358 .39724 .48173 .39005 .47146 .37938 Mtetra
.683 .788 .929 r
.47146 .37938 .48173 .39005 .5 .38183 .48981 .37165 Mtetra
.713 .808 .924 r
.48981 .37165 .5 .38183 .51836 .37176 .50827 .36253 Mtetra
.762 .84 .911 r
.50827 .36253 .51836 .37176 .5368 .35846 .52682 .35095 Mtetra
.831 .882 .88 r
.52682 .35095 .5368 .35846 .55522 .33987 .54541 .33517 Mtetra
.906 .922 .816 r
.54541 .33517 .55522 .33987 .57351 .31358 .56393 .31286 Mtetra
.958 .937 .72 r
.56393 .31286 .57351 .31358 .59149 .27833 .58223 .28191 Mtetra
.971 .927 .622 r
.58223 .28191 .59149 .27833 .60906 .23635 .60015 .24254 Mtetra
.963 .916 .565 r
.60015 .24254 .60906 .23635 .6263 .19378 .61767 .19914 Mtetra
.958 .924 .577 r
.61767 .19914 .6263 .19378 .64346 .15711 .63497 .1587 Mtetra
.956 .948 .663 r
.63497 .1587 .64346 .15711 .66077 .12918 .65231 .12616 Mtetra
.929 .952 .781 r
.65231 .12616 .66077 .12918 .67835 .10912 .66988 .10228 Mtetra
.861 .91 .864 r
.66988 .10228 .67835 .10912 .6962 .09457 .68773 .08515 Mtetra
.788 .851 .899 r
.68773 .08515 .6962 .09457 .71429 .08341 .70585 .07241 Mtetra
.734 .806 .908 r
.70585 .07241 .71429 .08341 .73259 .07417 .72419 .06224 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45789 .23242 .44738 Mtetra
.23242 .44738 .24374 .45789 .26058 .45221 .24932 .44164 Mtetra
.24932 .44164 .26058 .45221 .27752 .4465 .26633 .43585 Mtetra
.26633 .43585 .27752 .4465 .29458 .44075 .28346 .43003 Mtetra
.28346 .43003 .29458 .44075 .31174 .43495 .30069 .42417 Mtetra
.30069 .42417 .31174 .43495 .32902 .42912 .31804 .41827 Mtetra
.646 .763 .934 r
.31804 .41827 .32902 .42912 .34642 .42325 .3355 .41232 Mtetra
.3355 .41232 .34642 .42325 .36393 .41733 .35308 .40634 Mtetra
.35308 .40634 .36393 .41733 .38155 .41135 .37078 .4003 Mtetra
.647 .763 .934 r
.37078 .4003 .38155 .41135 .39929 .40531 .38859 .3942 Mtetra
.648 .764 .934 r
.38859 .3942 .39929 .40531 .41715 .39917 .40652 .38801 Mtetra
.65 .765 .933 r
.40652 .38801 .41715 .39917 .43513 .39288 .42458 .38171 Mtetra
.654 .768 .933 r
.42458 .38171 .43513 .39288 .45324 .38634 .44276 .37522 Mtetra
.661 .772 .932 r
.44276 .37522 .45324 .38634 .47146 .37938 .46106 .3684 Mtetra
.673 .781 .931 r
.46106 .3684 .47146 .37938 .48981 .37165 .47949 .36101 Mtetra
.696 .796 .927 r
.47949 .36101 .48981 .37165 .50827 .36253 .49804 .35258 Mtetra
.735 .822 .919 r
.49804 .35258 .50827 .36253 .52682 .35095 .5167 .34229 Mtetra
.794 .86 .899 r
.5167 .34229 .52682 .35095 .54541 .33517 .53543 .32874 Mtetra
.87 .904 .853 r
.53543 .32874 .54541 .33517 .56393 .31286 .55414 .30987 Mtetra
.937 .933 .771 r
.55414 .30987 .56393 .31286 .58223 .28191 .57272 .28325 Mtetra
.969 .934 .668 r
.57272 .28325 .58223 .28191 .60015 .24254 .59099 .24763 Mtetra
.968 .92 .586 r
.59099 .24763 .60015 .24254 .61767 .19914 .60885 .20524 Mtetra
.959 .916 .561 r
.60885 .20524 .61767 .19914 .63497 .1587 .62636 .16227 Mtetra
.958 .935 .612 r
.62636 .16227 .63497 .1587 .65231 .12616 .64378 .12526 Mtetra
.948 .955 .723 r
.64378 .12526 .65231 .12616 .66988 .10228 .66136 .09703 Mtetra
.898 .935 .83 r
.66136 .09703 .66988 .10228 .68773 .08515 .6792 .07669 Mtetra
.823 .88 .886 r
.6792 .07669 .68773 .08515 .70585 .07241 .69733 .0619 Mtetra
.758 .826 .905 r
.69733 .0619 .70585 .07241 .72419 .06224 .7157 .05051 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45397 Mtetra
.17073 .45397 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44738 .22097 .43674 Mtetra
.22097 .43674 .23242 .44738 .24932 .44164 .23793 .43093 Mtetra
.23793 .43093 .24932 .44164 .26633 .43585 .25501 .42508 Mtetra
.25501 .42508 .26633 .43585 .28346 .43003 .2722 .41918 Mtetra
.2722 .41918 .28346 .43003 .30069 .42417 .2895 .41325 Mtetra
.2895 .41325 .30069 .42417 .31804 .41827 .30692 .40728 Mtetra
.30692 .40728 .31804 .41827 .3355 .41232 .32445 .40126 Mtetra
.646 .763 .934 r
.32445 .40126 .3355 .41232 .35308 .40634 .3421 .39521 Mtetra
.3421 .39521 .35308 .40634 .37078 .4003 .35987 .3891 Mtetra
.647 .763 .934 r
.35987 .3891 .37078 .4003 .38859 .3942 .37776 .38294 Mtetra
.37776 .38294 .38859 .3942 .40652 .38801 .39577 .3767 Mtetra
.649 .764 .933 r
.39577 .3767 .40652 .38801 .42458 .38171 .4139 .37037 Mtetra
.652 .766 .933 r
.4139 .37037 .42458 .38171 .44276 .37522 .43215 .36388 Mtetra
.657 .77 .933 r
.43215 .36388 .44276 .37522 .46106 .3684 .45054 .35715 Mtetra
.666 .776 .932 r
.45054 .35715 .46106 .3684 .47949 .36101 .46905 .34998 Mtetra
.683 .788 .929 r
.46905 .34998 .47949 .36101 .49804 .35258 .48768 .34204 Mtetra
.713 .808 .924 r
.48768 .34204 .49804 .35258 .5167 .34229 .50643 .33271 Mtetra
.762 .84 .911 r
.50643 .33271 .5167 .34229 .53543 .32874 .52528 .32088 Mtetra
.831 .883 .88 r
.52528 .32088 .53543 .32874 .55414 .30987 .54417 .30484 Mtetra
.907 .922 .816 r
.54417 .30484 .55414 .30987 .57272 .28325 .56299 .28222 Mtetra
.958 .937 .72 r
.56299 .28222 .57272 .28325 .59099 .24763 .58158 .25091 Mtetra
.971 .927 .622 r
.58158 .25091 .59099 .24763 .60885 .20524 .59979 .21114 Mtetra
.963 .916 .565 r
.59979 .21114 .60885 .20524 .62636 .16227 .61759 .16734 Mtetra
.958 .924 .577 r
.61759 .16734 .62636 .16227 .64378 .12526 .63516 .12652 Mtetra
.956 .948 .663 r
.63516 .12652 .64378 .12526 .66136 .09703 .65278 .09366 Mtetra
.929 .951 .781 r
.65278 .09366 .66136 .09703 .6792 .07669 .67061 .06949 Mtetra
.861 .91 .864 r
.67061 .06949 .6792 .07669 .69733 .0619 .68874 .0521 Mtetra
.788 .851 .899 r
.68874 .0521 .69733 .0619 .7157 .05051 .70714 .03912 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45397 .15895 .44341 Mtetra
.15895 .44341 .17073 .45397 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43183 Mtetra
.19246 .43183 .20411 .44252 .22097 .43674 .20938 .42598 Mtetra
.20938 .42598 .22097 .43674 .23793 .43093 .22641 .42009 Mtetra
.22641 .42009 .23793 .43093 .25501 .42508 .24355 .41417 Mtetra
.24355 .41417 .25501 .42508 .2722 .41918 .26081 .4082 Mtetra
.26081 .4082 .2722 .41918 .2895 .41325 .27818 .4022 Mtetra
.27818 .4022 .2895 .41325 .30692 .40728 .29566 .39615 Mtetra
.29566 .39615 .30692 .40728 .32445 .40126 .31327 .39007 Mtetra
.646 .763 .934 r
.31327 .39007 .32445 .40126 .3421 .39521 .33099 .38394 Mtetra
.33099 .38394 .3421 .39521 .35987 .3891 .34883 .37776 Mtetra
.34883 .37776 .35987 .3891 .37776 .38294 .36679 .37153 Mtetra
.647 .763 .934 r
.36679 .37153 .37776 .38294 .39577 .3767 .38487 .36523 Mtetra
.648 .764 .934 r
.38487 .36523 .39577 .3767 .4139 .37037 .40308 .35885 Mtetra
.65 .765 .933 r
.40308 .35885 .4139 .37037 .43215 .36388 .42142 .35235 Mtetra
.654 .768 .933 r
.42142 .35235 .43215 .36388 .45054 .35715 .43988 .34566 Mtetra
.661 .772 .932 r
.43988 .34566 .45054 .35715 .46905 .34998 .45847 .33864 Mtetra
.673 .781 .931 r
.45847 .33864 .46905 .34998 .48768 .34204 .47718 .33103 Mtetra
.696 .797 .927 r
.47718 .33103 .48768 .34204 .50643 .33271 .49603 .32238 Mtetra
.735 .822 .919 r
.49603 .32238 .50643 .33271 .52528 .32088 .51498 .31186 Mtetra
.794 .861 .899 r
.51498 .31186 .52528 .32088 .54417 .30484 .53401 .29806 Mtetra
.87 .904 .853 r
.53401 .29806 .54417 .30484 .56299 .28222 .55303 .27889 Mtetra
.937 .933 .771 r
.55303 .27889 .56299 .28222 .58158 .25091 .57192 .25194 Mtetra
.969 .934 .668 r
.57192 .25194 .58158 .25091 .59979 .21114 .59049 .21594 Mtetra
.968 .92 .586 r
.59049 .21594 .59979 .21114 .61759 .16734 .60863 .17314 Mtetra
.959 .916 .561 r
.60863 .17314 .61759 .16734 .63516 .12652 .62642 .12978 Mtetra
.958 .935 .612 r
.62642 .12978 .63516 .12652 .65278 .09366 .64412 .0924 Mtetra
.948 .955 .723 r
.64412 .0924 .65278 .09366 .67061 .06949 .66197 .06387 Mtetra
.898 .935 .83 r
.66197 .06387 .67061 .06949 .68874 .0521 .68009 .04326 Mtetra
.823 .88 .886 r
.68009 .04326 .68874 .0521 .70714 .03912 .6985 .02822 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43183 .18066 .421 Mtetra
.18066 .421 .19246 .43183 .20938 .42598 .19765 .41508 Mtetra
.19765 .41508 .20938 .42598 .22641 .42009 .21474 .40913 Mtetra
.21474 .40913 .22641 .42009 .24355 .41417 .23195 .40313 Mtetra
.23195 .40313 .24355 .41417 .26081 .4082 .24927 .39709 Mtetra
.24927 .39709 .26081 .4082 .27818 .4022 .26671 .39101 Mtetra
.26671 .39101 .27818 .4022 .29566 .39615 .28427 .38489 Mtetra
.28427 .38489 .29566 .39615 .31327 .39007 .30194 .37873 Mtetra
.30194 .37873 .31327 .39007 .33099 .38394 .31974 .37253 Mtetra
.646 .763 .934 r
.31974 .37253 .33099 .38394 .34883 .37776 .33765 .36627 Mtetra
.33765 .36627 .34883 .37776 .36679 .37153 .35569 .35997 Mtetra
.647 .763 .934 r
.35569 .35997 .36679 .37153 .38487 .36523 .37384 .35361 Mtetra
.37384 .35361 .38487 .36523 .40308 .35885 .39213 .34717 Mtetra
.649 .764 .933 r
.39213 .34717 .40308 .35885 .42142 .35235 .41054 .34064 Mtetra
.652 .766 .933 r
.41054 .34064 .42142 .35235 .43988 .34566 .42908 .33395 Mtetra
.657 .77 .933 r
.42908 .33395 .43988 .34566 .45847 .33864 .44775 .32701 Mtetra
.666 .776 .932 r
.44775 .32701 .45847 .33864 .47718 .33103 .46655 .31963 Mtetra
.683 .788 .929 r
.46655 .31963 .47718 .33103 .49603 .32238 .48548 .31147 Mtetra
.713 .808 .924 r
.48548 .31147 .49603 .32238 .51498 .31186 .50454 .3019 Mtetra
.762 .84 .911 r
.50454 .3019 .51498 .31186 .53401 .29806 .52369 .28983 Mtetra
.831 .883 .88 r
.52369 .28983 .53401 .29806 .55303 .27889 .54288 .27351 Mtetra
.907 .922 .816 r
.54288 .27351 .55303 .27889 .57192 .25194 .56201 .25057 Mtetra
.958 .937 .72 r
.56201 .25057 .57192 .25194 .59049 .21594 .58092 .2189 Mtetra
.971 .927 .622 r
.58092 .2189 .59049 .21594 .60863 .17314 .59943 .17873 Mtetra
.963 .915 .565 r
.59943 .17873 .60863 .17314 .62642 .12978 .61751 .13453 Mtetra
.958 .924 .578 r
.61751 .13453 .62642 .12978 .64412 .0924 .63536 .09333 Mtetra
.957 .948 .664 r
.63536 .09333 .64412 .0924 .66197 .06387 .65325 .06013 Mtetra
.929 .951 .781 r
.65325 .06013 .66197 .06387 .68009 .04326 .67137 .03567 Mtetra
.861 .909 .864 r
.67137 .03567 .68009 .04326 .6985 .02822 .68978 .01802 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001oogooOol0
07oo0000Egoo003EOol30008Ool200000goo001oo`1EOol00=9oo`<000]oo`04001oogoo001FOol0
0=1oo`8000eoo`03Ki/007oo009oo`03001oogoo05=oo`00cGoo0`003Woo00A_Vf^J001[VP=oo`03
001oogoo059oo`00bgoo0P0047oo00I_Vf^KKi/006nKJi/2Ool00`00Oomoo`1BOol00<Qoo`<00003
Ool007oo00ioo`08Ki][VVnKJiY_V`00JiaWN`9oo`03001oogoo055oo`00Igoo0P000Woo0P00FGoo
0P0017oo00<007ooOol037oo00M_Vf^KKi][VVnKIg/00002Ig/3Ool00`00Oomoo`1@Ool006Qoo`04
001oogoo001GOol3000DOol02gOHLkM_Vf^JKi]WNf^L001[O6MkJi`00Woo00<007ooOol0D7oo001Y
Ool2001FOol2000GOol00gNhMmQc^004Ig/00`00Ig]WN`02He`2Ool00`00Oomoo`1?Ool006Uoo`80
05=oo`<001Qoo`0>LkMgf7>hLkY_VF^LIg][O000JiaSFf=LHe]WO09oo`03001oogoo04ioo`00J7oo
00@007ooOol0051oo`8001Yoo`07MkQgf7>hLkYc^G>jKkT00VMk00<006=LHe`016=L00=oo`00Ool0
Cgoo001WOol20002Ool2001<Ool3000KOol057>gMmQc^7OHKiUc^VniLkY_VFMl001SG6=KIgaSFf=L
Gc]SG7oo001?Ool00;Ioo`<0009oo`03001oogoo01Uoo`0;MmQc^7NhLkUc^VniLkYc^FnKJiX00003
He`2Gc`015mLGc`00000Cgoo002dOol2000POol05WOHLkQgf6nILkY_^G>jKiU_Vf^JKi/006MlHe]S
G5lkHeaO?6=LGc]oo`00CWoo002aOol3000ROol037NdNkAc^G>jKkUc^W>iKi][VVnKJi/000=O?005
GeaO?5llGcaOG002Ool00`00Oomoo`1;Ool00:moo`8002Aoo`0HMkAke7NfNmM_^G>jKiU_Vf^JKi][
VVnK001[O5lkHeaO?6=LGc]SG5/LGcaoo`004Goo1@00=goo002/Ool3000VOol03G^dMkAgeWNfMmIg
]VnKJiY_Vf^KKi]WN`00009WN`AO?0=K?09oo`03001oogoo00ioo`05001oogooOol0000gOol00:Yo
o`8002Qoo`0HNmAg]7_GMkIkeWNfMmQc^6nKJiY[W6MkJg`006^LIg][O5/LGcaK75llFaaO?5/L0Woo
00<007ooOol03Woo00<007ooOol0>7oo002WOol30002Ool00`00Oomoo`0UOol01gNdNkAg]WOFMkIg
eW>h009g^0AWN`03001WNfMk009SG0=K?006GcaK?5/LFaaoo`001goo1P0017oo00<007ooOol0=goo
002UOol2000/Ool05WNdNmEg]W_FMkIkeg>hMmQc]g>jKkU[O6MkJi`006=LHe]WO6=KGcaK75ll0U/L
00EG75/lFaaoo`00015oo`03001oogoo03Ioo`00XWoo0`00;Woo00Ik]7NfMmIg]WOFLkP2MkP01g>j
KkUc^W>iLkYSG00000ESG0MK709oo`03001oogoo00moo`03001oogoo03Eoo`00MGoo10009goo0P00
<7oo01UkeGNdNmIg]W_GLkQgf7>gMmQ_^G>jKiUc^V^JKi/006MlHe]SG6=KHeaO?5/LEaaK?002Fa`0
15LLFcaoo`003Goo00D007ooOomoo`0003Moo`00M7oo00<007ooOol00Woo00<007ooOol08Goo0`00
<Woo00Eg]7OFMkIgeWNf009g^009MmQ_^G>jLkUc^V^JKi][V`00009SG003GcaOG5ll009O?0EK709G
7003Ool007oo00aoo`<003Qoo`00M7oo00<007ooOol00Woo00<007ooOol07Woo0`00=7oo029gTG^b
Mi9k/gNbMmQc]gOHKkUc^VnILkY[VVnKJiY_Vf^J001O>f=LGcaSG5lkHeaO?5/LE_aK75KlFaaFo000
Ool004Moo`00M7oo00<007ooOol00Woo00<007ooOol077oo0P000Woo00<007ooOol0<Woo01=k/G^b
Nk=g/W^dMkAk]6niLkYc^G>jJiY_Vf^KKi][VVMk001OG003Gc`01EmLFcaK?5/lFa`00eLL00AK75LL
Ool004Moo`00M7oo00<007ooOol00Woo00<007ooOol06Goo0`00>7oo02Ak/WNANk=g/W^cMkAkeGNf
NmIg]W_GJiY_Vf^JKi][VV]lIg/005llHeaO>ellFaaO?5/LGcaFo5/LE_aK75KlEaaFo7oo0016Ool0
07Aoo`03001oogoo009oo`03001oogoo01Moo`8003]oo`0>Ni5k/gNbNk=g]7^dMkAgeWNfMmIc^7Nh
Ji]_V`AWN`04001WNe/lGc`3Fc`02EllFcaK?5KlEaaFo5LLE_aG7002Ool00`00Oomoo`13Ool007Ao
o`03001oogoo009oo`03001oogoo01Aoo`<003aoo`0VMi5k/WNbNk=gTW_EMkAkeWNfNmMg]WOHLkMg
f6MkJgaWNf^LIg/006=KIgaK75llFaaO?5/LGcaG75/lE_aG75KlFaaFo5LLOol004Eoo`00MGoo1000
5Goo0P00?goo00Yk/WNbNk=k/W^dMkAk]7NfMmIg]P9g^003MmQ_^G>j00=WN`03He`006=L009SG003
FcaO?5/l00AK7005EaaFo5LLE_aG7002E_`00goo001oo`13Ool008]oo`<0041oo`0INk9gTG^cMi9k
/gNdNmAg]W_GMkIgf7>gMmQ_^G>jKiUc^V=KHgaSF`00He]SO6=KIg`00U/L00iG75/lFaaK75LLFaaF
o5LLD_aG75KlEaaoo`00@goo0029Ool20002Ool00`00Oomoo`0nOol02GNANk=k/W^cMkAk]7NfMmIg
]P02MkP01gOHLkQc^W>iLkY[VVnK009SG004001SG6=LHe`2Gc`6Fa`7E_`00goo001oo`12Ool008Io
o`<004Aoo`0LMi5k/WNBNk=g/W_DMkAkegNfNmIc]gOHLkQc^VnILkY[VVnKJiY_Vf=K001SFf=LGcaS
G5lkFc`2Fa`03ELLFaaFo5/LD_aG75KlEaaBo5LLE_aoo`00049oo`00Q7oo0P00Agoo01Mk/G^bNk=g
/W^dMkAgeWNfMmIg^7OHLkQc^W>iLkY[VVnKJi]_Vf^JKi/005mL00=O?005GeaO?5LLEaaK7003Ea`0
0e/LE_aFo002E_`01E;lE_aFo7oo0000@Goo0021Ool30018Ool06g^bMi5k/GNANk5gTG^bMk9k/gNd
NmEg]7>jKiUc^V^JKi][VVnKJiY_VfMk001O?6=LGc]SG002Gc`2Fa`03UKlFaaFo5/LE_aK75;lEaaB
o5KlD_aG77oo0011Ool007ioo`<004]oo`9kT@0BMi5kTG^ANk9g/W^cNk9k]7NdMmIg]WOFJiY_Vf^K
Ki][VVnK0VMk00@005llGcaOG0=K?005GcaG75LLEaaK7002Ea`00eKlEaaBo003E_`015;lE_aoo`00
@7oo001lOol2001>Ool09G^aMi5k/GN@Nk9gTG^cMi9keGNdNmAg]W_FLkQgf6^JKi][VV]lIg][W6Mk
001WNellFaaO?5/LGcaK75llE_aK75KlEaaFo5/L009Fo008D_aG75;lE_aBo5KlOol003moo`00NGoo
0`000Woo0P00Bgoo17^A00Yk/WNANk=k/W^cMkAk]7NfMmIg]P9g^003MmQc^6Mk00AWN`03001SG6=L
009K?003GcaK?5/l009K7006E_aG75KlEaaFo5LL0UKl00MBo5KlD_aFo5;lOol0000oOol007Moo`80
059oo`0LMi5k/GN@Nk5gTG^bMi9k/gNdNmAg]7_FMkIgf7>gMmQc^7>jKiU[W6MkJgaSF`00He]SO5/L
Gc`2Fa`02ULLFcaK75/LE_aK75KlEaaBo5LL0UKl00MBo5KlD_aFo5;lOol0000nOol007Aoo`<005=o
o`AkT@09Mi5k/G^bNk=g/W^dMkAgeWNf009g^006MmQc^7>jLkUc^Vni0f=L00@006=LHeaSG0QK70IF
o006D_aFo5;lE_aBo5Kl0Woo00<007ooOol0>goo001bOol2001FOol07g^aMi5k/GNANk9gTG^cMk9k
e7NdNmIg]WOHLkMgf7>hMmQ_VG>jKkU_Vf^JIgaSF`00He]WO5llHeaG75/l009K700BEaaK?5KlFaaB
o5LLE_aG75;lEaaBo5KlD_aFo5;lE_aoo`00?Goo001_Ool3001GOol3Ni4057NANi5kTG^cMk9k/gNd
NkAg]WOFMkQgf7>hMkQc^G>jKkU_Vf^KKi/3He`01@00GcaO?5llGe`015/L0eLL1UKl0U;l00AFo5;l
D_aBo09oo`03001oogoo03Yoo`00KGoo0P0000=oo`00Ool0Egoo03=gTG^aMi5k/GNANk9g/W^cMkAk
eGNfNmIc]gOHLkQgf6nILkY_^FnKJiY_Vf^JKi]O>f=L001SG5lkHeaO?6=LE_aK75KlFaaFo5/LE_aG
75;lEaaBo5KlD_aFo5;lE_aBg5KlD_`00Woo00<007ooOol0>Goo001ZOol3001KOol2Ni401GNANi5k
TG^bMi400W^A00mk/WNANk=k/W^dMkAk]7>iLkY_^FnKJi]_Vf^JKi/00VMk00EO?000GcaOG5ll009K
?005GcaG75LLEaaK7002Ea`2E_`015;lE_aFo5Kl0e;l00IFo5;lD_aBo7oo000kOol006Moo`<005io
o`0QNk5gTG^aMi1k/WNANk5gT7^bMi5k/gNBNmEg]7_DMkIkeWNfKi][VVnKJiY_VfMkJiaWNf]l001O
?5/LGcaK75ll009K700EE_aK75KlEaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD_aoo`0003Yo
o`00IGoo0P00H7oo2G^A00UgTG^aNk9k/gNdNkAg]7OFMkH00WNh00=_Vf^JIg/01FMk00D006=LFcaK
?5ll00=K?005EaaFo5LLE_aG7004E_`015;lE_aBo5Kl0e;l00EFo5;lD_aBo00003Yoo`00HWoo0`00
HWoo02YgTG^aMi5k/W^ANk5gT7^aMi5k/WNBNk=g]7_DMkAkeWNfNmIc]gOHLkQ[O6MkJiaWNf]lIg]W
O000HgaK75llFaaO?5LLFcaK75LLE_aK75KlEa`2E_`03U;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;L
000iOol0061oo`8006Aoo`9kT@03Nk=k/W^B00=kT@0?Mi5k/G^ANk=g/W^dMkAk]7NfMmIg^7OHLkQc
^W>i00=WN`=SG003001SG6=L00IK7004E_aG75KlEa`4E_`01U;lE_aBo5KlD_aFo0=Bo005E_aBo5;l
Ool0000hOol005eoo`<00003Ool007oo06=oo`0SNk=kTW^bNi5k/WNANk5gTG^aMi5k/gNbNmAg]7_E
MkIkeW>gMmQc^7>jKiUc^VniLkYSFfMlHe]SO000IgaO?6=LEaaK?002Fa`05eLLFcaFo5LLD_aG75Kl
EaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5Kl0000>7oo001KOol2001YOol2Nk<2Ni82Ni4057NA
Ni5kTG^bMk9k/gNdNkAg]WOFMkQgf7>hMkQc^G>jKkUc^V^KKi/3He`01000GcaO?5ll1E/L0ULL1eKl
0U;l00EFo5;lD_aBo5Kl00=Bo004E_aBo7oo000gOol002ioo`@002Ioo`<006Yoo`0oNi9k/g^ANk9g
TG^aMi5k/GN@Nk9g/W^cMkAkeGNdNmIg]WOHLkQgf6nILkY_^G>jJiY_Vf^JKi]O>f=L001SG5lkHeaO
?5/LE_aK75KlFaaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aoo`00029o
o`<0015oo`00;Goo00<007ooOol00Woo00<007ooOol08Goo0P00KGoo00Ek/g^CNi9kTW^b00=kT@0J
Nk9gTG^cNk9k]7NdMmIg]WOHLkQg^7>iLkY_^G>jJi]_Vf^JKi]WNfMlGc`005llGeaO?09K?005FaaG
75LLEaaK7002Ea`2E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00=oo`00Ool08goo00<007ooOol0
3goo000bOol00`00Oomoo`0MOol4001^Ool09G^cNi=k/gNANk9gTG^aMi1k/GNANk5gT7^aMi5k/WNB
NmEg]7_DMkIkeVniLkY[VVnKJiY_VfMkJiaWNf=L001SG5/LGcaK75ll009K700JE_aK75KlEaaFo5/L
D_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlOol002=oo`03001oogoo00moo`009Goo
1P001goo00<007ooOol077oo0`00L7oo00EkTg^cNi9k/W^B00=kT@0AMi5kTG^ANi5gTG^aNk9k/gNd
NkAg]7OFMkIgeV^KKi][VP02Ig/01FMlIg]WNfMk00000e/l00UO?5/lFcaK?5LLE_aG75KlEa`015Kl
00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo003Ool007oo021oo`03001oo`00011oo`00;Woo100077oo
0`00LWoo02ikTg^cNi9k/W^ANk5gTG^aMi5k/GN@Nk5gTG^bMi5k/gNdNmAg]7_FMkIkeW>gMmQc^6]l
Ig][W6MkJgaWNfMl001O?5/LGcaK75llFaaK?5/LEaaFo5/LE_aG709Fo00CD_aFo5;lE_aBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg7oo00008Goo00<007oo000047oo000^Ool00`00Oomoo`0JOol3001e
Ool3Nk<2Ni82Ni4057NANi9kTG^AMi5k/G^ANk=g/W^dMkAk]7NfMmIg^7OHLkQc^W>iIg`2Ig/3He`0
0`00HeaO?002Fc`4Fa`015KlEaaFo5LL15Kl00IBo5KlD_aFo5;lE_`3D_`00eKlD_aBo005D_`2000O
Ool01@00Oomoogoo00003goo000^Ool00`00Oomoo`0HOol2001gOol09g^cNi9k/g^ANk9gTG^aNi5k
/WNANk5gTG^aMi5k/WNbNmAg]7_EMkIkeWNfMmQc^7>jKiUc^VniLkYSFfMlHe]SO000IgaSFe/LEaaK
?002Fa`07ELLFcaFo5LLD_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g7oo00007Woo00D007ooOomoo`0000moo`00;Woo1@004goo0`00NGoo0W^c00EkTg^BNi9k/g^C009k
TP0ENi5gTG^ANi5k/WNbNk=g]7^dMkIgeWNfMmQc^7NhLkUc^VniLkY[VfnK00=SG004001SG5llGc`5
Fa`2Ea`6E_`3D_`01EKlD_aBo5;lE_`00e;l00=Fo5;lD_`015;l00=oo`00Ool077oo0`0000Aoo`00
000000ioo`00A7oo0P00Ngoo04QkTW^cNi=k/WNANkEkTg^bMi5k/GNANk5gT7^bMi5k/gNdNmEg]7_F
MkIgf7>hMmQ_VG>jKkUc^V^JKk][VV=lHe]WO000HeaO>f=LGcaK75KlFaaFo5/LE_aG75KlEaaBo5LL
D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo7oo0009Ool4000TOol0045oo`<0
0003Ool007oo07Yoo`09Nk=kTg^cNkAk]G^CNk=kTW^b00AkT@0DMi5k/g^bNkAg]7OFMkIgf7>hMkQc
^G>jKkUc^V^KKi][VVnKJi]OG09O?003001OG5ll009K?006FaaG75LLEaaK75LL0eKl00ABo5KlE_aF
o0=Bo003E_aBo5;l00YBo004D]aBo7oo0007Ool00`00Oomoo`02Ool00`00Oomoo`0QOol003moo`80
07moo`1:NkIg]W^fMiIk]G^dNk=gTG^bNi5k/GN@Nk5gTG^bMi9k/WNANk9gTW_EMkAke6nILkY_^G>j
JiY_^f^JKi][VV^LIg]SG5lk001K75llFaaO?5KlFaaFo5/LE_aG75KlEaaBo5KlD_aG75;lE_aBg5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LOol000Moo`03001oogoo009oo`03001oogoo025o
o`00?7oo0`00PGoo00Eg]W^fNkIk]G^d009k/`03Nk9kTW^A009kT@0DMi5k/G^ANi5gTG^aNk9k/gNd
NkAg]WOFMkIgeV^KKi][VVnKIg]WO0=WN`05Gc`005/lFcaO?002Fc`01eKlEaaFo5LLE_aG75;l00=F
o004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01e;LD_aBo5;lD]aoo`0000Ioo`03001oogoo009oo`03
001oogoo025oo`00>Woo0P00Pgoo04Yg]W^fMiIk]W^dNkEkTW^cNi5k/WNANk5gTG^bMi5k/GNANk9g
TG^cMkAke7NdNmIg]W_FLkMgf7>hJgaWNf^LIg][O6MkIgaSF`00FaaO?5/LGcaG75/lE_aG75KlFaaF
o5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl0Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol08Goo000gOol30025Ool3NkH2Nk@2Nk<2Ni82Ni4057NA
Ni5kTG^AMi5k/G^ANk=g/W^dMkAgeWNfMmIg^7OHLkQc^W>iIg`2Ig/4He`00`00GcaK?004Fa`00eLL
E_aG7004E_`015;lE_aBo5Kl0e;l00EFo5;lD_aBo5Kl00QBo006D]aBo5;lD_aoo`001Goo00<007oo
Ool00Woo00<007ooOol08Goo000eOol200000goo001oo`24Ool0;G^fMiIk]WNfNkEkU7^cNi=k/WNA
Nk5kTG^bMi5k/GNANk5gTG^bMk9ke7NdNmEg]W_FMkIgf7>hLkY_VG>jKkUSO6=KIgaSFf=lHe/005/L
FcaG75/lFaaK?002Ea`015KlEaaBo5LL0UKl01MBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5;lD]aFo5;L009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo025oo`00<Woo
0`00RGoo0W^f00Eg]W^dNkAk/g^C009kTP06Ni5kTg^BNi9kTGNA0W^A011k/WNbNk=g]7^dMkIgeWNf
MmQc^7NhLkUc^VniKi][V`ESG003001O?5/L00=K7003EaaK75LL00MFo0=Bo005E_aBo5;lD_aFo00<
D_`00e;LD_aBo0030004Ool4000TOol002moo`<008]oo`1AMiIk]WNfNkIkU7^eNi=k/gNANk9kTg^b
Mi5k/WNANk5gT7^bMi5k/gNdNmEg]7_FMkIgf7>hMmQ_VG>jKkU_Vf^JKk][VV=lHe]SG5ll001O>f=L
GcaK75KlFaaFo5/LE_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aoo`0002aoo`00;Goo0P00SWoo00ek]WNfNkIk]7^eNi=k/g^BNk9k]7^cNi9k
/P03Ni405W^bMi5k/g^bNkAg]7OFMkIgf7>hMkQc^G>jKkUc^V^KKi][VVnKJi]OG5ll0P0000EOG5ll
FcaK?5/L00=G7003FaaG75Kl009Fo004D_aFo5KlE_`3D_`00eKlD_aBo00:D_`01U;LD_aBo5;lD]aB
o09oo`03001oogoo02Uoo`00:Woo0`00Sgoo02Ak]WNfNkIgUW^eNkAk/g^BNkEk]7^cMi5k/W^ANk5g
T7^aMi5k/WNBNk9gTG^bMi9keGNdNmA_VG>jKkUc^V^JKk][VVnKJiX30000:UlkHe`005llFaaO?5Kl
FaaFo5/LE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5;lD]aFo09oo`03001oogoo02Qoo`00:7oo0P0000=oo`00Ool0SWoo00Ic^G>ILkUcVG^eNk@3
NkH2Nk@017^cNk9kTW^B0W^A015gTG^aNi5kTGNANk5g/W^cMkAk]7NdMmIg]WOFJi]_Vf^J00<000=W
N`05GcaK?000FcaO?002Fc`01eKlEaaFo5LLE_aG75;l00=Fo004D_aFo5;lE_`3D_`00eKlD_aBo006
D_`01E;LD_aBo5;lD]`00e;l00ABg5;lOol002Yoo`009Woo0P00TWoo025c^G>ILkUcVGNhMiMk]WNF
NkIk]7^eNi9k/g^ANk9gTG^aMi5k/WNANk5gTG^bMi5k/gNdNmAg]7_FMkIkeW>gMmP00P00035WNf^L
Ig][O6MkIgaSFellFa`005/LGcaG75/lE_aG75KlFaaFo5LLD_aFo5;lE_aBo5KlD_aFo5;LE_aBo5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg002Ool00`00Oomoo`0WOol002Ioo`80095o
o`07LkUcVG>iLiUc^GNgMkP00W^f00Ag]W^dNkAk/`=kTP03Ni5gTG^A009kT@0:Mi5k/GNANk=g/W^d
MkAk]7NfMmH300000g>jLkUWO002Ig/4He`015/lGcaK?0000e/L00=G75KlEa`015Kl00QBo5KlD_aF
o5;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo004D]aoogoo000XOol002Ioo`<0
091oo`0LLiUc^G>ILkUgUgNhMiIk]WNfNkEkU7^cNi=k/WNANk5gTG^aMi5k/GNANk5gTG^bMk9ke7Nd
NmD300004gOHLkQc^VnILkY_^F=lHe]WO6=KHgaSFfMlFaaK?5LL001K75/l009G7004E_aG75;lEa`2
E_`07e;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aoo`0002Qoo`009Woo00@007ooOol008ioo`05LiUc^G>ILkUg]`02MkP01W^fMkIk]W^dNkEkT`9k
TP0;Nk9kTG^BNi9kTGNANi5gTG^bMk9k/`0300002WOFMkIgf7>hMkQc^G>jKkU_Vf^K16=L00=OG5ll
Gc`00U/L00D005/LEaaK75LL00MFo0=Bo005E_aBo5;lD_aFo00<D_`01E;LD_aBo5;lD]`00e;l0Woo
00<007ooOol09Goo000UOol00`00Oomoo`02Ool00`00Oomoo`2:Ool067>ILkUcVG>iMiMg^7>GNkIg
]W^fNiAk]G^CNk=gTG^bMi5k/gNANk9gTG^aMi1k/P<00011NmEg]7_FMkIgf7>hMmQ_VG>jKkU_Vf^J
Kk][VV=LGc]SG5llHeaO>f=LE_aK7000FaaFo5/LD_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol0000WOol002Eoo`03001o
ogoo00=oo`03001oogoo08Qoo`05LiUc^G>ILkUcV@02MkP03G^fMkIk]W^fNkEk]7^cNi9k/W^BNk=k
TW^b009kT@<0000@Nk=g/W^dMkAk]7NfMmQc^7NhLkUc^VniKi][VfnKJiX2Ig/01EmLGcaO?5llGe`0
0U/l00=G75/L00000ULL00=K75;lE_`00UKl00ABo5KlD_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;l
D_aBg003D_`01U;LD_aBo5;lOol002Ioo`009Goo00<007ooOol017oo00<007ooOol0QWoo01AWNf^K
LiUc^G>IMkQcUgNhMkIk]WNFNkEk]7^cNi9k]G^dNkEkTW^b0`0001]k/GNANk9gTW_EMkAke7NBNmEg
]7_DKiUc^VniKi][VVnkJiY[O6MkJiaO?6=LGc]O?5/LGc`00U/L02UFo5/L001K75KlEaaBo5LLD_aF
o5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aF
o5;L009oo`03001oogoo02=oo`009Goo0P001Woo0P00QGoo00EWNf]kIg][NfMk00=g^004MkIk]W^f
NkH2Nk@2NkH2Nk@017^c000007^B0W^A015gTG^aMk9kTGNANk5gTG^cMkAk]7NfMmIg]VnKJi]_Vf^J
009WN`05IgaWNfMkFcaO?003Fc`01ellFcaG75Kl001Fo5LL009Fo008D_aFo5KlE_aBo5KlD_aFo0=B
o003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool097oo000U
Ool00`00Oomoo`07Ool00`00Oomoo`21Ool04FMkJi]WNf^LIg]_Vf]jKi]cVG>iLiUc^GNGMkQgUW^f
Nk@00`0002QkTG^bMi5k/GNANk9gTG^aMi5k/WNANk=g]7_DMkAkeWNfMmQc]gOHLkQ[O6MkJiaWNf]l
He]WO5/LGcaK75llFaaK?5LLFaaFo000E_aK709Fo00UD_aFo5;lE_aBo5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000097oo000UOol00`00
Oomoo`08Ool00`00Oomoo`1oOol01FMkJg]WNf]kIg/016nJ00Ac^G>ILkUg]`9g^0<00003NkAk/g^C
009kTP03Ni5gTG^A009kT@0AMi5k/GNANk9g/W^dMkAgeWNfMmIg^7OHLkQc^W>iIgaWN`06He`6Fa`0
0eLLE_`00004E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L00=Bo006D]aBo5;l
D_aBg5;l0Woo00<007ooOol08Goo000UOol00`00Oomoo`09Ool00`00Oomoo`1mOol03FMkJi]WNf^L
Ig]_Vf]jKi][VW>iLiUc^G>I00<0000ZMkIk]G^DNkEkTg^bMi5k/GNANk5gTG^aMi5k/GNANk9g/W_D
MkAkeGNfNmIc]gOHLkQc^VnILkY_^F=lHe]WO6=KHgaSFf=LGcaK?5LLFcaK75/l0ULL02YFo000D_aG
75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo7oo000SOol002Aoo`8000aoo`03001oogoo07Yoo`06HeaOG5mLIg][NfMk16nJ
00=c^G>I00000P0000]g^7^fMkIk]W^dNkEkTg^cNi9k/W^A009kTP=kT@0AMi5k/WNANk=g]7^dMkIg
eWNhMmQc^7NhLkUc^VniKi][V`03He`015llGeaO?5ll15/L00EG75/LEaaFo00000=Fo003D_aFo5;l
009Bo005E_aBo5;lD_aFo008D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo
000ROol002Aoo`03001oogoo00aoo`03001oogoo07Moo`0;GcaSGEmLHeaO?6=MGea_Vf]jKi][VP03
0000Fg>IMkQcUgNhMkIk]W^DNkEk]7^cMi5k/WNANk=gTG^bMi5k/GN@Nk9gTG^cMkAkeGNdNmIg]WOH
LkQgf6nILkY_^FnKJiY_^f^JHeaO>f=LGcaSG5lkHeaFo5/LE_aK75KlFaaBo5LL001Fo5;lEaaBo5Kl
D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;L009oo`03001oogoo01moo`0097oo00<007ooOol03Goo00<007ooOol0M7oo0UmL00QSG5mL
GeaOG6=LGeaSO6=L0`0000=cVG>iLiT00gNh00Eg]W^fNkIk]G^d009k/`05Nk9kTW^cNi9k/P03Ni40
4W^bMi5k/GNbNkAg]7OFMkIgf7>hMkQc^G>jJiY_Vf^KKi][VP9WN`03GeaO?5ll009O?09K?003EaaK
75LL009G7005FaaBo5Kl001Fo003D_`01EKlD_aBo5;lE_`025;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01e;LD_aBo5;lD]aoo`00025oo`0097oo00<007ooOol03Woo00<007ooOol0LWoo
00UK?ELLHeeOG6=LGcaSGF=KIg`00P0006ESFfMlLiUc^G>ILkUcUgNhMkIk]WNFNkEk]7^eNi9k/W^A
NkEkTW^bNi5k/GN@Nk5gTG^bMi9k/WNANk9gTW_EMkAke6nILkY[VVnKJiY_^f^JJgaWNf^LIg]O?5/L
GcaK75llFaaO?5KlEaaFo5/LE_aG75;l001Bo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`00021oo`0097oo00<0
07ooOol03goo00<007ooOol0Kgoo00EK?5/mFcaK?E/l009OG00;He`00000001WO6=LHgaWNf]kIg][
N`02MkP017NgNkIk]W^f0W^d0W^c0W^d00Ak/g^bNi9kTP9kT@0@Mi5k/GNANi5gTG^aMk9k/gNdNkAg
]WOFLkQg^6^KKi/3Ig/01FMlIg]SG6=LGc`00e/l00eO?5/LFaaFo5LLE_aG75KlEaaBo000D_aFo003
D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo5;lD_`2Ool0
0`00Oomoo`0MOol002Aoo`80015oo`03001oogoo06aoo`07FceG75/mEaaK?ELLFcd00`0006]WO6=K
IgaSFf^KIg][W6MkJi][NVnKJiYk]WNFNkIk]7^eNiAk]WNfNkEkU7^cNi5k/WNANk5gTG^bMi5k/GNA
Nk9gTG^cMkAke7NdNmIg]WOHLkMgf6MkJgaWNf^LHe]SO6=KIgaK75llFaaK?5/LFcaG75/LE_aG75Kl
EaaFo5LLD_`005;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0001moo`008goo00<007ooOol04Woo00<007ooOol0
JGoo0ULM00AG75/mFcaK?@<0000;GceK?6=lHeaWO6=LJg]WNf]kIg][N`03KiX017>iLiUc^GNg0WNh
00Ik]WNfNkAk]7^cNi<2Ni800g^AMi5kT@02Ni402GNANk5gTG^cMk9k]7NdMmIg]P02MkP01GOHLkUc
^W>iLkX01V=L1e/L1eKl00ABo000D_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00IBg5;lD_aBo7oo000NOol001Yoo`@000Eoo`03001oogoo01=oo`03001oogoo
06Eoo`06DaaG7E<LEceC75LM0`0004MK?E/lGeeK?5mMFcaOGFMkJi]WNf^LIg][Vf]jKi][VVnKKiUc
^G>IMkQcUgNhMkIk]W^DNkEkTg^bMi5k/GNANk5gTG^aMi5k/GNANk9g/W_DMkAkeWNfNmIc]gOHKkUc
^VnILkY[VVnKHe]WO6=KHeaO>f=LFaaK?5LLFcaFo5/LE_aG75KlEaaBo5LL009Fo00W001Fo5;lE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;L009oo`03001oogoo01]oo`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool057oo00<007ooOol0HWoo0e<M0ULM0`0000UG7ELLGcaK?5lmFcaO?5/lGcd00UmL00AWNf]kIg][
N`A_VP03LiUc^G>I00=g^009MkIk]W^dNkEkTg^cNi9k/W^A009kTP=kT@0BMi5k/WNbNk=g]7OFMkIg
eWNhMmQc^7>jLkUc^V^JKi][VfnK0ell00EOG5llGcaG75/L00=G7003FaaFo5Kl009Fo005D_aFo5Kl
E_`00002D_`00eKlD_aBo00:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg002D_`00goo001oo`0LOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Eo
o`03001oogoo05eoo`06D_aG7E;lEaeBo5LM0`0007YG7E<LEceG75/mEaaOGE/lGeeK?5mMGeaSG5ll
HeeWNf^KJgY_Vf^JKi]_VG>iLiUc^G>GMkQgUg^fMiIk]G^dNk=gTG^bMi5k/gNANk9gTG^aMi1k/WNA
Nk=g]7_EMkIkeWNfMmQc^7>jKiUc^V^JKi][VVnkIg][O5lkHeaO?6=LFaaO?5KlFaaFo5/LE_aK75;l
EaaBo5KlD_aG75;lE_`005KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0077oo000IOol00`00Oomoo`02Ool00`00
Oomoo`02Ool2000GOol2001KOol00e<MD_eC7@03Dad20003Dad02ULMEceG75LmEaeG?ELLGcaK?6=L
0emL00=SG5mLGe`016nJ00AcVG>iLiUc^@9g^005MkMk]W^fNkEk]002Nk<01G^bNi9k/g^BNk800g^A
015k/WNANk=g/W^dMkIgeWNfMmQc^7>jLkUc^V^JKi][VfnK00=WN`05GeaO?5/lFcaO?002Fc`01eLL
FaaG75LLE_aG75;l00=Fo005D_aFo5;lE_`00002D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo7oo00006goo000IOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`1EOol01U<MD_aC7E;lDaeBo0<0001>
D_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaSGEmLHeaO?6=MGeaSG6=KIga[VVnKJgYc^G>ILkUcUgNh
MiMg^7NFNkIk]7^eNi9k/W^ANkEkTW^bNi5k/GN@Nk5gTG^bMi9k/WNANk=gTW_DMkAkeWNfNmI[VVnK
JiY[W6MkJgaWNf^LIg]O?5/LGcaK75llFaaO?5KlEaaFo5/L0UKl031Bo5LLD_aFo5;lE_aBo000D]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;L000KOol001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Uo
o`03001oogoo059oo`05D_eC7E;mDaeBo@0300000e;mDaeC7@02Dad015LMDaeG7E<M0ULM00IG?ELL
EceG7E/mFc`2Ge`03f=LGeaOG6=LIgaSG6=lHeac^G>ILkUcVGNhMkMg^002NkH2Nk@2Nk<2Nk@2Nk<2
Ni82Ni403GNANk5kTG^AMi5k/WNbNk=g]7^dMkIgeW>h009g^006IgaWNfMkIg]WO6Mk0V=L00AO?5/l
FcaK?0=K7004E_aG75KlEa`2E_`015;lE_aBo5Kl0e;l00D005;lD_aBo5Kl00QBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo7oo000JOol001Uoo`03001o
ogoo009oo`05001oogooOol0000MOol00`00Oomoo`1>Ool01DklDae>o5<MC_`00`0005IBo5<MD_aC
7E;lEaeC75LMD_aG7E<LEaeBo5/mEaaK?ELLFceG75/mEaaSGEmLIgaSFfMlHe]WO6=KJiaWNf]kIg]g
^7NGMkQcUg^fMkIk]G^DNkIg]W^eNiAk/g^ANk9gTG^aMi5k/WNANk5gTG^bMi9k/gNdNmAg]W_FMkIg
f7>gLkY_^F]lIg][W6=KHgaSFfMlHe]K?5LLFcaK75/lEaaK?5KlEaaBo5LL0UKl031Bo5KlD_aFo5;l
E_aBg000D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo0007Ool5000=Ool001Yoo`@000Aoo`8001eoo`03001oogoo
04]oo`9Bo@03DaeBo@0000800005D_eC7E<MDaeBo@03Dad06e;mEaeC7ELMDaeG7E<MEaeC7E/mFcaK
?E/lFceK?5/mFcaSO6=LIgaSG6=lHea[NfMkJg]WN`04KiX01W^fMkIg^7NhNkIg]P9k]006Nk=kTg^B
Ni9kTGNA0g^A00UgTG^aMk9k/gNbNkAg]WOFMkH00WNh00Ac^W>iLkYc^@ISG09O?0EK709G70IFo0=B
o005E_aBo5;lD_`00008D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`01e;LD_aBo5;lD]aoo`0000Moo`05001oogooOol0000=Ool0029oo`03001oogoo01eoo`03
001oogoo04Ioo`05C_aC7DklDae>o0030000SdklDae>o5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75LM
D_aG7E<LEaeC75/mEaaK?ELLFceG75mMFcaWO6=KIgaWNf^LIg][NfMkKi][VVnKJgYc^W>IMkQcUgNh
MkIk]W^DNkEkTg^cMi5k/GNANk5gTG^aMi5k/GNANk=g/W_DMkIkeWNfMmQc]gOHKkUc^VniKk][VV=l
He]WO5llHeaO>f=LGcaK75KlFaaFo5/LE_aG75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo000E_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg7oo00001goo00<007ooOol03Woo000ROol00`00Oomoo`0NOol00`00Oomoo`13Ool2
D_d00e<MD_d000020003D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeBo@03Ead04eLLEaeG7ELM
EaaK?E/lFceK?5llFcaO?E/lGcaWNf]kIg][NfMk00A_VP03LkUcVG>I009g^009MkIk]W^dNkEkTg^c
Ni9k/W^A009kTP0ENi5gTG^AMi5k/WNbNkAg]7OFMkIgeWNhMmQc^G>jLkU_Vf^JKi][VfnK00=O?005
GeaO?5/lFcaK7003Ea`00e/LEaaFo002E_`015;lE_aBo5Kl0e;l00AFo5;lD_`000UBo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo004D]aBo5;lD_`2Ool00`00Oomo
o`05Ool00`00Oomoo`0=Ool0029oo`03001oogoo01moo`03001oogoo03moo`05Dae>oE<MC_aC7@02
0000UTklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LmDaaG7E<LEceC75LM
DaaOGE/lGeeK?5mMFcaSG5llHeeWNf]kIg]_Vf^JKi][NW>jLiUc^G>GMkQgUg^fMiIk]G^dNk=kTW^b
Mi5k/gNANk9gTG^aMi1k/WNbNk=g]7_FMkIkeW>gMmQ_^G>jKkU_^f^JKi][VVnkIg][O5lkHeaK75ll
FaaO?5KlFaaFo5/LE_aG75KlEaaBo5KlD_aG75;lE_aBg5KlD_aFo5;LE_`005KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
Ool000Qoo`03001oogoo00aoo`008Woo00<007ooOol087oo00<007ooOol0?7oo00ABoE<MC_eBo@<0
009Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@QC7@=G7@08EaaG7ELMEceG75llFcaO?@=O
G004HeaOG5mLGe`4KiX00g>iLiUcV@02MkP01GNgNkIk]W^eNk@00g^c00AkTW^cNi9k/P=kT@0ANk9g
TG^bMi5k/WNbNk9g]7^dMkIgeWNfKi][VVnKJi]WO003Ig/01FMlFcaK?5/lGc`00U/l00MFo5LLE_aG
75KlEaaBo003E_`015;lE_aBo5Kl0e;l00=Fo5;l00001U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo09oo`03001oogoo00Ioo`03001o
ogoo00]oo`008Goo0P008goo00<007ooOol0>7oo00A>oE<MC_aC7@<0002JDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/mEaaK?ELLHeeO
G6=LGcaSGEmLHeaO?6MlHe]_Vf]jLkYcVG>iLiMg^7NGMkQgUW^fNkAk]G^BNk=kTG^eNi9k/W^ANk5g
T7^aMi5k/gN@Nk9g/W^cMi9ke7NdNmIg]WOHLkQgf6MkJiaWNf]lIg][W6=KHgaK75llFaaK?5LLFcaF
o5LLE_aK75KlEaaBo5KlD_aFo5;lE_aBo5KlD]aFo5;LE_aBg000D]aFo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`2Ool01@00
Oomoogoo00000goo00<007ooOol02goo000QOol00`00Oomoo`0SOol00`00Oomoo`0bOol01TkmD_eB
oE<MC_eBo@<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@03DaeBoE<M009C7@03
D_eC7E<M00AC7@06EaeC7ELMEaeG?ELL0ULM00EK?E/lGeaOG6=L009OG006HeaWO6=LHgaSG7>i0g>I
00=g^7NgMkP00W^f0W^d0W^c00AkTg^dNk=k/`9kTP9kT@0@Mi5k/G^ANk9gTG^bMk9k]7NdMmIg]WOH
LkQgf7>iLkX3Ig/5He`6Fa`6E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`00e;l00<005;lD_`015;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009B
o08000Aoo`<000ioo`008Goo00<007ooOol097oo00<007ooOol0;goo00EC7DkmDae>o5<M00<0001U
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<L
EaeBo5LMDaaG7E;lFceG75/mEaaK?ELLFceG76=MGeaSG6=KIgaSFfMlHe][W6MkJg]WNgNhMiMg^7>G
NkIg]W^eNiAk]WNfNkIkU7^cNi5k/WNANk5gTG^bMi5k/GNANk=gTW^cMkAke7NfNmIc^7OHKkUc^Vni
LkYSFfMlHe]SO6=KIgaO?6=LEaaK?002Fa`0?EKlFaaFo5LLD_aG75KlEaaBg5KlD_aFo5;LE_aBg5Kl
D]aFo5;LE_aBg000D]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0001Aoo`008Goo00<007ooOol09Goo00<007ooOol0
:goo0U;m00=C7DkmD_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeB
oE<MD_eC7E;mDaeBoE<MD_d3Dad06e;mDaeC7ELMDaeG7E<MEaeC7E/mFcaK?E/lFceK?5/mFcaSO6=L
IgaSG6=lHea[NfMkJg]WN`04KiX02W^fMkIg^7NhNkIg]W^fNkAk/g^C0W^B00=kTGNANi400W^A011g
TG^aMk9k/gNdNkAg]WOFLkQgf7NhLkYc^G>jJi]_V`=SG005GeaO?5llGcaOG003Ea`00e/LEaaFo006
E_`3D_`00eKlD_aBo006D_`00`00D_aBo005D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=B
o005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool04Woo000QOol00`00Oomoo`0V
Ool00`00Oomoo`0XOol014kmDae>o5<M0`000:]C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG7E<LEaeBo5LMDaaG7E<LFceG
75/mEaaK?ELLGeeK?6MlHe]WO6MkJiaWNf]kIg]_Vf^JKi][NW>jLiUg^7>GMkQg]W^fMiIk]G^CNk=g
TG^aMi5k/GNANk5gTG^bMi5k/gNbNmAg]W_FLkQgf7>gLkY_^G>jJiY_^f^JKi]O>f=LGcaSG5lkHeaK
75llE_aK75KlFaaFo5LLD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo7oo00004goo000QOol2000XOol2000UOol00e;mDae>o@02D_d20002D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:DaeBoE<MD_eC7E;mDaeBoE<M
D_d3Dad01E;mDaeG7ELMEa`00eLM00mG75/mFcaK?E/lGcaK?5lmFcaO?6MkJg]WNf]kIg/016nJ00=c
^G>ILiT00WNh00Ug]W^fNkIk]G^CNk=kTW^bNi400W^B0g^A019gTG^cMk9k]7NdMmIc^7OHMkQc^W>i
LkY[VfnKJiY_VfMkIg`4Gc`3Fc`01E/LEaaG75KlEa`015Kl00ABo5KlE_aFo0=Bo003E_aBo5;l00IB
o005001Bo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aB
g003D_`025;LD_aBo5;lD]aBo7oo000BOol0025oo`03001oogoo02Uoo`03001oogoo021oo`04Dae>
o5<MC_d30000/DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMDaaG?E<LEaeC75mMFcaOGE/l
GeeK?5mMGcaSGFMkJg]WNfnKJiY_Vf]jKi]cVG>iLiMg^7NGNkIgUW^fNkAk/g^BNk9gTG^cMi5k/WNA
Nk5gTG^bMk9k/gNdNk=g/W_DMkAkeWNfNmI[VVnkJiY[O6MkJiaWNf]lFaaO?5/LGcaK75llFaaG75Kl
FaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo000E_aBg5KlD]aFo5;L
D_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_`0000BOol0021oo`03001oogoo02]oo`03001oogoo01aoo`04Dae>oE;mD_d300000e;mDae>o@02
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0<DaeBoE;m
D_eC7E;mDaeBoE<MD_eC7E;m1e<M0ULM00aG75LMEaeG?ELLGcaK?5lmFcaO?5mLHe`3Ge`5KiX2LiT2
MkP01GNgNkIk]W^fNk@00g^c00AkTW^cNi9k/P=kT@0>Nk9g/W^bMi5k/WNbNkAg]7^dMkIgeWNhMmQc
^09WN`03IgaWNfMk009SG0=K?00AGcaK75/LFaaG75KlEaaFo5LLD_aFo5;lE_aBo5KlD_aFo003D_`0
0eKlD_aBo005D_`00`00D]aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00004Goo000POol00`00Oomoo`0/Ool00`00
Oomoo`0FOol01U<MC_eC7DklDae>o@<0002iC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeB
o5LMD_aG7E;lEaeG75/mEaaK?ELLFceG75mMFcaSG5llHeeOG6=LGcaWO6=KKi][NVnKLiUc^G>GMkQg
UgNhMiIk]WNfNkEkTW^cNi5k]G^BNk9kTG^aMi1k/GNANk5gT7^bMk9k/gNdNmAg]W_FLkMgf7>hLkY_
^F^LIg]SO6=KIgaSFf=lEaaK?5/LFcaG75/lFaaG75;lEaaFo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000@Ool0021oo`03001oo`0002eoo`03
001oogoo01=oo`03D_eC7Dkm009Bo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eBoE;mDaeBo@=C
7@03D_eC7E<M00AC7@06EaeC7ELMEaeG?ELL0ULM00EG?ELLGeaOG6=L00=OG005IgaSFf=lHeaWO003
LiT00gNhMkMg^002NkH01WNfNkAk/g^cNi=k]09k/`05Ni9kTG^ANi5gT@02Ni403W^bMi5k/WNdNkAg
]7OFMkIgf7>hLkYc^G>jLkT4He`2Gc`00emLFaaK7002Fa`3Ea`5E_`3D_`01EKlD_aBo5;lE_`02e;l
00<005;LD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo080011oo`0087oo0P00;goo00<007ooOol03goo00E>oE<MC_aC7Dkm00<0
0030C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeB
o5LMEaaK?ELLFceG75/mEaaSGEmLHeaSFfMlHe]WO6=KIgaWNf]kIg]g^7NGMkQcUg^fMkIk]W^DNkIg
]W^eNiAk/g^ANk9gTG^aMi5k/GN@Nk5gTG^cMi9ke7NdNmIg]WOHLkQc^VniLkY_^FnKJiY_^ellHeaO
>f=LGcaSG5lkFaaFo5/LE_aK75KlEaaBo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;L001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`003goo0005Ool50005Ool20005Ool40006Ool00`00Oomo
o`0_Ool00`00Oomoo`0<Ool015<MC_eBoE;m0`0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;m
DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad06e;mDaeC7ELMDaeG7E<MEaeC7ELMFcaK?E/lFceK?5/mFcaK
?F=LIgaSFf=lHeaWO6MkJg]WN`04KiX02g^fMkIk]WNhNkIg]W^fNkAk/g^CNi800W^A01AgTG^BNi5k
TGNANk5g/W^dMkAgeWNfMmQc^7>jLkUc^W>iKi][VfnK0VMk00MO?5mLGcaO?5/lGcaK?002Ea`00e/L
EaaG7002E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`01U;l00UBg5;lD_aBo5;LD_`005;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009B
o09oo`03001oogoo00aoo`0017oo0P0000Eoo`00001oo`0000Aoo`8000Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo031oo`03001oogoo00Qoo`05Dae>o5<MC_eC7@020000adkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG7E;lEaeBo5LM
DaaG7E<LEceG75/mEaaK?ELLFceK?5mMHe]WO6=KJiaWNf]kIg]_Vf^JKi][NW>jLiUc^G>GMkQg]W^f
NiAk]G^CNk9gTG^aMi5k/WNANk5gTG^bMi9k/gNdNmAg]WOHLkQc^VniLkY_^FnKJiY_^fMkJgaWNf^L
FaaO?5/LGcaK75llE_aK75KlEaaFo5/LD_aFo5;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aoo`0000ioo`0017oo0P000Woo00<007oo00003goo00<0
07ooOol00goo00<007ooOol0<Goo00<007ooOol01Goo00A>oE;mD_eC7@<00006Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<M
EaeG7003Ead03eLLEaeK?5/mFcaO?5/lGceK?5llFca[NfMkJg]WN`04KiX01W>iLiUcVG>IMkQg]P9k
]P04NkEkTg^cNi82Ni404g^cNi9kTGNANi5gTG^cMkAk]7NbNk=g]7OFMkIgeWNfKi][VfnK00=WN`05
IgaSG6=LFcaO?003Fc`03EllE_aG75KlEaaFo5LLD_aFo5;lE_aBo5Kl00=Bo003E_aBo5;l00IBo009
D]aBo5;lD_aBg5;l001Bo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg002D_`00goo001oo`0<Ool000Aoo`80009oo`03001oo`0000mo
o`03001oogoo009oo`8003Aoo`08001oogooOom>o5<MC_eC7@<0003>Dae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeBo5LM
DaaG?E<LEaeC75LmFcaOGE/lGeeK?5mMFcaSGEmLJg]WNfnKJiY_Vf]jKi]cVG>iKiUg^7NGNkIgUW^e
NkAk/g^BNk9kTg^cMi5k/GNANk5gTG^cMk9k/WNANk=g]7_DMkIkeWNfMmQc]gOHIg][O6MkIgaSFf=l
He]O?5/LGcaK75/lFaaK?5KlFaaFo5LLD_aG75;lE_aBo5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;lD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LOol000aoo`0017oo0P000Woo00<007oo00002goo
10001Goo00<007ooOol0<Woo00=BoE<MC_d00U;m00IC7@00000005<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC7E;mDaeBo@QC7@0=
EaeG75LMEaeG?ELLEaeK?5lmFcaO?5mLHe`00emL1FnJ0g>I00=g^7NgNkH00W^f00Ek]7^cNk=k/W^d
009k/`0DNk9kTG^ANi5k/WNANi5gTG^cMk9k]7NfMmIg]WOHMkQgf7>iLkYc^@ISG0MK70IFo003D_aF
o5;l009Bo005E_aBo5;lD_aFo008D_`01U;LD_aBo5;lD]`0009Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aoo`0037oo0003
Ool300001Goo000007oo00002goo00<007ooOol01Woo00<007ooOol0<7oo00EC7DklDae>oE<M00<0
003EDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/mEaaOGE/lGeeO?6=MGeaS
G5llIgaSFfnKJgY_Vg>ILkU_VGNhMiMg^7NFNkIk]7^eNi9k/g^DNk=kTW^bNi5k/GN@Nk9gTG^aMi5k
/WNbNmAg]7_FMkIkeW>gMmQ_^G>jKkU_^f^JHgaSFfMlGcaSG5lkFcaK75/lEaaK75KlFaaBo5LLE_aG
75;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;L001Bg5;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aoo`0000]oo`001Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol01Woo00<007oo
Ool0;Goo00EC7DkmD_eBoE<M00<00006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@03DaeBoE<M009C7@03D_eC7E<M00IC
7@04EaeC7ELmEa`2Ead01ELmEaaOG5mLHe`00emL00EWO6=KHgaSG6Ml00=cV@03LkUg]gNh009k]P06
MkIk]7^cNk=g]W^d0W^c00=kTW^ANi4017^A015k/GNbNk9g]7OFMkIgeWNhMmQc^G>jLkU_Vf^JKi][
VemL00=O?005GeaO?5LLEaaK7003Ea`00e/LD_aFo002E_`3D_`00eKlD_aBo00>D_`01U;LD_aBo5;l
D]`0009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`015;LD_`000002Woo0006Ool4000<Ool50004Ool00`00Oomoo`0[Ool014klDae>
oE<M0`00095C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeBo5LMEaaK?ELL
FceG75/mEaaSGEmLHeaSFfMlHe]WO6=KIgaWNf]kIg][W7NGMkQcUg^fMkIk]G^DNkIg]W^eNiAk/g^C
Nk9gTG^aNi5k/GN@Nk9gTG^cMkAke7NfNmIc]gOHKkUc^VniKk][VVnKJiY[W6MkHeaO>f=LFaaO?002
Fa`0BEKlFaaFo5/LE_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aBo5;LE_aBg5;l001Fo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aoo`0000Yoo`007goo00<007ooOol0:7oo00E>oE;mD_eC
7Dkm00800006Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eC7E;mDaeBoE<MD_eC7E;m0e<M01aBoE<MDaeG7E<M
EaeC7ELMDaeG7E/lFceK?5/mFcaK?E/lFceSG6MlHe]SO6=LIgaWNf]kIg][N`=_VP03LkUcVGNh009g
^006MkIk]W^dNk=kTg^B0W^A01AgTG^ANi5kTGNANk9g/W^dMkIgeWNhMmQc^G>jLkU_Vf^JKi][VfMl
0fMk00]O?5/lFcaK?5llFcaG75KlEaaFo5LL009Fo004D_aFo5;lE_`3D_`00eKlD_aBo006D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_aBo00000=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;L00000009Ool001ioo`8002Eoo`07C_eC
7DklDae>oE<MC_`00`0009i>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG
7E;lEaeBo5LMDaaG7E<LEceG75/mEaaK?ELLFceK?5mMHe]WO6=KJiaWNf]kIg][W6^JKi][NW>jLiUc
^G>GMkQg]W^fNiAk]G^CNk=gTG^aMi5k/WNANk5gTG^bMi9ke7NANk=gTW_DMkIkeWNfKk][VVnKIg][
W6MkJgaWNfMlHe]O?5/LGcaK75/lEaaK75KlEaaFo5/L0UKl049Bo5KlD_aFo5;LE_aBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo000E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo7oo0009Ool001ioo`03
001oogoo029oo`06Dae>oE;mD_eC7Dkm0`0000E>oE;mD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@0:
DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMEa`00eLM011G75LMFcaK?E/lGcaK?5lmFcaO
?5/lJg]WNf]kIg][N`=_VP03LkUcVG>I009g^007MkMk]W^fNkEkTg^cNi800W^A01=k/g^ANi5gTG^a
Mk9k/gNANk9g/W^dMkAgeWNfMmQc^7OHIg]WO002Ig/5He`6Fa`7E_`015;lE_aBo5Kl0e;l00=Fo5;l
D_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_`00003D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00<007ooOol01goo000NOol0
0`00Oomoo`0POol01DklDae>oE<MC_`00`000:I>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeBo5LMDaaG?E<LEaeC75LmFcaOGE/lGeeK?5mMFcaS
GEmLJg]WNf^LJiY_Vf]jKi]cVG>iKiUg^7NGNkIgUW^eNiAk/g^BNk9kTg^cNi5k/GNANk5gTG^aMi5k
/WNBNk=g]7_FMkIgf7>hMmQ_^G>jKkUc^V=KIgaSFf=lHe]SG5llFcaG75/lE_aK75KlEaaFo5LLD_aG
709Fo00kD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L
001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg004Ool00`00Oomoo`07Ool001ioo`03001oogoo01ioo`9Bo@03Dae>o@0000800005C_eBoE;m
Dae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@QC
7@0=EaeG75LMEaeG?ELLEaeK?5lmFcaO?5mLHe`00emL00=SG6nJKiX00VnJ0g>I00=g^7NgMkP00W^f
0W^d00=k/g^bNk@00W^c01Ek/W^ANi5gTG^AMi5k/GNbNk=g]7^dMkIgeW>hMmQc^G>jLkUc^V^KKi/0
0V=L00=O?5mLGc`00Ull00EK75LLEaaG75/L00AFo004D_aFo5KlE_`3D_`00eKlD_aBo00:D_`01E;L
D_aBo5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo0Moo`03001oogoo00Ioo`007Woo00<007ooOol06goo00AC7DkmDae>o0<0
002RC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>
o5<MD_aC7E;lEaeBo5LMD_aG7E;lFceG75/mEaaK?ELLFceG76=LGcaSGEmLHeaO?6=MHe]WO6]jKi]c
VG>iKiUg^7NGMkQgUW^fNiAk]G^BNk=kU7^cNi9k/WNANk5gT7^aMi5k/GNANk=g/W_DMkIkeW>hMmQc
]g>jKkUc^V^JKk][VVnKGc]SG5llHeaK75ll0U/L041Fo5/LE_aK75;lEaaBo5KlD_aG75;lE_aBg5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`005;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo0Yoo`03001oogoo00Ioo`007Goo
0P0067oo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@03DaeBoE<M009C7@03D_eC7E<M00IC7@04EaeC7ELm
Ea`2Ead01ELmEaaK?E/lHe`00emL00ESG6=KHgaSG6Ml00=cV@06LkUg]gNhMkQk]WNf0W^d00=k]W^d
Nk@00W^c00AkTW^ANi5k/P9kT@0CMi5k/GNbNkAg]7OFLkQgf7NhLkYc^FnKJi]_Vf^JKi]WNfMlIg/0
0U/l00YO?5/lFcaK?5LLE_aG75KlEaaBo0=Fo004D_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L009Bo003001Bg5;l009Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l3Woo
00<007ooOol01Woo000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@80003QC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<M
D_aC7E;lDaeBo5LMDaaG7E;lEaeC75/mEaaK?ELLFceG75/mEaaSG5llIgaSFfMlHe]WO6MkJg]WNf^L
MiMg^7>GNkIg]WNhLiMk]WNfNkEkTW^cNi5k/GNANk5gTG^aMi1k/WNbNk=g]7^cMk9ke7NdLkY_^FnK
JiY_^f^JJiaWNf^LIg]SO6=KGcaK75llEaaK?5/LEaaFo5/LE_aG75;lE_aBo5KlD_aFo5;lE_aBg5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;L01=oo`03001oogoo00Ioo`007Goo00<007ooOol04goo0U;m00=C7Dkm
D_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad05eLMDaeG7E<MEaeC7E/m
FcaK?E/lFceK?5/mFcaWO6=KHgaSG6MlIg][NfMkJg/00fnJ00=c^G>IMkP00WNh00Ig]W^dNkAk/g^C
Ni82Ni4047^BNi5kTG^AMi5k/WNANk5g/W^dMkAgeWNfMmQg^7OH0fMk00=WO6=LHe`00f=L1E/L00=F
o5LLE_`00eKl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00e;l00EBg5;l001Bo5;L00=Bo006D]aBo5;lD_aBg5;l5Goo00<007ooOol01Woo000MOol00`00
Oomoo`0AOol014kmDae>o5<M0`000;EC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5LMD_aC7E;lEaeBo5<MD_aG
7E<LEaeC75LmDaaK?ELLFceG75/mFcaOGE/lIgaSFf^LIg][NfMkJia[VVnKJgYc^W>ILkUcUgNhMkIk
]W^DNkEkTg^bMi5k/G^CNk5gTG^aMi5k/gN@Nk9g/W^cMkAke7NfNmIc]gOHKkUc^VniIgaSFf=lHe]W
O6=KHeaO>e/lFaaK?5LLFcaFo5LLD_aG7002E_`0:e;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;lD]aFo5;L01Mo
o`03001oogoo00Ioo`007Goo0P003goo00ABoE<MC_eBo@<0009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad0
0e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7E<MEa`00eLM011G75LMEaeG7E/lGcaK?5lmFcaO?5/l
Jg]WNf]kIg][N`A_VP9cV@9g^00:MkMk]W^dNkEkTg^cNi9k/g^CNi82Ni404GNANk5kTG^aMi5k/WNd
NkAg]WOFMkQgf7>iLkYc^FnKJiX00f=L0ell00=OG5/LFa`00U/L0ULL1UKl0e;l00EFo5;lD_aBo5Kl
00QBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L01aoo`03001oogoo
00Ioo`007Goo00<007ooOol02Goo00I>o5<MC_eC7DklDad30000hE<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDae>o5LMD_aC7E;lEaeBo5LMDaaG?E<LEaeC75LmEaaK?E/lGeeK?5mMFcaSGEll
Jg]WNf^LJiY_Vf]jKi]cVG>iLiMg^7NGNkIgUW^eNiAk/g^ANkEkTg^cNi5k/GNANk9gTG^aMi5k/gNB
NmAg]7_FLkMgf7>hLkY_^FnkJiY_Vf^JHeaO?6=LGc]SG5llHeaFo5/LE_aK75KlFaaBo5KlD_aG75;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;L
E_aBg5;lOol0000OOol00`00Oomoo`05Ool001eoo`03001oogoo00Moo`9Bo@03Dae>oE;m00<0009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@MC7@05
EaaG7ELMEceG7002Ead01ElmFcaO?5mLHe`00emL00=SG6nJKiX00VnJ0W>I0WNh00Eg]g^fNkIk]G^d
009k/`04NkEkTg^cNi85Ni404GNANk5g/W^dMkAgeWNfMmQc^7>jLkU_Vf^JKi][VfMlIg/00Ull00EO
G5llFcaK?5ll00AG7005E_aG75KlE_aBo003E_`3D_`00eKlD_aBo006D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo003D]aoogoo009oo`03001oogoo01aoo`03001oogoo00Eoo`007Goo00<0
07ooOol01Goo00A>oE<MC_aC7@<0003PDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEaeBo5LMEaaK?ELLFceG75/mEaaSG5llHeeO?6=LGcaSGF=K
IgaSFfMlLiUc^FnIMkQgUgNhMiIk]W^DNkEgUW^eNiAk/g^BNk9gTG^aNi5k/GNANk9gTW^cMkAke7Nf
MmQc^7>jKkU_^f^JKi]WNf^LIg][W6MkGcaK75llFaaO?5/LGcaFo5/LE_aG75KlFaaBo5KlD_aFo5;l
E_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg0Qoo`03001o
ogoo01]oo`03001oogoo00Eoo`007Goo00@007ooOom>o@9Bo@04Dae>oE;mD_d20002D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3Dad0
2E;mDaeC7ELMDaeG7E<MEaeG7002Ead01ELmFcaK?E/lHe`00emL00]WO6=KHgaSG6MlIg][NfMkMkQg
]gNh009k]P05MkMg^7^fNkIk]002Nk<017^bNi5kTG^B0g^A00igTG^cMkAk]7NbNk=g]7OFMkIgf7>h
MmQWNfMl0fMk0V=L0U/l00=O?5/lFa`00U/L00=Fo5LLE_`00eKl00IBo5KlD_aFo5;lE_`3D_`00eKl
D_aBo006D_`01E;LD_aBo5;lD]`00e;l37oo00<007ooOol06goo00<007ooOol01Goo000LOol02000
OomC7DkmDae>o5<MC_d30000gDkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMDaaG7E;lEaeC75LMEaaK?ELLFceG75/mEaaK?F=KIgaS
FfMlHe]WO6MkJg]WNfnKJiY_VfnILkYgUgNhLiMk]W^DNkEkTW^cNi5k/G^BNk9gTG^aMi5k/gNbNk9g
TG^cMkAke7NfNmIc^7OHKkUc^VMkJiaSFfMlHe]SO6=KFcaK75/lEaaK?5/LFcaBo5LLE_aG75;lE_aB
o5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]`04Goo00<007ooOol06Woo00<0
07ooOol01Goo000LOol00`00Dae>o@02D_d300000e;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@05D_eC
7E<MEaeC7@03Ead03e/lFceK?5/mFcaK?E/lGceSFf=lHea[NfMkJg]WN`03KiX00g>ILkUcV@02MkP0
2W^fMkIk]7^dNk=kTW^ANk=k/W^B0W^A00mk/GNANi5gTG^cMk9k]7NfMmIc^7OHLkUc^W>iLkX016=L
00=O?5mLGc`015/L0ULL00=K75KlE_`00eKl0U;l00EFo5;lD_aBo5Kl00UBo1Moo`03001oogoo01Uo
o`03001oogoo00Eoo`004Woo1@001Goo00<004km00000P000<Q>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aC7E;l
EaeC75LMDaaG?E<LEaeG75/mEaaOGE/lGeeK?5mMFca[W6MkJg]WNfnKJiY_Vf]jLkYcVGNhLiMg^7Nf
NkEkU7^cNi=k/W^BNk=kTG^aMi1k/GNANk5gTG^bMk9ke7NdNmIc^7OHLkMc^VniLkY[VVnkJiYSG5lk
HeaO?6=LGc]K75KlFaaFo5/L0UKl019Bo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`J
Ool00`00Oomoo`0HOol00`00Oomoo`05Ool001Aoo`03001oogoo00Eoo`800003D_eC7Dkm009Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<M
D_eBoE;mDaeBoE<MD_eC7E;mDaeBoE<MD_d5Dad2Ead03eLLEaeG7ELMFcaO?5/lGceK?5llFcaSG5mL
Jg]WN`04KiX00g>iLiUg^002MkP027NfNkIk]7^eNi=kTW^dNk<2Ni82Ni404GNANi5kTG^aMk9k/WNd
MmIg]WOHMkQc^W>iLkY[VfnKJiX00VMk00IOG5llGcaK?5llFc`2Ea`00e/LE_aG7002E_`015;lE_aF
o5Kl0e;l00=Fo5;lD_`01E;l77oo00<007ooOol06Goo00<007ooOol017oo000DOol00`00Oomoo`06
Ool0b000Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aG?E<LEaeC75/mEaaK?E/lGeeK?5mM
GcaSGEllHeaO?6nKJiY_Vf]jLkYcVGNhLiMg^7NfNkIkU7^eNi=k/g^DNk=kTg^bMi5k/GNANk5gT7^b
Mi5k/gNdNmAg]WOHLkMc^VniLkY[VVnkIg][W6MkJiaWNellFaaO?5/LGc`2Fa`015KlEaaFo5/L0UKl
00YBo5KlD_aFo5;lE_aBo5KlD]aFo25oo`03001oogoo01Qoo`03001oogoo00Aoo`0057oo00<007oo
Ool01goo0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d8Dad2Ead01ULmEaaG7ELMEceG
709OG009HeaOG5mLGeaWO6=KHgaSG7>i009cV@9g^005MkMk]W^fNkEk]002NkH01g^eNi=kTW^BNi5g
TG^B009kT@0<Mi5k/WNbNkAg/W^bMkAgeWNfMmI[VfnK0fMk00EWO6MkHeaSG5ll009K?0=K7003EaaF
o5LL00AFo005D_aFo5;lE_aBo00VOol00`00Oomoo`0GOol00`00Oomoo`04Ool001Aoo`03001oogoo
00Uoo`37001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMD_aK?ELLFceG75/mEaaK?ELLHeeO?6=L
He]WO6=KIgaSFf^LIg][Ng>GMkQgUg^fMiIg^7NGNkIgUW^eNi=k/g^ANk9gTG^bMi5k/GNANk9gTW^b
Mi5k/gNdNmAg]W_FLkMgf6niLkYWNf^LHe]SO6=KIgaSFe/lEaaK?5/LFc`00ULL00QFo5LLD_aG75;l
E_aBo5Kl:7oo00<007ooOol05goo00<007ooOol017oo000DOol00`00Oomoo`0:Ool01000OomC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06DaeBoE<MD_eC7E;m0e<M01YBoE<MDaeG7E<MEaeC7ELMDaeG7E/lFceK?5/mFcaK?E/lHgaSG6Ml
He]SO6=LJg]WNf]k0fnJ0W>I00=g^7NgMkP00W^f01Qk]7^cNi9k/W^ANk=kTW^AMi5k/GNbNi5gTG^b
Mk9k]7NfMmIg^7OHLkUc^W>iLkX4He`3Gc`3Fa`00eLLFaaG7005E_`/Ool00`00Oomoo`0FOol00`00
Oomoo`04Ool0019oo`<000eoo`38001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aG7E;lDaeBo5LMDaaG7E;lEaeC75LMDaaG?ELLFceG
75/mEaaOGE/lIgaSFfMlIg][W6MkJg][NVnKJgYc^FnILkYgUgNhMiIk]W^DNkEkTW^bNi5k/g^ANk9g
TG^aMi5k/GNANk9gTW_DMkAkeWNeMmQc^7>jKkUc^V^JKi][VV=LGcaSG5lkHeaO?5/LE_aK75KlFaaF
o35oo`03001oogoo01Eoo`03001oogoo00Aoo`0057oo00<007ooOol037oo0P0000IoodkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00YC7E;mD_eBoE<MD_eC
7E;mDaeBo@=C7@05D_eC7E<MEaeG7003Ead03eLLEaeK?5/mFcaO?5/lGceK?5llIg][NfMkJg]WN`03
KiX00g>ILkUg]`02MkP02G^fMkIk]7^cNk9kTW^dNk=k/P02Ni404gNANi5gTG^aMk9k/gNdMmIg]WOH
LkQc^W>iLkY[VVnKJi]WO6Mk009O?005GeaK?5/lFcaK7002Ea`dOol00`00Oomoo`0DOol00`00Oomo
o`04Ool002Eoo`31001oodklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<M
C_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MD_aG7E;lEaeC75LmDaaG7E<LEceK?5mMFcaOGE/lGeeO?6=M
Ig][NfMkKi][NVnKKiUc^W>IMkQcUg^fMkIk]G^DNk=kU7^eNi9k/W^ANk5gT7^aMi5k/WNANk=g]7_D
MkEgf7>hLkY_^G>jJiY_VfMkJiaWNf^LIg]O?5/LGcaK75llFa`0=Woo00<007ooOol05Goo00<007oo
Ool00goo000VOol00`00Oomoo`02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@05DaeBoE;mD_eC7@03D_d015<MD_eC7E;m25<M00YG7ELLEaeG7ELmEaaG7E/lGceK?09OG004
HeaOG5mLGe`3KiX00g>ILkUcV@02MkP01W^fMkIk]W^dNk=g]P9k]005Nk=kTW^ANi5k/P02Ni403WNA
Nk=g/W^dMk9k/gNdMmIg]WOFJiY_VfMkIg`3Ig/2He`2Fc`00ellOomoo`0gOol00`00Oomoo`0DOol0
0`00Oomoo`03Ool002Moo`2k001oogooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7E;lFceG75/mEaaK?ELLFceO?6=LGcaSGEll
HeaO?6MlHe]WO6nILkYcVG>iLiMg^7NfNkIkU7^eMkIk]G^DNk=kTG^bMi5k/WNANk5gT7^bMk9k/WNA
Nk=g]7_DMkEkeW>hMmQ_^G>jIg][W6=KIgaSFf=lHe/0?7oo00<007ooOol04goo00<007ooOol00goo
000XOol200001GooD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M
00=Bo@03DaeBoE<M009C7@03D_eC7E<M00IC7@04EaeC7ELmEa`2Ead01ELmFcaK?EmLHe`00UmL00QS
G6MlHe]SG6MkJg]WNf]k0WNh00Ug]W^fNkIg^7NfNkIk]7^eNi<00W^B01=k/g^BNi5kTG^aMk9kTGNA
Nk=g/W^dMkIgeW>hMmQc^G>jLkUc^P04He`oOol00`00Oomoo`0BOol00`00Oomoo`03Ool002Yoo`2d
001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;l
DaeBo5LMDaaG7E;lEaeG75/mEaaK?ELLFceG75/mEaaWO6=KIgaSFfMlIg][W6MkJg][NVnKLiUc^FnI
MkQgUg^fNiAk]G^CNk9kTG^aNi5k/WNANk5gTG^aMi5k/WNbNmAg]7_FMkIgf7>gLkY_^G>jJiY_^f^J
@Goo00<007ooOol04Woo00<007ooOol00goo000[Ool01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@0:Dae>oE;mD_eC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad05ELMDaeG7E<M
EaeK?5/mFcaK?E/lFceK?5llFcaWO6=KJg]WNf]kIg][N`03KiX2LiT02g>iMkMk]W^fNkEk]7^cNi9k
/W^CNi800W^A015gTG^ANi5k/GNbNk9g]7OFMkIgf7NhLkYc^FnKJi]_Vf^J04=oo`03001oogoo015o
o`03001oogoo00=oo`00;7oo0:l007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7E;lDaeBo5LMD_aC7E;lEceC75LMDaaG?ELLFceG75/mFcaOGE/lGeeK?6]kIg][W6Mk
Jg][NVnKJgYc^FnILkYgUgNhMiIk]W^DNk=kTG^bNiAk/W^ANk5gTG^aMi1k/WNANk=g]7_DMkIgf7>g
LkY_^FnKJiY_^`16Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool002eoo`80009Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@=G
7@09EaaG7ELMGceK?5llFcaO?E/l009OG003Jg]WNf]k00=_VP9cV@03LkUg]gNh009k]P9k]005Nk=k
]G^dNk=kTP02Ni403g^BNi5kTGNANk9g/W^dMk9k/WNdMmIg]WOHMkQgf018Ool00`00Oomoo`0@Ool0
0`00Oomoo`02Ool002moo`2Z001C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
Dae>o5<MD_aG7E;lEaeBo5LMDaaG?E<LEaeG75/mEaaOGE/lGeeO?6=LGcaSG5llHea[NVnKJgY_VfnI
LkYgUgNhMiIk]WNfNkEkTW^fNiAk]G^ANk9gTG^aMi5k/GNANk9gTW^bMi5k/gNdNmAg]W_FLkMgf4Uo
o`03001oogoo011oo`03001oogoo009oo`00<7oo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d7Dad01ELLEaeG7ELmEa`00ULM00EG?EmLGeaO
G6=L009OG007HeaWO6=KHeacVG>iLiT00WNh01Uk]WNfNkAk]7^fNkAk]G^cNk9kTW^ANi9kTGNANk5g
/W^AMi5k/WNbNkAg]WOFMkQgf01;Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0035oo`2W001oogoo
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMEaaK?ELL
FceG75/mEaaK?EllHeaO?6MlHe]WO6=KIgaWNf^LIg]g^7>GNkIg]W^fLiMk]WNfNkEkU7^bNi5k/G^C
Nk9gTG^aMi5k/GNANk9gTW_DMkAkeW>gMmQc^01<Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool0039o
o`05001oogooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<MC_eC7E;mDaeBoE<MD_eC7E;m0e<M015B
oE<MDaeG7E<MEaeC7ELMDaeK?E/lFceK?5/mFcaK?F=K009SG006IgaSFf=LIg][NfMk0VnJ00=c^G>I
LiT00WNh00Ag]W^eNkAk/`9kTP0;Nk=k/W^ANi5gTG^AMi5k/GNbNk=g]002MmH00gOHLkQoo`1<Ool0
0`00Oomoo`0>Ool00`00Oomoo`02Ool003=oo`80002QOomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5LMD_aC7E;lEaeC75LMD_aG7E<LEaeC75/mEaaK?ELLFceK?5mMHe]WO6=KJg]WNf^LIg]_
Vf]jKi]cVG>iLiMg^7NfNkIkU7^eNi5k/W^DNk=kTG^aMi1k/GNANk9gTG^cMkAke7NeMmQc^01?Ool0
0`00Oomoo`0=Ool00`00Oomoo`02Ool003Eoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<M
D_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7ELL00=G7@0<EaaK?E/lGceK?5llFcaO?E/lJg]W
Nf]k16nJ0g>I00Yg^7NgNkIk]7^eNi=k]G^dNk=kTP9kT@0:Nk9kTG^AMi5k/gNbNkAg/W^cMkAAOol0
0`00Oomoo`0<Ool00`00Oomoo`02Ool003Ioo`2O001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<M
D_aC7E;lEaeBo5LMD_aG7E<LEaeC75LmDaaG7E<LGeeK?5mMFcaOGE/lHeaO?6=LJgY_Vf]jKi]cVG>i
KiUg^7NGNkIgUW^eNiAk]W^DNkEkTg^bMi5k/GNANk5gT7^bMk9k/WNANk=g]7_D059oo`03001oogoo
00]oo`03001oogoo009oo`00=goo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d035<MD_eBoE;mDaeBoE<MD_eC
7E;mDaeBo@MC7@9G7@08EaaG7ELMEceG75llFcaO?@=OG003HeaSFf=L00=_VP9cV@0>MkQg]gNhNkIk
]G^dNkIk]7^eNi=k/g^BNi5kTP9kT@07Nk5g/W^AMi5k/gNbNk@0Dgoo00<007ooOol037oo00<007oo
Ool00Goo000hOol20000VU<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeBo5LMD_aG7ELL
FceG75/mEaaK?ELLHeaO?6=LGcaSG6=KIgaSFfMlHe]c^FnIMkQgUgNhMiIk]WNGMkQgUW^eNiAk/g^A
Nk5kTg^bMi5k/GNANk5gTG^bMk9ke7NcE7oo00<007ooOol02goo00<007ooOol00Goo000jOol00`00
Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7E;mD_eBoE<MD_d3Dad00e;mDaeC7@02Dad015LMDaeG7E<M0ULM00IG
?ELLEaeK?5/mFc`2Ge`026=LHe]SG6=LIgaSFf]kIg/3KiX01g>ILkUg]gNhNkIk]G^d009k/`03Nk9k
Tg^B009kT@07Mi5kTG^ANk5g/W^bMk@0EWoo00<007ooOol02Woo00<007ooOol00Goo000kOol0V000
Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEaeBo5LMEaaK?ELLFceG75/mEaaK?F=K
IgaSFfMlHe][NfMkKi][NVnKKiUc^W>IMkQcUg^gNiAk]G^CNk9kU7^cNi5k/GNANk5gT7^bMi5k/gNc
NmAGOol00`00Oomoo`09Ool00`00Oomoo`01Ool003aoo`03001oogoo009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<M
D_eC7E;m0e<M00=BoE<MDad00U<M01=G7E<MEaeG75LMFcaK?E/lFceK?5lmFcaO?6=LIgaWNf]kIg][
N`03KiX01g>iLiUg^7NhNkIk]7^e009k/`03NkAk/g^c009kT@07Ni9kTG^AMi5k/WNbNk@0F7oo00<0
07ooOol02Goo00<007ooOol00Goo000mOol20000TgooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lDaeC
75LmDaaG7E<LEceC75mMFcaOGE/lGeeK?5mMIg][NfMkJia[NVnKJgYc^W>IMkQcUgNhMkIk]G^DNk=k
U7^eNi=k/WNANk5gTG^aMi5k/WNBNk9gT@1IOol00`00Oomoo`08Ool00`00Oomoo`01Ool003moo`06
001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m1e<M00EG75LMEaeG7ELL009G7@05GceK?5llFcaSG003
Ge`01V=LKiY_VVnJLkUcV@=g^006MkIk]G^dNkIg]W^e0W^c00UkTW^ANi9kTGNANk5g/W^AMi40Fgoo
00<007ooOol01goo00<007ooOol00Goo0010Ool0T@00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG
7ELLFceG75/mEaaK?ELLFceO?6=LGcaSG5llHeaSFfMlHe]c^W>ILkUcUgNhMiMk]W>GMkQg]W^eNiAk
/g^ANk5kTg^bMi5k/GNANk5gTG^b05aoo`03001oogoo00Moo`40005oo`5oo`00@Goo00H007ooOomB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
DaeBoE;mD_eC7E;m0e<M00=BoE<MDad00U<M00AG7E<MEaeG709G7@05EceG75/mFcaK?@03Ge`01fMl
He]SG6=LJg]WNf]k009g^00<MkMcVGNhMkQg]W^fNkAk/g^CNi9k/g^b0W^A00AgTG^AMi5k/Eeoo`03
001oogoo00Moo`40005oo`5oo`00@Woo0P0008aoodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E<LEaeBo5LMDaaG7E;lFceG
75/mEaaK?ELLFceSFfMlHe]WO6=KJiaWNf]kJgY_Vf]jLkU_VGNhMiMk]W^DNkEkTg^cNiAk/g^ANk5g
T7^aMi5k/WNAGWoo00<007ooOol01Woo0@000Goo0Goo0014Ool01@00OomBoE<MC_d00U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m0e<M
00EBoE<MDaeG7E<M00=G7@0>EaaK?E/lFceK?5/mFcaO?F=KHeaWNf]kIg][N`=_VP9cV@0:MkQg]g^f
NkIk]G^CNk=kTW^cNi82Ni4017^bNi5kTGNAH7oo00<007ooOol01Goo0@000Goo0Goo0015Ool0RP00
Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
DaeBo5LMD_aC7E;lEaeC75LMDaaG?E<LEaeG75/mEaaOGE/lGeeK?5mMIg][W6MkJg][NVnKJgYc^FnI
LkYgUgNhMiIk]G^DNk=kTg^eNi=k/WNANk5gTG^aMi1k/V1oo`03001oogoo00Eoo`40005oo`5oo`00
AWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05DaeBoE;m
D_eC7@03D_d01U<MD_eC7E;mDaeBo@EC7@9G7@0<EaaG7ELMEaeK?5llFcaO?E/lGcaOG6=L0UmL0fnJ
0W>I00=c^GNgMkP00W^f00Uk]7^fNkIk]G^CNk=kTW^ANi800W^A00=k/GooOol0H7oo00<007ooOol0
17oo0@000Goo0Goo0017Ool20000QGooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7E<LEaeC75/mEaaK?E/lGeeK?6=LGcaSG5ll
HeaSFfMlHe]c^FnILkYcVGNhLiMk]gNGMkQgUW^gNiAk/g^ANk5kTg^bMi5k/GNA06=oo`03001oogoo
00=oo`40005oo`5oo`00BGoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@05DaeBoE;mD_eC7@02D_d2Dad00e;mDaeC7@07Dad00eLMEceG7002Ead01ULmEaaOG5mLHeaO
G09SG006IgaSFf]kIg][NfMk0WNh00=c^GNgMkP00W^f00Ik]7^eNk=k/W^CNi82Ni400gNANi5oo`1S
Ool00`00Oomoo`03Ool10001Ool004Yoo`23001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E;lEaeG75/mEaaK?ELLFceG75/mHe]W
O6=KIgaSFf]kIg][W6MkKi][NW>jLiUg^7>GNkMg]W^eNi=k/W^DNk=kTG^aMi5k/@1UOol00`00Oomo
o`03Ool10001Ool004]oo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MD_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@0DEaeC7ELMDaeG7E/lFceK?5/mFcaK?E/lGcaS
G6MlHe][NfMkJg]WN`9_VP0@LkUcVGNhMkQk]WNfNkEk]7^cNkAk/g^BNi5gTG^BNi5VOol00`00Oomo
o`02Ool10001Ool004aoo`80001nDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDaeBo5LMD_aC7E;lEceC75LMDaaG?ELLFceG75mMFcaOGE/lGeeK?6]kIg][W6]jKi][
NVnKLiUc^G>GMkQg]W^eNiAk/gNfNkEkTg^bMi5k/WNAJ7oo00D007ooOomoo`00005oo`00CWoo00<0
07ooC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@=C7@03
D_eC7E<M009C7@=G7@09EaaG7ELMGceK?5llFcaO?E/l009OG003Hea_VVnJ009_VP9cV@9g^006MkIk
]W^dNkEg]W^e0W^c00AkTW^cNi9kTFUoo`04001oogoo0001Ool004moo`1m001oodklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMDaaG?E<LEaeG75/mEaaO
GE/lGeeO?6=LGcaSG6=KIgaSFfMlLiUc^FnIMkQgUg^fLiMg^7NfNkIkU7^cNi9k/G^ANk5gT@1YOol0
1000Oomoo`000Goo001@Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=B
o@03DaeBoE<M009C7@03D_eC7E<M00EC7@05EaaG7ELMEceG7002Ead01V=LGeaOG5mLHeaSF`9SG007
IgaWNf]kIg]g^7NgLiT00WNh00Ug]g^fNkAk]G^CNi9k/g^bNi40Jgoo00<007oo00000Goo001AOol2
0000N4klDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeC75LM
EaaK?ELLFceG75/mEaaSG5llHeaSFfMlHe]WO6MkJg]WNfnKJgYc^FnIMkQgUg^fMiIk]G^CNk9kU7^c
Ni9k/Faoo`40005oo`400000Dgoo00H004kmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;m
DaeBoE<MD_d3Dad04E;mDaeC7ELMDaeG7E<MEaeC7E/mFcaK?E/lFceK?5/mHe/00V=L00A[NfMkJg]W
N`9_VP9cV@0;MkQg]gNhNkIk]G^dNk=k]7^cNi9kT@1^Ool2000005Aoo`1f001ooe<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG7E<LEaeBo5LMDaaG7E<LFceG75/mEaaOGE/lGeeK
?6^LIg][Nf]jKi][NVnKKiUc^WNGMkQgUW^gNiAk/gNFNkEkTg^bMi5^Ool2000005Eoo`06001ooe;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMEa`00eLM00QG
75llFcaO?E/lGcaK?6=L0UmL16nJ00AcVG>iMkMg^09k]P08NkAk]G^fNkEkTg^BNi5k/fioo`800000
EWoo07<007ooOom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aG7E;lEaeBo5LMDaaG7E<LEceG
75/mEaaOGE/lGeeO?6=LGcaSG6=KIgaSFfMlKiUc^W>IMkQcUg^gMkIg^7NFNkMkU7^cNi5k/`1[Ool4
0002Ool005Moo`800004OomBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d00e<MD_eC7@02Dad00e;mDaeC
7@04Dad02ULmEaaG7ELMEceG75LMGeaSG5mL0V=L00IWO6=KHeaWNf]kIg/2MkP02W>iLiUg^7NhNkIk
]7^eNk=k]G^CIgoo10001Woo001IOol0K`00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG
7E<LEaeBo5LMDaaK?ELLFceG75/mEaaK?ELLIgaSFfMlHe]WO6MkJiaWNfnKJgYc^W>IMkQcUg^gMkIk
]G^CNk9kT`1TOol4000:Ool005Yoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE<MD_eC7E;mDaeBoE<MD_d3
Dad05E;mEaeC7ELMDaeG7E<MFceK?5/mFcaK?E/lGcaK?6MlHe][NfMkJg]WN`02KiX00g>iLiUcV@02
MkP01WNfNkEk]7^cNkAk/f1oo`@000ioo`00Fgoo06d007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LM
D_aC7E;lEaeC75LMDaaG?E<LFceG75/mFcaOGE/lGeeK?6]kIg][W6MkKi][NVnKLiUc^G>GMkQg]W^f
NiAk/gNfNk=kT`1LOol4000BOol005aoo`800003OomC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m
1E<M0ULM00UG75LMEaeG7E/lGcaK?5lmFc`00UmL00=SG5mLKiX00VnJ0W>I0WNh00Mg]g^fNkAk]GNf
NkEk/`1JOol3000FOol005ioo`1Y001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aG7E;lEaeBo5LMD_aG?E<LEaeC
75/mEaaK?E/lGeeO?6=LGcaSG5llIgaSFfMlLiUc^G>GMkQgUg^fMiIg^7NfNkIkU7^c05Ioo`@001Uo
o`00Ggoo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@05Dae>oE;mD_eC7@03D_d00e<MD_eBo@02Dad00e;mDaeC7@06Dad2Ead01ELmEaaG7ELMEcd00emL
00MSG6=KHeaSG6MlIg][N`03KiX2LiT01GNhMiMk]W^dNk<0Dgoo10007Goo001POol0IP00OomC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MD_aC7E;lDaeBo5LMDaaG7E;lFceG75/mEaaK?ELLFceG76MlHe]WO6=KIgaWNf]kJgY_Vf]j
LkU_VGNhMiMk]WNFNkEkTdmoo`@0025oo`00HGoo0P0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m15<M00aG
7E<MEaeC7ELMFcaK?E/lFceK?5lmFc`2He`016MlIg][NfMk0fnJ00QcVG>iMiMg^7^fNkEkTg^fBgoo
10009Goo001SOol0HP00Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<MDaaG?E<LEaeC75LmDaaOGE/lGeeK?5mMFcaO
GFMkJg]WNfnKJgY_VfnILkYgUgNhMiIk]g^DNkI9Ool3000YOol006Aoo`03001C7Dkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<MD_d3
Dad01E;mDaeC7E<MEa`00eLM00QG75LMEaeO?E/lGcaK?6=L0emL0fnJ00=cVG>iMiL00WNh00Ak]WNG
NkIg]TEoo`@002aoo`00IGoo05l007ooC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lEaeBo5LMD_aG7E;lFceG75/mEaaK?ELLHeaO?6=L
GcaSG5llIgaSFfMlKiUc^WNGMkQcUg>jMiMg^7NF049oo`@0031oo`00IWoo0P0000E>oE;mD_eC7Dkm
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00=C7E;mDad00U<M00=B
oE<MDad015<M00UG7E<MEaeG7ELmFcaK?E/lHe`00UmL00ISG6MlHe]SG6MkJg/3KiX01G>iLiUg^7Nf
NkH0?Woo1000=7oo001XOol0F`00OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC
7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E<LEaeBo5LMDaaG7E;lFceG75/mEaaK?ELLFceSFfMlHe][
NfMkJia[NVnKJgYc^W>IMkQcUg^g03]oo`@003Qoo`00JGoo00H007ooD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7@03Ead0
35LLFceK?5/mFcaO?5/lGceK?6]kIg][N`=_VP06LkUcVG>IMkQk]WNf=goo1000?7oo001ZOol0F000
OomC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklEaeBo5<M
D_aG7E;lEaeC75LmDaaG7E<LGeeK?5mMFcaOGE/lHeaO?6=LJgY_Vf]jLkYcVG>iLiMg^7Nf=Goo0`00
@7oo001[Ool20002D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeB
oE<MD_eC7E;m1U<M00UG7ELLEaeG7ELmEaaO?5/lGcd00emL00ESG6=KHeaSG7>i00=cV@03MkQg]W^f
035oo`@004=oo`00KGoo05@007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC
7E;lDaeBo5<MD_aG7E;lEaeBo5LMD_aK?ELLFceG75/mEaaK?EllHeaO?6MlHe]WO6=KJiaWNf]kIg]_
Vg>ILkT^Ool40017Ool006ioo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7E;mDaeBoE<MD_d3Dad02E;mDaeC7ELMDaeG7E<MEceG7002Ead01U/mFcaK?E/lIgaSF`9SG004
Jg]WNf]kIg/2KiX2LiTZOol4001;Ool006moo`1A001oogooDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LFceG75/mEaaK?ELLGeeK?6MlHe][W6Mk
Jg]WNfnKJgYc^FnI02Moo`@004moo`00L7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;m
Dad00e;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMEa`00ULM00]K?E/lFceK?5lmFcaO?5/lJg]W
Nf]k00=_VP9cVBEoo`<005=oo`00LWoo04d004kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<M
C_aC7E;lDaeBo5LMD_aG7E;lEaeC75LMDaaG?E<LEaeK?5mMFcaOGEllHeaO?6=LJgY_Vf]jKi]_VG>j
025oo`@005Ioo`00Lgoo00@005;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@04DaeBoE<M
D_d8Dad01ULmEaaG7ELMEceG709OG007HeaOG5mLHeaWO6=KHe`00W>I7Woo1000FWoo001dOol0B@00
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lEaeBo5LMD_aG7E<LFceG75/m
EaaK?ELLHeaO?6MlHe]WO6=KIgaWNf^L01]oo`@005ioo`00MGoo0P0000IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06DaeBoE<MD_eC7E;m15<M00aG7E<MEaeC7ELMDaeK?E/lFceK?5/mFc`2He`01FMlHe][
NfMkJg/067oo1000HWoo001gOol0A000Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aG7E;l
DaeBo5LMDaaG7E<LEceC75/mEaaK?E/lGeeK?5mMFca[NfMkJi`EOol4001VOol007Qoo`03001C7Dkm
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>
oE;mD_eC7@03D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoELMEaeG7ELL009G7@05GceK?5ll
FcaO?@03Ge`00f=LOomoo`0AOol3001ZOol007Uoo`10001C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC
7E;lEaeBo5LMD_aG7E;lEaeG75/mEaaK?ELLFceO?6=LGcaSG5llHe`@Ool4001]Ool007Yoo`03001o
odkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00=C7E;mD_d00U<M00=BoE<MDad015<M00UG7E<MEaeG7ELmEaaK?E/lFcd0
0emL3Woo1000LGoo001kOol20000>DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeBo5LMDaaG7E;l
EaeG75/mEaaK?ELLFceG700;Ool4001eOol007eoo`06001>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m
15<M00UG7E<MEaeG75LMFcaK?E/lFcd02Goo1000NGoo001nOol0<`00C_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
DaeBo5LMD_aC7E<LEceC75LMDaaG?@08Ool4001mOol007moo`06001ooe;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eBoE;mDaeBoE<M
D_d5Dad00eLLEaeG7@07Ool30021Ool0081oo`80000[Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E;lEad0
1Goo1000Q7oo0022Ool01@00D_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@0:Dae>oE;mD_eC7DkmDaeBoE<MD_d3Dad00e;mDaeC7@05Ool40028Ool008=oo`0R001C7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7Dkl
Dad5Ool4002<Ool008Aoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7E;mD_eBoE<MD_d5Ool4002@Ool008Eoo`80000FC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDad6Ool3002DOol008Moo`04001BoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm17oo1000Ugoo0028Ool04@00C_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDad00Woo1000Vgoo0029Ool01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2Ool4002O
Ool008Yoo`800005Dae>o5<MC_eC7@02Ool4002SOol008aoo`800003Ool0000000800:Moo`00SGoo
0P00Zgoo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolk
Ool00?mooc]oo`00\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08733 .22266 -12 -8.87681 ]
[.08733 .22266 0 .12319 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60704 .01829 -5.08896 -9 ]
[.60704 .01829 .91104 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 12 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 6 3.08658 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01568 .31795 -6 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00248 .4007 -18 -2.85727 ]
[.00248 .4007 0 6.14273 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-2)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(2)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.77428 .13086 m
.77058 .1322 L
s
.79837 .1677 m
.79466 .16902 L
s
.82162 .20326 m
.8179 .20455 L
s
.86578 .27081 m
.86204 .27206 L
s
.88677 .30292 m
.88302 .30414 L
s
.90707 .33398 m
.90332 .33518 L
s
.72342 .05305 m
.71974 .05445 L
s
.69654 .01193 m
.69287 .01336 L
s
.94577 .39318 m
.94201 .39434 L
s
.96423 .4214 m
.96046 .42254 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02795 .31328 m
.03408 .31095 L
s
[(0)] .01568 .31795 1 -0.38067 Mshowa
.01481 .3962 m
.02097 .39395 L
s
[(0.5)] .00248 .4007 1 -0.36505 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02537 .32952 m
.02906 .32813 L
s
.02277 .34593 m
.02646 .34455 L
s
.02014 .36251 m
.02383 .36114 L
s
.01749 .37927 m
.02118 .37791 L
s
.01209 .41332 m
.01579 .41198 L
s
.00935 .43061 m
.01306 .42929 L
s
.00658 .4481 m
.01029 .44678 L
s
.00378 .46577 m
.00749 .46446 L
s
.03049 .29721 m
.03417 .2958 L
s
.03301 .2813 m
.03669 .27988 L
s
.03551 .26555 m
.03918 .26412 L
s
gsave
-0.05457 .39542 -71 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.646 .762 .934 r
.38973 .79902 .39806 .80577 .41196 .80211 .40367 .79532 Mtetra
.646 .763 .934 r
.40367 .79532 .41196 .80211 .42593 .79843 .41769 .79161 Mtetra
.41769 .79161 .42593 .79843 .43997 .79471 .43178 .78786 Mtetra
.647 .763 .934 r
.43178 .78786 .43997 .79471 .45409 .79096 .44595 .78408 Mtetra
.648 .764 .934 r
.44595 .78408 .45409 .79096 .46828 .78714 .46018 .78025 Mtetra
.649 .765 .933 r
.46018 .78025 .46828 .78714 .48255 .78322 .4745 .77635 Mtetra
.652 .767 .933 r
.4745 .77635 .48255 .78322 .49689 .77914 .48889 .77231 Mtetra
.658 .771 .932 r
.48889 .77231 .49689 .77914 .51131 .77474 .50336 .76804 Mtetra
.669 .778 .931 r
.50336 .76804 .51131 .77474 .52579 .76979 .51789 .76336 Mtetra
.689 .791 .928 r
.51789 .76336 .52579 .76979 .54034 .76381 .5325 .75792 Mtetra
.722 .813 .921 r
.5325 .75792 .54034 .76381 .55494 .75598 .54717 .75109 Mtetra
.776 .847 .905 r
.54717 .75109 .55494 .75598 .56954 .74494 .56186 .74179 Mtetra
.848 .89 .868 r
.56186 .74179 .56954 .74494 .58407 .72872 .57653 .72836 Mtetra
.92 .925 .798 r
.57653 .72836 .58407 .72872 .59843 .70521 .59108 .70861 Mtetra
.964 .935 .699 r
.59108 .70861 .59843 .70521 .6125 .67375 .6054 .6809 Mtetra
.97 .924 .605 r
.6054 .6809 .6125 .67375 .62626 .6371 .61939 .64608 Mtetra
.959 .914 .555 r
.61939 .64608 .62626 .6371 .63985 .60121 .63313 .60884 Mtetra
.953 .927 .579 r
.63313 .60884 .63985 .60121 .65348 .57147 .6468 .5754 Mtetra
.951 .954 .68 r
.6468 .5754 .65348 .57147 .6673 .54966 .66059 .54952 Mtetra
.917 .951 .802 r
.66059 .54952 .6673 .54966 .68135 .53455 .67461 .53123 Mtetra
.844 .901 .877 r
.67461 .53123 .68135 .53455 .69562 .52401 .68886 .51858 Mtetra
.774 .842 .904 r
.68886 .51858 .69562 .52401 .71006 .51622 .70331 .50954 Mtetra
.725 .799 .91 r
.70331 .50954 .71006 .51622 .72464 .50997 .71791 .50257 Mtetra
.697 .773 .91 r
.71791 .50257 .72464 .50997 .73934 .50457 .73264 .49676 Mtetra
.681 .758 .91 r
.73264 .49676 .73934 .50457 .75413 .4996 .74748 .49155 Mtetra
.673 .75 .909 r
.74748 .49155 .75413 .4996 .76902 .49486 .76241 .48666 Mtetra
.668 .746 .908 r
.76241 .48666 .76902 .49486 .78399 .49022 .77744 .48192 Mtetra
.666 .744 .908 r
.77744 .48192 .78399 .49022 .79904 .48562 .79254 .47725 Mtetra
.665 .743 .908 r
.79254 .47725 .79904 .48562 .81417 .48104 .80773 .47261 Mtetra
.664 .742 .908 r
.80773 .47261 .81417 .48104 .82939 .47646 .82301 .46797 Mtetra
.82301 .46797 .82939 .47646 .84469 .47186 .83836 .46333 Mtetra
.664 .741 .908 r
.83836 .46333 .84469 .47186 .86006 .46724 .8538 .45866 Mtetra
.8538 .45866 .86006 .46724 .87552 .4626 .86932 .45397 Mtetra
.86932 .45397 .87552 .4626 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.646 .762 .934 r
.38132 .79219 .38973 .79902 .40367 .79532 .39531 .78847 Mtetra
.646 .763 .934 r
.39531 .78847 .40367 .79532 .41769 .79161 .40937 .78472 Mtetra
.40937 .78472 .41769 .79161 .43178 .78786 .42351 .78094 Mtetra
.647 .763 .934 r
.42351 .78094 .43178 .78786 .44595 .78408 .43772 .77714 Mtetra
.43772 .77714 .44595 .78408 .46018 .78025 .45201 .77329 Mtetra
.648 .764 .933 r
.45201 .77329 .46018 .78025 .4745 .77635 .46637 .76938 Mtetra
.651 .766 .933 r
.46637 .76938 .4745 .77635 .48889 .77231 .48081 .76537 Mtetra
.655 .768 .933 r
.48081 .76537 .48889 .77231 .50336 .76804 .49532 .76118 Mtetra
.663 .774 .932 r
.49532 .76118 .50336 .76804 .51789 .76336 .50992 .75669 Mtetra
.677 .784 .93 r
.50992 .75669 .51789 .76336 .5325 .75792 .52458 .75163 Mtetra
.703 .801 .925 r
.52458 .75163 .5325 .75792 .54717 .75109 .53931 .74554 Mtetra
.746 .829 .915 r
.53931 .74554 .54717 .75109 .56186 .74179 .55409 .73758 Mtetra
.81 .868 .89 r
.55409 .73758 .56186 .74179 .57653 .72836 .56887 .72639 Mtetra
.886 .91 .838 r
.56887 .72639 .57653 .72836 .59108 .70861 .58358 .70998 Mtetra
.947 .934 .75 r
.58358 .70998 .59108 .70861 .6054 .6809 .59812 .68623 Mtetra
.971 .931 .648 r
.59812 .68623 .6054 .6809 .61939 .64608 .61237 .65447 Mtetra
.965 .917 .572 r
.61237 .65447 .61939 .64608 .63313 .60884 .62631 .6175 Mtetra
.954 .917 .557 r
.62631 .6175 .63313 .60884 .6468 .5754 .64007 .5813 Mtetra
.953 .941 .622 r
.64007 .5813 .6468 .5754 .66059 .54952 .65386 .5513 Mtetra
.94 .959 .744 r
.65386 .5513 .66059 .54952 .67461 .53123 .66784 .52927 Mtetra
.883 .93 .847 r
.66784 .52927 .67461 .53123 .68886 .51858 .68207 .51399 Mtetra
.807 .87 .894 r
.68207 .51399 .68886 .51858 .70331 .50954 .69651 .50331 Mtetra
.746 .818 .908 r
.69651 .50331 .70331 .50954 .71791 .50257 .71113 .49539 Mtetra
.709 .784 .91 r
.71113 .49539 .71791 .50257 .73264 .49676 .72589 .48902 Mtetra
.688 .764 .91 r
.72589 .48902 .73264 .49676 .74748 .49155 .74077 .4835 Mtetra
.676 .754 .909 r
.74077 .4835 .74748 .49155 .76241 .48666 .75575 .47842 Mtetra
.67 .748 .909 r
.75575 .47842 .76241 .48666 .77744 .48192 .77082 .47357 Mtetra
.667 .745 .908 r
.77082 .47357 .77744 .48192 .79254 .47725 .78599 .46881 Mtetra
.665 .743 .908 r
.78599 .46881 .79254 .47725 .80773 .47261 .80123 .46411 Mtetra
.665 .742 .908 r
.80123 .46411 .80773 .47261 .82301 .46797 .81656 .45941 Mtetra
.664 .742 .908 r
.81656 .45941 .82301 .46797 .83836 .46333 .83197 .45471 Mtetra
.83197 .45471 .83836 .46333 .8538 .45866 .84747 .45 Mtetra
.664 .741 .908 r
.84747 .45 .8538 .45866 .86932 .45397 .86305 .44526 Mtetra
.86305 .44526 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.646 .762 .934 r
.37283 .78531 .38132 .79219 .39531 .78847 .38686 .78154 Mtetra
.38686 .78154 .39531 .78847 .40937 .78472 .40097 .77776 Mtetra
.646 .763 .934 r
.40097 .77776 .40937 .78472 .42351 .78094 .41515 .77395 Mtetra
.41515 .77395 .42351 .78094 .43772 .77714 .42941 .77012 Mtetra
.647 .763 .934 r
.42941 .77012 .43772 .77714 .45201 .77329 .44375 .76624 Mtetra
.648 .764 .934 r
.44375 .76624 .45201 .77329 .46637 .76938 .45816 .76232 Mtetra
.649 .765 .933 r
.45816 .76232 .46637 .76938 .48081 .76537 .47265 .75831 Mtetra
.652 .767 .933 r
.47265 .75831 .48081 .76537 .49532 .76118 .48721 .75418 Mtetra
.658 .771 .932 r
.48721 .75418 .49532 .76118 .50992 .75669 .50186 .74981 Mtetra
.669 .778 .931 r
.50186 .74981 .50992 .75669 .52458 .75163 .51658 .74503 Mtetra
.689 .791 .928 r
.51658 .74503 .52458 .75163 .53931 .74554 .53137 .73947 Mtetra
.722 .813 .921 r
.53137 .73947 .53931 .74554 .55409 .73758 .54621 .73252 Mtetra
.776 .847 .905 r
.54621 .73252 .55409 .73758 .56887 .72639 .56109 .72309 Mtetra
.848 .89 .868 r
.56109 .72309 .56887 .72639 .58358 .70998 .57595 .70948 Mtetra
.92 .925 .798 r
.57595 .70948 .58358 .70998 .59812 .68623 .59068 .68952 Mtetra
.964 .935 .699 r
.59068 .68952 .59812 .68623 .61237 .65447 .60518 .66153 Mtetra
.97 .924 .604 r
.60518 .66153 .61237 .65447 .62631 .6175 .61935 .62641 Mtetra
.959 .914 .555 r
.61935 .62641 .62631 .6175 .64007 .5813 .63326 .58883 Mtetra
.953 .927 .58 r
.63326 .58883 .64007 .5813 .65386 .5513 .6471 .55511 Mtetra
.951 .954 .68 r
.6471 .55511 .65386 .5513 .66784 .52927 .66106 .52899 Mtetra
.917 .951 .802 r
.66106 .52899 .66784 .52927 .68207 .51399 .67525 .5105 Mtetra
.844 .901 .877 r
.67525 .5105 .68207 .51399 .69651 .50331 .68968 .4977 Mtetra
.774 .842 .904 r
.68968 .4977 .69651 .50331 .71113 .49539 .7043 .48851 Mtetra
.725 .799 .91 r
.7043 .48851 .71113 .49539 .72589 .48902 .71909 .48143 Mtetra
.697 .773 .91 r
.71909 .48143 .72589 .48902 .74077 .4835 .734 .47549 Mtetra
.681 .758 .91 r
.734 .47549 .74077 .4835 .75575 .47842 .74903 .47017 Mtetra
.673 .75 .909 r
.74903 .47017 .75575 .47842 .77082 .47357 .76415 .46516 Mtetra
.668 .746 .908 r
.76415 .46516 .77082 .47357 .78599 .46881 .77936 .46031 Mtetra
.666 .744 .908 r
.77936 .46031 .78599 .46881 .80123 .46411 .79467 .45553 Mtetra
.665 .743 .908 r
.79467 .45553 .80123 .46411 .81656 .45941 .81005 .45077 Mtetra
.664 .742 .908 r
.81005 .45077 .81656 .45941 .83197 .45471 .82552 .44601 Mtetra
.82552 .44601 .83197 .45471 .84747 .45 .84108 .44125 Mtetra
.664 .741 .908 r
.84108 .44125 .84747 .45 .86305 .44526 .85671 .43646 Mtetra
.85671 .43646 .86305 .44526 .87871 .4405 .87244 .43166 Mtetra
.87244 .43166 .87871 .4405 .89445 .43572 .88825 .42683 Mtetra
.88825 .42683 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.646 .762 .934 r
.36425 .77835 .37283 .78531 .38686 .78154 .37833 .77455 Mtetra
.37833 .77455 .38686 .78154 .40097 .77776 .39249 .77073 Mtetra
.646 .763 .934 r
.39249 .77073 .40097 .77776 .41515 .77395 .40672 .76689 Mtetra
.40672 .76689 .41515 .77395 .42941 .77012 .42102 .76302 Mtetra
.647 .763 .934 r
.42102 .76302 .42941 .77012 .44375 .76624 .43541 .75912 Mtetra
.43541 .75912 .44375 .76624 .45816 .76232 .44987 .75517 Mtetra
.648 .764 .933 r
.44987 .75517 .45816 .76232 .47265 .75831 .4644 .75117 Mtetra
.651 .766 .933 r
.4644 .75117 .47265 .75831 .48721 .75418 .47902 .74706 Mtetra
.655 .768 .933 r
.47902 .74706 .48721 .75418 .50186 .74981 .49372 .74277 Mtetra
.663 .774 .932 r
.49372 .74277 .50186 .74981 .51658 .74503 .50849 .73817 Mtetra
.677 .784 .93 r
.50849 .73817 .51658 .74503 .53137 .73947 .52334 .73301 Mtetra
.703 .801 .925 r
.52334 .73301 .53137 .73947 .54621 .73252 .53825 .7268 Mtetra
.746 .829 .915 r
.53825 .7268 .54621 .73252 .56109 .72309 .55321 .71871 Mtetra
.81 .868 .89 r
.55321 .71871 .56109 .72309 .57595 .70948 .56818 .70737 Mtetra
.886 .91 .838 r
.56818 .70737 .57595 .70948 .59068 .68952 .58309 .69076 Mtetra
.947 .934 .75 r
.58309 .69076 .59068 .68952 .60518 .66153 .59781 .66677 Mtetra
.971 .931 .648 r
.59781 .66677 .60518 .66153 .61935 .62641 .61224 .63471 Mtetra
.965 .917 .572 r
.61224 .63471 .61935 .62641 .63326 .58883 .62635 .59741 Mtetra
.954 .917 .557 r
.62635 .59741 .63326 .58883 .6471 .55511 .64028 .5609 Mtetra
.954 .941 .623 r
.64028 .5609 .6471 .55511 .66106 .52899 .65425 .53062 Mtetra
.94 .959 .744 r
.65425 .53062 .66106 .52899 .67525 .5105 .66841 .50838 Mtetra
.883 .93 .847 r
.66841 .50838 .67525 .5105 .68968 .4977 .68281 .49293 Mtetra
.807 .87 .894 r
.68281 .49293 .68968 .4977 .7043 .48851 .69743 .48209 Mtetra
.746 .818 .908 r
.69743 .48209 .7043 .48851 .71909 .48143 .71223 .47404 Mtetra
.709 .784 .91 r
.71223 .47404 .71909 .48143 .734 .47549 .72718 .46755 Mtetra
.688 .764 .91 r
.72718 .46755 .734 .47549 .74903 .47017 .74224 .46191 Mtetra
.676 .754 .909 r
.74224 .46191 .74903 .47017 .76415 .46516 .75741 .45672 Mtetra
.67 .748 .909 r
.75741 .45672 .76415 .46516 .77936 .46031 .77268 .45174 Mtetra
.667 .745 .908 r
.77268 .45174 .77936 .46031 .79467 .45553 .78804 .44687 Mtetra
.665 .743 .908 r
.78804 .44687 .79467 .45553 .81005 .45077 .80348 .44205 Mtetra
.665 .742 .908 r
.80348 .44205 .81005 .45077 .82552 .44601 .81901 .43724 Mtetra
.664 .742 .908 r
.81901 .43724 .82552 .44601 .84108 .44125 .83462 .43242 Mtetra
.83462 .43242 .84108 .44125 .85671 .43646 .85032 .42758 Mtetra
.664 .741 .908 r
.85032 .42758 .85671 .43646 .87244 .43166 .8661 .42272 Mtetra
.8661 .42272 .87244 .43166 .88825 .42683 .88197 .41784 Mtetra
.88197 .41784 .88825 .42683 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Mtetra
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.646 .762 .934 r
.35559 .77133 .36425 .77835 .37833 .77455 .36972 .76749 Mtetra
.36972 .76749 .37833 .77455 .39249 .77073 .38392 .76364 Mtetra
.38392 .76364 .39249 .77073 .40672 .76689 .3982 .75976 Mtetra
.646 .763 .934 r
.3982 .75976 .40672 .76689 .42102 .76302 .41255 .75585 Mtetra
.41255 .75585 .42102 .76302 .43541 .75912 .42699 .75192 Mtetra
.647 .763 .934 r
.42699 .75192 .43541 .75912 .44987 .75517 .44149 .74795 Mtetra
.648 .764 .934 r
.44149 .74795 .44987 .75517 .4644 .75117 .45608 .74393 Mtetra
.649 .765 .933 r
.45608 .74393 .4644 .75117 .47902 .74706 .47075 .73982 Mtetra
.652 .767 .933 r
.47075 .73982 .47902 .74706 .49372 .74277 .48549 .73559 Mtetra
.658 .771 .932 r
.48549 .73559 .49372 .74277 .50849 .73817 .50032 .73112 Mtetra
.669 .778 .931 r
.50032 .73112 .50849 .73817 .52334 .73301 .51522 .72622 Mtetra
.689 .791 .928 r
.51522 .72622 .52334 .73301 .53825 .7268 .5302 .72056 Mtetra
.722 .813 .921 r
.5302 .72056 .53825 .7268 .55321 .71871 .54524 .71348 Mtetra
.776 .848 .905 r
.54524 .71348 .55321 .71871 .56818 .70737 .5603 .70391 Mtetra
.848 .89 .868 r
.5603 .70391 .56818 .70737 .58309 .69076 .57535 .69012 Mtetra
.921 .926 .798 r
.57535 .69012 .58309 .69076 .59781 .66677 .59027 .66994 Mtetra
.964 .935 .698 r
.59027 .66994 .59781 .66677 .61224 .63471 .60496 .64168 Mtetra
.97 .924 .604 r
.60496 .64168 .61224 .63471 .62635 .59741 .61931 .60623 Mtetra
.959 .914 .555 r
.61931 .60623 .62635 .59741 .64028 .5609 .6334 .56833 Mtetra
.953 .927 .58 r
.6334 .56833 .64028 .5609 .65425 .53062 .6474 .53431 Mtetra
.951 .954 .681 r
.6474 .53431 .65425 .53062 .66841 .50838 .66154 .50794 Mtetra
.917 .951 .802 r
.66154 .50794 .66841 .50838 .68281 .49293 .67591 .48925 Mtetra
.844 .901 .877 r
.67591 .48925 .68281 .49293 .69743 .48209 .69051 .47629 Mtetra
.774 .842 .904 r
.69051 .47629 .69743 .48209 .71223 .47404 .70532 .46697 Mtetra
.725 .799 .91 r
.70532 .46697 .71223 .47404 .72718 .46755 .72029 .45975 Mtetra
.697 .773 .91 r
.72029 .45975 .72718 .46755 .74224 .46191 .7354 .45369 Mtetra
.681 .758 .91 r
.7354 .45369 .74224 .46191 .75741 .45672 .75061 .44825 Mtetra
.673 .75 .909 r
.75061 .44825 .75741 .45672 .77268 .45174 .76593 .44312 Mtetra
.668 .746 .908 r
.76593 .44312 .77268 .45174 .78804 .44687 .78134 .43815 Mtetra
.666 .744 .908 r
.78134 .43815 .78804 .44687 .80348 .44205 .79684 .43325 Mtetra
.665 .743 .908 r
.79684 .43325 .80348 .44205 .81901 .43724 .81243 .42837 Mtetra
.664 .742 .908 r
.81243 .42837 .81901 .43724 .83462 .43242 .8281 .4235 Mtetra
.8281 .4235 .83462 .43242 .85032 .42758 .84386 .41861 Mtetra
.664 .741 .908 r
.84386 .41861 .85032 .42758 .8661 .42272 .85971 .4137 Mtetra
.85971 .4137 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Mtetra
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Mtetra
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Mtetra
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.646 .762 .934 r
.34685 .76424 .35559 .77133 .36972 .76749 .36102 .76036 Mtetra
.36102 .76036 .36972 .76749 .38392 .76364 .37527 .75647 Mtetra
.37527 .75647 .38392 .76364 .3982 .75976 .3896 .75255 Mtetra
.646 .763 .934 r
.3896 .75255 .3982 .75976 .41255 .75585 .404 .74861 Mtetra
.404 .74861 .41255 .75585 .42699 .75192 .41848 .74465 Mtetra
.647 .763 .934 r
.41848 .74465 .42699 .75192 .44149 .74795 .43304 .74065 Mtetra
.43304 .74065 .44149 .74795 .45608 .74393 .44767 .7366 Mtetra
.648 .764 .933 r
.44767 .7366 .45608 .74393 .47075 .73982 .46239 .73249 Mtetra
.651 .766 .933 r
.46239 .73249 .47075 .73982 .48549 .73559 .47719 .72828 Mtetra
.655 .768 .933 r
.47719 .72828 .48549 .73559 .50032 .73112 .49207 .72389 Mtetra
.663 .774 .932 r
.49207 .72389 .50032 .73112 .51522 .72622 .50702 .71919 Mtetra
.677 .784 .93 r
.50702 .71919 .51522 .72622 .5302 .72056 .52206 .71391 Mtetra
.703 .801 .926 r
.52206 .71391 .5302 .72056 .54524 .71348 .53716 .70758 Mtetra
.746 .829 .915 r
.53716 .70758 .54524 .71348 .5603 .70391 .55232 .69936 Mtetra
.81 .869 .89 r
.55232 .69936 .5603 .70391 .57535 .69012 .56748 .68785 Mtetra
.886 .91 .838 r
.56748 .68785 .57535 .69012 .59027 .66994 .58258 .67105 Mtetra
.947 .934 .75 r
.58258 .67105 .59027 .66994 .60496 .64168 .59749 .6468 Mtetra
.971 .931 .648 r
.59749 .6468 .60496 .64168 .61931 .60623 .61211 .61444 Mtetra
.965 .917 .572 r
.61211 .61444 .61931 .60623 .6334 .56833 .6264 .57681 Mtetra
.955 .917 .557 r
.6264 .57681 .6334 .56833 .6474 .53431 .64051 .53998 Mtetra
.954 .941 .623 r
.64051 .53998 .6474 .53431 .66154 .50794 .65465 .50943 Mtetra
.94 .959 .744 r
.65465 .50943 .66154 .50794 .67591 .48925 .66898 .48697 Mtetra
.883 .93 .847 r
.66898 .48697 .67591 .48925 .69051 .47629 .68356 .47133 Mtetra
.807 .87 .894 r
.68356 .47133 .69051 .47629 .70532 .46697 .69836 .46034 Mtetra
.746 .818 .908 r
.69836 .46034 .70532 .46697 .72029 .45975 .71335 .45216 Mtetra
.709 .784 .91 r
.71335 .45216 .72029 .45975 .7354 .45369 .72849 .44554 Mtetra
.688 .764 .91 r
.72849 .44554 .7354 .45369 .75061 .44825 .74375 .43978 Mtetra
.676 .754 .909 r
.74375 .43978 .75061 .44825 .76593 .44312 .75912 .43446 Mtetra
.67 .748 .909 r
.75912 .43446 .76593 .44312 .78134 .43815 .77458 .42936 Mtetra
.667 .745 .908 r
.77458 .42936 .78134 .43815 .79684 .43325 .79014 .42437 Mtetra
.665 .743 .908 r
.79014 .42437 .79684 .43325 .81243 .42837 .80578 .41943 Mtetra
.665 .742 .908 r
.80578 .41943 .81243 .42837 .8281 .4235 .82152 .41449 Mtetra
.664 .742 .908 r
.82152 .41449 .8281 .4235 .84386 .41861 .83734 .40955 Mtetra
.83734 .40955 .84386 .41861 .85971 .4137 .85324 .40459 Mtetra
.664 .741 .908 r
.85324 .40459 .85971 .4137 .87564 .40877 .86924 .39961 Mtetra
.86924 .39961 .87564 .40877 .89166 .40381 .88532 .3946 Mtetra
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38957 Mtetra
.9015 .38957 .90777 .39883 .92396 .39382 .91776 .38451 Mtetra
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Mtetra
.646 .762 .934 r
.33802 .75707 .34685 .76424 .36102 .76036 .35224 .75316 Mtetra
.35224 .75316 .36102 .76036 .37527 .75647 .36654 .74923 Mtetra
.36654 .74923 .37527 .75647 .3896 .75255 .38091 .74528 Mtetra
.38091 .74528 .3896 .75255 .404 .74861 .39536 .7413 Mtetra
.646 .763 .934 r
.39536 .7413 .404 .74861 .41848 .74465 .40989 .7373 Mtetra
.40989 .7373 .41848 .74465 .43304 .74065 .4245 .73326 Mtetra
.647 .763 .934 r
.4245 .73326 .43304 .74065 .44767 .7366 .43918 .72919 Mtetra
.648 .764 .934 r
.43918 .72919 .44767 .7366 .46239 .73249 .45395 .72507 Mtetra
.649 .765 .933 r
.45395 .72507 .46239 .73249 .47719 .72828 .4688 .72086 Mtetra
.652 .767 .933 r
.4688 .72086 .47719 .72828 .49207 .72389 .48373 .71652 Mtetra
.658 .771 .932 r
.48373 .71652 .49207 .72389 .50702 .71919 .49874 .71194 Mtetra
.669 .778 .931 r
.49874 .71194 .50702 .71919 .52206 .71391 .51383 .70694 Mtetra
.689 .791 .928 r
.51383 .70694 .52206 .71391 .53716 .70758 .529 .70115 Mtetra
.722 .813 .921 r
.529 .70115 .53716 .70758 .55232 .69936 .54423 .69395 Mtetra
.776 .848 .905 r
.54423 .69395 .55232 .69936 .56748 .68785 .5595 .68422 Mtetra
.848 .89 .868 r
.5595 .68422 .56748 .68785 .58258 .67105 .57474 .67026 Mtetra
.921 .926 .798 r
.57474 .67026 .58258 .67105 .59749 .6468 .58986 .64985 Mtetra
.964 .936 .698 r
.58986 .64985 .59749 .6468 .61211 .61444 .60473 .62131 Mtetra
.97 .924 .604 r
.60473 .62131 .61211 .61444 .6264 .57681 .61927 .58554 Mtetra
.959 .914 .555 r
.61927 .58554 .6264 .57681 .64051 .53998 .63353 .5473 Mtetra
.954 .927 .581 r
.63353 .5473 .64051 .53998 .65465 .50943 .64772 .51298 Mtetra
.951 .954 .681 r
.64772 .51298 .65465 .50943 .66898 .48697 .66203 .48636 Mtetra
.917 .951 .802 r
.66203 .48636 .66898 .48697 .68356 .47133 .67658 .46747 Mtetra
.844 .901 .877 r
.67658 .46747 .68356 .47133 .69836 .46034 .69137 .45435 Mtetra
.774 .842 .904 r
.69137 .45435 .69836 .46034 .71335 .45216 .70636 .44488 Mtetra
.725 .799 .91 r
.70636 .44488 .71335 .45216 .72849 .44554 .72153 .43753 Mtetra
.697 .773 .91 r
.72153 .43753 .72849 .44554 .74375 .43978 .73683 .43134 Mtetra
.681 .758 .909 r
.73683 .43134 .74375 .43978 .75912 .43446 .75224 .42577 Mtetra
.673 .75 .909 r
.75224 .42577 .75912 .43446 .77458 .42936 .76776 .42052 Mtetra
.668 .746 .908 r
.76776 .42052 .77458 .42936 .79014 .42437 .78337 .41543 Mtetra
.666 .744 .908 r
.78337 .41543 .79014 .42437 .80578 .41943 .79907 .4104 Mtetra
.665 .743 .908 r
.79907 .4104 .80578 .41943 .82152 .41449 .81487 .4054 Mtetra
.664 .742 .908 r
.81487 .4054 .82152 .41449 .83734 .40955 .83075 .4004 Mtetra
.83075 .4004 .83734 .40955 .85324 .40459 .84672 .39538 Mtetra
.664 .741 .908 r
.84672 .39538 .85324 .40459 .86924 .39961 .86278 .39035 Mtetra
.86278 .39035 .86924 .39961 .88532 .3946 .87892 .38529 Mtetra
.87892 .38529 .88532 .3946 .9015 .38957 .89516 .3802 Mtetra
.89516 .3802 .9015 .38957 .91776 .38451 .91149 .37509 Mtetra
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Mtetra
.646 .762 .934 r
.32911 .74984 .33802 .75707 .35224 .75316 .34337 .74589 Mtetra
.34337 .74589 .35224 .75316 .36654 .74923 .35771 .74192 Mtetra
.35771 .74192 .36654 .74923 .38091 .74528 .37213 .73793 Mtetra
.37213 .73793 .38091 .74528 .39536 .7413 .38663 .73391 Mtetra
.646 .763 .934 r
.38663 .73391 .39536 .7413 .40989 .7373 .40121 .72987 Mtetra
.40121 .72987 .40989 .7373 .4245 .73326 .41587 .7258 Mtetra
.647 .763 .934 r
.41587 .7258 .4245 .73326 .43918 .72919 .43061 .7217 Mtetra
.43061 .7217 .43918 .72919 .45395 .72507 .44542 .71755 Mtetra
.648 .764 .933 r
.44542 .71755 .45395 .72507 .4688 .72086 .46033 .71334 Mtetra
.651 .766 .933 r
.46033 .71334 .4688 .72086 .48373 .71652 .47531 .70902 Mtetra
.655 .768 .933 r
.47531 .70902 .48373 .71652 .49874 .71194 .49037 .70452 Mtetra
.663 .774 .932 r
.49037 .70452 .49874 .71194 .51383 .70694 .50552 .69971 Mtetra
.677 .784 .93 r
.50552 .69971 .51383 .70694 .529 .70115 .52075 .69431 Mtetra
.703 .801 .926 r
.52075 .69431 .529 .70115 .54423 .69395 .53605 .68786 Mtetra
.746 .829 .915 r
.53605 .68786 .54423 .69395 .5595 .68422 .5514 .67949 Mtetra
.81 .869 .891 r
.5514 .67949 .5595 .68422 .57474 .67026 .56676 .66782 Mtetra
.886 .911 .838 r
.56676 .66782 .57474 .67026 .58986 .64985 .58206 .65082 Mtetra
.947 .934 .75 r
.58206 .65082 .58986 .64985 .60473 .62131 .59717 .62632 Mtetra
.971 .931 .647 r
.59717 .62632 .60473 .62131 .61927 .58554 .61197 .59365 Mtetra
.965 .917 .572 r
.61197 .59365 .61927 .58554 .63353 .5473 .62645 .55568 Mtetra
.955 .918 .558 r
.62645 .55568 .63353 .5473 .64772 .51298 .64074 .51852 Mtetra
.954 .941 .624 r
.64074 .51852 .64772 .51298 .66203 .48636 .65505 .48769 Mtetra
.94 .959 .744 r
.65505 .48769 .66203 .48636 .67658 .46747 .66957 .46501 Mtetra
.883 .929 .847 r
.66957 .46501 .67658 .46747 .69137 .45435 .68433 .44919 Mtetra
.807 .87 .894 r
.68433 .44919 .69137 .45435 .70636 .44488 .69933 .43805 Mtetra
.746 .818 .908 r
.69933 .43805 .70636 .44488 .72153 .43753 .71451 .42972 Mtetra
.709 .784 .91 r
.71451 .42972 .72153 .43753 .73683 .43134 .72984 .42297 Mtetra
.688 .764 .91 r
.72984 .42297 .73683 .43134 .75224 .42577 .7453 .41708 Mtetra
.676 .754 .909 r
.7453 .41708 .75224 .42577 .76776 .42052 .76087 .41163 Mtetra
.67 .748 .909 r
.76087 .41163 .76776 .42052 .78337 .41543 .77653 .40641 Mtetra
.667 .745 .908 r
.77653 .40641 .78337 .41543 .79907 .4104 .79229 .4013 Mtetra
.665 .743 .908 r
.79229 .4013 .79907 .4104 .81487 .4054 .80815 .39622 Mtetra
.665 .742 .908 r
.80815 .39622 .81487 .4054 .83075 .4004 .82409 .39116 Mtetra
.664 .742 .908 r
.82409 .39116 .83075 .4004 .84672 .39538 .84012 .38609 Mtetra
.84012 .38609 .84672 .39538 .86278 .39035 .85625 .381 Mtetra
.664 .741 .908 r
.85625 .381 .86278 .39035 .87892 .38529 .87246 .37589 Mtetra
.87246 .37589 .87892 .38529 .89516 .3802 .88876 .37075 Mtetra
.88876 .37075 .89516 .3802 .91149 .37509 .90516 .36558 Mtetra
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Mtetra
.646 .762 .934 r
.3201 .74254 .32911 .74984 .34337 .74589 .33441 .73855 Mtetra
.33441 .73855 .34337 .74589 .35771 .74192 .3488 .73454 Mtetra
.3488 .73454 .35771 .74192 .37213 .73793 .36327 .73051 Mtetra
.36327 .73051 .37213 .73793 .38663 .73391 .37782 .72645 Mtetra
.37782 .72645 .38663 .73391 .40121 .72987 .39245 .72237 Mtetra
.646 .763 .934 r
.39245 .72237 .40121 .72987 .41587 .7258 .40715 .71826 Mtetra
.40715 .71826 .41587 .7258 .43061 .7217 .42194 .71413 Mtetra
.647 .763 .934 r
.42194 .71413 .43061 .7217 .44542 .71755 .43681 .70995 Mtetra
.648 .764 .934 r
.43681 .70995 .44542 .71755 .46033 .71334 .45176 .70572 Mtetra
.649 .765 .933 r
.45176 .70572 .46033 .71334 .47531 .70902 .4668 .7014 Mtetra
.652 .767 .933 r
.4668 .7014 .47531 .70902 .49037 .70452 .48192 .69695 Mtetra
.658 .771 .932 r
.48192 .69695 .49037 .70452 .50552 .69971 .49712 .69226 Mtetra
.669 .778 .931 r
.49712 .69226 .50552 .69971 .52075 .69431 .51241 .68714 Mtetra
.689 .791 .928 r
.51241 .68714 .52075 .69431 .53605 .68786 .52777 .68123 Mtetra
.722 .813 .922 r
.52777 .68123 .53605 .68786 .5514 .67949 .5432 .6739 Mtetra
.776 .848 .905 r
.5432 .6739 .5514 .67949 .56676 .66782 .55866 .66402 Mtetra
.848 .891 .869 r
.55866 .66402 .56676 .66782 .58206 .65082 .57411 .64987 Mtetra
.921 .926 .798 r
.57411 .64987 .58206 .65082 .59717 .62632 .58943 .62923 Mtetra
.964 .936 .698 r
.58943 .62923 .59717 .62632 .61197 .59365 .6045 .60041 Mtetra
.97 .924 .604 r
.6045 .60041 .61197 .59365 .62645 .55568 .61923 .5643 Mtetra
.959 .914 .555 r
.61923 .5643 .62645 .55568 .64074 .51852 .63368 .52573 Mtetra
.954 .927 .581 r
.63368 .52573 .64074 .51852 .65505 .48769 .64804 .4911 Mtetra
.951 .954 .681 r
.64804 .4911 .65505 .48769 .66957 .46501 .66253 .46423 Mtetra
.917 .95 .802 r
.66253 .46423 .66957 .46501 .68433 .44919 .67727 .44514 Mtetra
.844 .9 .877 r
.67727 .44514 .68433 .44919 .69933 .43805 .69225 .43184 Mtetra
.774 .842 .903 r
.69225 .43184 .69933 .43805 .71451 .42972 .70743 .42222 Mtetra
.725 .799 .91 r
.70743 .42222 .71451 .42972 .72984 .42297 .72279 .41473 Mtetra
.697 .773 .91 r
.72279 .41473 .72984 .42297 .7453 .41708 .73829 .40841 Mtetra
.681 .758 .909 r
.73829 .40841 .7453 .41708 .76087 .41163 .75391 .40272 Mtetra
.673 .75 .909 r
.75391 .40272 .76087 .41163 .77653 .40641 .76963 .39734 Mtetra
.668 .746 .908 r
.76963 .39734 .77653 .40641 .79229 .4013 .78545 .39212 Mtetra
.666 .744 .908 r
.78545 .39212 .79229 .4013 .80815 .39622 .80136 .38696 Mtetra
.665 .743 .908 r
.80136 .38696 .80815 .39622 .82409 .39116 .81737 .38183 Mtetra
.664 .742 .908 r
.81737 .38183 .82409 .39116 .84012 .38609 .83346 .3767 Mtetra
.83346 .3767 .84012 .38609 .85625 .381 .84965 .37155 Mtetra
.664 .741 .908 r
.84965 .37155 .85625 .381 .87246 .37589 .86593 .36639 Mtetra
.86593 .36639 .87246 .37589 .88876 .37075 .8823 .36119 Mtetra
.8823 .36119 .88876 .37075 .90516 .36558 .89876 .35597 Mtetra
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Mtetra
.646 .762 .934 r
.31101 .73516 .3201 .74254 .33441 .73855 .32537 .73113 Mtetra
.32537 .73113 .33441 .73855 .3488 .73454 .3398 .72708 Mtetra
.3398 .72708 .3488 .73454 .36327 .73051 .35432 .72301 Mtetra
.35432 .72301 .36327 .73051 .37782 .72645 .36892 .71891 Mtetra
.36892 .71891 .37782 .72645 .39245 .72237 .38359 .71479 Mtetra
.646 .763 .934 r
.38359 .71479 .39245 .72237 .40715 .71826 .39835 .71065 Mtetra
.39835 .71065 .40715 .71826 .42194 .71413 .41319 .70647 Mtetra
.647 .763 .934 r
.41319 .70647 .42194 .71413 .43681 .70995 .42811 .70226 Mtetra
.42811 .70226 .43681 .70995 .45176 .70572 .44312 .698 Mtetra
.648 .764 .933 r
.44312 .698 .45176 .70572 .4668 .7014 .45821 .69368 Mtetra
.651 .766 .933 r
.45821 .69368 .4668 .7014 .48192 .69695 .47338 .68925 Mtetra
.655 .768 .933 r
.47338 .68925 .48192 .69695 .49712 .69226 .48864 .68464 Mtetra
.663 .774 .932 r
.48864 .68464 .49712 .69226 .51241 .68714 .50398 .67971 Mtetra
.677 .784 .93 r
.50398 .67971 .51241 .68714 .52777 .68123 .51941 .67419 Mtetra
.703 .801 .926 r
.51941 .67419 .52777 .68123 .5432 .6739 .5349 .66761 Mtetra
.746 .829 .915 r
.5349 .66761 .5432 .6739 .55866 .66402 .55046 .65911 Mtetra
.81 .869 .891 r
.55046 .65911 .55866 .66402 .57411 .64987 .56602 .64727 Mtetra
.886 .911 .838 r
.56602 .64727 .57411 .64987 .58943 .62923 .58152 .63005 Mtetra
.947 .935 .75 r
.58152 .63005 .58943 .62923 .6045 .60041 .59683 .60529 Mtetra
.971 .931 .647 r
.59683 .60529 .6045 .60041 .61923 .5643 .61184 .57231 Mtetra
.965 .917 .571 r
.61184 .57231 .61923 .5643 .63368 .52573 .6265 .534 Mtetra
.955 .918 .558 r
.6265 .534 .63368 .52573 .64804 .4911 .64097 .49651 Mtetra
.954 .941 .624 r
.64097 .49651 .64804 .4911 .66253 .46423 .65547 .4654 Mtetra
.94 .959 .745 r
.65547 .4654 .66253 .46423 .67727 .44514 .67017 .44248 Mtetra
.883 .929 .847 r
.67017 .44248 .67727 .44514 .69225 .43184 .68513 .42648 Mtetra
.807 .87 .894 r
.68513 .42648 .69225 .43184 .70743 .42222 .70031 .41517 Mtetra
.746 .818 .908 r
.70031 .41517 .70743 .42222 .72279 .41473 .71569 .4067 Mtetra
.709 .784 .91 r
.71569 .4067 .72279 .41473 .73829 .40841 .73122 .39982 Mtetra
.688 .764 .91 r
.73122 .39982 .73829 .40841 .75391 .40272 .74689 .39379 Mtetra
.676 .754 .909 r
.74689 .39379 .75391 .40272 .76963 .39734 .76266 .38822 Mtetra
.67 .748 .909 r
.76266 .38822 .76963 .39734 .78545 .39212 .77853 .38287 Mtetra
.667 .745 .908 r
.77853 .38287 .78545 .39212 .80136 .38696 .79451 .37762 Mtetra
.665 .743 .908 r
.79451 .37762 .80136 .38696 .81737 .38183 .81057 .37241 Mtetra
.665 .742 .908 r
.81057 .37241 .81737 .38183 .83346 .3767 .82673 .36722 Mtetra
.664 .742 .908 r
.82673 .36722 .83346 .3767 .84965 .37155 .84298 .36201 Mtetra
.84298 .36201 .84965 .37155 .86593 .36639 .85933 .35679 Mtetra
.664 .741 .908 r
.85933 .35679 .86593 .36639 .8823 .36119 .87576 .35154 Mtetra
.87576 .35154 .8823 .36119 .89876 .35597 .89229 .34626 Mtetra
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Mtetra
.646 .762 .934 r
.30182 .72771 .31101 .73516 .32537 .73113 .31623 .72364 Mtetra
.31623 .72364 .32537 .73113 .3398 .72708 .33071 .71955 Mtetra
.33071 .71955 .3398 .72708 .35432 .72301 .34528 .71543 Mtetra
.34528 .71543 .35432 .72301 .36892 .71891 .35992 .7113 Mtetra
.35992 .7113 .36892 .71891 .38359 .71479 .37465 .70713 Mtetra
.37465 .70713 .38359 .71479 .39835 .71065 .38946 .70295 Mtetra
.646 .763 .934 r
.38946 .70295 .39835 .71065 .41319 .70647 .40435 .69873 Mtetra
.40435 .69873 .41319 .70647 .42811 .70226 .41932 .69449 Mtetra
.647 .763 .934 r
.41932 .69449 .42811 .70226 .44312 .698 .43438 .6902 Mtetra
.648 .764 .934 r
.43438 .6902 .44312 .698 .45821 .69368 .44952 .68586 Mtetra
.649 .765 .933 r
.44952 .68586 .45821 .69368 .47338 .68925 .46475 .68143 Mtetra
.652 .767 .933 r
.46475 .68143 .47338 .68925 .48864 .68464 .48006 .67687 Mtetra
.658 .771 .932 r
.48006 .67687 .48864 .68464 .50398 .67971 .49546 .67206 Mtetra
.669 .778 .931 r
.49546 .67206 .50398 .67971 .51941 .67419 .51095 .66682 Mtetra
.689 .791 .928 r
.51095 .66682 .51941 .67419 .5349 .66761 .52651 .66079 Mtetra
.722 .814 .922 r
.52651 .66079 .5349 .66761 .55046 .65911 .54214 .65331 Mtetra
.776 .848 .906 r
.54214 .65331 .55046 .65911 .56602 .64727 .55781 .64328 Mtetra
.848 .891 .869 r
.55781 .64328 .56602 .64727 .58152 .63005 .57346 .62894 Mtetra
.921 .926 .797 r
.57346 .62894 .58152 .63005 .59683 .60529 .58898 .60807 Mtetra
.964 .936 .698 r
.58898 .60807 .59683 .60529 .61184 .57231 .60426 .57895 Mtetra
.97 .924 .603 r
.60426 .57895 .61184 .57231 .6265 .534 .61918 .54251 Mtetra
.959 .914 .555 r
.61918 .54251 .6265 .534 .64097 .49651 .63382 .50359 Mtetra
.954 .927 .581 r
.63382 .50359 .64097 .49651 .65547 .4654 .64837 .46865 Mtetra
.952 .954 .682 r
.64837 .46865 .65547 .4654 .67017 .44248 .66305 .44153 Mtetra
.917 .95 .802 r
.66305 .44153 .67017 .44248 .68513 .42648 .67797 .42222 Mtetra
.844 .9 .877 r
.67797 .42222 .68513 .42648 .70031 .41517 .69315 .40875 Mtetra
.774 .842 .903 r
.69315 .40875 .70031 .41517 .71569 .4067 .70853 .39898 Mtetra
.725 .799 .91 r
.70853 .39898 .71569 .4067 .73122 .39982 .72409 .39135 Mtetra
.697 .773 .91 r
.72409 .39135 .73122 .39982 .74689 .39379 .7398 .38489 Mtetra
.681 .758 .909 r
.7398 .38489 .74689 .39379 .76266 .38822 .75562 .37906 Mtetra
.673 .75 .909 r
.75562 .37906 .76266 .38822 .77853 .38287 .77155 .37355 Mtetra
.668 .746 .908 r
.77155 .37355 .77853 .38287 .79451 .37762 .78758 .36819 Mtetra
.666 .744 .908 r
.78758 .36819 .79451 .37762 .81057 .37241 .80371 .36291 Mtetra
.665 .743 .908 r
.80371 .36291 .81057 .37241 .82673 .36722 .81993 .35764 Mtetra
.664 .742 .908 r
.81993 .35764 .82673 .36722 .84298 .36201 .83625 .35237 Mtetra
.83625 .35237 .84298 .36201 .85933 .35679 .85266 .34709 Mtetra
.664 .741 .908 r
.85266 .34709 .85933 .35679 .87576 .35154 .86916 .34178 Mtetra
.86916 .34178 .87576 .35154 .89229 .34626 .88576 .33645 Mtetra
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Mtetra
.646 .762 .934 r
.29254 .72018 .30182 .72771 .31623 .72364 .30699 .71607 Mtetra
.30699 .71607 .31623 .72364 .33071 .71955 .32153 .71194 Mtetra
.32153 .71194 .33071 .71955 .34528 .71543 .33614 .70778 Mtetra
.33614 .70778 .34528 .71543 .35992 .7113 .35084 .7036 Mtetra
.35084 .7036 .35992 .7113 .37465 .70713 .36561 .6994 Mtetra
.36561 .6994 .37465 .70713 .38946 .70295 .38047 .69517 Mtetra
.646 .763 .934 r
.38047 .69517 .38946 .70295 .40435 .69873 .39542 .69092 Mtetra
.39542 .69092 .40435 .69873 .41932 .69449 .41044 .68663 Mtetra
.647 .763 .934 r
.41044 .68663 .41932 .69449 .43438 .6902 .42555 .68231 Mtetra
.42555 .68231 .43438 .6902 .44952 .68586 .44075 .67794 Mtetra
.648 .764 .933 r
.44075 .67794 .44952 .68586 .46475 .68143 .45603 .6735 Mtetra
.651 .766 .933 r
.45603 .6735 .46475 .68143 .48006 .67687 .4714 .66896 Mtetra
.655 .768 .933 r
.4714 .66896 .48006 .67687 .49546 .67206 .48685 .66423 Mtetra
.663 .774 .932 r
.48685 .66423 .49546 .67206 .51095 .66682 .5024 .65918 Mtetra
.677 .784 .93 r
.5024 .65918 .51095 .66682 .52651 .66079 .51803 .65354 Mtetra
.703 .801 .926 r
.51803 .65354 .52651 .66079 .54214 .65331 .53373 .64682 Mtetra
.746 .829 .915 r
.53373 .64682 .54214 .65331 .55781 .64328 .54949 .63817 Mtetra
.81 .869 .891 r
.54949 .63817 .55781 .64328 .57346 .62894 .56526 .62616 Mtetra
.886 .911 .838 r
.56526 .62616 .57346 .62894 .58898 .60807 .58097 .60873 Mtetra
.947 .935 .749 r
.58097 .60873 .58898 .60807 .60426 .57895 .59649 .58371 Mtetra
.971 .931 .647 r
.59649 .58371 .60426 .57895 .61918 .54251 .61169 .5504 Mtetra
.965 .917 .571 r
.61169 .5504 .61918 .54251 .63382 .50359 .62656 .51174 Mtetra
.955 .918 .558 r
.62656 .51174 .63382 .50359 .64837 .46865 .64121 .47392 Mtetra
.954 .941 .624 r
.64121 .47392 .64837 .46865 .66305 .44153 .6559 .44252 Mtetra
.94 .959 .745 r
.6559 .44252 .66305 .44153 .67797 .42222 .67079 .41937 Mtetra
.883 .929 .847 r
.67079 .41937 .67797 .42222 .69315 .40875 .68594 .40318 Mtetra
.807 .87 .894 r
.68594 .40318 .69315 .40875 .70853 .39898 .70132 .39171 Mtetra
.746 .818 .908 r
.70132 .39171 .70853 .39898 .72409 .39135 .71691 .38308 Mtetra
.709 .784 .91 r
.71691 .38308 .72409 .39135 .7398 .38489 .73264 .37606 Mtetra
.688 .764 .91 r
.73264 .37606 .7398 .38489 .75562 .37906 .74851 .3699 Mtetra
.676 .754 .909 r
.74851 .3699 .75562 .37906 .77155 .37355 .7645 .36418 Mtetra
.67 .748 .909 r
.7645 .36418 .77155 .37355 .78758 .36819 .78059 .3587 Mtetra
.667 .745 .908 r
.78059 .3587 .78758 .36819 .80371 .36291 .79678 .35331 Mtetra
.665 .743 .908 r
.79678 .35331 .80371 .36291 .81993 .35764 .81306 .34797 Mtetra
.665 .742 .908 r
.81306 .34797 .81993 .35764 .83625 .35237 .82944 .34264 Mtetra
.664 .742 .908 r
.82944 .34264 .83625 .35237 .85266 .34709 .84592 .33729 Mtetra
.84592 .33729 .85266 .34709 .86916 .34178 .86249 .33193 Mtetra
.664 .741 .908 r
.86249 .33193 .86916 .34178 .88576 .33645 .87915 .32654 Mtetra
.87915 .32654 .88576 .33645 .90245 .33109 .89591 .32112 Mtetra
.646 .762 .934 r
.28317 .71257 .29254 .72018 .30699 .71607 .29767 .70842 Mtetra
.29767 .70842 .30699 .71607 .32153 .71194 .31225 .70425 Mtetra
.31225 .70425 .32153 .71194 .33614 .70778 .32691 .70005 Mtetra
.32691 .70005 .33614 .70778 .35084 .7036 .34166 .69583 Mtetra
.34166 .69583 .35084 .7036 .36561 .6994 .35649 .69158 Mtetra
.35649 .69158 .36561 .6994 .38047 .69517 .3714 .68731 Mtetra
.3714 .68731 .38047 .69517 .39542 .69092 .38639 .68301 Mtetra
.646 .763 .934 r
.38639 .68301 .39542 .69092 .41044 .68663 .40147 .67869 Mtetra
.40147 .67869 .41044 .68663 .42555 .68231 .41663 .67433 Mtetra
.647 .763 .934 r
.41663 .67433 .42555 .68231 .44075 .67794 .43188 .66993 Mtetra
.648 .764 .934 r
.43188 .66993 .44075 .67794 .45603 .6735 .44722 .66547 Mtetra
.649 .765 .933 r
.44722 .66547 .45603 .6735 .4714 .66896 .46264 .66093 Mtetra
.652 .767 .933 r
.46264 .66093 .4714 .66896 .48685 .66423 .47816 .65625 Mtetra
.658 .771 .932 r
.47816 .65625 .48685 .66423 .5024 .65918 .49376 .65132 Mtetra
.669 .778 .931 r
.49376 .65132 .5024 .65918 .51803 .65354 .50945 .64596 Mtetra
.689 .791 .928 r
.50945 .64596 .51803 .65354 .53373 .64682 .52522 .63979 Mtetra
.722 .814 .922 r
.52522 .63979 .53373 .64682 .54949 .63817 .54106 .63217 Mtetra
.776 .848 .906 r
.54106 .63217 .54949 .63817 .56526 .62616 .55694 .62197 Mtetra
.848 .891 .869 r
.55694 .62197 .56526 .62616 .58097 .60873 .57279 .60744 Mtetra
.921 .927 .797 r
.57279 .60744 .58097 .60873 .59649 .58371 .58853 .58633 Mtetra
.964 .936 .697 r
.58853 .58633 .59649 .58371 .61169 .5504 .60401 .55692 Mtetra
.97 .924 .603 r
.60401 .55692 .61169 .5504 .62656 .51174 .61914 .52014 Mtetra
.959 .914 .555 r
.61914 .52014 .62656 .51174 .64121 .47392 .63397 .48087 Mtetra
.954 .927 .582 r
.63397 .48087 .64121 .47392 .6559 .44252 .64871 .44561 Mtetra
.952 .954 .682 r
.64871 .44561 .6559 .44252 .67079 .41937 .66358 .41823 Mtetra
.917 .95 .803 r
.66358 .41823 .67079 .41937 .68594 .40318 .6787 .39871 Mtetra
.844 .9 .877 r
.6787 .39871 .68594 .40318 .70132 .39171 .69407 .38506 Mtetra
.774 .841 .903 r
.69407 .38506 .70132 .39171 .71691 .38308 .70966 .37513 Mtetra
.725 .799 .91 r
.70966 .37513 .71691 .38308 .73264 .37606 .72543 .36735 Mtetra
.697 .773 .91 r
.72543 .36735 .73264 .37606 .74851 .3699 .74134 .36075 Mtetra
.681 .758 .909 r
.74134 .36075 .74851 .3699 .7645 .36418 .75738 .35478 Mtetra
.673 .75 .909 r
.75738 .35478 .7645 .36418 .78059 .3587 .77352 .34913 Mtetra
.668 .746 .908 r
.77352 .34913 .78059 .3587 .79678 .35331 .78977 .34364 Mtetra
.666 .744 .908 r
.78977 .34364 .79678 .35331 .81306 .34797 .80612 .33821 Mtetra
.665 .743 .908 r
.80612 .33821 .81306 .34797 .82944 .34264 .82257 .3328 Mtetra
.664 .742 .908 r
.82257 .3328 .82944 .34264 .84592 .33729 .83911 .3274 Mtetra
.83911 .3274 .84592 .33729 .86249 .33193 .85575 .32197 Mtetra
.664 .741 .908 r
.85575 .32197 .86249 .33193 .87915 .32654 .87248 .31652 Mtetra
.87248 .31652 .87915 .32654 .89591 .32112 .88931 .31104 Mtetra
.646 .762 .934 r
.2737 .70489 .28317 .71257 .29767 .70842 .28825 .7007 Mtetra
.28825 .7007 .29767 .70842 .31225 .70425 .30288 .69648 Mtetra
.30288 .69648 .31225 .70425 .32691 .70005 .31759 .69224 Mtetra
.31759 .69224 .32691 .70005 .34166 .69583 .33239 .68797 Mtetra
.33239 .68797 .34166 .69583 .35649 .69158 .34726 .68368 Mtetra
.34726 .68368 .35649 .69158 .3714 .68731 .36222 .67937 Mtetra
.36222 .67937 .3714 .68731 .38639 .68301 .37727 .67503 Mtetra
.646 .763 .934 r
.37727 .67503 .38639 .68301 .40147 .67869 .3924 .67066 Mtetra
.3924 .67066 .40147 .67869 .41663 .67433 .40762 .66626 Mtetra
.647 .763 .934 r
.40762 .66626 .41663 .67433 .43188 .66993 .42292 .66183 Mtetra
.42292 .66183 .43188 .66993 .44722 .66547 .43832 .65734 Mtetra
.648 .764 .933 r
.43832 .65734 .44722 .66547 .46264 .66093 .4538 .65279 Mtetra
.651 .766 .933 r
.4538 .65279 .46264 .66093 .47816 .65625 .46936 .64812 Mtetra
.655 .768 .933 r
.46936 .64812 .47816 .65625 .49376 .65132 .48502 .64327 Mtetra
.663 .774 .932 r
.48502 .64327 .49376 .65132 .50945 .64596 .50077 .6381 Mtetra
.677 .784 .93 r
.50077 .6381 .50945 .64596 .52522 .63979 .51661 .63233 Mtetra
.703 .801 .926 r
.51661 .63233 .52522 .63979 .54106 .63217 .53252 .62547 Mtetra
.746 .829 .915 r
.53252 .62547 .54106 .63217 .55694 .62197 .54849 .61666 Mtetra
.81 .869 .891 r
.54849 .61666 .55694 .62197 .57279 .60744 .56448 .60447 Mtetra
.886 .911 .838 r
.56448 .60447 .57279 .60744 .58853 .58633 .5804 .58682 Mtetra
.947 .935 .749 r
.5804 .58682 .58853 .58633 .60401 .55692 .59613 .56153 Mtetra
.971 .931 .647 r
.59613 .56153 .60401 .55692 .61914 .52014 .61155 .52791 Mtetra
.965 .917 .571 r
.61155 .52791 .61914 .52014 .63397 .48087 .62661 .48889 Mtetra
.955 .918 .558 r
.62661 .48889 .63397 .48087 .64871 .44561 .64146 .45073 Mtetra
.954 .941 .625 r
.64146 .45073 .64871 .44561 .66358 .41823 .65634 .41904 Mtetra
.94 .958 .745 r
.65634 .41904 .66358 .41823 .6787 .39871 .67143 .39565 Mtetra
.883 .929 .847 r
.67143 .39565 .6787 .39871 .69407 .38506 .68678 .37926 Mtetra
.807 .869 .894 r
.68678 .37926 .69407 .38506 .70966 .37513 .70236 .36762 Mtetra
.746 .818 .908 r
.70236 .36762 .70966 .37513 .72543 .36735 .71815 .35884 Mtetra
.709 .784 .91 r
.71815 .35884 .72543 .36735 .74134 .36075 .7341 .35167 Mtetra
.688 .764 .91 r
.7341 .35167 .74134 .36075 .75738 .35478 .75019 .34537 Mtetra
.676 .754 .909 r
.75019 .34537 .75738 .35478 .77352 .34913 .76639 .33951 Mtetra
.67 .748 .909 r
.76639 .33951 .77352 .34913 .78977 .34364 .7827 .33388 Mtetra
.667 .745 .908 r
.7827 .33388 .78977 .34364 .80612 .33821 .79911 .32836 Mtetra
.665 .743 .908 r
.79911 .32836 .80612 .33821 .82257 .3328 .81562 .32287 Mtetra
.665 .742 .908 r
.81562 .32287 .82257 .3328 .83911 .3274 .83223 .3174 Mtetra
.664 .742 .908 r
.83223 .3174 .83911 .3274 .85575 .32197 .84893 .31191 Mtetra
.84893 .31191 .85575 .32197 .87248 .31652 .86574 .3064 Mtetra
.664 .741 .908 r
.86574 .3064 .87248 .31652 .88931 .31104 .88264 .30086 Mtetra
.646 .762 .934 r
.26413 .69713 .2737 .70489 .28825 .7007 .27873 .69289 Mtetra
.27873 .69289 .28825 .7007 .30288 .69648 .29341 .68863 Mtetra
.29341 .68863 .30288 .69648 .31759 .69224 .30817 .68435 Mtetra
.30817 .68435 .31759 .69224 .33239 .68797 .32302 .68004 Mtetra
.32302 .68004 .33239 .68797 .34726 .68368 .33794 .6757 Mtetra
.33794 .6757 .34726 .68368 .36222 .67937 .35296 .67135 Mtetra
.35296 .67135 .36222 .67937 .37727 .67503 .36806 .66696 Mtetra
.36806 .66696 .37727 .67503 .3924 .67066 .38324 .66255 Mtetra
.646 .763 .934 r
.38324 .66255 .3924 .67066 .40762 .66626 .39851 .65811 Mtetra
.39851 .65811 .40762 .66626 .42292 .66183 .41387 .65363 Mtetra
.647 .763 .934 r
.41387 .65363 .42292 .66183 .43832 .65734 .42932 .64911 Mtetra
.648 .764 .934 r
.42932 .64911 .43832 .65734 .4538 .65279 .44485 .64454 Mtetra
.649 .765 .933 r
.44485 .64454 .4538 .65279 .46936 .64812 .46048 .63987 Mtetra
.652 .767 .933 r
.46048 .63987 .46936 .64812 .48502 .64327 .4762 .63507 Mtetra
.658 .771 .932 r
.4762 .63507 .48502 .64327 .50077 .6381 .49201 .63002 Mtetra
.669 .778 .931 r
.49201 .63002 .50077 .6381 .51661 .63233 .5079 .62452 Mtetra
.689 .791 .928 r
.5079 .62452 .51661 .63233 .53252 .62547 .52389 .61822 Mtetra
.722 .814 .922 r
.52389 .61822 .53252 .62547 .54849 .61666 .53994 .61045 Mtetra
.776 .848 .906 r
.53994 .61045 .54849 .61666 .56448 .60447 .55604 .60009 Mtetra
.848 .891 .869 r
.55604 .60009 .56448 .60447 .5804 .58682 .57211 .58536 Mtetra
.921 .927 .797 r
.57211 .58536 .5804 .58682 .59613 .56153 .58806 .564 Mtetra
.964 .936 .697 r
.58806 .564 .59613 .56153 .61155 .52791 .60376 .53428 Mtetra
.97 .924 .603 r
.60376 .53428 .61155 .52791 .62661 .48889 .61909 .49716 Mtetra
.959 .914 .555 r
.61909 .49716 .62661 .48889 .64146 .45073 .63412 .45754 Mtetra
.954 .927 .582 r
.63412 .45754 .64146 .45073 .65634 .41904 .64906 .42196 Mtetra
.952 .954 .683 r
.64906 .42196 .65634 .41904 .67143 .39565 .66413 .39431 Mtetra
.917 .95 .803 r
.66413 .39431 .67143 .39565 .68678 .37926 .67944 .37457 Mtetra
.844 .9 .876 r
.67944 .37457 .68678 .37926 .70236 .36762 .69502 .36074 Mtetra
.774 .841 .903 r
.69502 .36074 .70236 .36762 .71815 .35884 .71082 .35064 Mtetra
.725 .799 .91 r
.71082 .35064 .71815 .35884 .7341 .35167 .7268 .34271 Mtetra
.697 .773 .91 r
.7268 .34271 .7341 .35167 .75019 .34537 .74293 .33597 Mtetra
.681 .758 .909 r
.74293 .33597 .75019 .34537 .76639 .33951 .75918 .32985 Mtetra
.673 .75 .909 r
.75918 .32985 .76639 .33951 .7827 .33388 .77555 .32406 Mtetra
.668 .746 .908 r
.77555 .32406 .7827 .33388 .79911 .32836 .79202 .31842 Mtetra
.666 .744 .908 r
.79202 .31842 .79911 .32836 .81562 .32287 .8086 .31285 Mtetra
.665 .743 .908 r
.8086 .31285 .81562 .32287 .83223 .3174 .82528 .3073 Mtetra
.664 .742 .908 r
.82528 .3073 .83223 .3174 .84893 .31191 .84205 .30174 Mtetra
.84205 .30174 .84893 .31191 .86574 .3064 .85892 .29617 Mtetra
.664 .741 .908 r
.85892 .29617 .86574 .3064 .88264 .30086 .87589 .29057 Mtetra
.646 .762 .934 r
.25446 .68929 .26413 .69713 .27873 .69289 .26911 .68501 Mtetra
.26911 .68501 .27873 .69289 .29341 .68863 .28384 .6807 Mtetra
.28384 .6807 .29341 .68863 .30817 .68435 .29865 .67637 Mtetra
.29865 .67637 .30817 .68435 .32302 .68004 .31355 .67202 Mtetra
.31355 .67202 .32302 .68004 .33794 .6757 .32853 .66764 Mtetra
.32853 .66764 .33794 .6757 .35296 .67135 .34359 .66324 Mtetra
.34359 .66324 .35296 .67135 .36806 .66696 .35874 .65881 Mtetra
.35874 .65881 .36806 .66696 .38324 .66255 .37398 .65435 Mtetra
.646 .763 .934 r
.37398 .65435 .38324 .66255 .39851 .65811 .38931 .64986 Mtetra
.38931 .64986 .39851 .65811 .41387 .65363 .40472 .64534 Mtetra
.647 .763 .934 r
.40472 .64534 .41387 .65363 .42932 .64911 .42022 .64079 Mtetra
.42022 .64079 .42932 .64911 .44485 .64454 .43582 .63618 Mtetra
.648 .764 .933 r
.43582 .63618 .44485 .64454 .46048 .63987 .4515 .63151 Mtetra
.651 .766 .933 r
.4515 .63151 .46048 .63987 .4762 .63507 .46728 .62672 Mtetra
.655 .768 .933 r
.46728 .62672 .4762 .63507 .49201 .63002 .48314 .62174 Mtetra
.663 .774 .932 r
.48314 .62174 .49201 .63002 .5079 .62452 .4991 .61644 Mtetra
.677 .784 .93 r
.4991 .61644 .5079 .62452 .52389 .61822 .51515 .61053 Mtetra
.703 .801 .926 r
.51515 .61053 .52389 .61822 .53994 .61045 .53128 .60353 Mtetra
.746 .829 .915 r
.53128 .60353 .53994 .61045 .55604 .60009 .54747 .59456 Mtetra
.81 .869 .891 r
.54747 .59456 .55604 .60009 .57211 .58536 .56368 .58218 Mtetra
.887 .912 .838 r
.56368 .58218 .57211 .58536 .58806 .564 .57982 .56432 Mtetra
.947 .935 .749 r
.57982 .56432 .58806 .564 .60376 .53428 .59577 .53875 Mtetra
.97 .931 .646 r
.59577 .53875 .60376 .53428 .61909 .49716 .6114 .50479 Mtetra
.964 .917 .571 r
.6114 .50479 .61909 .49716 .63412 .45754 .62666 .46542 Mtetra
.955 .918 .558 r
.62666 .46542 .63412 .45754 .64906 .42196 .64172 .42692 Mtetra
.955 .941 .625 r
.64172 .42692 .64906 .42196 .66413 .39431 .6568 .39493 Mtetra
.94 .958 .745 r
.6568 .39493 .66413 .39431 .67944 .37457 .67208 .3713 Mtetra
.883 .928 .847 r
.67208 .3713 .67944 .37457 .69502 .36074 .68763 .35471 Mtetra
.806 .869 .894 r
.68763 .35471 .69502 .36074 .71082 .35064 .70343 .34289 Mtetra
.746 .818 .908 r
.70343 .34289 .71082 .35064 .7268 .34271 .71943 .33395 Mtetra
.709 .784 .91 r
.71943 .33395 .7268 .34271 .74293 .33597 .7356 .32663 Mtetra
.688 .764 .91 r
.7356 .32663 .74293 .33597 .75918 .32985 .7519 .32018 Mtetra
.676 .754 .909 r
.7519 .32018 .75918 .32985 .77555 .32406 .76833 .31417 Mtetra
.67 .748 .909 r
.76833 .31417 .77555 .32406 .79202 .31842 .78487 .3084 Mtetra
.667 .745 .908 r
.78487 .3084 .79202 .31842 .8086 .31285 .80151 .30273 Mtetra
.665 .743 .908 r
.80151 .30273 .8086 .31285 .82528 .3073 .81825 .29709 Mtetra
.665 .742 .908 r
.81825 .29709 .82528 .3073 .84205 .30174 .83509 .29147 Mtetra
.664 .742 .908 r
.83509 .29147 .84205 .30174 .85892 .29617 .85203 .28583 Mtetra
.85203 .28583 .85892 .29617 .87589 .29057 .86907 .28016 Mtetra
.646 .762 .934 r
.2447 .68137 .25446 .68929 .26911 .68501 .25939 .67704 Mtetra
.25939 .67704 .26911 .68501 .28384 .6807 .27417 .67269 Mtetra
.27417 .67269 .28384 .6807 .29865 .67637 .28903 .66832 Mtetra
.28903 .66832 .29865 .67637 .31355 .67202 .30398 .66392 Mtetra
.30398 .66392 .31355 .67202 .32853 .66764 .31901 .65949 Mtetra
.31901 .65949 .32853 .66764 .34359 .66324 .33413 .65504 Mtetra
.33413 .65504 .34359 .66324 .35874 .65881 .34933 .65057 Mtetra
.34933 .65057 .35874 .65881 .37398 .65435 .36463 .64606 Mtetra
.36463 .64606 .37398 .65435 .38931 .64986 .38001 .64153 Mtetra
.646 .763 .934 r
.38001 .64153 .38931 .64986 .40472 .64534 .39548 .63697 Mtetra
.39548 .63697 .40472 .64534 .42022 .64079 .41103 .63237 Mtetra
.647 .763 .934 r
.41103 .63237 .42022 .64079 .43582 .63618 .42668 .62773 Mtetra
.648 .764 .934 r
.42668 .62773 .43582 .63618 .4515 .63151 .44242 .62303 Mtetra
.649 .765 .933 r
.44242 .62303 .4515 .63151 .46728 .62672 .45826 .61824 Mtetra
.652 .767 .933 r
.45826 .61824 .46728 .62672 .48314 .62174 .47418 .6133 Mtetra
.658 .771 .932 r
.47418 .6133 .48314 .62174 .4991 .61644 .4902 .60812 Mtetra
.669 .778 .931 r
.4902 .60812 .4991 .61644 .51515 .61053 .50632 .60249 Mtetra
.689 .791 .928 r
.50632 .60249 .51515 .61053 .53128 .60353 .52252 .59605 Mtetra
.722 .814 .922 r
.52252 .59605 .53128 .60353 .54747 .59456 .53879 .58813 Mtetra
.776 .848 .906 r
.53879 .58813 .54747 .59456 .56368 .58218 .55511 .57759 Mtetra
.848 .892 .869 r
.55511 .57759 .56368 .58218 .57982 .56432 .57141 .56266 Mtetra
.921 .927 .797 r
.57141 .56266 .57982 .56432 .59577 .53875 .58759 .54104 Mtetra
.964 .936 .697 r
.58759 .54104 .59577 .53875 .6114 .50479 .6035 .51102 Mtetra
.969 .924 .602 r
.6035 .51102 .6114 .50479 .62666 .46542 .61905 .47355 Mtetra
.959 .914 .555 r
.61905 .47355 .62666 .46542 .64172 .42692 .63428 .43357 Mtetra
.954 .927 .582 r
.63428 .43357 .64172 .42692 .6568 .39493 .64942 .39767 Mtetra
.952 .954 .683 r
.64942 .39767 .6568 .39493 .67208 .3713 .66469 .36975 Mtetra
.917 .95 .803 r
.66469 .36975 .67208 .3713 .68763 .35471 .68021 .34979 Mtetra
.844 .9 .876 r
.68021 .34979 .68763 .35471 .70343 .34289 .69599 .33576 Mtetra
.774 .841 .903 r
.69599 .33576 .70343 .34289 .71943 .33395 .71201 .3255 Mtetra
.725 .799 .91 r
.71201 .3255 .71943 .33395 .7356 .32663 .7282 .31741 Mtetra
.697 .773 .91 r
.7282 .31741 .7356 .32663 .7519 .32018 .74455 .31051 Mtetra
.681 .758 .909 r
.74455 .31051 .7519 .32018 .76833 .31417 .76103 .30425 Mtetra
.673 .75 .909 r
.76103 .30425 .76833 .31417 .78487 .3084 .77763 .2983 Mtetra
.668 .746 .908 r
.77763 .2983 .78487 .3084 .80151 .30273 .79434 .29251 Mtetra
.666 .744 .908 r
.79434 .29251 .80151 .30273 .81825 .29709 .81115 .28679 Mtetra
.665 .743 .908 r
.81115 .28679 .81825 .29709 .83509 .29147 .82806 .28109 Mtetra
.664 .742 .908 r
.82806 .28109 .83509 .29147 .85203 .28583 .84507 .27538 Mtetra
.84507 .27538 .85203 .28583 .86907 .28016 .86218 .26965 Mtetra
.646 .762 .934 r
.23483 .67336 .2447 .68137 .25939 .67704 .24958 .66899 Mtetra
.24958 .66899 .25939 .67704 .27417 .67269 .2644 .6646 Mtetra
.2644 .6646 .27417 .67269 .28903 .66832 .27932 .66018 Mtetra
.27932 .66018 .28903 .66832 .30398 .66392 .29431 .65573 Mtetra
.29431 .65573 .30398 .66392 .31901 .65949 .3094 .65126 Mtetra
.3094 .65126 .31901 .65949 .33413 .65504 .32457 .64676 Mtetra
.32457 .64676 .33413 .65504 .34933 .65057 .33983 .64224 Mtetra
.33983 .64224 .34933 .65057 .36463 .64606 .35517 .63769 Mtetra
.35517 .63769 .36463 .64606 .38001 .64153 .37061 .63311 Mtetra
.646 .763 .934 r
.37061 .63311 .38001 .64153 .39548 .63697 .38613 .6285 Mtetra
.38613 .6285 .39548 .63697 .41103 .63237 .40174 .62386 Mtetra
.647 .763 .934 r
.40174 .62386 .41103 .63237 .42668 .62773 .41745 .61917 Mtetra
.41745 .61917 .42668 .62773 .44242 .62303 .43325 .61444 Mtetra
.648 .764 .933 r
.43325 .61444 .44242 .62303 .45826 .61824 .44914 .60964 Mtetra
.651 .766 .933 r
.44914 .60964 .45826 .61824 .47418 .6133 .46513 .60472 Mtetra
.655 .768 .933 r
.46513 .60472 .47418 .6133 .4902 .60812 .48121 .59961 Mtetra
.663 .774 .932 r
.48121 .59961 .4902 .60812 .50632 .60249 .49739 .59417 Mtetra
.677 .784 .93 r
.49739 .59417 .50632 .60249 .52252 .59605 .51365 .58812 Mtetra
.703 .801 .926 r
.51365 .58812 .52252 .59605 .53879 .58813 .53 .58097 Mtetra
.746 .83 .916 r
.53 .58097 .53879 .58813 .55511 .57759 .54642 .57184 Mtetra
.81 .87 .891 r
.54642 .57184 .55511 .57759 .57141 .56266 .56285 .55928 Mtetra
.887 .912 .838 r
.56285 .55928 .57141 .56266 .58759 .54104 .57922 .54118 Mtetra
.947 .936 .749 r
.57922 .54118 .58759 .54104 .6035 .51102 .5954 .51533 Mtetra
.97 .931 .646 r
.5954 .51533 .6035 .51102 .61905 .47355 .61124 .48104 Mtetra
.964 .917 .571 r
.61124 .48104 .61905 .47355 .63428 .43357 .62672 .4413 Mtetra
.955 .918 .559 r
.62672 .4413 .63428 .43357 .64942 .39767 .64198 .40245 Mtetra
.955 .941 .626 r
.64198 .40245 .64942 .39767 .66469 .36975 .65726 .37017 Mtetra
.94 .958 .746 r
.65726 .37017 .66469 .36975 .68021 .34979 .67275 .34629 Mtetra
.883 .928 .847 r
.67275 .34629 .68021 .34979 .69599 .33576 .68851 .32949 Mtetra
.806 .869 .894 r
.68851 .32949 .69599 .33576 .71201 .3255 .70453 .31749 Mtetra
.747 .817 .908 r
.70453 .31749 .71201 .3255 .7282 .31741 .72075 .30839 Mtetra
.709 .784 .91 r
.72075 .30839 .7282 .31741 .74455 .31051 .73714 .3009 Mtetra
.688 .764 .91 r
.73714 .3009 .74455 .31051 .76103 .30425 .75367 .2943 Mtetra
.676 .754 .909 r
.75367 .2943 .76103 .30425 .77763 .2983 .77032 .28814 Mtetra
.67 .748 .909 r
.77032 .28814 .77763 .2983 .79434 .29251 .78709 .28221 Mtetra
.667 .745 .908 r
.78709 .28221 .79434 .29251 .81115 .28679 .80397 .27639 Mtetra
.665 .743 .908 r
.80397 .27639 .81115 .28679 .82806 .28109 .82095 .2706 Mtetra
.665 .742 .908 r
.82095 .2706 .82806 .28109 .84507 .27538 .83803 .26482 Mtetra
.664 .742 .908 r
.83803 .26482 .84507 .27538 .86218 .26965 .85522 .25902 Mtetra
.646 .762 .934 r
.22486 .66527 .23483 .67336 .24958 .66899 .23965 .66086 Mtetra
.23965 .66086 .24958 .66899 .2644 .6646 .25453 .65642 Mtetra
.25453 .65642 .2644 .6646 .27932 .66018 .2695 .65195 Mtetra
.2695 .65195 .27932 .66018 .29431 .65573 .28454 .64746 Mtetra
.28454 .64746 .29431 .65573 .3094 .65126 .29968 .64294 Mtetra
.29968 .64294 .3094 .65126 .32457 .64676 .3149 .63839 Mtetra
.3149 .63839 .32457 .64676 .33983 .64224 .33021 .63382 Mtetra
.33021 .63382 .33983 .64224 .35517 .63769 .34561 .62922 Mtetra
.34561 .62922 .35517 .63769 .37061 .63311 .3611 .62459 Mtetra
.3611 .62459 .37061 .63311 .38613 .6285 .37668 .61994 Mtetra
.646 .763 .934 r
.37668 .61994 .38613 .6285 .40174 .62386 .39235 .61525 Mtetra
.39235 .61525 .40174 .62386 .41745 .61917 .40812 .61052 Mtetra
.647 .763 .934 r
.40812 .61052 .41745 .61917 .43325 .61444 .42398 .60575 Mtetra
.648 .764 .934 r
.42398 .60575 .43325 .61444 .44914 .60964 .43993 .60092 Mtetra
.649 .765 .933 r
.43993 .60092 .44914 .60964 .46513 .60472 .45597 .596 Mtetra
.652 .767 .933 r
.45597 .596 .46513 .60472 .48121 .59961 .47212 .59093 Mtetra
.658 .771 .932 r
.47212 .59093 .48121 .59961 .49739 .59417 .48835 .58562 Mtetra
.669 .778 .931 r
.48835 .58562 .49739 .59417 .51365 .58812 .50469 .57985 Mtetra
.689 .791 .928 r
.50469 .57985 .51365 .58812 .53 .58097 .52111 .57325 Mtetra
.722 .814 .922 r
.52111 .57325 .53 .58097 .54642 .57184 .53761 .56518 Mtetra
.776 .848 .906 r
.53761 .56518 .54642 .57184 .56285 .55928 .55416 .55446 Mtetra
.848 .892 .869 r
.55416 .55446 .56285 .55928 .57922 .54118 .57069 .53931 Mtetra
.921 .927 .797 r
.57069 .53931 .57922 .54118 .5954 .51533 .58709 .51745 Mtetra
.964 .936 .696 r
.58709 .51745 .5954 .51533 .61124 .48104 .60323 .48711 Mtetra
.969 .924 .602 r
.60323 .48711 .61124 .48104 .62672 .4413 .619 .44928 Mtetra
.959 .914 .555 r
.619 .44928 .62672 .4413 .64198 .40245 .63444 .40894 Mtetra
.954 .927 .583 r
.63444 .40894 .64198 .40245 .65726 .37017 .64979 .37271 Mtetra
.952 .954 .683 r
.64979 .37271 .65726 .37017 .67275 .34629 .66526 .34451 Mtetra
.917 .949 .803 r
.66526 .34451 .67275 .34629 .68851 .32949 .68099 .32433 Mtetra
.844 .899 .876 r
.68099 .32433 .68851 .32949 .70453 .31749 .697 .31011 Mtetra
.774 .841 .903 r
.697 .31011 .70453 .31749 .72075 .30839 .71323 .29967 Mtetra
.725 .798 .91 r
.71323 .29967 .72075 .30839 .73714 .3009 .72965 .29141 Mtetra
.697 .773 .91 r
.72965 .29141 .73714 .3009 .75367 .2943 .74623 .28436 Mtetra
.681 .758 .909 r
.74623 .28436 .75367 .2943 .77032 .28814 .76294 .27794 Mtetra
.673 .75 .909 r
.76294 .27794 .77032 .28814 .78709 .28221 .77977 .27184 Mtetra
.668 .746 .908 r
.77977 .27184 .78709 .28221 .80397 .27639 .79671 .26589 Mtetra
.666 .744 .908 r
.79671 .26589 .80397 .27639 .82095 .2706 .81376 .26001 Mtetra
.665 .743 .908 r
.81376 .26001 .82095 .2706 .83803 .26482 .83091 .25415 Mtetra
.664 .742 .908 r
.83091 .25415 .83803 .26482 .85522 .25902 .84817 .24828 Mtetra
.646 .762 .934 r
.21479 .6571 .22486 .66527 .23965 .66086 .22963 .65264 Mtetra
.22963 .65264 .23965 .66086 .25453 .65642 .24456 .64815 Mtetra
.24456 .64815 .25453 .65642 .2695 .65195 .25957 .64363 Mtetra
.25957 .64363 .2695 .65195 .28454 .64746 .27467 .63909 Mtetra
.27467 .63909 .28454 .64746 .29968 .64294 .28986 .63453 Mtetra
.28986 .63453 .29968 .64294 .3149 .63839 .30513 .62993 Mtetra
.30513 .62993 .3149 .63839 .33021 .63382 .3205 .62531 Mtetra
.3205 .62531 .33021 .63382 .34561 .62922 .33595 .62066 Mtetra
.33595 .62066 .34561 .62922 .3611 .62459 .3515 .61599 Mtetra
.3515 .61599 .3611 .62459 .37668 .61994 .36713 .61128 Mtetra
.646 .763 .934 r
.36713 .61128 .37668 .61994 .39235 .61525 .38286 .60654 Mtetra
.38286 .60654 .39235 .61525 .40812 .61052 .39868 .60177 Mtetra
.647 .763 .934 r
.39868 .60177 .40812 .61052 .42398 .60575 .4146 .59696 Mtetra
.4146 .59696 .42398 .60575 .43993 .60092 .43061 .5921 Mtetra
.648 .764 .933 r
.43061 .5921 .43993 .60092 .45597 .596 .44672 .58716 Mtetra
.651 .766 .933 r
.44672 .58716 .45597 .596 .47212 .59093 .46292 .58211 Mtetra
.655 .768 .933 r
.46292 .58211 .47212 .59093 .48835 .58562 .47922 .57686 Mtetra
.663 .774 .932 r
.47922 .57686 .48835 .58562 .50469 .57985 .49562 .57128 Mtetra
.677 .784 .93 r
.49562 .57128 .50469 .57985 .52111 .57325 .51211 .56509 Mtetra
.703 .801 .926 r
.51211 .56509 .52111 .57325 .53761 .56518 .52869 .55778 Mtetra
.746 .83 .916 r
.52869 .55778 .53761 .56518 .55416 .55446 .54534 .54848 Mtetra
.81 .87 .891 r
.54534 .54848 .55416 .55446 .57069 .53931 .562 .53572 Mtetra
.887 .912 .838 r
.562 .53572 .57069 .53931 .58709 .51745 .57861 .51738 Mtetra
.948 .936 .749 r
.57861 .51738 .58709 .51745 .60323 .48711 .59501 .49124 Mtetra
.97 .931 .646 r
.59501 .49124 .60323 .48711 .619 .44928 .61108 .45661 Mtetra
.964 .917 .571 r
.61108 .45661 .619 .44928 .63444 .40894 .62678 .41651 Mtetra
.955 .918 .559 r
.62678 .41651 .63444 .40894 .64979 .37271 .64225 .37731 Mtetra
.955 .941 .626 r
.64225 .37731 .64979 .37271 .66526 .34451 .65774 .34472 Mtetra
.94 .958 .746 r
.65774 .34472 .66526 .34451 .68099 .32433 .67344 .32059 Mtetra
.883 .928 .847 r
.67344 .32059 .68099 .32433 .697 .31011 .68942 .30357 Mtetra
.806 .869 .894 r
.68942 .30357 .697 .31011 .71323 .29967 .70565 .29139 Mtetra
.747 .817 .908 r
.70565 .29139 .71323 .29967 .72965 .29141 .7221 .28212 Mtetra
.709 .784 .91 r
.7221 .28212 .72965 .29141 .74623 .28436 .73872 .27447 Mtetra
.688 .764 .91 r
.73872 .27447 .74623 .28436 .76294 .27794 .75548 .2677 Mtetra
.676 .754 .909 r
.75548 .2677 .76294 .27794 .77977 .27184 .77237 .26139 Mtetra
.67 .748 .909 r
.77237 .26139 .77977 .27184 .79671 .26589 .78938 .2553 Mtetra
.667 .745 .908 r
.78938 .2553 .79671 .26589 .81376 .26001 .8065 .24932 Mtetra
.665 .743 .908 r
.8065 .24932 .81376 .26001 .83091 .25415 .82372 .24337 Mtetra
.665 .742 .908 r
.82372 .24337 .83091 .25415 .84817 .24828 .84105 .23742 Mtetra
.646 .762 .934 r
.2046 .64884 .21479 .6571 .22963 .65264 .2195 .64433 Mtetra
.2195 .64433 .22963 .65264 .24456 .64815 .23447 .63979 Mtetra
.23447 .63979 .24456 .64815 .25957 .64363 .24954 .63523 Mtetra
.24954 .63523 .25957 .64363 .27467 .63909 .26469 .63064 Mtetra
.26469 .63064 .27467 .63909 .28986 .63453 .27993 .62602 Mtetra
.27993 .62602 .28986 .63453 .30513 .62993 .29526 .62138 Mtetra
.29526 .62138 .30513 .62993 .3205 .62531 .31068 .61671 Mtetra
.31068 .61671 .3205 .62531 .33595 .62066 .32619 .61201 Mtetra
.32619 .61201 .33595 .62066 .3515 .61599 .34179 .60728 Mtetra
.34179 .60728 .3515 .61599 .36713 .61128 .35748 .60253 Mtetra
.35748 .60253 .36713 .61128 .38286 .60654 .37327 .59774 Mtetra
.646 .763 .934 r
.37327 .59774 .38286 .60654 .39868 .60177 .38915 .59292 Mtetra
.38915 .59292 .39868 .60177 .4146 .59696 .40512 .58806 Mtetra
.647 .763 .934 r
.40512 .58806 .4146 .59696 .43061 .5921 .42119 .58316 Mtetra
.648 .764 .934 r
.42119 .58316 .43061 .5921 .44672 .58716 .43736 .5782 Mtetra
.649 .765 .933 r
.43736 .5782 .44672 .58716 .46292 .58211 .45362 .57314 Mtetra
.652 .767 .933 r
.45362 .57314 .46292 .58211 .47922 .57686 .46999 .56793 Mtetra
.658 .771 .932 r
.46999 .56793 .47922 .57686 .49562 .57128 .48645 .56247 Mtetra
.669 .778 .931 r
.48645 .56247 .49562 .57128 .51211 .56509 .50301 .55656 Mtetra
.688 .791 .928 r
.50301 .55656 .51211 .56509 .52869 .55778 .51967 .54981 Mtetra
.722 .814 .922 r
.51967 .54981 .52869 .55778 .54534 .54848 .5364 .54157 Mtetra
.776 .849 .906 r
.5364 .54157 .54534 .54848 .562 .53572 .55318 .53067 Mtetra
.848 .892 .869 r
.55318 .53067 .562 .53572 .57861 .51738 .56995 .5153 Mtetra
.921 .928 .797 r
.56995 .5153 .57861 .51738 .59501 .49124 .58659 .49317 Mtetra
.964 .936 .696 r
.58659 .49317 .59501 .49124 .61108 .45661 .60296 .46252 Mtetra
.969 .924 .602 r
.60296 .46252 .61108 .45661 .62678 .41651 .61895 .42433 Mtetra
.959 .914 .555 r
.61895 .42433 .62678 .41651 .64225 .37731 .63461 .38362 Mtetra
.955 .928 .583 r
.63461 .38362 .64225 .37731 .65774 .34472 .65017 .34706 Mtetra
.952 .954 .684 r
.65017 .34706 .65774 .34472 .67344 .32059 .66585 .31858 Mtetra
.917 .949 .803 r
.66585 .31858 .67344 .32059 .68942 .30357 .6818 .29816 Mtetra
.844 .899 .876 r
.6818 .29816 .68942 .30357 .70565 .29139 .69802 .28374 Mtetra
.774 .841 .903 r
.69802 .28374 .70565 .29139 .7221 .28212 .71448 .27312 Mtetra
.725 .798 .909 r
.71448 .27312 .7221 .28212 .73872 .27447 .73114 .2647 Mtetra
.697 .773 .91 r
.73114 .2647 .73872 .27447 .75548 .2677 .74795 .25748 Mtetra
.681 .758 .909 r
.74795 .25748 .75548 .2677 .77237 .26139 .7649 .25089 Mtetra
.673 .75 .909 r
.7649 .25089 .77237 .26139 .78938 .2553 .78197 .24463 Mtetra
.668 .746 .908 r
.78197 .24463 .78938 .2553 .8065 .24932 .79915 .23852 Mtetra
.666 .744 .908 r
.79915 .23852 .8065 .24932 .82372 .24337 .81645 .23248 Mtetra
.665 .743 .908 r
.81645 .23248 .82372 .24337 .84105 .23742 .83385 .22645 Mtetra
.646 .762 .934 r
.19431 .64049 .2046 .64884 .2195 .64433 .20925 .63593 Mtetra
.20925 .63593 .2195 .64433 .23447 .63979 .22428 .63135 Mtetra
.22428 .63135 .23447 .63979 .24954 .63523 .2394 .62674 Mtetra
.2394 .62674 .24954 .63523 .26469 .63064 .2546 .6221 Mtetra
.2546 .6221 .26469 .63064 .27993 .62602 .2699 .61743 Mtetra
.2699 .61743 .27993 .62602 .29526 .62138 .28528 .61274 Mtetra
.28528 .61274 .29526 .62138 .31068 .61671 .30075 .60802 Mtetra
.30075 .60802 .31068 .61671 .32619 .61201 .31632 .60327 Mtetra
.31632 .60327 .32619 .61201 .34179 .60728 .33197 .59849 Mtetra
.33197 .59849 .34179 .60728 .35748 .60253 .34772 .59368 Mtetra
.34772 .59368 .35748 .60253 .37327 .59774 .36357 .58884 Mtetra
.646 .763 .934 r
.36357 .58884 .37327 .59774 .38915 .59292 .37951 .58397 Mtetra
.37951 .58397 .38915 .59292 .40512 .58806 .39554 .57907 Mtetra
.647 .763 .934 r
.39554 .57907 .40512 .58806 .42119 .58316 .41167 .57412 Mtetra
.41167 .57412 .42119 .58316 .43736 .5782 .4279 .56912 Mtetra
.648 .764 .933 r
.4279 .56912 .43736 .5782 .45362 .57314 .44422 .56404 Mtetra
.651 .766 .933 r
.44422 .56404 .45362 .57314 .46999 .56793 .46065 .55885 Mtetra
.655 .768 .933 r
.46065 .55885 .46999 .56793 .48645 .56247 .47718 .55346 Mtetra
.663 .774 .932 r
.47718 .55346 .48645 .56247 .50301 .55656 .49381 .54773 Mtetra
.677 .784 .93 r
.49381 .54773 .50301 .55656 .51967 .54981 .51053 .54139 Mtetra
.703 .801 .926 r
.51053 .54139 .51967 .54981 .5364 .54157 .52734 .53392 Mtetra
.746 .83 .916 r
.52734 .53392 .5364 .54157 .55318 .53067 .54423 .52444 Mtetra
.81 .87 .891 r
.54423 .52444 .55318 .53067 .56995 .5153 .56113 .51148 Mtetra
.887 .912 .838 r
.56113 .51148 .56995 .5153 .58659 .49317 .57797 .4929 Mtetra
.948 .936 .749 r
.57797 .4929 .58659 .49317 .60296 .46252 .59462 .46647 Mtetra
.97 .931 .645 r
.59462 .46647 .60296 .46252 .61895 .42433 .61092 .43149 Mtetra
.964 .917 .571 r
.61092 .43149 .61895 .42433 .63461 .38362 .62684 .39102 Mtetra
.955 .918 .559 r
.62684 .39102 .63461 .38362 .65017 .34706 .64252 .35146 Mtetra
.955 .941 .626 r
.64252 .35146 .65017 .34706 .66585 .31858 .65823 .31856 Mtetra
.94 .958 .746 r
.65823 .31856 .66585 .31858 .6818 .29816 .67415 .29417 Mtetra
.883 .928 .847 r
.67415 .29417 .6818 .29816 .69802 .28374 .69035 .27694 Mtetra
.806 .869 .894 r
.69035 .27694 .69802 .28374 .71448 .27312 .70681 .26457 Mtetra
.747 .817 .908 r
.70681 .26457 .71448 .27312 .73114 .2647 .72349 .25511 Mtetra
.709 .784 .91 r
.72349 .25511 .73114 .2647 .74795 .25748 .74034 .2473 Mtetra
.688 .764 .91 r
.74034 .2473 .74795 .25748 .7649 .25089 .75734 .24036 Mtetra
.676 .754 .909 r
.75734 .24036 .7649 .25089 .78197 .24463 .77448 .23388 Mtetra
.67 .748 .909 r
.77448 .23388 .78197 .24463 .79915 .23852 .79173 .22763 Mtetra
.667 .745 .908 r
.79173 .22763 .79915 .23852 .81645 .23248 .8091 .22148 Mtetra
.665 .743 .908 r
.8091 .22148 .81645 .23248 .83385 .22645 .82657 .21536 Mtetra
.646 .762 .934 r
.18391 .63206 .19431 .64049 .20925 .63593 .1989 .62745 Mtetra
.1989 .62745 .20925 .63593 .22428 .63135 .21398 .62281 Mtetra
.21398 .62281 .22428 .63135 .2394 .62674 .22915 .61815 Mtetra
.22915 .61815 .2394 .62674 .2546 .6221 .24441 .61346 Mtetra
.24441 .61346 .2546 .6221 .2699 .61743 .25975 .60874 Mtetra
.25975 .60874 .2699 .61743 .28528 .61274 .27519 .604 Mtetra
.27519 .604 .28528 .61274 .30075 .60802 .29072 .59923 Mtetra
.29072 .59923 .30075 .60802 .31632 .60327 .30634 .59442 Mtetra
.30634 .59442 .31632 .60327 .33197 .59849 .32205 .58959 Mtetra
.32205 .58959 .33197 .59849 .34772 .59368 .33786 .58473 Mtetra
.33786 .58473 .34772 .59368 .36357 .58884 .35376 .57984 Mtetra
.35376 .57984 .36357 .58884 .37951 .58397 .36976 .57492 Mtetra
.646 .763 .934 r
.36976 .57492 .37951 .58397 .39554 .57907 .38585 .56997 Mtetra
.38585 .56997 .39554 .57907 .41167 .57412 .40204 .56497 Mtetra
.647 .763 .934 r
.40204 .56497 .41167 .57412 .4279 .56912 .41833 .55993 Mtetra
.648 .764 .934 r
.41833 .55993 .4279 .56912 .44422 .56404 .43472 .55482 Mtetra
.649 .765 .933 r
.43472 .55482 .44422 .56404 .46065 .55885 .45121 .54962 Mtetra
.652 .767 .933 r
.45121 .54962 .46065 .55885 .47718 .55346 .4678 .54427 Mtetra
.658 .771 .932 r
.4678 .54427 .47718 .55346 .49381 .54773 .48449 .53866 Mtetra
.669 .778 .931 r
.48449 .53866 .49381 .54773 .51053 .54139 .50129 .53259 Mtetra
.688 .791 .928 r
.50129 .53259 .51053 .54139 .52734 .53392 .51818 .52569 Mtetra
.722 .814 .922 r
.51818 .52569 .52734 .53392 .54423 .52444 .53515 .51728 Mtetra
.776 .849 .906 r
.53515 .51728 .54423 .52444 .56113 .51148 .55217 .50618 Mtetra
.848 .892 .869 r
.55217 .50618 .56113 .51148 .57797 .4929 .56918 .4906 Mtetra
.921 .928 .797 r
.56918 .4906 .57797 .4929 .59462 .46647 .58607 .4682 Mtetra
.964 .937 .696 r
.58607 .4682 .59462 .46647 .61092 .43149 .60267 .43722 Mtetra
.969 .924 .602 r
.60267 .43722 .61092 .43149 .62684 .39102 .61889 .39866 Mtetra
.959 .914 .555 r
.61889 .39866 .62684 .39102 .64252 .35146 .63478 .35758 Mtetra
.955 .928 .583 r
.63478 .35758 .64252 .35146 .65823 .31856 .65056 .32068 Mtetra
.952 .954 .684 r
.65056 .32068 .65823 .31856 .67415 .29417 .66646 .29192 Mtetra
.916 .949 .803 r
.66646 .29192 .67415 .29417 .69035 .27694 .68263 .27126 Mtetra
.844 .899 .876 r
.68263 .27126 .69035 .27694 .70681 .26457 .69908 .25664 Mtetra
.774 .841 .903 r
.69908 .25664 .70681 .26457 .72349 .25511 .71577 .24583 Mtetra
.725 .798 .909 r
.71577 .24583 .72349 .25511 .74034 .2473 .73266 .23723 Mtetra
.697 .773 .91 r
.73266 .23723 .74034 .2473 .75734 .24036 .74972 .22984 Mtetra
.681 .758 .909 r
.74972 .22984 .75734 .24036 .77448 .23388 .76691 .22308 Mtetra
.673 .75 .909 r
.76691 .22308 .77448 .23388 .79173 .22763 .78423 .21665 Mtetra
.668 .746 .908 r
.78423 .21665 .79173 .22763 .8091 .22148 .80166 .21037 Mtetra
.666 .744 .908 r
.80166 .21037 .8091 .22148 .82657 .21536 .81922 .20416 Mtetra
.646 .762 .934 r
.1734 .62353 .18391 .63206 .1989 .62745 .18844 .61887 Mtetra
.18844 .61887 .1989 .62745 .21398 .62281 .20357 .61418 Mtetra
.20357 .61418 .21398 .62281 .22915 .61815 .21879 .60947 Mtetra
.21879 .60947 .22915 .61815 .24441 .61346 .2341 .60473 Mtetra
.2341 .60473 .24441 .61346 .25975 .60874 .2495 .59996 Mtetra
.2495 .59996 .25975 .60874 .27519 .604 .26499 .59517 Mtetra
.26499 .59517 .27519 .604 .29072 .59923 .28057 .59034 Mtetra
.28057 .59034 .29072 .59923 .30634 .59442 .29625 .58549 Mtetra
.29625 .58549 .30634 .59442 .32205 .58959 .31202 .5806 Mtetra
.31202 .5806 .32205 .58959 .33786 .58473 .32788 .57569 Mtetra
.32788 .57569 .33786 .58473 .35376 .57984 .34384 .57074 Mtetra
.34384 .57074 .35376 .57984 .36976 .57492 .3599 .56577 Mtetra
.646 .763 .934 r
.3599 .56577 .36976 .57492 .38585 .56997 .37605 .56076 Mtetra
.37605 .56076 .38585 .56997 .40204 .56497 .3923 .55571 Mtetra
.647 .763 .934 r
.3923 .55571 .40204 .56497 .41833 .55993 .40866 .55062 Mtetra
.40866 .55062 .41833 .55993 .43472 .55482 .42511 .54548 Mtetra
.648 .764 .933 r
.42511 .54548 .43472 .55482 .45121 .54962 .44166 .54026 Mtetra
.651 .766 .933 r
.44166 .54026 .45121 .54962 .4678 .54427 .45832 .53492 Mtetra
.655 .768 .933 r
.45832 .53492 .4678 .54427 .48449 .53866 .47507 .52938 Mtetra
.663 .774 .932 r
.47507 .52938 .48449 .53866 .50129 .53259 .49194 .5235 Mtetra
.677 .784 .93 r
.49194 .5235 .50129 .53259 .51818 .52569 .5089 .517 Mtetra
.703 .801 .926 r
.5089 .517 .51818 .52569 .53515 .51728 .52596 .50936 Mtetra
.746 .83 .916 r
.52596 .50936 .53515 .51728 .55217 .50618 .54308 .4997 Mtetra
.81 .87 .891 r
.54308 .4997 .55217 .50618 .56918 .4906 .56023 .48653 Mtetra
.887 .913 .838 r
.56023 .48653 .56918 .4906 .58607 .4682 .57732 .46771 Mtetra
.948 .936 .748 r
.57732 .46771 .58607 .4682 .60267 .43722 .59421 .44097 Mtetra
.97 .931 .645 r
.59421 .44097 .60267 .43722 .61889 .39866 .61075 .40565 Mtetra
.964 .917 .57 r
.61075 .40565 .61889 .39866 .63478 .35758 .6269 .36479 Mtetra
.955 .918 .559 r
.6269 .36479 .63478 .35758 .65056 .32068 .64281 .32488 Mtetra
.955 .941 .627 r
.64281 .32488 .65056 .32068 .66646 .29192 .65874 .29166 Mtetra
.94 .958 .746 r
.65874 .29166 .66646 .29192 .68263 .27126 .67488 .26701 Mtetra
.883 .928 .847 r
.67488 .26701 .68263 .27126 .69908 .25664 .69131 .24956 Mtetra
.806 .869 .894 r
.69131 .24956 .69908 .25664 .71577 .24583 .708 .23698 Mtetra
.747 .817 .907 r
.708 .23698 .71577 .24583 .73266 .23723 .72491 .22735 Mtetra
.709 .784 .91 r
.72491 .22735 .73266 .23723 .74972 .22984 .74201 .21936 Mtetra
.688 .764 .91 r
.74201 .21936 .74972 .22984 .76691 .22308 .75926 .21225 Mtetra
.676 .754 .909 r
.75926 .21225 .76691 .22308 .78423 .21665 .77664 .2056 Mtetra
.67 .748 .909 r
.77664 .2056 .78423 .21665 .80166 .21037 .79415 .19917 Mtetra
.667 .745 .908 r
.79415 .19917 .80166 .21037 .81922 .20416 .81177 .19284 Mtetra
.646 .762 .934 r
.16277 .61491 .1734 .62353 .18844 .61887 .17787 .6102 Mtetra
.17787 .6102 .18844 .61887 .20357 .61418 .19305 .60546 Mtetra
.19305 .60546 .20357 .61418 .21879 .60947 .20832 .6007 Mtetra
.20832 .6007 .21879 .60947 .2341 .60473 .22368 .59591 Mtetra
.22368 .59591 .2341 .60473 .2495 .59996 .23913 .59108 Mtetra
.23913 .59108 .2495 .59996 .26499 .59517 .25468 .58624 Mtetra
.25468 .58624 .26499 .59517 .28057 .59034 .27032 .58136 Mtetra
.27032 .58136 .28057 .59034 .29625 .58549 .28605 .57645 Mtetra
.28605 .57645 .29625 .58549 .31202 .5806 .30187 .57151 Mtetra
.30187 .57151 .31202 .5806 .32788 .57569 .3178 .56654 Mtetra
.3178 .56654 .32788 .57569 .34384 .57074 .33381 .56154 Mtetra
.33381 .56154 .34384 .57074 .3599 .56577 .34993 .55651 Mtetra
.34993 .55651 .3599 .56577 .37605 .56076 .36614 .55145 Mtetra
.646 .763 .934 r
.36614 .55145 .37605 .56076 .3923 .55571 .38246 .54635 Mtetra
.38246 .54635 .3923 .55571 .40866 .55062 .39887 .54121 Mtetra
.647 .763 .934 r
.39887 .54121 .40866 .55062 .42511 .54548 .41539 .53602 Mtetra
.648 .764 .934 r
.41539 .53602 .42511 .54548 .44166 .54026 .432 .53077 Mtetra
.649 .765 .933 r
.432 .53077 .44166 .54026 .45832 .53492 .44872 .52542 Mtetra
.652 .767 .933 r
.44872 .52542 .45832 .53492 .47507 .52938 .46555 .51992 Mtetra
.658 .771 .932 r
.46555 .51992 .47507 .52938 .49194 .5235 .48248 .51416 Mtetra
.669 .778 .931 r
.48248 .51416 .49194 .5235 .5089 .517 .49951 .50793 Mtetra
.688 .791 .928 r
.49951 .50793 .5089 .517 .52596 .50936 .51665 .50086 Mtetra
.722 .814 .922 r
.51665 .50086 .52596 .50936 .54308 .4997 .53386 .49227 Mtetra
.776 .849 .906 r
.53386 .49227 .54308 .4997 .56023 .48653 .55114 .48098 Mtetra
.849 .892 .869 r
.55114 .48098 .56023 .48653 .57732 .46771 .5684 .46516 Mtetra
.921 .928 .797 r
.5684 .46516 .57732 .46771 .59421 .44097 .58553 .44249 Mtetra
.964 .937 .696 r
.58553 .44249 .59421 .44097 .61075 .40565 .60238 .41118 Mtetra
.969 .924 .601 r
.60238 .41118 .61075 .40565 .6269 .36479 .61884 .37225 Mtetra
.959 .914 .555 r
.61884 .37225 .6269 .36479 .64281 .32488 .63496 .33079 Mtetra
.955 .928 .584 r
.63496 .33079 .64281 .32488 .65874 .29166 .65096 .29355 Mtetra
.952 .953 .684 r
.65096 .29355 .65874 .29166 .67488 .26701 .66709 .2645 Mtetra
.916 .949 .803 r
.66709 .2645 .67488 .26701 .69131 .24956 .68349 .2436 Mtetra
.844 .899 .876 r
.68349 .2436 .69131 .24956 .708 .23698 .70017 .22876 Mtetra
.774 .841 .903 r
.70017 .22876 .708 .23698 .72491 .22735 .7171 .21776 Mtetra
.725 .798 .909 r
.7171 .21776 .72491 .22735 .74201 .21936 .73423 .20898 Mtetra
.697 .773 .91 r
.73423 .20898 .74201 .21936 .75926 .21225 .75153 .20141 Mtetra
.681 .758 .909 r
.75153 .20141 .75926 .21225 .77664 .2056 .76898 .19448 Mtetra
.673 .75 .909 r
.76898 .19448 .77664 .2056 .79415 .19917 .78655 .18787 Mtetra
.668 .746 .908 r
.78655 .18787 .79415 .19917 .81177 .19284 .80425 .18141 Mtetra
.646 .762 .934 r
.15203 .60619 .16277 .61491 .17787 .6102 .16717 .60143 Mtetra
.16717 .60143 .17787 .6102 .19305 .60546 .18241 .59664 Mtetra
.18241 .59664 .19305 .60546 .20832 .6007 .19773 .59183 Mtetra
.19773 .59183 .20832 .6007 .22368 .59591 .21314 .58698 Mtetra
.21314 .58698 .22368 .59591 .23913 .59108 .22865 .58211 Mtetra
.22865 .58211 .23913 .59108 .25468 .58624 .24425 .57721 Mtetra
.24425 .57721 .25468 .58624 .27032 .58136 .25994 .57227 Mtetra
.25994 .57227 .27032 .58136 .28605 .57645 .27573 .56731 Mtetra
.27573 .56731 .28605 .57645 .30187 .57151 .29162 .56232 Mtetra
.29162 .56232 .30187 .57151 .3178 .56654 .3076 .55729 Mtetra
.3076 .55729 .3178 .56654 .33381 .56154 .32367 .55224 Mtetra
.32367 .55224 .33381 .56154 .34993 .55651 .33985 .54715 Mtetra
.33985 .54715 .34993 .55651 .36614 .55145 .35612 .54203 Mtetra
.646 .763 .934 r
.35612 .54203 .36614 .55145 .38246 .54635 .3725 .53688 Mtetra
.3725 .53688 .38246 .54635 .39887 .54121 .38898 .53169 Mtetra
.647 .763 .934 r
.38898 .53169 .39887 .54121 .41539 .53602 .40555 .52645 Mtetra
.40555 .52645 .41539 .53602 .432 .53077 .42223 .52116 Mtetra
.648 .764 .933 r
.42223 .52116 .432 .53077 .44872 .52542 .43902 .51578 Mtetra
.651 .766 .933 r
.43902 .51578 .44872 .52542 .46555 .51992 .45591 .51029 Mtetra
.655 .768 .933 r
.45591 .51029 .46555 .51992 .48248 .51416 .47291 .5046 Mtetra
.663 .774 .932 r
.47291 .5046 .48248 .51416 .49951 .50793 .49001 .49856 Mtetra
.677 .784 .93 r
.49001 .49856 .49951 .50793 .51665 .50086 .50722 .49189 Mtetra
.703 .801 .926 r
.50722 .49189 .51665 .50086 .53386 .49227 .52453 .48408 Mtetra
.746 .83 .916 r
.52453 .48408 .53386 .49227 .55114 .48098 .5419 .47423 Mtetra
.811 .87 .891 r
.5419 .47423 .55114 .48098 .5684 .46516 .55931 .46084 Mtetra
.887 .913 .838 r
.55931 .46084 .5684 .46516 .58553 .44249 .57665 .44176 Mtetra
.948 .936 .748 r
.57665 .44176 .58553 .44249 .60238 .41118 .59379 .41472 Mtetra
.97 .932 .645 r
.59379 .41472 .60238 .41118 .61884 .37225 .61058 .37904 Mtetra
.964 .917 .57 r
.61058 .37904 .61884 .37225 .63496 .33079 .62696 .33781 Mtetra
.955 .918 .559 r
.62696 .33781 .63496 .33079 .65096 .29355 .6431 .29752 Mtetra
.955 .941 .627 r
.6431 .29752 .65096 .29355 .66709 .2645 .65926 .26399 Mtetra
.94 .957 .747 r
.65926 .26399 .66709 .2645 .68349 .2436 .67563 .23907 Mtetra
.882 .927 .847 r
.67563 .23907 .68349 .2436 .70017 .22876 .69229 .22139 Mtetra
.806 .868 .894 r
.69229 .22139 .70017 .22876 .7171 .21776 .70922 .20861 Mtetra
.747 .817 .907 r
.70922 .20861 .7171 .21776 .73423 .20898 .72638 .19878 Mtetra
.709 .784 .91 r
.72638 .19878 .73423 .20898 .75153 .20141 .74373 .19061 Mtetra
.688 .764 .91 r
.74373 .19061 .75153 .20141 .76898 .19448 .76123 .18332 Mtetra
.676 .754 .909 r
.76123 .18332 .76898 .19448 .78655 .18787 .77887 .17649 Mtetra
.67 .748 .909 r
.77887 .17649 .78655 .18787 .80425 .18141 .79664 .16988 Mtetra
.646 .762 .934 r
.14117 .59738 .15203 .60619 .16717 .60143 .15637 .59257 Mtetra
.15637 .59257 .16717 .60143 .18241 .59664 .17165 .58773 Mtetra
.17165 .58773 .18241 .59664 .19773 .59183 .18703 .58286 Mtetra
.18703 .58286 .19773 .59183 .21314 .58698 .20249 .57796 Mtetra
.20249 .57796 .21314 .58698 .22865 .58211 .21805 .57303 Mtetra
.21805 .57303 .22865 .58211 .24425 .57721 .23371 .56808 Mtetra
.23371 .56808 .24425 .57721 .25994 .57227 .24946 .56309 Mtetra
.24946 .56309 .25994 .57227 .27573 .56731 .2653 .55807 Mtetra
.2653 .55807 .27573 .56731 .29162 .56232 .28124 .55302 Mtetra
.28124 .55302 .29162 .56232 .3076 .55729 .29728 .54794 Mtetra
.29728 .54794 .3076 .55729 .32367 .55224 .31342 .54283 Mtetra
.31342 .54283 .32367 .55224 .33985 .54715 .32965 .53769 Mtetra
.32965 .53769 .33985 .54715 .35612 .54203 .34599 .53251 Mtetra
.34599 .53251 .35612 .54203 .3725 .53688 .36243 .5273 Mtetra
.646 .763 .934 r
.36243 .5273 .3725 .53688 .38898 .53169 .37897 .52205 Mtetra
.37897 .52205 .38898 .53169 .40555 .52645 .39561 .51676 Mtetra
.647 .763 .934 r
.39561 .51676 .40555 .52645 .42223 .52116 .41235 .51142 Mtetra
.648 .764 .934 r
.41235 .51142 .42223 .52116 .43902 .51578 .42921 .50601 Mtetra
.649 .765 .933 r
.42921 .50601 .43902 .51578 .45591 .51029 .44616 .50051 Mtetra
.652 .767 .933 r
.44616 .50051 .45591 .51029 .47291 .5046 .46323 .49485 Mtetra
.658 .771 .932 r
.46323 .49485 .47291 .5046 .49001 .49856 .4804 .48893 Mtetra
.669 .778 .931 r
.4804 .48893 .49001 .49856 .50722 .49189 .49768 .48253 Mtetra
.688 .791 .928 r
.49768 .48253 .50722 .49189 .52453 .48408 .51507 .47529 Mtetra
.722 .814 .922 r
.51507 .47529 .52453 .48408 .5419 .47423 .53254 .46652 Mtetra
.776 .849 .906 r
.53254 .46652 .5419 .47423 .55931 .46084 .55007 .45502 Mtetra
.849 .893 .869 r
.55007 .45502 .55931 .46084 .57665 .44176 .56759 .43897 Mtetra
.921 .928 .797 r
.56759 .43897 .57665 .44176 .59379 .41472 .58498 .41601 Mtetra
.964 .937 .695 r
.58498 .41601 .59379 .41472 .61058 .37904 .60208 .38437 Mtetra
.969 .924 .601 r
.60208 .38437 .61058 .37904 .62696 .33781 .61879 .34506 Mtetra
.959 .914 .555 r
.61879 .34506 .62696 .33781 .6431 .29752 .63514 .30322 Mtetra
.955 .928 .584 r
.63514 .30322 .6431 .29752 .65926 .26399 .65137 .26564 Mtetra
.952 .953 .685 r
.65137 .26564 .65926 .26399 .67563 .23907 .66773 .23628 Mtetra
.916 .948 .803 r
.66773 .23628 .67563 .23907 .69229 .22139 .68436 .21514 Mtetra
.844 .899 .876 r
.68436 .21514 .69229 .22139 .70922 .20861 .70129 .20008 Mtetra
.774 .841 .903 r
.70129 .20008 .70922 .20861 .72638 .19878 .71846 .18888 Mtetra
.725 .798 .909 r
.71846 .18888 .72638 .19878 .74373 .19061 .73585 .17991 Mtetra
.697 .773 .91 r
.73585 .17991 .74373 .19061 .76123 .18332 .7534 .17215 Mtetra
.681 .758 .909 r
.7534 .17215 .76123 .18332 .77887 .17649 .77111 .16504 Mtetra
.673 .75 .909 r
.77111 .16504 .77887 .17649 .79664 .16988 .78895 .15825 Mtetra
.646 .762 .934 r
.13019 .58848 .14117 .59738 .15637 .59257 .14544 .58361 Mtetra
.14544 .58361 .15637 .59257 .17165 .58773 .16077 .57872 Mtetra
.16077 .57872 .17165 .58773 .18703 .58286 .1762 .57379 Mtetra
.1762 .57379 .18703 .58286 .20249 .57796 .19172 .56884 Mtetra
.19172 .56884 .20249 .57796 .21805 .57303 .20734 .56386 Mtetra
.20734 .56386 .21805 .57303 .23371 .56808 .22305 .55884 Mtetra
.22305 .55884 .23371 .56808 .24946 .56309 .23885 .5538 Mtetra
.23885 .5538 .24946 .56309 .2653 .55807 .25476 .54872 Mtetra
.25476 .54872 .2653 .55807 .28124 .55302 .27075 .54362 Mtetra
.27075 .54362 .28124 .55302 .29728 .54794 .28685 .53848 Mtetra
.28685 .53848 .29728 .54794 .31342 .54283 .30305 .53331 Mtetra
.30305 .53331 .31342 .54283 .32965 .53769 .31934 .52811 Mtetra
.31934 .52811 .32965 .53769 .34599 .53251 .33574 .52287 Mtetra
.33574 .52287 .34599 .53251 .36243 .5273 .35224 .51761 Mtetra
.646 .763 .934 r
.35224 .51761 .36243 .5273 .37897 .52205 .36884 .5123 Mtetra
.36884 .5123 .37897 .52205 .39561 .51676 .38555 .50695 Mtetra
.647 .763 .934 r
.38555 .50695 .39561 .51676 .41235 .51142 .40236 .50156 Mtetra
.40236 .50156 .41235 .51142 .42921 .50601 .41928 .49611 Mtetra
.648 .764 .933 r
.41928 .49611 .42921 .50601 .44616 .50051 .4363 .49058 Mtetra
.651 .766 .933 r
.4363 .49058 .44616 .50051 .46323 .49485 .45344 .48493 Mtetra
.655 .768 .933 r
.45344 .48493 .46323 .49485 .4804 .48893 .47068 .47907 Mtetra
.663 .774 .932 r
.47068 .47907 .4804 .48893 .49768 .48253 .48803 .47287 Mtetra
.677 .784 .93 r
.48803 .47287 .49768 .48253 .51507 .47529 .50549 .46603 Mtetra
.703 .801 .926 r
.50549 .46603 .51507 .47529 .53254 .46652 .52305 .45804 Mtetra
.746 .83 .916 r
.52305 .45804 .53254 .46652 .55007 .45502 .54069 .44799 Mtetra
.811 .87 .891 r
.54069 .44799 .55007 .45502 .56759 .43897 .55836 .43438 Mtetra
.887 .913 .838 r
.55836 .43438 .56759 .43897 .58498 .41601 .57596 .41504 Mtetra
.948 .937 .748 r
.57596 .41504 .58498 .41601 .60208 .38437 .59336 .38769 Mtetra
.97 .932 .644 r
.59336 .38769 .60208 .38437 .61879 .34506 .6104 .35164 Mtetra
.964 .917 .57 r
.6104 .35164 .61879 .34506 .63514 .30322 .62703 .31002 Mtetra
.956 .918 .56 r
.62703 .31002 .63514 .30322 .65137 .26564 .6434 .26937 Mtetra
.956 .941 .628 r
.6434 .26937 .65137 .26564 .66773 .23628 .65979 .23551 Mtetra
.94 .957 .747 r
.65979 .23551 .66773 .23628 .68436 .21514 .6764 .21032 Mtetra
.882 .927 .847 r
.6764 .21032 .68436 .21514 .70129 .20008 .6933 .1924 Mtetra
.806 .868 .893 r
.6933 .1924 .70129 .20008 .71846 .18888 .71048 .17941 Mtetra
.747 .817 .907 r
.71048 .17941 .71846 .18888 .73585 .17991 .72789 .16939 Mtetra
.709 .784 .91 r
.72789 .16939 .73585 .17991 .7534 .17215 .7455 .16102 Mtetra
.688 .764 .91 r
.7455 .16102 .7534 .17215 .77111 .16504 .76326 .15354 Mtetra
.676 .754 .909 r
.76326 .15354 .77111 .16504 .78895 .15825 .78117 .14652 Mtetra
.646 .762 .934 r
.11909 .57947 .13019 .58848 .14544 .58361 .13439 .57455 Mtetra
.13439 .57455 .14544 .58361 .16077 .57872 .14978 .5696 Mtetra
.14978 .5696 .16077 .57872 .1762 .57379 .16526 .56463 Mtetra
.16526 .56463 .1762 .57379 .19172 .56884 .18083 .55962 Mtetra
.18083 .55962 .19172 .56884 .20734 .56386 .1965 .55458 Mtetra
.1965 .55458 .20734 .56386 .22305 .55884 .21227 .54951 Mtetra
.21227 .54951 .22305 .55884 .23885 .5538 .22813 .54441 Mtetra
.22813 .54441 .23885 .5538 .25476 .54872 .24409 .53927 Mtetra
.24409 .53927 .25476 .54872 .27075 .54362 .26015 .53411 Mtetra
.26015 .53411 .27075 .54362 .28685 .53848 .2763 .52891 Mtetra
.2763 .52891 .28685 .53848 .30305 .53331 .29256 .52369 Mtetra
.29256 .52369 .30305 .53331 .31934 .52811 .30891 .51842 Mtetra
.30891 .51842 .31934 .52811 .33574 .52287 .32537 .51313 Mtetra
.32537 .51313 .33574 .52287 .35224 .51761 .34194 .5078 Mtetra
.34194 .5078 .35224 .51761 .36884 .5123 .3586 .50244 Mtetra
.646 .763 .934 r
.3586 .50244 .36884 .5123 .38555 .50695 .37537 .49703 Mtetra
.37537 .49703 .38555 .50695 .40236 .50156 .39225 .49158 Mtetra
.647 .763 .934 r
.39225 .49158 .40236 .50156 .41928 .49611 .40923 .48609 Mtetra
.648 .764 .934 r
.40923 .48609 .41928 .49611 .4363 .49058 .42633 .48052 Mtetra
.649 .765 .933 r
.42633 .48052 .4363 .49058 .45344 .48493 .44353 .47485 Mtetra
.652 .767 .933 r
.44353 .47485 .45344 .48493 .47068 .47907 .46084 .46903 Mtetra
.658 .771 .932 r
.46084 .46903 .47068 .47907 .48803 .47287 .47827 .46294 Mtetra
.669 .778 .931 r
.47827 .46294 .48803 .47287 .50549 .46603 .4958 .45637 Mtetra
.688 .791 .928 r
.4958 .45637 .50549 .46603 .52305 .45804 .51344 .44895 Mtetra
.722 .814 .922 r
.51344 .44895 .52305 .45804 .54069 .44799 .53118 .43998 Mtetra
.776 .849 .906 r
.53118 .43998 .54069 .44799 .55836 .43438 .54897 .42828 Mtetra
.849 .893 .869 r
.54897 .42828 .55836 .43438 .57596 .41504 .56675 .41198 Mtetra
.921 .929 .797 r
.56675 .41198 .57596 .41504 .59336 .38769 .58441 .38873 Mtetra
.964 .937 .695 r
.58441 .38873 .59336 .38769 .6104 .35164 .60177 .35675 Mtetra
.969 .924 .601 r
.60177 .35675 .6104 .35164 .62703 .31002 .61873 .31706 Mtetra
.959 .914 .555 r
.61873 .31706 .62703 .31002 .6434 .26937 .63532 .27483 Mtetra
.955 .928 .584 r
.63532 .27483 .6434 .26937 .65979 .23551 .65179 .2369 Mtetra
.953 .953 .685 r
.65179 .2369 .65979 .23551 .6764 .21032 .66839 .20725 Mtetra
.916 .948 .803 r
.66839 .20725 .6764 .21032 .6933 .1924 .68527 .18584 Mtetra
.844 .898 .876 r
.68527 .18584 .6933 .1924 .71048 .17941 .70244 .17056 Mtetra
.774 .84 .903 r
.70244 .17056 .71048 .17941 .72789 .16939 .71987 .15916 Mtetra
.725 .798 .909 r
.71987 .15916 .72789 .16939 .7455 .16102 .73751 .14998 Mtetra
.697 .772 .91 r
.73751 .14998 .7455 .16102 .76326 .15354 .75533 .14204 Mtetra
.681 .758 .909 r
.75533 .14204 .76326 .15354 .78117 .14652 .7733 .13473 Mtetra
.646 .762 .934 r
.10787 .57037 .11909 .57947 .13439 .57455 .12322 .56539 Mtetra
.12322 .56539 .13439 .57455 .14978 .5696 .13866 .56039 Mtetra
.13866 .56039 .14978 .5696 .16526 .56463 .15419 .55535 Mtetra
.15419 .55535 .16526 .56463 .18083 .55962 .16982 .55029 Mtetra
.16982 .55029 .18083 .55962 .1965 .55458 .18554 .54519 Mtetra
.18554 .54519 .1965 .55458 .21227 .54951 .20137 .54007 Mtetra
.20137 .54007 .21227 .54951 .22813 .54441 .21728 .53491 Mtetra
.21728 .53491 .22813 .54441 .24409 .53927 .2333 .52972 Mtetra
.2333 .52972 .24409 .53927 .26015 .53411 .24941 .52449 Mtetra
.24941 .52449 .26015 .53411 .2763 .52891 .26563 .51924 Mtetra
.26563 .51924 .2763 .52891 .29256 .52369 .28195 .51395 Mtetra
.28195 .51395 .29256 .52369 .30891 .51842 .29837 .50863 Mtetra
.29837 .50863 .30891 .51842 .32537 .51313 .31489 .50327 Mtetra
.31489 .50327 .32537 .51313 .34194 .5078 .33151 .49788 Mtetra
.33151 .49788 .34194 .5078 .3586 .50244 .34824 .49245 Mtetra
.646 .763 .934 r
.34824 .49245 .3586 .50244 .37537 .49703 .36508 .48699 Mtetra
.36508 .48699 .37537 .49703 .39225 .49158 .38202 .48149 Mtetra
.647 .763 .934 r
.38202 .48149 .39225 .49158 .40923 .48609 .39907 .47593 Mtetra
.39907 .47593 .40923 .48609 .42633 .48052 .41623 .47032 Mtetra
.648 .764 .933 r
.41623 .47032 .42633 .48052 .44353 .47485 .4335 .46462 Mtetra
.651 .766 .933 r
.4335 .46462 .44353 .47485 .46084 .46903 .45089 .4588 Mtetra
.655 .768 .933 r
.45089 .4588 .46084 .46903 .47827 .46294 .46838 .45278 Mtetra
.663 .774 .932 r
.46838 .45278 .47827 .46294 .4958 .45637 .48599 .4464 Mtetra
.677 .784 .93 r
.48599 .4464 .4958 .45637 .51344 .44895 .50371 .43938 Mtetra
.703 .801 .926 r
.50371 .43938 .51344 .44895 .53118 .43998 .52154 .4312 Mtetra
.746 .83 .916 r
.52154 .4312 .53118 .43998 .54897 .42828 .53944 .42095 Mtetra
.811 .871 .891 r
.53944 .42095 .54897 .42828 .56675 .41198 .55737 .40711 Mtetra
.887 .913 .838 r
.55737 .40711 .56675 .41198 .58441 .38873 .57525 .3875 Mtetra
.948 .937 .748 r
.57525 .3875 .58441 .38873 .60177 .35675 .59291 .35983 Mtetra
.97 .932 .644 r
.59291 .35983 .60177 .35675 .61873 .31706 .61021 .32341 Mtetra
.964 .917 .57 r
.61021 .32341 .61873 .31706 .63532 .27483 .62709 .2814 Mtetra
.956 .918 .56 r
.62709 .2814 .63532 .27483 .65179 .2369 .64371 .24037 Mtetra
.956 .941 .628 r
.64371 .24037 .65179 .2369 .66839 .20725 .66034 .20619 Mtetra
.94 .957 .747 r
.66034 .20619 .66839 .20725 .68527 .18584 .67719 .18072 Mtetra
.882 .927 .847 r
.67719 .18072 .68527 .18584 .70244 .17056 .69434 .16256 Mtetra
.806 .868 .893 r
.69434 .16256 .70244 .17056 .71987 .15916 .71178 .14935 Mtetra
.747 .817 .907 r
.71178 .14935 .71987 .15916 .73751 .14998 .72945 .13912 Mtetra
.709 .784 .91 r
.72945 .13912 .73751 .14998 .75533 .14204 .74732 .13056 Mtetra
.688 .764 .91 r
.74732 .13056 .75533 .14204 .7733 .13473 .76535 .12288 Mtetra
.646 .762 .934 r
.09652 .56116 .10787 .57037 .12322 .56539 .11192 .55613 Mtetra
.11192 .55613 .12322 .56539 .13866 .56039 .12741 .55107 Mtetra
.12741 .55107 .13866 .56039 .15419 .55535 .143 .54598 Mtetra
.143 .54598 .15419 .55535 .16982 .55029 .15868 .54086 Mtetra
.15868 .54086 .16982 .55029 .18554 .54519 .17446 .5357 Mtetra
.17446 .5357 .18554 .54519 .20137 .54007 .19034 .53052 Mtetra
.19034 .53052 .20137 .54007 .21728 .53491 .20631 .5253 Mtetra
.20631 .5253 .21728 .53491 .2333 .52972 .22239 .52005 Mtetra
.22239 .52005 .2333 .52972 .24941 .52449 .23856 .51476 Mtetra
.23856 .51476 .24941 .52449 .26563 .51924 .25484 .50945 Mtetra
.25484 .50945 .26563 .51924 .28195 .51395 .27121 .5041 Mtetra
.27121 .5041 .28195 .51395 .29837 .50863 .28769 .49872 Mtetra
.28769 .49872 .29837 .50863 .31489 .50327 .30428 .4933 Mtetra
.30428 .4933 .31489 .50327 .33151 .49788 .32097 .48784 Mtetra
.32097 .48784 .33151 .49788 .34824 .49245 .33776 .48236 Mtetra
.33776 .48236 .34824 .49245 .36508 .48699 .35466 .47683 Mtetra
.646 .763 .934 r
.35466 .47683 .36508 .48699 .38202 .48149 .37167 .47126 Mtetra
.37167 .47126 .38202 .48149 .39907 .47593 .38879 .46565 Mtetra
.647 .763 .934 r
.38879 .46565 .39907 .47593 .41623 .47032 .40602 .45999 Mtetra
.648 .764 .934 r
.40602 .45999 .41623 .47032 .4335 .46462 .42336 .45425 Mtetra
.649 .765 .933 r
.42336 .45425 .4335 .46462 .45089 .4588 .44081 .44842 Mtetra
.652 .767 .933 r
.44081 .44842 .45089 .4588 .46838 .45278 .45838 .44242 Mtetra
.658 .771 .932 r
.45838 .44242 .46838 .45278 .48599 .4464 .47606 .43615 Mtetra
.669 .778 .931 r
.47606 .43615 .48599 .4464 .50371 .43938 .49386 .42941 Mtetra
.688 .791 .929 r
.49386 .42941 .50371 .43938 .52154 .4312 .51177 .4218 Mtetra
.722 .814 .922 r
.51177 .4218 .52154 .4312 .53944 .42095 .52977 .41263 Mtetra
.776 .849 .906 r
.52977 .41263 .53944 .42095 .55737 .40711 .54784 .40071 Mtetra
.849 .893 .869 r
.54784 .40071 .55737 .40711 .57525 .3875 .56589 .38416 Mtetra
.921 .929 .797 r
.56589 .38416 .57525 .3875 .59291 .35983 .58382 .36062 Mtetra
.964 .937 .695 r
.58382 .36062 .59291 .35983 .61021 .32341 .60146 .32828 Mtetra
.969 .924 .601 r
.60146 .32828 .61021 .32341 .62709 .2814 .61867 .2882 Mtetra
.959 .914 .555 r
.61867 .2882 .62709 .2814 .64371 .24037 .63552 .24559 Mtetra
.955 .928 .585 r
.63552 .24559 .64371 .24037 .66034 .20619 .65223 .2073 Mtetra
.953 .953 .685 r
.65223 .2073 .66034 .20619 .67719 .18072 .66907 .17734 Mtetra
.916 .948 .803 r
.66907 .17734 .67719 .18072 .69434 .16256 .6862 .15568 Mtetra
.844 .898 .876 r
.6862 .15568 .69434 .16256 .71178 .14935 .70363 .14017 Mtetra
.774 .84 .903 r
.70363 .14017 .71178 .14935 .72945 .13912 .72132 .12855 Mtetra
.725 .798 .909 r
.72132 .12855 .72945 .13912 .74732 .13056 .73923 .11917 Mtetra
.697 .772 .91 r
.73923 .11917 .74732 .13056 .76535 .12288 .75732 .11102 Mtetra
.646 .762 .934 r
.08504 .55185 .09652 .56116 .11192 .55613 .1005 .54676 Mtetra
.1005 .54676 .11192 .55613 .12741 .55107 .11604 .54165 Mtetra
.11604 .54165 .12741 .55107 .143 .54598 .13168 .5365 Mtetra
.13168 .5365 .143 .54598 .15868 .54086 .14742 .53132 Mtetra
.14742 .53132 .15868 .54086 .17446 .5357 .16325 .5261 Mtetra
.16325 .5261 .17446 .5357 .19034 .53052 .17919 .52086 Mtetra
.17919 .52086 .19034 .53052 .20631 .5253 .19522 .51558 Mtetra
.19522 .51558 .20631 .5253 .22239 .52005 .21135 .51027 Mtetra
.21135 .51027 .22239 .52005 .23856 .51476 .22758 .50492 Mtetra
.22758 .50492 .23856 .51476 .25484 .50945 .24392 .49955 Mtetra
.24392 .49955 .25484 .50945 .27121 .5041 .26036 .49413 Mtetra
.26036 .49413 .27121 .5041 .28769 .49872 .2769 .48869 Mtetra
.2769 .48869 .28769 .49872 .30428 .4933 .29354 .48321 Mtetra
.29354 .48321 .30428 .4933 .32097 .48784 .3103 .47769 Mtetra
.3103 .47769 .32097 .48784 .33776 .48236 .32715 .47214 Mtetra
.32715 .47214 .33776 .48236 .35466 .47683 .34412 .46655 Mtetra
.646 .763 .934 r
.34412 .46655 .35466 .47683 .37167 .47126 .3612 .46092 Mtetra
.3612 .46092 .37167 .47126 .38879 .46565 .37839 .45525 Mtetra
.647 .763 .934 r
.37839 .45525 .38879 .46565 .40602 .45999 .39568 .44952 Mtetra
.39568 .44952 .40602 .45999 .42336 .45425 .41309 .44374 Mtetra
.648 .764 .933 r
.41309 .44374 .42336 .45425 .44081 .44842 .43062 .43787 Mtetra
.651 .766 .933 r
.43062 .43787 .44081 .44842 .45838 .44242 .44826 .43188 Mtetra
.655 .769 .933 r
.44826 .43188 .45838 .44242 .47606 .43615 .46602 .42568 Mtetra
.663 .774 .932 r
.46602 .42568 .47606 .43615 .49386 .42941 .48389 .41911 Mtetra
.677 .784 .93 r
.48389 .41911 .49386 .42941 .51177 .4218 .50188 .41191 Mtetra
.703 .801 .926 r
.50188 .41191 .51177 .4218 .52977 .41263 .51997 .40353 Mtetra
.746 .83 .916 r
.51997 .40353 .52977 .41263 .54784 .40071 .53815 .39307 Mtetra
.811 .871 .891 r
.53815 .39307 .54784 .40071 .56589 .38416 .55636 .37899 Mtetra
.887 .914 .838 r
.55636 .37899 .56589 .38416 .58382 .36062 .57451 .3591 Mtetra
.948 .937 .748 r
.57451 .3591 .58382 .36062 .60146 .32828 .59246 .33111 Mtetra
.97 .932 .644 r
.59246 .33111 .60146 .32828 .61867 .2882 .61002 .29432 Mtetra
.964 .917 .57 r
.61002 .29432 .61867 .2882 .63552 .24559 .62716 .25191 Mtetra
.956 .918 .56 r
.62716 .25191 .63552 .24559 .65223 .2073 .64403 .2105 Mtetra
.956 .941 .628 r
.64403 .2105 .65223 .2073 .66907 .17734 .66091 .17599 Mtetra
.941 .957 .747 r
.66091 .17599 .66907 .17734 .6862 .15568 .67801 .15023 Mtetra
.882 .927 .847 r
.67801 .15023 .6862 .15568 .70363 .14017 .69542 .13183 Mtetra
.806 .868 .893 r
.69542 .13183 .70363 .14017 .72132 .12855 .71311 .1184 Mtetra
.747 .817 .907 r
.71311 .1184 .72132 .12855 .73923 .11917 .73105 .10795 Mtetra
.709 .784 .91 r
.73105 .10795 .73923 .11917 .75732 .11102 .74919 .09918 Mtetra
.646 .762 .934 r
.07344 .54244 .08504 .55185 .1005 .54676 .08894 .53729 Mtetra
.08894 .53729 .1005 .54676 .11604 .54165 .10454 .53212 Mtetra
.10454 .53212 .11604 .54165 .13168 .5365 .12023 .52691 Mtetra
.12023 .52691 .13168 .5365 .14742 .53132 .13603 .52167 Mtetra
.13603 .52167 .14742 .53132 .16325 .5261 .15192 .51639 Mtetra
.15192 .51639 .16325 .5261 .17919 .52086 .1679 .51109 Mtetra
.1679 .51109 .17919 .52086 .19522 .51558 .18399 .50575 Mtetra
.18399 .50575 .19522 .51558 .21135 .51027 .20018 .50038 Mtetra
.20018 .50038 .21135 .51027 .22758 .50492 .21648 .49497 Mtetra
.21648 .49497 .22758 .50492 .24392 .49955 .23287 .48953 Mtetra
.23287 .48953 .24392 .49955 .26036 .49413 .24937 .48405 Mtetra
.24937 .48405 .26036 .49413 .2769 .48869 .26597 .47854 Mtetra
.26597 .47854 .2769 .48869 .29354 .48321 .28268 .473 Mtetra
.28268 .473 .29354 .48321 .3103 .47769 .2995 .46742 Mtetra
.2995 .46742 .3103 .47769 .32715 .47214 .31642 .4618 Mtetra
.31642 .4618 .32715 .47214 .34412 .46655 .33346 .45614 Mtetra
.33346 .45614 .34412 .46655 .3612 .46092 .3506 .45045 Mtetra
.646 .763 .934 r
.3506 .45045 .3612 .46092 .37839 .45525 .36786 .44471 Mtetra
.36786 .44471 .37839 .45525 .39568 .44952 .38522 .43893 Mtetra
.647 .763 .934 r
.38522 .43893 .39568 .44952 .41309 .44374 .40271 .43309 Mtetra
.648 .764 .934 r
.40271 .43309 .41309 .44374 .43062 .43787 .4203 .42718 Mtetra
.649 .765 .933 r
.4203 .42718 .43062 .43787 .44826 .43188 .43801 .42117 Mtetra
.652 .767 .933 r
.43801 .42117 .44826 .43188 .46602 .42568 .45584 .41499 Mtetra
.658 .771 .932 r
.45584 .41499 .46602 .42568 .48389 .41911 .47379 .40854 Mtetra
.669 .778 .931 r
.47379 .40854 .48389 .41911 .50188 .41191 .49186 .40161 Mtetra
.688 .791 .929 r
.49186 .40161 .50188 .41191 .51997 .40353 .51004 .3938 Mtetra
.722 .814 .922 r
.51004 .3938 .51997 .40353 .53815 .39307 .52832 .38443 Mtetra
.776 .849 .906 r
.52832 .38443 .53815 .39307 .55636 .37899 .54667 .37228 Mtetra
.849 .893 .869 r
.54667 .37228 .55636 .37899 .57451 .3591 .56501 .35547 Mtetra
.921 .929 .797 r
.56501 .35547 .57451 .3591 .59246 .33111 .58322 .33162 Mtetra
.964 .937 .695 r
.58322 .33162 .59246 .33111 .61002 .29432 .60113 .29893 Mtetra
.969 .924 .6 r
.60113 .29893 .61002 .29432 .62716 .25191 .61861 .25846 Mtetra
.959 .914 .555 r
.61861 .25846 .62716 .25191 .64403 .2105 .63571 .21545 Mtetra
.956 .928 .585 r
.63571 .21545 .64403 .2105 .66091 .17599 .65268 .1768 Mtetra
.953 .953 .686 r
.65268 .1768 .66091 .17599 .67801 .15023 .66978 .14654 Mtetra
.916 .948 .804 r
.66978 .14654 .67801 .15023 .69542 .13183 .68716 .12461 Mtetra
.844 .898 .876 r
.68716 .12461 .69542 .13183 .71311 .1184 .70485 .10886 Mtetra
.774 .84 .903 r
.70485 .10886 .71311 .1184 .73105 .10795 .72281 .09701 Mtetra
.725 .798 .909 r
.72281 .09701 .73105 .10795 .74919 .09918 .74099 .08742 Mtetra
.646 .762 .934 r
.0617 .53291 .07344 .54244 .08894 .53729 .07726 .52771 Mtetra
.07726 .52771 .08894 .53729 .10454 .53212 .09291 .52247 Mtetra
.09291 .52247 .10454 .53212 .12023 .52691 .10865 .51721 Mtetra
.10865 .51721 .12023 .52691 .13603 .52167 .1245 .51191 Mtetra
.1245 .51191 .13603 .52167 .15192 .51639 .14045 .50657 Mtetra
.14045 .50657 .15192 .51639 .1679 .51109 .15649 .5012 Mtetra
.15649 .5012 .1679 .51109 .18399 .50575 .17264 .4958 Mtetra
.17264 .4958 .18399 .50575 .20018 .50038 .18889 .49037 Mtetra
.18889 .49037 .20018 .50038 .21648 .49497 .20524 .4849 Mtetra
.20524 .4849 .21648 .49497 .23287 .48953 .2217 .47939 Mtetra
.2217 .47939 .23287 .48953 .24937 .48405 .23826 .47385 Mtetra
.23826 .47385 .24937 .48405 .26597 .47854 .25492 .46828 Mtetra
.25492 .46828 .26597 .47854 .28268 .473 .27169 .46267 Mtetra
.27169 .46267 .28268 .473 .2995 .46742 .28858 .45702 Mtetra
.28858 .45702 .2995 .46742 .31642 .4618 .30557 .45134 Mtetra
.30557 .45134 .31642 .4618 .33346 .45614 .32267 .44561 Mtetra
.32267 .44561 .33346 .45614 .3506 .45045 .33988 .43985 Mtetra
.646 .763 .934 r
.33988 .43985 .3506 .45045 .36786 .44471 .3572 .43405 Mtetra
.3572 .43405 .36786 .44471 .38522 .43893 .37464 .4282 Mtetra
.647 .763 .934 r
.37464 .4282 .38522 .43893 .40271 .43309 .39219 .4223 Mtetra
.39219 .4223 .40271 .43309 .4203 .42718 .40986 .41634 Mtetra
.648 .764 .933 r
.40986 .41634 .4203 .42718 .43801 .42117 .42764 .41029 Mtetra
.651 .766 .933 r
.42764 .41029 .43801 .42117 .45584 .41499 .44555 .40412 Mtetra
.655 .769 .933 r
.44555 .40412 .45584 .41499 .47379 .40854 .46357 .39773 Mtetra
.663 .774 .932 r
.46357 .39773 .47379 .40854 .49186 .40161 .48172 .39098 Mtetra
.677 .784 .93 r
.48172 .39098 .49186 .40161 .51004 .3938 .49998 .38357 Mtetra
.703 .801 .926 r
.49998 .38357 .51004 .3938 .52832 .38443 .51836 .37499 Mtetra
.746 .83 .916 r
.51836 .37499 .52832 .38443 .54667 .37228 .53682 .36431 Mtetra
.811 .871 .892 r
.53682 .36431 .54667 .37228 .56501 .35547 .55532 .34998 Mtetra
.887 .914 .838 r
.55532 .34998 .56501 .35547 .58322 .33162 .57376 .32982 Mtetra
.948 .937 .747 r
.57376 .32982 .58322 .33162 .60113 .29893 .59198 .30149 Mtetra
.97 .932 .643 r
.59198 .30149 .60113 .29893 .61861 .25846 .60983 .26432 Mtetra
.964 .917 .57 r
.60983 .26432 .61861 .25846 .63571 .21545 .62723 .2215 Mtetra
.956 .918 .56 r
.62723 .2215 .63571 .21545 .65268 .1768 .64436 .17972 Mtetra
.956 .941 .629 r
.64436 .17972 .65268 .1768 .66978 .14654 .66149 .14486 Mtetra
.941 .957 .748 r
.66149 .14486 .66978 .14654 .68716 .12461 .67885 .11882 Mtetra
.882 .926 .847 r
.67885 .11882 .68716 .12461 .70485 .10886 .69652 .10016 Mtetra
.806 .868 .893 r
.69652 .10016 .70485 .10886 .72281 .09701 .71449 .0865 Mtetra
.747 .817 .907 r
.71449 .0865 .72281 .09701 .74099 .08742 .73271 .07583 Mtetra
.646 .762 .934 r
.04983 .52328 .0617 .53291 .07726 .52771 .06544 .51802 Mtetra
.06544 .51802 .07726 .52771 .09291 .52247 .08114 .51272 Mtetra
.08114 .51272 .09291 .52247 .10865 .51721 .09694 .50739 Mtetra
.09694 .50739 .10865 .51721 .1245 .51191 .11284 .50203 Mtetra
.11284 .50203 .1245 .51191 .14045 .50657 .12885 .49664 Mtetra
.12885 .49664 .14045 .50657 .15649 .5012 .14495 .49121 Mtetra
.14495 .49121 .15649 .5012 .17264 .4958 .16115 .48574 Mtetra
.16115 .48574 .17264 .4958 .18889 .49037 .17746 .48024 Mtetra
.17746 .48024 .18889 .49037 .20524 .4849 .19387 .47471 Mtetra
.19387 .47471 .20524 .4849 .2217 .47939 .21039 .46914 Mtetra
.21039 .46914 .2217 .47939 .23826 .47385 .22701 .46353 Mtetra
.22701 .46353 .23826 .47385 .25492 .46828 .24374 .45789 Mtetra
.24374 .45789 .25492 .46828 .27169 .46267 .26058 .45221 Mtetra
.26058 .45221 .27169 .46267 .28858 .45702 .27752 .4465 Mtetra
.27752 .4465 .28858 .45702 .30557 .45134 .29458 .44075 Mtetra
.29458 .44075 .30557 .45134 .32267 .44561 .31174 .43496 Mtetra
.31174 .43496 .32267 .44561 .33988 .43985 .32902 .42913 Mtetra
.32902 .42913 .33988 .43985 .3572 .43405 .34642 .42326 Mtetra
.646 .763 .934 r
.34642 .42326 .3572 .43405 .37464 .4282 .36392 .41734 Mtetra
.36392 .41734 .37464 .4282 .39219 .4223 .38155 .41138 Mtetra
.647 .763 .934 r
.38155 .41138 .39219 .4223 .40986 .41634 .39929 .40536 Mtetra
.648 .764 .934 r
.39929 .40536 .40986 .41634 .42764 .41029 .41715 .39927 Mtetra
.649 .765 .933 r
.41715 .39927 .42764 .41029 .44555 .40412 .43513 .39307 Mtetra
.652 .767 .933 r
.43513 .39307 .44555 .40412 .46357 .39773 .45323 .3867 Mtetra
.658 .771 .932 r
.45323 .3867 .46357 .39773 .48172 .39098 .47145 .38006 Mtetra
.669 .778 .931 r
.47145 .38006 .48172 .39098 .49998 .38357 .4898 .37293 Mtetra
.688 .791 .929 r
.4898 .37293 .49998 .38357 .51836 .37499 .50826 .36492 Mtetra
.722 .814 .922 r
.50826 .36492 .51836 .37499 .53682 .36431 .52682 .35533 Mtetra
.776 .849 .906 r
.52682 .35533 .53682 .36431 .55532 .34998 .54546 .34294 Mtetra
.849 .893 .869 r
.54546 .34294 .55532 .34998 .57376 .32982 .56409 .32587 Mtetra
.922 .929 .797 r
.56409 .32587 .57376 .32982 .59198 .30149 .58259 .30171 Mtetra
.964 .937 .694 r
.58259 .30171 .59198 .30149 .60983 .26432 .60079 .26866 Mtetra
.969 .924 .6 r
.60079 .26866 .60983 .26432 .62723 .2215 .61855 .22779 Mtetra
.959 .914 .555 r
.61855 .22779 .62723 .2215 .64436 .17972 .63592 .18438 Mtetra
.956 .928 .585 r
.63592 .18438 .64436 .17972 .66149 .14486 .65314 .14536 Mtetra
.953 .953 .686 r
.65314 .14536 .66149 .14486 .67885 .11882 .6705 .11479 Mtetra
.916 .947 .804 r
.6705 .11479 .67885 .11882 .69652 .10016 .68815 .09258 Mtetra
.844 .898 .876 r
.68815 .09258 .69652 .10016 .71449 .0865 .70611 .07659 Mtetra
.774 .84 .903 r
.70611 .07659 .71449 .0865 .73271 .07583 .72434 .06451 Mtetra
.646 .762 .934 r
.03782 .51354 .04983 .52328 .06544 .51802 .05348 .50822 Mtetra
.05348 .50822 .06544 .51802 .08114 .51272 .06924 .50286 Mtetra
.06924 .50286 .08114 .51272 .09694 .50739 .08509 .49747 Mtetra
.08509 .49747 .09694 .50739 .11284 .50203 .10105 .49204 Mtetra
.10105 .49204 .11284 .50203 .12885 .49664 .11711 .48658 Mtetra
.11711 .48658 .12885 .49664 .14495 .49121 .13327 .48109 Mtetra
.13327 .48109 .14495 .49121 .16115 .48574 .14953 .47556 Mtetra
.14953 .47556 .16115 .48574 .17746 .48024 .1659 .47 Mtetra
.1659 .47 .17746 .48024 .19387 .47471 .18237 .4644 Mtetra
.18237 .4644 .19387 .47471 .21039 .46914 .19895 .45876 Mtetra
.19895 .45876 .21039 .46914 .22701 .46353 .21563 .45309 Mtetra
.21563 .45309 .22701 .46353 .24374 .45789 .23242 .44738 Mtetra
.23242 .44738 .24374 .45789 .26058 .45221 .24932 .44164 Mtetra
.24932 .44164 .26058 .45221 .27752 .4465 .26633 .43585 Mtetra
.26633 .43585 .27752 .4465 .29458 .44075 .28346 .43003 Mtetra
.28346 .43003 .29458 .44075 .31174 .43496 .30069 .42417 Mtetra
.30069 .42417 .31174 .43496 .32902 .42913 .31804 .41827 Mtetra
.31804 .41827 .32902 .42913 .34642 .42326 .3355 .41233 Mtetra
.646 .763 .934 r
.3355 .41233 .34642 .42326 .36392 .41734 .35308 .40635 Mtetra
.35308 .40635 .36392 .41734 .38155 .41138 .37078 .40032 Mtetra
.647 .763 .934 r
.37078 .40032 .38155 .41138 .39929 .40536 .38859 .39423 Mtetra
.38859 .39423 .39929 .40536 .41715 .39927 .40652 .38808 Mtetra
.648 .764 .933 r
.40652 .38808 .41715 .39927 .43513 .39307 .42458 .38185 Mtetra
.651 .766 .933 r
.42458 .38185 .43513 .39307 .45323 .3867 .44275 .37548 Mtetra
.655 .769 .933 r
.44275 .37548 .45323 .3867 .47145 .38006 .46106 .36889 Mtetra
.663 .774 .932 r
.46106 .36889 .47145 .38006 .4898 .37293 .47948 .36194 Mtetra
.677 .784 .93 r
.47948 .36194 .4898 .37293 .50826 .36492 .49803 .35433 Mtetra
.703 .801 .926 r
.49803 .35433 .50826 .36492 .52682 .35533 .51669 .34554 Mtetra
.746 .83 .916 r
.51669 .34554 .52682 .35533 .54546 .34294 .53545 .33463 Mtetra
.811 .871 .892 r
.53545 .33463 .54546 .34294 .56409 .32587 .55424 .32005 Mtetra
.887 .914 .838 r
.55424 .32005 .56409 .32587 .58259 .30171 .57298 .29959 Mtetra
.948 .937 .747 r
.57298 .29959 .58259 .30171 .60079 .26866 .5915 .27092 Mtetra
.97 .932 .643 r
.5915 .27092 .60079 .26866 .61855 .22779 .60963 .23336 Mtetra
.964 .917 .569 r
.60963 .23336 .61855 .22779 .63592 .18438 .62731 .19015 Mtetra
.956 .918 .56 r
.62731 .19015 .63592 .18438 .65314 .14536 .6447 .14797 Mtetra
.956 .941 .629 r
.6447 .14797 .65314 .14536 .6705 .11479 .6621 .11278 Mtetra
.941 .956 .748 r
.6621 .11278 .6705 .11479 .68815 .09258 .67972 .08644 Mtetra
.882 .926 .847 r
.67972 .08644 .68815 .09258 .70611 .07659 .69766 .06752 Mtetra
.806 .868 .893 r
.69766 .06752 .70611 .07659 .72434 .06451 .71591 .05361 Mtetra
.646 .762 .934 r
.02567 .50369 .03782 .51354 .05348 .50822 .04138 .4983 Mtetra
.04138 .4983 .05348 .50822 .06924 .50286 .0572 .49288 Mtetra
.0572 .49288 .06924 .50286 .08509 .49747 .07311 .48743 Mtetra
.07311 .48743 .08509 .49747 .10105 .49204 .08912 .48194 Mtetra
.08912 .48194 .10105 .49204 .11711 .48658 .10523 .47642 Mtetra
.10523 .47642 .11711 .48658 .13327 .48109 .12145 .47086 Mtetra
.12145 .47086 .13327 .48109 .14953 .47556 .13777 .46526 Mtetra
.13777 .46526 .14953 .47556 .1659 .47 .1542 .45963 Mtetra
.1542 .45963 .1659 .47 .18237 .4644 .17073 .45397 Mtetra
.17073 .45397 .18237 .4644 .19895 .45876 .18737 .44826 Mtetra
.18737 .44826 .19895 .45876 .21563 .45309 .20411 .44252 Mtetra
.20411 .44252 .21563 .45309 .23242 .44738 .22097 .43675 Mtetra
.22097 .43675 .23242 .44738 .24932 .44164 .23793 .43093 Mtetra
.23793 .43093 .24932 .44164 .26633 .43585 .25501 .42508 Mtetra
.25501 .42508 .26633 .43585 .28346 .43003 .2722 .41918 Mtetra
.2722 .41918 .28346 .43003 .30069 .42417 .2895 .41325 Mtetra
.2895 .41325 .30069 .42417 .31804 .41827 .30692 .40728 Mtetra
.30692 .40728 .31804 .41827 .3355 .41233 .32445 .40127 Mtetra
.32445 .40127 .3355 .41233 .35308 .40635 .3421 .39521 Mtetra
.646 .763 .934 r
.3421 .39521 .35308 .40635 .37078 .40032 .35987 .38911 Mtetra
.35987 .38911 .37078 .40032 .38859 .39423 .37776 .38296 Mtetra
.647 .763 .934 r
.37776 .38296 .38859 .39423 .40652 .38808 .39576 .37675 Mtetra
.648 .764 .934 r
.39576 .37675 .40652 .38808 .42458 .38185 .41389 .37047 Mtetra
.649 .765 .933 r
.41389 .37047 .42458 .38185 .44275 .37548 .43215 .36407 Mtetra
.652 .767 .933 r
.43215 .36407 .44275 .37548 .46106 .36889 .45053 .35751 Mtetra
.658 .771 .932 r
.45053 .35751 .46106 .36889 .47948 .36194 .46903 .35067 Mtetra
.669 .778 .931 r
.46903 .35067 .47948 .36194 .49803 .35433 .48767 .34333 Mtetra
.688 .792 .929 r
.48767 .34333 .49803 .35433 .51669 .34554 .50642 .33511 Mtetra
.722 .814 .922 r
.50642 .33511 .51669 .34554 .53545 .33463 .52528 .32529 Mtetra
.776 .85 .907 r
.52528 .32529 .53545 .33463 .55424 .32005 .54421 .31266 Mtetra
.849 .894 .869 r
.54421 .31266 .55424 .32005 .57298 .29959 .56315 .29531 Mtetra
.922 .93 .797 r
.56315 .29531 .57298 .29959 .5915 .27092 .58195 .27083 Mtetra
.964 .938 .694 r
.58195 .27083 .5915 .27092 .60963 .23336 .60044 .23741 Mtetra
.969 .924 .6 r
.60044 .23741 .60963 .23336 .62731 .19015 .61849 .19614 Mtetra
.959 .914 .555 r
.61849 .19614 .62731 .19015 .6447 .14797 .63613 .15233 Mtetra
.956 .928 .586 r
.63613 .15233 .6447 .14797 .6621 .11278 .65362 .11294 Mtetra
.953 .953 .686 r
.65362 .11294 .6621 .11278 .67972 .08644 .67125 .08205 Mtetra
.916 .947 .804 r
.67125 .08205 .67972 .08644 .69766 .06752 .68917 .05956 Mtetra
.844 .898 .876 r
.68917 .05956 .69766 .06752 .71591 .05361 .70741 .04331 Mtetra
.646 .762 .934 r
.01338 .49372 .02567 .50369 .04138 .4983 .02915 .48827 Mtetra
.02915 .48827 .04138 .4983 .0572 .49288 .04501 .48279 Mtetra
.04501 .48279 .0572 .49288 .07311 .48743 .06098 .47727 Mtetra
.06098 .47727 .07311 .48743 .08912 .48194 .07705 .47171 Mtetra
.07705 .47171 .08912 .48194 .10523 .47642 .09322 .46613 Mtetra
.09322 .46613 .10523 .47642 .12145 .47086 .10949 .4605 Mtetra
.10949 .4605 .12145 .47086 .13777 .46526 .12587 .45484 Mtetra
.12587 .45484 .13777 .46526 .1542 .45963 .14236 .44914 Mtetra
.14236 .44914 .1542 .45963 .17073 .45397 .15895 .44341 Mtetra
.15895 .44341 .17073 .45397 .18737 .44826 .17565 .43764 Mtetra
.17565 .43764 .18737 .44826 .20411 .44252 .19246 .43183 Mtetra
.19246 .43183 .20411 .44252 .22097 .43675 .20938 .42598 Mtetra
.20938 .42598 .22097 .43675 .23793 .43093 .22641 .42009 Mtetra
.22641 .42009 .23793 .43093 .25501 .42508 .24355 .41417 Mtetra
.24355 .41417 .25501 .42508 .2722 .41918 .26081 .4082 Mtetra
.26081 .4082 .2722 .41918 .2895 .41325 .27818 .4022 Mtetra
.27818 .4022 .2895 .41325 .30692 .40728 .29566 .39616 Mtetra
.29566 .39616 .30692 .40728 .32445 .40127 .31327 .39007 Mtetra
.31327 .39007 .32445 .40127 .3421 .39521 .33099 .38394 Mtetra
.646 .763 .934 r
.33099 .38394 .3421 .39521 .35987 .38911 .34883 .37777 Mtetra
.34883 .37777 .35987 .38911 .37776 .38296 .36679 .37155 Mtetra
.647 .763 .934 r
.36679 .37155 .37776 .38296 .39576 .37675 .38487 .36527 Mtetra
.38487 .36527 .39576 .37675 .41389 .37047 .40308 .35893 Mtetra
.648 .764 .933 r
.40308 .35893 .41389 .37047 .43215 .36407 .42141 .35249 Mtetra
.651 .766 .933 r
.42141 .35249 .43215 .36407 .45053 .35751 .43987 .34592 Mtetra
.655 .769 .933 r
.43987 .34592 .45053 .35751 .46903 .35067 .45846 .33913 Mtetra
.663 .774 .932 r
.45846 .33913 .46903 .35067 .48767 .34333 .47717 .33197 Mtetra
.677 .784 .93 r
.47717 .33197 .48767 .34333 .50642 .33511 .49601 .32415 Mtetra
.703 .802 .926 r
.49601 .32415 .50642 .33511 .52528 .32529 .51497 .31513 Mtetra
.746 .83 .916 r
.51497 .31513 .52528 .32529 .54421 .31266 .53403 .30398 Mtetra
.811 .871 .892 r
.53403 .30398 .54421 .31266 .56315 .29531 .55313 .28914 Mtetra
.887 .914 .838 r
.55313 .28914 .56315 .29531 .58195 .27083 .57217 .26838 Mtetra
.948 .938 .747 r
.57217 .26838 .58195 .27083 .60044 .23741 .59099 .23936 Mtetra
.97 .932 .643 r
.59099 .23936 .60044 .23741 .61849 .19614 .60942 .20141 Mtetra
.964 .917 .569 r
.60942 .20141 .61849 .19614 .63613 .15233 .62738 .15779 Mtetra
.956 .918 .561 r
.62738 .15779 .63613 .15233 .65362 .11294 .64505 .11522 Mtetra
.956 .941 .63 r
.64505 .11522 .65362 .11294 .67125 .08205 .66272 .07968 Mtetra
.941 .956 .748 r
.66272 .07968 .67125 .08205 .68917 .05956 .68062 .05304 Mtetra
.882 .926 .847 r
.68062 .05304 .68917 .05956 .70741 .04331 .69884 .03385 Mtetra
.646 .762 .934 r
.00095 .48363 .01338 .49372 .02915 .48827 .01677 .47812 Mtetra
.01677 .47812 .02915 .48827 .04501 .48279 .03269 .47257 Mtetra
.03269 .47257 .04501 .48279 .06098 .47727 .04871 .46699 Mtetra
.04871 .46699 .06098 .47727 .07705 .47171 .06483 .46137 Mtetra
.06483 .46137 .07705 .47171 .09322 .46613 .08106 .45571 Mtetra
.08106 .45571 .09322 .46613 .10949 .4605 .09739 .45002 Mtetra
.09739 .45002 .10949 .4605 .12587 .45484 .11383 .44429 Mtetra
.11383 .44429 .12587 .45484 .14236 .44914 .13038 .43853 Mtetra
.13038 .43853 .14236 .44914 .15895 .44341 .14703 .43272 Mtetra
.14703 .43272 .15895 .44341 .17565 .43764 .16379 .42688 Mtetra
.16379 .42688 .17565 .43764 .19246 .43183 .18066 .421 Mtetra
.18066 .421 .19246 .43183 .20938 .42598 .19765 .41508 Mtetra
.19765 .41508 .20938 .42598 .22641 .42009 .21474 .40913 Mtetra
.21474 .40913 .22641 .42009 .24355 .41417 .23195 .40313 Mtetra
.23195 .40313 .24355 .41417 .26081 .4082 .24927 .39709 Mtetra
.24927 .39709 .26081 .4082 .27818 .4022 .26671 .39101 Mtetra
.26671 .39101 .27818 .4022 .29566 .39616 .28427 .38489 Mtetra
.28427 .38489 .29566 .39616 .31327 .39007 .30194 .37873 Mtetra
.30194 .37873 .31327 .39007 .33099 .38394 .31974 .37253 Mtetra
.31974 .37253 .33099 .38394 .34883 .37777 .33765 .36628 Mtetra
.646 .763 .934 r
.33765 .36628 .34883 .37777 .36679 .37155 .35568 .35998 Mtetra
.35568 .35998 .36679 .37155 .38487 .36527 .37384 .35364 Mtetra
.647 .763 .934 r
.37384 .35364 .38487 .36527 .40308 .35893 .39213 .34723 Mtetra
.648 .764 .934 r
.39213 .34723 .40308 .35893 .42141 .35249 .41054 .34074 Mtetra
.649 .765 .933 r
.41054 .34074 .42141 .35249 .43987 .34592 .42907 .33414 Mtetra
.652 .767 .933 r
.42907 .33414 .43987 .34592 .45846 .33913 .44774 .32737 Mtetra
.658 .771 .933 r
.44774 .32737 .45846 .33913 .47717 .33197 .46654 .32032 Mtetra
.669 .778 .931 r
.46654 .32032 .47717 .33197 .49601 .32415 .48547 .31276 Mtetra
.688 .792 .929 r
.48547 .31276 .49601 .32415 .51497 .31513 .50452 .30432 Mtetra
.722 .814 .922 r
.50452 .30432 .51497 .31513 .53403 .30398 .52369 .29426 Mtetra
.776 .85 .907 r
.52369 .29426 .53403 .30398 .55313 .28914 .54293 .28138 Mtetra
.849 .894 .869 r
.54293 .28138 .55313 .28914 .57217 .26838 .56217 .26374 Mtetra
.922 .93 .797 r
.56217 .26374 .57217 .26838 .59099 .23936 .58128 .23894 Mtetra
.964 .938 .694 r
.58128 .23894 .59099 .23936 .60942 .20141 .60008 .20515 Mtetra
.969 .924 .599 r
.60008 .20515 .60942 .20141 .62738 .15779 .61842 .16346 Mtetra
.959 .914 .556 r
.61842 .16346 .62738 .15779 .64505 .11522 .63635 .11925 Mtetra
.956 .928 .586 r
.63635 .11925 .64505 .11522 .66272 .07968 .65411 .0795 Mtetra
.953 .953 .687 r
.65411 .0795 .66272 .07968 .68062 .05304 .67202 .04827 Mtetra
.916 .947 .804 r
.67202 .04827 .68062 .05304 .69884 .03385 .69022 .0255 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09674 .23181 m
.10144 .23638 L
s
[(-5)] .08733 .22266 1 .97262 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61454 .02905 m
.61829 .03444 L
s
[(5)] .60704 .01829 .69632 1 Mshowa
.125 Mabswid
.14416 .21324 m
.14694 .21603 L
s
.19248 .19432 m
.19521 .19716 L
s
.24172 .17504 m
.2444 .17792 L
s
.2919 .15539 m
.29453 .15832 L
s
.39523 .11493 m
.39774 .11796 L
s
.44843 .0941 m
.45088 .09718 L
s
.50269 .07285 m
.50508 .07598 L
s
.55805 .05117 m
.56037 .05435 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{251.313, 203.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.123752,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000oQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00<Aoo`@0079o
o`00`goo00<007ooOol00Woo00<007ooOol0Kgoo0038Ool00`00Oomoo`1_Ool00<Qoo`03001oogoo
06moo`00a7oo1000LWoo0034Ool00`00Oomoo`1cOol00<Aoo`03001oogoo01Qoo`8005Uoo`00a7oo
1@0057oo0P0000=oo`000000F7oo003JOol30003Ool2001HOol00=Qoo`80009oo`07001oogooOol0
07oo0000Egoo003EOol30008Ool200000goo001oo`1EOol00=9oo`<000]oo`04001oogoo001FOol0
0=1oo`8000ioo`05001oogooOol0001EOol00<eoo`<0011oo`03001oogoo009oo`03001oogoo059o
o`00bgoo0P004Woo00=c^@00Ool00goo00<007ooOol0DWoo0038Ool300000goo001oo`0AOol00g>h
MmT00004Ool00`00Oomoo`1AOol006Moo`80009oo`8005Uoo`8000Aoo`03001oogoo00moo`05LkQc
^G>i001c^004Ool00`00Oomoo`1@Ool006Qoo`04001oogoo001GOol3000GOol01g>hMmUc^7OI001_
^VnJ00=oo`03001oogoo051oo`00JGoo0P00EWoo0P006Goo00Ic^7>iLkUc^G>h0002KkX01FnJOomo
ogoo0000DGoo001YOol2001COol3000KOol02WOILkQgfG>hKkX007>jKiY[Vf]k0goo00<007ooOol0
CWoo001XOol01000Oomoo`00D7oo0P007Goo0g>i00Ec^6njKkX006nJ00=[V`04Jg]oogoo001@Ool0
06Moo`80009oo`8004aoo`<001ioo`0>NmEg]7_EMkE_^VnJLkX006^KJg][Vf]kJi][N`9oo`03001o
ogoo04eoo`00]Woo0`000Woo00<007ooOol077oo00Qg]G_EMkEgegNgKkY_VP000V^K00E[Nf^KJi]W
O6Mk008004moo`00]7oo0P008goo011g]7_EMkEkeGNfMmMg]f^K001[Vf]kJi]SFfMlHe]WO09oo`03
001oogoo04aoo`00/Goo0`009Goo00IkeGNeMkEg]gOGMkL2LkT02@00Jg][VfMkIgaWNfMlIg]WO002
Ool00`00Oomoo`1;Ool00:moo`8002Moo`0ENmEg]G_EMkIgegNgMmUc^7OI001WO6=KIgaSFfMlHe]W
O5mLHeaoo`00015oo`D003Moo`00[7oo0`00:Goo0WNe00Ag]gOGMkMge`9c^@08LkP006njIgaWNfMl
Ig]WO0=SG09oo`03001oogoo00ioo`05001oogooOol0000gOol00:Yoo`8002]oo`0EMkEkeGNdMmMg
]gOGLkQgfG>hKkX007>jKiYWO6=KHeaOG6=LGc]SG5mL009oo`03001oogoo00ioo`03001oogoo03Qo
o`00Ygoo0`000Woo00<007ooOol0:7oo0WNe00=gegNgMmL00W>i00Ec^7>iKkX006nJ009_^PMSG09o
o`03001oogoo00Eoo`H000Aoo`03001oogoo03Moo`00YGoo0P00;goo01MkeGNdMmMg]gOGLkQgfG>h
MmU_VW>j001_^VnJJi][Nf=LGc]SG5mLHeaK?5mL009oo`03001oogoo00moo`03001oogoo03Ioo`00
XWoo0`00<Goo00Qg/W^bMk=k/gNeNmEc^7>i0Vnj00I_VP00KkY[Vf]kJi/3He`5Gc`2Ool00`00Oomo
o`0?Ool00`00Oomoo`0eOol007Eoo`@002Moo`8003=oo`0BMi5k/WNcNk=g/g_EMkEkeFnJLkY_VVnj
001[Vf]kJi][Nf^K0Ull00QK?5mLGcaO?5/lGeaoo`003Goo00D007ooOomoo`0003Moo`00M7oo00<0
07ooOol00Woo00<007ooOol08Goo0`00=Goo00Ek/WNBNk=g/g_E009g]@07MkMgegNgMmM[V`00Jg/0
0f^K00=WNfMlGc`01Ell00AK75/lOol000eoo`<003Qoo`00M7oo00<007ooOol00Woo00<007ooOol0
7Woo0`00=goo01Ek/WNANk=g/g^dMkEkeGNdMmMg]gOGLkQgfF]k001[Nf^KHe]WO6=KIg`00Ull00QK
?5llFaaK?5/L001oo`00Agoo001dOol00`00Oomoo`02Ool00`00Oomoo`0LOol20002Ool00`00Oomo
o`0eOol017NBNk9g/g^c0gNe01QgegNgMmMg]g>iLkQ[V`00IgaWNfMlIg]WO6MkIgaK75/lFaaK?5/L
FcaK77oo0017Ool007Aoo`03001oogoo009oo`03001oogoo01Uoo`<003]oo`0LMi5k/WNcNkAg/g_E
MkAgegNgMmMg]WOILkQgfG>h001SFfMlHe]WO6=KHeaO>f=LFaaK?5/LGc`2Fa`00eLLOol00016Ool0
07Aoo`03001oogoo009oo`03001oogoo01Moo`8003ioo`04Nk9g/W^cMk<2MkD01WOGMkMgegNgLkUc
^09c^@05KkX006MlIg]WO005He`015/lFaaK?5LL0e/L0Woo00<007ooOol0@goo001dOol00`00Oomo
o`02Ool00`00Oomoo`0DOol3000oOol08g^bMi5k]7NcNk=g]7_EMkMgegNfMmUc^7OILkQc^VnJ001_
VV=LGeaSG5lkHeaOG6=LGc]K75LLFaaG75/LEaaK77oo0000AGoo001eOol4000EOol20012Ool02gNb
Nk9g/g^cMkEkeGNgMmMg]gOGLkP00W>i00I_^VnJKkX006^KJg/6He`2Gc`3Fa`00eLLFaaK7002Ool0
0`00Oomoo`12Ool008]oo`<004=oo`0JMi5k/WNANk5gT7^bMi5k/gNcNkAc^7OILkQc^VnJKkY_VP00
Jg][Vf]kHeaOG6=LFcaOG09O?007EaaK75LLFaaFo5/LE_`00Woo00<007ooOol0@Goo0029Ool20002
Ool00`00Oomoo`11Ool02G^AMi5kTGNANk9gTW^cMk=k/`03MkD01VnjKiY_^VnjJi/000=[V`03Jg]O
?5ll00EO?005E_aG75LLEaaFo002Ea`00goo001oo`12Ool008Ioo`<004Qoo`0HMi1k/GN@Nk5gTG^b
Mk=k]7NcNmEg]7OGMkM_^VnJJi][N`00Jg][Vf]kIgaSFemL0Ull00eK?5mLFaaK?5KlFaaFo5/LE_aK
75KlOol00012Ool008Aoo`8004Yoo`09Mi5kTGNANk5gTW^bMk=k/gNc009g]@0=NmEg]gOGMkM[Vf]k
Ji/006^KJg]WO6MkIg`00ell00IK?5/LFcaK75/lE_`3Ea`3E_`00goo001oo`10Ool0085oo`<004ao
o`0YNi5gT7^aMi5k/WNANkAg/g^cMkAkeGNgMmMg]WOILkQ[Vf]k001SFfMlHe]WO6=KIgaK75llFaaK
?5/LGcaK75/lE_aG75KlEaaFo5LLOol00011Ool007ioo`<004ioo`9kT@0>Nk5gTG^bMk9k/gNcNk=g
]G_EMkMgegNgLkUc^0=c^@06001WO6MkIgaWNfMl0V=L00IK75/lFaaK?5/LFc`2Fa`3E_`01ELLE_aF
o7oo0000@7oo001lOol2001AOol07WN@Nk5gTG^aMi5k/WNcNk=g]7_EMkMgegNfMmMc^7OILkQgfFnJ
001SFfMlHe]SG5lkHeaOG6=LFaaO?09K700<EaaK75LLEaaFo5LLE_aG75;lEaaoo`00?goo001iOol3
0002Ool2001?Ool03W^AMi5kTGNbNk9g/g^cMk=keGNeMmMg]gOGLkP3LkT016nJKkX006nj26=L00EG
75/LFaaK75LL009K7003EaaFo5Kl00=Fo003Ool007oo03ioo`00Mgoo0P00EGoo01ek/GN@Nk5gT7^b
Mi5k/gNcNmEg]GOGMkIgeg>hMmUc^7OIKiY_^VnJ001[Nf^KGc]SG5mLHeaO>emL009O?00?EaaK75LL
FaaG75/LD_aG75;lEaaBo5LLD_aoo`0003ioo`00M7oo0`00Egoo00egTG^AMi5k/WNBNi5gTG^aMi5k
/WNcNk=c^003LkT01FnJKkY_^Vnj00000V^K0f=L1Ell00MK75LLFaaK75LLE_aG7006E_`2Ool00`00
Oomoo`0kOol0079oo`8005Yoo`0KNi5gT7^aMi1kTGN@Nk5gTG^bMk=k]7NcNmEg]7_EKiY_^VnJJi][
N`00Jg][Vf]kGcaK?5mL009O?00BFcaOG5llFaaFo5/LE_aK75KlEaaBo5LLD_aG75;lE_aoo`00?Goo
001_Ool3001KOol00g^AMi5k/@02Ni401gNANk5gTG^bMk9k/gNc009g]@06NmEg]gOGMkM[Vf]k0V^K
00@006]kIgaWN`EO?005FaaK?5/LEaaFo003Ea`4E_`00e;lE_aFo002Ool00`00Oomoo`0jOol006eo
o`800003Ool007oo05]oo`0_Mi1k/WNANi5gT7^aMi5k/WNANkAg/g^cMkAkeGNeMmMg]WOILkQ[Vf]k
Ji/006MlHe]WO6=KIgaK75llFaaK?5/LGcaFo5/LE_aK75KlEaaFo5LLD_aFo5;lEaaBo002Ool00`00
Oomoo`0iOol006Yoo`<005moo`03Ni5k/W^A009kT@0>Nk5gTG^AMk9k/WNcNk=g]G_EMkEgegNgMmMc
^09c^@07IgaWN`00Ig]WO6MkIg`00V=L00QK75/lFaaK?5/LFcaFo5LL0eKl00=G75;lE_`00UKl00EB
o5KlD_aoo`0003]oo`00Igoo0`00HWoo025k/gNANk5gT7^aMi5k/GN@Nk9g/g^cMk=keGNeMmMg]WOG
LkQgfG>hLkY_VVMl001WO6=KIgaO>f=LGeaK?5/LGc`00U/L015G75/LE_aG75KlEaaFo5LLD]aFo5;l
E_aBg5KlD_aoo`0003Yoo`00IGoo0P00IGoo015kTW^ANi5kTGNANi5gTG^bMi5k/gNcNmEg]GOGMkMg
eg>h00=c^@05KiY_^Vnj001WN`06He`00e/LEaaK7002Fa`015LLE_aFo5LL15Kl00QBo5KlD_aFo5;l
E_aBo000>Woo001ROol3001VOol09W^BNk5gTG^bMi1k/GN@Nk5gTG^cMk=k]7NeNmEg]WOGLkQgfG>h
MmU_VVnjKiYc^P00HeaO>f=LGeaSG5lkGeaO?5/LEaaK75LLFa`2Ea`03U;lEaaBo5LLD_aG75;LE_aB
o5KlD]aFo5;l000iOol0061oo`8006Uoo`0;Nk9kTG^AMi5kTGNANk5gTG^bMk=k/`02MkD00gNgMmMg
]`03LkT01fnJKkY_^VnjKiX006^K00=SG0AO?09K7004EaaK75LLEa`8E_`3D_`01EKlD_aBo7oo0000
>7oo001MOol300000goo001oo`1WOol07g^bNi9k/WNANi5gT7^aMi5k/WN@Nk5gTG^bMi5k/gNcMmUc
^7OILkQ_^VnJLkY_VV^K001[Vf]kGcaK?5mL009O?00GFcaOG5KlFaaFo5/LE_aK75KlEaaBo5LLD_aG
75;lE_aBg5KlD_aFo5;LE_`0000hOol005]oo`8006eoo`03Ni9kTG^A009kT@0:Nk5gTG^bNi5k/GNA
Nk9g/W^cMk<2MkD00g_EMkE_^P02KkX01f]kJi][V`00Jg]WO6Mk00EO?005FaaK?5LLEaaFo003Ea`4
E_`015;lE_aFo5Kl0e;l00AFo5;lOol003Moo`00;Woo10009Woo0`00Kgoo01ek/gNANk5gT7^aMi5k
/GN@Nk5gTG^aMi5k/WNcNk=g]7_EMkEgegNfMmM[Nf^KJg][V`00IgaSFfMl009O?00KFcaO?5/LFcaK
75llE_aK75KlFaaFo5LLE_aG75;lE_aBo5LLD_aFo5;LE_aBg5KlD]aoo`00029oo`<0015oo`00;Goo
00<007ooOol00Woo00<007ooOol08Goo0P00LGoo00=k/W^ANi401W^A00QgTG^AMk9k/WNcNk=g]G_E
0WNe00Ag]gOGLkQc^@9[V`0@Ig/006MkIgaWNfMlFaaK?5/LFcaK75/lFaaK?5KlEa`3E_`00eLLD_aF
o002E_`015;lE_aBo5Kl0e;l00=Fo7oo000097oo00<007ooOol03goo000bOol00`00Oomoo`0MOol4
001cOol0?7^BNk5gTG^aNi9k/GNANk5gTG^aMi1k/WNANk=g/g_EMkEkeGNfMmMc^7OILkQgfF=KIg`0
06MlHe]WO5lkHeaK75/lFaaO?5/LFcaG75/LE_aG75KlEaaFo5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlOol002=oo`03001oogoo00moo`009Goo1P001goo00<007ooOol077oo0`00M7oo00EkTW^ANi5k
TG^B00=kT@08Mi5kTGNANk9gTG^cMk=ke@9g]@03MkMgegNg00=c^@05KiY_^VMk001WN`05He`00e/L
FcaK7003Fa`015LLE_aFo5LL15Kl00ABo5KlD_aFo0=Bo003E_aBo5;l009Bo003Ool007oo021oo`03
001oo`00011oo`00;Woo100077oo0`00Mgoo02Uk/W^CNkAkTg^bMi5k/WN@Ni5gT7^aMi5k/WNcNmEg
]G_EMkIgegNgMmUc^7OIKiY_^VnJLkX006=LGc]SG5mLHeaO>f=LEaaK75LLFaaG75/L009G700CD_aG
75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg7oo00008Goo00<007oo000047oo000^Ool00`00
Oomoo`0JOol3001iOol01G^bNkEk]7^cNk8017^A00IgTG^aMi5k/WNcNk<3MkD00gOGMkMc^@02LkT0
1VnJKkY_^VnjJi/000ESG0=O?09K7004EaaK75/LEa`8E_`015;lE_aBo5Kl1e;l0P007goo00D007oo
Oomoo`0000moo`00;Woo00<007ooOol067oo0P00O7oo029g]G^dNi=k]7^BNk9gTG^aMi1k/GNANk9g
TG^cMkEkeGNdMmMg]gOILkQgfFnJKkY_VW>jJg][V`00Ji][NellFcaOG09O?00MFcaK75LLFaaFo5/L
E_aK75;lEaaBo5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LOol0000NOol01@00Oomoogoo
00003goo000^Ool5000COol3001mOol2NkD017^cNkAkTW^b0g^A00Yk/GNANk9g/W^aMi5k/WNbNk9g
/`9g]@03NmE_VVnj009_^P=[V`04001[VfMlIg/6Gc`3Ea`015KlEaaG75LL15Kl00ABo5KlD_aFo0=B
o003E_aBo5;l00ABo003Ool007oo01aoo`<00004Ool00000000>Ool004Aoo`80081oo`0QNkIkTg^d
Ni=k/gNANk5gTG^aMi5k/GN@Nk5gTG^bMi5k/WNcNk=g]7_EMkMgegNfMmM[Nf^KJg][V`00IgaSFfMl
009O?004FcaOG5/LFc`2Fa`015KlFaaFo5/L0UKl01ABo5LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aoo`002Goo100097oo0011Ool300000goo001oo`1nOol2NkD017^dNk=k]7^B0g^A019g
TG^ANi5kTGNANi5g/W^bMi5k/gNeNmEg]GOGMkMgeg>hLkT2Ji/03FMkIg`006MlIg]WO5/LFcaK75/l
FaaK?5Kl00=G70AFo004D_aFo5KlE_`3D_`00eKlD_aBo008D_`00goo001oo`06Ool00`00Oomoo`02
Ool00`00Oomoo`0QOol003moo`8008=oo`16NkIg]G^dNi=k]7^BNk9gTG^bMi1k/GNANk5gT7^aMi1k
/WNANk=g/g_EMkEgegNfMmMc^7OILkQgfF=KIgaSF`00He]WO5lkHeaK75/lFaaO?5/LFcaFo5LLE_aG
75KlEaaBo5KlD_aG75;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg7oo0007Ool00`00Oomoo`02
Ool00`00Oomoo`0QOol003aoo`<008Eoo`9k]@04Nk=k]7^cNk82Ni4037NANk9kTG^AMi5kTGNANk9g
TG^bMk=ke@9g]@03MkMgegNg00=c^@05KiY_^VMkIg`00004He`00e/lFaaK?004Fa`3E_`02ELLE_aF
o5;lE_aBo5KlD_aFo003D_`00eKlD_aBo007D_`00goo001oo`05Ool00`00Oomoo`02Ool00`00Oomo
o`0QOol003Yoo`8008Moo`0/MkEk]G^CNkAkTg^bNi9k/WNANk9gTG^bMi1kTGN@Nk5gTG^bMk=k/gNe
NmEg]WOGMkMgfG>hMmU_VVnjKiYc^UmL001O>f=LGeaSG5lkFaaG75/LEaaK709G700HE_aG75KlEaaB
o5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl0Woo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol08Goo000gOol30028Ool3NkD017^dNk=k]7^B0W^A00=k]7^BNi400g^A00Ek
/GNANk9g/W^c00=g]@03MmMg]g>i009c^@04KiY_^VnjKkX2Ji/00`00HeaSG002He`2Gc`3Fa`00eLL
FaaK7007E_`00e;lE_aBo002D_`00eKlD_aBo00:D_`00goo001oo`04Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol003Eoo`800003Ool007oo08Qoo`0WNkEg]G^dNi=k]7^BNk=kTg^dNi9k/WNANk5gT7^a
Mi5k/WNANk=g/g_EMkAgegNgMmUc^7OIKiY_^VnJLkY[Nf^KJg/005mLHeaK?5mL009O?00OEaaK75LL
FaaFo5/LE_aG75;lEaaBo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol08Goo000bOol3002<Ool3NkD00g^cNkAk/`02
NkD00g^dNk=k/P04Ni402GNANi5g/W^bMk=k/WNbNk9g/`02MkD017_EKiY_^Vnj1F^K00<005llGc`0
1Ell00IFo5LLEaaG75KlEa`6E_`3D_`00eKlD_aBo00=D_`30004Ool4000TOol002moo`<008ioo`0W
MkUcV7NiMkMk]gNfNkIg]G^dNi=k/g^BNk5gTG^aMi5k/GNANk9gTG^aMi5k/WNcNk=g]7_EMkMgegNf
Ji][Nf^KJg][Vf]k001SFemL009O?00UFcaO?5/LFcaFo5/LE_aK75KlFaaBo5KlD_aG75;lE_aBg5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg7oo0000;7oo000]Ool2002AOol00g>hMkUc
^003MkL2NkD00g^cNkAkTP03Ni404GNANi5gTG^AMi5kTGNbNk9gTG^cMkEkeGNeMmMg]g>iLkP00f^K
00eWN`00001WO6MkIgaK75/lFaaK?5/LFcaFo003Ea`4E_`015;lE_aFo5Kl0e;l00=Fo5;lD_`02U;l
00EBg5;lOomoo`0002]oo`00:Woo0`00TWoo025cV7NiLiQk]gNfNkMg]G^eNi=k]7^CNk9gTG^bMi1k
/GN@Nk9gT7^aMi1k/WNANk=g/g_EMkEgegNfMmMc^7OILkP00`0002YSFfMl001WO5lkHeaK75/lFaaO
?5/LFcaFo5LLE_aG75KlEaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_`2Ool00`00Oomoo`0XOol002Qoo`800003Ool007oo095oo`04LkQg^G>hMkT2MkL3NkD00g^d
Nk=k/P06Ni403GNANi5gTG^bMi5k/WNcNmEg]GOGMkMgeg>h00<00006KiY_^VMkIgaWN`000f=L00=K
?5/LFc`015/L0eKl00UG75KlE_aBo5KlD_aFo5;lE_`035;l00QBg5;lD_aBo5;LD_aoo`00:Woo000V
Ool2002EOol07W>HMkUcV7NiMkIk]gNgNkEg]G^dNi=k]7^BNk9gTG^ANi9k/WNANi5gT7^aMi5k/WNc
Nk=g]GOGMkIge`80000aLkQgfFnJLkY_VW>jGeaSG5lk001OG6=LGc]K75LLFaaG75/LEaaK75;lEaaB
o5LLD_aG75;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]`00Woo00<0
07ooOol09goo000VOol2002EOol017NiLkQg^G>h0WNg0g^e00=k/g^dNi800g^A00=kTW^ANi400W^A
00Ek/GNANk9g/W^c009g]@<000=c^@04KiY_^VnjKkX2Ji/3He`01000GcaO?5ll0e/L15LL1UKl00=B
o5KlD_`00U;l00=Fo5;lD_`02U;l00EBg5;lD_aBo5;L009oo`03001oogoo02Ioo`009Woo0`00Tgoo
01Ug^G>HMkUcV7^gMkMk]GNeNkIkTg^dNi=k/g^CNkAkTg^cMi5k/GN@Nk5gTG^bMi5k/`0300003GOG
MkMgfG>hMmU_VW>jKiYc^V]kJi][Nf^K009O?00[Fc`005llGcaK?5/LE_aK75KlFaaFo5LLD_aG75;l
EaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg7oo0000:7oo
000VOol01000Oomoo`00TGoo00E[Vf]kMkUc^7Ni009g]`=k]@07NkAk/g^bNkEk]7^cNk8017^A00=g
TG^A00000P0000Ak/WNbNk=g/`9g]@04NmE_VVnjKkX5Ji/01FMkIgaO?5ll00000Ull00=K?5/LEa`0
0ULL00EFo5LLEaaFo5;l00=Fo0=Bo003E_aBo5;l00iBo004D]aBo5;lD_`2Ool00`00Oomoo`0UOol0
02Eoo`03001oogoo009oo`03001oogoo08eoo`0EKi][NV^KJgY_VgNgNkMg]G^fMkEk]7^CNkAg]G^d
Ni=k]7^BNk5gTG^a00<0000ENk9gTG^aMi5k/gNcNk=g]7_EMkIgegNfJi][Nf^KJg][Vf=KIgaSFemL
009O?00:001O?5/LFcaFo5/LE_aK75KlEa`2E_`07U;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lOol002Moo`009Goo00<007ooOol00goo00<007ooOol0
RWoo00I[Nf^KJg][Vf]kJi/2KiX00g>hMkUc^003MkL2NkD017^cNkAkTW^b0`0000akTGNANi5gTG^A
Mk9k/WNcNk=g]G_EMkD2MmL04G>iLkQ[Vf^KIgaWNfMlIg]WO6MkFcaK75/l001K?5/LFc`00eKl00=G
75KlE_`00UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`00goo001oo`0U
Ool002Eoo`03001oogoo00Aoo`03001oogoo08Qoo`0BJgY_Vf]jJi][NVnKKiUcVVnIMkUcV7NiMiIk
]gNgNkEkTg^d0`0004Ik/WN@Nk5gT7^bMi1k/GN@Nk9g/g^cMk=keGNeMmMg]WOGLkQgfG>hIgaSFfMl
He]WO6=KHeaO>ellFaaK?000FaaG75/LE_aG75KlEaaFo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5Kl
D]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg09oo`03001oogoo02=oo`009Goo0P001Woo
0P00Qgoo00I[Nf^KJg][Vf]kLiX3KiX00gNiLkQg^@03MkL2NkD200000g^bNi9kT@04Ni402GNANi5g
TG^bMi5k/gNcNmEg]@03MmL027>hLkUc^FnjKiYWO6MkIg`5He`2Fa`01@00EaaK75/LEa`01UKl00IB
o5KlD_aFo5;lE_`<D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aoo`0002Eoo`009Goo00<007ooOol0
1goo00<007ooOol0Pgoo00mOG6=lJgY[Vf]jLkY_VG>JKiUg^G>HMkUcV7^gMkL00`0002QkTg^dNi9k
/WNANi5kTW^bMi5kTGN@Nk5gTG^bMk=k/gNeMmMg]WOGLkQgfG>hLkY_VW>jKiYc^UmLHeaO>f=LGeaO
?5/lFaaG7000EaaK709G700UD_aG75;lEaaBo5KlD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000097oo000UOol00`00Oomoo`08Ool00`00Oomo
o`21Ool5He`027>JKiY_VVnJMkUc^7NiLkP30002NkD017^cNkAkTW^b0W^A00=kTW^ANi400W^A00Ek
/GNANk9g/g^c009g]@9ge`05MkMc^G>iLkU_VP03KkX2Ji/2He`5Gc`2Fa`01000E_aG75LL1UKl0U;l
00=Fo5;lD_`03U;l00EBg5;lD_aBo5;L00=Bo005D]aBo7ooOol0000SOol002Eoo`03001oogoo00Uo
o`03001oogoo07ioo`0<HeaOG6=lGeaSG5mLIgaWFg>JKiUc^W>H0`0002Ag]g^gMiIk]W^CNkAkTg^c
Mi5k/G^CNk=gTG^aMi1k/GNANk9gTG^cMk=keGNfMmMg]WOILkQgfFnJLkY_VW>jJg][Vf]kJi/2Gc`0
<5/lGeaO?5llFcaK75Kl001Fo5/LD_aG75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol002=oo`0097oo0P0037oo00<007ooOol0
O7oo1V=L00AWO6MkIgaWN`<00003LkQg^GNg009g]`9k]@08NkAk/g^bNi9k]7^cNk9kTP=kT@0=Mi5k
TGNbNk=g/g^bMk9k/gNcMmEg]G_EKiX00Vnj1F^K00=WNfMlGc`00ell00QK75/lFaaG7000EaaFo5LL
0UKl00ABo5KlE_aFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo
000ROol002Aoo`03001oogoo00aoo`03001oogoo07Uoo`09FcaK?E/lHgaOG6=LGeaWO6MK00<0001K
JgY[Vf]jKi]g]g^gMiIk]gNeNkAkTg^dMkEk]G^CNkAkTW^aMi5k/GNANk5gTG^bMi5k/GNANk=g/g^c
MkAkeGNfMmMg]V^KJg][Vf]kJi]SFfMlHe]WO5/LFcaK75llFaaK?5KlFa`005LLE_aG75;lE_aBo5LL
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]`00Woo00<007ooOol07goo000TOol00`00Oomoo`0=Ool00`00Oomoo`1fOol01U/mFcaK?E/lFceK
?09SG0<00006Ig]WO6]kJi][Nf^K0fnJ00=cVW^eNkD00gNg00Ek]G^cNkAkTW^b009kT@0=Mi5kTGNA
Ni5gTG^AMk9k/WNcNk=g]G_EMkD00WOG00Uc^G>hJi][VfMlIg]WO6MkIg`00V=L00IK75/lFaaK?5/L
Fc`2E_`00`00EaaFo003E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`00e;LOol0000QOol002Aoo`03001oogoo00ioo`03001oogoo07=oo`08FcaK
?E/lFceK?5/mFcaK?@80000fIe]WO6=KIga[NV^KJgY_VfnILiY_VG>jLiQg^GNFNkMg]g^eMiEk]7^C
Nk9kTW^bMi1k/GN@Nk9gT7^aMi1k/WNcNk=g/g_EMkEgegNfMmUc^7OILkQWO6=KIgaSFf=LGeaSG5lk
GcaK75/l0U/L02eG75/LE_`005KlEaaFo5LLD_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg7oo000087oo000TOol00`00Oomoo`0?
Ool00`00Oomoo`1`Ool3Ead015/lFceK?5/m0`0000YOG5llIgaWNfMlJg][Vf]kJi][N`9_VP04LiYc
V7NiLkP3MkL01G^eNkAk/g^dNi801G^A00UgTG^AMi5k/WNANk=g/g_EMkD00gOG00Ic^7>iLkU_^VnJ
KkX7He`3Fa`01ULLFaaK75LLE_`000AFo004D_aFo5;lE_`>D_`01E;LD_aBo5;lD]`00e;l00EBg5;l
D_aBo5;L00=Bo09oo`03001oogoo01eoo`0097oo0P004Goo00<007ooOol0K7oo00MG?ELLEceG75Lm
EaaG?@030000?emMFcaOGE/lGeeK?5mMJgY[Vf]jKi][NW>JKiUc^W>HMkUcV7^gMkMk]gNENkIkTg^d
Ni9k/gNANi5kTW^bMi5kTGN@Nk5gTG^bMk=keGNeMmMg]WOGLkQgfG>hLkY_VW>jJg][VemLHeaO>f=L
GeaO?5/lFaaG75/LEaaK7002Ea`0:U;l001Bo5LLD_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;L
E_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol001moo`008goo00<007oo
Ool04Woo00<007ooOol0JGoo00=C7ELMDad00eLM0`0000UG7EllGeaO?5mLGcaOG5llGe`00V=L00=[
Nf^KJg/00VnJ00EcVVnJMkUc^7Ni00=g]`08NkEk/g^dNk=k/W^BNi5kTPAkT@07Nk5gTG^bMk=k/gNe
MmD00WOG00Ic^7>iLkU_^VnJKkX3Ji/3He`4Gc`01ELLFaaK75/LE_`00ULL0UKl00@005KlE_aFo09B
o003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=oo`00Ool07Goo000J
Ool40005Ool00`00Oomoo`0COol00`00Oomoo`1UOol01U<LEaeBo5LMDaaG7@<0000kEceG75/mEaaK
?E/lGeeK?5mMFcaSO5mLHeaOG6=lGeacVVnILkY_VGNiLiQg^GNgNkMgUW^fMkEk]7^CNk=kTW^aNi=k
/gNANk5gT7^aMi5k/WNANk=g]G_EMkIgeg>hMmUc^7>jKiYc^V]kJi][Nf^KJg]OG002Gc`02U/lGeaO
?5llE_aK75KlFaaFo5/L0UKl02L005LLD_aFo5;lE_aBo5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]`00Woo00<007ooOol06goo000IOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`1ROol01E<MD_eC7E<MEad0
0`0000IG7E<MEceG?E/mEa`2Ecd015/mGcaOG5ll1V=L00MWO6MkLiY_VWNiLkQg^@04MkL02G^eNkAk
/g^dNi9k/W^cNk9kTP03Ni403WNANi5g/W^cMi5k/WNbNk=g/gOEMkEgegNgMmL5Ji/00fMlIg]O?003
Gc`015/lFaaK?5Kl0eLL15Kl00@005KlE_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003D_`0
1E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo003Ool007oo01aoo`006Goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0GGoo00IBo5<MD_aC7E;lDad30000NULMD_aG
7E<LEaeC75/mEaaK?ELLFceG75/mGeaSO5mLHeaOG6=lIe]WO6=KIgaWFgNiLiQg^G>HNkMgUW^gMkEk
]G^CNkAkTW^bMiEk]7^BNk5gTG^aMi5k/GNANk9gTG^bMi5k/gNcNmEg]7_EMkIgeg>hMmU[Nf^KHe]W
O6=KIgaSFfMlFaaK?5/LGcaK75/lE_aG75KlEaaFo5LLD_aFo000EaaBo5KlD]aFo5;LE_aBg5KlD]aF
o5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000L
Ool001Uoo`03001oogoo009oo`03001oogoo009oo`8001Moo`8005]oo`03DaeBoE<M009C7@05D_d0
0000DaeBo@02Dad00eLMDaeG7@02Ead025<MEceG?E/mEaaG?E/lFcd4He`02FMkIgaWNfMlIg][Vf]k
Ji][N`04MkL017^eNk=k]7^c0W^e00=k]7^BNk800W^A00igTG^AMi5kTGNANi5g/W^bMk=k/gNeNmEg
]gOG0W>i00Qc^7>iIg]WO6MkIgaWNfMl0V=L00=K75/lFa`00e/L0eKl00UG75KlE_aBo5Kl001Fo5;l
E_`00e;l00=Fo5;lD_`01U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;l
D]`00U;l00=oo`00Ool06Woo000IOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0HOol0
0`00Oomoo`1EOol01U<MC_aC7DklDae>o0<0001>D_aC7E;lDaeBo5LMDaaG7E<LEaeC75LMEaaK?ELL
FceK?5/mFcaK?E/lIgaWFfMlHe]WO6MKJi][NVnKJgYcVVnILkY_VGNiMiIk]gNgNkEgUG^fNi=k/W^B
Nk9gT7^aMi1k/WN@Nk5gT7^bMk=k/gNdNmEg]WOGMkIgfG>hMmU_VW>jHe]WO6=KHeaOG6=LGc]SG5LL
FaaG75/L0ULL031Fo5LLE_aG75;lEaaBo000D]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L000KOol001Uoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo059oo`=Bo@03DaeBo@0000800005
D_eC7E<MDaeBo@04Dad3Ead05E<MEaeG7ELMFcaK?E/lFceK?5/mFcaOG5llIgaWNfMlIg][Vf]kJi][
N`02KiX017>JKiYc^G>h0gNg0W^e00=k/g^dNi801G^A00UgTG^AMi5k/WNANk=g/g_EMkL00WOG00=c
^G>hLkT00Vnj00=_VVnjHe`01F=L0Ull0U/L00=G75/LFa`01eKl00=Bo000D_`00U;l00=Fo5;lD_`0
2U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo000JOol001Uo
o`03001oogoo009oo`05001oogooOol0000MOol00`00Oomoo`1>Ool01DklDae>o5<MC_`00`0008Q>
o5<MC_aC7DklEaeBo5<MD_aG7E;lDaeBo5LMDaaG7E<LEceG75LmFcaK?E/lFceK?5mMFcaOGE/lIgaW
Ff^KJgY_Vf]jJi]_VG>jKiUg^G>HNkMg]g^gMiEk]WNeNkAkTW^cMi5kTG^BNk9gTG^AMi1k/GNANk=g
/g_EMkEgegNfMmUc^7OIKiYc^VnJLkY[Nf^KGeaSG5lkGeaK?5llFcaK75LLFaaFo5/LE_aG75;lEaaB
o5LLD_aFo5;l001Bg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol000Moo`D000eoo`006Woo100017oo0P007Goo00<0
07ooOol0Bgoo0U;m00=C7E;m00000P000e;m00IC7E;mDaeBoE<MD_d8Dad3Ead055LLEaeG7ELMFcaK
?EllGeaO?5mLGcaOG5llJi][Nf^KJg][VfnJLiX2KiX00g>hMkUg]`02MkL2NkD01W^dNk=k/W^BNi5k
TPAkT@06Nk5gTG^bMk=k/gNe0WOG00=c^G>hLkT00Vnj00=_VVnjJi/00f^K1ell0eLL00EFo5LLEaaF
o5;l00=Fo0=Bo003001Bo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00MBg5;l
D_aBo5;LOol00007Ool01@00Oomoogoo00003Goo000ROol00`00Oomoo`0MOol00`00Oomoo`16Ool0
1DklDae>oE<MC_`00`0005Q>o5<MC_aC7DklDaeBo5<MC_aC7E;lDae>o5LMD_aC7E;lEaeC75LMD_aG
?ELLEceG75LmEaaG?E/lGeeK?5mMFcaOGE/lHeaOFfnKJgY[VfnILkY_VG>JLiQg^GNgNkMgUW^fMkEk
]G^CNk=kTW^aNi=k/gNANk5gT7^aMi5k/WNcNk=gTG^bMk=k/gNdNmE_VW>jKiY[Vf]kJi][Nf^KHe]W
O5/lGcaK?5mLFaaK?09K7004E_aK75KlEa`2E_`0;e;lEaaBo5KlD]aFo000E_aBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g7oo00001goo00<007ooOol03Woo000ROol00`00Oomoo`0NOol00`00Oomoo`13Ool2D_d00e<MC_d0
0002000014kmD_eBoE<M0e;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@9C7@06EaeC7E<MDaeG7E<M0eLM
00QG75LmEceK?EllGeaO?5mL1V=L00I_VW>JKiY_VW>hMkT4MkL2NkD01g^cNkAkTW^bNk=k/W^B00=k
T@0:Mi5kTGNbNk5gTG^bMk=k/gNeMmD2MmL00gNgJi][V`02Ji/036MlIg]WO6MkIgaK75/lFaaK?5/L
FcaK709Fo003EaaFo5Kl009Fo004D_aFo5KlE_`2D_`00`00E_aBo007D_`01E;LD_aBo5;lD]`00e;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`015;LD_aBo5;l0Woo00<007ooOol01Goo00<0
07ooOol03Goo000ROol00`00Oomoo`0OOol00`00Oomoo`0oOol01E<MC_eC7DklDad00P00061>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E<LEaeBo5LMDaaG7E;lFceG75/m
EaaK?ELLFceG76=lGeaSG5mKHgaOG6=LHe]WO6MKIgacV7NiLiQk]gNFNkMg]G^eMiEk]7^BNk9gUG^d
Ni9k/GNANk5gTG^aMi5k/GNANk9gTG^cMk=keGNdMmMg]WOILkQgfG>hIgaSFfMlHe]WO5lkHeaK75/l
FaaO?5LLFa`2Ea`0=5KlEaaFo5LLD_aFo5;LE_aBo5KlD]aFo000E_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`0027oo
00<007ooOol037oo000ROol00`00Oomoo`0POol00`00Oomoo`0lOol015;mDae>oE;m0`000U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MDaeBo@02Dad00eLMDaeC7@02Ead0
2E<MEceG?E/mEaaG?E/lFceK?005He`01fMkIgaWNfMlJg][Vf]k00Ag]`9k]@07NkAk/g^eNkEk]7^B
Nk800W^A00egTG^AMi5kTGNANi5g/W^cMk=geGNeMmMg]`02LkT01W?ILkQ_^VnjIgaWN`ESG09K7004
EaaK75/LFa`6E_`025;lE_aBo5KlD_aFo5;l000:D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo002Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0025o
o`8002=oo`03001oogoo03Qoo`04C_eC7DklDad30000VU<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LEaeG75/mEaaK?E/lFceK?5/m
FcaSO5mLIgaSFfMlIe]WO6]jKi][NW>JKiUc^VnINkEgUG^fMkMk]GNENkIkTg^bNi9k/WN@Nk5gT7^b
Mi1k/GNANk9g/g^cMkAkeGNfMmMc^7OILkQc^VnJLkY_VV=LGc]SG5mLHeaK?5mLEaaK75LLFaaG75/L
D_aG75;lEaaBo5KlD_aFo5;LE_aBo5KlD]`005;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;L0Woo00D007ooOomoo`0000=o
o`03001oogoo00]oo`008Goo00<007ooOol08goo00<007ooOol0<Woo00I>oE;mD_eC7DkmD_d30002
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad00e;mDaeC
7@02Dad3Ead05E<MEaeG7ELMFcaK?E/lFceK?5/mFcaK?E/lIgaWNfMlIg][Vf]kJi][N`02KiX01G>J
KiYc^G>hMkT00WNg0W^e00=k/g^dNi801G^A00egTG^AMi5k/WNANk=g]G_EMkMgeg>iLmUc^003KkX0
0fnJJi][V`02He`4Gc`3Fa`4Ea`5E_`2D_`00eKlD_aBo003D_`00`00D_aBo008D_`01E;LD_aBo5;l
D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`00e;LD_aBo0020004Ool3000>Ool0
025oo`03001oogoo02Aoo`03001oogoo02moo`05Dae>oE<MC_aC7@030000Y5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lDaeBo5LM
DaaG7E<LEceG75LmFcaK?E/lFceK?5/mFcaOGE/lIgaWFf^KJgY_Vf]jJi]_VG>jKiUcVW>HMkUcV7^g
MiEk]WNeNkAkTW^cMi5kTG^BNk9gTG^AMi1k/WNANk=g/g_EMkAgeg>hMmUc^7>jKiYc^VnJJi][Nf^K
Jg]O?5/lGeaK?5llFcaK75KlFaaFo5/LE_aK75;lEaaBo5KlD_aFo5;lE_aBg5KlD_aFo5;L001Bg5Kl
D]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg7oo000DOol0025oo`03001oogoo02Eoo`03001oogoo02]oo`9Bo@03Dae>oE;m00<0
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00IC7E;m
DaeBoE<MD_d8Dad3Ead055LLEaeG7ELMFcaK?E/lGeaO?5mLGcaOG5llJi][Nf^KJg][VfnJLiX2KiX0
0g>hMkUcV002MkL2NkD01W^dNk=k/W^BNi5kTP=kT@0;Mi5k/GNANk9g/g_EMkEk/gNcNmEg]@03KkX5
Ji/00fMlIg]O?002Gc`00e/LFcaK7003Ea`3E_`00eLLD_aFo002E_`3D_`00eKlD_aBo002D_`00`00
D_aBo005D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;L
D_aBo5;lD]`00U;l00=oo`00Ool04Woo000QOol00`00Oomoo`0VOol00`00Oomoo`0XOol014kmDae>
o5<M0`0007EC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkl
Dae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMDaaG7E;lEceG75LmEaaG?ELLEceK?5mMFcaOGE/l
GeeK?6=LGe]_Vf]jJi]_VG>jKiUcVW>HMkUcV7^gMiIk]WNeNkEkTg^cNi9k/G^CNk=gTG^aMi1k/GNA
Nk9g/g^aMi5k/WNcNmEg]7OGMkIgef]kJi][Nf^KHe]WO6=KIgaSFe/lFaaO?5/LFcaK75LLE_aG75Kl
Ea`00UKl03ABo5LLD_aFo5;lE_aBg5KlD]aFo5;LE_`005KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5Kl
D]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlOol001=oo`008Goo
0P00:7oo0P009Goo00=BoE<MC_d00U;m0P000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00IG7E<M
DaeC7ELMDad3Ead02ELLEceG?E/mGcaOG5llGeaO?005He`01fnJLiY_VVnJLkQg^G>H00=g]`9k]@07
Nk=k]7^BNk9k]7^bNi800W^A00]k/GNANk9g/W^aMi5k/WNcNk=g]GOE009ge`09LkQc^G>iIgaWNfMl
Ig]WO6Mk009SG003FcaK75/l009K7004EaaFo5KlEa`4E_`015;lE_aBo5Kl0e;l00=Fo5;lD_`00U;l
00D005;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo008D]aBo5;lD_aBg5;lOol0019oo`008Goo00<007ooOol0:Goo00<007ooOol087oo00AC7Dkl
Dae>o@<0002aC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E<LEaeBo5LMDaaG7E;lFceG75/mEaaK
?ELLFceK?5mMGeaSG5mKHgaOG6=LHe]WO6nILiY_VGNiLiQg^GNFNkMg]G^eMiEk]7^BNk9gUG^dNi9k
/GNANk5gTG^AMi1k/GNANk9gTG^cMkAkeGNfMmMc^7OILkQc^VnJIgaSFfMlGeaSG5lkHeaOG5/LEaaK
75LLFaaFo5LLE_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl001Fo5;LE_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aF
o000019oo`0087oo00<007ooOol0:goo00<007ooOol077oo00AC7DkmD_eBo@<00003D_eC7Dkm009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0>Dae>oE;m
D_eC7E;mDaeBoE<MD_eC7E;mDaeBo@=C7@04D_eC7E<MEad2Dad2Ead01E<MEceG?E/mEa`00ULm00=K
?F=LHe`016=L00QWNfMlIg]WO6MkMkUcV7>i0gNg0W^e00Mk]7^cNkEk]G^dNi9k/P02Ni403GNANi5k
TG^AMi5k/WNbNk=g/gOEMkEgegNg009c^@04KkY_VVnjKkX6He`2Gc`00e/LEaaK7002Fa`6E_`00e;l
E_aBo002D_`00eKlD_aBo005D_`00`00D_aBo002D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00=Bg7oo00004Goo000POol00`00Oomo
o`0/Ool00`00Oomoo`0FOol01U<MC_eC7DklDae>o@<0002iC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeC75/mEaaK?ELLFceK?5/mGe]SO5mLIgaSFfMl
Ie]WO6=KKi][NV^KKiUc^VnINkEgUG^fMkMk]GNENkIkTg^bNi9k/WN@Nk9gT7^aMi1k/GNANk9g/g_E
MkAgegNfMmUc^7OIKiYc^VnJJi][Nf=LGc]SG5/lGcaK?5mLEaaK75LLFaaFo5/LD_aG75;lEaaBo5LL
D_aFo5;LE_aBo5KlD]aFo5;LE_aBg5KlD]`005;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LOol0000@Ool0021oo`03001o
o`0002eoo`03001oogoo01=oo`03D_eC7Dkm009Bo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7Dkm
D_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m1E<M0ULM01aC7ELMEaeG7E<MFceK?5/mFcaK?E/lFceK?6Ml
Ig]WO6MkIgaWNf^KJg][VfnJLiY_VW>iLkQg^@9g]`9k]@03Nk=k/W^B009kT@0<Nk9kTG^AMi5kTGNb
Nk9g/g^cMkEkeGNg0W>i00AcfFnJKkY_^PA[V`MO?09G7005E_aG75LLEaaBo003E_`015;lE_aBo5Kl
2e;l00<005;lD_`00U;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo080011oo`0087oo0P00;goo00<007ooOol03goo00E>oE<MC_aC7Dkm
00<0001lC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aG7E;l
DaeBo5LMDaaG7E<LEaeC75LmEaaK?E/lFceK?5/mFcaOGE/lIgaWFfMlJgY_Vf]jJi]_VG>jKiUg^G>H
MkUcV7^gMiEk]WNeNkAkTW^cMi5kTGNANk9gT7^AMi1k/WNANk=g]7_EMk=k/gNdNmE_VW>jKiY[Vf]k
Ji][NfMlHe]O?5/lGe`2Fc`0@U/LGcaFo5/LE_aG75KlEaaBo5LLD_aFo5;lEaaBg5KlD]aFo5;LE_aB
g5KlD]aFo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lOol000moo`001Goo1@001Goo0P001Goo10001Woo00<0
07ooOol0;goo00<007ooOol037oo00AC7DkmD_eBo@<00003D_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7Dkm
D_eBoE<M00=Bo@0<DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;m1U<M0eLM01AG75LMEaeG7ELLFceK?5/m
GcaOG5llGeaO?5mLJg][Vf]kJi]_VW>J0VnJ00=c^7NiLiP00WNg0W^e01Ak]7^BNk9kTW^ANi9kTGNA
Ni5gTG^bMi5k/gNANk9g/g^cMkEkeGNg0WOG0f^K00iWNfMlIg]WO6MkIgaK75/lFaaK?5/LFcaFo5LL
15Kl00QBo5KlE_aFo5;lE_aBo5Kl2U;l00<005;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;l
D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L009Bo09oo`03001oogoo00aoo`0017oo
0P0000Eoo`00001oo`0000Aoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo031o
o`03001oogoo00Qoo`05Dae>o5<MC_eC7@020000Q4kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEceG75LmEaaG?ELLEceG
75mMFcaOGE/lGeeK?5mMGe]SO6]jJi]_VG>jKiUcVW>HMkUcV7^gMiIk]WNeNkEkTg^cNi9k/G^CNk=g
TG^AMi1k/GNANk9gT7^bMi5k/gNbNmEg]7OGMkIgfG>hMmUSFfMlHe]WO6=KIgaOG6=LFaaO?09K7006
EaaK75KlEaaFo5LL0UKl03UBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_`005;lD]aF
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg7oo00003Woo0004Ool20002Ool00`00Ool0000?Ool00`00Oomoo`03Ool00`00Oomoo`0a
Ool00`00Oomoo`05Ool014kmD_eBoE<M0`0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m015C7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBoELM00=C7@03EaeC7ELM009G
7@0:EaaG7ELmFceG75mLGcaOG5llGe`4He`01fnJLiY_VVnJLkQg^G>H00=g]`9k]@06NkAk/W^BNk9k
]7^b0g^A00Yk/GNANk9kTG^aMi5k/gNcNmEg]@9ge`03LmUc^7>i009_^P03Ig]WO6Mk00ESG006EaaK
75/LFaaG75/L1UKl00ABo5KlD_aFo0aBo005D]aBo000D_aBg003D_`01E;LD_aBo5;lD]`00e;l00EB
g5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l00=oo`00Ool037oo0004
Ool20002Ool00`00Ool0000?Ool00`00Oomoo`02Ool2000dOol02000OomoogooC_aC7DkmDad30000
cU<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMD_aG7ELLFceG75/mEaaK?ELLGeeK?6=LGe]SO5mLHeaS
FfMlIe]WO7>HMkUcV7NiMiIk]gNeNkEgUG^dMkEk]WNENkAkTW^bMi1k/GNANi5gT7^aMi5k/WNbNk=g
]7OGMkIgeg>hMmU_VW>jKiYc^UlkHeaOG6=LGc]OG5/lGcaG75/LEaaK75KlFaaBo5LLD_aG75;lE_aB
g5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;L001Bg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg7oo000<Ool000Ao
o`80009oo`03001oo`0000]oo`@000Eoo`03001oogoo039oo`03D_eC7Dkm009Bo@06Dad00000001C
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7DkmD_eBoE<M
D_eC7E;mDaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@06EaeC7ELMEceK?ELL0ULm00=K?ELLHe`0
16=L00QWNfMlIg]WO6]kJi][Nf^K0gNg0W^e00Mg]g^eNkEk]G^dNi9k/P02Ni402WNANi5kTG^AMi5k
/WNcNk=g]GOE0WOG00Ic^7>iLkU_^VnJKkX3Ji/7Gc`015KlEaaG75LL15Kl00ABo5KlE_aFo0=Bo003
E_aBo5;l00YBo005D]`005;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo005
D]aBo5;lD_aBg003D_`025;LD_aBo5;lD]aBo7oo000<Ool000=oo`<00005Ool00000Ool0000;Ool0
0`00Oomoo`06Ool00`00Oomoo`0`Ool01E<MC_aC7DkmDad00`000=EC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeB
o5<MD_aC7E;lDaeC75LMD_aG7E<LEaeC75/mEaaK?ELLFceK?5/mFcaSO5mLIgaSFfMlIe]WO6]jKi][
NV^KKiUc^VnIMkUcV7^gMkMk]WNENkIkTg^cMi5k/WN@Nk9gT7^aMi5k/WNANk=g/g_EMkIgeg>hMmUc
^7>jKiY[Vf]kJi][NfMlHe]OG5/lGcaK?5llFaaK?5KlFaaFo5/LE_aG75;lE_aBo5LLD_aFo5;LE_aB
g5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]`005;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aB
g5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo7oo00002goo0005Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0]Ool01E<MC_eBoE;mDad00`00
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@0:DaeBoE<MD_eC7E;mDaeBoE<MD_d3Dad01E;mDaeG7ELMDad00eLM01UC
7E/mFcaK?E/lFceK?5/mFcaWO6MkIgaWNfMlJg][Vf]kJi]_VW>JKiYc^G>hMkUg]`03NkD01W^cNk9k
TW^AMi5k/P9kT@0=Mi5kTGNaNk=g/g^bMk5k/gNeMmEg]FnjKiX016^K00mWO6MkIgaWNe/lFaaK?5/L
FcaK75LLE_aG75KlEa`015Kl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo006D]aBo5;lD_aBg0000U;l
00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L
00=Bo004D]aBo000000:Ool000Ioo`@000aoo`D000Aoo`03001oogoo02]oo`04C_aC7DkmDad30000
WE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeC75LMDaaG7ELLEceG
75/mFcaK?E/lFceK?5mMFcaWO6MKIga[NVnKJgY[Vf]jLkY_VGNiLiQg^GNgNkMgUG^fMkEk]7^BNk=g
TG^cMi5k/WN@Nk5gTG^bMk=k/GNANk=g/g_EMkAgegNfMmUc^6^KJg]WO6=KIgaSFf=LGc]O?5/LFcaK
75llFaaG75KlEaaFo5LL009Fo00mD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aF
o5;LD_`005KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lD]aFo5;LD_aBg7oo00002Woo000OOol00`00Oomoo`0XOol01DkmD_eBoE<MC_d00P00
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d025<MD_eC7E;mDaeBoE<MD_d7Dad2Ead055LL
EaeG7ELMEaaK?E/lFceO?5mLGcaOG5llGea[Nf^KJg][Vf]kLiX2KiX017>hMkUcV7Ng0g^e01]k]7^B
Nk9kTG^dNi9kTGNANi5gTG^bMi5kTGNaNk9g/gOEMkEkeGNgMmMc^G?ILkQWO6MkIg`016=L00EK75/l
FaaK?5LL009K7003EaaFo5Kl00AFo004D_aFo5;lE_`>D_`01E;LD_aBo5;l00000e;l00EBg5;lD_aB
o5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aBo5;L00=Bo003D]`0
000000Uoo`007Woo0P009Goo00M>oE<MC_aC7DkmDae>o0030000WTklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_aC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7ELLEceG75LmEaaG?ELLGeeK?5mM
FcaOGE/lGeeOFf=lJgY[Vf]jLkY_VG>JLiQg^G>HNkMgUW^fMkEk]W^CNk=kTW^dNi9k/gNANi5gT7^b
Mi1k/GN@Nk9g/g^cMkAkeGNfMmMc^7OILkQc^VnJLkYOG6=LGc]SG5mLHeaG75/LEaaK75LLFa`2Ea`0
@U;lEaaBo5LLD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;l001F
o5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aB
o5;LE_aBg5;lOol000Uoo`007Woo00<007ooOol08Woo00IC7DkmD_eBoE<MC_d300001DkmD_eBoE<M
C_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@0ADae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eG7@03
Dad00eLMDaeC7@02Ead02ELLEaeG?E/mEaaOG5llGeaO?006He`01W>JKiY_VW>hMkUcV09g]`=k]@06
NkAk/W^BNkEk]7^b0g^A00ik/GNANi5gTG^bMi5k/gNeNmEg]gOGLkUcfG>h0fnj0V^K0f=L0ell00EG
75/LFaaK75Kl009G70EFo0=Bo003E_aBo5;l00YBo005D]aBo5;lD_aBg003D_`01@00D_aBo5;lD]`0
0e;l00EBg5;lD_aBo5;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l00EBg5;lD_aB
o00000Uoo`007Woo00<007ooOol087oo00E>o5<MC_eC7Dkl00<0002VC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E;lEaeC75LMD_aG7ELL
FceG75/mEaaK?ELLFceOG6=LGe]SO5mLHeaOFfMlIe]WO7>HMkUcV7NiMiIk]gNeNkIgUG^dMkEk]W^C
Nk=kTW^bMi1k/GNANi5gT7^aMi5k/gNdNmEg]7OGMkIgfG>hLkY_VW>jJg][Vf]kJi]K?5llFcaOG5/l
GcaFo5/LE_aK75KlFa`2E_`0>e;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aB
g5KlD]aBo5;LE_aBg000D]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aB
g5;lD]aFo5;LD_aBg5KlD]`017oo00<007ooOol01goo000NOol00`00Oomoo`0NOol2D_d00e<MC_d0
000200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7Dkm
DaeBoE<MD_eC7E;mDaeBo@=C7@04D_eC7E<MEad3Dad01ULMDaeG7ELmFceG709G?@03FceK?5/m00ES
G007IgaWNfMlJg][Vf]kJi/00WNg0g^e0WNg0W^e00=k]7^BNi401G^A00Ik/GNANk9g/g_EMkD2MmL0
0g?ILkQ_^P02KkX4Ji/00fMkIgaO?002Gc`015/lFaaK?5Kl0eLL15Kl00ABo5KlE_aFo0=Bo003E_aB
o5;l00IBo005D]aBo5;lD_aBg003D_`01E;LD_aBo000D]`00e;l00EBg5;lD_aBo5;L00=Bo005D]aB
o5;lD_aBg003D_`01E;LD_aBo5;lD]`00e;l1goo00<007ooOol01Woo000NOol00`00Oomoo`0KOol0
15<MC_eC7Dkl0`000>A>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7ELLFceG75/mFcaK?E/l
FceOG6=LHe]WO6MKIga[NVnKJgY[VfnILkYcV7NiLiQk]gNgNkIgUG^dNi9k/gNANk5kTW^bMi1k/GN@
Nk9g/W^bMi5k/gNbNmEg]7OGMkIgef]kJi][NfMlHe]WO6=KIgaK75/lFaaO?5/LFcaFo5LLE_aG75Kl
EaaBo5KlD_aFo5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5;lD]aFo5;L
001Bg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_`:Ool00`00Oomo
o`06Ool001eoo`8001Qoo`06Dae>oE;mD_eC7Dkm0`0000E>oE;mD_eC7Dkm009Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00YC7DkmDaeBoE<MD_eC7E;mDaeB
o@IC7@03EaeC7ELM009G7@0HDaeG7E/lFceK?5/mFcaK?E/lFceWNfMlIg]WO6]kJi][Nf^KKiYcVVnJ
LkUc^7Ni0WNg0W^e00Ek/g^bNi9kTG^B00=kT@0:Mi5k/WNaNk5gTG^bMk=k/gNeMmD2MmL027>hLkUc
^FMlIg]WO6MkIg`2He`00e/LFcaK7003Fa`3E_`02ELLE_aFo5;lE_aBo5KlD_aFo00<D_`01E;LD_aB
o5;lD]`00e;l00EBg5;lD_`005;L00=Bo005D]aBo5;lD_aBg003D_`01E;LD_aBo5;lD]`00U;l3Woo
00<007ooOol01Woo000NOol00`00Oomoo`0DOol01TklDae>oE<MC_aC7@80003QC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5LMD_aC7E;lEaeBo5LMDaaG7E<LEceG75LmFcaK?E/lFceK?5/mFcaOGFMKIga[NVnK
JgY[VfnILkY_VGNiLiQg^GNgNkMgUG^fNi=k/g^BNk9kTg^cMi5k/GN@Nk5gTG^aMi5k/WNbNk=g]7_E
MkIgeg>hMmUc^7>jKiYWO6=KHeaOG6=LGc]SG5LLFaaG75/LEaaK75;lEaaBo5LLD_aG75;lE_aBg5Kl
D_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl001Bo5;LE_aBg5;l
D]aFo5;LD_aBg5KlD]aBo5;L01=oo`03001oogoo00Ioo`007Goo00<007ooOol04goo0U;m00=C7Dkm
D_d00`000U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@0<DaeBoE;mD_eC7E;mDaeBoE<MD_eC7E;m25<M00=G7ELLEad00ULM011G
75LMFcaK?E/lGeaO?5mLGcaOG6]kJi][Nf^KKiYcVP9_VP03LkQg^GNg009g]`9k]@08NkAkTW^bNk=k
/W^BNi5gT@=kT@06Mi5k/WNaNk=g/gOE0WOG00Ec^7>iLkU_^VnJ009_^PASG0=O?09K70AG70EFo09B
o003E_aBo5;l00iBo005D]aBo5;lD_aBg003D_`01E;LD_`005;lD]`00e;l00IBg5;lD_aBo5;LD_`E
Ool00`00Oomoo`06Ool001eoo`03001oogoo015oo`04C_eC7DklDad30000hU<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M
C_aC7DklDaeBo5<MC_aC7E;lDaeBo5LMD_aC7E;lEaeC75LmEaaG?ELLEceG75LmFcaOGE/lGeeK?5mM
Ge]SO5mLHea_VG>jKiUcVW>HMkUg]g^gMiIk]WNeNkAkTW^cMkEk]7^BNk9gT7^AMi5k/GN@Nk9gTG^c
Mk=keGNfMmMc^7OILkQc^VnJLkY_VV^KJg][Ve/lGeaK?5llFcaOG5KlFaaFo5/LE_aG75;lEaaBo5Kl
D_aFo5;lE_aBg5KlD_aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aBg5Kl
001Bo5;LE_aBg5;lD]aFo5;L5goo00<007ooOol01Woo000MOol2000?Ool015;mDae>oE;m0`000U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_d4Dad01ULMDaeC
7E<MEaeG709G7@06FceG75LmGcaOG5ll1F=L00=WNfMlKiX00VnJ00=g^G>HMkL00WNg0W^e00=k]7^e
NkD00W^d00ik/W^ANi5gTG^AMi5kTGNaNk9g/gOEMkEgeg>h0W>i00=_^VnJKkX016^K00=WNfMlGc`0
0Ull00=K?5/LFc`00ULL00EFo5LLEaaFo5;l00=Fo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aBg003
D_`01E;LD_aBo5;lD]`00e;l00EBg000D_aBo5;L01aoo`03001oogoo00Ioo`007Goo00<007ooOol0
2Goo00I>o5<MC_eC7DklDad30000_E<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7DklDaeBo5<MD_aG7E<LEaeBo5LMDaaK?ELLFceG75/mEaaK?EmLHeaOFf=lGeaSG6=KIgaWFfMl
He]g^G>HNkMgUW^gMkEk]WNFNkMg]G^fNi=k/gNANk9gT7^bMi1k/GN@Nk9g/g^cMkAk/gNcNmEg]7>j
KiY[Vf]kJi][NfMlHe]WO6=KIgaK75llFaaK?5/LGcaFo5LLE_aG7002E_`08U;lEaaBo5KlD]aFo5;L
E_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LE_aBg5KlD]aBo5;LE_aBg5;lD]aFo5;LD_aoo`007goo00<0
07ooOol01Goo000MOol00`00Oomoo`07Ool2D_d00e<MC_eBo@030002D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m0e<M00=BoE<MDad015<M00IG7E<M
EaeG7E/mEa`2Ecd00e/mFcaK?@03He`026MlIg]WO6MkIgaWNf^KJg/2KiX00g>JLiQc^@02MkL2NkD2
Nk@017^BNi5kTG^b0W^A00]gTG^bMi5k/gNaNk9g/gOEMkEgegNg009c^@07LmUWNfMlIg]WO6MkIg`0
0V=L00QK75/lFaaK75LLFaaFo5LL15Kl00ABo5KlD_aFo0=Bo003E_aBo5;l00IBo005D]aBo5;lD_aB
g003D_`01E;LD_aBo5;lD]`017oo00<007ooOol077oo00<007ooOol01Goo000MOol00`00Oomoo`05
Ool014kmDae>o5<M0`000;mC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeG75/mEaaK?E/lFceK?5/mFcaWO6=KIgaW
FfMlHe]_Vf]jLiY_VG>jKiUg^G>HNkMg]g^fMiEk]7^BNk=gTG^cMi5kTGN@Nk5gTG^aMi1k/WNcNk=g
]7_EMkIgeg>hMmU_VW>jHe]WO6=KHeaO>f=LGeaSG5LLFaaG75/L009G700OE_aG75;lEaaBo5KlD]aF
o5;lE_aBg5KlD]aFo5;LE_aBg5KlD]aFo5;LD_aBg5KlD]aBo5;LE_aBg5;lD]`027oo00<007ooOol0
6goo00<007ooOol01Goo000MOol01000Oomoodkm0U;m00AC7DkmD_eBo@80009Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC7E;m
0e<M00=BoE<MDad00U<M0eLM01MC7ELMFcaK?E/lFceK?5/mFcaOG5llIgaWNfMlJg][Vf]kJi]_VW>J
KiYc^G>h009g]`9k]@06NkAk/g^bNi5k]7^B0W^A00ek/GNANi5gTG^bMi5k/gNeNmEg]gOGLkUcf@04
KkX5He`3Gc`01ELLFaaK75/LEa`01eKl0e;l00=Fo5;lD_`02U;l00ABg5;lD_aBo0aoo`03001oogoo
01]oo`03001oogoo00Eoo`0077oo00P007ooDae>oE<MC_aC7Dkm0`000=e>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aG7E;lDaeBo5LM
D_aG7E<LEaeC75LmEaaG?E/lFceK?5/mFcaOGE/lGeeK?5mMJgY_Vf]jJi]_VG>jKiUg^G>HMkUg]g^g
MiEk]W^CNkAkTW^dNi9k/gNANk5gT7^AMi1k/GNANk=g/W_EMkIgeg>hMmUc^7>jKiYc^V]kJi][NemL
FcaO?5/lGeaK?5llE_aK75KlFaaFo5LLD_aG75;lEaaBo5KlD]aFo5;lE_aBg5KlD]aFo5;LE_aBg5Kl
D]aFo5;L015oo`03001oogoo01Yoo`03001oogoo00Eoo`0077oo00<005<MC_d00U;m0`0000=BoE<M
C_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01E<MC_eBoE;mDad0
0e;m00YC7E;mD_eBoE<MD_eC7E;mDaeBo@IC7@03EaeG75LM009G7@0:EaaG7ELMGeaO?5mLGcaOG5ll
Ge`2He`026]kJi]_VW>JKiYc^G>hMkT2MkL2NkD01W^cNkAkTW^eNk=k/P9kT@09Mi5kTG^ANk5gTG^b
Mk=keGNe009ge`04LmUc^6njKkX4Ji/00fMlIg]O?003Gc`015/lFaaK?5Kl0eLL15Kl00ABo5KlD_aF
o0=Bo003E_aBo5;l00=Bo1Moo`03001oogoo01Uoo`03001oogoo00Eoo`004Woo1@001Goo00<004km
00000P000=a>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeC75LMD_aG7E<LEceG75LmEaaG?ELLFceG75mM
FcaOGE/lHeaOFf=lGeaSG6nILkY_VG>JLiQg^GNgNkMgUW^fMkEk]7^CNkIkTg^dNi9k/WN@Nk9gT7^a
Mi1k/WNbNk=g]7OGMkIgfG>hLkY_VV^KJg][Vf]kIgaSFfMlHe]O?5/LFcaK75llFaaG75KlEaaFo5LL
E_aG75;lE_aBo5LLD]aFo5;LE_aBg5KlD]aFo1Yoo`03001oogoo01Qoo`03001oogoo00Eoo`0057oo
00<007ooOol01Goo0P0000=BoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0BDae>oE;mD_eC7E;mDaeBoE<MD_eC7E;mDaeBoE<MD_eC
7E;m0U<M00IG7E<MDaeC7ELMEa`2Ecd01E/mEaaG?ELmFcd01V=L00MWNfMlIg]WO7>hMkUcV002MkL2
NkD2MkL2NkD01G^dNi9kTG^ANk800W^A00UgTG^AMk5k/gNANk9g/g_EMkD00WOG00QcfG>hJi][VfMl
Ig]WO6Mk0V=L00AK?5/LFcaG709K7005EaaFo5KlE_aG7002E_`01U;lE_aBo5KlD_aFo0=Bo1aoo`03
001oogoo01Uoo`03001oogoo00Aoo`0057oo00<007ooOol01Woo0=X007ooC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC
7DklDaeBo5<MD_aC7E;lEaeC75LMD_aG7E<LEaeG75/mEaaK?ELLFceK?5/mGe]SO5mLIgaSFfMlIe]W
O6]jKi][NW^gMiIk]g>HMkUgUW^gMkEk]7^CNk=gTG^AMi5k/WN@Nk5gTG^cMi1k/WNbNk=g]7_EMkIg
eg>hMmUc^6MlHe]WO5lkHeaOG6=LGc]K75LLFaaG75/LE_aG75KlEaaBo5LLD_aFo5;lE_aBg5Kl8Goo
00<007ooOol067oo00<007ooOol017oo000DOol00`00Oomoo`07Ool200000e;mDae>o@02D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC7Dkm
D_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0e<M00EBoELMEaeG7E<M00=G7@0AEaaG?ELmFceK?5/mFcaK
?FMkIgaWNfMlIg]WO6]kJi][N`02KiX00g>JLiQc^@02MkL2NkD047^dNk9kTW^ANi9kTGNANi5gTG^b
Mi5k/WNaNk=g]GOE0WOG00=c^7>iLkT00fnj1F=L0Ull0e/L00=G75/LE_`01UKl9Woo00<007ooOol0
5goo00<007ooOol017oo000DOol00`00Oomoo`09Ool0[@00OomC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<M
D_aC7E;lEaeC75LMDaaG7E<LEaeK?5/mFcaK?E/lFceK?5mMHe]WO6MKJi][NVnKJgYcVVnILkYcV7Ni
LiQk]gNgNkIkTg^dNi9k/W^CNk<00W^A029gT7^bMi1k/GNANk=g/g_EMkIgeg>hMmUc^7>jKiYc^V]k
Ji]OG6=LFcaOG5/lGcaK?5/LE_aK75KlFaaBo5LLD_aG72Qoo`03001oogoo01Moo`03001oogoo00Ao
o`0057oo00<007ooOol02Woo00@007ooDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m25<M0eLM01MC
7ELMEaeG7E/lFceK?5mLGcaOG5llGeaO?6^KJg][Vf]kJi]_VW>JKiYc^G>h009g]`9k]@05NkAk/g^b
NkAk/P03Ni402W^aMi5kTGNaNk9g/gOEMkEgegNg0W>i0fnj16^K15ll00=K75/lFa`00eLL00=Fo5LL
Ool0:goo00<007ooOol05Woo00<007ooOol017oo000BOol3000=Ool0[@00OomC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC
7E;lDaeBo5LMD_aC7E;lEceG75LmEaaG?ELLEceK?5mMFcaOGE/lGeeK?6=LGe]_Vf]jJi]_VG>jKiUg
^G>HMkUg]g^gMiEk]7^CNk=gUG^dNi9k/WN@Nk400W^A01UgT7^bMk=k/gNdMmMg]WOILkQc^VnJLkY[
Nf^KJg][Vf=KIgaSFe/lFaaO?5/LFcaK700aOol00`00Oomoo`0EOol00`00Oomoo`04Ool001Aoo`03
001oogoo00aoo`800006Oom>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01E<MC_eBoE;mDad00e;m00IC7E;mDaeBoE<MD_d6Dad00eLMDaeG7@02Ead025LL
EceG?E/mGcaOG5llGe`6He`01VnJLiY_VW>iLkQg^@9g]`9k]@06Nk=k]7^eNkAkTW^b17^A00agTG^a
Mi5k/gNaNk9g/gOEMkEgegNgMmL3Ji/016MlIg]WO6Mk0V=L00=K?5/LFc`0=7oo00<007ooOol057oo
00<007ooOol017oo000UOol0`@00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7DklDaeC75LMD_aG7E<LEaeBo5LMEaaK?ELLFceG
75/mEaaSO5mLHeaOFf=lGeaSG6=KIgaWFgNiLiQg^G>HNkMgUW^fMkMk]gNENkIkTg^cMi5k/G^BNk9g
T7^aMi5k/gN@Nk9g/g^cMkAkeGNfMmMc^7OILkQWO6=KIgaOG6=LGc]SG5mL03Ioo`03001oogoo01Eo
o`03001oogoo00=oo`009Woo00<007ooOol00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m0e<M00ABoE<MDaeG7@=C7@06
EaeC7ELMEceK?ELL0ULm00=K?E/lHe`016=L00MWNfMlIg][Vf]kJi][N`02MkL02WNiMkMg]gNgNkEk
/g^dNi9kTG^B0g^A00egTG^bMi5k/WNANk=g]G_EMkMgeg>iLmUc^003KkX4He`iOol00`00Oomoo`0D
Ool00`00Oomoo`03Ool002Moo`2k001oogooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aC7E;lEaeC75LMDaaG7E<LFceG75/mFcaK
?E/lFceK?6=lGeaWO6=KIgaWFf^KJgY_Vf]jLiY_VGNiLiQk]gNFNkIg]G^dNi9k/g^CNk=gTG^aMi1k
/WN@Nk5gTG^cMk9keGNfMmMg]WOILkQc^VnJLkY[Nf^KJg/0?7oo00<007ooOol04goo00<007ooOol0
0goo000XOol200001GooD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d02U<MC_eC7E;mDaeBoE<MD_eC7E;m1U<M00=G7E<MEad00ULM015C7E/mFcaK?E/lFceK
?5/mFcaWO6MkIga[Nf^KJg][Vf]k009_VP03MkUcV7Ng009g]`09NkEk]7^dNk9kTG^bNi9kTGNA009k
T@06Nk5gTG^bMk=keGNe0WOG00AcfG>hKkY_^PA[Vcioo`03001oogoo019oo`03001oogoo00=oo`00
:Woo0;D007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lEaeBo5<MD_aG7E<LEaeC75LMEaaG?ELLFceK?5/mFcaK?E/lGeeK?5mMJgY[Vf]jKi][
NW>JKiUc^W>HMkUgUW^gMkEk]W^CNk=kTW^dNi9k/WN@Nk5gTG^aMi1k/WNbNk=g]7OGMkIgfG>hLkY_
VV^KJg][V`10Ool00`00Oomoo`0BOol00`00Oomoo`03Ool002]oo`06001ooe;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@08DaeBoE<MD_eC7E;mDaeBo@MC7@9G
7@0<EaaG7ELMEaeG75LMGcaOG5llGeaO?5mL0V=L00=[Nf^KJg/00VnJ00=cVW>HLkT00WNg0W^e0W^d
00Ak]G^dNkAk/PAkT@09Mi5kTGNaNk=gTGNbMk=keGNe009ge`03LmUc^7>i049oo`03001oogoo015o
o`03001oogoo00=oo`00;7oo0;4007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5LMD_aG7ELLEceG75LmEaaK?ELLFceK?5mMFcaSO5mL
HeaOFf=lGeacVVnILkYcV7NiLiQk]gNgNkIgUG^dMkEk]W^CNk=kTG^bNi9k/WN@Nk5gTG^cMi1k/WNb
Nk=g]7_EMkIgeg>hMmT0A7oo00<007ooOol047oo00<007ooOol00goo000]Ool20002D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0<DaeBoE<MD_eC7E;mDaeBoE<MD_eC7E;m
15<M00IG7E<MDaeC7E/mEa`2Ecd00e/mEaaG?@07He`01VMlIg]WO7>HLkUc^09g]`9k]@9g]`04NkEk
]7^dNi85Ni4027NANk9gTGNbMk5k/gNeMmD2MmL00g>hLkUoo`15Ool00`00Oomoo`0@Ool00`00Oomo
o`02Ool002moo`2N001C7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<M
D_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaK?ELLFceG75/mFcaK?EmLHeaOFf=lIe]WO6=KIga[NV^K
JgYc^VnIMkUcV7^gMkMk]WNENkAkTW^cMi5k/`9kT@0=Mi1k/WN@Nk5gTG^cMk=keGNfMmMc^7OILkP0
AWoo00<007ooOol047oo00<007ooOol00Woo000`Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00YC7DkmD_eBoE<MD_eC7E;mDaeBo@=C7@03D_eC7E<M009C7@=G7@0HDaeG7ELM
FceG75/mFcaK?E/lFceK?6MlIg]WO6MkIga[Nf^KJg]cVVnJLkUc^7Ni0WNg00Mk]G^dNk=k/W^ANkAk
TP02Ni402W^aMi5kTGNaNk9g/gOEMkEgegNg0W>iB7oo00<007ooOol03goo00<007ooOol00Woo000a
Ool0WP00Oomooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LM
D_aC7E<LEaeC75LMDaaG7E<LFceK?5/mFcaK?E/lGeeK?6MlHe]WO6]jJi][NW>jKiUcVW>HMkUg]g^g
MiEk]W^CNkAkTW^dNi9k/WN@Nk42Ni402GN@Nk9g/g^cMkAgegNfMmUc^01:Ool00`00Oomoo`0>Ool0
0`00Oomoo`02Ool0039oo`05001oogooDae>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<M
D_eBoE;mDaeBoE<MD_eC7E;m25<M0eLM011G75LMEaeK?E/lFceO?5mLGcaOG5llGea[Nf^KJg]cVP9_
VP03LkQg^G>H009g]`07NkEk/g^dNi9k]G^cNk8017^A00UgTG^AMi5k/gNaNk9g/gOEMkD0Bgoo00<0
07ooOol03Woo00<007ooOol00Woo000cOol20000Y7ooDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>
o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeBo5<MEaaG?ELLEceG75LmEaaOGE/lGeeK?5mMFcaOGEmLHeaO
Fg>jKiUcVW>HMkUcV7^gMiIk]WNeNkAkTg^fNi=k/gNANk9kTW^bMi1k/GNANk=gT7^bMk=k/gNdNmE<
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool003Eoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d02U<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00IG7E<MDaeC7ELMEa`3Ead01eLLEceG?EmL
GcaOG5ll00ASG007IgaWNfMlLkQg^G>HLkT00WNg00=k]GNgMkL00W^e00Ak]7^BNi5gT@=kT@08Mi5g
/WNANk9gTGNcMkEkeDioo`03001oogoo00aoo`03001oogoo009oo`00=Woo0:4007ooDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMD_aK?ELLFceG75/mEaaK
?EmKHgaOG6=LGe]WO6MKIga[NVnKJgY[VgNFNkMcV7^gMiIk]gNeNkAkTg^cNi5k/gNANk5gT7^bMi1k
/GNANk=g/W_E051oo`03001oogoo00]oo`03001oogoo009oo`00=goo00@007ooDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d03U<MC_eBoE;mDae>oE<MD_eC7E;mDaeBoE<MD_d3Dad015;mDaeC7ELM0U<M0ULM00QC7ELmEceK
?ELLFceK?5/m0V=L00aWNfMlIg]WO6]kJi][Nf^KKiYcVW>HLkT2MkL2NkD01g^dNk9kTG^dNi9kTGNA
00=kT@05Mi5g/WNcNmEg]@1@Ool00`00Oomoo`0<Ool00`00Oomoo`01Ool003Qoo`80002LDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MDaaG7E<LEaeC75LMDaaK?E/lFceK?5/m
FcaK?F=KIgaWFfMlHe]_Vf]jJi]_VG>jKiUg^GNFNkMg]g^fNi=k]7^BNkAkTW^bMi1k/GNANk5gT7^b
Mk9k/gNdDWoo00<007ooOol02goo00<007ooOol00Goo000jOol00`00Oom>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC
7DkmD_eBoE<M00=Bo@04DaeBoE<MD_d7Dad2Ead05e<MEaeG7ELMEaaK?E/lFceK?5/mGcaOG6MkIgaW
Nf^KJg][VfnJLiY_VW>iLkP00WNg0W^e00Ek]7^BNkEk]7^b00AkT@06Mi5kTGNaNk=gTGNbDgoo00<0
07ooOol02Woo00<007ooOol00Goo000kOol0VP00Oomooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<M
D_aG7E;lDaeBo5LMEaaG?ELLEceG75LmEaaK?E/lGeeK?5mMFcaOGE/lKi][NV^KKiUc^VnIMkUcV7^g
MkMk]WNENkAkTg^fNi=k/g^ANk9kTW^bMi1k/GNANk=gT7^bEGoo00<007ooOol02Goo00<007ooOol0
0Goo000lOol00`00Oomoo`02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7E;mD_eBoE<M00=Bo@04DaeBoE<MD_d4Dad00eLM
DaeC7@02Ead02eLLEaeG7ELMEaaOG5llGeaO?5mLGc`00f=L00I_VW>JKiY_VW>hMkT2MkL2NkD01GNg
NkEk]G^dNi801G^A00EgTG^bMi5g/WNa05Eoo`03001oogoo00Uoo`03001oogoo005oo`00?Goo0P00
08iooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E<LEaeBo5LMEaaG?ELLEceG75/mEaaOGE/l
GeeOFf=lGeaSG6=KIgaWFfMlLiQg^GNgNkMcV7NiMkMk]gNENkAkTg^cMi5k/`9kT@05Mi1k/WN@Nk5g
T@1GOol00`00Oomoo`08Ool00`00Oomoo`01Ool003moo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC
7E;m0e<M00=BoE<MDad015<M00IG7E<MDaeG?E/mEa`2Ecd00e/mEaaSG004He`01VMkIgaWNfMlJg][
V`9_VP04LkQg^G>HMkL2NkD01G^cNk9kTG^dNi800g^A00AgTG^AMk5k/UQoo`03001oogoo00Moo`03
001oogoo005oo`00@7oo08l007ooDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aC7E;lDaeC75LMDaaG7E<LEaeG
75/mEaaK?E/lFceK?6=lGeaSG6=KIgaWFfMlJgY_VfnILiY_VGNiLiQk]gNFNkIg]G^dNi9k]7^BNk9g
T7^a009kT@03Mi1k/Woo05Uoo`03001oogoo00Moo`40005oo`5oo`00@Goo00H007ooOomBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE;m
D_eC7E;mDaeBoE<MD_d3Dad00e;mDaeC7@02Dad3Ead045<MEaeG7E/mFcaK?E/lFceK?5/mIg]WO6Mk
Ji][Nf^K0fnJ00Ag^G>HLkUg]`9k]@05NkAkTW^eNk=k/P04Ni400gNANi5gT@1JOol00`00Oomoo`07
Ool10001Ool1Ool0049oo`80002>Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MD_aG7E;lDaeC75LMDaaG7ELLEceG
75/mFcaK?E/lGeeK?5mMFca[Vf]jKi]_VG>JKiUg^G>HMkUgUW^fMkEk]W^CNkIkTg^cMi5k/W^BNk9g
T7^aMi5LOol00`00Oomoo`06Ool10001Ool1Ool004Aoo`05001ooe;mDae>o@02D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:DaeBoE;mD_eC7E;mDaeBoE<M
D_d7Dad01ELLEaeG7ELMEa`00ULM00IOG5llGeaO?5mLGc`3He`4KiX017>HLkUg]gNg0W^e00Mk]7Ng
NkEk]7^BNi5gT@03Ni400gNANi5oo`1LOol00`00Oomoo`05Ool10001Ool1Ool004Eoo`2<001oodkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7Dkl
DaeBo5<MC_aC7E<LEaeBo5LMDaaG7ELLEceG75LmEaaK?ELLGeeK?5mMGeaSG5mKHgaWFfMlHe]WO7>H
MkUcV7^gMkEk]WNENkMg]G^dNi=k/g^ANk=gTG^aMi1k/Uioo`03001oogoo00Eoo`40005oo`5oo`00
AWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00YC7E;mDaeBoE<MD_eC7E;mDaeBo@9C7@06EaeC7E<MDaeG7ELL0ULm00AK?ELLEceG
?@ESG00;Ig]WO6MkIga[Nf^KJg]_VW>HLkUc^002MkL027^eNkAk/W^ANkAkTW^AMi42Ni5OOol00`00
Oomoo`04Ool10001Ool1Ool004Moo`800028OomC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMEaaK?ELLFceK
?5/mFcaSG5mKHgaWFfMlHe]WO6]jJi][NW>jKiUg^G>HMkUg]g^fMiEk]7^BNkAkTW^bMi1k/GNANk5P
Ool00`00Oomoo`03Ool10001Ool1Ool004Uoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m0e<M00EBoE<MEaeG7E<M
00=G7@0?DaeK?E/lFceK?5/mFcaK?FMkIgaWNf^KJg][Vf]k009_VP03LkUc^7Ni009g]`06NkEk]7^B
NkEk]7^b17^AHWoo00<007ooOol00goo0@000Goo001:Ool0QP00OomC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aG7E;lDaeBo5LMDaaG7E<LEaeG
75LmEaaK?E/lFceK?5mMFcaOGE/lKi][NV^KJgY_VfnIMkUcV7NiMkMk]gNENkIkTg^fNi=k/g^ANk9k
TW^bMi1ROol00`00Oomoo`03Ool10001Ool004]oo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01E<MD_eBoE;mDad00e;m00AC7E;mDaeBo@MC7@9G7@0;EaaG7ELMEaeG
75mLGcaOG5llGeaO?002He`00f^KJg][V`02KiX00g>hMkUg]`02MkL01W^eNk=g]g^eNkAkTP=kT@03
Mi5oogoo069oo`03001oogoo009oo`40005oo`00C7oo0P0007mC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5<MD_aG7E;lEaeBo5LMEaaG?ELLEceG75/m
EaaOGE/lGeeOFf=lGeaSG5mKHga_VG>JLiQg^G>HNkMgUW^fMkEk]gNENkAkTg^cMi5k/`02Ni5UOol0
1@00Oomoogoo00000Goo001>Ool00`00Oom>o@02D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC
7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<M
C_d2D_d035<MD_eC7E;mDaeBoE<MD_eC7E;mDaeBo@AC7@06EaeC7E<MDaeK?ELL0ULm00=K?ELLEcd0
1V=L00EWNfMlJg][Vf]k009_VP0:MkUcV7NgMkMk]G^cNk9kTG^dNi82Ni5VOol01000Oomoo`000Goo
001?Ool0O`00Oom>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeB
o5<MD_aC7E;lEaeC75LMDaaG7E<LFceG75/mEaaK?E/lFceOG6=LGe]WO6MKIga[NVnKJgYcVVnIMkUc
V7NiMiIk]W^CNkAkTW^dNi9k/WN@06Moo`04001oogoo0001Ool0051oo`03001oodkm009Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE<MD_eC7E;m0e<M00=BoE<MDad00U<M0eLM
015C7ELMEaeK?E/lFceK?5/mFcaK?FMkIgaWNfMlJg][Vf]k00=_VP0:LiQc^GNgMkMk]G^dNi9k]G^c
Nk82Ni5XOol00`00Ool00001Ool0055oo`80001kC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MC_aC7DklDae>o5<MD_aG7E;lDaeC75LMDaaG7ELLEceG75/mFcaK?E/lGeeK?5mMFcaOGF]j
Ki][NV^KKiUc^W>HMkUgUW^gMkEk]7^CNkIkTg^cMi5k/G^B06Uoo`40005oo`400000Dgoo00H004km
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00aC7E;mD_eBoE<MD_eC7E;mDaeBoE<MD_d6Dad3Ead0
2ULLEaeG7ELMGcaOG5llGeaO?5mL0V=L00I[Nf^KKiY_VW>HLkT3MkL027^eMkMg]g^eNkAkTW^ANi9[
Ool2000005Aoo`1i001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDaeBo5<MC_aC7E;l
DaeBo5LMDaaG7E;lEceG75LmEaaK?ELLFceK?5mMFcaSG5mKHgaOG6=LKiUc^W>HMkUcV7^gMkMg^GNF
NkMg]G^dNi=k/g^CNk<0Jgoo0P00001EOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
2U<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00IG7E<MDaeC7ELMDad2Ecd01E/mEaaG?ELmFcd01V=L00EW
NfMlJg][Vf]k009_VP09LkUc^7NgMkMk]G^dNk9kTG^b06aoo`800000EWoo07H007ooOom>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MDaaG7E;lEaeC75LMDaaK?ELLFceG75/mFcaK
?EmKHgaOG6MlHe]WO6]jJi][NW>jKiUg^G>HNkMg]g^fNi=k]7^BNkAkTVQoo`@0009oo`00Egoo0P00
00Aooe;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MD_eC7E;mDaeBo@=C7@05D_eC7E<MEaeC7@03
Ead03e<MEaeK?5/mFcaK?E/lFceWNfMlIg]WO6]kJi][N`03KiX02W>hMkUg]gNgNkEk]7^BNkEkTW^b
I7oo10001Woo001IOol0LP00Oom>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aG7E;lDaeBo5LM
D_aG7E<LEaeC75LmEaaG?E/lFceK?5mMFcaOGE/lGee[NV^KJgYc^VnILiYcV7NiMkMk]gNENkAkTg^f
Ni=k/f5oo`@000Yoo`00FWoo00D007ooD_eC7Dkm009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eB
oE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d0
1U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00EC7DkmD_eBoE<M00=Bo@06DaeBoE<MD_eC
7E;m1U<M00=G7ELLEad00ULM00QG75LMGcaOG5llGeaO?5mL0f=L0fnJ00=c^7NiLiP00WNg00Ik]GNg
MkMk]G^dNi9MOol4000>Ool005]oo`1_001oodkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDae>o5LM
D_aC7E;lEaeC75LmEaaG?ELLFceG75/mFcaOGE/lHgaOG6=LGe]WO6MKIgacV7NiLiQk]gNFMkUg]g^g
MiEk]7^B05Yoo`@0019oo`00G7oo0P0000=ooe<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d03U<MC_eBoE;mDaeBoE<MD_eC7E;mDaeB
oE<MD_d2Dad01ULMDaeC7E<MEaeG709G?@03FceG75Lm00ESG006IgaWNfMlJg][Vf]k0VnJ00Mg^G>H
MkMg]g^eNk=k/P1GOol3000FOol005ioo`1/001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG
7E<LEaeBo5LMDaaG7ELLFceG75/mFcaK?EmLHeaOFfMlIe]WO6]jKi][NW>JKiUcVW>HNkMgUW^fNi=k
/gNEDgoo10006Goo001OOol01000OomC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MC_eBoE;mDaeBoE<MD_eC7E;m0e<M00EBoELM
EaeG7E<M00=G7@0=FcaK?E/lFceK?5/mFcaWO6MkIga[Nf^KJg/00fnJ00McV7>iMkMg]g^eNkAk]@1@
Ool4000MOol0061oo`1Y001ooe<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC
7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lEaeBo5<MD_aG7E<LEaeC75LmEaaG
?E/lFceK?5/mFcaOGE/lGee[NVnKJgYcVVnILiYcV7NiMiIk]gNeNkAgUW^f04aoo`@0025oo`00HGoo
0P0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7Dkm
D_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2
D_d01E<MD_eBoE;mDad00e;m00AC7E;mDaeBo@MC7@9G7@0:EaaG7ELMEaeO?5mLGcaOG5llGe`3He`4
KiX01g>iLkQg]gNgNkEg]g^e04Uoo`@002Eoo`00Hgoo06D005<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7E;lDae>o5<MD_aC7E;lEaeC
75LMD_aG7ELLEceG75/mEaaK?E/lGeeK?6=LGe]SO5mLIgaSFfMlIe]g^G>HNkMg]gNiMiIk]gNe04Io
o`<002Uoo`00I7oo00<005<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00iC7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m1U<M00IG7E<MDaeG?E/mEa`2Ecd00e/m
EaaSG002He`3Ig/016MlIg][Nf]k0VnJ00Ac^G>HMkMk]D=oo`@002aoo`00IGoo068007ooC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7E;l
DaeBo5<MD_aC7E;lEaeC75LMDaaG7ELLFceG75/mFcaK?E/lFceWFfMlHe]WO6MKJi][NW>JKiUg^G>H
NkMg]g^f?goo1000<7oo001VOol200001DkmD_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmDaeBoE<MD_d3Dad00e;mDaeC7@02Dad3Ead015<MEaeK
?5/m0e/l00EK?EllGeaWNfMl00=[N`04Ji]_VVnJLiP2MkL00g^eOomoo`0jOol4000dOol006Qoo`1N
001ooe<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7Dkl
Dae>o5<MD_aC7E;lEaeBo5<MDaaG7E<LEceG75LmFcaK?E/lGeeK?5mMFcaOGF]jJi][NVnKKiUcVW>H
MkUg]g^gMiDhOol4000hOol006Uoo`06001ooe;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>
o@9Bo@05Dae>oE;mD_eC7@03D_d01U<MD_eC7E;mDaeBo@MC7@05EaaG7ELMEaeG7002Ead015mLGcaO
G5ll1F=L0VnJ00EcV7NiMkMg]g>H03Eoo`@003aoo`00JWoo05/007ooDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<M
C_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MD_aC7DklDaeBo5LMD_aG7E<LEaeG75Lm
EaaG?ELLFceG75/mGe]SO5mLHeaOFf=lIe]WO6]jKi]_VG>JLiQg^@0bOol30010Ool006]oo`80009B
o@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06DaeBoE<MD_eC7E;m0e<M
00ABoE<MDaeG7@=C7@06EaeG75LmEceK?ELL0U/l00EK?F=LHeaSG6Ml009WN`03Jg][VfnJ009_VP03
MkUoogoo02eoo`@004=oo`00KGoo05L007ooC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>
o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E<LEaeC75LMDaaG7E/lFceK?5/mFcaK?F=KIgaW
FfMlJgY_Vf]jLiY_VGNiLiP0:goo1000Agoo001^Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<M
C_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<M
C_eBoE;mDae>o@9Bo@0:Dae>oE;mD_eC7E;mDaeBoE<MD_d6Dad00eLMDaeG7@02Ead03ELLEaeK?5/m
FcaOG5llGeaO?5mLJg][Vf]k009_VP03MkUcV7oo02Moo`@004]oo`00Kgoo05@007ooOomC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5LMD_aG?ELLEceG
75LmEaaG?E/lGeeK?5mMFcaOGEmKHeaOG7>JKiUcVW>HMkTTOol4001?Ool0071oo`800003OomC7Dkm
009Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d02U<MD_eBoE;mDaeBoE<MD_eC7E;m0U<M00IG7E<M
DaeC7ELMEa`2Ead01U/mEaaG?EllGeaO?0ASG09WN`03IgacV7>i029oo`<005=oo`00LWoo04l004km
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeC75LMD_aG7E<L
EaeG75/mEaaK?ELLFceOG6=LGe]SG6MKIgaSFfMlJgY[V`0OOol4001FOol007=oo`04001BoE<MC_d2
D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eB
oE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7E;mDaeBoE<MD_d3Dad01E;mDaeC7ELMDad00eLM
00AG75LmEcaK?@=K?005FceWNfMkIg][V`02Jg/LOol4001JOol007Aoo`1;001>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDaeBo5LMD_aG7E<LEaeC75LMFcaK?E/lFceK
?5/mFcaOGE/lKi][NV^K01Uoo`@005ioo`00MGoo0P0000IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;m
Dae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@08
DaeBoE;mD_eC7E;mDaeBo@QC7@03EaeG75LM009G7@=K?004GeaO?5mLGc`3He`FOol4001ROol007Mo
o`16001C7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>
oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lEaeBo5<MD_aG7E<LEceG
75LmEaaG?E/lGeeK?5mMGe]SG5mLHe`COol4001VOol007Qoo`03001C7Dkm009Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m00iC
7DkmD_eBoE<MD_eC7E;mDaeBoE<MD_eC7E;m0U<M00]G7E<MDaeC7E/mEaaG?ELlFceG75Lm00ASG15o
o`<006Yoo`00NGoo048005<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>o5<MC_aC7DklDae>o5<MC_aC7E;lDaeBo5<MD_aG7E<L
EaeC75LMDaaK?ELLFceG75/mFcaK?EmLHe`>Ool4001]Ool007Yoo`03001oodkm009Bo@06Dae>oE;m
D_eC7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm0U;m
00YC7DkmD_eBoE<MD_eC7E;mDaeBo@=C7@05D_eG7ELMEaeC7@02Ead01E/mFcaK?5/lFcd00U/l2goo
1000LGoo001kOol20000>dklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<M
C_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC7DklDaeBo5LMD_aC7E;lEaeC75LM
EaaG?ELLFceK?5/mFc`02Goo1000MGoo001mOol01P00C_eBoE;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@05Dae>oE;mD_eC7@03D_d015<MD_eC
7E;m1U<M0eLM00AG75LMEaeG7@Moo`@007Uoo`00OWoo03<004klDae>oE<MC_aC7DkmDae>o5<MC_eC
7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_aC7DklDae>o5<MC_aC
7E;lDaeBo5LMDaaG7E;lEad027oo1000OGoo001oOol01P00OomBoE;mDae>o@9Bo@06Dae>oE;mD_eC
7Dkm0U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@0:Dae>oE;mD_eC7E;mDaeBoE<M
D_d6Dad7Ool30021Ool0081oo`80000[Dae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<MC_aC7DklDae>o5<MD_aC7E;lDad01Goo1000Q7oo
0022Ool01@00D_eBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06Dae>
oE;mD_eC7Dkm0U;m00QC7E;mD_eBoE<MD_eC7E;m1Goo1000R7oo0023Ool08P00Dae>oE<MC_aC7Dkm
Dae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>o5<MC_eC7DklDae>oE<MC_aC7DklDae>o5<M1Goo1000
S7oo0024Ool01@00OomBoE<MC_d00U;m00IC7DkmD_eBoE<MC_d2D_d01U<MC_eBoE;mDae>o@9Bo@06
Dae>oE;mD_eC7Dkm1Goo1000T7oo0025Ool2000064kmDae>o5<MC_eC7DklDae>oE<MC_aC7DkmDae>
o5<MC_eC7DklDae>oE<MC_aC7@Aoo`<009Aoo`00Qgoo00@005;mDae>o@9Bo@06Dae>oE;mD_eC7Dkm
0U;m00IC7DkmD_eBoE<MC_d2D_d2Ool4002GOol008Qoo`0A001>oE<MC_aC7DkmDae>o5<MC_eC7Dkl
Dae>oE<MC_aC7@02Ool4002KOol008Uoo`04001ooe<MC_d2D_d01U<MC_eBoE;mDae>o@9oo`@009mo
o`00RWoo0P0000EC7DklDae>oE<M009oo`@00:=oo`00S7oo0P0000=oo`0000000P00Ygoo002=Ool2
002[Ool00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]oo`00ogoo>goo003oOolkOol00?mooc]o
o`00ogoo>goo0000\
\>"],
  ImageRangeCache->{{{0, 313.125}, {253.75, 0}} -> {-0.0937584, 0.0170218, \
0.00417706, 0.00417706}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The animation shows that the step is stable and does not disperse. \
The solution is a soliton which propagates in a firm form.\[ThickSpace]\
\[EmptySquare]\
\>", "Text"],

Cell[TextData[{
  "This section was concerned with the reduction of the original equations \
(PDEs) either to an ODE or to a PDE with less independent variables. We \
demonstrated that the reductions are instrumental to find symbolic solutions. \
Even if we fail to write down an analytic solution, we can  utilize the \
numerical capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to solve the reduction. For PDEs in more than two independent variables, \
we can apply the functions of ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  " several times to find the reductions and even the solutions. The \
following sections will demonstrate the application of the functions of ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  " to physical problems."
}], "Text"],

Cell[TextData[ButtonBox["Next notebook",
  ButtonData:>{"symmet51.nb", None},
  ButtonStyle->"Hyperlink"]], "Text",
  CellFrame->{{0, 0}, {0, 0.5}}]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
Evaluator->"Local",
WindowSize->{696, 668},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->262,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          StyleBox[ 
          "Point Symmetries of Partial Differential Equations", FontSlant -> 
            "Italic"]}], "Header"], Inherited, None}, {
    None, Inherited, Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ 
            "Section", CounterFunction :> (
              Part[ {"Similarity Reduction of Partial Differential \
Equations"}, #]&)], FontSlant -> "Italic"], "     ", 
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"]}], "Header"]}},
PageFooters->{{Inherited, None, Inherited}, {Inherited, None, Inherited}},
PageHeaderLines->{False, False},
PrintingOptions->{"FirstPageHeader"->True,
"FirstPageFooter"->False,
"FacingPages"->True,
"FirstPageFace"->Right},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
StyleDefinitions -> "BookStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Reduction of partial differential equations"->{
    Cell[1739, 51, 414, 5, 52, "Section",
      CounterAssignments->{{"Title", 5}, {"SubTitle", 0}, {
          "SubSubTitle", 0}, {"Section", 0}, {"SubSection", 0}, {
          "SubSubSection", 0}, {"NumberedEquation", 23}, {
          "NumberedFigure", 0}, {"NumberedTable", 0}},
      CellTags->"Reduction of partial differential equations"]},
  "reduction of differential equations"->{
    Cell[2156, 58, 1454, 25, 222, "Text",
      CellTags->{
      "reduction of differential equations", "group invariance", 
        "invariance condition", "reduction of order", 
        "integration of ODEs by quadrature", 
        "invariance condition of partial differential equations", 
        "similarity representation", "reduce of independent variables"}]},
  "group invariance"->{
    Cell[2156, 58, 1454, 25, 222, "Text",
      CellTags->{
      "reduction of differential equations", "group invariance", 
        "invariance condition", "reduction of order", 
        "integration of ODEs by quadrature", 
        "invariance condition of partial differential equations", 
        "similarity representation", "reduce of independent variables"}]},
  "invariance condition"->{
    Cell[2156, 58, 1454, 25, 222, "Text",
      CellTags->{
      "reduction of differential equations", "group invariance", 
        "invariance condition", "reduction of order", 
        "integration of ODEs by quadrature", 
        "invariance condition of partial differential equations", 
        "similarity representation", "reduce of independent variables"}]},
  "reduction of order"->{
    Cell[2156, 58, 1454, 25, 222, "Text",
      CellTags->{
      "reduction of differential equations", "group invariance", 
        "invariance condition", "reduction of order", 
        "integration of ODEs by quadrature", 
        "invariance condition of partial differential equations", 
        "similarity representation", "reduce of independent variables"}]},
  "integration of ODEs by quadrature"->{
    Cell[2156, 58, 1454, 25, 222, "Text",
      CellTags->{
      "reduction of differential equations", "group invariance", 
        "invariance condition", "reduction of order", 
        "integration of ODEs by quadrature", 
        "invariance condition of partial differential equations", 
        "similarity representation", "reduce of independent variables"}]},
  "invariance condition of partial differential equations"->{
    Cell[2156, 58, 1454, 25, 222, "Text",
      CellTags->{
      "reduction of differential equations", "group invariance", 
        "invariance condition", "reduction of order", 
        "integration of ODEs by quadrature", 
        "invariance condition of partial differential equations", 
        "similarity representation", "reduce of independent variables"}]},
  "similarity representation"->{
    Cell[2156, 58, 1454, 25, 222, "Text",
      CellTags->{
      "reduction of differential equations", "group invariance", 
        "invariance condition", "reduction of order", 
        "integration of ODEs by quadrature", 
        "invariance condition of partial differential equations", 
        "similarity representation", "reduce of independent variables"}],
    Cell[220743, 5205, 1234, 38, 117, "Text",
      Evaluatable->False,
      CellTags->{
      "characteristic equation", "similarity variable", 
        "similarity representation"}],
    Cell[285474, 7320, 177, 5, 33, "Text",
      Evaluatable->False,
      CellTags->"similarity representation"],
    Cell[286071, 7341, 662, 14, 117, "Text",
      Evaluatable->False,
      CellTags->{"similarity variable", "similarity representation"}],
    Cell[287413, 7382, 1044, 19, 201, "Text",
      Evaluatable->False,
      CellTags->{"LieReduction[]", "similarity representation"}],
    Cell[292452, 7525, 586, 18, 75, "Text",
      Evaluatable->False,
      CellTags->"similarity representation"],
    Cell[364352, 9653, 199, 4, 54, "Text",
      CellTags->{"similarity representation", "Lie's procedure"}]},
  "reduce of independent variables"->{
    Cell[2156, 58, 1454, 25, 222, "Text",
      CellTags->{
      "reduction of differential equations", "group invariance", 
        "invariance condition", "reduction of order", 
        "integration of ODEs by quadrature", 
        "invariance condition of partial differential equations", 
        "similarity representation", "reduce of independent variables"}]},
  "boundary condition"->{
    Cell[3613, 85, 878, 14, 180, "Text",
      CellTags->{
      "boundary condition", "similarity solution", "mechanics", 
        "hydrodynamics", "theory of relativity", 
        "algorithmic procedure of similarity reduction"}]},
  "similarity solution"->{
    Cell[3613, 85, 878, 14, 180, "Text",
      CellTags->{
      "boundary condition", "similarity solution", "mechanics", 
        "hydrodynamics", "theory of relativity", 
        "algorithmic procedure of similarity reduction"}]},
  "mechanics"->{
    Cell[3613, 85, 878, 14, 180, "Text",
      CellTags->{
      "boundary condition", "similarity solution", "mechanics", 
        "hydrodynamics", "theory of relativity", 
        "algorithmic procedure of similarity reduction"}]},
  "hydrodynamics"->{
    Cell[3613, 85, 878, 14, 180, "Text",
      CellTags->{
      "boundary condition", "similarity solution", "mechanics", 
        "hydrodynamics", "theory of relativity", 
        "algorithmic procedure of similarity reduction"}]},
  "theory of relativity"->{
    Cell[3613, 85, 878, 14, 180, "Text",
      CellTags->{
      "boundary condition", "similarity solution", "mechanics", 
        "hydrodynamics", "theory of relativity", 
        "algorithmic procedure of similarity reduction"}]},
  "algorithmic procedure of similarity reduction"->{
    Cell[3613, 85, 878, 14, 180, "Text",
      CellTags->{
      "boundary condition", "similarity solution", "mechanics", 
        "hydrodynamics", "theory of relativity", 
        "algorithmic procedure of similarity reduction"}]},
  "invariance"->{
    Cell[4494, 101, 369, 7, 96, "Text",
      CellTags->"invariance"],
    Cell[6446, 167, 300, 8, 54, "Text",
      Evaluatable->False,
      CellTags->{"transformed PDE", "invariance"}]},
  "eq-1"->{
    Cell[4994, 115, 169, 4, 29, "NumberedEquation",
      CellTags->"eq-1"]},
  "one-parameter Lie group"->{
    Cell[5166, 121, 178, 5, 33, "Text",
      Evaluatable->False,
      CellTags->{"one-parameter Lie group", "transformation"}]},
  "transformation"->{
    Cell[5166, 121, 178, 5, 33, "Text",
      Evaluatable->False,
      CellTags->{"one-parameter Lie group", "transformation"}],
    Cell[5678, 140, 385, 12, 54, "Text",
      Evaluatable->False,
      CellTags->"transformation"]},
  "transformed PDE"->{
    Cell[6446, 167, 300, 8, 54, "Text",
      Evaluatable->False,
      CellTags->{"transformed PDE", "invariance"}]},
  "Definition: Invariance"->{
    Cell[6749, 177, 82, 1, 38, "Definition",
      CellTags->"Definition: Invariance"]},
  "invariant under a one-parameter Lie group"->{
    Cell[6834, 180, 667, 18, 54, "Text",
      Evaluatable->False,
      CellTags->"invariant under a one-parameter Lie group"]},
  "functional equation"->{
    Cell[7504, 200, 189, 5, 54, "Text",
      Evaluatable->False,
      CellTags->"functional equation"]},
  "eq-8"->{
    Cell[7696, 207, 256, 6, 28, "NumberedEquation",
      CellTags->"eq-8"]},
  "infinitesimal representation of a transformation"->{
    Cell[7955, 215, 432, 8, 75, "Text",
      Evaluatable->False,
      CellTags->{
      "infinitesimal representation of a transformation", 
        "infinitesimal representation"}]},
  "infinitesimal representation"->{
    Cell[7955, 215, 432, 8, 75, "Text",
      Evaluatable->False,
      CellTags->{
      "infinitesimal representation of a transformation", 
        "infinitesimal representation"}]},
  "simplification"->{
    Cell[9187, 251, 206, 5, 54, "Text",
      Evaluatable->False,
      CellTags->"simplification"]},
  "group parameter"->{
    Cell[9882, 273, 739, 14, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "group parameter", "infinitesimals parameter", "Taylor expansion"}],
    Cell[225519, 5358, 719, 19, 96, "Text",
      Evaluatable->False,
      CellTags->{"special functions", "group parameter"}]},
  "infinitesimals parameter"->{
    Cell[9882, 273, 739, 14, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "group parameter", "infinitesimals parameter", "Taylor expansion"}]},
  "Taylor expansion"->{
    Cell[9882, 273, 739, 14, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "group parameter", "infinitesimals parameter", "Taylor expansion"}]},
  "invariant surface condition"->{
    Cell[11121, 304, 865, 19, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "invariant surface condition", 
        "first-order partial differential equation", "DSolve[]", 
        "first-order PDEs"}]},
  "first-order partial differential equation"->{
    Cell[11121, 304, 865, 19, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "invariant surface condition", 
        "first-order partial differential equation", "DSolve[]", 
        "first-order PDEs"}]},
  "DSolve[]"->{
    Cell[11121, 304, 865, 19, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "invariant surface condition", 
        "first-order partial differential equation", "DSolve[]", 
        "first-order PDEs"}],
    Cell[224273, 5324, 727, 15, 117, "Text",
      Evaluatable->False,
      CellTags->{
      "reduced a PDE to an ODE", "invariants of a group", "DSolve[]"}],
    Cell[291893, 7504, 245, 6, 54, "Text",
      Evaluatable->False,
      CellTags->"DSolve[]"]},
  "first-order PDEs"->{
    Cell[11121, 304, 865, 19, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "invariant surface condition", 
        "first-order partial differential equation", "DSolve[]", 
        "first-order PDEs"}]},
  "surface"->{
    Cell[11989, 325, 311, 13, 33, "Text",
      Evaluatable->False,
      CellTags->"surface"]},
  "first-order PDE"->{
    Cell[12428, 345, 399, 10, 75, "Text",
      Evaluatable->False,
      CellTags->"first-order PDE"],
    Cell[18873, 553, 332, 10, 54, "Text",
      Evaluatable->False,
      CellTags->{"scaling symmetry", "first-order PDE"}]},
  "tangent vector"->{
    Cell[12960, 362, 103, 2, 33, "Text",
      Evaluatable->False,
      CellTags->"tangent vector"]},
  "normal direction"->{
    Cell[13944, 391, 647, 18, 75, "Text",
      Evaluatable->False,
      CellTags->{"normal direction", "unit vector", "gradient"}]},
  "unit vector"->{
    Cell[13944, 391, 647, 18, 75, "Text",
      Evaluatable->False,
      CellTags->{"normal direction", "unit vector", "gradient"}]},
  "gradient"->{
    Cell[13944, 391, 647, 18, 75, "Text",
      Evaluatable->False,
      CellTags->{"normal direction", "unit vector", "gradient"}]},
  "family of curves"->{
    Cell[16145, 458, 104, 2, 33, "Text",
      Evaluatable->False,
      CellTags->"family of curves"]},
  "characteristic differential equations"->{
    Cell[17201, 498, 370, 8, 54, "Text",
      Evaluatable->False,
      CellTags->{
      "characteristic differential equations", "surface condition"}],
    Cell[212671, 4935, 224, 6, 54, "Text",
      Evaluatable->False,
      CellTags->"characteristic differential equations"]},
  "surface condition"->{
    Cell[17201, 498, 370, 8, 54, "Text",
      Evaluatable->False,
      CellTags->{
      "characteristic differential equations", "surface condition"}]},
  "family of characteristic curves"->{
    Cell[17735, 513, 653, 17, 96, "Text",
      Evaluatable->False,
      CellTags->{
      "family of characteristic curves", "integral surface", 
        "characteristic curves"}]},
  "integral surface"->{
    Cell[17735, 513, 653, 17, 96, "Text",
      Evaluatable->False,
      CellTags->{
      "family of characteristic curves", "integral surface", 
        "characteristic curves"}]},
  "characteristic curves"->{
    Cell[17735, 513, 653, 17, 96, "Text",
      Evaluatable->False,
      CellTags->{
      "family of characteristic curves", "integral surface", 
        "characteristic curves"}]},
  "scaling symmetry"->{
    Cell[18873, 553, 332, 10, 54, "Text",
      Evaluatable->False,
      CellTags->{"scaling symmetry", "first-order PDE"}],
    Cell[216316, 5051, 228, 5, 54, "Text",
      Evaluatable->False,
      CellTags->{"heat equation", "scaling symmetry"}]},
  "Sin[]"->{
    Cell[19438, 575, 351, 13, 54, "Text",
      Evaluatable->False,
      CellTags->"Sin[]"]},
  "characteristic curve"->{
    Cell[213050, 4948, 625, 15, 96, "Text",
      Evaluatable->False,
      CellTags->{"characteristic curve", "family of surfaces"}]},
  "family of surfaces"->{
    Cell[213050, 4948, 625, 15, 96, "Text",
      Evaluatable->False,
      CellTags->{"characteristic curve", "family of surfaces"}]},
  "one-parameter Lie group transformation"->{
    Cell[213678, 4965, 393, 9, 75, "Text",
      Evaluatable->False,
      CellTags->"one-parameter Lie group transformation"],
    Cell[215319, 5018, 292, 8, 54, "Text",
      Evaluatable->False,
      CellTags->{"one-parameter Lie group transformation", "invariant"}]},
  "vector field"->{
    Cell[214364, 4986, 210, 7, 33, "Text",
      Evaluatable->False,
      CellTags->"vector field"]},
  "determining equation of a surface"->{
    Cell[214797, 5002, 423, 11, 56, "Text",
      Evaluatable->False,
      CellTags->"determining equation of a surface"]},
  "Theorem: Invariance condition"->{
    Cell[215223, 5015, 93, 1, 38, "Theorem",
      CellTags->"Theorem: Invariance condition"]},
  "invariant"->{
    Cell[215319, 5018, 292, 8, 54, "Text",
      Evaluatable->False,
      CellTags->{"one-parameter Lie group transformation", "invariant"}],
    Cell[218687, 5133, 821, 26, 75, "Text",
      Evaluatable->False,
      CellTags->{"invariant", "infinitesimals"}]},
  "method of characteristics"->{
    Cell[215914, 5039, 368, 8, 75, "Text",
      Evaluatable->False,
      CellTags->"method of characteristics"]},
  "heat equation"->{
    Cell[216316, 5051, 228, 5, 54, "Text",
      Evaluatable->False,
      CellTags->{"heat equation", "scaling symmetry"}],
    Cell[220042, 5180, 299, 6, 75, "Text",
      Evaluatable->False,
      CellTags->{"reduction process", "heat equation"}],
    Cell[284825, 7295, 344, 11, 54, "Text",
      Evaluatable->False,
      CellTags->"heat equation"]},
  "invariants"->{
    Cell[217730, 5104, 850, 24, 96, "Text",
      Evaluatable->False,
      CellTags->{"invariants", "reduction procedure"}]},
  "reduction procedure"->{
    Cell[217730, 5104, 850, 24, 96, "Text",
      Evaluatable->False,
      CellTags->{"invariants", "reduction procedure"}]},
  "Theorem: Invariant Representation"->{
    Cell[218583, 5130, 101, 1, 38, "Theorem",
      CellTags->"Theorem: Invariant Representation"]},
  "infinitesimals"->{
    Cell[218687, 5133, 821, 26, 75, "Text",
      Evaluatable->False,
      CellTags->{"invariant", "infinitesimals"}],
    Cell[295309, 7627, 288, 7, 54, "Text",
      Evaluatable->False,
      CellTags->{"infinitesimals", "Infinitesimals[]"}],
    Cell[368490, 9781, 325, 7, 75, "Text",
      CellTags->{
      "nonlinear third-order PDE", "second similarity representation", 
        "infinitesimals"}]},
  "invariants of a group"->{
    Cell[219715, 5167, 324, 11, 33, "Text",
      Evaluatable->False,
      CellTags->"invariants of a group"],
    Cell[224273, 5324, 727, 15, 117, "Text",
      Evaluatable->False,
      CellTags->{
      "reduced a PDE to an ODE", "invariants of a group", "DSolve[]"}]},
  "reduction process"->{
    Cell[220042, 5180, 299, 6, 75, "Text",
      Evaluatable->False,
      CellTags->{"reduction process", "heat equation"}]},
  "characteristic equation"->{
    Cell[220743, 5205, 1234, 38, 117, "Text",
      Evaluatable->False,
      CellTags->{
      "characteristic equation", "similarity variable", 
        "similarity representation"}]},
  "similarity variable"->{
    Cell[220743, 5205, 1234, 38, 117, "Text",
      Evaluatable->False,
      CellTags->{
      "characteristic equation", "similarity variable", 
        "similarity representation"}],
    Cell[286071, 7341, 662, 14, 117, "Text",
      Evaluatable->False,
      CellTags->{"similarity variable", "similarity representation"}]},
  "reduced a PDE to an ODE"->{
    Cell[224273, 5324, 727, 15, 117, "Text",
      Evaluatable->False,
      CellTags->{
      "reduced a PDE to an ODE", "invariants of a group", "DSolve[]"}]},
  "special functions"->{
    Cell[225519, 5358, 719, 19, 96, "Text",
      Evaluatable->False,
      CellTags->{"special functions", "group parameter"}]},
  "LieReduction[]"->{
    Cell[287413, 7382, 1044, 19, 201, "Text",
      Evaluatable->False,
      CellTags->{"LieReduction[]", "similarity representation"}],
    Cell[294288, 7592, 506, 14, 75, "Text",
      Evaluatable->False,
      CellTags->{"two coupled diffusion equations", "LieReduction[]"}],
    Cell[330052, 8707, 581, 15, 75, "Text",
      Evaluatable->False,
      CellTags->{"LieReduction[]", "Karpman-Belashov equation"}]},
  "similarity variables"->{
    Cell[289513, 7435, 1026, 25, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "similarity variables", "similarity representation of the solution", 
        "reduction", "potential Burgers equation"}]},
  "similarity representation of the solution"->{
    Cell[289513, 7435, 1026, 25, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "similarity variables", "similarity representation of the solution", 
        "reduction", "potential Burgers equation"}]},
  "reduction"->{
    Cell[289513, 7435, 1026, 25, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "similarity variables", "similarity representation of the solution", 
        "reduction", "potential Burgers equation"}],
    Cell[342893, 9062, 1475, 49, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "nonlinear partial differential equation of sixth order", "reduction"}],
    
    Cell[351996, 9321, 598, 22, 54, "Text",
      CellTags->"reduction"]},
  "potential Burgers equation"->{
    Cell[289513, 7435, 1026, 25, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "similarity variables", "similarity representation of the solution", 
        "reduction", "potential Burgers equation"}]},
  "solution of the potential Burgers equation"->{
    Cell[293374, 7558, 290, 8, 54, "Text",
      Evaluatable->False,
      CellTags->"solution of the potential Burgers equation"]},
  "two coupled diffusion equations"->{
    Cell[294288, 7592, 506, 14, 75, "Text",
      Evaluatable->False,
      CellTags->{"two coupled diffusion equations", "LieReduction[]"}]},
  "Infinitesimals[]"->{
    Cell[295309, 7627, 288, 7, 54, "Text",
      Evaluatable->False,
      CellTags->{"infinitesimals", "Infinitesimals[]"}]},
  "symmetry group"->{
    Cell[298762, 7734, 614, 17, 96, "Text",
      Evaluatable->False,
      CellTags->"symmetry group"]},
  "reduction of the coupled diffusion equations"->{
    Cell[300233, 7782, 194, 5, 33, "Text",
      Evaluatable->False,
      CellTags->"reduction of the coupled diffusion equations"]},
  "NDSolve[]"->{
    Cell[305284, 7939, 618, 13, 117, "Text",
      Evaluatable->False,
      CellTags->{"NDSolve[]", "numerical solution", "initial conditions"}]},
  "numerical solution"->{
    Cell[305284, 7939, 618, 13, 117, "Text",
      Evaluatable->False,
      CellTags->{"NDSolve[]", "numerical solution", "initial conditions"}]},
  "initial conditions"->{
    Cell[305284, 7939, 618, 13, 117, "Text",
      Evaluatable->False,
      CellTags->{"NDSolve[]", "numerical solution", "initial conditions"}]},
  "numerical integration"->{
    Cell[310457, 8089, 339, 11, 54, "Text",
      Evaluatable->False,
      CellTags->"numerical integration"]},
  "interpolating function"->{
    Cell[311360, 8122, 206, 5, 54, "Text",
      Evaluatable->False,
      CellTags->"interpolating function"]},
  "analytic solution"->{
    Cell[329293, 8688, 725, 15, 138, "Text",
      CellTags->"analytic solution"]},
  "Karpman-Belashov equation"->{
    Cell[330052, 8707, 581, 15, 75, "Text",
      Evaluatable->False,
      CellTags->{"LieReduction[]", "Karpman-Belashov equation"}]},
  "Zabolotskaya-Khoklov equation"->{
    Cell[331098, 8736, 817, 14, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "Zabolotskaya-Khoklov equation", "KB-equation", 
        "Kadomtsev-Petviashvili equation", 
        "wave in weakly dispersive and dissipative media", "ZK-equation"}]},
  "KB-equation"->{
    Cell[331098, 8736, 817, 14, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "Zabolotskaya-Khoklov equation", "KB-equation", 
        "Kadomtsev-Petviashvili equation", 
        "wave in weakly dispersive and dissipative media", "ZK-equation"}],
    Cell[332808, 8778, 238, 4, 54, "Text",
      Evaluatable->False,
      CellTags->{"KB-equation", "infinitesimals of the KB-equation"}],
    Cell[347776, 9187, 501, 8, 117, "Text",
      CellTags->{"KB-equation", "sixth-order nonlinear PDE"}],
    Cell[355243, 9413, 164, 3, 33, "Text",
      CellTags->"KB-equation"],
    Cell[388984, 10261, 244, 7, 54, "Text",
      CellTags->"KB-equation"]},
  "Kadomtsev-Petviashvili equation"->{
    Cell[331098, 8736, 817, 14, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "Zabolotskaya-Khoklov equation", "KB-equation", 
        "Kadomtsev-Petviashvili equation", 
        "wave in weakly dispersive and dissipative media", "ZK-equation"}]},
  "wave in weakly dispersive and dissipative media"->{
    Cell[331098, 8736, 817, 14, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "Zabolotskaya-Khoklov equation", "KB-equation", 
        "Kadomtsev-Petviashvili equation", 
        "wave in weakly dispersive and dissipative media", "ZK-equation"}]},
  "ZK-equation"->{
    Cell[331098, 8736, 817, 14, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "Zabolotskaya-Khoklov equation", "KB-equation", 
        "Kadomtsev-Petviashvili equation", 
        "wave in weakly dispersive and dissipative media", "ZK-equation"}],
    Cell[355907, 9437, 156, 4, 54, "Text",
      CellTags->"ZK-equation"],
    Cell[391125, 10310, 91, 1, 33, "Text",
      CellTags->"ZK-equation"],
    Cell[391421, 10323, 458, 10, 75, "Text",
      CellTags->{"ZK-equation", "symbolic solution"}],
    Cell[6519607, 131444, 372, 9, 75, "Text",
      CellTags->"ZK-equation"]},
  "infinitesimals of the KB-equation"->{
    Cell[332808, 8778, 238, 4, 54, "Text",
      Evaluatable->False,
      CellTags->{"KB-equation", "infinitesimals of the KB-equation"}]},
  "infinite-dimensional symmetry group"->{
    Cell[334821, 8841, 3971, 130, 201, "Text",
      Evaluatable->False,
      CellTags->{"infinite-dimensional symmetry group", "subgroup"}]},
  "subgroup"->{
    Cell[334821, 8841, 3971, 130, 201, "Text",
      Evaluatable->False,
      CellTags->{"infinite-dimensional symmetry group", "subgroup"}]},
  "nonlinear partial differential equation of sixth order"->{
    Cell[342893, 9062, 1475, 49, 138, "Text",
      Evaluatable->False,
      CellTags->{
      "nonlinear partial differential equation of sixth order", 
        "reduction"}]},
  "sixth-order nonlinear PDE"->{
    Cell[347776, 9187, 501, 8, 117, "Text",
      CellTags->{"KB-equation", "sixth-order nonlinear PDE"}]},
  "reduced KB-equation"->{
    Cell[348780, 9215, 194, 5, 54, "Text",
      CellTags->"reduced KB-equation"]},
  "fourth-order nonlinear PDE"->{
    Cell[354856, 9398, 384, 13, 54, "Text",
      CellTags->"fourth-order nonlinear PDE"]},
  "infinite symmetry group"->{
    Cell[358220, 9512, 690, 16, 96, "Text",
      CellTags->{"infinite symmetry group", "scaling group"}]},
  "scaling group"->{
    Cell[358220, 9512, 690, 16, 96, "Text",
      CellTags->{"infinite symmetry group", "scaling group"}]},
  "third-order nonlinear PDE"->{
    Cell[362575, 9608, 198, 4, 54, "Text",
      CellTags->{"third-order nonlinear PDE", "translation"}]},
  "translation"->{
    Cell[362575, 9608, 198, 4, 54, "Text",
      CellTags->{"third-order nonlinear PDE", "translation"}]},
  "Lie's procedure"->{
    Cell[364352, 9653, 199, 4, 54, "Text",
      CellTags->{"similarity representation", "Lie's procedure"}]},
  "finite symmetry group"->{
    Cell[367119, 9744, 231, 5, 54, "Text",
      CellTags->"finite symmetry group"]},
  "nonlinear third-order PDE"->{
    Cell[368490, 9781, 325, 7, 75, "Text",
      CellTags->{
      "nonlinear third-order PDE", "second similarity representation", 
        "infinitesimals"}]},
  "second similarity representation"->{
    Cell[368490, 9781, 325, 7, 75, "Text",
      CellTags->{
      "nonlinear third-order PDE", "second similarity representation", 
        "infinitesimals"}]},
  "third-order nonlinear ODE"->{
    Cell[370966, 9851, 345, 10, 54, "Text",
      CellTags->"third-order nonlinear ODE"]},
  "Airy"->{
    Cell[378174, 10025, 274, 8, 54, "Text",
      CellTags->"Airy"]},
  "Tan[]"->{
    Cell[380670, 10090, 613, 14, 96, "Text",
      CellTags->{"Tan[]", "special function"}]},
  "special function"->{
    Cell[380670, 10090, 613, 14, 96, "Text",
      CellTags->{"Tan[]", "special function"}]},
  "AiryBi[]"->{
    Cell[381308, 10108, 581, 10, 81, "Input",
      CellTags->{"AiryBi[]", "AiryBiPrime[]", "AiryAi[]", "AiryAiPrime[]"}]},
  "AiryBiPrime[]"->{
    Cell[381308, 10108, 581, 10, 81, "Input",
      CellTags->{"AiryBi[]", "AiryBiPrime[]", "AiryAi[]", "AiryAiPrime[]"}]},
  "AiryAi[]"->{
    Cell[381308, 10108, 581, 10, 81, "Input",
      CellTags->{"AiryBi[]", "AiryBiPrime[]", "AiryAi[]", "AiryAiPrime[]"}]},
  "AiryAiPrime[]"->{
    Cell[381308, 10108, 581, 10, 81, "Input",
      CellTags->{"AiryBi[]", "AiryBiPrime[]", "AiryAi[]", "AiryAiPrime[]"}]},
  "symbolic solution"->{
    Cell[391421, 10323, 458, 10, 75, "Text",
      CellTags->{"ZK-equation", "symbolic solution"}]},
  "ZK-Soliton"->{
    Cell[6520004, 131457, 325, 6, 45, "Input",
      CellTags->"ZK-Soliton"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Reduction of partial differential equations", 9896495, 199776},
  {"reduction of differential equations", 9896885, 199783},
  {"group invariance", 9897278, 199791},
  {"invariance condition", 9897675, 199799},
  {"reduction of order", 9898070, 199807},
  {"integration of ODEs by quadrature", 9898480, 199815},
  {"invariance condition of partial differential equations", 9898911, \
199823},
  {"similarity representation", 9899313, 199831},
  {"reduce of independent variables", 9900528, 199858},
  {"boundary condition", 9900923, 199866},
  {"similarity solution", 9901184, 199872},
  {"mechanics", 9901435, 199878},
  {"hydrodynamics", 9901690, 199884},
  {"theory of relativity", 9901952, 199890},
  {"algorithmic procedure of similarity reduction", 9902239, 199896},
  {"invariance", 9902491, 199902},
  {"eq-1", 9902693, 199908},
  {"one-parameter Lie group", 9902802, 199911},
  {"transformation", 9902955, 199915},
  {"transformed PDE", 9903211, 199922},
  {"Definition: Invariance", 9903360, 199926},
  {"invariant under a one-parameter Lie group", 9903498, 199929},
  {"functional equation", 9903655, 199933},
  {"eq-8", 9903774, 199937},
  {"infinitesimal representation of a transformation", 9903908, 199940},
  {"infinitesimal representation", 9904130, 199946},
  {"simplification", 9904338, 199952},
  {"group parameter", 9904463, 199956},
  {"infinitesimals parameter", 9904786, 199964},
  {"Taylor expansion", 9904972, 199969},
  {"invariant surface condition", 9905169, 199974},
  {"first-order partial differential equation", 9905440, 199981},
  {"DSolve[]", 9905678, 199988},
  {"first-order PDEs", 9906183, 200002},
  {"surface", 9906420, 200009},
  {"first-order PDE", 9906540, 200013},
  {"tangent vector", 9906793, 200020},
  {"normal direction", 9906920, 200024},
  {"unit vector", 9907074, 200028},
  {"gradient", 9907225, 200032},
  {"family of curves", 9907384, 200036},
  {"characteristic differential equations", 9907534, 200040},
  {"surface condition", 9907842, 200048},
  {"family of characteristic curves", 9908037, 200053},
  {"integral surface", 9908245, 200059},
  {"characteristic curves", 9908458, 200065},
  {"scaling symmetry", 9908666, 200071},
  {"Sin[]", 9908931, 200078},
  {"characteristic curve", 9909054, 200082},
  {"family of surfaces", 9909216, 200086},
  {"one-parameter Lie group transformation", 9909398, 200090},
  {"vector field", 9909690, 200097},
  {"determining equation of a surface", 9909834, 200101},
  {"Theorem: Invariance condition", 9909996, 200105},
  {"invariant", 9910109, 200108},
  {"method of characteristics", 9910406, 200115},
  {"heat equation", 9910543, 200119},
  {"invariants", 9910917, 200129},
  {"reduction procedure", 9911071, 200133},
  {"Theorem: Invariant Representation", 9911239, 200137},
  {"infinitesimals", 9911362, 200140},
  {"invariants of a group", 9911799, 200151},
  {"reduction process", 9912098, 200159},
  {"characteristic equation", 9912256, 200163},
  {"similarity variable", 9912470, 200169},
  {"reduced a PDE to an ODE", 9912830, 200178},
  {"special functions", 9913017, 200183},
  {"LieReduction[]", 9913169, 200187},
  {"similarity variables", 9913614, 200197},
  {"similarity representation of the solution", 9913883, 200203},
  {"reduction", 9914120, 200209},
  {"potential Burgers equation", 9914622, 200222},
  {"solution of the potential Burgers equation", 9914892, 200228},
  {"two coupled diffusion equations", 9915064, 200232},
  {"Infinitesimals[]", 9915231, 200236},
  {"symmetry group", 9915380, 200240},
  {"reduction of the coupled diffusion equations", 9915538, 200244},
  {"NDSolve[]", 9915690, 200248},
  {"numerical solution", 9915864, 200252},
  {"initial conditions", 9916038, 200256},
  {"numerical integration", 9916215, 200260},
  {"interpolating function", 9916358, 200264},
  {"analytic solution", 9916496, 200268},
  {"Karpman-Belashov equation", 9916613, 200271},
  {"Zabolotskaya-Khoklov equation", 9916787, 200275},
  {"KB-equation", 9917071, 200282},
  {"Kadomtsev-Petviashvili equation", 9917773, 200298},
  {"wave in weakly dispersive and dissipative media", 9918093, 200305},
  {"ZK-equation", 9918377, 200312},
  {"infinitesimals of the KB-equation", 9919011, 200327},
  {"infinite-dimensional symmetry group", 9919195, 200331},
  {"subgroup", 9919355, 200335},
  {"nonlinear partial differential equation of sixth order", 9919561, \
200339},
  {"sixth-order nonlinear PDE", 9919773, 200345},
  {"reduced KB-equation", 9919908, 200348},
  {"fourth-order nonlinear PDE", 9920026, 200351},
  {"infinite symmetry group", 9920149, 200354},
  {"scaling group", 9920278, 200357},
  {"third-order nonlinear PDE", 9920419, 200360},
  {"translation", 9920545, 200363},
  {"Lie's procedure", 9920675, 200366},
  {"finite symmetry group", 9920815, 200369},
  {"nonlinear third-order PDE", 9920934, 200372},
  {"second similarity representation", 9921136, 200377},
  {"third-order nonlinear ODE", 9921331, 200382},
  {"Airy", 9921434, 200385},
  {"Tan[]", 9921517, 200388},
  {"special function", 9921635, 200391},
  {"AiryBi[]", 9921745, 200394},
  {"AiryBiPrime[]", 9921890, 200397},
  {"AiryAi[]", 9922030, 200400},
  {"AiryAiPrime[]", 9922175, 200403},
  {"symbolic solution", 9922324, 200406},
  {"ZK-Soliton", 9922443, 200409}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 414, 5, 52, "Section",
  CounterAssignments->{{"Title", 5}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 23}, {"NumberedFigure", 0}, {"NumberedTable", 0}},
  CellTags->"Reduction of partial differential equations"],
Cell[2156, 58, 1454, 25, 222, "Text",
  CellTags->{
  "reduction of differential equations", "group invariance", 
    "invariance condition", "reduction of order", 
    "integration of ODEs by quadrature", 
    "invariance condition of partial differential equations", 
    "similarity representation", "reduce of independent variables"}],
Cell[3613, 85, 878, 14, 180, "Text",
  CellTags->{
  "boundary condition", "similarity solution", "mechanics", "hydrodynamics", 
    "theory of relativity", 
    "algorithmic procedure of similarity reduction"}],
Cell[4494, 101, 369, 7, 96, "Text",
  CellTags->"invariance"],
Cell[4866, 110, 125, 3, 54, "Text"],
Cell[4994, 115, 169, 4, 29, "NumberedEquation",
  CellTags->"eq-1"],
Cell[5166, 121, 178, 5, 33, "Text",
  Evaluatable->False,
  CellTags->{"one-parameter Lie group", "transformation"}],
Cell[5347, 128, 107, 2, 28, "NumberedEquation"],
Cell[5457, 132, 105, 2, 28, "NumberedEquation"],
Cell[5565, 136, 110, 2, 28, "NumberedEquation"],
Cell[5678, 140, 385, 12, 54, "Text",
  Evaluatable->False,
  CellTags->"transformation"],
Cell[6066, 154, 127, 3, 28, "NumberedEquation"],
Cell[6196, 159, 122, 2, 28, "NumberedEquation"],
Cell[6321, 163, 122, 2, 28, "NumberedEquation"],
Cell[6446, 167, 300, 8, 54, "Text",
  Evaluatable->False,
  CellTags->{"transformed PDE", "invariance"}],
Cell[6749, 177, 82, 1, 38, "Definition",
  CellTags->"Definition: Invariance"],
Cell[6834, 180, 667, 18, 54, "Text",
  Evaluatable->False,
  CellTags->"invariant under a one-parameter Lie group"],
Cell[7504, 200, 189, 5, 54, "Text",
  Evaluatable->False,
  CellTags->"functional equation"],
Cell[7696, 207, 256, 6, 28, "NumberedEquation",
  CellTags->"eq-8"],
Cell[7955, 215, 432, 8, 75, "Text",
  Evaluatable->False,
  CellTags->{
  "infinitesimal representation of a transformation", 
    "infinitesimal representation"}],

Cell[CellGroupData[{
Cell[8412, 227, 437, 12, 81, "Input"],
Cell[8852, 241, 320, 7, 70, "Output"]
}, Open  ]],
Cell[9187, 251, 206, 5, 54, "Text",
  Evaluatable->False,
  CellTags->"simplification"],

Cell[CellGroupData[{
Cell[9418, 260, 211, 4, 27, "Input"],
Cell[9632, 266, 235, 4, 30, "Output"]
}, Open  ]],
Cell[9882, 273, 739, 14, 138, "Text",
  Evaluatable->False,
  CellTags->{
  "group parameter", "infinitesimals parameter", "Taylor expansion"}],

Cell[CellGroupData[{
Cell[10646, 291, 338, 6, 45, "Input"],
Cell[10987, 299, 119, 2, 30, "Output"]
}, Open  ]],
Cell[11121, 304, 865, 19, 138, "Text",
  Evaluatable->False,
  CellTags->{
  "invariant surface condition", "first-order partial differential equation", 
    "DSolve[]", "first-order PDEs"}],
Cell[11989, 325, 311, 13, 33, "Text",
  Evaluatable->False,
  CellTags->"surface"],
Cell[12303, 340, 122, 3, 28, "NumberedEquation",
  Evaluatable->False],
Cell[12428, 345, 399, 10, 75, "Text",
  Evaluatable->False,
  CellTags->"first-order PDE"],
Cell[12830, 357, 127, 3, 28, "NumberedEquation",
  Evaluatable->False],
Cell[12960, 362, 103, 2, 33, "Text",
  Evaluatable->False,
  CellTags->"tangent vector"],
Cell[13066, 366, 875, 23, 44, "NumberedEquation"],
Cell[13944, 391, 647, 18, 75, "Text",
  Evaluatable->False,
  CellTags->{"normal direction", "unit vector", "gradient"}],
Cell[14594, 411, 437, 8, 46, "NumberedEquation"],
Cell[15034, 421, 370, 11, 54, "Text"],
Cell[15407, 434, 735, 22, 44, "NumberedEquation"],
Cell[16145, 458, 104, 2, 33, "Text",
  Evaluatable->False,
  CellTags->"family of curves"],
Cell[16252, 462, 313, 10, 44, "NumberedEquation"],
Cell[16568, 474, 313, 10, 44, "NumberedEquation"],
Cell[16884, 486, 314, 10, 44, "NumberedEquation"],
Cell[17201, 498, 370, 8, 54, "Text",
  Evaluatable->False,
  CellTags->{"characteristic differential equations", "surface condition"}],
Cell[17574, 508, 158, 3, 28, "NumberedEquation"],
Cell[17735, 513, 653, 17, 96, "Text",
  Evaluatable->False,
  CellTags->{
  "family of characteristic curves", "integral surface", 
    "characteristic curves"}],
Cell[18391, 532, 28, 0, 33, "Example"],
Cell[18422, 534, 110, 4, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18557, 542, 197, 4, 27, "Input"],
Cell[18757, 548, 101, 2, 30, "Output"]
}, Open  ]],
Cell[18873, 553, 332, 10, 54, "Text",
  Evaluatable->False,
  CellTags->{"scaling symmetry", "first-order PDE"}],

Cell[CellGroupData[{
Cell[19230, 567, 105, 2, 27, "Input"],
Cell[19338, 571, 85, 1, 41, "Output"]
}, Open  ]],
Cell[19438, 575, 351, 13, 54, "Text",
  Evaluatable->False,
  CellTags->"Sin[]"],

Cell[CellGroupData[{
Cell[19814, 592, 364, 7, 81, "Input"],
Cell[20181, 601, 192384, 4327, 247, 127058, 3516, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[212580, 4931, 88, 2, 33, "Text"],
Cell[212671, 4935, 224, 6, 54, "Text",
  Evaluatable->False,
  CellTags->"characteristic differential equations"],
Cell[212898, 4943, 149, 3, 28, "NumberedEquation",
  Evaluatable->False],
Cell[213050, 4948, 625, 15, 96, "Text",
  Evaluatable->False,
  CellTags->{"characteristic curve", "family of surfaces"}],
Cell[213678, 4965, 393, 9, 75, "Text",
  Evaluatable->False,
  CellTags->"one-parameter Lie group transformation"],
Cell[214074, 4976, 287, 8, 28, "NumberedEquation",
  Evaluatable->False],
Cell[214364, 4986, 210, 7, 33, "Text",
  Evaluatable->False,
  CellTags->"vector field"],
Cell[214577, 4995, 217, 5, 28, "NumberedEquation"],
Cell[214797, 5002, 423, 11, 56, "Text",
  Evaluatable->False,
  CellTags->"determining equation of a surface"],
Cell[215223, 5015, 93, 1, 38, "Theorem",
  CellTags->"Theorem: Invariance condition"],
Cell[215319, 5018, 292, 8, 54, "Text",
  Evaluatable->False,
  CellTags->{"one-parameter Lie group transformation", "invariant"}],
Cell[215614, 5028, 228, 7, 28, "NumberedEquation",
  Evaluatable->False],
Cell[215845, 5037, 66, 0, 33, "Text"],
Cell[215914, 5039, 368, 8, 75, "Text",
  Evaluatable->False,
  CellTags->"method of characteristics"],
Cell[216285, 5049, 28, 0, 33, "Example"],
Cell[216316, 5051, 228, 5, 54, "Text",
  Evaluatable->False,
  CellTags->{"heat equation", "scaling symmetry"}],
Cell[216547, 5058, 144, 3, 63, "Input"],
Cell[216694, 5063, 183, 6, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[216902, 5073, 250, 5, 63, "Input"],
Cell[217155, 5080, 257, 8, 30, "Output"]
}, Open  ]],
Cell[217427, 5091, 73, 1, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[217525, 5096, 99, 2, 27, "Input"],
Cell[217627, 5100, 88, 1, 41, "Output"]
}, Open  ]],
Cell[217730, 5104, 850, 24, 96, "Text",
  Evaluatable->False,
  CellTags->{"invariants", "reduction procedure"}],
Cell[218583, 5130, 101, 1, 38, "Theorem",
  CellTags->"Theorem: Invariant Representation"],
Cell[218687, 5133, 821, 26, 75, "Text",
  Evaluatable->False,
  CellTags->{"invariant", "infinitesimals"}],
Cell[219511, 5161, 201, 4, 30, "NumberedEquation"],
Cell[219715, 5167, 324, 11, 33, "Text",
  Evaluatable->False,
  CellTags->"invariants of a group"],
Cell[220042, 5180, 299, 6, 75, "Text",
  Evaluatable->False,
  CellTags->{"reduction process", "heat equation"}],

Cell[CellGroupData[{
Cell[220366, 5190, 117, 2, 28, "Input"],
Cell[220486, 5194, 242, 8, 30, "Output"]
}, Open  ]],
Cell[220743, 5205, 1234, 38, 117, "Text",
  Evaluatable->False,
  CellTags->{
  "characteristic equation", "similarity variable", 
    "similarity representation"}],

Cell[CellGroupData[{
Cell[222002, 5247, 144, 3, 38, "Input"],
Cell[222149, 5252, 112, 2, 41, "Output"]
}, Open  ]],
Cell[222276, 5257, 91, 1, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[222392, 5262, 91, 2, 27, "Input"],
Cell[222486, 5266, 931, 24, 69, "Output"]
}, Open  ]],
Cell[223432, 5293, 301, 9, 54, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[223758, 5306, 105, 2, 38, "Input"],
Cell[223866, 5310, 392, 11, 31, "Output"]
}, Open  ]],
Cell[224273, 5324, 727, 15, 117, "Text",
  Evaluatable->False,
  CellTags->{
  "reduced a PDE to an ODE", "invariants of a group", "DSolve[]"}],

Cell[CellGroupData[{
Cell[225025, 5343, 152, 4, 27, "Input"],
Cell[225180, 5349, 324, 6, 102, "Output"]
}, Open  ]],
Cell[225519, 5358, 719, 19, 96, "Text",
  Evaluatable->False,
  CellTags->{"special functions", "group parameter"}],

Cell[CellGroupData[{
Cell[226263, 5381, 394, 8, 95, "Input"],
Cell[226660, 5391, 30007, 941, 233, 11247, 705, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[256682, 6335, 221, 9, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[256928, 6348, 361, 7, 77, "Input"],
Cell[257292, 6357, 27518, 935, 242, 11761, 735, "GraphicsData", "PostScript", \
"Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[284825, 7295, 344, 11, 54, "Text",
  Evaluatable->False,
  CellTags->"heat equation"],

Cell[CellGroupData[{
Cell[285194, 7310, 149, 3, 38, "Input"],
Cell[285346, 7315, 113, 2, 41, "Output"]
}, Open  ]],
Cell[285474, 7320, 177, 5, 33, "Text",
  Evaluatable->False,
  CellTags->"similarity representation"],

Cell[CellGroupData[{
Cell[285676, 7329, 103, 2, 27, "Input"],
Cell[285782, 7333, 274, 5, 94, "Output"]
}, Open  ]],
Cell[286071, 7341, 662, 14, 117, "Text",
  Evaluatable->False,
  CellTags->{"similarity variable", "similarity representation"}],
Cell[286736, 7357, 105, 2, 28, "NumberedEquation"],
Cell[286844, 7361, 566, 19, 75, "Text",
  Evaluatable->False],
Cell[287413, 7382, 1044, 19, 201, "Text",
  Evaluatable->False,
  CellTags->{"LieReduction[]", "similarity representation"}],

Cell[CellGroupData[{
Cell[288482, 7405, 216, 4, 46, "Input"],
Cell[288701, 7411, 797, 21, 101, "Output"]
}, Open  ]],
Cell[289513, 7435, 1026, 25, 138, "Text",
  Evaluatable->False,
  CellTags->{
  "similarity variables", "similarity representation of the solution", 
    "reduction", "potential Burgers equation"}],

Cell[CellGroupData[{
Cell[290564, 7464, 288, 6, 46, "Input"],
Cell[290855, 7472, 1023, 29, 101, "Output"]
}, Open  ]],
Cell[291893, 7504, 245, 6, 54, "Text",
  Evaluatable->False,
  CellTags->"DSolve[]"],

Cell[CellGroupData[{
Cell[292163, 7514, 159, 4, 27, "Input"],
Cell[292325, 7520, 112, 2, 43, "Output"]
}, Open  ]],
Cell[292452, 7525, 586, 18, 75, "Text",
  Evaluatable->False,
  CellTags->"similarity representation"],

Cell[CellGroupData[{
Cell[293063, 7547, 153, 4, 27, "Input"],
Cell[293219, 7553, 140, 2, 46, "Output"]
}, Open  ]],
Cell[293374, 7558, 290, 8, 54, "Text",
  Evaluatable->False,
  CellTags->"solution of the potential Burgers equation"],

Cell[CellGroupData[{
Cell[293689, 7570, 149, 4, 27, "Input"],
Cell[293841, 7576, 181, 4, 46, "Output"]
}, Open  ]],
Cell[294037, 7583, 217, 5, 54, "Text",
  Evaluatable->False],
Cell[294257, 7590, 28, 0, 33, "Example"],
Cell[294288, 7592, 506, 14, 75, "Text",
  Evaluatable->False,
  CellTags->{"two coupled diffusion equations", "LieReduction[]"}],

Cell[CellGroupData[{
Cell[294819, 7610, 189, 3, 45, "Input"],
Cell[295011, 7615, 283, 9, 43, "Output"]
}, Open  ]],
Cell[295309, 7627, 288, 7, 54, "Text",
  Evaluatable->False,
  CellTags->{"infinitesimals", "Infinitesimals[]"}],

Cell[CellGroupData[{
Cell[295622, 7638, 215, 5, 45, "Input"],
Cell[295840, 7645, 2907, 86, 153, "Output"]
}, Open  ]],
Cell[298762, 7734, 614, 17, 96, "Text",
  Evaluatable->False,
  CellTags->"symmetry group"],

Cell[CellGroupData[{
Cell[299401, 7755, 319, 6, 63, "Input"],
Cell[299723, 7763, 43, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[299803, 7769, 372, 7, 63, "Input"],
Cell[300178, 7778, 40, 1, 30, "Output"]
}, Open  ]],
Cell[300233, 7782, 194, 5, 33, "Text",
  Evaluatable->False,
  CellTags->"reduction of the coupled diffusion equations"],

Cell[CellGroupData[{
Cell[300452, 7791, 176, 3, 45, "Input"],
Cell[300631, 7796, 2370, 73, 77, "Output"]
}, Open  ]],
Cell[303016, 7872, 656, 23, 54, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[303697, 7899, 114, 2, 27, "Input"],
Cell[303814, 7903, 1455, 33, 70, "Output"]
}, Open  ]],
Cell[305284, 7939, 618, 13, 117, "Text",
  Evaluatable->False,
  CellTags->{"NDSolve[]", "numerical solution", "initial conditions"}],

Cell[CellGroupData[{
Cell[305927, 7956, 93, 1, 27, "Input"],
Cell[306023, 7959, 1243, 30, 50, "Output"]
}, Open  ]],
Cell[307281, 7992, 111, 4, 33, "Text",
  Evaluatable->False],
Cell[307395, 7998, 553, 14, 27, "Input"],
Cell[307951, 8014, 295, 10, 54, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[308271, 8028, 83, 2, 27, "Input"],
Cell[308357, 8032, 2085, 54, 70, "Output"]
}, Open  ]],
Cell[310457, 8089, 339, 11, 54, "Text",
  Evaluatable->False,
  CellTags->"numerical integration"],

Cell[CellGroupData[{
Cell[310821, 8104, 104, 2, 27, "Input"],
Cell[310928, 8108, 417, 11, 50, "Output"]
}, Open  ]],
Cell[311360, 8122, 206, 5, 54, "Text",
  Evaluatable->False,
  CellTags->"interpolating function"],

Cell[CellGroupData[{
Cell[311591, 8131, 345, 8, 81, "Input"],
Cell[311939, 8141, 17339, 544, 204, 7226, 413, "GraphicsData", "PostScript", \
"Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[329293, 8688, 725, 15, 138, "Text",
  CellTags->"analytic solution"],
Cell[330021, 8705, 28, 0, 33, "Example"],
Cell[330052, 8707, 581, 15, 75, "Text",
  Evaluatable->False,
  CellTags->{"LieReduction[]", "Karpman-Belashov equation"}],
Cell[330636, 8724, 459, 10, 31, "NumberedEquation"],
Cell[331098, 8736, 817, 14, 138, "Text",
  Evaluatable->False,
  CellTags->{
  "Zabolotskaya-Khoklov equation", "KB-equation", 
    "Kadomtsev-Petviashvili equation", 
    "wave in weakly dispersive and dissipative media", "ZK-equation"}],

Cell[CellGroupData[{
Cell[331940, 8754, 428, 8, 65, "Input"],
Cell[332371, 8764, 422, 11, 31, "Output"]
}, Open  ]],
Cell[332808, 8778, 238, 4, 54, "Text",
  Evaluatable->False,
  CellTags->{"KB-equation", "infinitesimals of the KB-equation"}],

Cell[CellGroupData[{
Cell[333071, 8786, 135, 3, 27, "Input"],
Cell[333209, 8791, 1597, 47, 109, "Output"]
}, Open  ]],
Cell[334821, 8841, 3971, 130, 201, "Text",
  Evaluatable->False,
  CellTags->{"infinite-dimensional symmetry group", "subgroup"}],

Cell[CellGroupData[{
Cell[338817, 8975, 191, 3, 45, "Input"],
Cell[339011, 8980, 3867, 79, 297, "Output"]
}, Open  ]],
Cell[342893, 9062, 1475, 49, 138, "Text",
  Evaluatable->False,
  CellTags->{
  "nonlinear partial differential equation of sixth order", "reduction"}],

Cell[CellGroupData[{
Cell[344393, 9115, 190, 3, 45, "Input"],
Cell[344586, 9120, 3175, 64, 201, "Output"]
}, Open  ]],
Cell[347776, 9187, 501, 8, 117, "Text",
  CellTags->{"KB-equation", "sixth-order nonlinear PDE"}],

Cell[CellGroupData[{
Cell[348302, 9199, 92, 1, 27, "Input"],
Cell[348397, 9202, 368, 10, 31, "Output"]
}, Open  ]],
Cell[348780, 9215, 194, 5, 54, "Text",
  CellTags->"reduced KB-equation"],

Cell[CellGroupData[{
Cell[348999, 9224, 138, 3, 27, "Input"],
Cell[349140, 9229, 1597, 47, 109, "Output"]
}, Open  ]],
Cell[350752, 9279, 1241, 40, 96, "Text"],
Cell[351996, 9321, 598, 22, 54, "Text",
  CellTags->"reduction"],

Cell[CellGroupData[{
Cell[352619, 9347, 194, 3, 45, "Input"],
Cell[352816, 9352, 2025, 43, 161, "Output"]
}, Open  ]],
Cell[354856, 9398, 384, 13, 54, "Text",
  CellTags->"fourth-order nonlinear PDE"],
Cell[355243, 9413, 164, 3, 33, "Text",
  CellTags->"KB-equation"],

Cell[CellGroupData[{
Cell[355432, 9420, 121, 2, 27, "Input"],
Cell[355556, 9424, 336, 10, 31, "Output"]
}, Open  ]],
Cell[355907, 9437, 156, 4, 54, "Text",
  CellTags->"ZK-equation"],

Cell[CellGroupData[{
Cell[356088, 9445, 119, 2, 27, "Input"],
Cell[356210, 9449, 1995, 60, 127, "Output"]
}, Open  ]],
Cell[358220, 9512, 690, 16, 96, "Text",
  CellTags->{"infinite symmetry group", "scaling group"}],

Cell[CellGroupData[{
Cell[358935, 9532, 254, 5, 67, "Input"],
Cell[359192, 9539, 3368, 66, 275, "Output"]
}, Open  ]],
Cell[362575, 9608, 198, 4, 54, "Text",
  CellTags->{"third-order nonlinear PDE", "translation"}],

Cell[CellGroupData[{
Cell[362798, 9616, 196, 3, 45, "Input"],
Cell[362997, 9621, 1340, 29, 121, "Output"]
}, Open  ]],
Cell[364352, 9653, 199, 4, 54, "Text",
  CellTags->{"similarity representation", "Lie's procedure"}],

Cell[CellGroupData[{
Cell[364576, 9661, 263, 5, 46, "Input"],
Cell[364842, 9668, 2262, 73, 113, "Output"]
}, Open  ]],
Cell[367119, 9744, 231, 5, 54, "Text",
  CellTags->"finite symmetry group"],

Cell[CellGroupData[{
Cell[367375, 9753, 202, 4, 27, "Input"],
Cell[367580, 9759, 895, 19, 51, "Output"]
}, Open  ]],
Cell[368490, 9781, 325, 7, 75, "Text",
  CellTags->{
  "nonlinear third-order PDE", "second similarity representation", 
    "infinitesimals"}],

Cell[CellGroupData[{
Cell[368840, 9792, 293, 5, 45, "Input"],
Cell[369136, 9799, 40, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[369213, 9805, 252, 4, 45, "Input"],
Cell[369468, 9811, 37, 1, 30, "Output"]
}, Open  ]],
Cell[369520, 9815, 56, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[369601, 9819, 158, 2, 45, "Input"],
Cell[369762, 9823, 1189, 25, 103, "Output"]
}, Open  ]],
Cell[370966, 9851, 345, 10, 54, "Text",
  CellTags->"third-order nonlinear ODE"],

Cell[CellGroupData[{
Cell[371336, 9865, 255, 5, 46, "Input"],
Cell[371594, 9872, 1055, 34, 65, "Output"]
}, Open  ]],
Cell[372664, 9909, 241, 7, 54, "Text"],

Cell[CellGroupData[{
Cell[372930, 9920, 226, 4, 57, "Input"],
Cell[373159, 9926, 505, 13, 51, "Output"]
}, Open  ]],
Cell[373679, 9942, 59, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[373763, 9946, 76, 1, 27, "Input"],
Cell[373842, 9949, 4317, 73, 461, "Output"]
}, Open  ]],
Cell[378174, 10025, 274, 8, 54, "Text",
  CellTags->"Airy"],

Cell[CellGroupData[{
Cell[378473, 10037, 135, 2, 27, "Input"],
Cell[378611, 10041, 475, 12, 51, "Output"]
}, Open  ]],
Cell[379101, 10056, 38, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[379164, 10060, 76, 1, 27, "Input"],
Cell[379243, 10063, 1412, 24, 223, "Output"]
}, Open  ]],
Cell[380670, 10090, 613, 14, 96, "Text",
  CellTags->{"Tan[]", "special function"}],

Cell[CellGroupData[{
Cell[381308, 10108, 581, 10, 81, "Input",
  CellTags->{"AiryBi[]", "AiryBiPrime[]", "AiryAi[]", "AiryAiPrime[]"}],
Cell[381892, 10120, 7077, 138, 684, "Output"]
}, Open  ]],
Cell[388984, 10261, 244, 7, 54, "Text",
  CellTags->"KB-equation"],

Cell[CellGroupData[{
Cell[389253, 10272, 510, 9, 81, "Input"],
Cell[389766, 10283, 1344, 24, 225, "Output"]
}, Open  ]],
Cell[391125, 10310, 91, 1, 33, "Text",
  CellTags->"ZK-equation"],

Cell[CellGroupData[{
Cell[391241, 10315, 125, 2, 27, "Input"],
Cell[391369, 10319, 37, 1, 30, "Output"]
}, Open  ]],
Cell[391421, 10323, 458, 10, 75, "Text",
  CellTags->{"ZK-equation", "symbolic solution"}],
Cell[391882, 10335, 161, 3, 27, "Input"],
Cell[392046, 10340, 48, 0, 33, "Text"],
Cell[392097, 10342, 89, 1, 27, "Input"],
Cell[392189, 10345, 111, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[392325, 10353, 85, 1, 27, "Input"],
Cell[392413, 10356, 68, 1, 42, "Output"]
}, Open  ]],
Cell[392496, 10360, 351, 9, 54, "Text"],

Cell[CellGroupData[{
Cell[392872, 10373, 395, 7, 63, "Input"],

Cell[CellGroupData[{
Cell[393292, 10384, 352109, 6588, 302, 245620, 5268, "GraphicsData", \
"PostScript", "Graphics"],
Cell[745404, 16974, 352338, 6651, 302, 246587, 5340, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1097745, 23627, 353372, 6725, 302, 247860, 5417, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1451120, 30354, 354991, 6790, 302, 248981, 5476, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1806114, 37146, 355049, 6813, 302, 249521, 5505, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2161166, 43961, 355970, 6899, 302, 250632, 5593, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2517139, 50862, 359643, 7009, 302, 252037, 5675, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2876785, 57873, 359011, 7027, 302, 252807, 5711, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3235799, 64902, 359589, 7109, 302, 253980, 5800, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3595391, 72013, 361864, 7182, 302, 255145, 5859, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3957258, 79197, 362741, 7240, 302, 256087, 5918, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4320002, 86439, 364409, 7355, 302, 257719, 6033, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4684414, 93796, 363322, 7366, 302, 257980, 6060, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5047739, 101164, 365475, 7434, 302, 259198, 6117, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5413217, 108600, 368704, 7563, 302, 261293, 6232, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5781924, 116165, 368724, 7612, 302, 261823, 6287, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6150651, 123779, 368929, 7661, 302, 262372, 6340, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[6519607, 131444, 372, 9, 75, "Text",
  CellTags->"ZK-equation"],

Cell[CellGroupData[{
Cell[6520004, 131457, 325, 6, 45, "Input",
  CellTags->"ZK-Soliton"],

Cell[CellGroupData[{
Cell[6520354, 131467, 198072, 3977, 265, 119576, 3003, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6718429, 135446, 198139, 3977, 265, 119719, 3004, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6916571, 139425, 199197, 4014, 265, 120145, 3033, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7115771, 143441, 198835, 4016, 265, 120083, 3039, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7314609, 147459, 199167, 4029, 265, 120828, 3057, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7513779, 151490, 198670, 4034, 265, 120813, 3068, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7712452, 155526, 199645, 4036, 265, 120848, 3058, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7912100, 159564, 199102, 4046, 265, 120982, 3077, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8111205, 163612, 199339, 4037, 265, 120818, 3063, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8310547, 167651, 198278, 4035, 265, 121045, 3077, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8508828, 171688, 198836, 4029, 265, 120614, 3058, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8707667, 175719, 197701, 4025, 265, 120605, 3068, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8905371, 179746, 198018, 4008, 265, 120416, 3045, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9103392, 183756, 198264, 4015, 265, 120528, 3050, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9301659, 187773, 197383, 3984, 265, 119915, 3023, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9499045, 191759, 197534, 3969, 265, 119794, 3004, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9696582, 195730, 196876, 3961, 265, 119865, 3005, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[9893485, 199695, 180, 4, 54, "Text"],
Cell[9893668, 199701, 794, 17, 159, "Text"],
Cell[9894465, 199720, 148, 3, 44, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

